(* ::Package:: *)

BeginPackage["coefhl2`"];

Quiet[Check[ Needs["HPL`"] , Global`HPL::usage="Harmonic Polylogarithm" ] ] ; 


(*
if you don't want to use the HPL.m package, replace the line above by the following lines: 

BeginPackage["coefhl2`"];
HPL::usage="Harmonic Polylogarithm";
*)


Cbar2::usage= 
"Cbar2[case, aOrd, zOrd, x (,options)] returns the corrections of order
alpha_s^aOrd (aOrd=0,1,2) for zOrd-th (zOrd=-1,...,4) moment of the
heavy-light correlator where case defines whether the vector (\"v\"),
axial-vector (\"a\"), scalar (\"s\") or pseudo-scalar (\"p\") currents
are used. These expressions depend only on x=m2/m1, the ratio of the
light (m2) and heavy (m1) MS-bar quark mass.";

CbarL2::usage= 
"CbarL2[case, aOrd, zOrd, xd (,options)] returns the corrections of
order alpha_s^aOrd (aOrd=0,1,2) for zOrd^th (zOrd=-1,...,4) moment of
the longitudinal part of the heavy-light correlator where case defines
whether the vector (\"v\"), or axial-vector (\"a\") currents are
used. These expressions depend only on x=m2/m1, the ratio of the light
(m2) and heavy (m1) MS-bar quark mass.";


Global`ep::usage=
"ep = 1/2(4-d) in d dimensions, refer to manual.";

master3l8a::usage=
"Master integral, refer to manual.";

master3l9a::usage=
"Master integral, refer to manual.";

master3l10a::usage=
"Master integral, refer to manual.";

master3l8b::usage=
"Master integral, refer to manual.";

master3l9b::usage=
"Master integral, refer to manual.";

master3l10b::usage=
"Master integral, refer to manual.";

nc::usage=
"SU(nc)";

ca::usage=
"ca = nc (SU(nc))";

cf::usage=
"cf = (nc^2-1)/(2 nc) (SU(nc))";

(*******************************************)
(* Options *)
(*******************************************)

Options[Cbar2]={
  "solutionType" -> "numeric",
  SU3->True,
  nl->3,
  nh->1,
  nm->1,
  imu->1,
  subtractPoles->True
  };

Options[CbarL2]=Options[Cbar2]


Begin["`Private`"]

ep = Global`ep ;

If[Length[$HPLFunctions] == 0 , HPL = Global`HPL ] ;

(*******************************************)
(* Cbar2 *)
(*******************************************)
Cbar2[case_String,aOrd_Integer,zOrd_Integer,xd_,opts:OptionsPattern[]]:=
Cbar2[case,aOrd,zOrd,xd,opts]=Module[{res},

  If[FreeQ[{"s","p","v","a"},case],

     Print["ERROR: case not implemented; only case = \"s\", \"p\", \"v\" or \"a\" is valid!"];

    Return[Indeterminate]
  ];

  If[aOrd==2 && (zOrd<-1||zOrd>4),

     Print["ERROR: case not implemented; only zOrd = -1, ..., 4 for aOrd = 2 is valid!"];

    Return[Indeterminate]
  ];

  If[aOrd<2 && (zOrd<-1||zOrd>9),

     Print["ERROR: case not implemented; only zOrd = -1, ..., 9 for aOrd = 0,1 is valid!"];

    Return[Indeterminate]
  ];

  If[FreeQ[{"numeric","exact","expansion0","expansion1"},OptionValue["solutionType"]],

     Print["ERROR: unknown "solutionType"."];

    Return[Indeterminate]
  ];

 If[aOrd < 2 && !(opts===Null) && MemberQ[Flatten[List@opts/.Rule->List],"solutionType"] && !(OptionValue["solutionType"]=="exact"),
    Print["ERROR: for aOrd < 2 there is only the exact result available!"];
]


  Which[
    aOrd==0||aOrd==1,
      res=CbarData[case,aOrd,zOrd];

	If[OptionValue[subtractPoles]&&(zOrd==0||zOrd==-1),
	   res=Coefficient[res,ep,0];
       ];
    ,
    aOrd==2,
    Which[
	OptionValue["solutionType"]=="numeric",
	res= Interpolation[CbarTable[case,2,zOrd]][x];
	,
	OptionValue["solutionType"]=="exact",
	res= CbarData[case,2,zOrd];
	,
	OptionValue["solutionType"]=="expansion0",
	res= CbarSeries[case,2,zOrd,"x0"];
	,
	OptionValue["solutionType"]=="expansion1",
	res= CbarSeries[case,2,zOrd,"x1"];
    ];

	If[(!OptionValue[subtractPoles])&&(zOrd==0||zOrd==-1),
       res=res+CbarPoleData[case,2,zOrd];
       ];
    ,
    True,
    Print["ERROR: case not implemented; only aOrd = 0, 1, 2 is valid!"];
    res=Indeterminate
  ];
									       
							       
  res=res/.{lm->Log[OptionValue[imu]^2],NH->OptionValue[nh],NM->OptionValue[nm],NL->OptionValue[nl]};


 If[OptionValue[SU3],
  res=res/.{NC->3,CA->3,CF->4/3};
    ,
  res=res/.{NC->nc,CA->ca,CF->cf};
];



  If[NumericQ[xd] && (xd > 1 || xd < 0),
     res=Indeterminate;
     ,
     res=res/.x->xd;
 ];


  Return[res]
]



(*******************************************)
(* CbarL2 *)
(*******************************************)

CbarL2[case_String,aOrd_Integer,zOrd_Integer,xd_,opts:OptionsPattern[]]:=
CbarL2[case,aOrd,zOrd,xd,opts]=Module[{res},

  If[FreeQ[{"v","a"},case],

     Print["ERROR: for the longitudinal part the case = \"v\" or \"a\" is valid only!"];

    Return[Indeterminate]
  ];

  If[aOrd==2 && (zOrd<-1||zOrd>4),

     Print["ERROR: case not implemented; only zOrd = -1, ..., 4 for aOrd = 2 is valid!"];

    Return[Indeterminate]
  ];

  If[aOrd<2 && (zOrd<-1||zOrd>9),

     Print["ERROR: case not implemented; only zOrd = -1, ..., 9 for aOrd = 0,1 is valid!"];

    Return[Indeterminate]
  ];



 If[aOrd < 2 && !(opts===Null) && MemberQ[Flatten[List@opts/.Rule->List],"solutionType"] && !(OptionValue["solutionType"]=="exact"),
    Print["ERROR: for aOrd < 2 there is only the exact result available!"];
]

  Which[
    aOrd==0||aOrd==1,
      res=CbarLData[case,aOrd,zOrd];
	If[OptionValue[subtractPoles]&&(zOrd==0||zOrd==-1),
	   res=Coefficient[res,ep,0];
       ];
    ,
    aOrd==2,
    Which[
	OptionValue["solutionType"]=="numeric",
	res= Interpolation[CbarLTable[case,2,zOrd]][x];
	,
	OptionValue["solutionType"]=="exact",
	res= CbarLData[case,2,zOrd];
	,
	OptionValue["solutionType"]=="expansion0",
	res= CbarLSeries[case,2,zOrd,"x0"];
	,
	OptionValue["solutionType"]=="expansion1",
	res= CbarLSeries[case,2,zOrd,"x1"];
    ];
	   If[!OptionValue[subtractPoles]&&(zOrd==0||zOrd==-1),
	      res=res+CbarLPoleData[case,2,zOrd];
	  ];
    ,
    True,
    Print["ERROR: case not implemented; only aOrd = 0, 1, 2 is valid!"];
	   res=Indeterminate;
  ];
										
  res=res/.{lm->Log[OptionValue[imu]^2],NH->OptionValue[nh],NM->OptionValue[nm],NL->OptionValue[nl]};
										
	
 If[OptionValue[SU3],
  res=res/.{NC->3,CA->3,CF->4/3};
    ,
  res=res/.{NC->nc,CA->ca,CF->cf};
];


  If[NumericQ[xd] && (xd > 1 || xd < 0),
     res=Indeterminate;
     ,
     res=res/.x->xd;
 ];


  Return[res]
]


(**********************************)
(* data section *)
(**********************************)

(* poles for aOrd=2, zOrd=-1,0; a=2  *)

CbarPoleData["a", 2, -1] = 
    NC*(CF*(((NM + NL + NH)*(1 + x)^2)/(36*ep^3) - 
        (5*(NM + NL + NH)*(1 + x)^2)/(72*ep^2) + 
        ((NM + NL + NH)*(1 + x)^2)/(18*ep)) + 
      CA*CF*((-11*(1 + x)^2)/(72*ep^3) + (83*(1 + x)^2)/(144*ep^2) + 
        ((1 + x)^2*(-77 + 36*Zeta[3]))/(144*ep)) + 
      CF^2*(-(1 + x)^2/(4*ep^3) + (1 + x)^2/(4*ep^2) - 
        ((1 + x)^2*(-119 + 144*Zeta[3]))/(288*ep)))
 
CbarPoleData["a", 2, 0] = NC*(CA*CF*(-11/(216*ep^2) + 133/(1296*ep)) - 
      CF^2/(72*ep) + CF*((NM + NL + NH)/(108*ep^2) - 
        (11*(NM + NL + NH))/(648*ep)))
 
CbarPoleData["p", 2, -1] = 
    NC*(CF*(((NM + NL + NH)*(1 - x + x^2))/(9*ep^3) - 
        (2*(NM + NL + NH)*(1 - x + x^2))/(9*ep^2) + 
        (5*NL*(1 - x + x^2) + NH*(29 - 5*x + 5*x^2) + 
          NM*(5 - 5*x + 29*x^2))/(36*ep)) + 
      CA*CF*((-11*(1 - x + x^2))/(18*ep^3) + (2*(1 - x + x^2))/ep^2 + 
        ((1 - x + x^2)*(-109 + 48*Zeta[3]))/(72*ep)) + 
      CF^2*((-2*(1 - x + x^2))/ep^3 + (5*(1 - x + x^2))/(6*ep^2) - 
        ((1 - x + x^2)*(-131 + 96*Zeta[3]))/(72*ep)))
 
CbarPoleData["p", 2, 0] = 
    NC*(CF*((-NM - NL - NH)/(36*ep^3) + (-NM - NL - NH)/(18*ep) + 
        (5*(NM + NL + NH))/(72*ep^2)) + 
      CA*CF*(11/(72*ep^3) - 83/(144*ep^2) + (77/144 - Zeta[3]/4)/ep) + 
      CF^2*(1/(4*ep^3) - 1/(4*ep^2) + (-119/288 + Zeta[3]/2)/ep))
 
CbarPoleData["s", 2, -1] = 
    NC*(CF*(((NM + NL + NH)*(1 + x + x^2))/(9*ep^3) - 
        (2*(NM + NL + NH)*(1 + x + x^2))/(9*ep^2) + 
        (5*NL*(1 + x + x^2) + NH*(29 + 5*x + 5*x^2) + 
          NM*(5 + 5*x + 29*x^2))/(36*ep)) + 
      CA*CF*((-11*(1 + x + x^2))/(18*ep^3) + (2*(1 + x + x^2))/ep^2 + 
        ((1 + x + x^2)*(-109 + 48*Zeta[3]))/(72*ep)) + 
      CF^2*((-2*(1 + x + x^2))/ep^3 + (5*(1 + x + x^2))/(6*ep^2) - 
        ((1 + x + x^2)*(-131 + 96*Zeta[3]))/(72*ep)))
 
CbarPoleData["s", 2, 0] = 
    NC*(CF*((-NM - NL - NH)/(36*ep^3) + (-NM - NL - NH)/(18*ep) + 
        (5*(NM + NL + NH))/(72*ep^2)) + 
      CA*CF*(11/(72*ep^3) - 83/(144*ep^2) + (77/144 - Zeta[3]/4)/ep) + 
      CF^2*(1/(4*ep^3) - 1/(4*ep^2) + (-119/288 + Zeta[3]/2)/ep))
 
CbarPoleData["v", 2, -1] = 
    NC*(CF*(((NM + NL + NH)*(-1 + x)^2)/(36*ep^3) - 
        (5*(NM + NL + NH)*(-1 + x)^2)/(72*ep^2) + 
        ((NM + NL + NH)*(-1 + x)^2)/(18*ep)) + 
      CA*CF*((-11*(-1 + x)^2)/(72*ep^3) + (83*(-1 + x)^2)/(144*ep^2) + 
        ((-1 + x)^2*(-77 + 36*Zeta[3]))/(144*ep)) + 
      CF^2*(-(-1 + x)^2/(4*ep^3) + (-1 + x)^2/(4*ep^2) - 
        ((-1 + x)^2*(-119 + 144*Zeta[3]))/(288*ep)))
 
CbarPoleData["v", 2, 0] = NC*(CA*CF*(-11/(216*ep^2) + 133/(1296*ep)) - 
      CF^2/(72*ep) + CF*((NM + NL + NH)/(108*ep^2) - 
        (11*(NM + NL + NH))/(648*ep)))
 
CbarLPoleData["a", 2, -1] = 
    NC*(CF*(-((NM + NL + NH)*(1 + x)^2)/(36*ep^3) + 
        (5*(NM + NL + NH)*(1 + x)^2)/(72*ep^2) - 
        ((NM + NL + NH)*(1 + x)^2)/(18*ep)) + 
      CA*CF*((11*(1 + x)^2)/(72*ep^3) - (83*(1 + x)^2)/(144*ep^2) - 
        ((1 + x)^2*(-77 + 36*Zeta[3]))/(144*ep)) + 
      CF^2*((1 + x)^2/(4*ep^3) - (1 + x)^2/(4*ep^2) + 
        ((1 + x)^2*(-119 + 144*Zeta[3]))/(288*ep)))
 
CbarLPoleData["a", 2, 0] = 0
 
CbarLPoleData["v", 2, -1] = 
    NC*(CF*(-((NM + NL + NH)*(-1 + x)^2)/(36*ep^3) + 
        (5*(NM + NL + NH)*(-1 + x)^2)/(72*ep^2) - 
        ((NM + NL + NH)*(-1 + x)^2)/(18*ep)) + 
      CA*CF*((11*(-1 + x)^2)/(72*ep^3) - (83*(-1 + x)^2)/(144*ep^2) - 
        ((-1 + x)^2*(-77 + 36*Zeta[3]))/(144*ep)) + 
      CF^2*((-1 + x)^2/(4*ep^3) - (-1 + x)^2/(4*ep^2) + 
        ((-1 + x)^2*(-119 + 144*Zeta[3]))/(288*ep)))
 
CbarLPoleData["v", 2, 0] = 0


(* scalar  *)

CbarData["s", 0, -1] = (-4*NC*(1 + x + x^2))/(3*ep) - 
     (4*NC*(-1 - lm + x^3 + lm*x^3 - 2*x^3*HPL[{0}, x]))/(3*(-1 + x))
 
CbarData["s", 0, 0] = (2*NC)/(3*ep) + 
     NC*((1 + 2*lm*(-1 + x)^2 - 4*x + x^2)/(3*(-1 + x)^2) - 
       (4*(-2 + x)*x^3*HPL[{0}, x])/(3*(-1 + x)^3*(1 + x)))
 
CbarData["s", 0, 1] = (2*NC*(-1 + 3*x + 3*x^2 - 3*x^4 - 3*x^5 + x^6 + 
       12*x^3*HPL[{0}, x]))/(9*(-1 + x)^5*(1 + x)^3)
 
CbarData["s", 0, 2] = NC*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6)/
       (18*(-1 + x)^6*(1 + x)^4) + (4*x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
       (3*(-1 + x)^7*(1 + x)^5))
 
CbarData["s", 0, 3] = 
    NC*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 5*x^7 - 
         x^8)/(45*(-1 + x)^8*(1 + x)^6) + (8*x^3*(1 + x + 3*x^2 + x^3 + x^4)*
        HPL[{0}, x])/(3*(-1 + x)^9*(1 + x)^7))
 
CbarData["s", 0, 4] = 
    NC*(-(-1 + 6*x + 23*x^2 + 356*x^3 + 398*x^4 + 956*x^5 + 398*x^6 + 
         356*x^7 + 23*x^8 + 6*x^9 - x^10)/(90*(-1 + x)^10*(1 + x)^8) + 
      (4*x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*x^5 + 2*x^6)*HPL[{0}, x])/
       (3*(-1 + x)^11*(1 + x)^9))
 
CbarData["s", 0, 5] = 
    NC*((2*(1 - 7*x - 34*x^2 - 714*x^3 - 1133*x^4 - 3689*x^5 - 2708*x^6 - 
         3689*x^7 - 1133*x^8 - 714*x^9 - 34*x^10 - 7*x^11 + x^12))/
       (315*(-1 + x)^12*(1 + x)^10) + 
      (8*x^3*(1 + 2*x + 10*x^2 + 10*x^3 + 20*x^4 + 10*x^5 + 10*x^6 + 2*x^7 + 
         x^8)*HPL[{0}, x])/(3*(-1 + x)^13*(1 + x)^11))
 
CbarData["s", 0, 6] = 
    NC*(-(-5 + 40*x + 235*x^2 + 6312*x^3 + 12975*x^4 + 53352*x^5 + 
         56095*x^6 + 102352*x^7 + 56095*x^8 + 53352*x^9 + 12975*x^10 + 
         6312*x^11 + 235*x^12 + 40*x^13 - 5*x^14)/(1260*(-1 + x)^14*
        (1 + x)^12) + (4*x^3*(2 + 5*x + 30*x^2 + 40*x^3 + 100*x^4 + 75*x^5 + 
         100*x^6 + 40*x^7 + 30*x^8 + 5*x^9 + 2*x^10)*HPL[{0}, x])/
       (3*(-1 + x)^15*(1 + x)^13))
 
CbarData["s", 0, 7] = 
    NC*(-(-5 + 45*x + 310*x^2 + 10233*x^3 + 25834*x^4 + 128421*x^5 + 
         175774*x^6 + 401841*x^7 + 316894*x^8 + 401841*x^9 + 175774*x^10 + 
         128421*x^11 + 25834*x^12 + 10233*x^13 + 310*x^14 + 45*x^15 - 5*x^16)/
       (1890*(-1 + x)^16*(1 + x)^14) + 
      (8*x^3*(1 + 3*x + 21*x^2 + 35*x^3 + 105*x^4 + 105*x^5 + 175*x^6 + 
         105*x^7 + 105*x^8 + 35*x^9 + 21*x^10 + 3*x^11 + x^12)*HPL[{0}, x])/
       (3*(-1 + x)^17*(1 + x)^15))
 
CbarData["s", 0, 8] = 
    NC*(-(-7 + 70*x + 553*x^2 + 21796*x^3 + 65254*x^4 + 380644*x^5 + 
         641830*x^6 + 1763620*x^7 + 1814890*x^8 + 2874940*x^9 + 
         1814890*x^10 + 1763620*x^11 + 641830*x^12 + 380644*x^13 + 
         65254*x^14 + 21796*x^15 + 553*x^16 + 70*x^17 - 7*x^18)/
       (3780*(-1 + x)^18*(1 + x)^16) + 
      (4*x^3*(2 + 7*x + 56*x^2 + 112*x^3 + 392*x^4 + 490*x^5 + 980*x^6 + 
         784*x^7 + 980*x^8 + 490*x^9 + 392*x^10 + 112*x^11 + 56*x^12 + 
         7*x^13 + 2*x^14)*HPL[{0}, x])/(3*(-1 + x)^19*(1 + x)^17))
 
CbarData["s", 0, 9] = 
    NC*(-(-14 + 154*x + 1372*x^2 + 63173*x^3 + 218798*x^4 + 1465607*x^5 + 
         2936744*x^6 + 9426791*x^7 + 11967920*x^8 + 22737935*x^9 + 
         18759320*x^10 + 22737935*x^11 + 11967920*x^12 + 9426791*x^13 + 
         2936744*x^14 + 1465607*x^15 + 218798*x^16 + 63173*x^17 + 1372*x^18 + 
         154*x^19 - 14*x^20)/(10395*(-1 + x)^20*(1 + x)^18) + 
      (8*x^3*(1 + 4*x + 36*x^2 + 84*x^3 + 336*x^4 + 504*x^5 + 1176*x^6 + 
         1176*x^7 + 1764*x^8 + 1176*x^9 + 1176*x^10 + 504*x^11 + 336*x^12 + 
         84*x^13 + 36*x^14 + 4*x^15 + x^16)*HPL[{0}, x])/
       (3*(-1 + x)^21*(1 + x)^19))
 

CbarData["s", 1, -1] = (2*CF*NC*(1 + x + x^2))/ep^2 - 
     (2*CF*NC*(1 + x + x^2))/(3*ep) - 
     (2*CF*NC*(-5 - 5*lm - 3*lm^2 + 5*x^3 + 5*lm*x^3 + 3*lm^2*x^3 - 
        10*x^3*HPL[{0}, x] - 12*lm*x^3*HPL[{0}, x] + 24*x^3*HPL[{0, 0}, x]))/
      (3*(-1 + x))
 
CbarData["s", 1, 0] = -(CF*NC)/(2*ep^2) + (5*CF*NC)/(12*ep) + 
     CF*NC*(lm^2/2 + (39 - 4*Pi^2 - 198*x + 39*x^2 + 4*Pi^2*x^2)/
        (72*(-1 + x)^2) - (2*x^2*(1 - 5*x + x^2)*HPL[{0}, x])/
        (3*(-1 + x)^3*(1 + x)) + lm*((1 - 5*x + x^2)/(3*(-1 + x)^2) - 
         (2*(-2 + x)*x^3*HPL[{0}, x])/((-1 + x)^3*(1 + x))) - 
       (2*(1 + x)*HPL[{-1, 0}, x])/(3*(-1 + x)) + 
       (8*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
        (3*(-1 + x)^4*(1 + x)^2) + (2*(1 + x)*HPL[{1, 0}, x])/(3*(-1 + x)))
 
CbarData["s", 1, 1] = CF*NC*((3 + 4*Pi^2 - 108*x - 12*Pi^2*x - 66*x^2 - 
        108*x^3 + 12*Pi^2*x^3 + 3*x^4 - 4*Pi^2*x^4)/(108*(-1 + x)^4*
        (1 + x)^2) + (4*x^2*(1 - 6*x + x^2)*HPL[{0}, x])/
       (9*(-1 + x)^5*(1 + x)^3) + (4*(1 - 3*x + x^2)*HPL[{-1, 0}, x])/
       (9*(-1 + x)^3*(1 + x)) - (8*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*
        HPL[{0, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) - 
      (4*(1 - 3*x + x^2)*HPL[{1, 0}, x])/(9*(-1 + x)^3*(1 + x)))
 
CbarData["s", 1, 2] = CF*NC*((9 + 4*Pi^2 - 216*x - 16*Pi^2*x - 381*x^2 - 
        4*Pi^2*x^2 - 336*x^3 - 381*x^4 + 4*Pi^2*x^4 - 216*x^5 + 16*Pi^2*x^5 + 
        9*x^6 - 4*Pi^2*x^6)/(432*(-1 + x)^6*(1 + x)^4) + 
      (x^2*(2 - 122*x - 27*x^2 - 230*x^3 - 22*x^4 - 12*x^5 + 3*x^6)*
        HPL[{0}, x])/(18*(-1 + x)^7*(1 + x)^5) + 
      lm*((-1 + 4*x + 7*x^2 + 40*x^3 + 7*x^4 + 4*x^5 - x^6)/
         (12*(-1 + x)^6*(1 + x)^4) - (2*x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
         ((-1 + x)^7*(1 + x)^5)) + ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0}, x])/
       (9*(-1 + x)^5*(1 + x)^3) - (2*x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 
         136*x^4 - 3*x^5 - 4*x^6 + x^7)*HPL[{0, 0}, x])/
       (9*(-1 + x)^8*(1 + x)^6) - ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/
       (9*(-1 + x)^5*(1 + x)^3))
 
CbarData["s", 1, 3] = CF*NC*((-11 + 4*Pi^2 - 219*x - 20*Pi^2*x - 658*x^2 - 
        8*Pi^2*x^2 + 1479*x^3 - 60*Pi^2*x^3 - 1326*x^4 + 1479*x^5 + 
        60*Pi^2*x^5 - 658*x^6 + 8*Pi^2*x^6 - 219*x^7 + 20*Pi^2*x^7 - 11*x^8 - 
        4*Pi^2*x^8)/(1080*(-1 + x)^8*(1 + x)^6) + 
      (2*x^2*(1 - 263*x - 184*x^2 - 1109*x^3 - 424*x^4 - 683*x^5 - 44*x^6 - 
         15*x^7 + 3*x^8)*HPL[{0}, x])/(45*(-1 + x)^9*(1 + x)^7) + 
      lm*((-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 5*x^7 - 
          x^8)/(15*(-1 + x)^8*(1 + x)^6) - (8*x^3*(1 + x + 3*x^2 + x^3 + x^4)*
          HPL[{0}, x])/((-1 + x)^9*(1 + x)^7)) + 
      (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*HPL[{-1, 0}, x])/
       (45*(-1 + x)^7*(1 + x)^5) - (4*x^3*(-180 - 180*x - 1260*x^2 - 
         800*x^3 - 1940*x^4 - 535*x^5 - 545*x^6 - 4*x^7 - 5*x^8 + x^9)*
        HPL[{0, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) - 
      (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*HPL[{1, 0}, x])/
       (45*(-1 + x)^7*(1 + x)^5))
 
CbarData["s", 1, 4] = CF*NC*((-61 + 6*Pi^2 - 201*x - 36*Pi^2*x - 978*x^2 - 
        18*Pi^2*x^2 + 19344*x^3 - 288*Pi^2*x^3 + 7591*x^4 - 96*Pi^2*x^4 + 
        51570*x^5 + 7591*x^6 + 96*Pi^2*x^6 + 19344*x^7 + 288*Pi^2*x^7 - 
        978*x^8 + 18*Pi^2*x^8 - 201*x^9 + 36*Pi^2*x^9 - 61*x^10 - 
        6*Pi^2*x^10)/(3240*(-1 + x)^10*(1 + x)^8) + 
      (x^2*(2 - 1512*x - 1780*x^2 - 11358*x^3 - 7758*x^4 - 16758*x^5 - 
         5155*x^6 - 4662*x^7 - 214*x^8 - 54*x^9 + 9*x^10)*HPL[{0}, x])/
       (90*(-1 + x)^11*(1 + x)^9) + 
      lm*((-1 + 6*x + 23*x^2 + 356*x^3 + 398*x^4 + 956*x^5 + 398*x^6 + 
          356*x^7 + 23*x^8 + 6*x^9 - x^10)/(20*(-1 + x)^10*(1 + x)^8) - 
        (6*x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*x^5 + 2*x^6)*
          HPL[{0}, x])/((-1 + x)^11*(1 + x)^9)) + 
      ((1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + x^8)*
        HPL[{-1, 0}, x])/(45*(-1 + x)^9*(1 + x)^7) - 
      (2*x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 13200*x^4 - 7055*x^5 - 
         9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 6*x^10 + x^11)*
        HPL[{0, 0}, x])/(45*(-1 + x)^12*(1 + x)^10) - 
      ((1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + x^8)*
        HPL[{1, 0}, x])/(45*(-1 + x)^9*(1 + x)^7))
 
CbarData["s", 1, 5] = CF*NC*((-4519 + 240*Pi^2 + 2230*x - 1680*Pi^2*x - 
        7106*x^2 - 960*Pi^2*x^2 + 2867370*x^3 - 25200*Pi^2*x^3 + 
        2876915*x^4 - 15600*Pi^2*x^4 + 14316800*x^5 - 33600*Pi^2*x^5 + 
        7125020*x^6 + 14316800*x^7 + 33600*Pi^2*x^7 + 2876915*x^8 + 
        15600*Pi^2*x^8 + 2867370*x^9 + 25200*Pi^2*x^9 - 7106*x^10 + 
        960*Pi^2*x^10 + 2230*x^11 + 1680*Pi^2*x^11 - 4519*x^12 - 
        240*Pi^2*x^12)/(226800*(-1 + x)^12*(1 + x)^10) + 
      (x^2*(4 - 6928*x - 11460*x^2 - 81817*x^3 - 81218*x^4 - 217254*x^5 - 
         119018*x^6 - 153217*x^7 - 37836*x^8 - 23896*x^9 - 836*x^10 - 
         168*x^11 + 24*x^12)*HPL[{0}, x])/(315*(-1 + x)^13*(1 + x)^11) + 
      lm*((-4*(1 - 7*x - 34*x^2 - 714*x^3 - 1133*x^4 - 3689*x^5 - 2708*x^6 - 
           3689*x^7 - 1133*x^8 - 714*x^9 - 34*x^10 - 7*x^11 + x^12))/
         (105*(-1 + x)^12*(1 + x)^10) - (16*x^3*(1 + 2*x + 10*x^2 + 10*x^3 + 
           20*x^4 + 10*x^5 + 10*x^6 + 2*x^7 + x^8)*HPL[{0}, x])/
         ((-1 + x)^13*(1 + x)^11)) + 
      (4*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 112*x^7 - 
         3*x^8 - 7*x^9 + x^10)*HPL[{-1, 0}, x])/(315*(-1 + x)^11*(1 + x)^9) - 
      (8*x^3*(-630 - 1260*x - 12285*x^2 - 16310*x^3 - 58975*x^4 - 47040*x^5 - 
         83860*x^6 - 36344*x^7 - 34902*x^8 - 6356*x^9 - 3241*x^10 - 6*x^11 - 
         7*x^12 + x^13)*HPL[{0, 0}, x])/(315*(-1 + x)^14*(1 + x)^12) - 
      (4*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 112*x^7 - 
         3*x^8 - 7*x^9 + x^10)*HPL[{1, 0}, x])/(315*(-1 + x)^11*(1 + x)^9))
 
CbarData["s", 1, 6] = CF*NC*((-33887 + 1200*Pi^2 + 88456*x - 9600*Pi^2*x + 
        357835*x^2 - 6000*Pi^2*x^2 + 38148864*x^3 - 230400*Pi^2*x^3 + 
        58045437*x^4 - 205200*Pi^2*x^4 + 308482680*x^5 - 720000*Pi^2*x^5 + 
        254107015*x^6 - 270000*Pi^2*x^6 + 581132800*x^7 + 254107015*x^8 + 
        270000*Pi^2*x^8 + 308482680*x^9 + 720000*Pi^2*x^9 + 58045437*x^10 + 
        205200*Pi^2*x^10 + 38148864*x^11 + 230400*Pi^2*x^11 + 357835*x^12 + 
        6000*Pi^2*x^12 + 88456*x^13 + 9600*Pi^2*x^13 - 33887*x^14 - 
        1200*Pi^2*x^14)/(1814400*(-1 + x)^14*(1 + x)^12) + 
      (x^2*(10 - 34310*x - 73129*x^2 - 587186*x^3 - 767766*x^4 - 
         2446244*x^5 - 1929345*x^6 - 3181244*x^7 - 1414566*x^8 - 
         1292786*x^9 - 264229*x^10 - 128390*x^11 - 3590*x^12 - 600*x^13 + 
         75*x^14)*HPL[{0}, x])/(1260*(-1 + x)^15*(1 + x)^13) + 
      lm*((-5 + 40*x + 235*x^2 + 6312*x^3 + 12975*x^4 + 53352*x^5 + 
          56095*x^6 + 102352*x^7 + 56095*x^8 + 53352*x^9 + 12975*x^10 + 
          6312*x^11 + 235*x^12 + 40*x^13 - 5*x^14)/(168*(-1 + x)^14*
          (1 + x)^12) - (10*x^3*(2 + 5*x + 30*x^2 + 40*x^3 + 100*x^4 + 
           75*x^5 + 100*x^6 + 40*x^7 + 30*x^8 + 5*x^9 + 2*x^10)*HPL[{0}, x])/
         ((-1 + x)^15*(1 + x)^13)) + 
      ((1 - 8*x - 4*x^2 - 200*x^3 - 175*x^4 - 800*x^5 - 400*x^6 - 800*x^7 - 
         175*x^8 - 200*x^9 - 4*x^10 - 8*x^11 + x^12)*HPL[{-1, 0}, x])/
       (126*(-1 + x)^13*(1 + x)^11) - 
      (x^3*(-1008 - 2520*x - 28224*x^2 - 47432*x^3 - 201488*x^4 - 
         214228*x^5 - 467264*x^6 - 301924*x^7 - 376880*x^8 - 135520*x^9 - 
         99008*x^10 - 15280*x^11 - 6224*x^12 - 7*x^13 - 8*x^14 + x^15)*
        HPL[{0, 0}, x])/(63*(-1 + x)^16*(1 + x)^14) - 
      ((1 - 8*x - 4*x^2 - 200*x^3 - 175*x^4 - 800*x^5 - 400*x^6 - 800*x^7 - 
         175*x^8 - 200*x^9 - 4*x^10 - 8*x^11 + x^12)*HPL[{1, 0}, x])/
       (126*(-1 + x)^13*(1 + x)^11))
 
CbarData["s", 1, 7] = CF*NC*((-106795 + 2800*Pi^2 + 447867*x - 25200*Pi^2*x + 
        2475714*x^2 - 16800*Pi^2*x^2 + 195845265*x^3 - 882000*Pi^2*x^3 + 
        393705676*x^4 - 1019200*Pi^2*x^4 + 2342972583*x^5 - 
        4762800*Pi^2*x^5 + 2676880150*x^6 - 3096800*Pi^2*x^6 + 
        7136097885*x^7 - 4410000*Pi^2*x^7 + 4801356910*x^8 + 7136097885*x^9 + 
        4410000*Pi^2*x^9 + 2676880150*x^10 + 3096800*Pi^2*x^10 + 
        2342972583*x^11 + 4762800*Pi^2*x^11 + 393705676*x^12 + 
        1019200*Pi^2*x^12 + 195845265*x^13 + 882000*Pi^2*x^13 + 
        2475714*x^14 + 16800*Pi^2*x^14 + 447867*x^15 + 25200*Pi^2*x^15 - 
        106795*x^16 - 2800*Pi^2*x^16)/(6350400*(-1 + x)^16*(1 + x)^14) + 
      (x^2*(15 - 92115*x - 240375*x^2 - 2157813*x^3 - 3507887*x^4 - 
         12971727*x^5 - 13369639*x^6 - 26775333*x^7 - 17179879*x^8 - 
         20354067*x^9 - 7556267*x^10 - 5348889*x^11 - 929523*x^12 - 
         367191*x^13 - 8490*x^14 - 1215*x^15 + 135*x^16)*HPL[{0}, x])/
       (2835*(-1 + x)^17*(1 + x)^15) + 
      lm*((-5 + 45*x + 310*x^2 + 10233*x^3 + 25834*x^4 + 128421*x^5 + 
          175774*x^6 + 401841*x^7 + 316894*x^8 + 401841*x^9 + 175774*x^10 + 
          128421*x^11 + 25834*x^12 + 10233*x^13 + 310*x^14 + 45*x^15 - 
          5*x^16)/(210*(-1 + x)^16*(1 + x)^14) - 
        (24*x^3*(1 + 3*x + 21*x^2 + 35*x^3 + 105*x^4 + 105*x^5 + 175*x^6 + 
           105*x^7 + 105*x^8 + 35*x^9 + 21*x^10 + 3*x^11 + x^12)*HPL[{0}, x])/
         ((-1 + x)^17*(1 + x)^15)) + 
      ((1 - 9*x - 5*x^2 - 324*x^3 - 369*x^4 - 2025*x^5 - 1475*x^6 - 
         3600*x^7 - 1475*x^8 - 2025*x^9 - 369*x^10 - 324*x^11 - 5*x^12 - 
         9*x^13 + x^14)*HPL[{-1, 0}, x])/(189*(-1 + x)^15*(1 + x)^13) - 
      (2*x^3*(-1512 - 4536*x - 57456*x^2 - 116928*x^3 - 571536*x^4 - 
         760284*x^5 - 1963332*x^6 - 1687392*x^7 - 2595348*x^8 - 1393476*x^9 - 
         1332072*x^10 - 407616*x^11 - 239976*x^12 - 32103*x^13 - 10881*x^14 - 
         8*x^15 - 9*x^16 + x^17)*HPL[{0, 0}, x])/(189*(-1 + x)^18*
        (1 + x)^16) - ((1 - 9*x - 5*x^2 - 324*x^3 - 369*x^4 - 2025*x^5 - 
         1475*x^6 - 3600*x^7 - 1475*x^8 - 2025*x^9 - 369*x^10 - 324*x^11 - 
         5*x^12 - 9*x^13 + x^14)*HPL[{1, 0}, x])/(189*(-1 + x)^15*(1 + x)^13))
 
CbarData["s", 1, 8] = CF*NC*((-31297299 + 646800*Pi^2 + 173472090*x - 
        6468000*Pi^2*x + 1222395471*x^2 - 5821200*Pi^2*x^2 + 
        87403060140*x^3 - 297528000*Pi^2*x^3 + 215840145675*x^4 - 
        430122000*Pi^2*x^4 + 1284273131130*x^5 - 1920996000*Pi^2*x^5 + 
        1693380533625*x^6 - 1406790000*Pi^2*x^6 + 3725105017920*x^7 - 
        310464000*Pi^2*x^7 + 1918673573850*x^8 + 2095632000*Pi^2*x^8 - 
        1072346384340*x^9 + 7606368000*Pi^2*x^9 - 3829085351322*x^10 + 
        3803184000*Pi^2*x^10 - 8049216593880*x^11 - 3829085351322*x^12 - 
        3803184000*Pi^2*x^12 - 1072346384340*x^13 - 7606368000*Pi^2*x^13 + 
        1918673573850*x^14 - 2095632000*Pi^2*x^14 + 3725105017920*x^15 + 
        310464000*Pi^2*x^15 + 1693380533625*x^16 + 1406790000*Pi^2*x^16 + 
        1284273131130*x^17 + 1920996000*Pi^2*x^17 + 215840145675*x^18 + 
        430122000*Pi^2*x^18 + 87403060140*x^19 + 297528000*Pi^2*x^19 + 
        1222395471*x^20 + 5821200*Pi^2*x^20 + 173472090*x^21 + 
        6468000*Pi^2*x^21 - 31297299*x^22 - 646800*Pi^2*x^22)/
       (2095632000*(-1 + x)^20*(1 + x)^18) + 
      (x^2*((462*(-1 + x)^2)/(1 + x)^17 - (4711476*(-1 + x)^2*x)/(1 + x)^17 - 
         (14551812*(-1 + x)^2*x^2)/(1 + x)^17 - (144839838*(-1 + x)^2*x^3)/
          (1 + x)^17 - (281860942*(-1 + x)^2*x^4)/(1 + x)^17 - 
         (1186726046*(-1 + x)^2*x^5)/(1 + x)^17 - (1511489452*(-1 + x)^2*x^6)/
          (1 + x)^17 - (3556217170*(-1 + x)^2*x^7)/(1 + x)^17 - 
         (2982067022*(-1 + x)^2*x^8)/(1 + x)^17 - (4326361930*(-1 + x)^2*x^9)/
          (1 + x)^17 - (2324420032*(-1 + x)^2*x^10)/(1 + x)^17 - 
         (2145128414*(-1 + x)^2*x^11)/(1 + x)^17 - 
         (681428110*(-1 + x)^2*x^12)/(1 + x)^17 - (393521502*(-1 + x)^2*x^13)/
          (1 + x)^17 - (59389605*(-1 + x)^2*x^14)/(1 + x)^17 - 
         (19767594*(-1 + x)^2*x^15)/(1 + x)^17 - (387618*(-1 + x)^2*x^16)/
          (1 + x)^17 - (48510*(-1 + x)^2*x^17)/(1 + x)^17 + 
         (4851*(-1 + x)^2*x^18)/(1 + x)^17)*HPL[{0}, x])/
       (124740*(-1 + x)^21) + lm*((-539 + 5390*x + 43659*x^2 + 1667512*x^3 + 
          4938857*x^4 + 25958394*x^5 + 39414375*x^6 + 78857856*x^7 + 
          45929268*x^8 - 20917512*x^9 - 90325620*x^10 - 171143280*x^11 - 
          90325620*x^12 - 20917512*x^13 + 45929268*x^14 + 78857856*x^15 + 
          39414375*x^16 + 25958394*x^17 + 4938857*x^18 + 1667512*x^19 + 
          43659*x^20 + 5390*x^21 - 539*x^22)/(27720*(-1 + x)^20*(1 + x)^18) + 
        (2*x^3*(-14 - 49*x - 364*x^2 - 686*x^3 - 1974*x^4 - 1911*x^5 - 
           1764*x^6 + 588*x^7 + 4116*x^8 + 4116*x^9 + 4116*x^10 + 588*x^11 - 
           1764*x^12 - 1911*x^13 - 1974*x^14 - 686*x^15 - 364*x^16 - 
           49*x^17 - 14*x^18)*HPL[{0}, x])/((-1 + x)^21*(1 + x)^19)) + 
      ((1 - 10*x - 6*x^2 - 490*x^3 - 686*x^4 - 4410*x^5 - 4214*x^6 - 
         12250*x^7 - 7350*x^8 - 12250*x^9 - 4214*x^10 - 4410*x^11 - 
         686*x^12 - 490*x^13 - 6*x^14 - 10*x^15 + x^16)*HPL[{-1, 0}, x])/
       (270*(-1 + x)^17*(1 + x)^15) + 
      (x^3*(166320 + 582120*x + 7900200*x^2 + 18516960*x^3 + 92584800*x^4 + 
         135232020*x^5 + 309909600*x^6 + 229108572*x^7 + 89369280*x^8 - 
         212749152*x^9 - 658479360*x^10 - 505028832*x^11 - 397763520*x^12 + 
         21505407*x^13 + 291695250*x^14 + 236569795*x^15 + 226087400*x^16 + 
         71555638*x^17 + 37164820*x^18 + 4706702*x^19 + 1364440*x^20 + 
         847*x^21 + 770*x^22 - 77*x^23)*HPL[{0, 0}, x])/
       (10395*(-1 + x)^22*(1 + x)^20) - 
      ((1 - 10*x - 6*x^2 - 490*x^3 - 686*x^4 - 4410*x^5 - 4214*x^6 - 
         12250*x^7 - 7350*x^8 - 12250*x^9 - 4214*x^10 - 4410*x^11 - 
         686*x^12 - 490*x^13 - 6*x^14 - 10*x^15 + x^16)*HPL[{1, 0}, x])/
       (270*(-1 + x)^17*(1 + x)^15))
 
CbarData["s", 1, 9] = CF*NC*((-27701012 + 470400*Pi^2 + 187515732*x - 
        5174400*Pi^2*x + 1453840496*x^2 - 3763200*Pi^2*x^2 + 
        113081223276*x^3 - 325987200*Pi^2*x^3 + 334336181652*x^4 - 
        546134400*Pi^2*x^4 + 2499525966240*x^5 - 3725568000*Pi^2*x^5 + 
        4431271644768*x^6 - 4244889600*Pi^2*x^6 + 15561582225504*x^7 - 
        12170188800*Pi^2*x^7 + 17815490005824*x^8 - 8021260800*Pi^2*x^8 + 
        36958906813248*x^9 - 9127641600*Pi^2*x^9 + 27790760408544*x^10 + 
        36958906813248*x^11 + 9127641600*Pi^2*x^11 + 17815490005824*x^12 + 
        8021260800*Pi^2*x^12 + 15561582225504*x^13 + 12170188800*Pi^2*x^13 + 
        4431271644768*x^14 + 4244889600*Pi^2*x^14 + 2499525966240*x^15 + 
        3725568000*Pi^2*x^15 + 334336181652*x^16 + 546134400*Pi^2*x^16 + 
        113081223276*x^17 + 325987200*Pi^2*x^17 + 1453840496*x^18 + 
        3763200*Pi^2*x^18 + 187515732*x^19 + 5174400*Pi^2*x^19 - 
        27701012*x^20 - 470400*Pi^2*x^20)/(2095632000*(-1 + x)^20*
        (1 + x)^18) + (x^2*(336/(1 + x)^19 - (5371296*x)/(1 + x)^19 - 
         (19168428*x^2)/(1 + x)^19 - (209821182*x^3)/(1 + x)^19 - 
         (475866736*x^4)/(1 + x)^19 - (2247647092*x^5)/(1 + x)^19 - 
         (3410766282*x^6)/(1 + x)^19 - (9211517924*x^7)/(1 + x)^19 - 
         (9539686250*x^8)/(1 + x)^19 - (16352360052*x^9)/(1 + x)^19 - 
         (11495609450*x^10)/(1 + x)^19 - (13045127396*x^11)/(1 + x)^19 - 
         (6011744970*x^12)/(1 + x)^19 - (4540468084*x^13)/(1 + x)^19 - 
         (1258635184*x^14)/(1 + x)^19 - (613722174*x^15)/(1 + x)^19 - 
         (81787116*x^16)/(1 + x)^19 - (23520768*x^17)/(1 + x)^19 - 
         (398832*x^18)/(1 + x)^19 - (44352*x^19)/(1 + x)^19 + 
         (4032*x^20)/(1 + x)^19)*HPL[{0}, x])/(124740*(-1 + x)^21) + 
      lm*((-448 + 4928*x + 43904*x^2 + 2021536*x^3 + 7001536*x^4 + 
          46899424*x^5 + 93975808*x^6 + 301657312*x^7 + 382973440*x^8 + 
          727613920*x^9 + 600298240*x^10 + 727613920*x^11 + 382973440*x^12 + 
          301657312*x^13 + 93975808*x^14 + 46899424*x^15 + 7001536*x^16 + 
          2021536*x^17 + 43904*x^18 + 4928*x^19 - 448*x^20)/
         (27720*(-1 + x)^20*(1 + x)^18) + 
        (2*x^3*(-16 - 64*x - 576*x^2 - 1344*x^3 - 5376*x^4 - 8064*x^5 - 
           18816*x^6 - 18816*x^7 - 28224*x^8 - 18816*x^9 - 18816*x^10 - 
           8064*x^11 - 5376*x^12 - 1344*x^13 - 576*x^14 - 64*x^15 - 16*x^16)*
          HPL[{0}, x])/((-1 + x)^21*(1 + x)^19)) + 
      (4*(1 - 11*x - 7*x^2 - 704*x^3 - 1168*x^4 - 8624*x^5 - 10192*x^6 - 
         34496*x^7 - 27244*x^8 - 53900*x^9 - 27244*x^10 - 34496*x^11 - 
         10192*x^12 - 8624*x^13 - 1168*x^14 - 704*x^15 - 7*x^16 - 11*x^17 + 
         x^18)*HPL[{-1, 0}, x])/(1485*(-1 + x)^19*(1 + x)^17) + 
      (x^3*(166320 + 665280*x + 10395000*x^2 + 28551600*x^3 + 176437800*x^4 + 
         329341320*x^5 + 1116062640*x^6 + 1436583456*x^7 + 3044908944*x^8 + 
         2715414240*x^9 + 3825467184*x^10 + 2329315296*x^11 + 
         2232365520*x^12 + 888185760*x^13 + 576206400*x^14 + 135372160*x^15 + 
         57331120*x^16 + 6051584*x^17 + 1534456*x^18 + 560*x^19 + 616*x^20 - 
         56*x^21)*HPL[{0, 0}, x])/(10395*(-1 + x)^22*(1 + x)^20) - 
      (4*(1 - 11*x - 7*x^2 - 704*x^3 - 1168*x^4 - 8624*x^5 - 10192*x^6 - 
         34496*x^7 - 27244*x^8 - 53900*x^9 - 27244*x^10 - 34496*x^11 - 
         10192*x^12 - 8624*x^13 - 1168*x^14 - 704*x^15 - 7*x^16 - 11*x^17 + 
         x^18)*HPL[{1, 0}, x])/(1485*(-1 + x)^19*(1 + x)^17))
 

CbarData["s",2,-1] = NC*(CA*CF*((-11*lm^3*(1 + x + x^2))/18 + 
        lm^2*((-38*(1 + x + x^2))/9 + (11*x^3*HPL[{0}, x])/(3*(-1 + x))) + 
        (304*x^3*HPL[{0, 0}, x])/(9 - 9*x) + (88*x^3*HPL[{0, 0, 0}, x])/
         (3*(-1 + x)) - (x^3*HPL[{0}, x]*(-247 + 48*Zeta[3]))/(12*(-1 + x)) + 
        lm*((152*x^3*HPL[{0}, x])/(9*(-1 + x)) + (44*x^3*HPL[{0, 0}, x])/
           (3 - 3*x) + ((1 + x + x^2)*(-247 + 48*Zeta[3]))/24) - 
        ((1 + x + x^2)*(88*Pi^4 + 480*Pi^2*Log[2]^2 - 
           15*(-749 + 32*Log[2]^4 + 768*PolyLog[4, 1/2] + 392*Zeta[3])))/
         1080) + CF^2*(-2*lm^3*(1 + x + x^2) + 
        lm^2*((-9*(1 + x + x^2))/4 + (12*x^3*HPL[{0}, x])/(-1 + x)) - 
        (18*x^3*HPL[{0, 0}, x])/(-1 + x) + (96*x^3*HPL[{0, 0, 0}, x])/
         (-1 + x) + (x^3*HPL[{0}, x]*(-5 + 96*Zeta[3]))/(12*(-1 + x)) + 
        lm*((9*x^3*HPL[{0}, x])/(-1 + x) - (48*x^3*HPL[{0, 0}, x])/(-1 + x) - 
          ((1 + x + x^2)*(-5 + 96*Zeta[3]))/24) + 
        ((1 + x + x^2)*(176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           15*(-139 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 1008*Zeta[3])))/
         1080) + CF*(NL*((lm^3*(1 + x + x^2))/9 + (5*x^3*HPL[{0}, x])/
           (2 - 2*x) + lm^2*((5*(1 + x + x^2))/9 + (2*x^3*HPL[{0}, x])/
             (3 - 3*x)) + (40*x^3*HPL[{0, 0}, x])/(9*(-1 + x)) + 
          lm*((5*(1 + x + x^2))/4 + (20*x^3*HPL[{0}, x])/(9 - 9*x) + 
            (8*x^3*HPL[{0, 0}, x])/(3*(-1 + x))) + (16*x^3*HPL[{0, 0, 0}, x])/
           (3 - 3*x) + ((1 + x + x^2)*(45 + 32*Zeta[3]))/36) + 
        NH*((lm^3*(1 + x + x^2))/9 + (x*(8 + 15*x^2)*HPL[{0}, x])/
           (6 - 6*x) + lm^2*((5*(1 + x + x^2))/9 + (2*x^3*HPL[{0}, x])/
             (3 - 3*x)) + (4*x*(3 + 10*x^2)*HPL[{0, 0}, x])/(9*(-1 + x)) + 
          lm*((13 + 5*x + 5*x^2)/4 + (20*x^3*HPL[{0}, x])/(9 - 9*x) + 
            (8*x^3*HPL[{0, 0}, x])/(3*(-1 + x))) + 
          ((2 + 6*x^2 + 8*x^3)*HPL[{-1, 0, 0}, x])/(3 - 3*x) + 
          (2*(1 + x + 4*x^2)*HPL[{1, 0, 0}, x])/3 + 
          (-125 + 80*x + 112*Zeta[3] + x^3*(45 + 32*Zeta[3]))/
           (36*(-1 + x))) + NM*((lm^3*(1 + x + x^2))/9 + 
          ((16 - 39*x)*x^2*HPL[{0}, x])/(6*(-1 + x)) + 
          lm^2*((5*(1 + x + x^2))/9 + (2*x^3*HPL[{0}, x])/(3 - 3*x)) + 
          (4*x^2*(-3 + 10*x)*HPL[{0, 0}, x])/(9*(-1 + x)) + 
          lm*((5 + 5*x + 13*x^2)/4 + (20*x^3*HPL[{0}, x])/(9 - 9*x) + 
            (8*x^3*HPL[{0, 0}, x])/(3*(-1 + x))) + 
          (2*(4 + 3*x + x^3)*HPL[{-1, 0, 0}, x])/(3*(-1 + x)) + 
          (16*x^3*HPL[{0, 0, 0}, x])/(3 - 3*x) + 
          (2*(4 + x + x^2)*HPL[{1, 0, 0}, x])/3 - 
          (45 + 80*x^2 + 32*Zeta[3] + x^3*(-125 + 112*Zeta[3]))/
           (36*(-1 + x)))));

CbarData["s",2,0] = NC*(CF^2*(lm^3/4 + (Pi^2*(1 + x^2)*HPL[{-2}, x])/(9*(-1 + x)^2) + 
        lm^2*((-7 + 2*x - 7*x^2)/(16*(-1 + x)^2) - 
          (3*(-2 + x)*x^3*HPL[{0}, x])/(2*(-1 + x)^3*(1 + x))) - 
        (Pi^2*(1 + x^2)*HPL[{2}, x])/(9*(-1 + x)^2) + 
        (x^2*(6 + 12*x - 57*x^2 - 39*x^3 + 46*x^4 + 22*x^5 - 22*x^6 + x^7 + 
           5*x^8 - 2*x^9)*HPL[{-2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        ((12 - 30*x + 12*x^2 + (-181 + 12*Pi^2)*x^3 - 6*x^4 + 554*x^5 - 
           6*x^6 - (181 + 12*Pi^2)*x^7 + 12*x^8 - 30*x^9 + 12*x^10)*
          HPL[{-1, 0}, x])/(108*(-1 + x)^3*x^3*(1 + x)) - 
        (x^2*(384 + 747*x - 99*x^2 + 1746*x^3 - 3923*x^4 - 15*x^6 + 6*x^7)*
          HPL[{0, 0}, x])/(27*(-1 + x)^4*(1 + x)^2) + 
        ((-12 + 30*x - 12*x^2 + (181 - 12*Pi^2)*x^3 + 6*x^4 - 554*x^5 + 
           6*x^6 + (181 + 12*Pi^2)*x^7 - 12*x^8 + 30*x^9 - 12*x^10)*
          HPL[{1, 0}, x])/(108*(-1 + x)^3*x^3*(1 + x)) + 
        (x^2*(-6 - 12*x + 57*x^2 + 39*x^3 - 46*x^4 - 22*x^5 + 22*x^6 - x^7 - 
           5*x^8 + 2*x^9)*HPL[{2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) - 
        (4*(1 + x^2)*HPL[{-2, -1, 0}, x])/(3*(-1 + x)^2) + 
        (8*(1 + x^2)*HPL[{-2, 0, 0}, x])/(3*(-1 + x)^2) + 
        (4*(1 + x^2)*HPL[{-2, 1, 0}, x])/(3*(-1 + x)^2) + 
        (4*(1 + x^2)*HPL[{-1, -2, 0}, x])/(3*(-1 + x)^2) + 
        ((-2 + x + x^2 - 11*x^3 - 5*x^4 + 5*x^6 + 11*x^7 - x^8 - x^9 + 
           2*x^10)*HPL[{-1, -1, 0}, x])/(18*x^5) - 
        ((56 - 91*x + 51*x^2 - 39*x^3 + 69*x^4 - 39*x^5 + x^6 + 15*x^7 - 
           9*x^8 + 2*x^9)*HPL[{-1, 0, 0}, x])/(9*(-1 + x)^4) + 
        ((2 - x - x^2 + 11*x^3 + 5*x^4 - 5*x^6 - 11*x^7 + x^8 + x^9 - 2*x^10)*
          HPL[{-1, 1, 0}, x])/(18*x^5) - (4*(1 + x^2)*HPL[{-1, 2, 0}, x])/
         (3*(-1 + x)^2) + (2*x^2*(3 + 366*x - 309*x^2 - 828*x^3 + 1415*x^4 + 
           652*x^5 - 1155*x^6 - 21*x^7 + 27*x^8 - 3*x^9 - 5*x^10 + 2*x^11)*
          HPL[{0, 0, 0}, x])/(9*(-1 + x)^5*(1 + x)^3) - 
        (4*(1 + x^2)*HPL[{1, -2, 0}, x])/(3*(-1 + x)^2) + 
        ((2 - x - x^2 + 11*x^3 + 5*x^4 - 5*x^6 - 11*x^7 + x^8 + x^9 - 2*x^10)*
          HPL[{1, -1, 0}, x])/(18*x^5) + 
        ((56 + 85*x + 39*x^2 - 3*x^3 - 3*x^4 + 9*x^5 + 13*x^6 - 5*x^7 - x^8 + 
           2*x^9)*HPL[{1, 0, 0}, x])/(9*(-1 + x^2)^2) + 
        ((-2 + x + x^2 - 11*x^3 - 5*x^4 + 5*x^6 + 11*x^7 - x^8 - x^9 + 
           2*x^10)*HPL[{1, 1, 0}, x])/(18*x^5) + 
        (4*(1 + x^2)*HPL[{1, 2, 0}, x])/(3*(-1 + x)^2) + 
        (4*(1 + x^2)*HPL[{2, -1, 0}, x])/(3*(-1 + x)^2) - 
        (8*(1 + x^2)*HPL[{2, 0, 0}, x])/(3*(-1 + x)^2) - 
        (4*(1 + x^2)*HPL[{2, 1, 0}, x])/(3*(-1 + x)^2) + 
        (8*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/(3*(-1 + x)^2) + 
        (8*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/(3*(-1 + x)^2) - 
        ((1 + 3*x - x^2 + x^3)*master3l10a[x])/(12*(-1 + x)^3*(1 + x)) + 
        (x*(1 - x + 3*x^2 + x^3)*master3l10b[x])/(12*(-1 + x)^3*(1 + x)) + 
        ((11 + 6*x - x^2)*master3l8a[x])/(12*(-1 + x)^4*(1 + x)^2) + 
        ((5 + 18*x - 39*x^2)*master3l8b[x])/(36*(-1 + x)^4*(1 + x)^2) - 
        ((-9 + x^2)*master3l9a[x])/(3*(-1 + x)^4*(1 + x)^2) + 
        ((1 - 9*x^2)*master3l9b[x])/(9*(-1 + x)^4*(1 + x)^2) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 
             11*x^6 + x^8 + 2*x^9) - 288*x^5*(1 + x^2)*Zeta[3]))/
         (216*(-1 + x)^2*x^5) + (HPL[{-1}, x]*
          (-(Pi^2*(-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 11*x^6 + 
              x^8 + 2*x^9)) + 288*x^5*(1 + x^2)*Zeta[3]))/
         (216*(-1 + x)^2*x^5) + (HPL[{0}, x]*(-24 + 60*x - 12*x^2 - 
           4*(-2947 + 6*Pi^2)*x^3 + (24 - 88*Pi^2)*x^8 + 88*Pi^2*x^9 - 
           4*Pi^2*x^10 - 20*Pi^2*x^11 + 8*Pi^2*x^12 - 
           6*x^4*(-2283 + 8*Pi^2 + 576*Zeta[3]) + 6*x^6*(1499 + 26*Pi^2 + 
             576*Zeta[3]) - x^7*(21885 + 184*Pi^2 + 1728*Zeta[3]) + 
           x^5*(-12643 + 228*Pi^2 + 1728*Zeta[3])))/(432*(-1 + x)^4*x*
          (1 + x)^2) + lm*((x^2*(-4 - 2*x + 7*x^2)*HPL[{0}, x])/
           (4*(-1 + x)^3*(1 + x)) + ((1 + x)*HPL[{-1, 0}, x])/(1 - x) + 
          (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
           ((-1 + x)^4*(1 + x)^2) + ((1 + x)*HPL[{1, 0}, x])/(-1 + x) + 
          (-95 + 8*Pi^2*(-1 + x^2) + x*(82 - 288*Zeta[3]) + 144*Zeta[3] + 
            x^2*(-95 + 144*Zeta[3]))/(96*(-1 + x)^2)) - 
        (24*Pi^4*x^3*(-1 + x^2)^2*(39 - 88*x + 39*x^2) + 10*Pi^2*(-1 + x^2)*
           (12 - 30*x + 12*x^2 + 554*x^5 + 12*x^8 - 30*x^9 + 12*x^10 + 
            6*x^4*(-1 + 192*Log[2]^2) - 6*x^6*(1 + 192*Log[2]^2) + 
            x^7*(-181 + 576*Log[2]^2) - x^3*(181 + 576*Log[2]^2)) + 
          15*x^2*(-12 + 528*x^9*Zeta[3] - 24*x^10*Zeta[3] - 
            120*x^11*Zeta[3] + 48*x^12*Zeta[3] - 12*x^8*(1 + 44*Zeta[3]) + 
            3*x^2*(377 + 256*Log[2]^4 + 6144*PolyLog[4, 1/2] + 
              4072*Zeta[3]) - 6*x^4*(-2927 + 256*Log[2]^4 + 6144*PolyLog[4, 
                1/2] + 4192*Zeta[3]) + 3*x^6*(377 + 256*Log[2]^4 + 
              6144*PolyLog[4, 1/2] + 4384*Zeta[3]) + 
            x^3*(10405 + 384*Log[2]^4 + 9216*PolyLog[4, 1/2] + 
              6288*Zeta[3]) + x^5*(-17675 + 384*Log[2]^4 + 9216*PolyLog[4, 
                1/2] + 6504*Zeta[3]) - x*(-14255 + 384*Log[2]^4 + 
              9216*PolyLog[4, 1/2] + 9096*Zeta[3]) - 
            x^7*(6625 + 384*Log[2]^4 + 9216*PolyLog[4, 1/2] + 9768*Zeta[3])))/
         (12960*(-1 + x)^4*x^3*(1 + x)^2)) + 
      CA*CF*((11*lm^3)/72 - (Pi^2*(1 + x^2)*HPL[{-2}, x])/(18*(-1 + x)^2) + 
        lm^2*((119 - 304*x + 119*x^2)/(144*(-1 + x)^2) - 
          (11*(-2 + x)*x^3*HPL[{0}, x])/(12*(-1 + x)^3*(1 + x))) + 
        (Pi^2*(1 + x^2)*HPL[{2}, x])/(18*(-1 + x)^2) - 
        (x^2*(6 + 6*x - 42*x^2 - 21*x^3 + 31*x^4 + 6*x^5 - 9*x^6 + 3*x^7)*
          HPL[{-2, 0}, x])/(18*(-1 + x)^4*(1 + x)^2) + 
        ((6 - (161 + 4*Pi^2)*x - 12*x^2 + 294*x^3 - 12*x^4 + 
           (-161 + 4*Pi^2)*x^5 + 6*x^6)*HPL[{-1, 0}, x])/
         (72*(-1 + x)^3*x*(1 + x)) + (x^2*(326 + 1666*x - 711*x^2 + 598*x^3 - 
           2229*x^4 - 6*x^5)*HPL[{0, 0}, x])/(36*(-1 + x)^4*(1 + x)^2) + 
        ((-6 + (161 + 4*Pi^2)*x + 12*x^2 - 294*x^3 + 12*x^4 + 
           (161 - 4*Pi^2)*x^5 - 6*x^6)*HPL[{1, 0}, x])/(72*(-1 + x)^3*x*
          (1 + x)) + (x^2*(6 + 6*x - 42*x^2 - 21*x^3 + 31*x^4 + 6*x^5 - 
           9*x^6 + 3*x^7)*HPL[{2, 0}, x])/(18*(-1 + x)^4*(1 + x)^2) + 
        (2*(1 + x^2)*HPL[{-2, -1, 0}, x])/(3*(-1 + x)^2) - 
        (8*x^2*HPL[{-2, 0, 0}, x])/(3*(-1 + x)^2) - 
        (2*(1 + x^2)*HPL[{-2, 1, 0}, x])/(3*(-1 + x)^2) - 
        (2*(1 + x^2)*HPL[{-1, -2, 0}, x])/(3*(-1 + x)^2) + 
        ((3 - 6*x + 6*x^2 + 41*x^3 + 41*x^4 + 6*x^5 - 6*x^6 + 3*x^7)*
          HPL[{-1, -1, 0}, x])/(36*(-1 + x)*x^3) + 
        ((67 - 119*x + 129*x^2 - 149*x^3 + 109*x^4 - 33*x^5 + 15*x^6 - 3*x^7)*
          HPL[{-1, 0, 0}, x])/(18*(-1 + x)^4) - 
        ((3 - 6*x + 6*x^2 + 41*x^3 + 41*x^4 + 6*x^5 - 6*x^6 + 3*x^7)*
          HPL[{-1, 1, 0}, x])/(36*(-1 + x)*x^3) + 
        (2*(1 + x^2)*HPL[{-1, 2, 0}, x])/(3*(-1 + x)^2) + 
        (x^2*(-9 - 330*x + 72*x^2 - 366*x^3 + 907*x^4 + 6*x^5 - 9*x^6 + 
           3*x^7)*HPL[{0, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        (2*(1 + x^2)*HPL[{1, -2, 0}, x])/(3*(-1 + x)^2) - 
        ((3 - 6*x + 6*x^2 + 41*x^3 + 41*x^4 + 6*x^5 - 6*x^6 + 3*x^7)*
          HPL[{1, -1, 0}, x])/(36*(-1 + x)*x^3) - 
        ((67 + 101*x + 93*x^2 + 107*x^3 + 61*x^4 + 3*x^5 + 3*x^6 - 3*x^7)*
          HPL[{1, 0, 0}, x])/(18*(-1 + x^2)^2) + 
        ((3 - 6*x + 6*x^2 + 41*x^3 + 41*x^4 + 6*x^5 - 6*x^6 + 3*x^7)*
          HPL[{1, 1, 0}, x])/(36*(-1 + x)*x^3) - 
        (2*(1 + x^2)*HPL[{1, 2, 0}, x])/(3*(-1 + x)^2) - 
        (2*(1 + x^2)*HPL[{2, -1, 0}, x])/(3*(-1 + x)^2) + 
        (8*x^2*HPL[{2, 0, 0}, x])/(3*(-1 + x)^2) + 
        (2*(1 + x^2)*HPL[{2, 1, 0}, x])/(3*(-1 + x)^2) + 
        (4*(1 + x)*HPL[{-1, 0, 0, 0}, x])/(3*(-1 + x)) - 
        (4*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/(3*(-1 + x)^2) - 
        (4*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/(3*(-1 + x)^2) + 
        ((4 + 4*x)*HPL[{1, 0, 0, 0}, x])/(3 - 3*x) + 
        ((1 + 3*x - x^2 + x^3)*master3l10a[x])/(24*(-1 + x)^3*(1 + x)) - 
        (x*(1 - x + 3*x^2 + x^3)*master3l10b[x])/(24*(-1 + x)^3*(1 + x)) + 
        ((-11 - 6*x + x^2)*master3l8a[x])/(24*(-1 + x)^4*(1 + x)^2) + 
        ((-5 - 18*x + 39*x^2)*master3l8b[x])/(72*(-1 + x)^4*(1 + x)^2) + 
        ((-9 + x^2)*master3l9a[x])/(6*(-1 + x)^4*(1 + x)^2) + 
        ((-1 + 9*x^2)*master3l9b[x])/(18*(-1 + x)^4*(1 + x)^2) + 
        (HPL[{-1}, x]*(Pi^2*(3 - 9*x + 12*x^2 + 35*x^3 - 35*x^5 - 12*x^6 + 
             9*x^7 - 3*x^8) - 288*x^3*(1 + x^2)*Zeta[3]))/
         (432*(-1 + x)^2*x^3) + (HPL[{1}, x]*
          (Pi^2*(-3 + 9*x - 12*x^2 - 35*x^3 + 35*x^5 + 12*x^6 - 9*x^7 + 
             3*x^8) + 288*x^3*(1 + x^2)*Zeta[3]))/(432*(-1 + x)^2*x^3) + 
        (x*HPL[{0}, x]*(-18 + 12*(-426 + Pi^2)*x + 12*Pi^2*x^6 - 
           18*Pi^2*x^7 + 6*Pi^2*x^8 + x^3*(6345 - 84*Pi^2 - 864*Zeta[3]) + 
           6*x^2*(-1905 + 2*Pi^2 + 288*Zeta[3]) - 6*x^4*(-18 + 7*Pi^2 + 
             288*Zeta[3]) + x^5*(10107 + 62*Pi^2 + 864*Zeta[3])))/
         (432*(-1 + x)^4*(1 + x)^2) + 
        (8*Pi^4*x*(-1 + x^2)^2*(47 - 88*x + 31*x^2) - 10*Pi^2*(-1 + x^2)*
           (6 + 294*x^3 + 6*x^6 + 12*x^4*(-1 + 32*Log[2]^2) - 
            12*x^2*(1 + 32*Log[2]^2) + x*(-161 + 192*Log[2]^2) - 
            x^5*(161 + 192*Log[2]^2)) - 15*x*(-5269 + 128*Log[2]^4 + 
            3072*PolyLog[4, 1/2] + 2256*Zeta[3] + 48*x^7*Zeta[3] - 
            72*x^8*Zeta[3] + 24*x^9*Zeta[3] + 16*x^3*(-878 + 32*Log[2]^4 + 
              768*PolyLog[4, 1/2] + 415*Zeta[3]) - 4*x*(-931 + 64*Log[2]^4 + 
              1536*PolyLog[4, 1/2] + 806*Zeta[3]) - 
            4*x^5*(-931 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 848*Zeta[3]) - 
            x^2*(2951 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 1096*Zeta[3]) - 
            x^4*(-6409 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 
              2008*Zeta[3]) + x^6*(1691 + 128*Log[2]^4 + 3072*PolyLog[4, 
                1/2] + 2680*Zeta[3])))/(8640*(-1 + x)^4*x*(1 + x)^2) + 
        lm*(-(x^2*(22 - 304*x + 119*x^2)*HPL[{0}, x])/(36*(-1 + x)^3*
            (1 + x)) - (11*(1 + x)*HPL[{-1, 0}, x])/(18*(-1 + x)) + 
          (22*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
           (9*(-1 + x)^4*(1 + x)^2) + (11*(1 + x)*HPL[{1, 0}, x])/
           (18*(-1 + x)) + (44*Pi^2*(-1 + x^2) - 
            9*(-137 + x*(550 - 144*Zeta[3]) + 72*Zeta[3] + x^2*(-137 + 
                72*Zeta[3])))/(864*(-1 + x)^2))) + 
      CF*(NH*(-lm^3/36 + (x*(-48 + 472*x - 2985*x^2 + 1552*x^3 + 807*x^4 - 
             521*x^5 - 102*x^6 + 49*x^7)*HPL[{0}, x])/(36*(-1 + x)^5*
            (1 + x)^3) + lm^2*((-7 + 20*x - 7*x^2)/(72*(-1 + x)^2) + 
            ((-2 + x)*x^3*HPL[{0}, x])/(6*(-1 + x)^3*(1 + x))) + 
          (x*(24 - 136*x + 1016*x^2 - 523*x^3 - 378*x^4 + 208*x^5 + 58*x^6 - 
             29*x^7)*HPL[{0, 0}, x])/(18*(-1 + x)^5*(1 + x)^3) + 
          lm*(-(4*Pi^2*(-1 + x^2) + 9*(9 - 38*x + 9*x^2))/(432*(-1 + x)^2) + 
            (x^2*(2 - 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x)^3*(1 + x)) + 
            ((1 + x)*HPL[{-1, 0}, x])/(9*(-1 + x)) - 
            (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
             (9*(-1 + x)^4*(1 + x)^2) + ((1 + x)*HPL[{1, 0}, x])/(9 - 9*x)) + 
          ((14 + 5*x - 19*x^3 + 8*x^4)*HPL[{-1, 0, 0}, x])/(9*(-1 + x)^4) - 
          (2*x^3*(54 - 33*x - 6*x^2 + x^5)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x)^5*(1 + x)^3) + ((-2 - 43*x + 12*x^2 + 5*x^3 - 8*x^4)*
            HPL[{1, 0, 0}, x])/(9*(-1 + x^2)^2) + 
          ((9 - 54*x + 28*x^2 + 6*x^3 - 5*x^4)*master3l8a[x])/
           (18*(-1 + x)^5*(1 + x)^3) + ((27 - 108*x + 51*x^2 + 12*x^3 - 
             15*x^4 + x^6)*master3l9a[x])/(18*(-1 + x)^5*(1 + x)^3) + 
          (x*(16923 - 768*Zeta[3]) + 39*(-99 + 32*Zeta[3]) - 
            4*x^8*(113 + 32*Zeta[3]) - 3*x^3*(-6687 + 64*Zeta[3]) + 
            3*x^7*(309 + 64*Zeta[3]) - 3*x^4*(3253 + 96*Zeta[3]) + 
            x^6*(4517 + 320*Zeta[3]) - 3*x^2*(3535 + 384*Zeta[3]) + 
            x^5*(-7671 + 768*Zeta[3]))/(432*(-1 + x)^5*(1 + x)^3)) + 
        NM*(-lm^3/36 + ((2*Pi^2*(-1 + x^2)^4 + 3*(38 - 219*x^2 - 9*x^3 - 188*
                x^4 - 459*x^5 + 1030*x^6 - 1860*x^7 + 891*x^8))*HPL[{0}, x])/
           (108*(-1 + x)^5*(1 + x)^3) + lm^2*((-7 + 20*x - 7*x^2)/
             (72*(-1 + x)^2) + ((-2 + x)*x^3*HPL[{0}, x])/(6*(-1 + x)^3*
              (1 + x))) + ((2 + 2*x)*HPL[{-2, 0}, x])/(9 - 9*x) - 
          ((12 + 14*x^2 - 32*x^3 - 601*x^4 + 30*x^5 + 978*x^6 - 2446*x^7 + 
             1229*x^8)*HPL[{0, 0}, x])/(18*(-1 + x)^5*(1 + x)^3) + 
          lm*(-(4*Pi^2*(-1 + x^2) + 9*(9 - 38*x + 9*x^2))/(432*(-1 + x)^2) + 
            (x^2*(2 - 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x)^3*(1 + x)) + 
            ((1 + x)*HPL[{-1, 0}, x])/(9*(-1 + x)) - 
            (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
             (9*(-1 + x)^4*(1 + x)^2) + ((1 + x)*HPL[{1, 0}, x])/(9 - 9*x)) + 
          (2*(1 + x)*HPL[{2, 0}, x])/(9*(-1 + x)) + 
          ((12 - 27*x + 13*x^3 + 10*x^4)*HPL[{-1, 0, 0}, x])/(9*(-1 + x)^4) + 
          (2*(1 + 28*x^2 - 30*x^3 - 243*x^4 + 138*x^5 + 332*x^6 - 1020*x^7 + 
             490*x^8)*HPL[{0, 0, 0}, x])/(9*(-1 + x)^5*(1 + x)^3) + 
          ((-12 - 3*x + 12*x^2 - 35*x^3 + 2*x^4)*HPL[{1, 0, 0}, x])/
           (9*(-1 + x^2)^2) + ((2 - 15*x^2 + 6*x^3 + 18*x^4 - 54*x^5 + 
             27*x^6)*master3l8b[x])/(54*(-1 + x)^5*x^2*(1 + x)^3) + 
          ((1 - 15*x^2 + 12*x^3 + 51*x^4 - 108*x^5 + 27*x^6)*master3l9b[x])/
           (54*(-1 + x)^5*x^2*(1 + x)^3) + (15 + x^5*(3171 - 768*Zeta[3]) - 
            156*x^10*(9 + 8*Zeta[3]) - 3*x^3*(249 + 64*Zeta[3]) + 
            3*x^7*(1173 + 64*Zeta[3]) + 12*x^8*(-485 + 96*Zeta[3]) + 
            3*x^6*(283 + 96*Zeta[3]) + x^2*(-13 + 128*Zeta[3]) - 
            x^4*(347 + 320*Zeta[3]) + x^9*(4137 + 768*Zeta[3]))/
           (432*(-1 + x)^5*x^2*(1 + x)^3)) + 
        NL*(-lm^3/36 + (Pi^2*(1 + x)*HPL[{-1}, x])/(54*(-1 + x)) - 
          (x^2*(84 + 6*(-57 + 4*Pi^2)*x - 3*(1 + 4*Pi^2)*x^2 + 342*x^3 + 
             (-81 + 4*Pi^2)*x^4)*HPL[{0}, x])/(216*(-1 + x)^4*(1 + x)^2) + 
          lm^2*((-7 + 20*x - 7*x^2)/(72*(-1 + x)^2) + 
            ((-2 + x)*x^3*HPL[{0}, x])/(6*(-1 + x)^3*(1 + x))) - 
          (Pi^2*(1 + x)*HPL[{1}, x])/(54*(-1 + x)) + 
          (2*x^3*(6 - 3*x + x^3)*HPL[{-2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
          ((7 - 6*x - 10*x^2 - 6*x^3 + 7*x^4)*HPL[{-1, 0}, x])/
           (18*(-1 + x)^3*(1 + x)) + (2*x^3*(-20 + 10*x + 13*x^2 - 7*x^3)*
            HPL[{0, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
          ((-7 + 6*x + 10*x^2 + 6*x^3 - 7*x^4)*HPL[{1, 0}, x])/
           (18*(-1 + x)^3*(1 + x)) + 
          lm*(-(4*Pi^2*(-1 + x^2) + 9*(9 - 38*x + 9*x^2))/(432*(-1 + x)^2) + 
            (x^2*(2 - 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x)^3*(1 + x)) + 
            ((1 + x)*HPL[{-1, 0}, x])/(9*(-1 + x)) - 
            (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
             (9*(-1 + x)^4*(1 + x)^2) + ((1 + x)*HPL[{1, 0}, x])/(9 - 9*x)) - 
          (2*x^3*(6 - 3*x + x^3)*HPL[{2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
          ((2 + 2*x)*HPL[{-1, -1, 0}, x])/(9 - 9*x) + 
          (2*(1 + x)*HPL[{-1, 1, 0}, x])/(9*(-1 + x)) + 
          (8*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x)^4*(1 + x)^2) + (2*(1 + x)*HPL[{1, -1, 0}, x])/
           (9*(-1 + x)) + ((2 + 2*x)*HPL[{1, 1, 0}, x])/(9 - 9*x) - 
          (4*Pi^2*(-7 + 6*x + 17*x^2 - 17*x^4 - 6*x^5 + 7*x^6) + 
            3*(73 + 96*Zeta[3] - 8*x*(41 + 16*Zeta[3]) - 8*x^5*(41 + 
                16*Zeta[3]) + 16*x^3*(41 + 28*Zeta[3]) - x^4*(73 + 
                64*Zeta[3]) + x^6*(73 + 64*Zeta[3]) - x^2*(73 + 
                160*Zeta[3])))/(864*(-1 + x)^4*(1 + x)^2))));


CbarData["s",2,1] = NC*(CA*CF*((Pi^2*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2}, x])/
         (27*(-1 + x)^4*(1 + x)^2) - (Pi^2*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{2}, x])/(27*(-1 + x)^4*(1 + x)^2) + 
        (x^2*(18 - 36*x + 54*x^2 + 309*x^3 - 96*x^4 - 171*x^5 + 134*x^6 + 
           27*x^7 - 78*x^8 + 15*x^9 + 20*x^10 - 8*x^11)*HPL[{-2, 0}, x])/
         (27*(-1 + x)^6*(1 + x)^4) + 
        ((24 - 60*x - 9*x^2 + (293 + 6*Pi^2)*x^3 - 2*(374 + 9*Pi^2)*x^4 - 
           (311 + 30*Pi^2)*x^5 + 1058*x^6 + (-311 + 30*Pi^2)*x^7 + 
           2*(-374 + 9*Pi^2)*x^8 + (293 - 6*Pi^2)*x^9 - 9*x^10 - 60*x^11 + 
           24*x^12)*HPL[{-1, 0}, x])/(162*(-1 + x)^5*x^3*(1 + x)^3) + 
        (x^2*(486 + 84942*x + 37827*x^2 - 699990*x^3 - 298536*x^4 - 
           978312*x^5 + 1600633*x^6 + 160972*x^7 - 462668*x^8 - 10686*x^9 + 
           22362*x^10 + 4530*x^11 + 1080*x^12 - 432*x^13)*HPL[{0, 0}, x])/
         (162*(-1 + x)^6*(1 + x)^4*(9 - 82*x^2 + 9*x^4)) + 
        ((-24 + 60*x + 9*x^2 - (293 + 6*Pi^2)*x^3 + 2*(374 + 9*Pi^2)*x^4 + 
           (311 + 30*Pi^2)*x^5 - 1058*x^6 + (311 - 30*Pi^2)*x^7 + 
           (748 - 18*Pi^2)*x^8 + (-293 + 6*Pi^2)*x^9 + 9*x^10 + 60*x^11 - 
           24*x^12)*HPL[{1, 0}, x])/(162*(-1 + x)^5*x^3*(1 + x)^3) + 
        lm*((-11*(-3*(1 - 36*x - 22*x^2 - 36*x^3 + x^4) + 
             4*Pi^2*(-1 + 3*x - 3*x^3 + x^4)))/(1296*(-1 + x)^4*(1 + x)^2) + 
          (11*x^2*(1 - 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x)^5*(1 + x)^3) + 
          (11*(1 - 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x)^3*(1 + x)) - 
          (22*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0}, x])/
           (27*(-1 + x)^6*(1 + x)^4) - (11*(1 - 3*x + x^2)*HPL[{1, 0}, x])/
           (27*(-1 + x)^3*(1 + x))) + (x^2*(-18 + 36*x - 54*x^2 - 309*x^3 + 
           96*x^4 + 171*x^5 - 134*x^6 - 27*x^7 + 78*x^8 - 15*x^9 - 20*x^10 + 
           8*x^11)*HPL[{2, 0}, x])/(27*(-1 + x)^6*(1 + x)^4) - 
        (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2, -1, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) + (16*x^2*(-2 - 3*x + x^2)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2, 1, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) + (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        ((8 - 20*x + 9*x^2 + 18*x^3 - 24*x^4 - 42*x^5 + 146*x^6 - 42*x^7 - 
           24*x^8 + 18*x^9 + 9*x^10 - 20*x^11 + 8*x^12)*HPL[{-1, -1, 0}, x])/
         (54*(-1 + x)^3*x^5*(1 + x)) + ((-51 + 157*x + 7*x^2 - 200*x^3 + 
           99*x^4 + 120*x^5 - 139*x^6 + 108*x^7 - 16*x^8 - 49*x^9 + 36*x^10 - 
           8*x^11)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^6*(1 + x)^2) + 
        ((-8 + 20*x - 9*x^2 - 18*x^3 + 24*x^4 + 42*x^5 - 146*x^6 + 42*x^7 + 
           24*x^8 - 18*x^9 - 9*x^10 + 20*x^11 - 8*x^12)*HPL[{-1, 1, 0}, x])/
         (54*(-1 + x)^3*x^5*(1 + x)) - (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        (2*x^2*(-27 - 5049*x - 2679*x^2 + 34182*x^3 + 35826*x^4 + 
           123906*x^5 - 208865*x^6 - 30821*x^7 + 72525*x^8 + 3906*x^9 - 
           12030*x^10 + 1059*x^11 + 2342*x^12 - 791*x^13 - 180*x^14 + 
           72*x^15)*HPL[{0, 0, 0}, x])/(27*(-1 + x)^6*(1 + x)^4*
          (9 - 82*x^2 + 9*x^4)) - (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        ((-8 + 20*x - 9*x^2 - 18*x^3 + 24*x^4 + 42*x^5 - 146*x^6 + 42*x^7 + 
           24*x^8 - 18*x^9 - 9*x^10 + 20*x^11 - 8*x^12)*HPL[{1, -1, 0}, x])/
         (54*(-1 + x)^3*x^5*(1 + x)) - ((-51 + x + 179*x^2 + 152*x^3 + 
           119*x^4 + 28*x^5 - 7*x^6 - 44*x^7 - 20*x^8 + 31*x^9 + 4*x^10 - 
           8*x^11)*HPL[{1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        ((8 - 20*x + 9*x^2 + 18*x^3 - 24*x^4 - 42*x^5 + 146*x^6 - 42*x^7 - 
           24*x^8 + 18*x^9 + 9*x^10 - 20*x^11 + 8*x^12)*HPL[{1, 1, 0}, x])/
         (54*(-1 + x)^3*x^5*(1 + x)) + (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{2, -1, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) - (16*x^2*(-2 - 3*x + x^2)*
          HPL[{2, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) - 
        (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{2, 1, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) - (8*(1 - 3*x + x^2)*HPL[{-1, 0, 0, 0}, x])/
         (9*(-1 + x)^3*(1 + x)) + (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{1, -1, 0, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) + (8*(1 - 3*x + x^2)*HPL[{1, 0, 0, 0}, x])/
         (9*(-1 + x)^3*(1 + x)) + ((-2 + 7*x + 8*x^2 + 12*x^3 - 2*x^4 + x^5)*
          master3l10a[x])/(36*(-1 + x)^5*(1 + x)^3) + 
        (x*(-1 + 2*x - 12*x^2 - 8*x^3 - 7*x^4 + 2*x^5)*master3l10b[x])/
         (36*(-1 + x)^5*(1 + x)^3) + ((-81 + 819*x + 795*x^2 + 264*x^3 - 
           129*x^4 - 43*x^5 + 7*x^6)*master3l8a[x])/(108*(-1 + x)^6*(1 + x)^4*
          (-9 + x^2)) + ((15 + 31*x - 169*x^2 - 384*x^3 + 903*x^4 + 81*x^5 - 
           189*x^6)*master3l8b[x])/(108*(-1 + x)^6*(1 + x)^4*(-1 + 9*x^2)) + 
        ((-135 + 450*x + 849*x^2 - 60*x^3 - 149*x^4 - 6*x^5 + 11*x^6)*
          master3l9a[x])/(36*(-1 + x)^6*(1 + x)^4*(-9 + x^2)) + 
        ((11 - 6*x - 149*x^2 - 60*x^3 + 849*x^4 + 450*x^5 - 135*x^6)*
          master3l9b[x])/(108*(-1 + x)^6*(1 + x)^4*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(-8 + 20*x - x^2 - 38*x^3 + 33*x^4 + 60*x^5 - 
             170*x^6 + 170*x^8 - 60*x^9 - 33*x^10 + 38*x^11 + x^12 - 
             20*x^13 + 8*x^14) - 288*x^5*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
            Zeta[3]))/(648*(-1 + x)^4*x^5*(1 + x)^2) + 
        (HPL[{-1}, x]*(Pi^2*(8 - 20*x + x^2 + 38*x^3 - 33*x^4 - 60*x^5 + 
             170*x^6 - 170*x^8 + 60*x^9 + 33*x^10 - 38*x^11 - x^12 + 
             20*x^13 - 8*x^14) + 288*x^5*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
            Zeta[3]))/(648*(-1 + x)^4*x^5*(1 + x)^2) + 
        (HPL[{0}, x]*(-432 + 1080*x + 4314*x^2 - 12*(2230 + 27*Pi^2)*x^3 + 
           (27611 + 1980*Pi^2)*x^5 + 12*(30898 + 855*Pi^2)*x^7 - 
           2*(1238827 + 9564*Pi^2)*x^9 + 4*(198036 + 6277*Pi^2)*x^11 + 
           6*(6463 + 1206*Pi^2)*x^12 - 3*(19359 + 5188*Pi^2)*x^13 + 
           6*(72 + 353*Pi^2)*x^14 + 4684*Pi^2*x^15 - 1582*Pi^2*x^16 - 
           360*Pi^2*x^17 + 144*Pi^2*x^18 + 6*x^4*(-25021 + 108*Pi^2 + 
             3888*Zeta[3]) - 6*x^10*(98447 + 5682*Pi^2 + 3888*Zeta[3]) - 
           2*x^6*(-651148 + 5733*Pi^2 + 117936*Zeta[3]) + 
           2*x^8*(866990 + 27201*Pi^2 + 117936*Zeta[3])))/
         (648*(-1 + x)^6*x*(1 + x)^4*(9 - 82*x^2 + 9*x^4)) + 
        (48*Pi^4*x^3*(-1 + x^2)^2*(-27 + 81*x + 66*x^2 - 1089*x^3 + 
            1730*x^4 + 3279*x^5 - 1246*x^6 - 351*x^7 + 117*x^8) - 
          40*Pi^2*(-216 + 540*x + 2265*x^2 - 8097*x^3 + 3729*x^4 + 
            34922*x^5 - 76555*x^6 - 52705*x^7 + 170997*x^8 - 170997*x^10 + 
            52705*x^11 + 76555*x^12 - 34922*x^13 - 3729*x^14 + 8097*x^15 - 
            2265*x^16 - 540*x^17 + 216*x^18) - 
          15*x^2*(-864 + x^6*(9692024 - 1586256*Zeta[3]) + 
            x^5*(4770255 - 1207296*Zeta[3]) + x^7*(275932 - 717216*Zeta[3]) + 
            112416*x^15*Zeta[3] - 37968*x^16*Zeta[3] - 8640*x^17*Zeta[3] + 
            3456*x^18*Zeta[3] + 144*x^14*(-6 + 353*Zeta[3]) - 
            45*x*(-1817 + 576*Zeta[3]) - 48*x^2*(6253 + 639*Zeta[3]) + 
            48*x^12*(4817 + 3573*Zeta[3]) - 45*x^13*(1891 + 9088*Zeta[3]) + 
            24*x^4*(71881 + 18430*Zeta[3]) - 24*x^10*(102719 + 
              30698*Zeta[3]) + 8*x^8*(394483 + 110994*Zeta[3]) + 
            2*x^3*(-654203 + 189360*Zeta[3]) + 2*x^11*(588157 + 
              547344*Zeta[3]) - 3*x^9*(1297295 + 632192*Zeta[3])))/
         (77760*(-1 + x)^6*x^3*(1 + x)^4*(9 - 82*x^2 + 9*x^4))) + 
      CF^2*((-2*Pi^2*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2}, x])/
         (27*(-1 + x)^4*(1 + x)^2) + (2*Pi^2*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{2}, x])/(27*(-1 + x)^4*(1 + x)^2) + 
        (x^2*(-36 + 24*x - 132*x^2 - 786*x^3 + 204*x^4 + 658*x^5 - 486*x^6 - 
           337*x^7 + 519*x^8 + 23*x^9 - 285*x^10 + 73*x^11 + 63*x^12 - 
           27*x^13)*HPL[{-2, 0}, x])/(27*(-1 + x)^6*(1 + x)^4) + 
        ((108 - 252*x - 130*x^2 + 762*x^3 - 332*x^4 - (735 + 16*Pi^2)*x^5 + 
           (214 + 48*Pi^2)*x^6 + (531 + 80*Pi^2)*x^7 + 1768*x^8 + 
           (531 - 80*Pi^2)*x^9 + (214 - 48*Pi^2)*x^10 + (-735 + 16*Pi^2)*
            x^11 - 332*x^12 + 762*x^13 - 130*x^14 - 252*x^15 + 108*x^16)*
          HPL[{-1, 0}, x])/(216*(-1 + x)^5*x^5*(1 + x)^3) + 
        (x^2*(-2412 - 69444*x - 22538*x^2 + 539634*x^3 + 286706*x^4 + 
           1311030*x^5 - 2100677*x^6 - 323352*x^7 + 561810*x^8 + 4856*x^9 + 
           47481*x^10 - 18670*x^11 - 29790*x^12 + 10998*x^13 + 2268*x^14 - 
           972*x^15)*HPL[{0, 0}, x])/(108*(-1 + x)^6*(1 + x)^4*
          (9 - 82*x^2 + 9*x^4)) + ((-108 + 252*x + 130*x^2 - 762*x^3 + 
           332*x^4 + (735 + 16*Pi^2)*x^5 - 2*(107 + 24*Pi^2)*x^6 - 
           (531 + 80*Pi^2)*x^7 - 1768*x^8 + (-531 + 80*Pi^2)*x^9 + 
           (-214 + 48*Pi^2)*x^10 + (735 - 16*Pi^2)*x^11 + 332*x^12 - 
           762*x^13 + 130*x^14 + 252*x^15 - 108*x^16)*HPL[{1, 0}, x])/
         (216*(-1 + x)^5*x^5*(1 + x)^3) + 
        (x^2*(36 - 24*x + 132*x^2 + 786*x^3 - 204*x^4 - 658*x^5 + 486*x^6 + 
           337*x^7 - 519*x^8 - 23*x^9 + 285*x^10 - 73*x^11 - 63*x^12 + 
           27*x^13)*HPL[{2, 0}, x])/(27*(-1 + x)^6*(1 + x)^4) + 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2, -1, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) - (16*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) - 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2, 1, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) - (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) - 
        ((-27 + 36*x + x^2 - 32*x^3 + 13*x^4 + 22*x^5 - 33*x^6 - 33*x^7 + 
           22*x^8 + 13*x^9 - 32*x^10 + x^11 + 36*x^12 - 27*x^13)*
          HPL[{-1, -1, 0}, x])/(54*(-1 + x)*x^7) - 
        ((-101 + 253*x - 2*x^2 - 382*x^3 + 469*x^4 + 121*x^5 - 548*x^6 + 
           368*x^7 + 197*x^8 - 425*x^9 + 134*x^10 + 134*x^11 - 117*x^12 + 
           27*x^13)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^6*(1 + x)^2) + 
        ((-27 + 36*x + x^2 - 32*x^3 + 13*x^4 + 22*x^5 - 33*x^6 - 33*x^7 + 
           22*x^8 + 13*x^9 - 32*x^10 + x^11 + 36*x^12 - 27*x^13)*
          HPL[{-1, 1, 0}, x])/(54*(-1 + x)*x^7) + 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-1, 2, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) + (2*x^2*(-270 + 9342*x - 2796*x^2 - 
           89910*x^3 + 78174*x^4 + 130956*x^5 - 552146*x^6 - 416260*x^7 + 
           628902*x^8 + 159854*x^9 - 235426*x^10 - 41508*x^11 + 87402*x^12 - 
           1760*x^13 - 36339*x^14 + 8893*x^15 + 8298*x^16 - 3114*x^17 - 
           567*x^18 + 243*x^19)*HPL[{0, 0, 0}, x])/(27*(-1 + x)^7*(1 + x)^5*
          (9 - 82*x^2 + 9*x^4)) + (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        ((-27 + 36*x + x^2 - 32*x^3 + 13*x^4 + 22*x^5 - 33*x^6 - 33*x^7 + 
           22*x^8 + 13*x^9 - 32*x^10 + x^11 + 36*x^12 - 27*x^13)*
          HPL[{1, -1, 0}, x])/(54*(-1 + x)*x^7) - 
        ((101 + 55*x - 106*x^2 + 218*x^3 + 263*x^4 - 17*x^5 - 172*x^6 + 
           184*x^7 + 155*x^8 - 211*x^9 - 58*x^10 + 118*x^11 + 9*x^12 - 
           27*x^13)*HPL[{1, 0, 0}, x])/(27*(-1 + x^2)^4) - 
        ((-27 + 36*x + x^2 - 32*x^3 + 13*x^4 + 22*x^5 - 33*x^6 - 33*x^7 + 
           22*x^8 + 13*x^9 - 32*x^10 + x^11 + 36*x^12 - 27*x^13)*
          HPL[{1, 1, 0}, x])/(54*(-1 + x)*x^7) - 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{1, 2, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) - (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) + 
        (16*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{2, 0, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) + (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{2, 1, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) - 
        (16*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-1, 1, 0, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^2) - (16*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^2) - 
        ((-2 + 7*x + 8*x^2 + 12*x^3 - 2*x^4 + x^5)*master3l10a[x])/
         (18*(-1 + x)^5*(1 + x)^3) + ((x - 2*x^2 + 12*x^3 + 8*x^4 + 7*x^5 - 
           2*x^6)*master3l10b[x])/(18*(-1 + x)^5*(1 + x)^3) + 
        ((81 - 819*x - 795*x^2 - 264*x^3 + 129*x^4 + 43*x^5 - 7*x^6)*
          master3l8a[x])/(54*(-1 + x)^6*(1 + x)^4*(-9 + x^2)) + 
        ((-15 - 31*x + 169*x^2 + 384*x^3 - 903*x^4 - 81*x^5 + 189*x^6)*
          master3l8b[x])/(54*(-1 + x)^6*(1 + x)^4*(-1 + 9*x^2)) + 
        ((135 - 450*x - 849*x^2 + 60*x^3 + 149*x^4 + 6*x^5 - 11*x^6)*
          master3l9a[x])/(18*(-1 + x)^6*(1 + x)^4*(-9 + x^2)) + 
        ((-11 + 6*x + 149*x^2 + 60*x^3 - 849*x^4 - 450*x^5 + 135*x^6)*
          master3l9b[x])/(54*(-1 + x)^6*(1 + x)^4*(-1 + 9*x^2)) - 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(27 - 63*x + 62*x^2 - 30*x^3 + 
             17*x^4 - 39*x^5 + 72*x^6 - 39*x^7 + 17*x^8 - 30*x^9 + 62*x^10 - 
             63*x^11 + 27*x^12) + 576*x^7*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
            Zeta[3]))/(648*(-1 + x)^4*x^7*(1 + x)^2) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(27 - 63*x + 62*x^2 - 30*x^3 + 
             17*x^4 - 39*x^5 + 72*x^6 - 39*x^7 + 17*x^8 - 30*x^9 + 62*x^10 - 
             63*x^11 + 27*x^12) + 576*x^7*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
            Zeta[3]))/(648*(-1 + x)^4*x^7*(1 + x)^2) + 
        (HPL[{0}, x]*(-2916 + 6804*x + 31536*x^2 - 85968*x^3 - 40485*x^4 + 
           9*(33467 + 144*Pi^2)*x^5 - 6*(38797 + 1176*Pi^2)*x^7 - 
           24*(50235 + 2056*Pi^2)*x^9 + (9717342 + 89160*Pi^2)*x^11 - 
           27*(123089 + 6868*Pi^2)*x^13 - (89115 + 135052*Pi^2)*x^14 + 
           12*(26064 + 16499*Pi^2)*x^15 + 8*(-3942 + 2131*Pi^2)*x^16 - 
           12*(567 + 9536*Pi^2)*x^17 + 4*(729 + 6022*Pi^2)*x^18 + 
           30924*Pi^2*x^19 - 11484*Pi^2*x^20 - 2268*Pi^2*x^21 + 
           972*Pi^2*x^22 - 9*x^6*(-62581 + 96*Pi^2 + 10368*Zeta[3]) + 
           6*x^8*(-946879 + 6028*Pi^2 + 157248*Zeta[3]) - 
           6*x^10*(1012361 + 47060*Pi^2 + 157248*Zeta[3]) + 
           x^12*(256252*Pi^2 + 729*(2699 + 128*Zeta[3]))))/
         (1296*(-1 + x)^6*x^3*(1 + x)^4*(9 - 82*x^2 + 9*x^4)) - 
        (64*Pi^4*x^5*(-1 + x^2)^2*(9 - 27*x - 118*x^2 + 219*x^3 + 346*x^4 + 
            219*x^5 - 118*x^6 - 27*x^7 + 9*x^8) + 
          4*Pi^2*(-972 + 2268*x + 10998*x^2 - 29790*x^3 - 18670*x^4 + 
            98889*x^5 - 19336*x^6 - 143274*x^7 + 32604*x^8 + 117285*x^9 + 
            136500*x^10 - 136500*x^12 - 117285*x^13 - 32604*x^14 + 
            143274*x^15 + 19336*x^16 - 98889*x^17 + 18670*x^18 + 29790*x^19 - 
            10998*x^20 - 2268*x^21 + 972*x^22) + 
          x^2*(-5832 + 13608*x + 65016*x^2 + x^5*(6251894 - 2213856*Zeta[
                3]) + 742176*x^19*Zeta[3] - 275616*x^20*Zeta[3] - 
            54432*x^21*Zeta[3] + 23328*x^22*Zeta[3] - 
            48*x^4*(-36811 + 1782*Zeta[3]) + 24*x^16*(2709 + 17048*Zeta[3]) + 
            9*x^3*(-56615 + 17568*Zeta[3]) + 16*x^6*(-841013 + 
              22626*Zeta[3]) + 24*x^18*(-243 + 24088*Zeta[3]) - 
            72*x^17*(-189 + 38144*Zeta[3]) - 48*x^14*(7469 + 69308*Zeta[3]) - 
            48*x^10*(139373 + 75948*Zeta[3]) + 48*x^8*(-684053 + 
              83316*Zeta[3]) + 12*x^9*(634843 + 94592*Zeta[3]) + 
            39*x^7*(-622855 + 176576*Zeta[3]) + 33*x^11*(313855 + 
              278656*Zeta[3]) + 16*x^12*(206587 + 408300*Zeta[3]) + 
            9*x^15*(17545 + 545536*Zeta[3]) - 2*x^13*(1843493 + 
              3347712*Zeta[3])))/(10368*(-1 + x)^6*x^5*(1 + x)^4*
          (9 - 82*x^2 + 9*x^4))) + 
      CF*(NH*((x*(2592 - 19728*x + 430128*x^2 - 114871*x^3 - 64570*x^4 + 
             6624*x^5 + 4322*x^6 + 4382*x^7 + 74*x^8 - 592*x^9 - 66*x^10 + 
             25*x^11)*HPL[{0}, x])/(216*(-1 + x)^7*(1 + x)^5*(-9 + x^2)) - 
          (x*(648 - 3060*x + 77256*x^2 - 18407*x^3 - 19194*x^4 + 1708*x^5 - 
             1278*x^6 + 640*x^7 + 162*x^8 - 84*x^9 + 6*x^10 + 3*x^11)*
            HPL[{0, 0}, x])/(54*(-1 + x)^7*(1 + x)^5*(-9 + x^2)) + 
          lm*((-3*(1 - 36*x - 22*x^2 - 36*x^3 + x^4) + 4*Pi^2*(-1 + 3*x - 
                3*x^3 + x^4))/(648*(-1 + x)^4*(1 + x)^2) - 
            (2*x^2*(1 - 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x)^5*(1 + x)^3) - 
            (2*(1 - 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x)^3*(1 + x)) + 
            (4*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x)^6*(1 + x)^4) + (2*(1 - 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x)^3*(1 + x))) + ((62 + 200*x - 130*x^2 + 40*x^3 - 
             28*x^4 + 20*x^5 - 4*x^6)*HPL[{-1, 0, 0}, x])/
           (27*(-1 + x)^6*(1 + x)^2) + (4*x^3*(2646 - 549*x - 549*x^2 - 
             108*x^3 - 219*x^4 + 24*x^5 + 45*x^6 - 8*x^7 - 3*x^8 + x^9)*
            HPL[{0, 0, 0}, x])/(27*(-1 + x)^7*(1 + x)^5*(-9 + x^2)) + 
          (2*(-13 - 188*x - 61*x^2 - 52*x^3 - 10*x^4 - 2*x^5 + 2*x^6)*
            HPL[{1, 0, 0}, x])/(27*(-1 + x^2)^4) - 
          ((189 - 3798*x + 1044*x^2 - 18*x^3 + 66*x^4 - 26*x^5 - 20*x^6 + 
             2*x^7 + x^8)*master3l8a[x])/(54*(-1 + x)^7*(1 + x)^5*
            (-9 + x^2)) + ((-567 + 6102*x - 2034*x^2 + 1152*x^3 + 18*x^4 + 
             516*x^5 + 12*x^6 - 96*x^7 + 13*x^8 + 6*x^9 - 2*x^10)*
            master3l9a[x])/(54*(-1 + x)^7*(1 + x)^5*(-9 + x^2)) + 
          (76302 + x^2*(395631 - 19968*Zeta[3]) + x^10*(3255 - 768*Zeta[3]) + 
            x^11*(515 - 192*Zeta[3]) - 22464*Zeta[3] + 
            x^12*(-135 + 64*Zeta[3]) + 4*x^8*(-5643 + 752*Zeta[3]) - 
            27*x*(40457 + 832*Zeta[3]) - 6*x^6*(5841 + 2944*Zeta[3]) - 
            6*x^7*(5683 + 2976*Zeta[3]) + x^9*(-1271 + 5376*Zeta[3]) - 
            6*x^5*(-63735 + 25952*Zeta[3]) + x^4*(388965 + 57792*Zeta[3]) + 
            3*x^3*(-558139 + 63616*Zeta[3]))/(1296*(-1 + x)^7*(1 + x)^5*
            (-9 + x^2))) + 
        NM*(((-8*Pi^2*(-1 + x^2)^4*(-1 + 3*x + 8*x^2 - 27*x^3 + 9*x^4) + 
             3*(152 - 456*x - 796*x^2 + 6748*x^3 - 847*x^4 - 28838*x^5 - 7304*
                x^6 - 142394*x^7 + 15966*x^8 - 151650*x^9 + 80116*x^10 - 
               55890*x^11 + 36873*x^12))*HPL[{0}, x])/(648*(-1 + x)^7*
            (1 + x)^5*(-1 + 9*x^2)) + (4*(1 - 3*x + x^2)*HPL[{-2, 0}, x])/
           (27*(-1 + x)^3*(1 + x)) + ((-24 + 72*x - 16*x^2 - 756*x^3 + 
             1167*x^4 - 2010*x^5 - 108*x^6 + 66378*x^7 + 4936*x^8 + 
             96354*x^9 - 45720*x^10 + 35802*x^11 - 25515*x^12)*
            HPL[{0, 0}, x])/(54*(-1 + x)^7*(1 + x)^5*(-1 + 9*x^2)) + 
          lm*((-3*(1 - 36*x - 22*x^2 - 36*x^3 + x^4) + 4*Pi^2*(-1 + 3*x - 
                3*x^3 + x^4))/(648*(-1 + x)^4*(1 + x)^2) - 
            (2*x^2*(1 - 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x)^5*(1 + x)^3) - 
            (2*(1 - 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x)^3*(1 + x)) + 
            (4*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x)^6*(1 + x)^4) + (2*(1 - 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x)^3*(1 + x))) - (4*(1 - 3*x + x^2)*HPL[{2, 0}, x])/
           (27*(-1 + x)^3*(1 + x)) + (2*(-6 + 30*x - 42*x^2 + 20*x^3 - 
             37*x^4 + 80*x^5 + 35*x^6)*HPL[{-1, 0, 0}, x])/
           (27*(-1 + x)^6*(1 + x)^2) + (4*(1 - 3*x + 20*x^2 - 3*x^3 - 
             191*x^4 + 939*x^5 + 116*x^6 - 7371*x^7 - 2061*x^8 - 21456*x^9 + 
             9424*x^10 - 8586*x^11 + 4851*x^12)*HPL[{0, 0, 0}, x])/
           (27*(-1 + x)^7*(1 + x)^5*(-1 + 9*x^2)) - 
          (2*(-6 + 6*x + 30*x^2 + 52*x^3 + 41*x^4 + 184*x^5 + 17*x^6)*
            HPL[{1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
          ((4 - 12*x - 29*x^2 + 186*x^3 + 36*x^4 - 954*x^5 - 234*x^6 - 
             2250*x^7 + 936*x^8 - 810*x^9 + 567*x^10)*master3l8b[x])/
           (162*(-1 + x)^7*x^2*(1 + x)^5*(-1 + 9*x^2)) - 
          ((-2 + 6*x + 13*x^2 - 96*x^3 + 12*x^4 + 516*x^5 + 18*x^6 + 
             1152*x^7 - 2034*x^8 + 6102*x^9 - 567*x^10)*master3l9b[x])/
           (162*(-1 + x)^7*x^2*(1 + x)^5*(-1 + 9*x^2)) + 
          (30 - 90*x + x^9*(667980 - 155712*Zeta[3]) + 
            x^8*(2124 - 17664*Zeta[3]) + x^4*(5805 - 768*Zeta[3]) + 
            x^3*(3395 - 192*Zeta[3]) + x^2*(-810 + 64*Zeta[3]) - 
            27*x^13*(-3613 + 832*Zeta[3]) - 27*x^14*(1269 + 832*Zeta[3]) - 
            6*x^7*(-8957 + 2976*Zeta[3]) + x^6*(-17427 + 3008*Zeta[3]) + 
            12*x^10*(-7265 + 4816*Zeta[3]) + x^5*(-30881 + 5376*Zeta[3]) - 
            3*x^12*(45693 + 6656*Zeta[3]) + 3*x^11*(4901 + 63616*Zeta[3]))/
           (1296*(-1 + x)^7*x^2*(1 + x)^5*(-1 + 9*x^2))) + 
        NL*(-(Pi^2*(1 - 3*x + x^2)*HPL[{-1}, x])/(81*(-1 + x)^3*(1 + x)) + 
          (x^2*(18 - 12*(29 + 6*Pi^2)*x + 69*x^2 + (456 - 36*Pi^2)*x^3 - 
             2*(45 + 4*Pi^2)*x^4 - 12*(9 + Pi^2)*x^5 + (3 + 4*Pi^2)*x^6)*
            HPL[{0}, x])/(324*(-1 + x)^6*(1 + x)^4) + 
          (Pi^2*(1 - 3*x + x^2)*HPL[{1}, x])/(81*(-1 + x)^3*(1 + x)) + 
          (4*x^3*(18 + 9*x^2 + 2*x^3 + 3*x^4 - x^5)*HPL[{-2, 0}, x])/
           (27*(-1 + x)^6*(1 + x)^4) + ((-3 + 14*x + x^2 - 148*x^3 + x^4 + 
             14*x^5 - 3*x^6)*HPL[{-1, 0}, x])/(54*(-1 + x)^5*(1 + x)^3) + 
          (x^3*(-120 - 6*x^2 + 4*x^3 - 14*x^4 + 3*x^5)*HPL[{0, 0}, x])/
           (27*(-1 + x)^6*(1 + x)^4) - ((-3 + 14*x + x^2 - 148*x^3 + x^4 + 
             14*x^5 - 3*x^6)*HPL[{1, 0}, x])/(54*(-1 + x)^5*(1 + x)^3) + 
          lm*((-3*(1 - 36*x - 22*x^2 - 36*x^3 + x^4) + 4*Pi^2*(-1 + 3*x - 
                3*x^3 + x^4))/(648*(-1 + x)^4*(1 + x)^2) - 
            (2*x^2*(1 - 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x)^5*(1 + x)^3) - 
            (2*(1 - 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x)^3*(1 + x)) + 
            (4*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x)^6*(1 + x)^4) + (2*(1 - 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x)^3*(1 + x))) + (4*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + 
             x^5)*HPL[{2, 0}, x])/(27*(-1 + x)^6*(1 + x)^4) + 
          (4*(1 - 3*x + x^2)*HPL[{-1, -1, 0}, x])/(27*(-1 + x)^3*(1 + x)) - 
          (4*(1 - 3*x + x^2)*HPL[{-1, 1, 0}, x])/(27*(-1 + x)^3*(1 + x)) - 
          (8*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0, 0}, x])/
           (27*(-1 + x)^6*(1 + x)^4) - (4*(1 - 3*x + x^2)*HPL[{1, -1, 0}, x])/
           (27*(-1 + x)^3*(1 + x)) + (4*(1 - 3*x + x^2)*HPL[{1, 1, 0}, x])/
           (27*(-1 + x)^3*(1 + x)) + (4*Pi^2*(-3 + 14*x + 4*x^2 - 162*x^3 + 
              162*x^5 - 4*x^6 - 14*x^7 + 3*x^8) - 3*(15 + 338*x^4 - 184*x^6 - 
              360*x^7 + 15*x^8 - 64*Zeta[3] + 24*x*(-15 + 8*Zeta[3]) + 
              72*x^3*(5 + 8*Zeta[3]) + 8*x^2*(-23 + 16*Zeta[3]) + 
              72*x^5*(5 + 16*Zeta[3])))/(2592*(-1 + x)^6*(1 + x)^4))));


CbarData["s",2,2] = NC*(CA*CF*((Pi^2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{-2}, x])/(108*(-1 + x)^6*(1 + x)^4) + 
        lm^2*((-11*(1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6))/
           (288*(-1 + x)^6*(1 + x)^4) - (11*x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
           (12*(-1 + x)^7*(1 + x)^5)) + (Pi^2*(-1 + 4*x + 19*x^2 + 56*x^3 + 
           19*x^4 + 4*x^5 - x^6)*HPL[{2}, x])/(108*(-1 + x)^6*(1 + x)^4) + 
        (x*(3 + 165*x - 6*x^2 + 789*x^3 + 5754*x^4 + 461*x^5 - 1310*x^6 + 
           2175*x^7 + 1582*x^8 - 3313*x^9 - 540*x^10 + 2682*x^11 - 372*x^12 - 
           1110*x^13 + 348*x^14 + 189*x^15 - 81*x^16)*HPL[{-2, 0}, x])/
         (216*(-1 + x)^8*(1 + x)^6) + ((1620 - 3780*x - 4530*x^2 + 
           16530*x^3 - 30*x^4 + (-24331 + 80*Pi^2)*x^5 - 80*(69 + 4*Pi^2)*
            x^6 + (8784 - 1600*Pi^2)*x^7 - 40*(1133 + 104*Pi^2)*x^8 - 
           35166*x^9 + 40*(-1133 + 104*Pi^2)*x^10 + 16*(549 + 100*Pi^2)*
            x^11 + 80*(-69 + 4*Pi^2)*x^12 - (24331 + 80*Pi^2)*x^13 - 
           30*x^14 + 16530*x^15 - 4530*x^16 - 3780*x^17 + 1620*x^18)*
          HPL[{-1, 0}, x])/(8640*(-1 + x)^7*x^5*(1 + x)^5) + 
        (x*(14580 + 2165292*x + 19896030*x^2 - 21856833*x^3 - 294211440*x^4 - 
           82997683*x^5 + 376333390*x^6 + 1348334612*x^7 + 5464656740*x^8 - 
           3527388452*x^9 + 2746622870*x^10 + 1456475729*x^11 + 
           454371390*x^12 - 661341095*x^13 - 271517850*x^14 - 27492126*x^15 + 
           66953460*x^16 + 49956750*x^17 - 20597220*x^18 - 7224390*x^19 + 
           2889270*x^20 + 306180*x^21 - 131220*x^22)*HPL[{0, 0}, x])/
         (4320*(-1 + x)^8*(1 + x)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        ((-1620 + 3780*x + 4530*x^2 - 16530*x^3 + 30*x^4 + 
           (24331 - 80*Pi^2)*x^5 + 80*(69 + 4*Pi^2)*x^6 + 
           16*(-549 + 100*Pi^2)*x^7 + 40*(1133 + 104*Pi^2)*x^8 + 35166*x^9 + 
           (45320 - 4160*Pi^2)*x^10 - 16*(549 + 100*Pi^2)*x^11 - 
           80*(-69 + 4*Pi^2)*x^12 + (24331 + 80*Pi^2)*x^13 + 30*x^14 - 
           16530*x^15 + 4530*x^16 + 3780*x^17 - 1620*x^18)*HPL[{1, 0}, x])/
         (8640*(-1 + x)^7*x^5*(1 + x)^5) + 
        lm*(-(44*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 
             3*(161 + 16*x + 39*x^2 - 6528*x^3 + 39*x^4 + 16*x^5 + 161*x^6))/
           (5184*(-1 + x)^6*(1 + x)^4) + (x^2*(22 - 2506*x - 879*x^2 - 
             3694*x^3 - 242*x^4 - 132*x^5 + 33*x^6)*HPL[{0}, x])/
           (216*(-1 + x)^7*(1 + x)^5) + (11*(1 - 4*x - 4*x^3 + x^4)*
            HPL[{-1, 0}, x])/(108*(-1 + x)^5*(1 + x)^3) - 
          (11*x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 136*x^4 - 3*x^5 - 4*x^6 + 
             x^7)*HPL[{0, 0}, x])/(54*(-1 + x)^8*(1 + x)^6) - 
          (11*(1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/(108*(-1 + x)^5*
            (1 + x)^3)) + (x*(-3 - 165*x + 6*x^2 - 789*x^3 - 5754*x^4 - 
           461*x^5 + 1310*x^6 - 2175*x^7 - 1582*x^8 + 3313*x^9 + 540*x^10 - 
           2682*x^11 + 372*x^12 + 1110*x^13 - 348*x^14 - 189*x^15 + 81*x^16)*
          HPL[{2, 0}, x])/(216*(-1 + x)^8*(1 + x)^6) + 
        ((-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{-2, -1, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (4*x^2*(-9 - 28*x - 10*x^2 - 4*x^3 + x^4)*HPL[{-2, 0, 0}, x])/
         (9*(-1 + x)^6*(1 + x)^4) + ((1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 
           4*x^5 + x^6)*HPL[{-2, 1, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        ((1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        ((81 - 189*x - 105*x^2 + 543*x^3 - 186*x^4 - 486*x^5 + 378*x^6 - 
           7*x^7 + 184*x^8 + 102*x^9 + 184*x^10 - 7*x^11 + 378*x^12 - 
           486*x^13 - 186*x^14 + 543*x^15 - 105*x^16 - 189*x^17 + 81*x^18)*
          HPL[{-1, -1, 0}, x])/(432*(-1 + x)^5*x^7*(1 + x)^3) + 
        ((797 - 2859*x + 3721*x^2 - 4203*x^3 + 9015*x^4 - 1263*x^5 - 
           4679*x^6 + 2721*x^7 + 8747*x^8 - 12705*x^9 + 675*x^10 + 
           8655*x^11 - 4575*x^12 - 1365*x^13 + 1755*x^14 - 405*x^15)*
          HPL[{-1, 0, 0}, x])/(1080*(-1 + x)^8*(1 + x)^4) + 
        ((-81 + 189*x + 105*x^2 - 543*x^3 + 186*x^4 + 486*x^5 - 378*x^6 + 
           7*x^7 - 184*x^8 - 102*x^9 - 184*x^10 + 7*x^11 - 378*x^12 + 
           486*x^13 + 186*x^14 - 543*x^15 + 105*x^16 + 189*x^17 - 81*x^18)*
          HPL[{-1, 1, 0}, x])/(432*(-1 + x)^5*x^7*(1 + x)^3) + 
        ((-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (x*(-1215 - 57105*x - 3662550*x^2 - 3206655*x^3 + 45744330*x^4 + 
           80230173*x^5 + 70296690*x^6 - 612033039*x^7 - 1595727840*x^8 + 
           1810115311*x^9 - 498635290*x^10 - 1016478681*x^11 - 
           439968730*x^12 + 715901371*x^13 + 154641870*x^14 - 
           323189703*x^15 + 15419505*x^16 + 125149782*x^17 - 30212160*x^18 - 
           31570560*x^19 + 11015460*x^20 + 3688740*x^21 - 1477440*x^22 - 
           153090*x^23 + 65610*x^24)*HPL[{0, 0, 0}, x])/
         (1080*(-1 + x)^8*(1 + x)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        ((-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        ((-81 + 189*x + 105*x^2 - 543*x^3 + 186*x^4 + 486*x^5 - 378*x^6 + 
           7*x^7 - 184*x^8 - 102*x^9 - 184*x^10 + 7*x^11 - 378*x^12 + 
           486*x^13 + 186*x^14 - 543*x^15 + 105*x^16 + 189*x^17 - 81*x^18)*
          HPL[{1, -1, 0}, x])/(432*(-1 + x)^5*x^7*(1 + x)^3) + 
        ((-797 - 809*x + 2299*x^2 + 7267*x^3 + 865*x^4 + 4747*x^5 - 221*x^6 + 
           4951*x^7 + 2533*x^8 - 7875*x^9 - 2295*x^10 + 5985*x^11 + 
           855*x^12 - 2415*x^13 - 135*x^14 + 405*x^15)*HPL[{1, 0, 0}, x])/
         (1080*(-1 + x^2)^6) + ((81 - 189*x - 105*x^2 + 543*x^3 - 186*x^4 - 
           486*x^5 + 378*x^6 - 7*x^7 + 184*x^8 + 102*x^9 + 184*x^10 - 
           7*x^11 + 378*x^12 - 486*x^13 - 186*x^14 + 543*x^15 - 105*x^16 - 
           189*x^17 + 81*x^18)*HPL[{1, 1, 0}, x])/(432*(-1 + x)^5*x^7*
          (1 + x)^3) + ((1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        ((1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (4*x^2*(9 + 28*x + 10*x^2 + 4*x^3 - x^4)*HPL[{2, 0, 0}, x])/
         (9*(-1 + x)^6*(1 + x)^4) + ((-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 
           4*x^5 - x^6)*HPL[{2, 1, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) - 
        (2*(1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0, 0, 0}, x])/
         (9*(-1 + x)^5*(1 + x)^3) + (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 
           4*x^5 + x^6)*HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (2*(1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0, 0, 0}, x])/
         (9*(-1 + x)^5*(1 + x)^3) + ((-2 + 11*x + 31*x^2 + 177*x^3 + 76*x^4 + 
           73*x^5 - 9*x^6 + 3*x^7)*master3l10a[x])/(144*(-1 + x)^7*
          (1 + x)^5) + (x*(-3 + 9*x - 73*x^2 - 76*x^3 - 177*x^4 - 31*x^5 - 
           11*x^6 + 2*x^7)*master3l10b[x])/(144*(-1 + x)^7*(1 + x)^5) - 
        ((78489 + 266355*x + 335988*x^2 + 795960*x^3 + 323646*x^4 - 
           63690*x^5 - 88764*x^6 - 17120*x^7 + 6641*x^8 + 1535*x^9 - 
           128*x^10)*master3l8a[x])/(4320*(-1 + x)^8*(1 + x)^6*
          (-9 + x^2)^2) - ((10 + 638*x + 1425*x^2 - 13729*x^3 - 29180*x^4 + 
           124352*x^5 + 127290*x^6 - 475446*x^7 + 85770*x^8 + 105786*x^9 + 
           111645*x^10 - 68769*x^11)*master3l8b[x])/(4320*(-1 + x)^8*x*
          (1 + x)^6*(1 - 9*x^2)^2) + ((8181 + 8595*x + 13698*x^2 + 
           40410*x^3 + 45916*x^4 - 6120*x^5 - 6738*x^6 - 10*x^7 + 383*x^8 + 
           5*x^9)*master3l9a[x])/(1440*(-1 + x)^8*(1 + x)^6*(-9 + x^2)) + 
        ((5 + 383*x - 10*x^2 - 6738*x^3 - 6120*x^4 + 45916*x^5 + 40410*x^6 + 
           13698*x^7 + 8595*x^8 + 8181*x^9)*master3l9b[x])/
         (4320*(-1 + x)^8*x*(1 + x)^6*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(-81 + 189*x + 186*x^2 - 732*x^3 + 81*x^4 + 
             1029*x^5 - 564*x^6 - 479*x^7 + 194*x^8 - 109*x^9 + 109*x^11 - 
             194*x^12 + 479*x^13 + 564*x^14 - 1029*x^15 - 81*x^16 + 
             732*x^17 - 186*x^18 - 189*x^19 + 81*x^20) - 
           576*x^7*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
            Zeta[3]))/(5184*(-1 + x)^6*x^7*(1 + x)^4) + 
        (HPL[{-1}, x]*(Pi^2*(81 - 189*x - 186*x^2 + 732*x^3 - 81*x^4 - 
             1029*x^5 + 564*x^6 + 479*x^7 - 194*x^8 + 109*x^9 - 109*x^11 + 
             194*x^12 - 479*x^13 - 564*x^14 + 1029*x^15 + 81*x^16 - 
             732*x^17 + 186*x^18 + 189*x^19 - 81*x^20) + 
           576*x^7*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
            Zeta[3]))/(5184*(-1 + x)^6*x^7*(1 + x)^4) + 
        (HPL[{0}, x]*(-393660 + 918540*x + 8470980*x^2 - 21213900*x^3 - 
           405*(142879 + 12*Pi^2)*x^4 - 243*(-513079 + 1100*Pi^2)*x^5 - 
           150*(186761105 + 5559046*Pi^2)*x^12 - 216*(4261087 + 2332230*Pi^2)*
            x^19 + 15*(-137673 + 2875492*Pi^2)*x^20 + 
           15*(4117311 + 16199212*Pi^2)*x^21 - 60*(141183 + 1007072*Pi^2)*
            x^22 - 34020*(27 + 1856*Pi^2)*x^23 + 540*(729 + 40798*Pi^2)*
            x^24 + 7377480*Pi^2*x^25 - 2954880*Pi^2*x^26 - 306180*Pi^2*x^27 + 
           131220*Pi^2*x^28 + 10*x^13*(882854985 + 2910812*Pi^2 - 
             86697216*Zeta[3]) - 20*x^16*(52902375 + 14060194*Pi^2 - 
             15303168*Zeta[3]) - 12*x^15*(375783054 + 32446255*Pi^2 - 
             13452480*Zeta[3]) + 20*x^17*(217112874 + 30034819*Pi^2 - 
             419904*Zeta[3]) + 90*x^18*(8028935 + 1240516*Pi^2 - 
             186624*Zeta[3]) + 180*x^7*(882815 + 19959*Pi^2 + 
             46656*Zeta[3]) + 90*x^6*(923281 + 1092*Pi^2 + 186624*Zeta[3]) - 
           60*x^8*(-7921179 + 165196*Pi^2 + 5101056*Zeta[3]) - 
           12*x^9*(192759431 + 14945*Pi^2 + 13452480*Zeta[3]) + 
           30*x^10*(72129745 + 5763172*Pi^2 + 47036160*Zeta[3]) + 
           x^11*(812707740 - 93705060*Pi^2 + 866972160*Zeta[3]) + 
           10*x^14*(39785644*Pi^2 - 3*(403031513 + 47036160*Zeta[3]))))/
         (51840*(-1 + x)^8*x^3*(1 + x)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        (64*Pi^4*x^5*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(-3 + 12*x - 87*x^2 - 
            280*x^3 - 103*x^4 - 52*x^5 + 13*x^6) - 
          4*Pi^2*(9 - 82*x^2 + 9*x^4)^2*(-1620 + 3780*x + 6150*x^2 - 
            20310*x^3 - 4500*x^4 + 40861*x^5 + 5490*x^6 - 33115*x^7 + 
            39800*x^8 + 43950*x^9 - 43950*x^11 - 39800*x^12 + 33115*x^13 - 
            5490*x^14 - 40861*x^15 + 4500*x^16 + 20310*x^17 - 6150*x^18 - 
            3780*x^19 + 1620*x^20) + x^2*(787320 - 1837080*x - 17277300*x^2 + 
            x^7*(3482676640 - 4766682432*Zeta[3]) - 177059520*x^25*Zeta[3] + 
            70917120*x^26*Zeta[3] + 7348320*x^27*Zeta[3] - 
            3149280*x^28*Zeta[3] + 204120*x^23*(-9 + 7424*Zeta[3]) + 
            810*x^4*(380303 + 69456*Zeta[3]) - 3240*x^24*
             (-243 + 163192*Zeta[3]) - 81*x^3*(-1934245 + 387552*Zeta[3]) + 
            720*x^22*(-23895 + 2014144*Zeta[3]) - 1620*x^18*
             (21251 + 2194784*Zeta[3]) + 440*x^14*(-884767 + 2322768*Zeta[
                3]) - 360*x^6*(6009217 + 2824368*Zeta[3]) - 
            90*x^20*(-1389447 + 10954192*Zeta[3]) + 
            320*x^8*(-31792037 + 13526943*Zeta[3]) + 320*x^16*
             (-11961617 + 31276620*Zeta[3]) + 80*x^10*(1217950169 + 
              64332792*Zeta[3]) + 9*x^5*(-218927495 + 73606848*Zeta[3]) - 
            224*x^17*(-3789035 + 84157938*Zeta[3]) + 
            64*x^9*(347633345 + 250085748*Zeta[3]) + 
            64*x^15*(-385627570 + 386667183*Zeta[3]) - 
            60*x^12*(-1766691143 + 417676856*Zeta[3]) - 
            9*x^21*(1114875 + 651266368*Zeta[3]) + 
            9*x^19*(45603745 + 1412224608*Zeta[3]) - 
            6*x^11*(-5283157295 + 5244788752*Zeta[3]) - 
            6*x^13*(-4027677815 + 5601577472*Zeta[3])))/(414720*(-1 + x)^8*
          x^5*(1 + x)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF^2*((Pi^2*(-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{-2}, x])/(54*(-1 + x)^6*(1 + x)^4) + 
        lm^2*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6)/
           (16*(-1 + x)^6*(1 + x)^4) + (3*x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
           (2*(-1 + x)^7*(1 + x)^5)) + (Pi^2*(1 - 4*x - 19*x^2 - 56*x^3 - 
           19*x^4 - 4*x^5 + x^6)*HPL[{2}, x])/(54*(-1 + x)^6*(1 + x)^4) - 
        (x*(15 + 825*x + 2730*x^2 + 5085*x^3 + 38610*x^4 + 4885*x^5 - 
           22950*x^6 + 22695*x^7 + 38830*x^8 - 53827*x^9 - 28334*x^10 + 
           66964*x^11 + 4306*x^12 - 47356*x^13 + 8706*x^14 + 18099*x^15 - 
           6129*x^16 - 2916*x^17 + 1296*x^18)*HPL[{-2, 0}, x])/
         (540*(-1 + x)^8*(1 + x)^6) + ((77760 - 174960*x - 251100*x^2 + 
           823500*x^3 + 113310*x^4 - 1533210*x^5 + 529710*x^6 + 
           (1396573 - 1200*Pi^2)*x^7 + 30*(-33893 + 160*Pi^2)*x^8 + 
           4*(-132403 + 6000*Pi^2)*x^9 + 30*(55317 + 2080*Pi^2)*x^10 + 
           902658*x^11 - 30*(-55317 + 2080*Pi^2)*x^12 - 
           4*(132403 + 6000*Pi^2)*x^13 - 30*(33893 + 160*Pi^2)*x^14 + 
           (1396573 + 1200*Pi^2)*x^15 + 529710*x^16 - 1533210*x^17 + 
           113310*x^18 + 823500*x^19 - 251100*x^20 - 174960*x^21 + 
           77760*x^22)*HPL[{-1, 0}, x])/(64800*(-1 + x)^7*x^7*(1 + x)^5) - 
        (x*(218700 + 34442820*x + 268201530*x^2 - 422417295*x^3 - 
           3936086460*x^4 - 34005585*x^5 + 4471314990*x^6 + 15570856200*x^7 + 
           75196130610*x^8 - 51845369792*x^9 + 49208866590*x^10 + 
           8825980267*x^11 - 6172209750*x^12 + 11251412923*x^13 + 
           1308159510*x^14 - 19488145758*x^15 + 2486885130*x^16 + 
           10709350038*x^17 - 2883444480*x^18 - 2869395030*x^19 + 
           1050369930*x^20 + 339116220*x^21 - 141411420*x^22 - 
           14171760*x^23 + 6298560*x^24)*HPL[{0, 0}, x])/
         (32400*(-1 + x)^8*(1 + x)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        ((-77760 + 174960*x + 251100*x^2 - 823500*x^3 - 113310*x^4 + 
           1533210*x^5 - 529710*x^6 + (-1396573 + 1200*Pi^2)*x^7 - 
           30*(-33893 + 160*Pi^2)*x^8 + (529612 - 24000*Pi^2)*x^9 - 
           30*(55317 + 2080*Pi^2)*x^10 - 902658*x^11 + 
           30*(-55317 + 2080*Pi^2)*x^12 + 4*(132403 + 6000*Pi^2)*x^13 + 
           30*(33893 + 160*Pi^2)*x^14 - (1396573 + 1200*Pi^2)*x^15 - 
           529710*x^16 + 1533210*x^17 - 113310*x^18 - 823500*x^19 + 
           251100*x^20 + 174960*x^21 - 77760*x^22)*HPL[{1, 0}, x])/
         (64800*(-1 + x)^7*x^7*(1 + x)^5) + 
        lm*((2*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 
            3*(4 + 14*x + 25*x^2 - 164*x^3 + 25*x^4 + 14*x^5 + 4*x^6))/
           (144*(-1 + x)^6*(1 + x)^4) + (x^2*(-2 + 188*x + 60*x^2 + 296*x^3 + 
             22*x^4 + 12*x^5 - 3*x^6)*HPL[{0}, x])/(12*(-1 + x)^7*
            (1 + x)^5) - ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0}, x])/
           (6*(-1 + x)^5*(1 + x)^3) + (x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 
             136*x^4 - 3*x^5 - 4*x^6 + x^7)*HPL[{0, 0}, x])/
           (3*(-1 + x)^8*(1 + x)^6) + ((1 - 4*x - 4*x^3 + x^4)*
            HPL[{1, 0}, x])/(6*(-1 + x)^5*(1 + x)^3)) + 
        (x*(15 + 825*x + 2730*x^2 + 5085*x^3 + 38610*x^4 + 4885*x^5 - 
           22950*x^6 + 22695*x^7 + 38830*x^8 - 53827*x^9 - 28334*x^10 + 
           66964*x^11 + 4306*x^12 - 47356*x^13 + 8706*x^14 + 18099*x^15 - 
           6129*x^16 - 2916*x^17 + 1296*x^18)*HPL[{2, 0}, x])/
         (540*(-1 + x)^8*(1 + x)^6) + (2*(1 - 4*x - 19*x^2 - 56*x^3 - 
           19*x^4 - 4*x^5 + x^6)*HPL[{-2, -1, 0}, x])/(9*(-1 + x)^6*
          (1 + x)^4) + (4*(-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        ((-2 + 8*x + 38*x^2 + 112*x^3 + 38*x^4 + 8*x^5 - 2*x^6)*
          HPL[{-2, 1, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        ((-2 + 8*x + 38*x^2 + 112*x^3 + 38*x^4 + 8*x^5 - 2*x^6)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        ((1296 - 2916*x + 351*x^2 + 3519*x^3 - 2499*x^4 - 601*x^5 + 
           1261*x^6 - 391*x^7 - 9*x^8 + 178*x^9 - 9*x^10 - 391*x^11 + 
           1261*x^12 - 601*x^13 - 2499*x^14 + 3519*x^15 + 351*x^16 - 
           2916*x^17 + 1296*x^18)*HPL[{-1, -1, 0}, x])/(1080*(-1 + x)^3*x^9*
          (1 + x)) - ((961 - 4369*x + 3039*x^2 - 6471*x^3 + 16575*x^4 + 
           3543*x^5 - 17909*x^6 + 393*x^7 + 34795*x^8 - 32895*x^9 - 
           22051*x^10 + 48663*x^11 - 8311*x^12 - 27735*x^13 + 16425*x^14 + 
           3591*x^15 - 5508*x^16 + 1296*x^17)*HPL[{-1, 0, 0}, x])/
         (540*(-1 + x)^8*(1 + x)^4) + ((-1296 + 2916*x - 351*x^2 - 3519*x^3 + 
           2499*x^4 + 601*x^5 - 1261*x^6 + 391*x^7 + 9*x^8 - 178*x^9 + 
           9*x^10 + 391*x^11 - 1261*x^12 + 601*x^13 + 2499*x^14 - 3519*x^15 - 
           351*x^16 + 2916*x^17 - 1296*x^18)*HPL[{-1, 1, 0}, x])/
         (1080*(-1 + x)^3*x^9*(1 + x)) + 
        (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (x*(-1215 - 76545*x + 3181545*x^2 + 655290*x^3 - 47253120*x^4 + 
           31166748*x^5 + 129241320*x^6 - 620025492*x^7 - 26451570*x^8 + 
           3373313510*x^9 + 3535336414*x^10 - 3028346856*x^11 - 
           986161904*x^12 + 2610887716*x^13 + 1542414584*x^14 - 
           2708218538*x^15 - 738676569*x^16 + 2213587489*x^17 + 
           7544639*x^18 - 1324611878*x^19 + 234137292*x^20 + 509769612*x^21 - 
           150588612*x^22 - 112799142*x^23 + 42170382*x^24 + 12012462*x^25 - 
           5028642*x^26 - 472392*x^27 + 209952*x^28)*HPL[{0, 0, 0}, x])/
         (540*(-1 + x)^9*(1 + x)^7*(9 - 82*x^2 + 9*x^4)^2) + 
        (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        ((-1296 + 2916*x - 351*x^2 - 3519*x^3 + 2499*x^4 + 601*x^5 - 
           1261*x^6 + 391*x^7 + 9*x^8 - 178*x^9 + 9*x^10 + 391*x^11 - 
           1261*x^12 + 601*x^13 + 2499*x^14 - 3519*x^15 - 351*x^16 + 
           2916*x^17 - 1296*x^18)*HPL[{1, -1, 0}, x])/(1080*(-1 + x)^3*x^9*
          (1 + x)) - ((-961 + 45*x + 7709*x^2 + 22375*x^3 + 23329*x^4 + 
           16909*x^5 - 2303*x^6 + 12607*x^7 + 11765*x^8 - 26645*x^9 - 
           12009*x^10 + 30961*x^11 + 6967*x^12 - 21333*x^13 - 2277*x^14 + 
           8073*x^15 + 324*x^16 - 1296*x^17)*HPL[{1, 0, 0}, x])/
         (540*(-1 + x^2)^6) + ((1296 - 2916*x + 351*x^2 + 3519*x^3 - 
           2499*x^4 - 601*x^5 + 1261*x^6 - 391*x^7 - 9*x^8 + 178*x^9 - 
           9*x^10 - 391*x^11 + 1261*x^12 - 601*x^13 - 2499*x^14 + 3519*x^15 + 
           351*x^16 - 2916*x^17 + 1296*x^18)*HPL[{1, 1, 0}, x])/
         (1080*(-1 + x)^3*x^9*(1 + x)) + 
        ((-2 + 8*x + 38*x^2 + 112*x^3 + 38*x^4 + 8*x^5 - 2*x^6)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        ((-2 + 8*x + 38*x^2 + 112*x^3 + 38*x^4 + 8*x^5 - 2*x^6)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (4*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{2, 0, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{2, 1, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (4*(-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) + 
        (4*(-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x)^6*(1 + x)^4) - 
        ((-2 + 11*x + 31*x^2 + 177*x^3 + 76*x^4 + 73*x^5 - 9*x^6 + 3*x^7)*
          master3l10a[x])/(72*(-1 + x)^7*(1 + x)^5) + 
        (x*(3 - 9*x + 73*x^2 + 76*x^3 + 177*x^4 + 31*x^5 + 11*x^6 - 2*x^7)*
          master3l10b[x])/(72*(-1 + x)^7*(1 + x)^5) + 
        ((78489 + 266355*x + 335988*x^2 + 795960*x^3 + 323646*x^4 - 
           63690*x^5 - 88764*x^6 - 17120*x^7 + 6641*x^8 + 1535*x^9 - 
           128*x^10)*master3l8a[x])/(2160*(-1 + x)^8*(1 + x)^6*
          (-9 + x^2)^2) + ((10 + 638*x + 1425*x^2 - 13729*x^3 - 29180*x^4 + 
           124352*x^5 + 127290*x^6 - 475446*x^7 + 85770*x^8 + 105786*x^9 + 
           111645*x^10 - 68769*x^11)*master3l8b[x])/(2160*(-1 + x)^8*x*
          (1 + x)^6*(1 - 9*x^2)^2) - ((8181 + 8595*x + 13698*x^2 + 
           40410*x^3 + 45916*x^4 - 6120*x^5 - 6738*x^6 - 10*x^7 + 383*x^8 + 
           5*x^9)*master3l9a[x])/(720*(-1 + x)^8*(1 + x)^6*(-9 + x^2)) - 
        ((5 + 383*x - 10*x^2 - 6738*x^3 - 6120*x^4 + 45916*x^5 + 40410*x^6 + 
           13698*x^7 + 8595*x^8 + 8181*x^9)*master3l9b[x])/
         (2160*(-1 + x)^8*x*(1 + x)^6*(-1 + 9*x^2)) - 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(1296 - 2916*x + 351*x^2 + 
             3519*x^3 - 2499*x^4 - 601*x^5 + 1261*x^6 - 391*x^7 - 9*x^8 + 
             178*x^9 - 9*x^10 - 391*x^11 + 1261*x^12 - 601*x^13 - 2499*x^14 + 
             3519*x^15 + 351*x^16 - 2916*x^17 + 1296*x^18) + 
           2880*x^9*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
            Zeta[3]))/(12960*(-1 + x)^6*x^9*(1 + x)^4) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(1296 - 2916*x + 351*x^2 + 3519*x^3 - 
             2499*x^4 - 601*x^5 + 1261*x^6 - 391*x^7 - 9*x^8 + 178*x^9 - 
             9*x^10 - 391*x^11 + 1261*x^12 - 601*x^13 - 2499*x^14 + 
             3519*x^15 + 351*x^16 - 2916*x^17 + 1296*x^18) + 
           2880*x^9*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
            Zeta[3]))/(12960*(-1 + x)^6*x^9*(1 + x)^4) + 
        (HPL[{0}, x]*(-6298560 + 14171760*x + 138262140*x^2 - 332030340*x^3 - 
           981763740*x^4 + 2704560840*x^5 + 405*(5938783 + 60*Pi^2)*x^6 + 
           81*(-114940631 + 16500*Pi^2)*x^7 + 450*(329642927 + 13282650*Pi^2)*
            x^14 + 2*(6617526093 + 6137645260*Pi^2)*x^21 + 
           5*(-422257293 + 245083300*Pi^2)*x^22 - 
           5*(581025393 + 1824970348*Pi^2)*x^23 + 
           60*(16362729 + 20150062*Pi^2)*x^24 + 1620*(204957 + 2521670*Pi^2)*
            x^25 - 540*(256041 + 2096980*Pi^2)*x^26 - 
           19440*(729 + 52088*Pi^2)*x^27 + 3240*(1944 + 115283*Pi^2)*x^28 + 
           115400700*Pi^2*x^29 - 48186900*Pi^2*x^30 - 4723920*Pi^2*x^31 + 
           2099520*Pi^2*x^32 - 4*x^15*(14719840269 + 58291660*Pi^2 - 
             1083715200*Zeta[3]) + 6*x^13*(1955538721 + 94752150*Pi^2 - 
             722476800*Zeta[3]) - 10*x^11*(413940491 + 2857650*Pi^2 - 
             80714880*Zeta[3]) + 10*x^17*(3678653861 + 468704262*Pi^2 - 
             80714880*Zeta[3]) - 2*x^19*(18123623319 + 5064295570*Pi^2 - 
             20995200*Zeta[3]) + 100*x^18*(146845419 + 69310952*Pi^2 - 
             15303168*Zeta[3]) - 300*x^10*(35738039 + 53252*Pi^2 - 
             5101056*Zeta[3]) - 160*x^20*(20297529 + 32491303*Pi^2 - 
             524880*Zeta[3]) + 360*x^8*(-2088386 + 11055*Pi^2 - 
             233280*Zeta[3]) - 6*x^9*(-2366373523 + 2686050*Pi^2 + 
             6998400*Zeta[3]) - 300*x^12*(-37570841 + 2671378*Pi^2 + 
             23518080*Zeta[3]) - 60*x^16*(91469688*Pi^2 - 
             5*(96743131 + 23518080*Zeta[3]))))/(129600*(-1 + x)^8*x^5*
          (1 + x)^6*(9 - 82*x^2 + 9*x^4)^2) - 
        (4800*Pi^4*x^7*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(1 - 4*x - 19*x^2 - 
            56*x^3 - 19*x^4 - 4*x^5 + x^6) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^2*
           (-77760 + 174960*x + 328860*x^2 - 998460*x^3 - 364410*x^4 + 
            2356710*x^5 - 416400*x^6 - 2929783*x^7 + 1546500*x^8 + 
            1926185*x^9 - 2676300*x^10 - 1432270*x^11 + 1432270*x^13 + 
            2676300*x^14 - 1926185*x^15 - 1546500*x^16 + 2929783*x^17 + 
            416400*x^18 - 2356710*x^19 + 364410*x^20 + 998460*x^21 - 
            328860*x^22 - 174960*x^23 + 77760*x^24) + 
          3*x^2*(-12597120 + 28343520*x + 280723320*x^2 - 673508520*x^3 - 
            2054492100*x^4 + x^23*(5356932165 - 219131005440*Zeta[3]) + 
            x^15*(91503052690 - 176505325440*Zeta[3]) + 
            x^13*(129167437090 - 160565496480*Zeta[3]) + 2769616800*x^29*
             Zeta[3] - 1156485600*x^30*Zeta[3] - 113374080*x^31*Zeta[3] + 
            50388480*x^32*Zeta[3] + 77760*x^28*(-162 + 115283*Zeta[3]) + 
            1620*x^6*(4131611 + 122904*Zeta[3]) - 116640*x^27*
             (-243 + 208352*Zeta[3]) - 405*x^5*(-15285113 + 349536*Zeta[3]) - 
            3600*x^8*(5203229 + 1118340*Zeta[3]) - 3240*x^26*
             (-86643 + 8387920*Zeta[3]) + 9720*x^25*(-69291 + 
              10086680*Zeta[3]) + 720*x^24*(-2852955 + 40300124*Zeta[3]) + 
            9*x^7*(-3140185031 + 321283200*Zeta[3]) - 
            120*x^14*(-3207606931 + 461701996*Zeta[3]) + 
            60*x^22*(96303897 + 493008728*Zeta[3]) - 
            40*x^12*(-13835275103 + 493167000*Zeta[3]) + 
            40*x^10*(-1002124325 + 578262672*Zeta[3]) - 
            160*x^16*(-401777807 + 793721172*Zeta[3]) - 
            60*x^20*(134786115 + 2138700832*Zeta[3]) - 
            8*x^9*(-5223864701 + 2505966960*Zeta[3]) + 
            40*x^18*(-208907525 + 4661504832*Zeta[3]) + 
            8*x^11*(16228902977 + 8652628200*Zeta[3]) + 
            8*x^17*(-13101533623 + 22493175960*Zeta[3]) - 
            8*x^19*(-3577656701 + 32717701080*Zeta[3]) + 
            3*x^21*(-5452586493 + 99105974560*Zeta[3])))/
         (3110400*(-1 + x)^8*x^7*(1 + x)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF*(NH*((x*(-466560 + 3873744*x - 172225440*x^2 - 9453555*x^3 - 
             90194760*x^4 + 32261800*x^5 + 38253440*x^6 - 6593175*x^7 - 
             3974640*x^8 - 380392*x^9 + 153280*x^10 + 167455*x^11 + 
             760*x^12 - 10352*x^13 - 480*x^14 + 75*x^15)*HPL[{0}, x])/
           (4320*(-1 + x)^9*(1 + x)^7*(-9 + x^2)^2) + 
          lm^2*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6)/
             (144*(-1 + x)^6*(1 + x)^4) + (x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x)^7*(1 + x)^5)) + (x*(116640 - 598428*x + 
             31298400*x^2 + 2336427*x^3 + 14110200*x^4 - 5818448*x^5 - 
             10848640*x^6 + 949125*x^7 + 528320*x^8 + 78880*x^9 + 
             129680*x^10 - 19991*x^11 - 6360*x^12 + 396*x^13 - 240*x^14 + 
             39*x^15)*HPL[{0, 0}, x])/(1080*(-1 + x)^9*(1 + x)^7*
            (-9 + x^2)^2) + lm*((4*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + 
                x^6) + 3*(7 + 32*x + 57*x^2 - 288*x^3 + 57*x^4 + 32*x^5 + 
                7*x^6))/(2592*(-1 + x)^6*(1 + x)^4) + 
            (x^2*(-2 + 182*x + 57*x^2 + 290*x^3 + 22*x^4 + 12*x^5 - 3*x^6)*
              HPL[{0}, x])/(108*(-1 + x)^7*(1 + x)^5) - 
            ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0}, x])/(54*(-1 + x)^5*
              (1 + x)^3) + (x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 136*x^4 - 3*
                x^5 - 4*x^6 + x^7)*HPL[{0, 0}, x])/(27*(-1 + x)^8*
              (1 + x)^6) + ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/
             (54*(-1 + x)^5*(1 + x)^3)) + ((77 + 471*x - 26*x^2 + 423*x^3 - 
             216*x^4 + 114*x^5 - 8*x^6 + 6*x^7 - x^8)*HPL[{-1, 0, 0}, x])/
           (27*(-1 + x)^8*(1 + x)^4) + (x^3*(-1132380 - 130707*x - 
             558360*x^2 + 226062*x^3 + 521820*x^4 + 17331*x^5 + 2760*x^6 - 
             11412*x^7 - 12300*x^8 + 1211*x^9 + 880*x^10 - 90*x^11 - 
             20*x^12 + 5*x^13)*HPL[{0, 0, 0}, x])/(135*(-1 + x)^9*(1 + x)^7*
            (-9 + x^2)^2) - ((41 + 689*x + 494*x^2 + 977*x^3 + 308*x^4 + 
             182*x^5 + 8*x^6 + 2*x^7 - x^8)*HPL[{1, 0, 0}, x])/
           (27*(-1 + x^2)^6) - ((-38799 + 1532520*x + 73116*x^2 + 
             974880*x^3 - 263763*x^4 - 164880*x^5 + 19360*x^6 + 13600*x^7 + 
             5915*x^8 - 920*x^9 - 636*x^10 + 7*x^12)*master3l8a[x])/
           (1080*(-1 + x)^9*(1 + x)^7*(-9 + x^2)^2) + 
          ((-12933 + 259200*x - 6111*x^2 + 229680*x^3 - 38364*x^4 + 
             86520*x^5 + 6042*x^6 + 14760*x^7 + 107*x^8 - 1400*x^9 + 
             69*x^10 + 40*x^11 - 10*x^12)*master3l9a[x])/(1080*(-1 + x)^9*
            (1 + x)^7*(-9 + x^2)) + (x^10*(1345891 - 901760*Zeta[3]) + 
            x^14*(67707 - 7040*Zeta[3]) - 40*x^15*(-167 + 32*Zeta[3]) + 
            5*x^16*(-143 + 64*Zeta[3]) + 200*x^11*(-12577 + 160*Zeta[3]) + 
            60*x^13*(599 + 1024*Zeta[3]) + 4860*x*(90497 + 1792*Zeta[3]) - 
            300*x^5*(-855625 + 2176*Zeta[3]) + 1458*(-10473 + 3040*Zeta[3]) + 
            19*x^12*(-49467 + 5120*Zeta[3]) + 405*x^2*(-17675 + 
              34432*Zeta[3]) - 1080*x^3*(-857527 + 60832*Zeta[3]) - 
            180*x^9*(-157913 + 66432*Zeta[3]) + 120*x^7*(-1373397 + 
              579232*Zeta[3]) - 45*x^4*(446239 + 717056*Zeta[3]) + 
            3*x^8*(11157259 + 755200*Zeta[3]) + 9*x^6*(-13384447 + 
              1381760*Zeta[3]))/(25920*(-1 + x)^9*(1 + x)^7*(-9 + x^2)^2)) + 
        NM*(((-40*Pi^2*(1 - 9*x^2)^2*(-1 + x^2)^4*(1 - 4*x - 4*x^3 + x^4) + 
             3*(-760 + 3040*x + 11388*x^2 - 130640*x^3 - 94735*x^4 + 1793440*
                x^5 + 1010188*x^6 + 934840*x^7 - 3670395*x^8 - 62244640*x^9 - 
               13303220*x^10 - 128239520*x^11 + 4780955*x^12 - 35655840*
                x^13 + 23572044*x^14 - 4915080*x^15 + 7560135*x^16))*
            HPL[{0}, x])/(12960*(-1 + x)^9*(1 + x)^7*(1 - 9*x^2)^2) + 
          lm^2*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6)/
             (144*(-1 + x)^6*(1 + x)^4) + (x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x)^7*(1 + x)^5)) + ((1 - 4*x - 4*x^3 + x^4)*
            HPL[{-2, 0}, x])/(27*(-1 + x)^5*(1 + x)^3) + 
          ((120 - 480*x - 1096*x^2 + 22000*x^3 + 5959*x^4 - 189360*x^5 - 
             78588*x^6 - 2698200*x^7 - 484687*x^8 + 17415440*x^9 + 
             7591900*x^10 + 75562320*x^11 + 2252733*x^12 + 27077760*x^13 - 
             14498136*x^14 + 2925720*x^15 - 5233005*x^16)*HPL[{0, 0}, x])/
           (1080*(-1 + x)^9*(1 + x)^7*(1 - 9*x^2)^2) + 
          lm*((4*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 3*(7 + 32*x + 
                57*x^2 - 288*x^3 + 57*x^4 + 32*x^5 + 7*x^6))/
             (2592*(-1 + x)^6*(1 + x)^4) + (x^2*(-2 + 182*x + 57*x^2 + 290*
                x^3 + 22*x^4 + 12*x^5 - 3*x^6)*HPL[{0}, x])/
             (108*(-1 + x)^7*(1 + x)^5) - ((1 - 4*x - 4*x^3 + x^4)*
              HPL[{-1, 0}, x])/(54*(-1 + x)^5*(1 + x)^3) + 
            (x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 136*x^4 - 3*x^5 - 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x)^8*(1 + x)^6) + 
            ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x)^5*
              (1 + x)^3)) - ((1 - 4*x - 4*x^3 + x^4)*HPL[{2, 0}, x])/
           (27*(-1 + x)^5*(1 + x)^3) + ((-3 + 18*x - 24*x^2 + 118*x^3 - 
             216*x^4 + 419*x^5 - 10*x^6 + 459*x^7 + 79*x^8)*
            HPL[{-1, 0, 0}, x])/(27*(-1 + x)^8*(1 + x)^4) - 
          ((5 - 20*x + 50*x^2 + 1040*x^3 - 862*x^4 + 7540*x^5 + 3336*x^6 - 
             347200*x^7 - 165088*x^8 + 194580*x^9 + 1203214*x^10 + 
             14289040*x^11 + 750338*x^12 + 7127820*x^13 - 2739240*x^14 + 
             1101600*x^15 - 997353*x^16)*HPL[{0, 0, 0}, x])/
           (135*(-1 + x)^9*(1 + x)^7*(1 - 9*x^2)^2) - 
          ((-3 + 6*x + 24*x^2 + 194*x^3 + 308*x^4 + 965*x^5 + 478*x^6 + 
             685*x^7 + 43*x^8)*HPL[{1, 0, 0}, x])/(27*(-1 + x^2)^6) - 
          ((20 - 80*x - 339*x^2 + 3520*x^3 + 2936*x^4 - 51960*x^5 - 
             27903*x^6 + 51840*x^7 + 127404*x^8 + 1592640*x^9 + 112959*x^10 + 
             691200*x^11 - 303480*x^12 + 68040*x^13 - 116397*x^14)*
            master3l8b[x])/(3240*(-1 + x)^9*(1 + x)^7*(x - 9*x^3)^2) - 
          ((-10 + 40*x + 69*x^2 - 1400*x^3 + 107*x^4 + 14760*x^5 + 6042*x^6 + 
             86520*x^7 - 38364*x^8 + 229680*x^9 - 6111*x^10 + 259200*x^11 - 
             12933*x^12)*master3l9b[x])/(3240*(-1 + x)^9*x^2*(1 + x)^7*
            (-1 + 9*x^2)) + (-150 + 600*x + x^6*(1108413 - 97280*Zeta[3]) + 
            x^5*(789060 - 61440*Zeta[3]) + x^2*(5500 - 320*Zeta[3]) + 
            40*x^3*(-1067 + 32*Zeta[3]) - 200*x^7*(22013 + 160*Zeta[3]) - 
            4860*x^17*(-3103 + 1792*Zeta[3]) + 300*x^13*(830921 + 
              2176*Zeta[3]) - 729*x^18*(10189 + 6080*Zeta[3]) + 
            x^4*(-111627 + 7040*Zeta[3]) + 540*x^9*(-57181 + 22144*Zeta[3]) - 
            2760*x^11*(-100899 + 25184*Zeta[3]) - 405*x^16*
             (71555 + 34432*Zeta[3]) + 1080*x^15*(-12697 + 60832*Zeta[3]) + 
            45*x^14*(-1209029 + 717056*Zeta[3]) - 3*x^10*(2372209 + 
              755200*Zeta[3]) + x^8*(-3855751 + 901760*Zeta[3]) - 
            9*x^12*(-6419567 + 1381760*Zeta[3]))/(25920*(-1 + x)^9*(1 + x)^7*
            (x - 9*x^3)^2)) + NL*(-(Pi^2*(1 - 4*x - 4*x^3 + x^4)*
             HPL[{-1}, x])/(324*(-1 + x)^5*(1 + x)^3) + 
          (x^2*(78 - 240*(89 + 9*Pi^2)*x - 3*(1777 + 360*Pi^2)*x^2 - 
             480*(10 + 9*Pi^2)*x^3 + (6081 - 1000*Pi^2)*x^4 - 
             80*(-333 + 25*Pi^2)*x^5 - 3*(241 + 20*Pi^2)*x^6 - 
             80*(6 + Pi^2)*x^7 + 5*(-21 + 4*Pi^2)*x^8)*HPL[{0}, x])/
           (6480*(-1 + x)^8*(1 + x)^6) + 
          lm^2*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6)/
             (144*(-1 + x)^6*(1 + x)^4) + (x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x)^7*(1 + x)^5)) + (Pi^2*(1 - 4*x - 4*x^3 + x^4)*
            HPL[{1}, x])/(324*(-1 + x)^5*(1 + x)^3) + 
          (x^3*(108 + 54*x + 216*x^2 + 50*x^3 + 100*x^4 + 3*x^5 + 4*x^6 - 
             x^7)*HPL[{-2, 0}, x])/(27*(-1 + x)^8*(1 + x)^6) - 
          ((13 - 80*x + 198*x^2 + 4360*x^3 + 1698*x^4 + 4360*x^5 + 198*x^6 - 
             80*x^7 + 13*x^8)*HPL[{-1, 0}, x])/(1080*(-1 + x)^7*(1 + x)^5) + 
          (x^3*(-2400 - 1200*x - 5040*x^2 - 640*x^3 - 2560*x^4 - 45*x^5 - 
             200*x^6 + 43*x^7)*HPL[{0, 0}, x])/(540*(-1 + x)^8*(1 + x)^6) + 
          ((13 - 80*x + 198*x^2 + 4360*x^3 + 1698*x^4 + 4360*x^5 + 198*x^6 - 
             80*x^7 + 13*x^8)*HPL[{1, 0}, x])/(1080*(-1 + x)^7*(1 + x)^5) + 
          lm*((4*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 3*(7 + 32*x + 
                57*x^2 - 288*x^3 + 57*x^4 + 32*x^5 + 7*x^6))/
             (2592*(-1 + x)^6*(1 + x)^4) + (x^2*(-2 + 182*x + 57*x^2 + 290*
                x^3 + 22*x^4 + 12*x^5 - 3*x^6)*HPL[{0}, x])/
             (108*(-1 + x)^7*(1 + x)^5) - ((1 - 4*x - 4*x^3 + x^4)*
              HPL[{-1, 0}, x])/(54*(-1 + x)^5*(1 + x)^3) + 
            (x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 136*x^4 - 3*x^5 - 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x)^8*(1 + x)^6) + 
            ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x)^5*
              (1 + x)^3)) + (x^3*(-108 - 54*x - 216*x^2 - 50*x^3 - 100*x^4 - 
             3*x^5 - 4*x^6 + x^7)*HPL[{2, 0}, x])/(27*(-1 + x)^8*(1 + x)^6) + 
          ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, -1, 0}, x])/(27*(-1 + x)^5*
            (1 + x)^3) - ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 1, 0}, x])/
           (27*(-1 + x)^5*(1 + x)^3) + (2*x^3*(72 + 36*x + 216*x^2 + 68*x^3 + 
             136*x^4 + 3*x^5 + 4*x^6 - x^7)*HPL[{0, 0, 0}, x])/
           (27*(-1 + x)^8*(1 + x)^6) - ((1 - 4*x - 4*x^3 + x^4)*
            HPL[{1, -1, 0}, x])/(27*(-1 + x)^5*(1 + x)^3) + 
          ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 1, 0}, x])/(27*(-1 + x)^5*
            (1 + x)^3) + (4*Pi^2*(-13 + 80*x - 185*x^2 - 4440*x^3 - 
              1500*x^4 + 1500*x^6 + 4440*x^7 + 185*x^8 - 80*x^9 + 13*x^10) - 
            3*(5 - 5111*x^8 - 3920*x^9 + 5*x^10 - 320*Zeta[3] + 
              80*x*(-49 + 16*Zeta[3]) + 480*x^7*(7 + 72*Zeta[3]) + 
              160*x^3*(21 + 200*Zeta[3]) + 160*x^5*(7 + 432*Zeta[3]) + 
              x^2*(-5111 + 960*Zeta[3]) + 6*x^6*(851 + 2880*Zeta[3]) + 
              2*x^4*(2553 + 8000*Zeta[3])))/(51840*(-1 + x)^8*(1 + x)^6))));


CbarData["s",2,3] = NC*(CF*(NL*((Pi^2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*
            HPL[{-1}, x])/(810*(-1 + x)^7*(1 + x)^5) + 
          (x^2*(-6 - 90*(1047 + 80*Pi^2)*x - 3*(23143 + 2400*Pi^2)*x^2 - 
             45*(5027 + 720*Pi^2)*x^3 - 20*(1033 + 800*Pi^2)*x^4 - 
             25*(-7029 + 1264*Pi^2)*x^5 + (88824 - 7100*Pi^2)*x^6 + 
             (144315 - 7300*Pi^2)*x^7 + (1626 - 80*Pi^2)*x^8 - 
             5*(-81 + 20*Pi^2)*x^9 + 5*(-71 + 4*Pi^2)*x^10)*HPL[{0}, x])/
           (16200*(-1 + x)^10*(1 + x)^8) + 
          lm^2*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 5*
                x^7 - x^8)/(180*(-1 + x)^8*(1 + x)^6) + 
            (2*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x)^9*(1 + x)^7)) + (Pi^2*(1 - 5*x - x^2 - 20*x^3 - 
             x^4 - 5*x^5 + x^6)*HPL[{1}, x])/(810*(-1 + x)^7*(1 + x)^5) + 
          (2*x^3*(360 + 360*x + 1620*x^2 + 800*x^3 + 1580*x^4 + 355*x^5 + 
             365*x^6 + 4*x^7 + 5*x^8 - x^9)*HPL[{-2, 0}, x])/
           (135*(-1 + x)^10*(1 + x)^8) + ((1 + 25*x - 803*x^2 - 17070*x^3 - 
             14378*x^4 - 44510*x^5 - 14378*x^6 - 17070*x^7 - 803*x^8 + 
             25*x^9 + x^10)*HPL[{-1, 0}, x])/(2700*(-1 + x)^9*(1 + x)^7) + 
          (x^3*(-6000 - 6000*x - 33000*x^2 - 16000*x^3 - 43000*x^4 - 
             9725*x^5 - 13525*x^6 - 116*x^7 - 325*x^8 + 59*x^9)*
            HPL[{0, 0}, x])/(1350*(-1 + x)^10*(1 + x)^8) + 
          ((-1 - 25*x + 803*x^2 + 17070*x^3 + 14378*x^4 + 44510*x^5 + 
             14378*x^6 + 17070*x^7 + 803*x^8 - 25*x^9 - x^10)*HPL[{1, 0}, x])/
           (2700*(-1 + x)^9*(1 + x)^7) + 
          lm*(-(-71 + 81*x + 182*x^2 + 10179*x^3 + 4314*x^4 + 10179*x^5 + 182*
                x^6 + 81*x^7 - 71*x^8 - 4*Pi^2*(-1 + 5*x + 2*x^2 + 15*x^3 - 
                 15*x^5 - 2*x^6 - 5*x^7 + x^8))/(6480*(-1 + x)^8*(1 + x)^6) + 
            (x^2*(-1 + 413*x + 334*x^2 + 1559*x^3 + 574*x^4 + 833*x^5 + 44*
                x^6 + 15*x^7 - 3*x^8)*HPL[{0}, x])/(135*(-1 + x)^9*
              (1 + x)^7) + ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*
              HPL[{-1, 0}, x])/(135*(-1 + x)^7*(1 + x)^5) + 
            (2*x^3*(-180 - 180*x - 1260*x^2 - 800*x^3 - 1940*x^4 - 535*x^5 - 
               545*x^6 - 4*x^7 - 5*x^8 + x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x)^10*(1 + x)^8) - ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 
               5*x^5 - x^6)*HPL[{1, 0}, x])/(135*(-1 + x)^7*(1 + x)^5)) + 
          (2*x^3*(-360 - 360*x - 1620*x^2 - 800*x^3 - 1580*x^4 - 355*x^5 - 
             365*x^6 - 4*x^7 - 5*x^8 + x^9)*HPL[{2, 0}, x])/
           (135*(-1 + x)^10*(1 + x)^8) + (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 
             5*x^5 + x^6)*HPL[{-1, -1, 0}, x])/(135*(-1 + x)^7*(1 + x)^5) + 
          (2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*
            HPL[{-1, 1, 0}, x])/(135*(-1 + x)^7*(1 + x)^5) + 
          (4*x^3*(180 + 180*x + 1260*x^2 + 800*x^3 + 1940*x^4 + 535*x^5 + 
             545*x^6 + 4*x^7 + 5*x^8 - x^9)*HPL[{0, 0, 0}, x])/
           (135*(-1 + x)^10*(1 + x)^8) + (2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 
             5*x^5 - x^6)*HPL[{1, -1, 0}, x])/(135*(-1 + x)^7*(1 + x)^5) + 
          (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*HPL[{1, 1, 0}, x])/
           (135*(-1 + x)^7*(1 + x)^5) - (-96972*x^10 - 48285*x^11 - 
            2365*x^12 + 12*Pi^2*(-1 - 25*x + 804*x^2 + 17095*x^3 + 
              13575*x^4 + 27440*x^5 - 27440*x^7 - 13575*x^8 - 17095*x^9 - 
              804*x^10 + 25*x^11 + x^12) + 45*x*(-1073 + 320*Zeta[3]) - 
            5*(473 + 576*Zeta[3]) + 12*x^2*(-8081 + 960*Zeta[3]) + 
            135*x^9*(2693 + 7680*Zeta[3]) + 45*x^3*(8079 + 23360*Zeta[3]) + 
            90*x^5*(-3503 + 50560*Zeta[3]) + 90*x^7*(-3503 + 51840*Zeta[3]) + 
            15*x^4*(6499 + 68160*Zeta[3]) + 15*x^8*(6499 + 69120*Zeta[3]) + 
            8*x^6*(463 + 288000*Zeta[3]))/(388800*(-1 + x)^10*(1 + x)^8)) + 
        NM*(-((2280 - 11400*x - 73452*x^2 + 1081140*x^3 + 1828239*x^4 - 
              32627445*x^5 - 38392273*x^6 + 278469990*x^7 + 405309622*x^8 + 
              1048381530*x^9 - 1130622306*x^10 - 19689020010*x^11 - 
              7281803612*x^12 + 16827011280*x^13 + 27485371124*x^14 + 
              232524544050*x^15 + 65392370802*x^16 + 204095829870*x^17 - 
              13529755458*x^18 + 7817020830*x^19 - 25940545731*x^20 - 
              2331134235*x^21 - 5314639635*x^22 + 40*Pi^2*(1 - 10*x^2 + 
                 9*x^4)^4*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6))*
             HPL[{0}, x])/(32400*(-1 + x)^11*(1 + x)^9*(1 - 9*x^2)^4) + 
          lm^2*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 5*
                x^7 - x^8)/(180*(-1 + x)^8*(1 + x)^6) + 
            (2*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x)^9*(1 + x)^7)) + (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 
             5*x^5 + x^6)*HPL[{-2, 0}, x])/(135*(-1 + x)^7*(1 + x)^5) + 
          ((120 - 600*x - 3208*x^2 + 68600*x^3 + 90533*x^4 - 1696515*x^5 - 
             1792587*x^6 + 783270*x^7 + 9734400*x^8 + 276847440*x^9 + 
             120564172*x^10 - 1752361370*x^11 - 1334871578*x^12 - 
             4293282030*x^13 + 1240110138*x^14 + 34742728530*x^15 + 
             14251168728*x^16 + 44722497600*x^17 - 462919860*x^18 + 
             4142068650*x^19 - 5576432283*x^20 - 629691975*x^21 - 
             1226742975*x^22)*HPL[{0, 0}, x])/(2700*(-1 + x)^11*(1 + x)^9*
            (1 - 9*x^2)^4) + lm*(-(-71 + 81*x + 182*x^2 + 10179*x^3 + 4314*
                x^4 + 10179*x^5 + 182*x^6 + 81*x^7 - 71*x^8 - 4*Pi^2*
                (-1 + 5*x + 2*x^2 + 15*x^3 - 15*x^5 - 2*x^6 - 5*x^7 + x^8))/
             (6480*(-1 + x)^8*(1 + x)^6) + (x^2*(-1 + 413*x + 334*x^2 + 1559*
                x^3 + 574*x^4 + 833*x^5 + 44*x^6 + 15*x^7 - 3*x^8)*
              HPL[{0}, x])/(135*(-1 + x)^9*(1 + x)^7) + 
            ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*HPL[{-1, 0}, x])/
             (135*(-1 + x)^7*(1 + x)^5) + (2*x^3*(-180 - 180*x - 1260*x^2 - 
               800*x^3 - 1940*x^4 - 535*x^5 - 545*x^6 - 4*x^7 - 5*x^8 + x^9)*
              HPL[{0, 0}, x])/(135*(-1 + x)^10*(1 + x)^8) - 
            ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*HPL[{1, 0}, x])/
             (135*(-1 + x)^7*(1 + x)^5)) + (2*(-1 + 5*x + x^2 + 20*x^3 + 
             x^4 + 5*x^5 - x^6)*HPL[{2, 0}, x])/(135*(-1 + x)^7*(1 + x)^5) + 
          (2*(-3 + 21*x - 27*x^2 + 508*x^3 - 589*x^4 + 2295*x^5 - 276*x^6 + 
             4812*x^7 + 1107*x^8 + 1994*x^9 + 238*x^10)*HPL[{-1, 0, 0}, x])/
           (135*(-1 + x)^10*(1 + x)^6) + (2*(-5 + 25*x + 45*x^2 - 3700*x^3 - 
             2879*x^4 + 32075*x^5 + 52445*x^6 + 1425030*x^7 + 946068*x^8 - 
             18388770*x^9 - 24935088*x^10 - 78965010*x^11 + 127888324*x^12 + 
             1785206170*x^13 + 303221596*x^14 - 4552985070*x^15 - 
             2696106015*x^16 - 9675214695*x^17 - 245293677*x^18 - 
             1804632210*x^19 + 994008267*x^20 - 38349045*x^21 + 
             232777719*x^22)*HPL[{0, 0, 0}, x])/(675*(-1 + x)^11*(1 + x)^9*
            (1 - 9*x^2)^4) - (2*(-3 + 9*x + 33*x^2 + 692*x^3 + 1461*x^4 + 
             5405*x^5 + 4504*x^6 + 8648*x^7 + 2887*x^8 + 2676*x^9 + 148*x^10)*
            HPL[{1, 0, 0}, x])/(135*(-1 + x^2)^8) + 
          ((-20 + 100*x + 677*x^2 - 10175*x^3 - 16927*x^4 + 319510*x^5 + 
             354946*x^6 - 3089550*x^7 - 4007742*x^8 - 5099130*x^9 + 
             15884316*x^10 + 198305460*x^11 + 38331132*x^12 - 
             548521470*x^13 - 307774962*x^14 - 1037858850*x^15 - 
             27042174*x^16 - 131308290*x^17 + 119366703*x^18 + 
             13380795*x^19 + 27278451*x^20)*master3l8b[x])/
           (8100*(-1 + x)^11*x^2*(1 + x)^9*(1 - 9*x^2)^4) - 
          ((-10 + 50*x + 217*x^2 - 4525*x^3 - 3218*x^4 + 125585*x^5 + 
             81860*x^6 - 715605*x^7 - 971994*x^8 - 4605915*x^9 + 
             3343890*x^10 + 25139745*x^11 + 1347762*x^12 + 63294795*x^13 + 
             4941612*x^14 + 197741025*x^15 + 28697220*x^16 + 97495245*x^17 - 
             3030939*x^18)*master3l9b[x])/(8100*(-1 + x)^11*x^2*(1 + x)^9*
            (-1 + 9*x^2)^3) + (-450 + 2250*x + x^6*(22682778 - 
              993600*Zeta[3]) - 40*x^2*(-625 + 24*Zeta[3]) + 
            30*x^3*(-10111 + 160*Zeta[3]) + 31744*x^10*(32942 + 
              375*Zeta[3]) - 15*x^5*(-693941 + 17280*Zeta[3]) + 
            x^4*(-1014583 + 39360*Zeta[3]) - 98415*x^23*(-50041 + 
              93120*Zeta[3]) - 15*x^7*(9282743 + 360000*Zeta[3]) - 
            6561*x^24*(825139 + 452160*Zeta[3]) + 17*x^8*(-14902651 + 
              724800*Zeta[3]) - 2160*x^11*(-6037489 + 2033440*Zeta[3]) + 
            120*x^9*(1536061 + 2653280*Zeta[3]) + 10935*x^21*
             (-3585523 + 5919360*Zeta[3]) - 1458*x^22*(17315719 + 
              13286880*Zeta[3]) + 2430*x^19*(94107691 + 40065120*Zeta[3]) + 
            72*x^18*(1611206789 + 131067000*Zeta[3]) - 
            90*x^15*(-1422197881 + 173735680*Zeta[3]) + 
            243*x^20*(-340442729 + 183672000*Zeta[3]) - 
            810*x^17*(-893865471 + 192368000*Zeta[3]) + 
            90*x^13*(-1175315371 + 251241600*Zeta[3]) - 
            6*x^12*(-758669363 + 296812800*Zeta[3]) - 
            16*x^16*(-8521779803 + 2853572400*Zeta[3]) + 
            4*x^14*(-14407418483 + 3921134400*Zeta[3]))/(194400*(-1 + x)^11*
            x^2*(1 + x)^9*(1 - 9*x^2)^4)) + 
        NH*((x*(-283435200 + 2636052336*x - 196662563280*x^2 - 
             73189006947*x^3 - 345787606395*x^4 + 7855418313*x^5 + 
             82125137250*x^6 + 36080629506*x^7 + 31408549470*x^8 - 
             15667801998*x^9 - 13035465990*x^10 + 2298151356*x^11 + 
             1812974520*x^12 - 41658812*x^13 - 120645690*x^14 - 
             23162002*x^15 + 3491970*x^16 + 2409006*x^17 + 20910*x^18 - 
             80713*x^19 - 3165*x^20 + 355*x^21)*HPL[{0}, x])/
           (32400*(-1 + x)^11*(1 + x)^9*(-9 + x^2)^4) + 
          lm^2*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 5*
                x^7 - x^8)/(180*(-1 + x)^8*(1 + x)^6) + 
            (2*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x)^9*(1 + x)^7)) + (x*(23619600 - 135620244*x + 
             11978913420*x^2 + 4633602489*x^3 + 20372261805*x^4 - 
             532364643*x^5 - 7795632330*x^6 - 2772998208*x^7 - 
             2996508960*x^8 + 960603844*x^9 + 1234599070*x^10 - 
             82937602*x^11 - 104931950*x^12 - 7532486*x^13 - 5059230*x^14 + 
             1726192*x^15 + 990280*x^16 - 96128*x^17 - 27330*x^18 + 
             729*x^19 - 375*x^20 + 57*x^21)*HPL[{0, 0}, x])/
           (2700*(-1 + x)^11*(1 + x)^9*(-9 + x^2)^4) + 
          lm*(-(-71 + 81*x + 182*x^2 + 10179*x^3 + 4314*x^4 + 10179*x^5 + 182*
                x^6 + 81*x^7 - 71*x^8 - 4*Pi^2*(-1 + 5*x + 2*x^2 + 15*x^3 - 
                 15*x^5 - 2*x^6 - 5*x^7 + x^8))/(6480*(-1 + x)^8*(1 + x)^6) + 
            (x^2*(-1 + 413*x + 334*x^2 + 1559*x^3 + 574*x^4 + 833*x^5 + 44*
                x^6 + 15*x^7 - 3*x^8)*HPL[{0}, x])/(135*(-1 + x)^9*
              (1 + x)^7) + ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*
              HPL[{-1, 0}, x])/(135*(-1 + x)^7*(1 + x)^5) + 
            (2*x^3*(-180 - 180*x - 1260*x^2 - 800*x^3 - 1940*x^4 - 535*x^5 - 
               545*x^6 - 4*x^7 - 5*x^8 + x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x)^10*(1 + x)^8) - ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 
               5*x^5 - x^6)*HPL[{1, 0}, x])/(135*(-1 + x)^7*(1 + x)^5)) + 
          (2*(236 + 2008*x + 1089*x^2 + 4844*x^3 - 332*x^4 + 2295*x^5 - 
             533*x^6 + 476*x^7 - 9*x^8 + 7*x^9 - x^10)*HPL[{-1, 0, 0}, x])/
           (135*(-1 + x)^10*(1 + x)^6) + (2*x^3*(-445419000 - 190336311*x - 
             775432845*x^2 + 5632443*x^3 + 332973360*x^4 + 150293358*x^5 + 
             192779280*x^6 - 33539190*x^7 - 65856240*x^8 - 1896240*x^9 + 
             3466830*x^10 + 1149504*x^11 + 621840*x^12 - 122062*x^13 - 
             76600*x^14 + 5878*x^15 + 2600*x^16 - 185*x^17 - 25*x^18 + 
             5*x^19)*HPL[{0, 0, 0}, x])/(675*(-1 + x)^11*(1 + x)^9*
            (-9 + x^2)^4) + (2*(-146 - 2682*x - 2909*x^2 - 8696*x^3 - 
             4568*x^4 - 5405*x^5 - 1397*x^6 - 644*x^7 - 11*x^8 - 3*x^9 + 
             x^10)*HPL[{1, 0, 0}, x])/(135*(-1 + x^2)^8) + 
          ((9092817 - 589431735*x - 213992847*x^2 - 1077679890*x^3 - 
             1504134*x^4 + 98011530*x^5 + 97799490*x^6 + 74198550*x^7 - 
             31941876*x^8 - 21706500*x^9 + 2766452*x^10 + 2922730*x^11 + 
             196758*x^12 - 200730*x^13 - 44434*x^14 + 4370*x^15 + 2195*x^16 + 
             75*x^17 - 21*x^18)*master3l8a[x])/(2700*(-1 + x)^11*(1 + x)^9*
            (-9 + x^2)^4) + ((-3030939 + 97495245*x + 28697220*x^2 + 
             197741025*x^3 + 4941612*x^4 + 63294795*x^5 + 1347762*x^6 + 
             25139745*x^7 + 3343890*x^8 - 4605915*x^9 - 971994*x^10 - 
             715605*x^11 + 81860*x^12 + 125585*x^13 - 3218*x^14 - 4525*x^15 + 
             217*x^16 + 50*x^17 - 10*x^18)*master3l9a[x])/(2700*(-1 + x)^11*
            (1 + x)^9*(-9 + x^2)^3) + 
          (x^10*(70930497362 - 15684537600*Zeta[3]) + 
            x^14*(663879382 - 11904000*Zeta[3]) + 
            x^20*(566698 - 39360*Zeta[3]) + x^21*(43455 - 4800*Zeta[3]) + 
            5*x^22*(-797 + 192*Zeta[3]) + 590490*x*(860959 + 15520*Zeta[3]) + 
            15*x^19*(41839 + 17280*Zeta[3]) + 52488*(-200887 + 
              56520*Zeta[3]) + 30*x^17*(-2021861 + 180000*Zeta[3]) + 
            3*x^18*(-4717421 + 331200*Zeta[3]) - 16*x^16*(-6230327 + 
              770100*Zeta[3]) - 60*x^15*(-18832693 + 5306560*Zeta[3]) + 
            270*x^13*(-38093777 + 16267520*Zeta[3]) - 
            3645*x^3*(-454059989 + 17758080*Zeta[3]) + 
            729*x^2*(217379693 + 26573760*Zeta[3]) + 
            360*x^9*(-184326259 + 43433920*Zeta[3]) - 
            486*x^4*(-578858207 + 91836000*Zeta[3]) + 
            1620*x^7*(-269517793 + 96184000*Zeta[3]) + 
            12*x^12*(-1129346239 + 148406400*Zeta[3]) - 
            405*x^5*(-2865596539 + 240390720*Zeta[3]) - 
            90*x^11*(-549165631 + 251241600*Zeta[3]) - 
            9*x^6*(12466764877 + 1048536000*Zeta[3]) + 
            8*x^8*(-14383222201 + 5707144800*Zeta[3]))/(194400*(-1 + x)^11*
            (1 + x)^9*(-9 + x^2)^4))) + 
      CA*CF*((Pi^2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 
           5*x^7 + x^8)*HPL[{-2}, x])/(270*(-1 + x)^8*(1 + x)^6) + 
        lm^2*((-11*(1 - 5*x - 14*x^2 - 145*x^3 - 94*x^4 - 145*x^5 - 14*x^6 - 
             5*x^7 + x^8))/(360*(-1 + x)^8*(1 + x)^6) - 
          (11*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/
           (3*(-1 + x)^9*(1 + x)^7)) + (Pi^2*(-1 + 5*x + 50*x^2 + 245*x^3 + 
           242*x^4 + 245*x^5 + 50*x^6 + 5*x^7 - x^8)*HPL[{2}, x])/
         (270*(-1 + x)^8*(1 + x)^6) + (x*(30 + 1290*x + 2475*x^2 + 9840*x^3 + 
           75135*x^4 + 35780*x^5 + 50015*x^6 + 37750*x^7 + 38600*x^8 - 
           61052*x^9 - 31597*x^10 + 82454*x^11 + 9660*x^12 - 68520*x^13 + 
           7500*x^14 + 35160*x^15 - 9105*x^16 - 10230*x^17 + 3735*x^18 + 
           1296*x^19 - 576*x^20)*HPL[{-2, 0}, x])/(1350*(-1 + x)^10*
          (1 + x)^8) + ((5760 - 12960*x - 28710*x^2 + 82860*x^3 + 45585*x^4 - 
           221910*x^5 + 5100*x^6 + 4*(80718 + 25*Pi^2)*x^7 - 
           (145569 + 500*Pi^2)*x^8 - 2*(147523 + 2550*Pi^2)*x^9 - 
           2*(77257 + 12000*Pi^2)*x^10 - 32*(6083 + 600*Pi^2)*x^11 - 
           914024*x^12 + 32*(-6083 + 600*Pi^2)*x^13 + 2*(-77257 + 12000*Pi^2)*
            x^14 + (-295046 + 5100*Pi^2)*x^15 + (-145569 + 500*Pi^2)*x^16 - 
           4*(-80718 + 25*Pi^2)*x^17 + 5100*x^18 - 221910*x^19 + 45585*x^20 + 
           82860*x^21 - 28710*x^22 - 12960*x^23 + 5760*x^24)*HPL[{-1, 0}, x])/
         (27000*(-1 + x)^9*x^7*(1 + x)^7) + 
        (x*(11809800 + 520637220*x + 10141162740*x^2 - 547327125*x^3 - 
           303619643865*x^4 - 323011723050*x^5 + 2599762873275*x^6 + 
           5368484145330*x^7 + 1054252087425*x^8 - 33864946932034*x^9 - 
           95235525626947*x^10 + 87203138478249*x^11 + 193499362766224*x^12 - 
           98497791861664*x^13 + 589685341071424*x^14 + 217859066411444*
            x^15 + 271223390649598*x^16 - 71406459566864*x^17 - 
           175121593852890*x^18 - 50666613438579*x^19 + 33777658550463*x^20 + 
           55787234655174*x^21 - 11899592917101*x^22 - 26407866755694*x^23 + 
           7076793104109*x^24 + 7543074059694*x^25 - 2519461764567*x^26 - 
           1317043155969*x^27 + 500083749450*x^28 + 135205894980*x^29 - 
           55407404430*x^30 - 7455133080*x^31 + 3206885580*x^32 + 
           170061120*x^33 - 75582720*x^34)*HPL[{0, 0}, x])/
         (27000*(-1 + x)^10*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        ((-5760 + 12960*x + 28710*x^2 - 82860*x^3 - 45585*x^4 + 221910*x^5 - 
           5100*x^6 - 4*(80718 + 25*Pi^2)*x^7 + (145569 + 500*Pi^2)*x^8 + 
           (295046 + 5100*Pi^2)*x^9 + 2*(77257 + 12000*Pi^2)*x^10 + 
           32*(6083 + 600*Pi^2)*x^11 + 914024*x^12 - 32*(-6083 + 600*Pi^2)*
            x^13 + (154514 - 24000*Pi^2)*x^14 + (295046 - 5100*Pi^2)*x^15 + 
           (145569 - 500*Pi^2)*x^16 + 4*(-80718 + 25*Pi^2)*x^17 - 5100*x^18 + 
           221910*x^19 - 45585*x^20 - 82860*x^21 + 28710*x^22 + 12960*x^23 - 
           5760*x^24)*HPL[{1, 0}, x])/(27000*(-1 + x)^9*x^7*(1 + x)^7) + 
        lm*((-1285 + 3411*x + 9058*x^2 + 185049*x^3 + 94830*x^4 + 
            185049*x^5 + 9058*x^6 + 3411*x^7 - 1285*x^8 - 
            44*Pi^2*(-1 + 5*x + 2*x^2 + 15*x^3 - 15*x^5 - 2*x^6 - 5*x^7 + 
              x^8))/(12960*(-1 + x)^8*(1 + x)^6) + 
          (x^2*(11 - 5803*x - 4934*x^2 - 20929*x^3 - 7574*x^4 - 10423*x^5 - 
             484*x^6 - 165*x^7 + 33*x^8)*HPL[{0}, x])/(270*(-1 + x)^9*
            (1 + x)^7) + (11*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*
            HPL[{-1, 0}, x])/(270*(-1 + x)^7*(1 + x)^5) - 
          (11*x^3*(-180 - 180*x - 1260*x^2 - 800*x^3 - 1940*x^4 - 535*x^5 - 
             545*x^6 - 4*x^7 - 5*x^8 + x^9)*HPL[{0, 0}, x])/
           (135*(-1 + x)^10*(1 + x)^8) - (11*(1 - 5*x - x^2 - 20*x^3 - x^4 - 
             5*x^5 + x^6)*HPL[{1, 0}, x])/(270*(-1 + x)^7*(1 + x)^5)) + 
        (x*(-30 - 1290*x - 2475*x^2 - 9840*x^3 - 75135*x^4 - 35780*x^5 - 
           50015*x^6 - 37750*x^7 - 38600*x^8 + 61052*x^9 + 31597*x^10 - 
           82454*x^11 - 9660*x^12 + 68520*x^13 - 7500*x^14 - 35160*x^15 + 
           9105*x^16 + 10230*x^17 - 3735*x^18 - 1296*x^19 + 576*x^20)*
          HPL[{2, 0}, x])/(1350*(-1 + x)^10*(1 + x)^8) + 
        (2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{-2, -1, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (8*x^2*(-24 - 115*x - 121*x^2 - 130*x^3 - 26*x^4 - 5*x^5 + x^6)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{-2, 1, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{-1, -2, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        ((576 - 1296*x - 2007*x^2 + 6342*x^3 + 1356*x^4 - 12246*x^5 + 
           3165*x^6 + 11460*x^7 - 6240*x^8 - 5104*x^9 + 5318*x^10 + 
           844*x^11 + 2264*x^12 + 844*x^13 + 5318*x^14 - 5104*x^15 - 
           6240*x^16 + 11460*x^17 + 3165*x^18 - 12246*x^19 + 1356*x^20 + 
           6342*x^21 - 2007*x^22 - 1296*x^23 + 576*x^24)*HPL[{-1, -1, 0}, x])/
         (2700*(-1 + x)^7*x^9*(1 + x)^5) - 
        ((203 + 10*x - 1053*x^2 + 28376*x^3 - 32774*x^4 + 10266*x^5 - 
           14558*x^6 + 21464*x^7 - 32805*x^8 + 33751*x^9 + 26375*x^10 - 
           55008*x^11 + 1500*x^12 + 42348*x^13 - 17676*x^14 - 14496*x^15 + 
           11508*x^16 + 585*x^17 - 2448*x^18 + 576*x^19)*HPL[{-1, 0, 0}, x])/
         (1350*(-1 + x)^10*(1 + x)^6) - 
        ((576 - 1296*x - 2007*x^2 + 6342*x^3 + 1356*x^4 - 12246*x^5 + 
           3165*x^6 + 11460*x^7 - 6240*x^8 - 5104*x^9 + 5318*x^10 + 
           844*x^11 + 2264*x^12 + 844*x^13 + 5318*x^14 - 5104*x^15 - 
           6240*x^16 + 11460*x^17 + 3165*x^18 - 12246*x^19 + 1356*x^20 + 
           6342*x^21 - 2007*x^22 - 1296*x^23 + 576*x^24)*HPL[{-1, 1, 0}, x])/
         (2700*(-1 + x)^7*x^9*(1 + x)^5) + 
        (2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{-1, 2, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (x*(-196830 - 8070030*x - 356513805*x^2 - 370005651*x^3 + 
           9139532535*x^4 + 19576634256*x^5 - 42301223811*x^6 - 
           306290660436*x^7 - 638260657491*x^8 + 2261731865694*x^9 + 
           6554153714892*x^10 - 8665747640091*x^11 - 12546516066138*x^12 + 
           18271448612816*x^13 - 21126767941126*x^14 - 25328170972448*x^15 - 
           30430975020202*x^16 + 22842828791530*x^17 + 18465495677669*x^18 - 
           17527820957353*x^19 - 4294376328381*x^20 + 12886004067648*x^21 - 
           430808558487*x^22 - 7497482831004*x^23 + 1329704954265*x^24 + 
           3052037815194*x^25 - 829593175014*x^26 - 820531553769*x^27 + 
           276736945680*x^28 + 138419510688*x^29 - 52752336048*x^30 - 
           13891928976*x^31 + 5700454866*x^32 + 754016364*x^33 - 
           324467694*x^34 - 17006112*x^35 + 7558272*x^36)*HPL[{0, 0, 0}, x])/
         (1350*(-1 + x)^10*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        (2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{1, -2, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) - 
        ((576 - 1296*x - 2007*x^2 + 6342*x^3 + 1356*x^4 - 12246*x^5 + 
           3165*x^6 + 11460*x^7 - 6240*x^8 - 5104*x^9 + 5318*x^10 + 
           844*x^11 + 2264*x^12 + 844*x^13 + 5318*x^14 - 5104*x^15 - 
           6240*x^16 + 11460*x^17 + 3165*x^18 - 12246*x^19 + 1356*x^20 + 
           6342*x^21 - 2007*x^22 - 1296*x^23 + 576*x^24)*HPL[{1, -1, 0}, x])/
         (2700*(-1 + x)^7*x^9*(1 + x)^5) + 
        ((203 + 582*x + 1331*x^2 + 26360*x^3 + 44714*x^4 + 74114*x^5 + 
           37514*x^6 + 41480*x^7 + 11411*x^8 - 31053*x^9 - 11245*x^10 + 
           39816*x^11 + 8736*x^12 - 32004*x^13 - 4224*x^14 + 16056*x^15 + 
           1176*x^16 - 4599*x^17 - 144*x^18 + 576*x^19)*HPL[{1, 0, 0}, x])/
         (1350*(-1 + x^2)^8) + ((576 - 1296*x - 2007*x^2 + 6342*x^3 + 
           1356*x^4 - 12246*x^5 + 3165*x^6 + 11460*x^7 - 6240*x^8 - 
           5104*x^9 + 5318*x^10 + 844*x^11 + 2264*x^12 + 844*x^13 + 
           5318*x^14 - 5104*x^15 - 6240*x^16 + 11460*x^17 + 3165*x^18 - 
           12246*x^19 + 1356*x^20 + 6342*x^21 - 2007*x^22 - 1296*x^23 + 
           576*x^24)*HPL[{1, 1, 0}, x])/(2700*(-1 + x)^7*x^9*(1 + x)^5) + 
        (2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{1, 2, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{2, -1, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (8*x^2*(24 + 115*x + 121*x^2 + 130*x^3 + 26*x^4 + 5*x^5 - x^6)*
          HPL[{2, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{2, 1, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (4*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*HPL[{-1, 0, 0, 0}, 
           x])/(45*(-1 + x)^7*(1 + x)^5) + 
        (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{-1, 1, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{1, -1, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (4*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*HPL[{1, 0, 0, 0}, x])/
         (45*(-1 + x)^7*(1 + x)^5) + ((-1 + 8*x + 39*x^2 + 359*x^3 + 
           353*x^4 + 651*x^5 + 161*x^6 + 119*x^7 - 12*x^8 + 3*x^9)*
          master3l10a[x])/(180*(-1 + x)^9*(1 + x)^7) + 
        (x*(-3 + 12*x - 119*x^2 - 161*x^3 - 651*x^4 - 353*x^5 - 359*x^6 - 
           39*x^7 - 8*x^8 + x^9)*master3l10b[x])/(180*(-1 + x)^9*(1 + x)^7) - 
        ((22599 + 62421354*x + 196915212*x^2 + 366482556*x^3 + 
           205839180*x^4 + 149609106*x^5 - 9454680*x^6 - 88567884*x^7 - 
           25698522*x^8 + 10580814*x^9 + 6134716*x^10 + 118580*x^11 - 
           550620*x^12 - 84170*x^13 + 19792*x^14 + 3612*x^15 - 157*x^16)*
          master3l8a[x])/(10800*(-1 + x)^10*(1 + x)^8*(-9 + x^2)^4) - 
        ((40 + 1837*x + 2848*x^2 - 72224*x^3 - 125038*x^4 + 1250220*x^5 + 
           1582952*x^6 - 11916132*x^7 - 7274646*x^8 + 61801058*x^9 + 
           4353216*x^10 - 139324296*x^11 + 6170022*x^12 + 29581524*x^13 + 
           173969208*x^14 - 26955828*x^15 + 5346486*x^16 + 764721*x^17)*
          master3l8b[x])/(10800*(-1 + x)^10*x*(1 + x)^8*(1 - 9*x^2)^4) + 
        ((-41229 + 3170826*x + 12432699*x^2 + 11047500*x^3 + 11173503*x^4 + 
           9196338*x^5 + 8456479*x^6 - 4140468*x^7 - 3921479*x^8 + 
           531918*x^9 + 567105*x^10 - 22252*x^11 - 37035*x^12 - 202*x^13 + 
           997*x^14 + 20*x^15)*master3l9a[x])/(3600*(-1 + x)^10*(1 + x)^8*
          (-9 + x^2)^3) + ((20 + 997*x - 202*x^2 - 37035*x^3 - 22252*x^4 + 
           567105*x^5 + 531918*x^6 - 3921479*x^7 - 4140468*x^8 + 
           8456479*x^9 + 9196338*x^10 + 11173503*x^11 + 11047500*x^12 + 
           12432699*x^13 + 3170826*x^14 - 41229*x^15)*master3l9b[x])/
         (10800*(-1 + x)^10*x*(1 + x)^8*(-1 + 9*x^2)^3) + 
        (HPL[{1}, x]*(Pi^2*(-576 + 1296*x + 2583*x^2 - 7638*x^3 - 3363*x^4 + 
             18588*x^5 - 1809*x^6 - 23706*x^7 + 9405*x^8 + 16564*x^9 - 
             11558*x^10 - 5948*x^11 + 3054*x^12 - 3054*x^14 + 5948*x^15 + 
             11558*x^16 - 16564*x^17 - 9405*x^18 + 23706*x^19 + 1809*x^20 - 
             18588*x^21 + 3363*x^22 + 7638*x^23 - 2583*x^24 - 1296*x^25 + 
             576*x^26) - 1440*x^9*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
             245*x^5 - 50*x^6 - 5*x^7 + x^8)*Zeta[3]))/(32400*(-1 + x)^8*x^9*
          (1 + x)^6) + (HPL[{-1}, x]*(Pi^2*(576 - 1296*x - 2583*x^2 + 
             7638*x^3 + 3363*x^4 - 18588*x^5 + 1809*x^6 + 23706*x^7 - 
             9405*x^8 - 16564*x^9 + 11558*x^10 + 5948*x^11 - 3054*x^12 + 
             3054*x^14 - 5948*x^15 - 11558*x^16 + 16564*x^17 + 9405*x^18 - 
             23706*x^19 - 1809*x^20 + 18588*x^21 - 3363*x^22 - 7638*x^23 + 
             2583*x^24 + 1296*x^25 - 576*x^26) + 1440*x^9*(1 - 5*x - 50*x^2 - 
             245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + x^8)*Zeta[3]))/
         (32400*(-1 + x)^8*x^9*(1 + x)^6) - 
        (HPL[{0}, x]*(226748160 - 510183360*x - 9507282660*x^2 + 
           22110307560*x^3 + 161487467640*x^4 - 394605046440*x^5 + 
           1215*(-1168778563 + 3240*Pi^2)*x^6 + 4374*(861149891 + 38700*Pi^2)*
            x^7 + 20*(-9377207229065 + 657157005176*Pi^2)*x^19 - 
           24*(159633707391 + 1271156451320*Pi^2)*x^31 + 
           180*(7925412789 + 46079914813*Pi^2)*x^32 + 
           135*(2929020669 + 60778996808*Pi^2)*x^33 - 
           360*(448576299 + 7687137380*Pi^2)*x^34 - 
           29160*(758241 + 47468968*Pi^2)*x^35 + 
           1620*(5868693 + 325631704*Pi^2)*x^36 + 349920*(1458 + 397003*Pi^2)*
            x^37 - 43740*(5184 + 1303259*Pi^2)*x^38 - 7540163640*Pi^2*x^39 + 
           3244676940*Pi^2*x^40 + 170061120*Pi^2*x^41 - 75582720*Pi^2*x^42 + 
           30*x^18*(10007221817567 + 1964244353636*Pi^2 - 5220591091200*
              Zeta[3]) + 3*x^28*(2435097086541 + 1842971916740*Pi^2 - 
             97627680000*Zeta[3]) - 81*x^10*(214085735633 + 4500*Pi^2 - 
             3615840000*Zeta[3]) - 6*x^30*(1116927497007 + 2216188370180*
              Pi^2 - 1417176000*Zeta[3]) + 27*x^8*(253885802771 + 
             6714900*Pi^2 - 314928000*Zeta[3]) - 81*x^9*(260701084897 + 
             60220800*Pi^2 + 104976000*Zeta[3]) + 450*x^11*
            (162555269027 + 94723992*Pi^2 + 688642560*Zeta[3]) + 
           6*x^29*(3840147140247 + 12437287972580*Pi^2 + 1417176000*
              Zeta[3]) - 30*x^27*(3372238047255 + 4140862781336*Pi^2 + 
             10329638400*Zeta[3]) - 18*x^13*(8962990419283 + 
             2694022500*Pi^2 + 236703384000*Zeta[3]) + 
           60*x^14*(2200981212237 + 62149398400*Pi^2 + 291744828000*
              Zeta[3]) - 9*x^12*(-1036110693347 + 22448026500*Pi^2 + 
             403597728000*Zeta[3]) - 6*x^16*(101178006747923 + 
             4207986708690*Pi^2 + 929879568000*Zeta[3]) + 
           3*x^26*(44423908626009 + 7204364199380*Pi^2 + 1210793184000*
              Zeta[3]) - 5*x^24*(173931429546279 + 9820611655840*Pi^2 + 
             3500937936000*Zeta[3]) + x^25*(373899649098169 + 
             143381162972080*Pi^2 + 4260660912000*Zeta[3]) + 
           x^22*(1198090137251163 + 37941449649460*Pi^2 + 5579277408000*
              Zeta[3]) - 2*x^23*(508827579850707 + 57525698624360*Pi^2 + 
             13172201856000*Zeta[3]) + 4*x^21*(338470872522069 + 
             13975303708100*Pi^2 + 15711784488000*Zeta[3]) - 
           3*x^17*(57129955100017 + 755498057080*Pi^2 + 20949045984000*
              Zeta[3]) + x^15*(218917948040364 - 542669283840*Pi^2 + 
             26344403712000*Zeta[3]) + 10*x^20*(305602153708*Pi^2 + 
             51*(6096140591399 + 307093593600*Zeta[3]))))/
         (324000*(-1 + x)^10*x^5*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        (240*Pi^4*x^7*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (-3 + 15*x - 234*x^2 - 1105*x^3 - 1210*x^4 - 1345*x^5 - 266*x^6 - 
            65*x^7 + 13*x^8) - 12*Pi^2*(9 - 82*x^2 + 9*x^4)^4*
           (-5760 + 12960*x + 34470*x^2 - 95820*x^3 - 74295*x^4 + 
            304770*x^5 + 40485*x^6 - 544782*x^7 + 150669*x^8 + 617918*x^9 + 
            8945*x^10 - 100390*x^11 + 759510*x^12 - 759510*x^14 + 
            100390*x^15 - 8945*x^16 - 617918*x^17 - 150669*x^18 + 
            544782*x^19 - 40485*x^20 - 304770*x^21 + 74295*x^22 + 
            95820*x^23 - 34470*x^24 - 12960*x^25 + 5760*x^26) + 
          x^2*(680244480 - 1530550080*x - 28748596140*x^2 + 66841106040*x^3 + 
            493796081520*x^4 + x^20*(9189104741491476 - 4213260023906880*Zeta[
                3]) - 271445891040*x^39*Zeta[3] + 116808369840*x^40*Zeta[3] + 
            6122200320*x^41*Zeta[3] - 2720977920*x^42*Zeta[3] + 
            32805*x^5*(-36950231 + 35712*Zeta[3]) + 29160*x^6*
             (-143812181 + 373734*Zeta[3]) + 6298560*x^37*
             (-243 + 794006*Zeta[3]) - 1574640*x^38*(-432 + 1303259*Zeta[
                3]) - 2916*x^7*(-4377968929 + 22298040*Zeta[3]) - 
            324*x^8*(-48848934413 + 50043420*Zeta[3]) - 262440*x^35*
             (-254691 + 189875872*Zeta[3]) + 14580*x^36*(-1971783 + 
              1302526816*Zeta[3]) + 243*x^9*(-409374449101 + 5484234240*Zeta[
                3]) + 3888*x^12*(63319044551 + 43904811430*Zeta[3]) - 
            1620*x^34*(-304867071 + 61497099040*Zeta[3]) + 
            2376*x^28*(-39647528981 + 79567955540*Zeta[3]) - 
            108*x^10*(158282931857 + 81467820360*Zeta[3]) + 
            3240*x^32*(-1372570209 + 92162347592*Zeta[3]) - 
            72*x^11*(-8741359875197 + 191986282800*Zeta[3]) + 
            1215*x^33*(-991342287 + 243117379136*Zeta[3]) - 
            180*x^15*(-20146975664831 + 3888368468320*Zeta[3]) - 
            108*x^30*(-218759101089 + 4431734617720*Zeta[3]) + 
            108*x^26*(3544925516111 + 8908407494360*Zeta[3]) - 
            108*x^31*(-105503235183 + 10170104676640*Zeta[3]) - 
            108*x^14*(24738394306711 + 11888060251000*Zeta[3]) + 
            5*x^13*(-508973095636355 + 19571874780096*Zeta[3]) - 
            180*x^23*(5148170516389 + 26935017844496*Zeta[3]) + 
            96*x^16*(45015231369733 + 40838011131840*Zeta[3]) - 
            256*x^19*(-39778711073069 + 45761028781590*Zeta[3]) - 
            72*x^27*(-1528442446997 + 62364673334640*Zeta[3]) - 
            36*x^24*(25186501622883 + 88528634951200*Zeta[3]) + 
            27*x^29*(-2124046149759 + 99566730260800*Zeta[3]) - 
            24*x^18*(-645092073920849 + 101631649404120*Zeta[3]) + 
            48*x^22*(-42754999128709 + 127233754812630*Zeta[3]) + 
            5*x^25*(48848328816415 + 1054649176336512*Zeta[3]) + 
            3*x^17*(931574668022351 + 1384278704792640*Zeta[3]) + 
            x^21*(-3111682800853497 + 6272777047512960*Zeta[3])))/
         (3888000*(-1 + x)^10*x^7*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^4)) + 
      CF^2*((Pi^2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{-2}, x])/(135*(-1 + x)^8*(1 + x)^6) + 
        lm^2*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 
             5*x^7 - x^8)/(10*(-1 + x)^8*(1 + x)^6) + 
          (12*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/
           ((-1 + x)^9*(1 + x)^7)) + (Pi^2*(1 - 5*x - 50*x^2 - 245*x^3 - 
           242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{2}, x])/
         (135*(-1 + x)^8*(1 + x)^6) - (x*(60 + 2580*x + 16890*x^2 + 
           28500*x^3 + 216150*x^4 + 102320*x^5 + 43190*x^6 + 147130*x^7 + 
           325660*x^8 - 412803*x^9 - 418722*x^10 + 812413*x^11 + 
           317296*x^12 - 989548*x^13 - 61264*x^14 + 773847*x^15 - 
           109254*x^16 - 379803*x^17 + 106026*x^18 + 106896*x^19 - 
           40512*x^20 - 13200*x^21 + 6000*x^22)*HPL[{-2, 0}, x])/
         (1350*(-1 + x)^10*(1 + x)^8) + ((360000 - 792000*x - 1890720*x^2 + 
           5225760*x^3 + 3375480*x^4 - 14619540*x^5 - 719220*x^6 + 
           22357110*x^7 - 6087840*x^8 - (19946173 + 1200*Pi^2)*x^9 + 
           20*(505147 + 300*Pi^2)*x^10 + 3*(3422023 + 20400*Pi^2)*x^11 + 
           40*(-90929 + 7200*Pi^2)*x^12 + (2858734 + 230400*Pi^2)*x^13 + 
           21084240*x^14 + (2858734 - 230400*Pi^2)*x^15 - 
           40*(90929 + 7200*Pi^2)*x^16 + (10266069 - 61200*Pi^2)*x^17 - 
           20*(-505147 + 300*Pi^2)*x^18 + (-19946173 + 1200*Pi^2)*x^19 - 
           6087840*x^20 + 22357110*x^21 - 719220*x^22 - 14619540*x^23 + 
           3375480*x^24 + 5225760*x^25 - 1890720*x^26 - 792000*x^27 + 
           360000*x^28)*HPL[{-1, 0}, x])/(162000*(-1 + x)^9*x^9*(1 + x)^7) - 
        (x*(70858800 + 3317897700*x + 71883628200*x^2 - 12478132620*x^3 - 
           2150931959550*x^4 - 1738112221170*x^5 + 18679600823850*x^6 + 
           29584605691575*x^7 + 1022929740630*x^8 - 180954915419358*x^9 - 
           610476981434370*x^10 + 403923962550363*x^11 + 1044673618325640*
            x^12 - 193054704625498*x^13 + 5107315230871640*x^14 + 
           354355949021818*x^15 + 315663050111780*x^16 + 1743757818268912*
            x^17 + 67099971371540*x^18 - 3401247748578478*x^19 - 
           349345453104030*x^20 + 3278082703495218*x^21 - 
           174097018768470*x^22 - 2058560083476093*x^23 + 
           382888271550270*x^24 + 868106451224538*x^25 - 244356928116570*
            x^26 - 239270788678113*x^27 + 83224339080660*x^28 + 
           41099739060330*x^29 - 16104161938860*x^30 - 4178057178420*x^31 + 
           1758604578840*x^32 + 228859227360*x^33 - 100847293920*x^34 - 
           5196312000*x^35 + 2361960000*x^36)*HPL[{0, 0}, x])/
         (81000*(-1 + x)^10*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        ((-360000 + 792000*x + 1890720*x^2 - 5225760*x^3 - 3375480*x^4 + 
           14619540*x^5 + 719220*x^6 - 22357110*x^7 + 6087840*x^8 + 
           (19946173 + 1200*Pi^2)*x^9 - 20*(505147 + 300*Pi^2)*x^10 - 
           3*(3422023 + 20400*Pi^2)*x^11 - 40*(-90929 + 7200*Pi^2)*x^12 - 
           2*(1429367 + 115200*Pi^2)*x^13 - 21084240*x^14 + 
           (-2858734 + 230400*Pi^2)*x^15 + 40*(90929 + 7200*Pi^2)*x^16 + 
           3*(-3422023 + 20400*Pi^2)*x^17 + 20*(-505147 + 300*Pi^2)*x^18 + 
           (19946173 - 1200*Pi^2)*x^19 + 6087840*x^20 - 22357110*x^21 + 
           719220*x^22 + 14619540*x^23 - 3375480*x^24 - 5225760*x^25 + 
           1890720*x^26 + 792000*x^27 - 360000*x^28)*HPL[{1, 0}, x])/
         (162000*(-1 + x)^9*x^9*(1 + x)^7) + 
        lm*((22 + 27*x + 98*x^2 - 3132*x^3 - 888*x^4 - 3132*x^5 + 98*x^6 + 
            27*x^7 + 22*x^8 + 2*Pi^2*(-1 + 5*x + 2*x^2 + 15*x^3 - 15*x^5 - 
              2*x^6 - 5*x^7 + x^8))/(180*(-1 + x)^8*(1 + x)^6) + 
          (x^2*(-2 + 691*x + 533*x^2 + 2713*x^3 + 1013*x^4 + 1531*x^5 + 
             88*x^6 + 30*x^7 - 6*x^8)*HPL[{0}, x])/(15*(-1 + x)^9*
            (1 + x)^7) + (2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*
            HPL[{-1, 0}, x])/(15*(-1 + x)^7*(1 + x)^5) + 
          (4*x^3*(-180 - 180*x - 1260*x^2 - 800*x^3 - 1940*x^4 - 535*x^5 - 
             545*x^6 - 4*x^7 - 5*x^8 + x^9)*HPL[{0, 0}, x])/
           (15*(-1 + x)^10*(1 + x)^8) + (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 
             5*x^5 + x^6)*HPL[{1, 0}, x])/(15*(-1 + x)^7*(1 + x)^5)) + 
        (x*(60 + 2580*x + 16890*x^2 + 28500*x^3 + 216150*x^4 + 102320*x^5 + 
           43190*x^6 + 147130*x^7 + 325660*x^8 - 412803*x^9 - 418722*x^10 + 
           812413*x^11 + 317296*x^12 - 989548*x^13 - 61264*x^14 + 
           773847*x^15 - 109254*x^16 - 379803*x^17 + 106026*x^18 + 
           106896*x^19 - 40512*x^20 - 13200*x^21 + 6000*x^22)*HPL[{2, 0}, x])/
         (1350*(-1 + x)^10*(1 + x)^8) + (4*(1 - 5*x - 50*x^2 - 245*x^3 - 
           242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^6) - (8*(1 - 5*x - 50*x^2 - 245*x^3 - 
           242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{-2, 0, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^6) + (4*(-1 + 5*x + 50*x^2 + 245*x^3 + 
           242*x^4 + 245*x^5 + 50*x^6 + 5*x^7 - x^8)*HPL[{-2, 1, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^6) + (4*(-1 + 5*x + 50*x^2 + 245*x^3 + 
           242*x^4 + 245*x^5 + 50*x^6 + 5*x^7 - x^8)*HPL[{-1, -2, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^6) + ((6000 - 13200*x - 10512*x^2 + 
           40896*x^3 - 6534*x^4 - 43323*x^5 + 23196*x^6 + 16272*x^7 - 
           15064*x^8 + 2*x^9 + 3236*x^10 - 847*x^11 + 356*x^12 - 847*x^13 + 
           3236*x^14 + 2*x^15 - 15064*x^16 + 16272*x^17 + 23196*x^18 - 
           43323*x^19 - 6534*x^20 + 40896*x^21 - 10512*x^22 - 13200*x^23 + 
           6000*x^24)*HPL[{-1, -1, 0}, x])/(2700*(-1 + x)^5*x^11*(1 + x)^3) + 
        ((153 + 2670*x + 1302*x^2 + 73598*x^3 - 84254*x^4 - 12390*x^5 + 
           4358*x^6 + 83734*x^7 - 224412*x^8 + 133392*x^9 + 378366*x^10 - 
           470166*x^11 - 249934*x^12 + 652738*x^13 - 65994*x^14 - 
           459486*x^15 + 211119*x^16 + 146502*x^17 - 124320*x^18 - 
           3888*x^19 + 25200*x^20 - 6000*x^21)*HPL[{-1, 0, 0}, x])/
         (1350*(-1 + x)^10*(1 + x)^6) + 
        ((-6000 + 13200*x + 10512*x^2 - 40896*x^3 + 6534*x^4 + 43323*x^5 - 
           23196*x^6 - 16272*x^7 + 15064*x^8 - 2*x^9 - 3236*x^10 + 847*x^11 - 
           356*x^12 + 847*x^13 - 3236*x^14 - 2*x^15 + 15064*x^16 - 
           16272*x^17 - 23196*x^18 + 43323*x^19 + 6534*x^20 - 40896*x^21 + 
           10512*x^22 + 13200*x^23 - 6000*x^24)*HPL[{-1, 1, 0}, x])/
         (2700*(-1 + x)^5*x^11*(1 + x)^3) + 
        (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{-1, 2, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (x*(-196830 - 8857350*x + 332588025*x^2 + 355269159*x^3 - 
           9018876960*x^4 - 562710753*x^5 + 71409011454*x^6 - 
           152761356072*x^7 - 64358188680*x^8 + 2674235367660*x^9 + 
           300284572803*x^10 - 18039998897457*x^11 - 19094877285798*x^12 + 
           46282689270877*x^13 + 83161616473588*x^14 - 24387812783387*x^15 - 
           12282103060040*x^16 + 86774374448164*x^17 + 88623403078063*x^18 - 
           135012094617754*x^19 - 77789478865834*x^20 + 164926038657617*
            x^21 + 38199573272414*x^22 - 158484501831526*x^23 - 
           3152853262384*x^24 + 112692046835100*x^25 - 13874744389707*x^26 - 
           57693941276433*x^27 + 13055621594886*x^28 + 20734392938211*x^29 - 
           6264061915392*x^30 - 5044216698951*x^31 + 1801819466862*x^32 + 
           791032772106*x^33 - 313066501632*x^34 - 75391852491*x^35 + 
           31847661162*x^36 + 3944228256*x^37 - 1739837232*x^38 - 
           86605200*x^39 + 39366000*x^40)*HPL[{0, 0, 0}, x])/
         (675*(-1 + x)^11*(1 + x)^9*(9 - 82*x^2 + 9*x^4)^4) + 
        (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{1, -2, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        ((-6000 + 13200*x + 10512*x^2 - 40896*x^3 + 6534*x^4 + 43323*x^5 - 
           23196*x^6 - 16272*x^7 + 15064*x^8 - 2*x^9 - 3236*x^10 + 847*x^11 - 
           356*x^12 + 847*x^13 - 3236*x^14 - 2*x^15 + 15064*x^16 - 
           16272*x^17 - 23196*x^18 + 43323*x^19 + 6534*x^20 - 40896*x^21 + 
           10512*x^22 + 13200*x^23 - 6000*x^24)*HPL[{1, -1, 0}, x])/
         (2700*(-1 + x)^5*x^11*(1 + x)^3) - 
        ((153 + 2802*x + 14646*x^2 + 101362*x^3 + 193122*x^4 + 253486*x^5 + 
           130774*x^6 + 164026*x^7 + 85492*x^8 - 228740*x^9 - 119834*x^10 + 
           408550*x^11 + 125034*x^12 - 475778*x^13 - 87042*x^14 + 
           362958*x^15 + 39111*x^16 - 175482*x^17 - 10272*x^18 + 48912*x^19 + 
           1200*x^20 - 6000*x^21)*HPL[{1, 0, 0}, x])/(1350*(-1 + x^2)^8) + 
        ((6000 - 13200*x - 10512*x^2 + 40896*x^3 - 6534*x^4 - 43323*x^5 + 
           23196*x^6 + 16272*x^7 - 15064*x^8 + 2*x^9 + 3236*x^10 - 847*x^11 + 
           356*x^12 - 847*x^13 + 3236*x^14 + 2*x^15 - 15064*x^16 + 
           16272*x^17 + 23196*x^18 - 43323*x^19 - 6534*x^20 + 40896*x^21 - 
           10512*x^22 - 13200*x^23 + 6000*x^24)*HPL[{1, 1, 0}, x])/
         (2700*(-1 + x)^5*x^11*(1 + x)^3) + 
        (4*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{1, 2, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (4*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{2, -1, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (8*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{2, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) + 
        (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{2, 1, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) - 
        (8*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{-1, 1, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) - 
        (8*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{1, -1, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^6) - 
        ((-1 + 8*x + 39*x^2 + 359*x^3 + 353*x^4 + 651*x^5 + 161*x^6 + 
           119*x^7 - 12*x^8 + 3*x^9)*master3l10a[x])/(90*(-1 + x)^9*
          (1 + x)^7) + (x*(3 - 12*x + 119*x^2 + 161*x^3 + 651*x^4 + 353*x^5 + 
           359*x^6 + 39*x^7 + 8*x^8 - x^9)*master3l10b[x])/
         (90*(-1 + x)^9*(1 + x)^7) + ((22599 + 62421354*x + 196915212*x^2 + 
           366482556*x^3 + 205839180*x^4 + 149609106*x^5 - 9454680*x^6 - 
           88567884*x^7 - 25698522*x^8 + 10580814*x^9 + 6134716*x^10 + 
           118580*x^11 - 550620*x^12 - 84170*x^13 + 19792*x^14 + 3612*x^15 - 
           157*x^16)*master3l8a[x])/(5400*(-1 + x)^10*(1 + x)^8*
          (-9 + x^2)^4) + ((40 + 1837*x + 2848*x^2 - 72224*x^3 - 125038*x^4 + 
           1250220*x^5 + 1582952*x^6 - 11916132*x^7 - 7274646*x^8 + 
           61801058*x^9 + 4353216*x^10 - 139324296*x^11 + 6170022*x^12 + 
           29581524*x^13 + 173969208*x^14 - 26955828*x^15 + 5346486*x^16 + 
           764721*x^17)*master3l8b[x])/(5400*(-1 + x)^10*x*(1 + x)^8*
          (1 - 9*x^2)^4) - ((-41229 + 3170826*x + 12432699*x^2 + 
           11047500*x^3 + 11173503*x^4 + 9196338*x^5 + 8456479*x^6 - 
           4140468*x^7 - 3921479*x^8 + 531918*x^9 + 567105*x^10 - 
           22252*x^11 - 37035*x^12 - 202*x^13 + 997*x^14 + 20*x^15)*
          master3l9a[x])/(1800*(-1 + x)^10*(1 + x)^8*(-9 + x^2)^3) - 
        ((20 + 997*x - 202*x^2 - 37035*x^3 - 22252*x^4 + 567105*x^5 + 
           531918*x^6 - 3921479*x^7 - 4140468*x^8 + 8456479*x^9 + 
           9196338*x^10 + 11173503*x^11 + 11047500*x^12 + 12432699*x^13 + 
           3170826*x^14 - 41229*x^15)*master3l9b[x])/(5400*(-1 + x)^10*x*
          (1 + x)^8*(-1 + 9*x^2)^3) - 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(6000 - 13200*x - 10512*x^2 + 
             40896*x^3 - 6534*x^4 - 43323*x^5 + 23196*x^6 + 16272*x^7 - 
             15064*x^8 + 2*x^9 + 3236*x^10 - 847*x^11 + 356*x^12 - 847*x^13 + 
             3236*x^14 + 2*x^15 - 15064*x^16 + 16272*x^17 + 23196*x^18 - 
             43323*x^19 - 6534*x^20 + 40896*x^21 - 10512*x^22 - 13200*x^23 + 
             6000*x^24) + 2880*x^11*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
             245*x^5 - 50*x^6 - 5*x^7 + x^8)*Zeta[3]))/(32400*(-1 + x)^8*x^11*
          (1 + x)^6) + (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(6000 - 13200*x - 
             10512*x^2 + 40896*x^3 - 6534*x^4 - 43323*x^5 + 23196*x^6 + 
             16272*x^7 - 15064*x^8 + 2*x^9 + 3236*x^10 - 847*x^11 + 
             356*x^12 - 847*x^13 + 3236*x^14 + 2*x^15 - 15064*x^16 + 
             16272*x^17 + 23196*x^18 - 43323*x^19 - 6534*x^20 + 40896*x^21 - 
             10512*x^22 - 13200*x^23 + 6000*x^24) + 2880*x^11*
            (1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 
             5*x^7 + x^8)*Zeta[3]))/(32400*(-1 + x)^8*x^11*(1 + x)^6) + 
        (HPL[{0}, x]*(-2361960000 + 5196312000*x + 99666313920*x^2 - 
           226261071360*x^3 - 1708968251880*x^4 + 4065359668740*x^5 + 
           15257884924080*x^6 - 39085697802240*x^7 + 
           90*(-841480793707 + 87480*Pi^2)*x^8 + 9*(24453266583499 + 
             37616400*Pi^2)*x^9 + 40*(-1067590990125 + 67347665356*Pi^2)*
            x^21 - 3*(73409723590197 + 275219744708300*Pi^2)*x^33 + 
           120*(631195103694 + 1385051667943*Pi^2)*x^34 + 
           30*(1302921558243 + 10939773241478*Pi^2)*x^35 - 
           240*(63574520517 + 395430146686*Pi^2)*x^36 - 
           60*(67755994479 + 1441572718760*Pi^2)*x^37 + 
           120*(14241402099 + 253150025860*Pi^2)*x^38 + 
           540*(419001984 + 26648094173*Pi^2)*x^39 - 
           1080*(92283624 + 5239246513*Pi^2)*x^40 - 
           72900*(71280 + 19625303*Pi^2)*x^41 + 145800*(16200 + 4135417*Pi^2)*
            x^42 + 77152461120*Pi^2*x^43 - 34009424640*Pi^2*x^44 - 
           1732104000*Pi^2*x^45 + 787320000*Pi^2*x^46 + 
           20*x^20*(159989558716117 + 11133338135460*Pi^2 - 
             15661773273600*Zeta[3]) + 18*x^15*(-139526265847877 + 
             19244079300*Pi^2 - 473406768000*Zeta[3]) + 
           270*x^14*(99360124033 + 222429620*Pi^2 - 26906515200*Zeta[3]) - 
           30*x^12*(9506002496831 + 1615196700*Pi^2 - 19525536000*Zeta[3]) + 
           90*x^10*(2308101097681 + 21437460*Pi^2 - 188956800*Zeta[3]) - 
           120*x^32*(1727993960877 + 927664667132*Pi^2 - 141717600*Zeta[3]) - 
           144*x^11*(5290119729517 + 59711175*Pi^2 + 118098000*Zeta[3]) + 
           18*x^31*(42560441575511 + 79299363083680*Pi^2 + 
             944784000*Zeta[3]) - 160*x^29*(11007900948687 + 
             10817628087980*Pi^2 + 3873614400*Zeta[3]) + 
           120*x^13*(14172502601531 + 392571360*Pi^2 + 5164819200*Zeta[3]) - 
           10*x^30*(-26522862153783 + 17098645091924*Pi^2 + 
             58576608000*Zeta[3]) - 20*x^18*(119461452102271 + 
             3510358060782*Pi^2 + 557927740800*Zeta[3]) + 
           10*x^28*(24487340011839 + 53963807540636*Pi^2 + 726475910400*
              Zeta[3]) + 10*x^24*(313548979755737 + 52711150882220*Pi^2 + 
             1115855481600*Zeta[3]) + 20*x^16*(37809675891739 + 
             359568484620*Pi^2 + 1750468968000*Zeta[3]) + 
           4*x^27*(738097172779509 + 370076282866310*Pi^2 + 
             2130330456000*Zeta[3]) - 10*x^26*(210272084631443 + 
             69984338447424*Pi^2 + 3500937936000*Zeta[3]) - 
           9*x^25*(435695304656879 + 98287583861140*Pi^2 + 5854311936000*
              Zeta[3]) - 6*x^19*(204125831035669 + 309329879770*Pi^2 + 
             20949045984000*Zeta[3]) + 4*x^23*(801613783049991 + 
             85080835391795*Pi^2 + 31423568976000*Zeta[3]) + 
           x^22*(3939132467387860 - 206129045451440*Pi^2 + 313235465472000*
              Zeta[3]) + x^17*(-3067446117660*Pi^2 + 
             99*(23868572330689 + 532210176000*Zeta[3]))))/
         (324000*(-1 + x)^10*x^7*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^4) - 
        (4800*Pi^4*x^9*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
            x^8) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^4*(-360000 + 792000*x + 
            2250720*x^2 - 6017760*x^3 - 5266200*x^4 + 19845300*x^5 + 
            4094700*x^6 - 36976650*x^7 + 5368620*x^8 + 42303283*x^9 - 
            16190780*x^10 - 30212242*x^11 + 13740100*x^12 + 7407335*x^13 - 
            24721400*x^14 + 24721400*x^16 - 7407335*x^17 - 13740100*x^18 + 
            30212242*x^19 + 16190780*x^20 - 42303283*x^21 - 5368620*x^22 + 
            36976650*x^23 - 4094700*x^24 - 19845300*x^25 + 5266200*x^26 + 
            6017760*x^27 - 2250720*x^28 - 792000*x^29 + 360000*x^30) + 
          x^2*(-14171760000 + 31177872000*x + 602721803520*x^2 - 
            1367959052160*x^3 - 10451370669120*x^4 + 24840782921160*x^5 + 
            94891126168800*x^6 + 5554977200640*x^43*Zeta[3] - 
            2448678574080*x^44*Zeta[3] - 124711488000*x^45*Zeta[3] + 
            56687040000*x^46*Zeta[3] + 10497600*x^42*(-1350 + 
              4135417*Zeta[3]) + 1215*x^7*(-199590778795 + 7177248*Zeta[3]) + 
            1080*x^8*(-446908487201 + 13629384*Zeta[3]) - 
            5248800*x^41*(-5940 + 19625303*Zeta[3]) + 
            360*x^10*(3773725899173 + 1227315240*Zeta[3]) - 
            77760*x^40*(-7751052 + 5239246513*Zeta[3]) - 
            4320*x^12*(429641255719 + 6961503204*Zeta[3]) - 
            54*x^9*(-25931427110713 + 8880833520*Zeta[3]) + 
            38880*x^39*(-35184132 + 26648094173*Zeta[3]) + 
            8640*x^38*(-1209649383 + 253150025860*Zeta[3]) + 
            720*x^14*(1581331416599 + 705169925640*Zeta[3]) + 
            9*x^11*(-569335714570631 + 1062652841280*Zeta[3]) - 
            36*x^13*(-369257561718367 + 2458956703680*Zeta[3]) - 
            2160*x^36*(-43931240955 + 3163441173488*Zeta[3]) - 
            8640*x^22*(-4243906014317 + 3959111613024*Zeta[3]) - 
            1080*x^37*(-23000724927 + 5766290875040*Zeta[3]) - 
            720*x^20*(-85888566797409 + 6786728434624*Zeta[3]) + 
            1080*x^34*(-447847614161 + 11080410701648*Zeta[3]) + 
            2880*x^28*(585148840991 + 13679519349434*Zeta[3]) - 
            720*x^30*(3006225157749 + 17146377549848*Zeta[3]) - 
            360*x^32*(-3860380656593 + 22261436203008*Zeta[3]) - 
            90*x^17*(-357958617378017 + 22526303064672*Zeta[3]) - 
            120*x^16*(64394914339355 + 31126677591264*Zeta[3]) + 
            675*x^35*(-359217941391 + 35007292330624*Zeta[3]) + 
            5*x^15*(-5393814643684217 + 86519143468224*Zeta[3]) + 
            120*x^18*(126138856679801 + 96215483140752*Zeta[3]) + 
            120*x^24*(-86317882309279 + 449804167666656*Zeta[3]) - 
            120*x^26*(5560496782655 + 455411214775248*Zeta[3]) - 
            90*x^25*(-155597447928257 + 729639872223552*Zeta[3]) - 
            54*x^33*(-25829811703513 + 1100890858481120*Zeta[3]) - 
            36*x^29*(-311554222292767 + 3464697277478080*Zeta[3]) + 
            3*x^19*(746549604115883 + 4520600529945600*Zeta[3]) - 
            8*x^21*(-5300158343875999 + 5946737595334560*Zeta[3]) + 
            9*x^31*(-550611827864831 + 11420486445758400*Zeta[3]) + 
            3*x^23*(-7128659469111517 + 12789420758980800*Zeta[3]) + 
            5*x^27*(-3162528945873137 + 21413527913448000*Zeta[3])))/
         (7776000*(-1 + x)^10*x^9*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^4)));


CbarData["s",2,4] = NC*(CF*(NL*((Pi^2*(-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 
             2*x^6 + 6*x^7 - x^8)*HPL[{-1}, x])/(1620*(-1 + x)^9*(1 + x)^7) + 
          (x^2*(-1233 - 63*(45809 + 3000*Pi^2)*x - 18*(195203 + 15750*Pi^2)*
              x^2 - 63*(254581 + 24000*Pi^2)*x^3 - 4*(1953451 + 301875*Pi^2)*
              x^4 - 210*(18871 + 13200*Pi^2)*x^5 + (5742014 - 1198050*Pi^2)*
              x^6 - 252*(-70094 + 5925*Pi^2)*x^7 + (5504139 - 285390*Pi^2)*
              x^8 - 63*(-82579 + 3120*Pi^2)*x^9 + (89398 - 1050*Pi^2)*x^10 - 
             105*(-203 + 12*Pi^2)*x^11 + 70*(-98 + 3*Pi^2)*x^12)*HPL[{0}, x])/
           (340200*(-1 + x)^12*(1 + x)^10) + 
          lm^2*(-(-1 + 6*x + 23*x^2 + 356*x^3 + 398*x^4 + 956*x^5 + 398*x^6 + 
               356*x^7 + 23*x^8 + 6*x^9 - x^10)/(240*(-1 + x)^10*(1 + x)^8) + 
            (x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*x^5 + 2*x^6)*
              HPL[{0}, x])/(2*(-1 + x)^11*(1 + x)^9)) + 
          (Pi^2*(1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + 
             x^8)*HPL[{1}, x])/(1620*(-1 + x)^9*(1 + x)^7) + 
          (x^3*(900 + 1350*x + 7200*x^2 + 5750*x^3 + 13200*x^4 + 5705*x^5 + 
             7110*x^6 + 1359*x^7 + 936*x^8 + 5*x^9 + 6*x^10 - x^11)*
            HPL[{-2, 0}, x])/(135*(-1 + x)^12*(1 + x)^10) - 
          ((-137 + 602*x + 13968*x^2 + 347774*x^3 + 454821*x^4 + 
             1706264*x^5 + 1046216*x^6 + 1706264*x^7 + 454821*x^8 + 
             347774*x^9 + 13968*x^10 + 602*x^11 - 137*x^12)*HPL[{-1, 0}, x])/
           (37800*(-1 + x)^11*(1 + x)^9) + 
          (x^3*(-84000 - 126000*x - 861000*x^2 - 721000*x^3 - 2212000*x^4 - 
             1045275*x^5 - 1668450*x^6 - 344757*x^7 - 291228*x^8 - 1365*x^9 - 
             3178*x^10 + 493*x^11)*HPL[{0, 0}, x])/(18900*(-1 + x)^12*
            (1 + x)^10) + ((-137 + 602*x + 13968*x^2 + 347774*x^3 + 
             454821*x^4 + 1706264*x^5 + 1046216*x^6 + 1706264*x^7 + 
             454821*x^8 + 347774*x^9 + 13968*x^10 + 602*x^11 - 137*x^12)*
            HPL[{1, 0}, x])/(37800*(-1 + x)^11*(1 + x)^9) + 
          lm*(-(-196 + 609*x + 2127*x^2 + 67404*x^3 + 61321*x^4 + 180630*
                x^5 + 61321*x^6 + 67404*x^7 + 2127*x^8 + 609*x^9 - 196*x^10 - 
               6*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 16*x^4 - 16*x^6 - 48*x^7 - 
                 3*x^8 - 6*x^9 + x^10))/(19440*(-1 + x)^10*(1 + x)^8) + 
            (x^2*(-2 + 2412*x + 3130*x^2 + 16758*x^3 + 11358*x^4 + 22158*
                x^5 + 6505*x^6 + 5562*x^7 + 214*x^8 + 54*x^9 - 9*x^10)*
              HPL[{0}, x])/(540*(-1 + x)^11*(1 + x)^9) + 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{-1, 0}, x])/(270*(-1 + x)^9*(1 + x)^7) + 
            (x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 13200*x^4 - 7055*x^5 - 
               9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 6*x^10 + x^11)*
              HPL[{0, 0}, x])/(135*(-1 + x)^12*(1 + x)^10) - 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{1, 0}, x])/(270*(-1 + x)^9*(1 + x)^7)) + 
          (x^3*(-900 - 1350*x - 7200*x^2 - 5750*x^3 - 13200*x^4 - 5705*x^5 - 
             7110*x^6 - 1359*x^7 - 936*x^8 - 5*x^9 - 6*x^10 + x^11)*
            HPL[{2, 0}, x])/(135*(-1 + x)^12*(1 + x)^10) - 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{-1, -1, 0}, x])/(135*(-1 + x)^9*(1 + x)^7) + 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{-1, 1, 0}, x])/(135*(-1 + x)^9*(1 + x)^7) + 
          (2*x^3*(360 + 540*x + 4500*x^2 + 4400*x^3 + 13200*x^4 + 7055*x^5 + 
             9810*x^6 + 2169*x^7 + 1476*x^8 + 5*x^9 + 6*x^10 - x^11)*
            HPL[{0, 0, 0}, x])/(135*(-1 + x)^12*(1 + x)^10) + 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{1, -1, 0}, x])/(135*(-1 + x)^9*(1 + x)^7) - 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{1, 1, 0}, x])/(135*(-1 + x)^9*(1 + x)^7) - 
          (-2759767*x^12 - 1083390*x^13 - 131005*x^14 + 
            36*Pi^2*(-137 + 602*x + 14105*x^2 + 347172*x^3 + 440853*x^4 + 
              1358490*x^5 + 591395*x^6 - 591395*x^8 - 1358490*x^9 - 
              440853*x^10 - 347172*x^11 - 14105*x^12 - 602*x^13 + 137*x^14) + 
            210*x*(-5159 + 1728*Zeta[3]) - 35*(3743 + 1728*Zeta[3]) + 
            252*x^11*(174391 + 216000*Zeta[3]) + 252*x^3*
             (174391 + 224640*Zeta[3]) + x^2*(-2759767 + 302400*Zeta[3]) + 
            630*x^5*(56909 + 682560*Zeta[3]) + 630*x^9*(56909 + 
              691200*Zeta[3]) + 27*x^10*(1007201 + 3024000*Zeta[3]) + 
            27*x^4*(1007201 + 3044160*Zeta[3]) + 168*x^7*(-937093 + 
              4752000*Zeta[3]) + 5*x^6*(-4860731 + 69007680*Zeta[3]) + 
            5*x^8*(-4860731 + 69552000*Zeta[3]))/(16329600*(-1 + x)^12*
            (1 + x)^10)) + NH*((x*(-964246550400 + 9949254819696*x - 
             1126512716072436*x^2 - 769700029364811*x^3 - 4117798490348970*
              x^4 - 1013461146341658*x^5 - 789271041204450*x^6 + 
             786249767764188*x^7 + 1542223615448250*x^8 - 13589688309966*
              x^9 - 349982760245202*x^10 - 107396456038263*x^11 - 
             17631537296436*x^12 + 36590998182732*x^13 + 18664867884348*
              x^14 - 5538763746576*x^15 - 3349681943580*x^16 + 
             377572057828*x^17 + 303704730840*x^18 + 2089773639*x^19 - 
             15103115202*x^20 - 2192465554*x^21 + 348743430*x^22 + 
             143855348*x^23 + 478338*x^24 - 3447078*x^25 - 124530*x^26 + 
             12475*x^27)*HPL[{0}, x])/(1360800*(-1 + x)^13*(1 + x)^11*
            (-9 + x^2)^6) + lm^2*(-(-1 + 6*x + 23*x^2 + 356*x^3 + 398*x^4 + 
               956*x^5 + 398*x^6 + 356*x^7 + 23*x^8 + 6*x^9 - x^10)/
             (240*(-1 + x)^10*(1 + x)^8) + (x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 
               12*x^4 + 3*x^5 + 2*x^6)*HPL[{0}, x])/(2*(-1 + x)^11*
              (1 + x)^9)) + (x*(26784626400 - 170660454228*x + 
             22931072966088*x^2 + 15945043536945*x^3 + 82825302376278*x^4 + 
             20448773578314*x^5 + 7938559171998*x^6 - 19190717670402*x^7 - 
             40133549561490*x^8 - 869188316886*x^9 + 8907586415910*x^10 + 
             3067531468587*x^11 + 1356306125244*x^12 - 811715479484*x^13 - 
             701210282388*x^14 + 77603957236*x^15 + 88091577084*x^16 + 
             961382592*x^17 - 2699426380*x^18 - 816897961*x^19 - 
             307758290*x^20 + 67738770*x^21 + 27222006*x^22 - 2218834*x^23 - 
             569226*x^24 + 14922*x^25 - 3234*x^26 + 429*x^27)*HPL[{0, 0}, x])/
           (37800*(-1 + x)^13*(1 + x)^11*(-9 + x^2)^6) + 
          lm*(-(-196 + 609*x + 2127*x^2 + 67404*x^3 + 61321*x^4 + 180630*
                x^5 + 61321*x^6 + 67404*x^7 + 2127*x^8 + 609*x^9 - 196*x^10 - 
               6*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 16*x^4 - 16*x^6 - 48*x^7 - 
                 3*x^8 - 6*x^9 + x^10))/(19440*(-1 + x)^10*(1 + x)^8) + 
            (x^2*(-2 + 2412*x + 3130*x^2 + 16758*x^3 + 11358*x^4 + 22158*
                x^5 + 6505*x^6 + 5562*x^7 + 214*x^8 + 54*x^9 - 9*x^10)*
              HPL[{0}, x])/(540*(-1 + x)^11*(1 + x)^9) + 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{-1, 0}, x])/(270*(-1 + x)^9*(1 + x)^7) + 
            (x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 13200*x^4 - 7055*x^5 - 
               9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 6*x^10 + x^11)*
              HPL[{0, 0}, x])/(135*(-1 + x)^12*(1 + x)^10) - 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{1, 0}, x])/(270*(-1 + x)^9*(1 + x)^7)) + 
          ((561 + 6027*x + 6750*x^2 + 28387*x^3 + 10357*x^4 + 29839*x^5 + 
             220*x^6 + 9591*x^7 - 657*x^8 + 1328*x^9 - 10*x^10 + 8*x^11 - 
             x^12)*HPL[{-1, 0, 0}, x])/(135*(-1 + x)^12*(1 + x)^8) + 
          (x^3*(-867831999300 - 638448236757*x - 3157253788878*x^2 - 
             832176116496*x^3 - 277665815322*x^4 + 829097131050*x^5 + 
             1916783213814*x^6 + 172454857920*x^7 - 295176047418*x^8 - 
             180985589163*x^9 - 133513748676*x^10 + 34850023624*x^11 + 
             44483948292*x^12 - 935467276*x^13 - 4389159852*x^14 - 
             484600760*x^15 + 5063184*x^16 + 69255485*x^17 + 28060242*x^18 - 
             4059928*x^19 - 1862826*x^20 + 116226*x^21 + 40950*x^22 - 
             1960*x^23 - 210*x^24 + 35*x^25)*HPL[{0, 0, 0}, x])/
           (4725*(-1 + x)^13*(1 + x)^11*(-9 + x^2)^6) - 
          ((381 + 7641*x + 11226*x^2 + 43865*x^3 + 32485*x^4 + 57545*x^5 + 
             24160*x^6 + 20745*x^7 + 4395*x^8 + 1660*x^9 + 14*x^10 + 4*x^11 - 
             x^12)*HPL[{1, 0, 0}, x])/(135*(-1 + x^2)^10) + 
          ((35187738687 - 3409851309102*x - 2289614951250*x^2 - 
             12551343804342*x^3 - 3201193243764*x^4 - 3618822460554*x^5 + 
             1866748472586*x^6 + 3595112653230*x^7 + 81885700683*x^8 - 
             661450533660*x^9 - 256118713668*x^10 - 25571691180*x^11 + 
             72060163104*x^12 + 29801473884*x^13 - 8702743100*x^14 - 
             5557322484*x^15 + 349712181*x^16 + 513303210*x^17 + 
             24773558*x^18 - 23212350*x^19 - 3145260*x^20 + 323022*x^21 + 
             109074*x^22 + 4326*x^23 - 831*x^24)*master3l8a[x])/
           (113400*(-1 + x)^13*(1 + x)^11*(-9 + x^2)^6) + 
          ((-3909748743 + 186020812278*x + 112089858777*x^2 + 
             713650782096*x^3 + 183214541061*x^4 + 419682401334*x^5 - 
             2815518825*x^6 + 73126241748*x^7 + 28912055148*x^8 + 
             16024964508*x^9 - 8548934390*x^10 - 25047871296*x^11 - 
             1212116694*x^12 + 3790950156*x^13 + 624410206*x^14 + 
             63328104*x^15 - 77167055*x^16 - 48872082*x^17 + 4063373*x^18 + 
             3384528*x^19 - 101247*x^20 - 73794*x^21 + 2459*x^22 + 420*x^23 - 
             70*x^24)*master3l9a[x])/(37800*(-1 + x)^13*(1 + x)^11*
            (-9 + x^2)^5) + (x^16*(31427468457173 - 7395694689600*Zeta[3]) + 
            x^20*(89645769594 - 20287834560*Zeta[3]) + 
            x^22*(8131736582 - 209664000*Zeta[3]) + 160*x^28*
             (-799 + 126*Zeta[3]) - 840*x^27*(-1855 + 144*Zeta[3]) + 
            42*x^25*(1306741 + 54720*Zeta[3]) - 3*x^26*(-8111431 + 
              403200*Zeta[3]) + 252*x^23*(-22625159 + 2940480*Zeta[3]) + 
            5*x^24*(-164879341 + 7640640*Zeta[3]) + 2480058*x*
             (1188166087 + 19414080*Zeta[3]) + 177147*(-227381303 + 
              62354880*Zeta[3]) - 168*x^21*(-892430297 + 215952480*Zeta[3]) - 
            918540*x^3*(-16298018147 + 329228064*Zeta[3]) - 
            653184*x^11*(-2465847488 + 879682925*Zeta[3]) + 
            19683*x^2*(93915887267 + 6383059200*Zeta[3]) - 
            204120*x^5*(-88204117829 + 6530650272*Zeta[3]) - 
            39366*x^4*(-141045318583 + 6768367200*Zeta[3]) + 
            84*x^19*(-23640974107 + 8390152800*Zeta[3]) - 
            567*x^10*(-846489483349 + 34079366400*Zeta[3]) + 
            672*x^13*(-140512977119 + 41770148400*Zeta[3]) - 
            126*x^17*(-116399370607 + 53165937600*Zeta[3]) - 
            7290*x^6*(-293560885831 + 68994938880*Zeta[3]) + 
            6804*x^7*(-140830579657 + 135498536640*Zeta[3]) + 
            168*x^15*(-296857672441 + 160371432000*Zeta[3]) + 
            84*x^14*(-1925198681443 + 562126118400*Zeta[3]) + 
            x^18*(-2990523728897 + 591327878400*Zeta[3]) + 
            243*x^8*(-13115632192829 + 3065320802880*Zeta[3]) + 
            378*x^9*(-13172226917561 + 3150735278400*Zeta[3]) - 
            28*x^12*(-11836691874121 + 4757528840400*Zeta[3]))/
           (8164800*(-1 + x)^13*(1 + x)^11*(-9 + x^2)^6)) + 
        NM*(((-47880 + 287280*x + 2339892*x^2 - 48039012*x^3 - 
             114690807*x^4 + 2288301750*x^5 + 4125733846*x^6 - 
             37885939602*x^7 - 76121183196*x^8 + 93818078970*x^9 + 
             619748750198*x^10 + 3735043460190*x^11 - 446080343251*x^12 - 
             36646840032852*x^13 - 23947565715348*x^14 + 56658458220924*
              x^15 + 107959083615352*x^16 + 518539707710388*x^17 + 
             102681631474704*x^18 - 1043595489588120*x^19 - 
             900844778821437*x^20 - 3354795372249090*x^21 - 
             777493194172578*x^22 - 1196783585624970*x^23 + 
             229749460520364*x^24 + 173451939151554*x^25 + 164705104901286*
              x^26 + 35044926646590*x^27 + 20570244390855*x^28 - 
             840*Pi^2*(1 - 9*x^2)^6*(-1 + x^2)^4*(1 - 6*x - 2*x^2 - 54*x^3 - 
               18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + x^8))*HPL[{0}, x])/
           (1360800*(-1 + x)^13*(1 + x)^11*(1 - 9*x^2)^6) + 
          lm^2*(-(-1 + 6*x + 23*x^2 + 356*x^3 + 398*x^4 + 956*x^5 + 398*x^6 + 
               356*x^7 + 23*x^8 + 6*x^9 - x^10)/(240*(-1 + x)^10*(1 + x)^8) + 
            (x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*x^5 + 2*x^6)*
              HPL[{0}, x])/(2*(-1 + x)^11*(1 + x)^9)) - 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{-2, 0}, x])/(135*(-1 + x)^9*(1 + x)^7) + 
          ((840 - 5040*x - 36856*x^2 + 1092336*x^3 + 2220125*x^4 - 
             44783634*x^5 - 75086814*x^6 + 373807238*x^7 + 1001744606*x^8 + 
             8365811062*x^9 + 207313406*x^10 - 172810817130*x^11 - 
             129292238241*x^12 + 856889383308*x^13 + 1085477324404*x^14 + 
             2666798430492*x^15 - 1362416357700*x^16 - 30116700228132*x^17 - 
             16761322434204*x^18 + 16475984895132*x^19 + 42845516091531*
              x^20 + 202848684308550*x^21 + 61118586897930*x^22 + 
             100150586849502*x^23 - 10168351607106*x^24 - 6918601666914*
              x^25 - 12157161030666*x^26 - 2797253284770*x^27 - 
             1582778625255*x^28)*HPL[{0, 0}, x])/(37800*(-1 + x)^13*
            (1 + x)^11*(1 - 9*x^2)^6) + 
          lm*(-(-196 + 609*x + 2127*x^2 + 67404*x^3 + 61321*x^4 + 180630*
                x^5 + 61321*x^6 + 67404*x^7 + 2127*x^8 + 609*x^9 - 196*x^10 - 
               6*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 16*x^4 - 16*x^6 - 48*x^7 - 
                 3*x^8 - 6*x^9 + x^10))/(19440*(-1 + x)^10*(1 + x)^8) + 
            (x^2*(-2 + 2412*x + 3130*x^2 + 16758*x^3 + 11358*x^4 + 22158*
                x^5 + 6505*x^6 + 5562*x^7 + 214*x^8 + 54*x^9 - 9*x^10)*
              HPL[{0}, x])/(540*(-1 + x)^11*(1 + x)^9) + 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{-1, 0}, x])/(270*(-1 + x)^9*(1 + x)^7) + 
            (x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 13200*x^4 - 7055*x^5 - 
               9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 6*x^10 + x^11)*
              HPL[{0, 0}, x])/(135*(-1 + x)^12*(1 + x)^10) - 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{1, 0}, x])/(270*(-1 + x)^9*(1 + x)^7)) + 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{2, 0}, x])/(135*(-1 + x)^9*(1 + x)^7) + 
          ((-3 + 24*x - 30*x^2 + 1424*x^3 - 811*x^4 + 9623*x^5 + 220*x^6 + 
             29807*x^7 + 10511*x^8 + 28291*x^9 + 6770*x^10 + 6011*x^11 + 
             563*x^12)*HPL[{-1, 0, 0}, x])/(135*(-1 + x)^12*(1 + x)^8) + 
          ((-35 + 210*x + 980*x^2 - 60270*x^3 - 104543*x^4 + 1247988*x^5 + 
             2950602*x^6 + 20801256*x^7 + 5059073*x^8 - 680091678*x^9 - 
             1137659238*x^10 + 668975454*x^11 + 14399514113*x^12 + 
             120887950848*x^13 - 30013517540*x^14 - 1300332630072*x^15 - 
             588303062241*x^16 + 4104391691358*x^17 + 4019345188416*x^18 + 
             5793750622422*x^19 - 5086246984893*x^20 - 35572598168436*x^21 - 
             13033331718822*x^22 - 25093047136752*x^23 + 575824989123*x^24 - 
             1062205932690*x^25 + 2115707837202*x^26 + 293032906362*x^27 + 
             299056435803*x^28)*HPL[{0, 0, 0}, x])/(4725*(-1 + x)^13*
            (1 + x)^11*(1 - 9*x^2)^6) - ((-3 + 12*x + 42*x^2 + 1780*x^3 + 
             4625*x^4 + 20905*x^5 + 24160*x^6 + 57385*x^7 + 32255*x^8 + 
             43745*x^9 + 11198*x^10 + 7633*x^11 + 383*x^12)*
            HPL[{1, 0, 0}, x])/(135*(-1 + x^2)^10) + 
          ((-140 + 840*x + 7009*x^2 - 159474*x^3 - 355830*x^4 + 7774326*x^5 + 
             13094452*x^6 - 135453318*x^7 - 252248382*x^8 + 493050474*x^9 + 
             2288115221*x^10 + 11999316924*x^11 - 4960873996*x^12 - 
             148134319284*x^13 - 67339931392*x^14 + 508483303524*x^15 + 
             467823642984*x^16 + 519253656012*x^17 - 607933730997*x^18 - 
             4072020202026*x^19 - 1449640051614*x^20 - 2508159199266*x^21 + 
             127511222220*x^22 + 77671351170*x^23 + 264177995778*x^24 + 
             61476688098*x^25 + 35187738687*x^26)*master3l8b[x])/
           (113400*(-1 + x)^13*x^2*(1 + x)^11*(1 - 9*x^2)^6) - 
          ((-70 + 420*x + 2459*x^2 - 73794*x^3 - 101247*x^4 + 3384528*x^5 + 
             4063373*x^6 - 48872082*x^7 - 77167055*x^8 + 63328104*x^9 + 
             624410206*x^10 + 3790950156*x^11 - 1212116694*x^12 - 
             25047871296*x^13 - 8548934390*x^14 + 16024964508*x^15 + 
             28912055148*x^16 + 73126241748*x^17 - 2815518825*x^18 + 
             419682401334*x^19 + 183214541061*x^20 + 713650782096*x^21 + 
             112089858777*x^22 + 186020812278*x^23 - 3909748743*x^24)*
            master3l9b[x])/(113400*(-1 + x)^13*x^2*(1 + x)^11*
            (-1 + 9*x^2)^5) + (-9450 + 56700*x + 
            x^2*(696055 - 20160*Zeta[3]) + 210*x^3*(-61609 + 576*Zeta[3]) - 
            336*x^5*(-1959853 + 6840*Zeta[3]) + 3*x^4*(-15846571 + 
              403200*Zeta[3]) - 50*x^6*(-35140849 + 764064*Zeta[3]) - 
            504*x^7*(27018623 + 1470240*Zeta[3]) - 4251528*x^30*
             (5051023 + 2598120*Zeta[3]) - 14880348*x^29*
             (572707 + 3235680*Zeta[3]) + 4*x^8*(-8503721543 + 
              52416000*Zeta[3]) + 168*x^9*(489607633 + 215952480*Zeta[3]) + 
            1377810*x^27*(-296477323 + 219485376*Zeta[3]) + 
            3674160*x^25*(168134441 + 362813904*Zeta[3]) + 
            1049760*x^24*(644707449 + 479131520*Zeta[3]) - 
            177147*x^28*(831123283 + 709228800*Zeta[3]) - 
            714*x^11*(-2063086267 + 987076800*Zeta[3]) + 
            9*x^10*(36149997109 + 2254203840*Zeta[3]) + 45927*x^26*
             (-14436209219 + 5801457600*Zeta[3]) + 252*x^13*(-121008798071 + 
              26582968800*Zeta[3]) - 672*x^15*(-304486972789 + 
              40092858000*Zeta[3]) + 10206*x^19*(-187441279357 + 
              56299707200*Zeta[3]) - 13608*x^23*(-525563267201 + 
              67749268320*Zeta[3]) + 81*x^20*(-857332362703 + 
              238555564800*Zeta[3]) - 84*x^17*(3962869501313 + 
              334161187200*Zeta[3]) - x^12*(581014861183 + 591327878400*Zeta[
                3]) - 1512*x^21*(-3442703985209 + 787683819600*Zeta[3]) - 
            486*x^22*(-6153817157107 + 1532660401440*Zeta[3]) + 
            4*x^14*(-4666709974547 + 1848923672400*Zeta[3]) - 
            6*x^16*(-30483124287137 + 7869765657600*Zeta[3]) + 
            7*x^18*(-85674134501449 + 19030115361600*Zeta[3]))/
           (8164800*(-1 + x)^13*x^2*(1 + x)^11*(1 - 9*x^2)^6))) + 
      CA*CF*((Pi^2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 
           1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{-2}, x])/
         (540*(-1 + x)^10*(1 + x)^8) + 
        lm^2*((-11*(1 - 6*x - 23*x^2 - 356*x^3 - 398*x^4 - 956*x^5 - 
             398*x^6 - 356*x^7 - 23*x^8 - 6*x^9 + x^10))/(480*(-1 + x)^10*
            (1 + x)^8) - (11*x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*x^5 + 
             2*x^6)*HPL[{0}, x])/(4*(-1 + x)^11*(1 + x)^9)) + 
        (Pi^2*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 
           1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{2}, x])/
         (540*(-1 + x)^10*(1 + x)^8) + (x*(29 + 1227*x + 4734*x^2 + 
           15486*x^3 + 114753*x^4 + 97607*x^5 + 229200*x^6 + 140617*x^7 + 
           176793*x^8 - 93480*x^9 - 87858*x^10 + 205013*x^11 + 75517*x^12 - 
           255366*x^13 - 23760*x^14 + 218790*x^15 - 19800*x^16 - 
           127490*x^17 + 28160*x^18 + 48510*x^19 - 15444*x^20 - 10902*x^21 + 
           4296*x^22 + 1100*x^23 - 500*x^24)*HPL[{-2, 0}, x])/
         (1080*(-1 + x)^12*(1 + x)^10) + 
        ((210000 - 462000*x - 1489320*x^2 + 3885840*x^3 + 4165000*x^4 - 
           14352940*x^5 - 4967900*x^6 + 30416540*x^7 - 812420*x^8 + 
           (-40351757 + 1680*Pi^2)*x^9 - 14*(-689677 + 720*Pi^2)*x^10 + 
           (32926448 - 174720*Pi^2)*x^11 - 14*(2376641 + 83280*Pi^2)*x^12 - 
           3*(13847733 + 590800*Pi^2)*x^13 - 56*(1349519 + 37440*Pi^2)*x^14 - 
           42304904*x^15 + 56*(-1349519 + 37440*Pi^2)*x^16 + 
           3*(-13847733 + 590800*Pi^2)*x^17 + 14*(-2376641 + 83280*Pi^2)*
            x^18 + 16*(2057903 + 10920*Pi^2)*x^19 + 14*(689677 + 720*Pi^2)*
            x^20 - (40351757 + 1680*Pi^2)*x^21 - 812420*x^22 + 
           30416540*x^23 - 4967900*x^24 - 14352940*x^25 + 4165000*x^26 + 
           3885840*x^27 - 1489320*x^28 - 462000*x^29 + 210000*x^30)*
          HPL[{-1, 0}, x])/(907200*(-1 + x)^11*x^9*(1 + x)^9) + 
        (x*(38837708280 + 2284087674708*x + 22995042112476*x^2 - 
           57991406106951*x^3 - 967670437408542*x^4 - 197065243403307*x^5 + 
           12257742375553248*x^6 + 21080359707338628*x^7 + 
           8497494629846712*x^8 - 261959354008296228*x^9 - 
           1493676232917171408*x^10 + 1129459021235738064*x^11 + 
           12376909031034473352*x^12 + 640217370687886848*x^13 - 
           27073695318424678896*x^14 - 12557180532030800316*x^15 - 
           78594043247676304320*x^16 - 20693805227905902244*x^17 + 
           234728663965565217224*x^18 + 143409535463545355274*x^19 + 
           448864882775746425324*x^20 + 114924912174267800434*x^21 - 
           148595730066986462064*x^22 - 182676550195879922756*x^23 - 
           33549156789665782496*x^24 + 137725146622439668124*x^25 + 
           15853827165424906896*x^26 - 88560059469416773032*x^27 + 
           7462965888643214712*x^28 + 46554978037072633832*x^29 - 
           9616389697344860528*x^30 - 18389402616248191572*x^31 + 
           5149028205191257800*x^32 + 5265421143815099040*x^33 - 
           1744479184787090052*x^34 - 1070310716887260267*x^35 + 
           394989492472222914*x^36 + 151305200386183665*x^37 - 
           60056561917522800*x^38 - 14451569132479920*x^39 + 
           6035474991326760*x^40 + 886409847401400*x^41 - 
           384018595803360*x^42 - 31465388666880*x^43 + 14008062000240*x^44 + 
           491051484000*x^45 - 223205220000*x^46)*HPL[{0, 0}, x])/
         (907200*(-1 + x)^12*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        ((-210000 + 462000*x + 1489320*x^2 - 3885840*x^3 - 4165000*x^4 + 
           14352940*x^5 + 4967900*x^6 - 30416540*x^7 + 812420*x^8 + 
           (40351757 - 1680*Pi^2)*x^9 + 14*(-689677 + 720*Pi^2)*x^10 + 
           16*(-2057903 + 10920*Pi^2)*x^11 + 14*(2376641 + 83280*Pi^2)*x^12 + 
           3*(13847733 + 590800*Pi^2)*x^13 + 56*(1349519 + 37440*Pi^2)*x^14 + 
           42304904*x^15 - 56*(-1349519 + 37440*Pi^2)*x^16 + 
           (41543199 - 1772400*Pi^2)*x^17 - 14*(-2376641 + 83280*Pi^2)*x^18 - 
           16*(2057903 + 10920*Pi^2)*x^19 - 14*(689677 + 720*Pi^2)*x^20 + 
           (40351757 + 1680*Pi^2)*x^21 + 812420*x^22 - 30416540*x^23 + 
           4967900*x^24 + 14352940*x^25 - 4165000*x^26 - 3885840*x^27 + 
           1489320*x^28 + 462000*x^29 - 210000*x^30)*HPL[{1, 0}, x])/
         (907200*(-1 + x)^11*x^9*(1 + x)^9) + 
        lm*((-3290 + 13503*x + 49479*x^2 + 1145148*x^3 + 1125863*x^4 + 
            3071034*x^5 + 1125863*x^6 + 1145148*x^7 + 49479*x^8 + 13503*x^9 - 
            3290*x^10 - 66*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 16*x^4 - 
              16*x^6 - 48*x^7 - 3*x^8 - 6*x^9 + x^10))/(38880*(-1 + x)^10*
            (1 + x)^8) + (x^2*(22 - 34092*x - 45770*x^2 - 229698*x^3 - 
             155178*x^4 - 289098*x^5 - 82895*x^6 - 68742*x^7 - 2354*x^8 - 
             594*x^9 + 99*x^10)*HPL[{0}, x])/(1080*(-1 + x)^11*(1 + x)^9) + 
          (11*(1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + 
             x^8)*HPL[{-1, 0}, x])/(540*(-1 + x)^9*(1 + x)^7) - 
          (11*x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 13200*x^4 - 
             7055*x^5 - 9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 6*x^10 + 
             x^11)*HPL[{0, 0}, x])/(270*(-1 + x)^12*(1 + x)^10) - 
          (11*(1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + 
             x^8)*HPL[{1, 0}, x])/(540*(-1 + x)^9*(1 + x)^7)) + 
        (x*(-29 - 1227*x - 4734*x^2 - 15486*x^3 - 114753*x^4 - 97607*x^5 - 
           229200*x^6 - 140617*x^7 - 176793*x^8 + 93480*x^9 + 87858*x^10 - 
           205013*x^11 - 75517*x^12 + 255366*x^13 + 23760*x^14 - 
           218790*x^15 + 19800*x^16 + 127490*x^17 - 28160*x^18 - 48510*x^19 + 
           15444*x^20 + 10902*x^21 - 4296*x^22 - 1100*x^23 + 500*x^24)*
          HPL[{2, 0}, x])/(1080*(-1 + x)^12*(1 + x)^10) + 
        ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (4*x^2*(-50 - 326*x - 571*x^2 - 
           974*x^3 - 587*x^4 - 374*x^5 - 53*x^6 - 6*x^7 + x^8)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) - 
        ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-2, 1, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) - ((-1 + 6*x + 103*x^2 + 700*x^3 + 
           1158*x^4 + 1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{-1, -2, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) + 
        ((250 - 550*x - 1398*x^2 + 3801*x^3 + 2778*x^4 - 11202*x^5 - 
           1302*x^6 + 18186*x^7 - 3738*x^8 - 17430*x^9 + 7350*x^10 + 
           9611*x^11 - 5650*x^12 - 2474*x^13 + 4350*x^14 + 996*x^15 + 
           4350*x^16 - 2474*x^17 - 5650*x^18 + 9611*x^19 + 7350*x^20 - 
           17430*x^21 - 3738*x^22 + 18186*x^23 - 1302*x^24 - 11202*x^25 + 
           2778*x^26 + 3801*x^27 - 1398*x^28 - 550*x^29 + 250*x^30)*
          HPL[{-1, -1, 0}, x])/(1080*(-1 + x)^9*x^11*(1 + x)^7) + 
        ((5731 - 22438*x - 21720*x^2 - 669318*x^3 + 298267*x^4 - 
           1148254*x^5 + 1486814*x^6 - 1230714*x^7 + 1181212*x^8 - 
           1336348*x^9 - 1470580*x^10 + 1949672*x^11 + 1080476*x^12 - 
           2795940*x^13 + 47460*x^14 + 2285220*x^15 - 789075*x^16 - 
           1053570*x^17 + 665140*x^18 + 216090*x^19 - 248395*x^20 + 
           10430*x^21 + 36750*x^22 - 8750*x^23)*HPL[{-1, 0, 0}, x])/
         (18900*(-1 + x)^12*(1 + x)^8) + 
        ((-250 + 550*x + 1398*x^2 - 3801*x^3 - 2778*x^4 + 11202*x^5 + 
           1302*x^6 - 18186*x^7 + 3738*x^8 + 17430*x^9 - 7350*x^10 - 
           9611*x^11 + 5650*x^12 + 2474*x^13 - 4350*x^14 - 996*x^15 - 
           4350*x^16 + 2474*x^17 + 5650*x^18 - 9611*x^19 - 7350*x^20 + 
           17430*x^21 + 3738*x^22 - 18186*x^23 + 1302*x^24 + 11202*x^25 - 
           2778*x^26 - 3801*x^27 + 1398*x^28 + 550*x^29 - 250*x^30)*
          HPL[{-1, 1, 0}, x])/(1080*(-1 + x)^9*x^11*(1 + x)^7) + 
        ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (x*(-539412615 - 22376323305*x - 
           744174011070*x^2 - 812145134178*x^3 + 27085708472382*x^4 + 
           74286875645712*x^5 - 214270183141812*x^6 - 1793620625287590*x^7 - 
           3730578902246322*x^8 + 21560753147307336*x^9 + 83496870266489736*
            x^10 - 148179865580754306*x^11 - 597325957982667298*x^12 + 
           639990712284597904*x^13 + 1453720495375196804*x^14 - 
           2139925984722381066*x^15 + 1401034991670733048*x^16 + 
           6648485057937832258*x^17 - 2615792915889228124*x^18 - 
           13233994609820065458*x^19 - 30775793310362726878*x^20 + 
           7216427388312290468*x^21 + 14454125154855576484*x^22 - 
           10247260919733392878*x^23 - 3435072871872619558*x^24 + 
           14443297249962006252*x^25 + 1047045267963666552*x^26 - 
           13488255641023872354*x^27 + 504464298748656498*x^28 + 
           9147599962136546156*x^29 - 1264409268452469524*x^30 - 
           4641244545672532566*x^31 + 1026924191693311527*x^32 + 
           1750815948233734095*x^33 - 499928047783646790*x^34 - 
           482897055109762580*x^35 + 161428336388367272*x^36 + 
           95422126022504748*x^37 - 35376900229414800*x^38 - 
           13205266031708100*x^39 + 5253572970220680*x^40 + 
           1241014366744740*x^41 - 518860520912160*x^42 - 
           75175135064820*x^43 + 32583668864040*x^44 + 2642576200740*x^45 - 
           1176638717520*x^46 - 40920957000*x^47 + 18600435000*x^48)*
          HPL[{0, 0, 0}, x])/(37800*(-1 + x)^12*(1 + x)^10*
          (9 - 82*x^2 + 9*x^4)^6) + ((-1 + 6*x + 103*x^2 + 700*x^3 + 
           1158*x^4 + 1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{1, -2, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) + 
        ((-250 + 550*x + 1398*x^2 - 3801*x^3 - 2778*x^4 + 11202*x^5 + 
           1302*x^6 - 18186*x^7 + 3738*x^8 + 17430*x^9 - 7350*x^10 - 
           9611*x^11 + 5650*x^12 + 2474*x^13 - 4350*x^14 - 996*x^15 - 
           4350*x^16 + 2474*x^17 + 5650*x^18 - 9611*x^19 - 7350*x^20 + 
           17430*x^21 + 3738*x^22 - 18186*x^23 + 1302*x^24 + 11202*x^25 - 
           2778*x^26 - 3801*x^27 + 1398*x^28 + 550*x^29 - 250*x^30)*
          HPL[{1, -1, 0}, x])/(1080*(-1 + x)^9*x^11*(1 + x)^7) + 
        ((-5731 - 2166*x + 72344*x^2 + 789090*x^3 + 1576725*x^4 + 
           3664582*x^5 + 3567802*x^6 + 4134282*x^7 + 1798100*x^8 - 
           254260*x^9 - 335756*x^10 + 1817624*x^11 + 471844*x^12 - 
           2190300*x^13 - 388500*x^14 + 1829100*x^15 + 217875*x^16 - 
           1046850*x^17 - 80500*x^18 + 393050*x^19 + 17675*x^20 - 
           87430*x^21 - 1750*x^22 + 8750*x^23)*HPL[{1, 0, 0}, x])/
         (18900*(-1 + x^2)^10) + ((250 - 550*x - 1398*x^2 + 3801*x^3 + 
           2778*x^4 - 11202*x^5 - 1302*x^6 + 18186*x^7 - 3738*x^8 - 
           17430*x^9 + 7350*x^10 + 9611*x^11 - 5650*x^12 - 2474*x^13 + 
           4350*x^14 + 996*x^15 + 4350*x^16 - 2474*x^17 - 5650*x^18 + 
           9611*x^19 + 7350*x^20 - 17430*x^21 - 3738*x^22 + 18186*x^23 - 
           1302*x^24 - 11202*x^25 + 2778*x^26 + 3801*x^27 - 1398*x^28 - 
           550*x^29 + 250*x^30)*HPL[{1, 1, 0}, x])/(1080*(-1 + x)^9*x^11*
          (1 + x)^7) - ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 
           1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) - ((-1 + 6*x + 103*x^2 + 700*x^3 + 
           1158*x^4 + 1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{2, -1, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) - 
        (4*x^2*(-50 - 326*x - 571*x^2 - 974*x^3 - 587*x^4 - 374*x^5 - 
           53*x^6 - 6*x^7 + x^8)*HPL[{2, 0, 0}, x])/(45*(-1 + x)^10*
          (1 + x)^8) + ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 
           1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{2, 1, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (2*(-1 + 6*x + 2*x^2 + 54*x^3 + 
           18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^8)*HPL[{-1, 0, 0, 0}, x])/
         (45*(-1 + x)^9*(1 + x)^7) + (2*(1 - 6*x - 103*x^2 - 700*x^3 - 
           1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*
          HPL[{-1, 1, 0, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) + 
        (2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{1, -1, 0, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (2*(1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 
           54*x^5 - 2*x^6 - 6*x^7 + x^8)*HPL[{1, 0, 0, 0}, x])/
         (45*(-1 + x)^9*(1 + x)^7) + ((-1 + 11*x + 79*x^2 + 983*x^3 + 
           1519*x^4 + 4040*x^5 + 2444*x^6 + 2792*x^7 + 464*x^8 + 289*x^9 - 
           25*x^10 + 5*x^11)*master3l10a[x])/(360*(-1 + x)^11*(1 + x)^9) + 
        (x*(-5 + 25*x - 289*x^2 - 464*x^3 - 2792*x^4 - 2444*x^5 - 4040*x^6 - 
           1519*x^7 - 983*x^8 - 79*x^9 - 11*x^10 + x^11)*master3l10b[x])/
         (360*(-1 + x)^11*(1 + x)^9) - ((36780231168 + 219984864687*x + 
           1577323152297*x^2 + 5156784534762*x^3 + 6203142941544*x^4 + 
           5606272174671*x^5 + 240649731351*x^6 - 1706932920168*x^7 - 
           973764252864*x^8 - 540328340034*x^9 + 98219048346*x^10 + 
           273934359132*x^11 + 45280970640*x^12 - 41091162378*x^13 - 
           13008879026*x^14 + 2236800216*x^15 + 1442524416*x^16 + 
           48383027*x^17 - 77601939*x^18 - 9956534*x^19 + 1794248*x^20 + 
           292635*x^21 - 6677*x^22)*master3l8a[x])/(907200*(-1 + x)^12*
          (1 + x)^10*(-9 + x^2)^6) - ((4060 + 176777*x + 150325*x^2 - 
           10004580*x^3 - 12840366*x^4 + 259152035*x^5 + 274778189*x^6 - 
           3964932000*x^7 - 2672435808*x^8 + 38371794922*x^9 + 
           12743040170*x^10 - 231109171192*x^11 - 40785838212*x^12 + 
           781009535382*x^13 + 292551429954*x^14 - 1040815666800*x^15 - 
           1816581627756*x^16 - 577131299235*x^17 + 3655791054657*x^18 + 
           717237731772*x^19 + 1711026799650*x^20 + 40656095991*x^21 + 
           48140635473*x^22 - 34101768528*x^23)*master3l8b[x])/
         (907200*(-1 + x)^12*x*(1 + x)^10*(1 - 9*x^2)^6) + 
        ((3937888872 + 9546901623*x + 85807935225*x^2 + 192491752131*x^3 + 
           314306726679*x^4 + 129748034682*x^5 + 80355249108*x^6 + 
           20508043164*x^7 + 12653439564*x^8 - 43992426870*x^9 - 
           36526867106*x^10 + 12596407978*x^11 + 11296467090*x^12 - 
           1591188144*x^13 - 1599318876*x^14 + 95936652*x^15 + 
           122712148*x^16 - 1917881*x^17 - 5073871*x^18 - 52885*x^19 + 
           91727*x^20 + 2030*x^21)*master3l9a[x])/(302400*(-1 + x)^12*
          (1 + x)^10*(-9 + x^2)^5) + ((2030 + 91727*x - 52885*x^2 - 
           5073871*x^3 - 1917881*x^4 + 122712148*x^5 + 95936652*x^6 - 
           1599318876*x^7 - 1591188144*x^8 + 11296467090*x^9 + 
           12596407978*x^10 - 36526867106*x^11 - 43992426870*x^12 + 
           12653439564*x^13 + 20508043164*x^14 + 80355249108*x^15 + 
           129748034682*x^16 + 314306726679*x^17 + 192491752131*x^18 + 
           85807935225*x^19 + 9546901623*x^20 + 3937888872*x^21)*
          master3l9b[x])/(907200*(-1 + x)^12*x*(1 + x)^10*(-1 + 9*x^2)^5) + 
        (HPL[{1}, x]*(Pi^2*(-250 + 550*x + 1648*x^2 - 4351*x^3 - 4176*x^4 + 
             15003*x^5 + 4080*x^6 - 29388*x^7 + 2436*x^8 + 35616*x^9 - 
             11088*x^10 - 27041*x^11 + 13000*x^12 + 12085*x^13 - 10000*x^14 - 
             3470*x^15 + 3470*x^17 + 10000*x^18 - 12085*x^19 - 13000*x^20 + 
             27041*x^21 + 11088*x^22 - 35616*x^23 - 2436*x^24 + 29388*x^25 - 
             4080*x^26 - 15003*x^27 + 4176*x^28 + 4351*x^29 - 1648*x^30 - 
             550*x^31 + 250*x^32) - 288*x^11*(1 - 6*x - 103*x^2 - 700*x^3 - 
             1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + 
             x^10)*Zeta[3]))/(12960*(-1 + x)^10*x^11*(1 + x)^8) + 
        (HPL[{-1}, x]*(Pi^2*(250 - 550*x - 1648*x^2 + 4351*x^3 + 4176*x^4 - 
             15003*x^5 - 4080*x^6 + 29388*x^7 - 2436*x^8 - 35616*x^9 + 
             11088*x^10 + 27041*x^11 - 13000*x^12 - 12085*x^13 + 10000*x^14 + 
             3470*x^15 - 3470*x^17 - 10000*x^18 + 12085*x^19 + 13000*x^20 - 
             27041*x^21 - 11088*x^22 + 35616*x^23 + 2436*x^24 - 29388*x^25 + 
             4080*x^26 + 15003*x^27 - 4176*x^28 - 4351*x^29 + 1648*x^30 + 
             550*x^31 - 250*x^32) + 288*x^11*(1 - 6*x - 103*x^2 - 700*x^3 - 
             1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + 
             x^10)*Zeta[3]))/(12960*(-1 + x)^10*x^11*(1 + x)^8) + 
        (HPL[{0}, x]*(-669615660000 + 1473154452000*x + 41689378170720*x^2 - 
           93659588774640*x^3 - 1131266899629720*x^4 + 2612522510687880*x^5 + 
           17544237738360480*x^6 - 42056189726391540*x^7 - 
           612360*(280049084941 + 21141*Pi^2)*x^8 - 
           17496*(-24752600277626 + 31306905*Pi^2)*x^9 - 
           1680*(620379792518444825 + 12434167663613526*Pi^2)*x^26 - 
           3*(144744418081838907 + 1931522995525397960*Pi^2)*x^43 + 
           210*(816499516011615 + 9224500983427964*Pi^2)*x^44 + 
           405*(103893725206071 + 2827313422686368*Pi^2)*x^45 - 
           90720*(193388863959 + 4679484157330*Pi^2)*x^46 - 
           204120*(12798954099 + 776323693810*Pi^2)*x^47 + 
           204120*(5542165881 + 308852026468*Pi^2)*x^48 + 
           1224720*(76474287 + 12159654779*Pi^2)*x^49 - 
           2449440*(17019963 + 2541938668*Pi^2)*x^50 - 
           33067440*(44550 + 27280661*Pi^2)*x^51 + 66134880*
            (10125 + 5912221*Pi^2)*x^52 + 31710914408880*Pi^2*x^53 - 
           14119664610240*Pi^2*x^54 - 491051484000*Pi^2*x^55 + 
           223205220000*Pi^2*x^56 + 144*x^41*(145871095024886455*Pi^2 + 
             27*(777351155693173 - 8928208800*Zeta[3])) - 
           8*x^31*(-2134408344070302028 + 19425358561203709905*Pi^2 - 
             944274647073643200*Zeta[3]) - 168*x^24*(-5556647351870891849 + 
             31797301627372560*Pi^2 - 410807471955062400*Zeta[3]) + 
           8*x^33*(14611941684268865474 + 22691597012462908845*Pi^2 - 
             350010488321726400*Zeta[3]) + 24*x^23*(775357814610594553 + 
             235241647549475595*Pi^2 - 120530949548385600*Zeta[3]) + 
           504*x^22*(-196018615306448773 + 20185226352660540*Pi^2 - 
             57449513274796800*Zeta[3]) - 12*x^35*(8997085371295203163 + 
             13507180784798466150*Pi^2 - 38255347012579200*Zeta[3]) - 
           560*x^20*(116012790364159348 + 5702282920638507*Pi^2 - 
             4668414937272000*Zeta[3]) + 168*x^34*(-556919285760906203 + 
             135245303216964000*Pi^2 - 4357523820844800*Zeta[3]) + 
           12*x^37*(4080714715632289503 + 9127746123675213230*Pi^2 - 
             3350971039651200*Zeta[3]) - 36*x^39*(405032337331745009 + 
             1545737785293561090*Pi^2 - 51105067171200*Zeta[3]) + 
           126*x^12*(-37365166658167723 + 381768187500*Pi^2 - 
             9122078476800*Zeta[3]) - 6804*x^10*(-161792844953239 + 
             206584020*Pi^2 - 3401222400*Zeta[3]) - 
           252*x^42*(4368478491287073 + 23806361535983740*Pi^2 + 
             91833004800*Zeta[3]) + 243*x^11*(-12330374870254243 + 
             94774957200*Pi^2 + 142851340800*Zeta[3]) + 
           504*x^40*(9418794272891332 + 24441469934316975*Pi^2 + 
             2280519619200*Zeta[3]) + 504*x^14*(26741428762555979 + 
             502613982900*Pi^2 + 44899536902400*Zeta[3]) - 
           1680*x^16*(15923706918476849 + 16332032158083*Pi^2 + 
             126028422417600*Zeta[3]) - 168*x^38*(86324604711803817 + 
             89422592862300700*Pi^2 + 134698610707200*Zeta[3]) - 
           9*x^13*(-1588477073587759091 + 38998575864360*Pi^2 + 
             204420268684800*Zeta[3]) + 840*x^36*(45062123919731773 + 
             5007784841903574*Pi^2 + 252056844835200*Zeta[3]) + 
           72*x^15*(-662400224900929763 + 29234999458035*Pi^2 + 
             558495173275200*Zeta[3]) + 168*x^18*(263411923845474083 + 
             2629180702116720*Pi^2 + 4357523820844800*Zeta[3]) - 
           280*x^32*(-146819638906071461 + 190876667784415410*Pi^2 + 
             9336829874544000*Zeta[3]) - 24*x^17*(-4613264696301836264 + 
             164029897104885*Pi^2 + 19127673506289600*Zeta[3]) + 
           504*x^30*(1895648439501076253 + 137177145409717620*Pi^2 + 
             57449513274796800*Zeta[3]) + 12*x^19*(-13869051427606184731 + 
             6040957751273970*Pi^2 + 233340325547817600*Zeta[3]) + 
           6*x^29*(31208915380324645703 + 17889133048558671900*Pi^2 + 
             482123798193542400*Zeta[3]) - 84*x^28*(28356611282019229033 + 
             532261198377337560*Pi^2 + 821614943910124800*Zeta[3]) - 
           42*x^27*(28084438840721332099 + 1455150096058891340*Pi^2 + 
             1226387823950534400*Zeta[3]) - 4*x^21*(-28013769960182051219 + 
             301627635852516750*Pi^2 + 1888549294147286400*Zeta[3]) + 
           8*x^25*(46393824342611695256 + 151528677277569585*Pi^2 + 
             6438536075740305600*Zeta[3])))/(10886400*(-1 + x)^12*x^7*
          (1 + x)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        (4032*Pi^4*x^9*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^6*
           (-3 + 18*x - 491*x^2 - 3116*x^3 - 5662*x^4 - 9740*x^5 - 5918*x^6 - 
            3884*x^7 - 539*x^8 - 78*x^9 + 13*x^10) - 
          12*Pi^2*(9 - 82*x^2 + 9*x^4)^6*(-210000 + 462000*x + 1699320*x^2 - 
            4347840*x^3 - 5654320*x^4 + 18238780*x^5 + 9132900*x^6 - 
            44769480*x^7 - 4155480*x^8 + 70768297*x^9 - 10467898*x^10 - 
            73278205*x^11 + 42928452*x^12 + 74469647*x^13 + 42300090*x^14 + 
            761705*x^15 - 761705*x^17 - 42300090*x^18 - 74469647*x^19 - 
            42928452*x^20 + 73278205*x^21 + 10467898*x^22 - 70768297*x^23 + 
            4155480*x^24 + 44769480*x^25 - 9132900*x^26 - 18238780*x^27 + 
            5654320*x^28 + 4347840*x^29 - 1699320*x^30 - 462000*x^31 + 
            210000*x^32) + x^2*(2008846980000 - 4419463356000*x - 
            125737750172160*x^2 + 282451920775920*x^3 + 3435238971187380*
             x^4 - 7930674687918780*x^5 - 53748777383971740*x^6 + 
            x^33*(945508478323245855324 - 6430224102065715457728*Zeta[3]) + 
            x^26*(9158322674740257027128 - 6374993760933864756480*Zeta[3]) + 
            x^25*(6121511437130707020858 - 3052437854539743854784*Zeta[3]) + 
            x^27*(588910402336373971398 - 767213266512819248064*Zeta[3]) - 
            1141592918719680*x^53*Zeta[3] + 508307925968640*x^54*Zeta[3] + 
            17677853424000*x^55*Zeta[3] - 8035387920000*x^56*Zeta[3] - 
            595213920*x^52*(-3375 + 23648884*Zeta[3]) + 595213920*x^51*
             (-7425 + 54561322*Zeta[3]) + 91854*x^8*(5790498413329 + 
              385588512*Zeta[3]) + 352719360*x^50*(-356481 + 635484667*Zeta[
                3]) - 19683*x^7*(-6544360713613 + 1125855936*Zeta[3]) - 
            20412*x^10*(170099421452689 + 8892656928*Zeta[3]) - 
            11022480*x^49*(-25625079 + 48638619116*Zeta[3]) + 
            6561*x^9*(-204425763126989 + 198781807104*Zeta[3]) - 
            918540*x^48*(-3739890447 + 2470816211744*Zeta[3]) + 
            918540*x^47*(-8634000357 + 6210589550480*Zeta[3]) - 
            91008*x^15*(-1518635200415149 + 29810088351801*Zeta[3]) - 
            729*x^11*(-12833715948327709 + 44141781829824*Zeta[3]) + 
            204120*x^46*(-263318078097 + 74871746517280*Zeta[3]) - 
            378*x^12*(-39574502567230789 + 129194849407392*Zeta[3]) + 
            504*x^14*(-74048142702213103 + 2963602945899072*Zeta[3]) - 
            4788*x^16*(1478384459284177 + 4062168209810880*Zeta[3]) + 
            27*x^13*(-1633692548611227629 + 15449478924817152*Zeta[3]) - 
            729*x^45*(-176545152041841 + 56546297881859392*Zeta[3]) + 
            36*x^17*(-8331399419965729145 + 61800107526684576*Zeta[3]) + 
            2268*x^42*(-1526560652678481 + 95225434838334688*Zeta[3]) + 
            1008*x^18*(478356098063734115 + 125261983902574368*Zeta[3]) - 
            378*x^44*(-1406253412585557 + 184489938427527904*Zeta[3]) - 
            1008*x^34*(-24281882968484975 + 672361240961639232*Zeta[3]) - 
            252*x^36*(-212536498654759337 + 681988067593434720*Zeta[3]) - 
            2688*x^30*(494554197459835673 + 949856378263085466*Zeta[3]) + 
            5364*x^35*(-82742258112201475 + 1088113865288701104*Zeta[3]) - 
            378*x^40*(-39545514246054979 + 1173325363979696352*Zeta[3]) - 
            224*x^20*(6517058009304522311 + 1493749405548144432*Zeta[3]) + 
            252*x^38*(-161756199531789641 + 2152224702772880064*Zeta[3]) - 
            168*x^22*(2495633779842948353 + 2300031895315971456*Zeta[3]) + 
            27*x^43*(-49571695025751177 + 7726137993118293632*Zeta[3]) + 
            12*x^19*(59717073839774160947 + 8459641989969073056*Zeta[3]) - 
            81*x^41*(-115849827471058011 + 9336123891753956416*Zeta[3]) + 
            112*x^32*(640959997941431003 + 13292115119962406136*Zeta[3]) - 
            36*x^21*(62016115395424092997 + 21777495451895480288*Zeta[3]) + 
            84*x^24*(56030174884897219993 + 46266535762544542176*Zeta[3]) - 
            72*x^37*(-2258323049256598561 + 54801418984787561304*Zeta[3]) - 
            18*x^29*(15556276426650829065 + 63044034625963431776*Zeta[3]) + 
            84*x^28*(2314706467099847863 + 63770130755027885376*Zeta[3]) + 
            27*x^39*(-1698587586369673859 + 74209842097124666112*Zeta[3]) + 
            36*x^31*(-33040399838966576767 + 132517662643664405872*Zeta[3]) + 
            18*x^23*(127452848049239642025 + 141468569787246819424*Zeta[3])))/
         (130636800*(-1 + x)^12*x^9*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^6)) + 
      CF^2*((Pi^2*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 
           1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-2}, x])/
         (270*(-1 + x)^10*(1 + x)^8) + 
        lm^2*((9*(1 - 6*x - 23*x^2 - 356*x^3 - 398*x^4 - 956*x^5 - 398*x^6 - 
             356*x^7 - 23*x^8 - 6*x^9 + x^10))/(80*(-1 + x)^10*(1 + x)^8) + 
          (27*x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*x^5 + 2*x^6)*
            HPL[{0}, x])/(2*(-1 + x)^11*(1 + x)^9)) + 
        (Pi^2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{2}, x])/
         (270*(-1 + x)^10*(1 + x)^8) - (x*(1015 + 42945*x + 407610*x^2 + 
           819210*x^3 + 6097875*x^4 + 4870285*x^5 + 8353800*x^6 + 
           7674555*x^7 + 15461075*x^8 - 12868912*x^9 - 20129130*x^10 + 
           37002133*x^11 + 26571699*x^12 - 64173336*x^13 - 19815616*x^14 + 
           76271400*x^15 + 4336204*x^16 - 62992620*x^17 + 7167284*x^18 + 
           35714786*x^19 - 8463716*x^20 - 13303386*x^21 + 4391560*x^22 + 
           2939400*x^23 - 1184500*x^24 - 292500*x^25 + 135000*x^26)*
          HPL[{-2, 0}, x])/(18900*(-1 + x)^12*(1 + x)^10) + 
        ((56700000 - 122850000*x - 412440000*x^2 + 1050273000*x^3 + 
           1202170200*x^4 - 3960825120*x^5 - 1582017920*x^6 + 
           8626477440*x^7 + 152646900*x^8 - 11908724940*x^9 + 
           2665127780*x^10 + (10725927941 - 58800*Pi^2)*x^11 + 
           70*(-61825937 + 5040*Pi^2)*x^12 + 8*(-770741747 + 764400*Pi^2)*
            x^13 + 210*(20009839 + 194320*Pi^2)*x^14 + 
           25*(126607651 + 2481360*Pi^2)*x^15 + 280*(10510343 + 262080*Pi^2)*
            x^16 + 2096591960*x^17 - 280*(-10510343 + 262080*Pi^2)*x^18 + 
           (3165191275 - 62034000*Pi^2)*x^19 - 210*(-20009839 + 194320*Pi^2)*
            x^20 - 8*(770741747 + 764400*Pi^2)*x^21 - 
           70*(61825937 + 5040*Pi^2)*x^22 + (10725927941 + 58800*Pi^2)*x^23 + 
           2665127780*x^24 - 11908724940*x^25 + 152646900*x^26 + 
           8626477440*x^27 - 1582017920*x^28 - 3960825120*x^29 + 
           1202170200*x^30 + 1050273000*x^31 - 412440000*x^32 - 
           122850000*x^33 + 56700000*x^34)*HPL[{-1, 0}, x])/
         (15876000*(-1 + x)^11*x^11*(1 + x)^9) - 
        (x*(1359319789800 + 81681390868140*x + 1249549482473460*x^2 - 
           1756670570945325*x^3 - 52865231533318890*x^4 - 20781097242417225*
            x^5 + 714420971912889360*x^6 + 955363853684845080*x^7 - 
           957392402072586480*x^8 - 9876230295863685768*x^9 - 
           62100122026979544480*x^10 + 22885777817504974260*x^11 + 
           533519037296663664960*x^12 + 231681514068510290556*x^13 - 
           881428887447366066480*x^14 - 1408595713322251161360*x^15 - 
           6015347228148396590760*x^16 + 1193121273407717687152*x^17 + 
           18076774522125013344440*x^18 + 1691746970857645171794*x^19 + 
           11234379271094508371500*x^20 + 18941885850756276351970*x^21 + 
           3762018594557874725200*x^22 - 33404962118352608800128*x^23 - 
           11223742896708612864440*x^24 + 39036168699626595884200*x^25 + 
           5772426591606935940400*x^26 - 35737148266567336859676*x^27 + 
           689574745375509891520*x^28 + 25020270772894701247452*x^29 - 
           3459622520501745366160*x^30 - 13139781448374437135760*x^31 + 
           2965750585203704696160*x^32 + 5103388011807266293476*x^33 - 
           1488145417940579594700*x^34 - 1441472023426204552365*x^35 + 
           491818636815264000270*x^36 + 290281070088020679327*x^37 - 
           109733151988939298400*x^38 - 40768738979924473560*x^39 + 
           16520351873379487560*x^40 + 3875496101895327840*x^41 - 
           1648755439523645040*x^42 - 236863170922749840*x^43 + 
           104378339433236400*x^44 + 8384994256086000*x^45 - 
           3793149508680000*x^46 - 130575053700000*x^47 + 
           60265409400000*x^48)*HPL[{0, 0}, x])/(15876000*(-1 + x)^12*
          (1 + x)^10*(9 - 82*x^2 + 9*x^4)^6) - 
        ((56700000 - 122850000*x - 412440000*x^2 + 1050273000*x^3 + 
           1202170200*x^4 - 3960825120*x^5 - 1582017920*x^6 + 
           8626477440*x^7 + 152646900*x^8 - 11908724940*x^9 + 
           2665127780*x^10 + (10725927941 - 58800*Pi^2)*x^11 + 
           70*(-61825937 + 5040*Pi^2)*x^12 + 8*(-770741747 + 764400*Pi^2)*
            x^13 + 210*(20009839 + 194320*Pi^2)*x^14 + 
           25*(126607651 + 2481360*Pi^2)*x^15 + 280*(10510343 + 262080*Pi^2)*
            x^16 + 2096591960*x^17 - 280*(-10510343 + 262080*Pi^2)*x^18 + 
           (3165191275 - 62034000*Pi^2)*x^19 - 210*(-20009839 + 194320*Pi^2)*
            x^20 - 8*(770741747 + 764400*Pi^2)*x^21 - 
           70*(61825937 + 5040*Pi^2)*x^22 + (10725927941 + 58800*Pi^2)*x^23 + 
           2665127780*x^24 - 11908724940*x^25 + 152646900*x^26 + 
           8626477440*x^27 - 1582017920*x^28 - 3960825120*x^29 + 
           1202170200*x^30 + 1050273000*x^31 - 412440000*x^32 - 
           122850000*x^33 + 56700000*x^34)*HPL[{1, 0}, x])/
         (15876000*(-1 + x)^11*x^11*(1 + x)^9) + 
        lm*(-(-221 + 192*x + 321*x^2 + 73932*x^3 + 54584*x^4 + 197784*x^5 + 
             54584*x^6 + 73932*x^7 + 321*x^8 + 192*x^9 - 221*x^10 - 
             12*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 16*x^4 - 16*x^6 - 48*x^7 - 
               3*x^8 - 6*x^9 + x^10))/(1440*(-1 + x)^10*(1 + x)^8) + 
          (x^2*(-2 + 1842*x + 2275*x^2 + 13338*x^3 + 9078*x^4 + 18738*x^5 + 
             5650*x^6 + 4992*x^7 + 214*x^8 + 54*x^9 - 9*x^10)*HPL[{0}, x])/
           (20*(-1 + x)^11*(1 + x)^9) + ((-1 + 6*x + 2*x^2 + 54*x^3 + 
             18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^8)*HPL[{-1, 0}, x])/
           (10*(-1 + x)^9*(1 + x)^7) + (x^3*(-360 - 540*x - 4500*x^2 - 
             4400*x^3 - 13200*x^4 - 7055*x^5 - 9810*x^6 - 2169*x^7 - 
             1476*x^8 - 5*x^9 - 6*x^10 + x^11)*HPL[{0, 0}, x])/
           (5*(-1 + x)^12*(1 + x)^10) - ((-1 + 6*x + 2*x^2 + 54*x^3 + 
             18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^8)*HPL[{1, 0}, x])/
           (10*(-1 + x)^9*(1 + x)^7)) + (x*(1015 + 42945*x + 407610*x^2 + 
           819210*x^3 + 6097875*x^4 + 4870285*x^5 + 8353800*x^6 + 
           7674555*x^7 + 15461075*x^8 - 12868912*x^9 - 20129130*x^10 + 
           37002133*x^11 + 26571699*x^12 - 64173336*x^13 - 19815616*x^14 + 
           76271400*x^15 + 4336204*x^16 - 62992620*x^17 + 7167284*x^18 + 
           35714786*x^19 - 8463716*x^20 - 13303386*x^21 + 4391560*x^22 + 
           2939400*x^23 - 1184500*x^24 - 292500*x^25 + 135000*x^26)*
          HPL[{2, 0}, x])/(18900*(-1 + x)^12*(1 + x)^10) + 
        (2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (4*(-1 + 6*x + 103*x^2 + 700*x^3 + 
           1158*x^4 + 1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) + 
        (2*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-2, 1, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (2*(-1 + 6*x + 103*x^2 + 700*x^3 + 
           1158*x^4 + 1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{-1, -2, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) + 
        ((67500 - 146250*x - 254750*x^2 + 738450*x^3 + 247030*x^4 - 
           1496943*x^5 + 225792*x^6 + 1525678*x^7 - 642698*x^8 - 782740*x^9 + 
           508242*x^10 + 157290*x^11 - 171598*x^12 + 9017*x^13 + 24682*x^14 - 
           10404*x^15 + 24682*x^16 + 9017*x^17 - 171598*x^18 + 157290*x^19 + 
           508242*x^20 - 782740*x^21 - 642698*x^22 + 1525678*x^23 + 
           225792*x^24 - 1496943*x^25 + 247030*x^26 + 738450*x^27 - 
           254750*x^28 - 146250*x^29 + 67500*x^30)*HPL[{-1, -1, 0}, x])/
         (18900*(-1 + x)^7*x^13*(1 + x)^5) + 
        ((-6838 + 36002*x + 51262*x^2 + 865984*x^3 - 339497*x^4 + 
           893652*x^5 - 1439760*x^6 + 1725552*x^7 - 3320382*x^8 + 
           1484354*x^9 + 8622458*x^10 - 7524430*x^11 - 11946214*x^12 + 
           18142502*x^13 + 7742930*x^14 - 23720554*x^15 + 1562478*x^16 + 
           18427496*x^17 - 6921160*x^18 - 8168818*x^19 + 5401403*x^20 + 
           1597870*x^21 - 1945450*x^22 + 97250*x^23 + 281250*x^24 - 
           67500*x^25)*HPL[{-1, 0, 0}, x])/(9450*(-1 + x)^12*(1 + x)^8) - 
        ((67500 - 146250*x - 254750*x^2 + 738450*x^3 + 247030*x^4 - 
           1496943*x^5 + 225792*x^6 + 1525678*x^7 - 642698*x^8 - 782740*x^9 + 
           508242*x^10 + 157290*x^11 - 171598*x^12 + 9017*x^13 + 24682*x^14 - 
           10404*x^15 + 24682*x^16 + 9017*x^17 - 171598*x^18 + 157290*x^19 + 
           508242*x^20 - 782740*x^21 - 642698*x^22 + 1525678*x^23 + 
           225792*x^24 - 1496943*x^25 + 247030*x^26 + 738450*x^27 - 
           254750*x^28 - 146250*x^29 + 67500*x^30)*HPL[{-1, 1, 0}, x])/
         (18900*(-1 + x)^7*x^13*(1 + x)^5) + 
        (2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (x*(-539412615 - 23269144185*x + 
           815230658025*x^2 + 1594211742207*x^3 - 31056118656948*x^4 - 
           24526562452110*x^5 + 391856187431646*x^6 - 445542859704582*x^7 - 
           1105429170372030*x^8 + 19451396874940686*x^9 - 4765615656251142*
            x^10 - 268891916517843306*x^11 - 180655069430656618*x^12 + 
           1818637932471212290*x^13 + 3135607857091037334*x^14 - 
           5765943655416996022*x^15 - 16462210807305905620*x^16 + 
           5541739308455536244*x^17 + 27035029717601729068*x^18 - 
           5537555902617695832*x^19 - 1826432163426790074*x^20 + 
           73788801358987914358*x^21 + 91390327817018674242*x^22 - 
           119748058343114240102*x^23 - 95321900745595850242*x^24 + 
           187457352037323409666*x^25 + 74515713570124355710*x^26 - 
           242547619881425719418*x^27 - 42785702718907981774*x^28 + 
           242118103313941243038*x^29 + 5840933819402051578*x^30 - 
           186904729733820827086*x^31 + 17186839240699541363*x^32 + 
           111458928285775864189*x^33 - 20290944882501327213*x^34 - 
           50920616632389431967*x^35 + 12854789425703681734*x^36 + 
           17583659274820005504*x^37 - 5406980618916577352*x^38 - 
           4508886916054457244*x^39 + 1579129631004308400*x^40 + 
           840569988875067360*x^41 - 321896118155241672*x^42 - 
           111143639859018876*x^43 + 45325759238700336*x^44 + 
           10081617060140280*x^45 - 4302145039468392*x^46 - 
           594035877569652*x^47 + 262126605436920*x^48 + 20430611515800*
            x^49 - 9246541959000*x^50 - 310892985000*x^51 + 
           143489070000*x^52)*HPL[{0, 0, 0}, x])/(18900*(-1 + x)^13*
          (1 + x)^11*(9 - 82*x^2 + 9*x^4)^6) + 
        (2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{1, -2, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) - ((67500 - 146250*x - 254750*x^2 + 
           738450*x^3 + 247030*x^4 - 1496943*x^5 + 225792*x^6 + 1525678*x^7 - 
           642698*x^8 - 782740*x^9 + 508242*x^10 + 157290*x^11 - 
           171598*x^12 + 9017*x^13 + 24682*x^14 - 10404*x^15 + 24682*x^16 + 
           9017*x^17 - 171598*x^18 + 157290*x^19 + 508242*x^20 - 
           782740*x^21 - 642698*x^22 + 1525678*x^23 + 225792*x^24 - 
           1496943*x^25 + 247030*x^26 + 738450*x^27 - 254750*x^28 - 
           146250*x^29 + 67500*x^30)*HPL[{1, -1, 0}, x])/
         (18900*(-1 + x)^7*x^13*(1 + x)^5) - 
        ((-6838 + 6970*x + 147286*x^2 + 1199152*x^3 + 2703551*x^4 + 
           5367776*x^5 + 5343984*x^6 + 6317796*x^7 + 3286506*x^8 - 
           3096458*x^9 - 2199838*x^10 + 9808662*x^11 + 3454626*x^12 - 
           16175446*x^13 - 3723798*x^14 + 18635658*x^15 + 2859414*x^16 - 
           15084932*x^17 - 1532968*x^18 + 8435354*x^19 + 546283*x^20 - 
           3110930*x^21 - 116450*x^22 + 682250*x^23 + 11250*x^24 - 
           67500*x^25)*HPL[{1, 0, 0}, x])/(9450*(-1 + x^2)^10) + 
        ((67500 - 146250*x - 254750*x^2 + 738450*x^3 + 247030*x^4 - 
           1496943*x^5 + 225792*x^6 + 1525678*x^7 - 642698*x^8 - 782740*x^9 + 
           508242*x^10 + 157290*x^11 - 171598*x^12 + 9017*x^13 + 24682*x^14 - 
           10404*x^15 + 24682*x^16 + 9017*x^17 - 171598*x^18 + 157290*x^19 + 
           508242*x^20 - 782740*x^21 - 642698*x^22 + 1525678*x^23 + 
           225792*x^24 - 1496943*x^25 + 247030*x^26 + 738450*x^27 - 
           254750*x^28 - 146250*x^29 + 67500*x^30)*HPL[{1, 1, 0}, x])/
         (18900*(-1 + x)^7*x^13*(1 + x)^5) + 
        (2*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (2*(-1 + 6*x + 103*x^2 + 700*x^3 + 
           1158*x^4 + 1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{2, -1, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) + 
        (4*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{2, 0, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (2*(1 - 6*x - 103*x^2 - 700*x^3 - 
           1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*
          HPL[{2, 1, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) + 
        (4*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-1, 1, 0, 0}, x])/
         (45*(-1 + x)^10*(1 + x)^8) + (4*(-1 + 6*x + 103*x^2 + 700*x^3 + 
           1158*x^4 + 1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{1, -1, 0, 0}, x])/(45*(-1 + x)^10*(1 + x)^8) - 
        ((-1 + 11*x + 79*x^2 + 983*x^3 + 1519*x^4 + 4040*x^5 + 2444*x^6 + 
           2792*x^7 + 464*x^8 + 289*x^9 - 25*x^10 + 5*x^11)*master3l10a[x])/
         (180*(-1 + x)^11*(1 + x)^9) + (x*(5 - 25*x + 289*x^2 + 464*x^3 + 
           2792*x^4 + 2444*x^5 + 4040*x^6 + 1519*x^7 + 983*x^8 + 79*x^9 + 
           11*x^10 - x^11)*master3l10b[x])/(180*(-1 + x)^11*(1 + x)^9) + 
        ((36780231168 + 219984864687*x + 1577323152297*x^2 + 
           5156784534762*x^3 + 6203142941544*x^4 + 5606272174671*x^5 + 
           240649731351*x^6 - 1706932920168*x^7 - 973764252864*x^8 - 
           540328340034*x^9 + 98219048346*x^10 + 273934359132*x^11 + 
           45280970640*x^12 - 41091162378*x^13 - 13008879026*x^14 + 
           2236800216*x^15 + 1442524416*x^16 + 48383027*x^17 - 
           77601939*x^18 - 9956534*x^19 + 1794248*x^20 + 292635*x^21 - 
           6677*x^22)*master3l8a[x])/(453600*(-1 + x)^12*(1 + x)^10*
          (-9 + x^2)^6) + ((4060 + 176777*x + 150325*x^2 - 10004580*x^3 - 
           12840366*x^4 + 259152035*x^5 + 274778189*x^6 - 3964932000*x^7 - 
           2672435808*x^8 + 38371794922*x^9 + 12743040170*x^10 - 
           231109171192*x^11 - 40785838212*x^12 + 781009535382*x^13 + 
           292551429954*x^14 - 1040815666800*x^15 - 1816581627756*x^16 - 
           577131299235*x^17 + 3655791054657*x^18 + 717237731772*x^19 + 
           1711026799650*x^20 + 40656095991*x^21 + 48140635473*x^22 - 
           34101768528*x^23)*master3l8b[x])/(453600*(-1 + x)^12*x*(1 + x)^10*
          (1 - 9*x^2)^6) - ((3937888872 + 9546901623*x + 85807935225*x^2 + 
           192491752131*x^3 + 314306726679*x^4 + 129748034682*x^5 + 
           80355249108*x^6 + 20508043164*x^7 + 12653439564*x^8 - 
           43992426870*x^9 - 36526867106*x^10 + 12596407978*x^11 + 
           11296467090*x^12 - 1591188144*x^13 - 1599318876*x^14 + 
           95936652*x^15 + 122712148*x^16 - 1917881*x^17 - 5073871*x^18 - 
           52885*x^19 + 91727*x^20 + 2030*x^21)*master3l9a[x])/
         (151200*(-1 + x)^12*(1 + x)^10*(-9 + x^2)^5) - 
        ((2030 + 91727*x - 52885*x^2 - 5073871*x^3 - 1917881*x^4 + 
           122712148*x^5 + 95936652*x^6 - 1599318876*x^7 - 1591188144*x^8 + 
           11296467090*x^9 + 12596407978*x^10 - 36526867106*x^11 - 
           43992426870*x^12 + 12653439564*x^13 + 20508043164*x^14 + 
           80355249108*x^15 + 129748034682*x^16 + 314306726679*x^17 + 
           192491752131*x^18 + 85807935225*x^19 + 9546901623*x^20 + 
           3937888872*x^21)*master3l9b[x])/(453600*(-1 + x)^12*x*(1 + x)^10*
          (-1 + 9*x^2)^5) - (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*
            (67500 - 146250*x - 254750*x^2 + 738450*x^3 + 247030*x^4 - 
             1496943*x^5 + 225792*x^6 + 1525678*x^7 - 642698*x^8 - 
             782740*x^9 + 508242*x^10 + 157290*x^11 - 171598*x^12 + 
             9017*x^13 + 24682*x^14 - 10404*x^15 + 24682*x^16 + 9017*x^17 - 
             171598*x^18 + 157290*x^19 + 508242*x^20 - 782740*x^21 - 
             642698*x^22 + 1525678*x^23 + 225792*x^24 - 1496943*x^25 + 
             247030*x^26 + 738450*x^27 - 254750*x^28 - 146250*x^29 + 
             67500*x^30) + 10080*x^13*(1 - 6*x - 103*x^2 - 700*x^3 - 
             1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + 
             x^10)*Zeta[3]))/(226800*(-1 + x)^10*x^13*(1 + x)^8) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(67500 - 146250*x - 254750*x^2 + 
             738450*x^3 + 247030*x^4 - 1496943*x^5 + 225792*x^6 + 
             1525678*x^7 - 642698*x^8 - 782740*x^9 + 508242*x^10 + 
             157290*x^11 - 171598*x^12 + 9017*x^13 + 24682*x^14 - 
             10404*x^15 + 24682*x^16 + 9017*x^17 - 171598*x^18 + 
             157290*x^19 + 508242*x^20 - 782740*x^21 - 642698*x^22 + 
             1525678*x^23 + 225792*x^24 - 1496943*x^25 + 247030*x^26 + 
             738450*x^27 - 254750*x^28 - 146250*x^29 + 67500*x^30) + 
           10080*x^13*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 
             1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*Zeta[3]))/
         (226800*(-1 + x)^10*x^13*(1 + x)^8) + 
        (HPL[{0}, x]*(-180796228200000 + 391725161100000*x + 
           11289050411940000*x^2 - 24959120187708000*x^3 - 
           307505559446089200*x^4 + 698142596437820520*x^5 + 
           4793446759872710520*x^6 - 11279480612267669760*x^7 - 
           47189492097400361520*x^8 + 116723625557193334260*x^9 + 
           3061800*(99938490896131 + 147987*Pi^2)*x^10 + 
           17496*(-46490162340436882 + 1095741675*Pi^2)*x^11 - 
           35280*(-1103636209822708135 + 64717083552992562*Pi^2)*x^28 + 
           27*(30127107064501975761 + 214879623248705657480*Pi^2)*x^45 - 
           210*(1457099411915174805 + 8216941807160399236*Pi^2)*x^46 - 
           945*(123517829924853993 + 1675534473654211952*Pi^2)*x^47 + 
           45360*(1040332718196657 + 12023242135193024*Pi^2)*x^48 + 
           816480*(13814766573912 + 380110107982073*Pi^2)*x^49 - 
           204120*(23483474230221 + 577406338278728*Pi^2)*x^50 - 
           1837080*(380028412719 + 23236382935052*Pi^2)*x^51 + 
           1224720*(251082336735 + 14155225566454*Pi^2)*x^52 + 
           11022480*(2264383350 + 362280936637*Pi^2)*x^53 - 
           198404640*(56899125 + 8571528491*Pi^2)*x^54 - 
           297606960*(1316250 + 809943379*Pi^2)*x^55 + 
           5952139200*(30375 + 17854067*Pi^2)*x^56 + 8450281782936000*Pi^2*
            x^57 - 3823282213380000*Pi^2*x^58 - 130575053700000*Pi^2*x^59 + 
           60265409400000*Pi^2*x^60 + 24*x^33*(2967628209806162231269 + 
             1333510687083964100075*Pi^2 - 11016537549192504000*Zeta[3]) + 
           280*x^26*(-147046066749525853615 + 4960675747302334668*Pi^2 - 
             8626956911056310400*Zeta[3]) - 24*x^25*
            (-2041969763667158443868 + 6560566123387168515*Pi^2 - 
             4218583234193496000*Zeta[3]) - 280*x^24*(-75775987410053966033 + 
             2577475763217288324*Pi^2 - 3619319336312198400*Zeta[3]) - 
           72*x^35*(1068050889964115220433 + 664843373320902548605*Pi^2 - 
             1361151899028936000*Zeta[3]) + 108*x^21*(726388718302498485547 + 
             24639025261251870*Pi^2 - 907434599352624000*Zeta[3]) + 
           36*x^37*(1646619572706069347399 + 1512964466681535671370*Pi^2 - 
             446312381813424000*Zeta[3]) - 72*x^19*(824660045163430892062 + 
             14266876927577715*Pi^2 - 223156190906712000*Zeta[3]) + 
           560*x^22*(-19779106338141174103 + 303817754767697331*Pi^2 - 
             163394522804520000*Zeta[3]) - 840*x^36*(-2224193636641717501 + 
             16017527671322259448*Pi^2 - 30502666745913600*Zeta[3]) - 
           108*x^39*(305906511247585905413 + 437672000537937361350*Pi^2 - 
             13031554043088000*Zeta[3]) + 840*x^38*(-9085165317043054019 + 
             5833646439871289242*Pi^2 - 8821989569232000*Zeta[3]) + 
           216*x^17*(152763225871506665419 + 217132272420525*Pi^2 - 
             6515777021544000*Zeta[3]) + 22680*x^16*(-312724970691484349 + 
             3333667696380*Pi^2 - 34921862035200*Zeta[3]) - 
           3150*x^14*(-1214378431977274649 + 2113697035044*Pi^2 - 
             12770909867520*Zeta[3]) - 648*x^43*(6061470080147249003 + 
             24050548676247654820*Pi^2 - 1874923848000*Zeta[3]) + 
           34020*x^12*(-38983113312035747 + 4620562380*Pi^2 - 
             23808556800*Zeta[3]) + 10125*x^15*(-1324334412638496893 + 
             609276522456*Pi^2 + 6359741692416*Zeta[3]) - 
           81*x^13*(-48480832682694616699 + 8423654778000*Pi^2 + 
             14999390784000*Zeta[3]) - 840*x^42*(4555632518655800430 + 
             5771956754969149607*Pi^2 + 47890912003200*Zeta[3]) + 
           840*x^40*(8486502989474196423 + 2812191163615058372*Pi^2 + 
             942890274950400*Zeta[3]) + 1680*x^18*(4314867079741065157 + 
             271337634582525*Pi^2 + 4410994784616000*Zeta[3]) - 
           840*x^20*(250313134034771701 + 21566077024886100*Pi^2 + 
             30502666745913600*Zeta[3]) + 280*x^34*(43419718085997431231 + 
             63258831800434244394*Pi^2 + 326789045609040000*Zeta[3]) - 
           280*x^32*(182384956436148340313 + 55776131633386338300*Pi^2 + 
             3619319336312198400*Zeta[3]) - 168*x^27*(227554564408455003859 + 
             4795323835129114105*Pi^2 + 10730893459567176000*Zeta[3]) - 
           6*x^31*(9922113138663042083897 + 2730135066788283865340*Pi^2 + 
             16874332936773984000*Zeta[3]) + 140*x^30*
            (636391600454578829705 + 66888954267046923216*Pi^2 + 
             17253913822112620800*Zeta[3]) + 12*x^23*
            (-6206342449038172550213 + 2935591810567462410*Pi^2 + 
             22033075098385008000*Zeta[3]) + 42*x^29*
            (1637089432362168800461 + 155177023014329748540*Pi^2 + 
             42923573838268704000*Zeta[3]) + 420*x^44*
            (8746317158636390060*Pi^2 + 81*(38983276174468487 + 23808556800*
                Zeta[3])) + 60*x^41*(520440257439998484694*Pi^2 - 
             675*(-331318132364530655 + 1589935423104*Zeta[3]))))/
         (190512000*(-1 + x)^12*x^9*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^6) - 
        (235200*Pi^4*x^11*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^6*
           (1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
            700*x^7 - 103*x^8 - 6*x^9 + x^10) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^6*
           (-56700000 + 122850000*x + 469140000*x^2 - 1173123000*x^3 - 
            1614610200*x^4 + 5011098120*x^5 + 2784188120*x^6 - 
            12587302560*x^7 - 1734664820*x^8 + 20535202380*x^9 - 
            2512480880*x^10 - 22634652881*x^11 + 6992943370*x^12 + 
            16891861917*x^13 - 8529881780*x^14 - 9331125251*x^15 + 
            1259170150*x^16 + 1068599315*x^17 - 1068599315*x^19 - 
            1259170150*x^20 + 9331125251*x^21 + 8529881780*x^22 - 
            16891861917*x^23 - 6992943370*x^24 + 22634652881*x^25 + 
            2512480880*x^26 - 20535202380*x^27 + 1734664820*x^28 + 
            12587302560*x^29 - 2784188120*x^30 - 5011098120*x^31 + 
            1614610200*x^32 + 1173123000*x^33 - 469140000*x^34 - 
            122850000*x^35 + 56700000*x^36) + x^2*(-180796228200000 + 
            391725161100000*x + 11349315821340000*x^2 - 25089695241408000*
             x^3 - 311245976721544200*x^4 + 706413337521919020*x^5 + 
            4894550037013539420*x^6 - 11509102124193000600*x^7 - 
            48749648604584660460*x^8 + x^35*(98161974351701489617644 - 
              573761233602105462970560*Zeta[3]) + 101403381395232000*x^57*
             Zeta[3] - 45879386560560000*x^58*Zeta[3] - 1566900644400000*x^59*
             Zeta[3] + 723184912800000*x^60*Zeta[3] + 17856417600*x^56*
             (-10125 + 71416268*Zeta[3]) - 688905*x^9*(-174768194526857 + 
              351133056*Zeta[3]) + 238140*x^12*(-5974236887006129 + 
              422703360*Zeta[3]) - 1785641760*x^55*(-219375 + 
              1619886758*Zeta[3]) + 153090*x^10*(2097765844308733 + 
              1696248864*Zeta[3]) - 595213920*x^54*(-19067625 + 
              34286113964*Zeta[3]) + 132269760*x^53*(-189685800 + 
              362280936637*Zeta[3]) + 2187*x^11*(-389093062329837797 + 
              6304507473600*Zeta[3]) + 1837080*x^52*(-169424291115 + 
              113241804531632*Zeta[3]) - 2755620*x^51*(-256353683571 + 
              185891063480416*Zeta[3]) - 630*x^14*(-6715010991721366021 + 
              700120671741792*Zeta[3]) - 81*x^13*(-51648761128483043659 + 
              4128233253399360*Zeta[3]) - 306180*x^50*(-15985858112919 + 
              4619250706229824*Zeta[3]) + 612360*x^49*(-18794666738835 + 
              6081761727713168*Zeta[3]) - 2916*x^17*(-12615115779698186063 + 
              10818431693202000*Zeta[3]) + 5184*x^19*(-13087710131850941623 + 
              14842390056764445*Zeta[3]) + 840*x^16*(-9692466508736178931 + 
              15419921253870816*Zeta[3]) - 2940*x^18*(-2751281877145393471 + 
              57085936834470048*Zeta[3]) + 68040*x^48*(-716485085336349 + 
              96185937081544192*Zeta[3]) + 27*x^15*(-540834794318266728799 + 
              162839736080138880*Zeta[3]) + 840*x^20*(6673282757953573819 + 
              1296865020099401424*Zeta[3]) - 1120*x^22*
             (29938607012283120287 + 2454440521985124432*Zeta[3]) + 
            8820*x^44*(-161291393527978323 + 4997895987148689920*Zeta[3]) - 
            2835*x^47*(-42468213508349121 + 6702137972799613376*Zeta[3]) + 
            2940*x^38*(2991907680526552171 + 19942242326987558496*Zeta[3]) - 
            280*x^24*(-101673976576067096845 + 20908106945562264192*Zeta[
                3]) - 7840*x^32*(-2276905104266647855 + 23707247919232799448*
               Zeta[3]) - 630*x^46*(-509751236254048389 + 
              32867767017933034912*Zeta[3]) + 12*x^21*
             (7957619370180444764287 + 55966028755786914240*Zeta[3]) + 
            420*x^40*(-19480552416363901907 + 67523313563151816000*Zeta[3]) - 
            630*x^42*(-6714808073473135351 + 92352056521242420704*Zeta[3]) + 
            210*x^25*(440811481561373176079 + 134326054630249033120*Zeta[
                3]) - 840*x^36*(-316243746620085859 + 190720875305559906912*
               Zeta[3]) - 28*x^23*(4078175546458676256791 + 
              254619869281735990080*Zeta[3]) + 140*x^26*
             (93466729386111932077 + 366080661051349815648*Zeta[3]) + 
            560*x^34*(-27968703319281797449 + 371726374850432220408*Zeta[
                3]) - 280*x^28*(-535695243998140148605 + 
              405042765031164041952*Zeta[3]) + 644*x^33*
             (-158414774483122326667 + 584783929024393482480*Zeta[3]) - 
            66*x^27*(-705126417889052953351 + 726994293471724121760*Zeta[
                3]) - 210*x^31*(-297802357085482704989 + 
              795507850397225268896*Zeta[3]) + 81*x^45*
             (-10505109150739648269 + 859518645460301160320*Zeta[3]) + 
            140*x^30*(-282541549538469672833 + 1060543888899314398848*Zeta[
                3]) - 324*x^39*(-114414329828958841817 + 
              1750776380783604594000*Zeta[3]) - 81*x^43*
             (-51652802274404311009 + 2308856321204929265280*Zeta[3]) + 
            216*x^37*(-321877370739774275177 + 3026270308125146902680*Zeta[
                3]) + 6*x^29*(-3001444748653842887089 + 
              6846739935965560891680*Zeta[3]) + 9*x^41*
             (-1624775709276345804447 + 41635653373459904951360*Zeta[3])))/
         (762048000*(-1 + x)^12*x^11*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^6)));


CbarSeries["s", 2, -1, "x0"] = SeriesData[x, 0, 
     {(CF*NC*(30*(NH*(125 + 117*lm + 20*lm^2 + 4*lm^3 - 112*Zeta[3]) + 
           NM*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3]) + 
           NL*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3])) - 
         CA*(4560*lm^2 + 660*lm^3 + 88*Pi^4 + 480*Pi^2*Log[2]^2 - 
           45*lm*(-247 + 48*Zeta[3]) - 15*(-749 + 32*Log[2]^4 + 
             768*PolyLog[4, 1/2] + 392*Zeta[3])) + 
         CF*(-2430*lm^2 - 2160*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           45*lm*(-5 + 96*Zeta[3]) - 15*(-139 + 64*Log[2]^4 + 
             1536*PolyLog[4, 1/2] + 1008*Zeta[3]))))/1080, 
      (CF*NC*(30*(NH*(93 + 45*lm + 20*lm^2 + 4*lm^3 - 112*Zeta[3]) + 
           NM*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3]) + 
           NL*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3])) - 
         CA*(4560*lm^2 + 660*lm^3 + 88*Pi^4 + 480*Pi^2*Log[2]^2 - 
           45*lm*(-247 + 48*Zeta[3]) - 15*(-749 + 32*Log[2]^4 + 
             768*PolyLog[4, 1/2] + 392*Zeta[3])) + 
         CF*(-2430*lm^2 - 2160*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           45*lm*(-5 + 96*Zeta[3]) - 15*(-139 + 64*Log[2]^4 + 
             1536*PolyLog[4, 1/2] + 1008*Zeta[3]))))/1080, 
      (CF*NC*(30*(NH*(93 + 45*lm + 20*lm^2 + 4*lm^3 - 112*Zeta[3]) + 
           NL*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3]) + 
           NM*(5 + 117*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3])) - 
         CA*(4560*lm^2 + 660*lm^3 + 88*Pi^4 + 480*Pi^2*Log[2]^2 - 
           45*lm*(-247 + 48*Zeta[3]) - 15*(-749 + 32*Log[2]^4 + 
             768*PolyLog[4, 1/2] + 392*Zeta[3])) + 
         CF*(-2430*lm^2 - 2160*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           45*lm*(-5 + 96*Zeta[3]) - 15*(-139 + 64*Log[2]^4 + 
             1536*PolyLog[4, 1/2] + 1008*Zeta[3]))))/1080, 
      -(CF*NC*(-36*(27*CF*(3 + 8*lm) + 2*CA*(76 + 33*lm) - 
            4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          144*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          8*(2*NH*(109 - 81*Zeta[3]) + 27*NM*(-5 + 6*Zeta[3])) + 
          3*Log[x]*(-2*(3*(117 + 40*lm + 12*lm^2)*NM + 3*(45 + 40*lm + 
                12*lm^2)*NL + (-89 + 120*lm + 36*lm^2)*NH) + 
            3*CA*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]) + 
            9*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3]))))/324, 
      -(CF*NC*(-36*(27*CF*(3 + 8*lm) + 2*CA*(76 + 33*lm) - 
            2*(13*NM + 6*lm*NM + 10*NL + 6*lm*NL + 6*lm*NH))*Log[x]^2 + 
          144*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          16*NH*(-109 + 81*Zeta[3]) - 3*NM*(-511 + 432*Zeta[3]) + 
          3*Log[x]*(-2*(3*(143 + 40*lm + 12*lm^2)*NM + 3*(45 + 40*lm + 
                12*lm^2)*NL + (-89 + 120*lm + 36*lm^2)*NH) + 
            3*CA*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]) + 
            9*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3]))))/324, 
      (CF*NC*(135*CF*(3 + 8*lm) + 10*CA*(76 + 33*lm) - 
          2*(5*(13 + 6*lm)*NM + 10*(5 + 3*lm)*NL + 6*(2 + 5*lm)*NH))*
         Log[x]^2)/45 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + CF*(NC*NH*(49358/10125 - 4*Zeta[3]) + 
         NM*NC*(-511/108 + 4*Zeta[3])) - 
       (CF*NC*Log[x]*(-2*(75*(143 + 40*lm + 12*lm^2)*NM + 
            75*(45 + 40*lm + 12*lm^2)*NL + (-1097 + 3000*lm + 900*lm^2)*
             NH) + 75*CA*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]) + 
          225*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3])))/2700, 
      -(CF*NC*(-900*(135*CF*(3 + 8*lm) + 10*CA*(76 + 33*lm) - 
            2*((69 + 30*lm)*NM + 10*(5 + 3*lm)*NL + 6*(2 + 5*lm)*NH))*
           Log[x]^2 + 18000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          NM*(193921 - 162000*Zeta[3]) + 8*NH*(-24679 + 20250*Zeta[3]) + 
          15*Log[x]*(-2*(3*(3647 + 1000*lm + 300*lm^2)*NM + 75*(45 + 40*lm + 
                12*lm^2)*NL + (-1097 + 3000*lm + 900*lm^2)*NH) + 
            75*CA*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]) + 
            225*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3]))))/40500, 
      (CF*NC*(945*CF*(3 + 8*lm) + 70*CA*(76 + 33*lm) - 
          2*(21*(23 + 10*lm)*NM + 70*(5 + 3*lm)*NL + 3*(37 + 70*lm)*NH))*
         Log[x]^2)/315 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + CF*(NC*NH*(67060079/13891500 - 4*Zeta[3]) + 
         NM*NC*(-193921/40500 + 4*Zeta[3])) - 
       (CF*NC*Log[x]*(-2*(147*(3647 + 1000*lm + 300*lm^2)*NM + 
            3675*(45 + 40*lm + 12*lm^2)*NL + (-44087 + 147000*lm + 
              44100*lm^2)*NH) + 3675*CA*(741 + 608*lm + 132*lm^2 - 
            144*Zeta[3]) + 11025*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3])))/
        132300, (CF*NC*(945*CF*(3 + 8*lm) + 70*CA*(76 + 33*lm) - 993*NM - 
          420*lm*NM - 700*NL - 420*lm*NL - 222*NH - 420*lm*NH)*Log[x]^2)/
        315 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NC*NH*(67060079/13891500 - 4*Zeta[3]) + 
         NM*NC*(-533443007/111132000 + 4*Zeta[3])) - 
       (CF*NC*Log[x]*(-1079049*NM - 294000*lm*NM - 88200*lm^2*NM - 
          330750*NL - 294000*lm*NL - 88200*lm^2*NL + 88174*NH - 
          294000*lm*NH - 88200*lm^2*NH + 3675*CA*(741 + 608*lm + 132*lm^2 - 
            144*Zeta[3]) + 11025*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3])))/
        132300, (CF*NC*(2835*CF*(3 + 8*lm) + 210*CA*(76 + 33*lm) - 2979*NM - 
          1260*lm*NM - 2100*NL - 1260*lm*NL - 746*NH - 1260*lm*NH)*
         Log[x]^2)/945 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + CF*(NC*NH*(1806421133/375070500 - 4*Zeta[3]) + 
         NM*NC*(-533443007/111132000 + 4*Zeta[3])) - 
       (CF*NC*Log[x]*(-9711441*NM - 2646000*lm*NM - 793800*lm^2*NM - 
          2976750*NL - 2646000*lm*NL - 793800*lm^2*NL + 733966*NH - 
          2646000*lm*NH - 793800*lm^2*NH + 33075*CA*(741 + 608*lm + 
            132*lm^2 - 144*Zeta[3]) + 99225*CF*(-5 + 108*lm + 144*lm^2 + 
            96*Zeta[3])))/1190700, 
      (CF*NC*(2835*CF*(3 + 8*lm) + 210*CA*(76 + 33*lm) - 3027*NM - 
          1260*lm*NM - 2100*NL - 1260*lm*NL - 746*NH - 1260*lm*NH)*
         Log[x]^2)/945 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + CF*(NC*NH*(1806421133/375070500 - 4*Zeta[3]) + 
         NM*NC*(-4805028727/1000188000 + 4*Zeta[3])) - 
       (CF*NC*Log[x]*(-9739137*NM - 2646000*lm*NM - 793800*lm^2*NM - 
          2976750*NL - 2646000*lm*NL - 793800*lm^2*NL + 733966*NH - 
          2646000*lm*NH - 793800*lm^2*NH + 33075*CA*(741 + 608*lm + 
            132*lm^2 - 144*Zeta[3]) + 99225*CF*(-5 + 108*lm + 144*lm^2 + 
            96*Zeta[3])))/1190700, 
      (CF*NC*(31185*CF*(3 + 8*lm) + 2310*CA*(76 + 33*lm) - 33297*NM - 
          13860*lm*NM - 23100*NL - 13860*lm*NL - 8731*NH - 13860*lm*NH)*
         Log[x]^2)/10395 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + Log[x]*(CF*((3246379/396900 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (85506061*NC*NH)/144074700 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(19219084990559/3993750684000 - 4*Zeta[3]) + 
         NM*NC*(-4805028727/1000188000 + 4*Zeta[3])), 
      (CF*NC*(31185*CF*(3 + 8*lm) + 2310*CA*(76 + 33*lm) - 33647*NM - 
          13860*lm*NM - 23100*NL - 13860*lm*NL - 8731*NH - 13860*lm*NH)*
         Log[x]^2)/10395 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + Log[x]*(CF*((1180233877/144074700 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (85506061*NC*NH)/144074700 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(19219084990559/3993750684000 - 4*Zeta[3]) + 
         NM*NC*(-19193460099911/3993750684000 + 4*Zeta[3])), 
      (CF*NC*(405405*CF*(3 + 8*lm) + 30030*CA*(76 + 33*lm) - 437411*NM - 
          180180*lm*NM - 300300*NL - 180180*lm*NL - 118039*NH - 
          180180*lm*NH)*Log[x]^2)/135135 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((1180233877/144074700 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (14148943813*NC*NH)/24348624300 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(42209227573587467/8774270252748000 - 4*Zeta[3]) + 
         NM*NC*(-19193460099911/3993750684000 + 4*Zeta[3])), 
      (CF*NC*(405405*CF*(3 + 8*lm) + 30030*CA*(76 + 33*lm) - 440651*NM - 
          180180*lm*NM - 300300*NL - 180180*lm*NL - 118039*NH - 
          180180*lm*NH)*Log[x]^2)/135135 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((199641580813/24348624300 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (14148943813*NC*NH)/24348624300 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(42209227573587467/8774270252748000 - 4*Zeta[3]) + 
         NM*NC*(-6025106074165781/1253467178964000 + 4*Zeta[3])), 
      (CF*NC*(405405*CF*(3 + 8*lm) + 30030*CA*(76 + 33*lm) - 440651*NM - 
          180180*lm*NM - 300300*NL - 180180*lm*NL - 121273*NH - 
          180180*lm*NH)*Log[x]^2)/135135 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((199641580813/24348624300 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (13967729857*NC*NH)/24348624300 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(42201587873667923/8774270252748000 - 4*Zeta[3]) + 
         NM*NC*(-6025106074165781/1253467178964000 + 4*Zeta[3])), 
      (CF*NC*(810810*CF*(3 + 8*lm) + 60060*CA*(76 + 33*lm) - 886153*NM - 
          360360*lm*NM - 600600*NL - 360360*lm*NL - 242546*NH - 
          360360*lm*NH)*Log[x]^2)/270270 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((159807425471/19478899440 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (13967729857*NC*NH)/24348624300 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(42201587873667923/8774270252748000 - 4*Zeta[3]) + 
         NM*NC*(-9641152416943673/2005547486342400 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (886153*NM*NC)/270270 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (420565*NC*NH)/459459 - (4*lm*NC*NH)/3))*
        Log[x]^2 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((159807425471/19478899440 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (4002760325521*NC*NH)/7036752422700 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(29616486431553649669/6158284250250132000 - 4*Zeta[3]) + 
         NM*NC*(-9641152416943673/2005547486342400 + 4*Zeta[3])), 
      (3*CF^2*(3 + 8*lm)*NC + (2*CA*CF*(76 + 33*lm)*NC)/9 - 
         (CF*NC*((3025733 + 1225224*lm)*NM + 2*(204204*(5 + 3*lm)*NL + 
              (420565 + 612612*lm)*NH)))/918918)*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((77004926542153/9382336563600 + (20*lm)/9 + (2*lm^2)/3)*
            NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (4002760325521*NC*NH)/7036752422700 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(29616486431553649669/6158284250250132000 - 4*Zeta[3]) + 
         NM*NC*(-236849429542791214477/49266274002001056000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (3025733*NM*NC)/918918 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (16224713*NC*NH)/17459442 - (4*lm*NC*NH)/3))*
        Log[x]^2 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((77004926542153/9382336563600 + (20*lm)/9 + (2*lm^2)/3)*
            NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (5746463941547299*NC*NH)/10161070498378800 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(1625016656261802799233743/337917373379725243104000 - 
           4*Zeta[3]) + NM*NC*(-236849429542791214477/49266274002001056000 + 
           4*Zeta[3])), ((2*CA*CF*(76 + 33*lm)*NC)/9 + 
         CF*(3*CF*(3 + 8*lm)*NC - (288417607*NM*NC)/87297210 - 
           (4*lm*NM*NC)/3 - (20*NC*NL)/9 - (4*lm*NC*NL)/3 - 
           (16224713*NC*NH)/17459442 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((5561354784128141/677404699891920 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (5746463941547299*NC*NH)/10161070498378800 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(1625016656261802799233743/337917373379725243104000 - 
           4*Zeta[3]) + NM*NC*(-1624613731082485277637007/
            337917373379725243104000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (288417607*NM*NC)/87297210 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (2345599*NC*NH)/2494206 - (4*lm*NC*NH)/3))*
        Log[x]^2 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((5561354784128141/677404699891920 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (272500612484119*NC*NH)/483860499922800 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(11374673440564897144780201/2365421613658076701728000 - 
           4*Zeta[3]) + NM*NC*(-1624613731082485277637007/
            337917373379725243104000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (289213207*NM*NC)/87297210 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (2345599*NC*NH)/2494206 - (4*lm*NC*NH)/3))*
        Log[x]^2 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((5562536486262221/677404699891920 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (272500612484119*NC*NH)/483860499922800 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(11374673440564897144780201/2365421613658076701728000 - 
           4*Zeta[3]) + NM*NC*(-11372592822018734836515049/
            2365421613658076701728000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (289213207*NM*NC)/87297210 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (1906498039*NC*NH)/2007835830 - 
           (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((5562536486262221/677404699891920 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (201189512429774669*NC*NH)/
            358347086242825680 + (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(138392049583313812614866057183/
            28780084773377819229924576000 - 4*Zeta[3]) + 
         NM*NC*(-11372592822018734836515049/2365421613658076701728000 + 
           4*Zeta[3])), ((2*CA*CF*(76 + 33*lm)*NC)/9 + 
         CF*(3*CF*(3 + 8*lm)*NC - (6667146131*NM*NC)/2007835830 - 
           (4*lm*NM*NC)/3 - (20*NC*NL)/9 - (4*lm*NC*NL)/3 - 
           (1906498039*NC*NH)/2007835830 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((2943056829358432769/358347086242825680 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (201189512429774669*NC*NH)/
            358347086242825680 + (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(138392049583313812614866057183/
            28780084773377819229924576000 - 4*Zeta[3]) + 
         NM*NC*(-138372838677408433354052498183/
            28780084773377819229924576000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (6667146131*NM*NC)/2007835830 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (9608676851*NC*NH)/10039179150 - 
           (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((2943056829358432769/358347086242825680 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (25089359598783200473*NC*NH)/
            44793385780353210000 + (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(17298693987653518238116499010019/
            3597510596672227403740572000000 - 4*Zeta[3]) + 
         NM*NC*(-138372838677408433354052498183/
            28780084773377819229924576000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (33400196287*NM*NC)/10039179150 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (9608676851*NC*NH)/
            10039179150 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((367928282628777556669/44793385780353210000 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (25089359598783200473*NC*NH)/
            44793385780353210000 + (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(17298693987653518238116499010019/
            3597510596672227403740572000000 - 4*Zeta[3]) + 
         NM*NC*(-17296828390993605618969623859307/
            3597510596672227403740572000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (33400196287*NM*NC)/10039179150 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (29019377707*NC*NH)/
            30117537450 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((367928282628777556669/44793385780353210000 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (676166678835784784959*NC*NH)/
            1209421416069536670000 + (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(467058709400221266644143254479177/
            97132786110150139900995444000000 - 4*Zeta[3]) + 
         NM*NC*(-17296828390993605618969623859307/
            3597510596672227403740572000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (1593116111*NM*NC)/478056150 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (29019377707*NC*NH)/30117537450 - 
           (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((3311684143526228561653/403140472023178890000 + 
             (20*lm)/9 + (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + 
           (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - (676166678835784784959*NC*
             NH)/1209421416069536670000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(467058709400221266644143254479177/
            97132786110150139900995444000000 - 4*Zeta[3]) + 
         NM*NC*(-155672931939313225358967308493059/
            32377595370050046633665148000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (1593116111*NM*NC)/478056150 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (846367030703*NC*NH)/873408586050 - 
           (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((3311684143526228561653/403140472023178890000 + 
             (20*lm)/9 + (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + 
           (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - (567825020559178820590519*
             NC*NH)/1017123410914480339470000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(11390986948423782674115482030140647853/
            2368971520440451762045377883716000000 - 4*Zeta[3]) + 
         NM*NC*(-155672931939313225358967308493059/
            32377595370050046633665148000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (416398219291*NM*NC)/124772655150 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (846367030703*NC*NH)/
            873408586050 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((8356049689812139939032919/1017123410914480339470000 + 
             (20*lm)/9 + (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + 
           (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - (567825020559178820590519*
             NC*NH)/1017123410914480339470000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(11390986948423782674115482030140647853/
            2368971520440451762045377883716000000 - 4*Zeta[3]) + 
         NM*NC*(-11390202472319336737927923941234271853/
            2368971520440451762045377883716000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (416398219291*NM*NC)/124772655150 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (3766636158899*NC*NH)/
            3867952309650 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((8356049689812139939032919/1017123410914480339470000 + 
             (20*lm)/9 + (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + 
           (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (545035667419860666229318759*NC*NH)/977455597888815606230670000 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(339346479274581452622693643644685253188723/
            70574030565441498443093852533783356000000 - 4*Zeta[3]) + 
         NM*NC*(-11390202472319336737927923941234271853/
            2368971520440451762045377883716000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (25848958386167*NM*NC)/7735904619300 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (3766636158899*NC*NH)/
            3867952309650 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((32122764011820975684556895011/
              3909822391555262424922680000 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (545035667419860666229318759*NC*NH)/977455597888815606230670000 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(339346479274581452622693643644685253188723/
            70574030565441498443093852533783356000000 - 4*Zeta[3]) + 
         NM*NC*(-2714618954592808975065563696627843933103659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (25848958386167*NM*NC)/7735904619300 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (3782768380979*NC*NH)/
            3867952309650 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((32122764011820975684556895011/
              3909822391555262424922680000 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (544508593881525258015205159*NC*NH)/977455597888815606230670000 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(339344633046661304827223791270314000772723/
            70574030565441498443093852533783356000000 - 4*Zeta[3]) + 
         NM*NC*(-2714618954592808975065563696627843933103659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (25877427013367*NM*NC)/7735904619300 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (3782768380979*NC*NH)/
            3867952309650 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((32124511421186097581557055011/
              3909822391555262424922680000 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (544508593881525258015205159*NC*NH)/977455597888815606230670000 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(339344633046661304827223791270314000772723/
            70574030565441498443093852533783356000000 - 4*Zeta[3]) + 
         NM*NC*(-2714630454053256954084736071362261789103659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (25877427013367*NM*NC)/7735904619300 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (53158015482991*NC*NH)/
            54151332335100 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((32124511421186097581557055011/
              3909822391555262424922680000 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (2176287453678091031829805411*NC*NH)/
            3909822391555262424922680000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(2714745571326530773683860265467556461487659/
            564592244523531987544750820270266848000000 - 4*Zeta[3]) + 
         NM*NC*(-2714630454053256954084736071362261789103659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (181319107448489*NM*NC)/54151332335100 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (53158015482991*NC*NH)/
            54151332335100 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((32125975433246366478853386211/
              3909822391555262424922680000 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (2176287453678091031829805411*NC*NH)/
            3909822391555262424922680000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(2714745571326530773683860265467556461487659/
            564592244523531987544750820270266848000000 - 4*Zeta[3]) + 
         NM*NC*(-2714639535284307262095271366458053094255659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (181319107448489*NM*NC)/54151332335100 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (1973399339136427*NC*NH)/
            2003599296398700 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((32125975433246366478853386211/
              3909822391555262424922680000 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (2977333760126732452408127620459*NC*NH)/
            5352546854039154259719148920000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(137509547647797015009072206967782649990582647327/
            28598290961850465765104263299149826651744000000 - 4*Zeta[3]) + 
         NM*NC*(-2714639535284307262095271366458053094255659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (6714669976989773*NM*NC)/2003599296398700 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (1973399339136427*NC*NH)/
            2003599296398700 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((43982156226223991347508902420459/
              5352546854039154259719148920000 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (2977333760126732452408127620459*NC*NH)/
            5352546854039154259719148920000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(137509547647797015009072206967782649990582647327/
            28598290961850465765104263299149826651744000000 - 4*Zeta[3]) + 
         NM*NC*(-137505004467196798936188319364970676501038647327/
            28598290961850465765104263299149826651744000000 + 4*Zeta[3]))}, 
     0, 39, 1]
 
CbarSeries["s", 2, -1, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(10*(NM*(77 + 127*lm + 36*lm^2 + 12*lm^3 - 84*Zeta[3]) + 
           NH*(77 + 127*lm + 36*lm^2 + 12*lm^3 - 84*Zeta[3]) + 
           NL*(45 + 55*lm + 36*lm^2 + 12*lm^3 + 96*Zeta[3])) - 
         CA*(3240*lm^2 + 660*lm^3 + 88*Pi^4 + 480*Pi^2*Log[2]^2 + 
           lm*(5035 - 2160*Zeta[3]) - 15*(-255 + 32*Log[2]^4 + 
             768*PolyLog[4, 1/2] + 296*Zeta[3])) + 
         CF*(1890*lm^2 - 2160*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           45*lm*(-77 + 96*Zeta[3]) - 15*(-129 + 64*Log[2]^4 + 
             1536*PolyLog[4, 1/2] + 816*Zeta[3]))))/360, 
      -(CF*NC*(CF*(-8370*lm^2 + 2160*lm^3 - 176*Pi^4 - 960*Pi^2*Log[2]^2 + 
            45*lm*(7 + 96*Zeta[3]) + 30*(51 + 32*Log[2]^4 + 768*PolyLog[4, 
                1/2] + 264*Zeta[3])) - 
          10*(NH*(-10 - 17*lm + 12*lm^3 + 42*Zeta[3]) + 
            NL*(-10 - 17*lm + 12*lm^3 + 96*Zeta[3]) + 
            NM*(127*lm + 12*lm^3 - 30*(3 + 7*Zeta[3]))) + 
          CA*(1260*lm^2 + 660*lm^3 - 5*lm*(289 + 432*Zeta[3]) + 
            2*(44*Pi^4 + 240*Pi^2*Log[2]^2 - 5*(121 + 48*Log[2]^4 + 
                1152*PolyLog[4, 1/2] + 228*Zeta[3])))))/360, 
      -(CF*NC*(CF*(-21330*lm^2 + 2160*lm^3 - 176*Pi^4 - 960*Pi^2*Log[2]^2 + 
            60*(15 + 16*Log[2]^4 + 384*PolyLog[4, 1/2] - 12*Zeta[3]) + 
            45*lm*(751 + 96*Zeta[3])) + CA*(-2700*lm^2 + 660*lm^3 + 
            8*(11*Pi^4 + 60*Pi^2*Log[2]^2 - 15*(-14 + 4*Log[2]^4 + 
                96*PolyLog[4, 1/2] - 17*Zeta[3])) - 
            5*lm*(1297 + 432*Zeta[3])) - 
          10*(NL*(24 - 17*lm - 72*lm^2 + 12*lm^3 + 96*Zeta[3]) + 
            NH*(-12 - 17*lm - 72*lm^2 + 12*lm^3 + 168*Zeta[3]) + 
            NM*(199*lm - 72*lm^2 + 12*lm^3 - 6*(94 + 35*Zeta[3])))))/1080, 
      (CF*NC*(-470*NM + 288*lm*NM - 72*lm^2*NM + 34*NL + 288*lm*NL - 
         72*lm^2*NL - 38*NH + 288*lm*NH - 72*lm^2*NH + 
         CA*(-1297 - 1080*lm + 396*lm^2 - 432*Zeta[3]) + 
         9*CF*(751 - 948*lm + 144*lm^2 + 96*Zeta[3])))/432, 
      -(CF*NC*(106*NM - 72*lm^2*NM + 610*NL - 72*lm^2*NL + 466*NH - 
          72*lm^2*NH + CA*(-3457 + 504*lm + 396*lm^2 - 432*Zeta[3]) + 
          9*CF*(-1145 - 372*lm + 144*lm^2 + 96*Zeta[3])))/2160, 
      (CF*NC*(-2*((-71 + 72*lm + 36*lm^2)*NM + (-305 + 72*lm + 36*lm^2)*
            NL + (-215 + 72*lm + 36*lm^2)*NH) + 
         CA*(-2953 + 1296*lm + 396*lm^2 - 432*Zeta[3]) + 
         9*CF*(-1517 - 84*lm + 144*lm^2 + 96*Zeta[3])))/6480, 
      -(CF*NC*(-2*(3*(-15 + 40*lm + 12*lm^2)*NM + (-257 + 120*lm + 36*lm^2)*
             NL + 3*(-57 + 40*lm + 12*lm^2)*NH) + 
          CA*(-2089 + 1824*lm + 396*lm^2 - 432*Zeta[3]) + 
          9*CF*(-1573 + 108*lm + 144*lm^2 + 96*Zeta[3])))/15120, 
      (CF*NC*(-2*(4*(-1 + 39*lm + 9*lm^2)*NM + (-197 + 156*lm + 36*lm^2)*
            NL + 2*(-67 + 78*lm + 18*lm^2)*NH) + 
         CA*(-1177 + 2220*lm + 396*lm^2 - 432*Zeta[3]) + 
         9*CF*(-1519 + 252*lm + 144*lm^2 + 96*Zeta[3])))/30240, 
      -(CF*NC*(-2*((223 + 924*lm + 180*lm^2)*NM + (-673 + 924*lm + 180*lm^2)*
             NL + 2*(-271 + 462*lm + 90*lm^2)*NH) + 
          9*CF*(-7091 + 1836*lm + 720*lm^2 + 480*Zeta[3]) + 
          CA*(12684*lm + 1980*lm^2 - 5*(289 + 432*Zeta[3]))))/272160, 
      (CF*NC*(-2*((487 + 1044*lm + 180*lm^2)*NM + 
           (-365 + 1044*lm + 180*lm^2)*NL + 6*(-77 + 174*lm + 30*lm^2)*
            NH) + CA*(2783 + 14004*lm + 1980*lm^2 - 2160*Zeta[3]) + 
         9*CF*(-6479 + 2316*lm + 720*lm^2 + 480*Zeta[3])))/453600, 
      -(CF*NC*(-2*((26633 + 40140*lm + 6300*lm^2)*NM + 
            5*(-467 + 8028*lm + 1260*lm^2)*NL + 18*(-809 + 2230*lm + 
              350*lm^2)*NH) + 5*CA*(47489 + 105948*lm + 13860*lm^2 - 
            15120*Zeta[3]) + 45*CF*(-40721 + 19092*lm + 5040*lm^2 + 
            3360*Zeta[3])))/24948000, 
      (CF*NC*(-36299*NM - 43290*lm*NM - 6300*lm^2*NM - 7700*NL - 
         43290*lm*NL - 6300*lm^2*NL + 13728*NH - 43290*lm*NH - 
         6300*lm^2*NH + 5*CA*(36988 + 56439*lm + 6930*lm^2 - 7560*Zeta[3]) + 
         90*CF*(-8987 + 5403*lm + 1260*lm^2 + 840*Zeta[3])))/18711000, 
      -(CF*NC*(-137587*NM - 138270*lm*NM - 18900*lm^2*NM - 51960*NL - 
          138270*lm*NL - 18900*lm^2*NL + 40097*NH - 138270*lm*NH - 
          18900*lm^2*NH + 15*CA*(49530 + 59519*lm + 6930*lm^2 - 
            7560*Zeta[3]) + 90*CF*(-23359 + 17889*lm + 3780*lm^2 + 
            2520*Zeta[3])))/81081000, 
      (CF*NC*(-331267*NM - 291660*lm*NM - 37800*lm^2*NM - 159228*NL - 
         291660*lm*NL - 37800*lm^2*NL + 79647*NH - 291660*lm*NH - 
         37800*lm^2*NH + 6*CA*(307169 + 311455*lm + 34650*lm^2 - 
           37800*Zeta[3]) + 36*CF*(-98906 + 97005*lm + 18900*lm^2 + 
           12600*Zeta[3])))/227026800, 
      -(CF*NC*(-29698958*NM - 23516220*lm*NM - 2910600*lm^2*NM - 
          16343796*NL - 23516220*lm*NL - 2910600*lm^2*NL + 6158017*NH - 
          23516220*lm*NH - 2910600*lm^2*NH + 42*CA*(4001769 + 3564605*lm + 
            381150*lm^2 - 415800*Zeta[3]) + 252*CF*(-893956 + 1142655*lm + 
            207900*lm^2 + 138600*Zeta[3])))/23837814000, 
      (CF*NC*(-67498965*NM - 48972840*lm*NM - 5821200*lm^2*NM - 
         40526332*NL - 48972840*lm*NL - 5821200*lm^2*NL + 12431861*NH - 
         48972840*lm*NH - 5821200*lm^2*NH + 14*CA*(27575219 + 22149930*lm + 
           2286900*lm^2 - 2494800*Zeta[3]) + 756*CF*(-469009 + 807970*lm + 
           138600*lm^2 + 92400*Zeta[3])))/63567504000, 
      -(CF*NC*(-979052828*NM - 659931720*lm*NM - 75675600*lm^2*NM - 
          624787996*NL - 659931720*lm*NL - 75675600*lm^2*NL + 
          163457281*NH - 659931720*lm*NH - 75675600*lm^2*NH + 
          14*CA*(402777707 + 297096690*lm + 29729700*lm^2 - 
            32432400*Zeta[3]) + 756*CF*(-4481177 + 11058010*lm + 
            1801800*lm^2 + 1201200*Zeta[3])))/1080647568000, 
      (CF*NC*(-1076939108*NM - 681553320*lm*NM - 75675600*lm^2*NM - 
         719063956*NL - 681553320*lm*NL - 75675600*lm^2*NL + 
         165359769*NH - 681553320*lm*NH - 75675600*lm^2*NH + 
         CA*(6233081278 + 4278272460*lm + 416215800*lm^2 - 
           454053600*Zeta[3]) + 108*CF*(-20310229 + 81009670*lm + 
           12612600*lm^2 + 8408400*Zeta[3])))/1389404016000, 
      -(CF*NC*(-3513886732*NM - 2105200440*lm*NM - 227026800*lm^2*NM - 
          2429813196*NL - 2105200440*lm*NL - 227026800*lm^2*NL + 
          501545243*NH - 2105200440*lm*NH - 227026800*lm^2*NH + 
          18*CA*(1133919601 + 731543890*lm + 69369300*lm^2 - 
            75675600*Zeta[3]) + 108*CF*(-28526819 + 253119090*lm + 
            37837800*lm^2 + 25225200*Zeta[3])))/5279735260800, 
      (CF*NC*(-2*(5*(757387081 + 432391428*lm + 45405360*lm^2)*NM + 
           3*((897654417 + 720652380*lm + 75675600*lm^2)*NL + 
             2*(-84430639 + 360326190*lm + 37837800*lm^2)*NH)) + 
         9*CA*(4901450349 + 2995544860*lm + 277477200*lm^2 - 
           302702400*Zeta[3]) + 54*CF*(12452269 + 1050314160*lm + 
           151351200*lm^2 + 100900800*Zeta[3])))/13199338152000, 
      -(CF*NC*(9*CA*(89315745653 + 52034171420*lm + 4717112400*lm^2 - 
            5145940800*Zeta[3]) + 2*(-((68859726007 + 37661378580*lm + 
               3859455600*lm^2)*NM) - 50104289547*NL - 37661378580*lm*NL - 
            3859455600*lm^2*NL + 8689308038*NH - 37661378580*lm*NH - 
            3859455600*lm^2*NH + 27*CF*(2312316893 + 18460745520*lm + 
              2572970400*lm^2 + 1715313600*Zeta[3]))))/277186101192000, 
      (CF*NC*(CA*(855875882297 + 477741767580*lm + 42454011600*lm^2 - 
           46313467200*Zeta[3]) + 
         2*(-((73191825797 + 38519035380*lm + 3859455600*lm^2)*NM) - 
           54288887167*NL - 38519035380*lm*NL - 3859455600*lm^2*NL + 
           8758505388*NH - 38519035380*lm*NH - 3859455600*lm^2*NH + 
           9*CF*(13090532519 + 57097550160*lm + 7718911200*lm^2 + 
             5145940800*Zeta[3]))))/338783012568000, 
      -(CF*NC*(11*CA*(17217125298803 + 9246909630420*lm + 806626220400*lm^2 - 
            879955876800*Zeta[3]) + 2*(-9*(1797028788787 + 913366048980*lm + 
              89625135600*lm^2)*NM - 12193796196263*NL - 8220294440820*lm*
             NL - 806626220400*lm^2*NL + 1843403267312*NH - 
            8220294440820*lm*NH - 806626220400*lm^2*NH + 
            99*CF*(362915218181 + 1115729097840*lm + 146659312800*lm^2 + 
              97772875200*Zeta[3]))))/85712102179704000, 
      (CF*NC*(-2*(12*(283701679769 + 139693661415*lm + 13443770340*lm^2)*
            NM + 11*(236651375279 + 152393085180*lm + 14665931280*lm^2)*
            NL + (-370971199967 + 1676323936980*lm + 161325244080*lm^2)*
            NH) + 11*CA*(3628363252369 + 1881646974900*lm + 
           161325244080*lm^2 - 175991175360*Zeta[3]) + 
         198*CF*(94897625593 + 229012192080*lm + 29331862560*lm^2 + 
           19554575040*Zeta[3])))/20570904523128960, 
      -(CF*NC*(-2*(15*(237938450723 + 113803503660*lm + 10755016272*lm^2)*
             NM + 11*(251165002439 + 155186595900*lm + 14665931280*lm^2)*
             NL + 3*(-124337010557 + 569017518300*lm + 53775081360*lm^2)*
             NH) + 11*CA*(3807567726169 + 1912375592820*lm + 
            161325244080*lm^2 - 175991175360*Zeta[3]) + 
          198*CF*(116708310553 + 234599213520*lm + 29331862560*lm^2 + 
            19554575040*Zeta[3])))/24489172051344000, 
      (CF*NC*(-2*((3728945569577 + 1736384417460*lm + 161325244080*lm^2)*
            NM + (2918001622729 + 1736384417460*lm + 161325244080*lm^2)*
            NL + (-374831953403 + 1736384417460*lm + 161325244080*lm^2)*
            NH) + 11*CA*(3981420052789 + 1941707455380*lm + 
           161325244080*lm^2 - 175991175360*Zeta[3]) + 
         18*CF*(1518390629603 + 2639255073840*lm + 322650488160*lm^2 + 
           215100325440*Zeta[3])))/28941748787952000, 
      -(CF*NC*(143*CA*(95456076124907 + 45304572450060*lm + 
            3710480613840*lm^2 - 4047797033280*Zeta[3]) + 
          2*(-((1161412458650707 + 527567853512700*lm + 48236247979920*lm^2)*
              NM) - 917628480049931*NL - 527567853512700*lm*NL - 
            48236247979920*lm^2*NL + 112562268492281*NH - 
            527567853512700*lm*NH - 48236247979920*lm^2*NH + 
            117*CF*(40201494628549 + 61993468650960*lm + 7420961227680*lm^2 + 
              4947307485120*Zeta[3]))))/10158553824571152000, 
      (CF*NC*(-2*((603303983044351 + 267803614088010*lm + 24118123989960*
              lm^2)*NM + 26*(18492162843128 + 10300139003385*lm + 
             927620153460*lm^2)*NL + 5*(-11300027033303 + 53560722817602*
              lm + 4823624797992*lm^2)*NH) + 286*CA*(24807864290603 + 
           11480746471425*lm + 927620153460*lm^2 - 1011949258320*Zeta[3]) + 
         117*CF*(45367617016129 + 63230295522240*lm + 7420961227680*lm^2 + 
           4947307485120*Zeta[3])))/5925823064333172000, 
      -(CF*NC*(-6253075355922487*NM - 2716625139264036*lm*NM - 
          241181239899600*lm^2*NM - 5022205230483688*NL - 
          2716625139264036*lm*NL - 241181239899600*lm^2*NL + 
          566975774353543*NH - 2716625139264036*lm*NH - 
          241181239899600*lm^2*NH + 286*CA*(128631620041585 + 
            58145828479893*lm + 4638100767300*lm^2 - 5059746291600*Zeta[3]) + 
          117*CF*(252130203289541 + 322088246593344*lm + 37104806138400*
             lm^2 + 24736537425600*Zeta[3])))/34369773773132397600}, 0, 29, 1]
 
CbarSeries["s", 2, 0, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 391*Pi^4 + 
            20*Pi^2*(-73 + 96*Log[2]^2) + 15*(869 + 936*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 144*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              128*Log[2]^4 - 156*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
              2712*Zeta[3]) - 10*lm*(-1233 + 44*Pi^2 + 648*Zeta[3])) + 
          2*(CF*(5670*lm^2 - 3240*lm^3 + 981*Pi^4 + 10*Pi^2*(259 + 
                576*Log[2]^2) + 15*(1025 + 2808*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 432*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                384*Log[2]^4 - 468*PolyGamma[2, 1] - 9216*PolyLog[4, 1/2] - 
                10464*Zeta[3]) + 135*lm*(95 + 8*Pi^2 - 144*Zeta[3])) - 
            15*(NL*(-219 - 162*lm - 84*lm^2 - 24*lm^3 + 28*Pi^2 + 
                8*lm*Pi^2 - 288*Zeta[3]) + NM*(-219 - 84*lm^2 - 24*lm^3 + 
                28*Pi^2 + 2*lm*(-81 + 4*Pi^2) + 8*PolyGamma[2, 1] - 
                272*Zeta[3]) - NH*(-837 + 162*lm + 84*lm^2 + 24*lm^3 - 
                8*lm*Pi^2 - 1296*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                216*PolyGamma[2, 1] + 2928*Zeta[3])))))/25920, 
      (CF*NC*(2*(-(CF*(3240*lm^2 + 1530*Pi^2 + 7*Pi^4 + 180*lm*(27 + 
                4*Pi^2) + 15*(281 + 1440*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                720*Im[PolyLog[2, (-1)^(1/3)]]^2 - 240*PolyGamma[2, 1] - 
                3048*Zeta[3]))) + 10*(NH*(1905 + 180*lm + 36*lm^2 + 8*lm*
                Pi^2 - 1728*Zeta[3]) + NL*(273 + 180*lm + 36*lm^2 + 16*
                Pi^2 + 8*lm*Pi^2 - 96*Zeta[3]) + NM*(273 + 36*lm^2 + 16*
                Pi^2 + 4*lm*(45 + 2*Pi^2) + 8*PolyGamma[2, 1] - 80*
                Zeta[3]))) + 5*CA*(-792*lm^2 - 614*Pi^2 + 27*Pi^4 - 
           8*lm*(621 + 22*Pi^2) + 12*(-693 + 360*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 180*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             60*PolyGamma[2, 1] - 586*Zeta[3]))))/8640, 
      (CF*NC*(2*(CF*(-6480*lm^2 - 1970*Pi^2 + 13*Pi^4 - 
             360*lm*(21 + 2*Pi^2) - 360*(32 + 132*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 54*Im[PolyLog[2, (-1)^(1/3)]]^2 - 26*
                PolyGamma[2, 1] - 297*Zeta[3])) + 
           20*(NH*(36*lm^2 + 4*lm*(42 + Pi^2) + 3*(537 + 216*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] - 48*PolyGamma[2, 1] - 
                 896*Zeta[3])) + NL*(231 + 36*lm^2 + 10*Pi^2 + 4*lm*
                (42 + Pi^2) - 48*Zeta[3]) + NM*(771 + 36*lm^2 - 26*Pi^2 + 4*
                lm*(42 + Pi^2) + 16*PolyGamma[2, 1] - 16*Zeta[3]))) + 
         5*CA*(-1584*lm^2 - 630*Pi^2 + 23*Pi^4 - 16*lm*(588 + 11*Pi^2) + 
           6*(-2445 + 1584*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             648*Im[PolyLog[2, (-1)^(1/3)]]^2 - 312*PolyGamma[2, 1] - 
             2972*Zeta[3]))))/8640, 
      -(CF*NC*(-2880*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
            4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          11520*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          3*CA*(-11880*lm^2 - 4090*Pi^2 + 1050*Sqrt[3]*Pi^3 + 203*Pi^4 - 
            40*lm*(1731 + 22*Pi^2) + 810*Sqrt[3]*Pi*Log[3]^2 + 
            120*(-920 + 522*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              306*Im[PolyLog[2, (-1)^(1/3)]]^2 + 324*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 90*PolyGamma[2, 1] - 
              1235*Zeta[3])) - 120*Log[x]*(-3*CA*(608*lm + 132*lm^2 + 
              3*(241 - 9*Pi^2 + 36*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                96*Zeta[3])) + 2*(135*NL + 120*lm*NL + 36*lm^2*NL - 
              889*NH + 120*lm*NH + 36*lm^2*NH - 12*NL*Pi^2 + 
              3*NM*(189 + 40*lm + 12*lm^2 - 4*Pi^2) + 432*Sqrt[3]*NH*Im[
                PolyLog[2, (-1)^(1/3)]] - 3*CF*(60 - 18*lm + 108*lm^2 + 
                29*Pi^2 - 108*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                288*Zeta[3]))) + 5*(9*CF*(1735 + 1296*lm^2 + 224*Pi^2 + 
              140*Sqrt[3]*Pi^3 + 10*Pi^4 + 24*lm*(57 + 4*Pi^2) + 
              8352*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              4896*Im[PolyLog[2, (-1)^(1/3)]]^2 + 5184*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 108*Sqrt[3]*Pi*Log[3]^
                2 - 1440*PolyGamma[2, 1] - 23184*Zeta[3]) - 
            4*(NH*(31177 + 1476*lm + 324*lm^2 + 24*lm*Pi^2 - 420*Sqrt[3]*
                 Pi^3 + 1728*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                15552*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                324*Sqrt[3]*Pi*Log[3]^2 - 504*PolyGamma[2, 1] - 
                17136*Zeta[3]) + 3*NL*(723 + 492*lm + 108*lm^2 + 8*lm*Pi^2 - 
                384*Zeta[3]) + 3*NM*(1443 + 108*lm^2 + lm*(492 + 8*Pi^2) + 
                32*PolyGamma[2, 1] + 1408*Zeta[3])))))/25920, 
      -(CF*NC*(299475*CF + 174960*CF*lm + 155520*CF*lm^2 - 54600*NM - 
          79920*lm*NM - 17280*lm^2*NM - 115560*NL - 79920*lm*NL - 
          17280*lm^2*NL - 1746600*NH - 79920*lm*NH - 17280*lm^2*NH + 
          8040*CF*Pi^2 + 8640*CF*lm*Pi^2 + 1920*NM*Pi^2 - 960*lm*NM*Pi^2 + 
          1920*NL*Pi^2 - 960*lm*NL*Pi^2 - 960*lm*NH*Pi^2 + 
          20300*Sqrt[3]*CF*Pi^3 + 25200*Sqrt[3]*NH*Pi^3 + 1956*CF*Pi^4 + 
          1207440*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          311040*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          648000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 751680*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 933120*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 15660*Sqrt[3]*CF*Pi*
           Log[3]^2 + 19440*Sqrt[3]*NH*Pi*Log[3]^2 - 
          8640*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
            4*(3*(2 + lm)*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          34560*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          224640*CF*PolyGamma[2, 1] + 13440*NM*PolyGamma[2, 1] + 
          86400*NH*PolyGamma[2, 1] - 2*CA*(-47520*lm^2 - 15375*Pi^2 + 
            5075*Sqrt[3]*Pi^3 + 873*Pi^4 - 60*lm*(4671 + 44*Pi^2) + 
            3915*Sqrt[3]*Pi*Log[3]^2 + 90*(-4883 + 3354*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 1800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              2088*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              624*PolyGamma[2, 1] - 8340*Zeta[3])) - 3435840*CF*Zeta[3] - 
          324480*NM*Zeta[3] + 63360*NL*Zeta[3] + 1336320*NH*Zeta[3] - 
          360*Log[x]*(CA*(-2205 - 1824*lm - 396*lm^2 + 47*Pi^2 - 
              348*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 864*Zeta[3]) + 
            2*(135*NL + 120*lm*NL + 36*lm^2*NL - 889*NH + 120*lm*NH + 
              36*lm^2*NH - 12*NL*Pi^2 + NM*(803 + 120*lm + 36*lm^2 - 
                36*Pi^2) + 432*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
              3*CF*(25 - 18*lm + 108*lm^2 + 15*Pi^2 - 116*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3])))))/51840, 
      -(CF*NC*(-86400*(540*CF*(-1 + 7*lm) + 35*CA*(155 + 66*lm) - 
            2*(10*(65 + 21*lm)*NM + 5*(67 + 42*lm)*NL + 6*(4 + 35*lm)*NH))*
           Log[x]^2 + 1728000*(83*CA + 282*CF - 20*NM - 14*NL)*Log[x]^3 - 
          75*CA*(-237600*lm^2 - 75600*Pi^2 + 51100*Sqrt[3]*Pi^3 + 5844*Pi^4 - 
            960*lm*(1470 + 11*Pi^2) + 39420*Sqrt[3]*Pi*Log[3]^2 + 
            45*(-59099 + 32400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              21312*Im[PolyLog[2, (-1)^(1/3)]]^2 + 42048*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 4800*PolyGamma[2, 1] - 
              92704*Zeta[3])) - 360*Log[x]*
           (-8*(-75*NL*(93 + 120*lm + 36*lm^2 - 16*Pi^2) - 75*NM*(831 + 
                120*lm + 36*lm^2 - 16*Pi^2) - NH*(-89219 + 9000*lm + 
                2700*lm^2 + 45600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
            450*CF*(459 - 72*lm + 432*lm^2 + 54*Pi^2 - 584*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 1152*Zeta[3]) + 
            225*CA*(-2593 - 2432*lm - 528*lm^2 + 62*Pi^2 - 584*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 1152*Zeta[3])) + 
          2*(75*CF*(194400*lm^2 - 3864*Pi^2 + 51100*Sqrt[3]*Pi^3 + 
              4308*Pi^4 + 2160*lm*(105 + 4*Pi^2) + 39420*Sqrt[3]*Pi*Log[3]^
                2 + 135*(-327 + 10800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                7104*Im[PolyLog[2, (-1)^(1/3)]]^2 + 14016*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1600*PolyGamma[2, 
                  1] - 34976*Zeta[3])) - 8*(NH*(32731059 + 202500*lm^2 - 
                665000*Sqrt[3]*Pi^3 + 9000*lm*(105 + Pi^2) + 2592000*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 24624000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 513000*Sqrt[3]*Pi*
                 Log[3]^2 - 756000*PolyGamma[2, 1] - 12312000*Zeta[3]) + 
              1125*NL*(1653 + 180*lm^2 - 56*Pi^2 + 8*lm*(105 + Pi^2) - 
                1248*Zeta[3]) + 1125*NM*(123 + 180*lm^2 - 128*Pi^2 + 
                8*lm*(105 + Pi^2) - 88*PolyGamma[2, 1] + 7216*Zeta[3])))))/
       7776000, -(CF*NC*(-172800*(15*CA*(753 + 319*lm) + 
            5*CF*(-217 + 1566*lm) - 2858*NM - 870*lm*NM - 1365*NL - 
            870*lm*NL - 108*NH - 870*lm*NH)*Log[x]^2 + 
          1728000*(319*CA + 1270*CF - 80*NM - 58*NL)*Log[x]^3 - 
          25*CA*(-2566080*lm^2 - 1202040*Pi^2 + 647500*Sqrt[3]*Pi^3 + 
            73764*Pi^4 - 1440*lm*(10661 + 66*Pi^2) + 499500*Sqrt[3]*Pi*
             Log[3]^2 + 45*(-504781 + 409936*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 254016*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              532800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              67392*PolyGamma[2, 1] - 1288608*Zeta[3])) - 
          360*Log[x]*(75*CA*(-36671 - 29360*lm - 6336*lm^2 + 1006*Pi^2 - 
              7400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 13824*Zeta[3]) + 
            2*(-8*(-2*NM*(69338 + 9075*lm + 2700*lm^2 - 2325*Pi^2) - 
                75*NL*(169 + 242*lm + 72*lm^2 - 34*Pi^2) - 2*NH*
                 (-92062 + 9075*lm + 2700*lm^2 + 47100*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) - 75*CF*(-199 - 720*lm + 
                5184*lm^2 + 814*Pi^2 - 7400*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 13824*Zeta[3]))) + 
          2*(25*CF*(2099520*lm^2 - 573912*Pi^2 + 647500*Sqrt[3]*Pi^3 + 
              59940*Pi^4 + 25920*lm*(98 + 3*Pi^2) + 499500*Sqrt[3]*Pi*Log[3]^
                2 + 15*(449321 + 1229808*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                762048*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1598400*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 202176*PolyGamma[2, 
                  1] - 4304736*Zeta[3])) - 16*(NH*(364500*lm^2 - 
                1373750*Sqrt[3]*Pi^3 + 2250*lm*(763 + 6*Pi^2) - 
                1059750*Sqrt[3]*Pi*Log[3]^2 + 9*(7115421 + 997000*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]] - 5652000*Sqrt[3]*
                   Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 294000*PolyGamma[
                    2, 1] - 3312000*Zeta[3])) + 2250*NL*(1619 + 162*lm^2 - 
                67*Pi^2 + lm*(763 + 6*Pi^2) - 1296*Zeta[3]) + 
              3*NM*(-1099987 + 121500*lm^2 - 111750*Pi^2 + 750*lm*
                 (763 + 6*Pi^2) - 270000*PolyGamma[2, 1] + 5724000*
                 Zeta[3])))))/23328000, (-455843*CF^2*NC)/31104 - 
       (469*CF^2*lm*NC)/72 - (21*CF^2*lm^2*NC)/4 + (5425*CF*NM*NC)/3888 + 
       (224*CF*lm*NM*NC)/81 + (7*CF*lm^2*NM*NC)/12 + 
       (10393*CF*NC*NL)/1296 + (224*CF*lm*NC*NL)/81 + 
       (7*CF*lm^2*NC*NL)/12 + (7998655981*CF*NC*NH)/55566000 + 
       (224*CF*lm*NC*NH)/81 + (7*CF*lm^2*NC*NH)/12 + 
       (7633*CF^2*NC*Pi^2)/3240 - (CF^2*lm*NC*Pi^2)/6 - 
       (118*CF*NM*NC*Pi^2)/81 + (CF*lm*NM*NC*Pi^2)/54 - 
       (55*CF*NC*NL*Pi^2)/162 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (56245*CF^2*NC*Pi^3)/(7776*Sqrt[3]) - 
       (31255*CF*NC*NH*Pi^3)/(2916*Sqrt[3]) - (859*CF^2*NC*Pi^4)/4320 - 
       (29369*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(216*Sqrt[3]) + 
       (376*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(9*Sqrt[3]) - 
       (65*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (1607*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6*Sqrt[3]) - 
       (3572*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9*Sqrt[3]) - 
       (1607*CF^2*NC*Pi*Log[3]^2)/(288*Sqrt[3]) - (893*CF*NC*NH*Pi*Log[3]^2)/
        (108*Sqrt[3]) + (CF*NC*(105*CA*(1282 + 539*lm) + 
          35*CF*(-401 + 2646*lm) - 41860*NM - 10290*lm*NM - 15645*NL - 
          10290*lm*NL - 1926*NH - 10290*lm*NH)*Log[x]^2)/945 - 
       (2*CF*NC*(565*CA + 2382*CF - 268*NM - 98*NL)*Log[x]^3)/27 + 
       (35*CF^2*NC*PolyGamma[2, 1])/6 - (32*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (209*CF*NC*NH*PolyGamma[2, 1])/54 + 
       (CA*CF*NC*(-2993760*lm^2 - 1703376*Pi^2 + 1124900*Sqrt[3]*Pi^3 + 
          106596*Pi^4 - 2880*lm*(6251 + 33*Pi^2) + 867780*Sqrt[3]*Pi*
           Log[3]^2 + 15*(-1899881 + 1409712*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 1010880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            2776896*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
            181440*PolyGamma[2, 1] - 5119776*Zeta[3])))/933120 + 
       (19673*CF^2*NC*Zeta[3])/108 + (1028*CF*NM*NC*Zeta[3])/27 - 
       (64*CF*NC*NL*Zeta[3])/9 - (343*CF*NC*NH*Zeta[3])/9 - 
       (CF*NC*Log[x]*(-3675*CA*(-52005 - 44128*lm - 9504*lm^2 + 1626*Pi^2 - 
            12856*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 20736*Zeta[3]) + 
          2*(-8*(3675*NL*(143 + 364*lm + 108*lm^2 - 62*Pi^2) + 
              2450*NM*(3616 + 546*lm + 162*lm^2 + 93*Pi^2) + 
              2*NH*(-8359013 + 668850*lm + 198450*lm^2 + 4375700*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 1225*CF*(9017 - 3024*lm + 
              23328*lm^2 + 3918*Pi^2 - 38568*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 62208*Zeta[3]))))/3175200, 
      (-3113675*CF^2*NC)/62208 - (2191*CF^2*lm*NC)/288 - 6*CF^2*lm^2*NC - 
       (74597729*CF*NM*NC)/83349000 + (8239*CF*lm*NM*NC)/2592 + 
       (2*CF*lm^2*NM*NC)/3 + (53483*CF*NC*NL)/5184 + 
       (8239*CF*lm*NC*NL)/2592 + (2*CF*lm^2*NC*NL)/3 + 
       (2667462601*CF*NC*NH)/14817600 + (8239*CF*lm*NC*NH)/2592 + 
       (2*CF*lm^2*NC*NH)/3 + (196307*CF^2*NC*Pi^2)/51840 - 
       (CF^2*lm*NC*Pi^2)/6 - (166*CF*NM*NC*Pi^2)/81 + 
       (CF*lm*NM*NC*Pi^2)/54 - (295*CF*NC*NL*Pi^2)/648 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (1318625*CF^2*NC*Pi^3)/(139968*Sqrt[3]) - (81515*CF*NC*NH*Pi^3)/
        (5832*Sqrt[3]) - (1163*CF^2*NC*Pi^4)/4320 - 
       (459233*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(2592*Sqrt[3]) + 
       (217*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(3*Sqrt[3]) - 
       (81*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (37675*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(108*Sqrt[3]) - 
       (4658*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9*Sqrt[3]) - 
       (37675*CF^2*NC*Pi*Log[3]^2)/(5184*Sqrt[3]) - 
       (2329*CF*NC*NH*Pi*Log[3]^2)/(216*Sqrt[3]) + 
       (CF*NC*(70*CA*(20923 + 8448*lm) + 35*CF*(-6959 + 27648*lm) - 
          4*((113123 + 26880*lm)*NM + 30*(1337*NL + 896*lm*NL + 180*NH + 
              896*lm*NH)))*Log[x]^2)/7560 - 
       (CF*NC*(1277*CA + 8*(870*CF - 91*NM - 32*NL))*Log[x]^3)/27 + 
       (26*CF^2*NC*PolyGamma[2, 1])/3 - (77*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (187*CF*NC*NH*PolyGamma[2, 1])/27 + (18941*CF^2*NC*Zeta[3])/72 + 
       (1289*CF*NM*NC*Zeta[3])/27 - (85*CF*NC*NL*Zeta[3])/9 - 
       (500*CF*NC*NH*Zeta[3])/9 + (CA*CF*NC*(-30792960*lm^2 - 
          20973411*Pi^2 + 13186250*Sqrt[3]*Pi^3 + 1254852*Pi^4 - 
          1620*lm*(114821 + 528*Pi^2) + 10172250*Sqrt[3]*Pi*Log[3]^2 + 
          540*(459233*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            314928*Im[PolyLog[2, (-1)^(1/3)]]^2 + 904200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
            9*(34643 + 7488*PolyGamma[2, 1] + 207804*Zeta[3]))))/8398080 + 
       (CF*NC*Log[x]*(1225*CA*(-1488627 - 998424*lm - 213840*lm^2 + 
            66186*Pi^2 - 301400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            466560*Zeta[3]) + 2*(24*(NM*(22618762 + 3369975*lm + 
                992250*lm^2 + 477750*Pi^2) + 5*(735*NL*(260 + 917*lm + 
                  270*lm^2 - 166*Pi^2) + NH*(-8705689 + 673995*lm + 
                  198450*lm^2 + 4564840*Sqrt[3]*Im[PolyLog[2, (-1)^
                      (1/3)]]))) - 1225*CF*(-250395 - 18144*lm + 
              174960*lm^2 + 56106*Pi^2 - 301400*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 466560*Zeta[3]))))/19051200, 
      (-128759*CF^2*NC)/1944 - (1253*CF^2*lm*NC)/144 - (27*CF^2*lm^2*NC)/4 + 
       (23677871*CF*NM*NC)/1944000 + (4655*CF*lm*NM*NC)/1296 + 
       (3*CF*lm^2*NM*NC)/4 + (9895*CF*NC*NL)/648 + (4655*CF*lm*NC*NL)/
        1296 + (3*CF*lm^2*NC*NL)/4 + (226308972161*CF*NC*NH)/857304000 + 
       (4655*CF*lm*NC*NH)/1296 + (3*CF*lm^2*NC*NH)/4 + 
       (131645*CF^2*NC*Pi^2)/24192 - (CF^2*lm*NC*Pi^2)/6 - 
       (323*CF*NM*NC*Pi^2)/162 + (CF*lm*NM*NC*Pi^2)/54 - 
       (203*CF*NC*NL*Pi^2)/324 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (1954085*CF^2*NC*Pi^3)/(139968*Sqrt[3]) - 
       (145880*CF*NC*NH*Pi^3)/(6561*Sqrt[3]) - (35*CF^2*NC*Pi^4)/96 - 
       (1526783*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(7776*Sqrt[3]) + 
       (64328*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(729*Sqrt[3]) - 
       (101*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (55831*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(108*Sqrt[3]) - 
       (66688*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) - 
       (55831*CF^2*NC*Pi*Log[3]^2)/(5184*Sqrt[3]) - 
       (4168*CF*NC*NH*Pi*Log[3]^2)/(243*Sqrt[3]) + 
       (CF*NC*(270*CF*(-827 + 3008*lm) + 5*CA*(248209 + 99264*lm) - 
          16*((20099 + 5640*lm)*NM + 60*(137 + 94*lm)*NL + 
            (1369 + 5640*lm)*NH))*Log[x]^2)/4320 - 
       (CF*NC*(3873*CA + 22322*CF - 4048*NM - 752*NL)*Log[x]^3)/54 + 
       (15*CF^2*NC*PolyGamma[2, 1])/2 - (175*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (208*CF*NC*NH*PolyGamma[2, 1])/27 + 
       (CA*CF*NC*(-34642080*lm^2 - 27500229*Pi^2 + 19540850*Sqrt[3]*Pi^3 + 
          1655316*Pi^4 - 3240*lm*(64813 + 264*Pi^2) + 15074370*Sqrt[3]*Pi*
           Log[3]^2 + 180*(-895587 + 1526783*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 1178064*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            4019832*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
            174960*PolyGamma[2, 1] - 7208460*Zeta[3])))/8398080 + 
       (72697*CF^2*NC*Zeta[3])/216 + (1511*CF*NM*NC*Zeta[3])/27 - 
       (130*CF*NC*NL*Zeta[3])/9 - (148*CF*NC*NH*Zeta[3])/3 - 
       (CF*NC*Log[x]*(-525*CA*(-3975459 - 2667744*lm - 570240*lm^2 + 
            194724*Pi^2 - 893296*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            1244160*Zeta[3]) + 2*(-8*(18900*NL*(2 + 613*lm + 180*lm^2 - 
                128*Pi^2) + 63*NM*(633821 + 183900*lm + 54000*lm^2 + 
                186000*Pi^2) + NH*(-175716477 + 11585700*lm + 3402000*lm^2 + 
                93363200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            525*CF*(-664047 - 44064*lm + 466560*lm^2 + 165924*Pi^2 - 
              893296*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1244160*Zeta[3]))))/
        16329600, (-9925907989*CF^2*NC)/87480000 - (35303*CF^2*lm*NC)/3600 - 
       (15*CF^2*lm^2*NC)/2 + (5902322093*CF*NM*NC)/400075200 + 
       (129803*CF*lm*NM*NC)/32400 + (5*CF*lm^2*NM*NC)/6 + 
       (1245421*CF*NC*NL)/64800 + (129803*CF*lm*NC*NL)/32400 + 
       (5*CF*lm^2*NC*NL)/6 + (128271233501*CF*NC*NH)/400075200 + 
       (129803*CF*lm*NC*NH)/32400 + (5*CF*lm^2*NC*NH)/6 + 
       (891487*CF^2*NC*Pi^2)/362880 - (CF^2*lm*NC*Pi^2)/6 - 
       (3563*CF*NM*NC*Pi^2)/1620 + (CF*lm*NM*NC*Pi^2)/54 - 
       (316*CF*NC*NL*Pi^2)/405 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (7266091*CF^2*NC*Pi^3)/(419904*Sqrt[3]) - 
       (122045*CF*NC*NH*Pi^3)/(4374*Sqrt[3]) - (1987*CF^2*NC*Pi^4)/4320 - 
       (426249803*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(1749600*Sqrt[3]) + 
       (32009*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(243*Sqrt[3]) - 
       (121*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (1038013*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1620*Sqrt[3]) - (27896*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27*Sqrt[3]) - 
       (1038013*CF^2*NC*Pi*Log[3]^2)/(77760*Sqrt[3]) - 
       (3487*CF*NC*NH*Pi*Log[3]^2)/(162*Sqrt[3]) + 
       (CF*NC*(21*CA*(2903787 + 1038400*lm) + 
          2*(7*CF*(-1579457 + 2548800*lm) - 40*((168821 + 49560*lm)*NM + 
              420*(169 + 118*lm)*NL + 3*(4247 + 16520*lm)*NH)))*Log[x]^2)/
        151200 - (CF*NC*(17293*CA + 161570*CF - 27440*NM - 4720*NL)*
         Log[x]^3)/270 + (65*CF^2*NC*PolyGamma[2, 1])/6 - 
       (158*CF*NM*NC*PolyGamma[2, 1])/27 - (322*CF*NC*NH*PolyGamma[2, 1])/
        27 + (CA*CF*NC*(-577368000*lm^2 - 215678295*Pi^2 + 
          363304550*Sqrt[3]*Pi^3 + 30836700*Pi^4 - 
          1944*lm*(1805833 + 6600*Pi^2) + 280263510*Sqrt[3]*Pi*Log[3]^2 + 
          12*(-40978227 + 426249803*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            317552400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1121054040*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 56862000*
             PolyGamma[2, 1] - 2308543740*Zeta[3])))/125971200 + 
       (512329*CF^2*NC*Zeta[3])/1080 + (1694*CF*NM*NC*Zeta[3])/27 - 
       (166*CF*NC*NL*Zeta[3])/9 - (608*CF*NC*NH*Zeta[3])/9 - 
       (CF*NC*Log[x]*(-49*CA*(-2366391117 - 1205949600*lm - 256608000*lm^2 + 
            169044300*Pi^2 - 415205200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            559872000*Zeta[3]) + 2*(-120*(4410*NL*(-923 + 7402*lm + 
                2160*lm^2 - 1640*Pi^2) + NM*(90975009 + 32642820*lm + 
                9525600*lm^2 + 37396800*Pi^2) + NH*(-513600357 + 
                32642820*lm + 9525600*lm^2 + 273380800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 49*CF*(-876992889 - 
              15357600*lm + 209952000*lm^2 + 153060300*Pi^2 - 
              415205200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 559872000*Zeta[
                3]))))/571536000, (-100368711811*CF^2*NC)/699840000 - 
       (39281*CF^2*lm*NC)/3600 - (33*CF^2*lm^2*NC)/4 - 
       (335719973*CF*NM*NC)/133358400 + (143231*CF*lm*NM*NC)/32400 + 
       (11*CF*lm^2*NM*NC)/12 + (191711*CF*NC*NL)/7200 + 
       (143231*CF*lm*NC*NL)/32400 + (11*CF*lm^2*NC*NL)/12 + 
       (299838866747759*CF*NC*NH)/684642974400 + (143231*CF*lm*NC*NH)/
        32400 + (11*CF*lm^2*NC*NH)/12 + (543083*CF^2*NC*Pi^2)/362880 - 
       (CF^2*lm*NC*Pi^2)/6 + (4231*CF*NM*NC*Pi^2)/405 + 
       (CF*lm*NM*NC*Pi^2)/54 - (1603*CF*NC*NL*Pi^2)/1620 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (9853375*CF^2*NC*Pi^3)/(419904*Sqrt[3]) - (3161095*CF*NC*NH*Pi^3)/
        (78732*Sqrt[3]) - (2507*CF^2*NC*Pi^4)/4320 - 
       (92272583*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(349920*Sqrt[3]) + 
       (1070818*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) - 
       (145*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (281525*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(324*Sqrt[3]) - 
       (361268*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (243*Sqrt[3]) - (281525*CF^2*NC*Pi*Log[3]^2)/(15552*Sqrt[3]) - 
       (90317*CF*NC*NH*Pi*Log[3]^2)/(2916*Sqrt[3]) + 
       (CF*NC*(385*CA*(2415409 + 844800*lm) + 154*CF*(-2393617 + 
            3456000*lm) - 80*(11*(-80887 + 67200*lm)*NM + 
            7*(3300*(45 + 32*lm)*NL + (30367 + 105600*lm)*NH)))*Log[x]^2)/
        1663200 - (CF*NC*(23319*CA + 236794*CF - 80*(883*NM + 80*NL))*
         Log[x]^3)/270 + (55*CF^2*NC*PolyGamma[2, 1])/6 - 
       (182*CF*NM*NC*PolyGamma[2, 1])/27 - (725*CF*NC*NH*PolyGamma[2, 1])/
        54 + (CA*CF*NC*(-111143340000*lm^2 - 25547288625*Pi^2 + 
          86217031250*Sqrt[3]*Pi^3 + 6723202500*Pi^4 - 
          3742200*lm*(181031 + 600*Pi^2) + 66510281250*Sqrt[3]*Pi*Log[3]^2 + 
          84*(714176931 + 11534072875*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            9513450000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 38005875000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1202850000*
             PolyGamma[2, 1] - 72729535500*Zeta[3])))/22044960000 + 
       (643477*CF^2*NC*Zeta[3])/1080 + (728*CF*NM*NC*Zeta[3])/27 - 
       (232*CF*NC*NL*Zeta[3])/9 - (511*CF*NC*NH*Zeta[3])/9 + 
       (CF*NC*Log[x]*(17787*CA*(-3075388293 - 1509991200*lm - 
            320760000*lm^2 + 239319900*Pi^2 - 563050000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 699840000*Zeta[3]) + 
          2*(40*(6534*NM*(-30621179 + 6816390*lm + 1984500*lm^2 + 
                21182700*Pi^2) - 7*(343035*NL*(7219 - 18548*lm - 5400*lm^2 + 
                  4600*Pi^2) - 2*NH*(-56993941803 + 3181306590*lm + 
                  926194500*lm^2 + 30599399600*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]]))) - 17787*CF*(-1211956527 - 17107200*lm + 
              262440000*lm^2 + 218151900*Pi^2 - 563050000*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 699840000*Zeta[3]))))/207467568000, 
      (-33640376348657*CF^2*NC)/288054144000 - (4809*CF^2*lm*NC)/400 - 
       9*CF^2*lm^2*NC - (51130442724937*CF*NM*NC)/3423214872000 + 
       (5803*CF*lm*NM*NC)/1200 + CF*lm^2*NM*NC + (2547191*CF*NC*NL)/
        77760 + (5803*CF*lm*NC*NL)/1200 + CF*lm^2*NC*NL + 
       (37407496575787441*CF*NC*NH)/71887512312000 + 
       (5803*CF*lm*NC*NH)/1200 + CF*lm^2*NC*NH - (18114149*CF^2*NC*Pi^2)/
        604800 - (CF^2*lm*NC*Pi^2)/6 + (28189*CF*NM*NC*Pi^2)/1620 + 
       (CF*lm*NM*NC*Pi^2)/54 - (1913*CF*NC*NL*Pi^2)/1620 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (35409647*CF^2*NC*Pi^3)/(1259712*Sqrt[3]) - (23130695*CF*NC*NH*Pi^3)/
        (472392*Sqrt[3]) - (1009*CF^2*NC*Pi^4)/1440 - 
       (1659797981*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(5248800*Sqrt[3]) + 
       (4396981*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) - 
       (169*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (5058521*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4860*Sqrt[3]) - (1321754*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (5058521*CF^2*NC*Pi*Log[3]^2)/(233280*Sqrt[3]) - 
       (660877*CF*NC*NH*Pi*Log[3]^2)/(17496*Sqrt[3]) + 
       (CF*NC*(3267*CA*(1363307 + 364000*lm) + 66*CF*(-51961547 + 
            29484000*lm) - 320*(7*(-244034 + 96525*lm)*NM + 
            51975*(18 + 13*lm)*NL + (203551 + 675675*lm)*NH))*Log[x]^2)/
        4989600 - (CF*NC*(442*CA + 178557*CF - 300*(160*NM + 13*NL))*
         Log[x]^3)/135 + 13*CF^2*NC*PolyGamma[2, 1] - 
       (283*CF*NM*NC*PolyGamma[2, 1])/27 - 19*CF*NC*NH*PolyGamma[2, 1] + 
       CA*CF*NC*(-14598502654943/720135360000 - (11*lm^2)/2 + 
         (5909933*Pi^2)/403200 + (35409647*Pi^3)/(2519424*Sqrt[3]) + 
         (631*Pi^4)/1728 - (lm*(725697 + 2200*Pi^2))/21600 + 
         (1659797981*Im[PolyLog[2, (-1)^(1/3)]])/(10497600*Sqrt[3]) + 
         (169*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (5058521*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9720*Sqrt[3]) + 
         (5058521*Pi*Log[3]^2)/(466560*Sqrt[3]) - (13*PolyGamma[2, 1])/2 - 
         (292213*Zeta[3])/720) + (310573*CF^2*NC*Zeta[3])/360 + 
       (223*CF*NM*NC*Zeta[3])/27 - (287*CF*NC*NL*Zeta[3])/9 - 
       (224*CF*NC*NH*Zeta[3])/3 + 
       (CF*NC*Log[x]*(363*CA*(-726234636777 - 259912346400*lm - 
            55010340000*lm^2 + 87166781100*Pi^2 - 99147011600*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 120022560000*Zeta[3]) - 
          40*(-63*NM*(-32144615561 + 4973550120*lm + 1440747000*lm^2 + 
              18180855000*Pi^2) + 5*(1440747*NL*(23025 - 43496*lm - 
                12600*lm^2 + 11400*Pi^2) - NH*(-1165746532353 + 
                62666731512*lm + 18153412200*lm^2 + 626934357280*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 1815*CF*(-4074030159 - 
              21575484*lm + 450084600*lm^2 + 829437651*Pi^2 - 
              991470116*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1200225600*Zeta[
                3]))))/622402704000, (-149947349197201*CF^2*NC)/
        1440270720000 - (47281*CF^2*lm*NC)/3600 - (39*CF^2*lm^2*NC)/4 - 
       (1069076732471*CF*NM*NC)/3600676800 + (170131*CF*lm*NM*NC)/32400 + 
       (13*CF*lm^2*NM*NC)/12 + (20969467*CF*NC*NL)/486000 + 
       (170131*CF*lm*NC*NL)/32400 + (13*CF*lm^2*NC*NL)/12 + 
       (320624575856803547257*CF*NC*NH)/473810593648392000 + 
       (170131*CF*lm*NC*NH)/32400 + (13*CF*lm^2*NC*NH)/12 - 
       (274059173*CF^2*NC*Pi^2)/5443200 - (CF^2*lm*NC*Pi^2)/6 + 
       (84131*CF*NM*NC*Pi^2)/810 + (CF*lm*NM*NC*Pi^2)/54 - 
       (257*CF*NC*NL*Pi^2)/180 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (45377171*CF^2*NC*Pi^3)/(1259712*Sqrt[3]) - 
       (23391725*CF*NC*NH*Pi^3)/(354294*Sqrt[3]) - (731*CF^2*NC*Pi^4)/864 - 
       (1765467833*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(5248800*Sqrt[3]) + 
       (81267164*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
       (197*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (6482453*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4860*Sqrt[3]) - (5346680*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (6482453*CF^2*NC*Pi*Log[3]^2)/(233280*Sqrt[3]) - 
       (668335*CF*NC*NH*Pi*Log[3]^2)/(13122*Sqrt[3]) + 
       (CF*NC*(6435*CA*(12299303 + 3092320*lm) + 
          858*CF*(-77555389 + 37951200*lm) - 
          80*(143*(-6366359 + 316260*lm)*NM + 90090*(685 + 502*lm)*NL + 
            (14686289 + 45225180*lm)*NH))*Log[x]^2)/64864800 + 
       (CF*NC*(5099*CA - 498830*CF + 40*(6448*NM + 251*NL))*Log[x]^3)/270 + 
       (65*CF^2*NC*PolyGamma[2, 1])/6 - (217*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (578*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-104578183676621/2880541440000 - (143*lm^2)/24 + 
         (30181337*Pi^2)/1209600 + (45377171*Pi^3)/(2519424*Sqrt[3]) + 
         (1261*Pi^4)/2880 - (lm*(2362841 + 6600*Pi^2))/64800 + 
         (1765467833*Im[PolyLog[2, (-1)^(1/3)]])/(10497600*Sqrt[3]) + 
         (197*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (6482453*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9720*Sqrt[3]) + 
         (6482453*Pi*Log[3]^2)/(466560*Sqrt[3]) - (65*PolyGamma[2, 1])/12 - 
         (368597*Zeta[3])/720) + (43373*CF^2*NC*Zeta[3])/40 - 
       (2107*CF*NM*NC*Zeta[3])/9 - 42*CF*NC*NL*Zeta[3] - 
       (524*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((-3781913783*NM*NC)/7144200 + 
         (2179*lm*NM*NC)/90 + 7*lm^2*NM*NC - (51197*NC*NL)/2700 + 
         (2179*lm*NC*NL)/90 + 7*lm^2*NC*NL - (660107952857933*NC*NH)/
          1314825712200 + (2179*lm*NC*NH)/90 + 7*lm^2*NC*NH + 
         (5954*NM*NC*Pi^2)/27 - (188*NC*NL*Pi^2)/27 + 
         (5346680*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
         CF*NC*(22879869877/35721000 + (13*lm)/5 - 63*lm^2 - 
           (298151*Pi^2)/2160 + (6482453*Im[PolyLog[2, (-1)^(1/3)]])/
            (14580*Sqrt[3]) - 168*Zeta[3]) + CA*NC*(-6209462599/11430720 - 
           (32789*lm)/180 - (77*lm^2)/2 + (311591*Pi^2)/4320 - 
           (6482453*Im[PolyLog[2, (-1)^(1/3)]])/(29160*Sqrt[3]) + 
           84*Zeta[3])), (134549187079085087*CF^2*NC)/272211166080000 - 
       (2513419*CF^2*lm*NC)/176400 - (21*CF^2*lm^2*NC)/2 - 
       (4927172447824567231*CF*NM*NC)/10529124303297600 + 
       (8996119*CF*lm*NM*NC)/1587600 + (7*CF*lm^2*NM*NC)/6 + 
       (44217739*CF*NC*NL)/850500 + (8996119*CF*lm*NC*NL)/1587600 + 
       (7*CF*lm^2*NC*NL)/6 + (374426277778694186509*CF*NC*NH)/
        473810593648392000 + (8996119*CF*lm*NC*NH)/1587600 + 
       (7*CF*lm^2*NC*NH)/6 - (1820656123*CF^2*NC*Pi^2)/7620480 - 
       (CF^2*lm*NC*Pi^2)/6 + (355115*CF*NM*NC*Pi^2)/2268 + 
       (CF*lm*NM*NC*Pi^2)/54 - (3131*CF*NC*NL*Pi^2)/1890 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (1431585485*CF^2*NC*Pi^3)/(34012224*Sqrt[3]) - 
       (55804735*CF*NC*NH*Pi^3)/(708588*Sqrt[3]) - (4283*CF^2*NC*Pi^4)/
        4320 - (546317957179*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1388832480*Sqrt[3]) + (105193331*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
       (225*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (286317097*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (183708*Sqrt[3]) - (6377684*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (286317097*CF^2*NC*Pi*Log[3]^2)/(8817984*Sqrt[3]) - 
       (1594421*CF*NC*NH*Pi*Log[3]^2)/(26244*Sqrt[3]) + 
       (CF*NC*(143*CA*(8101702097 + 1160359200*lm) + 
          2*(143*CF*(-5416686641 + 949384800*lm) - 
            280*(7*(-200858377 + 7696260*lm)*NM + 2072070*(35 + 26*lm)*NL + 
              (18173081 + 53873820*lm)*NH)))*Log[x]^2)/454053600 + 
       (CF*NC*(924179*CA - 6075482*CF + 280*(8920*NM + 299*NL))*Log[x]^3)/
        1890 + (91*CF^2*NC*PolyGamma[2, 1])/6 - 
       (154*CF*NM*NC*PolyGamma[2, 1])/9 - (770*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-37758687597920827/108884466432000 - (77*lm^2)/12 + 
         (606332953*Pi^2)/5080320 + (1431585485*Pi^3)/(68024448*Sqrt[3]) + 
         (4411*Pi^4)/8640 - (lm*(124888109 + 323400*Pi^2))/3175200 + 
         (546317957179*Im[PolyLog[2, (-1)^(1/3)]])/(2777664960*Sqrt[3]) + 
         (225*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (286317097*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(367416*Sqrt[3]) + 
         (286317097*Pi*Log[3]^2)/(17635968*Sqrt[3]) - (91*PolyGamma[2, 1])/
          12 - (4356967*Zeta[3])/5040) + (4540367*CF^2*NC*Zeta[3])/2520 - 
       (3416*CF*NM*NC*Zeta[3])/9 - (152*CF*NC*NL*Zeta[3])/3 - 
       (224*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((-1094571559231*NM*NC)/
          1490732100 + (17503*lm*NM*NC)/630 + 8*lm^2*NM*NC - 
         (46607*NC*NL)/1800 + (17503*lm*NC*NL)/630 + 8*lm^2*NC*NL - 
         (393100729144987*NC*NH)/657412856100 + (17503*lm*NC*NH)/630 + 
         8*lm^2*NC*NH + (8315*NM*NC*Pi^2)/27 - (227*NC*NL*Pi^2)/27 + 
         (6377684*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
         CF*NC*(17605903704407/13502538000 + (137*lm)/70 - 72*lm^2 - 
           (6020261*Pi^2)/15120 + (286317097*Im[PolyLog[2, (-1)^(1/3)]])/
            (551124*Sqrt[3]) - 192*Zeta[3]) + 
         CA*NC*(-249589972027/275562000 - (263093*lm)/1260 - 44*lm^2 + 
           (6141221*Pi^2)/30240 - (286317097*Im[PolyLog[2, (-1)^(1/3)]])/
            (1102248*Sqrt[3]) + 96*Zeta[3])), 
      (81828188472693739*CF^2*NC)/90737055360000 - (2710069*CF^2*lm*NC)/
        176400 - (45*CF^2*lm^2*NC)/4 - (11154819518828287*CF*NM*NC)/
        4792500820800 + (9655819*CF*lm*NM*NC)/1587600 + 
       (5*CF*lm^2*NM*NC)/4 + (3138422699*CF*NC*NL)/47628000 + 
       (9655819*CF*lm*NC*NL)/1587600 + (5*CF*lm^2*NC*NL)/4 + 
       (52187558728281067447*CF*NC*NH)/52645621516488000 + 
       (9655819*CF*lm*NC*NH)/1587600 + (5*CF*lm^2*NC*NH)/4 - 
       (14155105571*CF^2*NC*Pi^2)/38102400 - (CF^2*lm*NC*Pi^2)/6 + 
       (1852888*CF*NM*NC*Pi^2)/2835 + (CF*lm*NM*NC*Pi^2)/54 - 
       (7337*CF*NC*NL*Pi^2)/3780 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (588038819*CF^2*NC*Pi^3)/(11337408*Sqrt[3]) - 
       (215688025*CF*NC*NH*Pi^3)/(2125764*Sqrt[3]) - 
       (1673*CF^2*NC*Pi^4)/1440 - (955516932733*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2314720800*Sqrt[3]) + 
       (14223742*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(32805*Sqrt[3]) - 
       (257*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (588038819*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (306180*Sqrt[3]) - (24650060*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (588038819*CF^2*NC*Pi*Log[3]^2)/(14696640*Sqrt[3]) - 
       (6162515*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) + 
       (CF*NC*(143*CA*(11480628433 + 1439776800*lm) + 
          14*(1001*CF*(-166271593 + 24040800*lm) - 
            40*(13*(-478300897 + 5142060*lm)*NM + 630630*(141 + 106*lm)*
               NL + (23804021 + 66846780*lm)*NH)))*Log[x]^2)/454053600 + 
       (CF*NC*(1466771*CA - 8449106*CF + 280*(26914*NM + 371*NL))*Log[x]^3)/
        1890 + (25*CF^2*NC*PolyGamma[2, 1])/2 - 
       (176*CF*NM*NC*PolyGamma[2, 1])/9 - (1729*CF*NC*NH*PolyGamma[2, 1])/
        54 + CA*CF*NC*(-20391666841226519/36294822144000 - (55*lm^2)/8 + 
         (4718541937*Pi^2)/25401600 + (588038819*Pi^3)/(22674816*Sqrt[3]) + 
         (5147*Pi^4)/8640 - (lm*(133997009 + 323400*Pi^2))/3175200 + 
         (955516932733*Im[PolyLog[2, (-1)^(1/3)]])/(4629441600*Sqrt[3]) + 
         (257*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (588038819*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(612360*Sqrt[3]) + 
         (588038819*Pi*Log[3]^2)/(29393280*Sqrt[3]) - (25*PolyGamma[2, 1])/
          4 - (381149*Zeta[3])/336) + (1186343*CF^2*NC*Zeta[3])/504 - 
       (14764*CF*NM*NC*Zeta[3])/9 - 64*CF*NC*NL*Zeta[3] - 
       (463*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((-414571392017*NM*NC)/
          216112050 + (20453*lm*NM*NC)/630 + (28*lm^2*NM*NC)/3 - 
         (1445767*NC*NL)/37800 + (20453*lm*NC*NL)/630 + 
         (28*lm^2*NC*NL)/3 - (216081443047741*NC*NH)/281748366900 + 
         (20453*lm*NC*NH)/630 + (28*lm^2*NC*NH)/3 + (26207*NM*NC*Pi^2)/
          27 - (287*NC*NL*Pi^2)/27 + (24650060*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CF*NC*(15460285453183/9001692000 + (127*lm)/70 - 84*lm^2 - 
           (1757005*Pi^2)/3024 + (588038819*Im[PolyLog[2, (-1)^(1/3)]])/
            (918540*Sqrt[3]) - 224*Zeta[3]) + 
         CA*NC*(-20779517908549/18003384000 - (307303*lm)/1260 - 
           (154*lm^2)/3 + (1786573*Pi^2)/6048 - 
           (588038819*Im[PolyLog[2, (-1)^(1/3)]])/(1837080*Sqrt[3]) + 
           112*Zeta[3])), (64234625960004391448507*CF^2*NC)/
        13043270233889280000 - (23257127*CF^2*lm*NC)/1411200 - 
       12*CF^2*lm^2*NC - (1476565392157764623917*CF*NM*NC)/
        421164972131904000 + (82527527*CF*lm*NM*NC)/12700800 + 
       (4*CF*lm^2*NM*NC)/3 + (14856692111*CF*NC*NL)/190512000 + 
       (82527527*CF*lm*NC*NL)/12700800 + (4*CF*lm^2*NC*NL)/3 + 
       (147504631023682089797*CF*NC*NH)/129221070995016000 + 
       (82527527*CF*lm*NC*NH)/12700800 + (4*CF*lm^2*NC*NH)/3 - 
       (221759388323*CF^2*NC*Pi^2)/152409600 - (CF^2*lm*NC*Pi^2)/6 + 
       (4416061*CF*NM*NC*Pi^2)/4536 + (CF*lm*NM*NC*Pi^2)/54 - 
       (33373*CF*NC*NL*Pi^2)/15120 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (36408844277*CF^2*NC*Pi^3)/
        (612220032*Sqrt[3]) - (505537865*CF*NC*NH*Pi^3)/(4251528*Sqrt[3]) - 
       (1151*CF^2*NC*Pi^4)/864 - (118390208729173*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(249989846400*Sqrt[3]) + 
       (478274237*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) - 
       (289*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (36408844277*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (16533720*Sqrt[3]) - (28887878*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (36408844277*CF^2*NC*Pi*Log[3]^2)/(793618560*Sqrt[3]) - 
       (14443939*CF*NC*NH*Pi*Log[3]^2)/(157464*Sqrt[3]) + 
       (CF*NC*(39*CA*(241704744551 + 12351292800*lm) + 
          2*(117*CF*(-71008538449 + 3368534400*lm) - 
            280*((-18620084711 + 156396240*lm)*NM + 22*(57330*(163 + 124*lm)*
                 NL + (2612557 + 7108920*lm)*NH))))*Log[x]^2)/908107200 + 
       (CF*NC*(12601921*CA - 38567860*CF + 1120*(19157*NM + 217*NL))*
         Log[x]^3)/3780 + (52*CF^2*NC*PolyGamma[2, 1])/3 - 
       (235*CF*NM*NC*PolyGamma[2, 1])/9 - (1103*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-13494155677603456505233/5217308093555712000 - 
         (22*lm^2)/3 + (24644728747*Pi^2)/33868800 + (36408844277*Pi^3)/
          (1224440064*Sqrt[3]) + (1961*Pi^4)/2880 + 
         lm*(-1144884397/25401600 - (11*Pi^2)/108) + 
         (118390208729173*Im[PolyLog[2, (-1)^(1/3)]])/(499979692800*
           Sqrt[3]) + (289*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (36408844277*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33067440*Sqrt[3]) + (36408844277*Pi*Log[3]^2)/
          (1587237120*Sqrt[3]) - (26*PolyGamma[2, 1])/3 - 
         (8620957*Zeta[3])/3360) + (26370791*CF^2*NC*Zeta[3])/5040 - 
       (21929*CF*NM*NC*Zeta[3])/9 - (227*CF*NC*NL*Zeta[3])/3 - 
       (196*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((-365906534329883*NM*NC)/
          146091745800 + (92347*lm*NM*NC)/2520 + (21*lm^2*NM*NC)/2 - 
         (410441*NC*NL)/8400 + (92347*lm*NC*NL)/2520 + (21*lm^2*NC*NL)/2 - 
         (643720005898367*NC*NH)/717177661200 + (92347*lm*NC*NH)/2520 + 
         (21*lm^2*NC*NH)/2 + (74941*NM*NC*Pi^2)/54 - (679*NC*NL*Pi^2)/54 + 
         (28887878*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CF*NC*(111609732572366569/33609746016000 + (263*lm)/280 - 
           (189*lm^2)/2 - (57259423*Pi^2)/30240 + 
           (36408844277*Im[PolyLog[2, (-1)^(1/3)]])/(49601160*Sqrt[3]) - 
           252*Zeta[3]) + CA*NC*(-58551698515199389/29408527764000 - 
           (1386257*lm)/5040 - (231*lm^2)/4 + (57625663*Pi^2)/60480 - 
           (36408844277*Im[PolyLog[2, (-1)^(1/3)]])/(99202320*Sqrt[3]) + 
           126*Zeta[3])), (101887540576605752949661*CF^2*NC)/
        13043270233889280000 - (12416851*CF^2*lm*NC)/705600 - 
       (51*CF^2*lm^2*NC)/4 - (1223289749598709669931*CF*NM*NC)/
        84232994426380800 + (43904251*CF*lm*NM*NC)/6350400 + 
       (17*CF*lm^2*NM*NC)/12 + (127935914321*CF*NC*NL)/1333584000 + 
       (43904251*CF*lm*NC*NL)/6350400 + (17*CF*lm^2*NC*NL)/12 + 
       (2101361959974763137184982279*CF*NC*NH)/1508434777393268332608000 + 
       (43904251*CF*lm*NC*NH)/6350400 + (17*CF*lm^2*NC*NH)/12 - 
       (753041154791*CF^2*NC*Pi^2)/335301120 - (CF^2*lm*NC*Pi^2)/6 + 
       (43639321*CF*NM*NC*Pi^2)/11340 + (CF*lm*NM*NC*Pi^2)/54 - 
       (6373*CF*NC*NL*Pi^2)/2520 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (43597602025*CF^2*NC*Pi^3)/
        (612220032*Sqrt[3]) - (2125416440*CF*NC*NH*Pi^3)/
        (14348907*Sqrt[3]) - (6599*CF^2*NC*Pi^4)/4320 - 
       (24579990291349*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (49997969280*Sqrt[3]) + (108473262304*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) - 
       (325*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (8719520405*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3306744*Sqrt[3]) - (971618944*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (8719520405*CF^2*NC*Pi*Log[3]^2)/(158723712*Sqrt[3]) - 
       (60726184*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) + 
       (CF*NC*(202657*CA*(2356306223 + 97574400*lm) + 
          2*(221*CF*(-1952909764867 + 73207411200*lm) - 
            560*(85*(-14900824915 + 37765728*lm)*NM + 12252240*(341 + 
                262*lm)*NL + (1229201627 + 3210086880*lm)*NH)))*Log[x]^2)/
        30875644800 + (CF*NC*(9686411*CA + 16*(-1738526*CF + 2291905*NM + 
            9170*NL))*Log[x]^3)/1890 + (85*CF^2*NC*PolyGamma[2, 1])/6 - 
       (533*CF*NM*NC*PolyGamma[2, 1])/18 - (1232*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-105466438230358215105589/26086540467778560000 - 
         (187*lm^2)/24 + (4565013275*Pi^2)/4064256 + (43597602025*Pi^3)/
          (1224440064*Sqrt[3]) + (6727*Pi^4)/8640 + 
         lm*(-608896361/12700800 - (11*Pi^2)/108) + 
         (24579990291349*Im[PolyLog[2, (-1)^(1/3)]])/(99995938560*Sqrt[3]) + 
         (325*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (8719520405*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6613488*Sqrt[3]) + (8719520405*Pi*Log[3]^2)/(317447424*Sqrt[3]) - 
         (85*PolyGamma[2, 1])/12 - (36527717*Zeta[3])/10080) + 
       (37114597*CF^2*NC*Zeta[3])/5040 - (82907*CF*NM*NC*Zeta[3])/9 - 
       (278*CF*NC*NL*Zeta[3])/3 - (308*CF*NC*NH*Zeta[3])/9 + 
       CF*Log[x]*((-641845481209507*NM*NC)/116873396640 + 
         (52841*lm*NM*NC)/1260 + 12*lm^2*NM*NC - (5820979*NC*NL)/88200 + 
         (52841*lm*NC*NL)/1260 + 12*lm^2*NC*NL - 
         (137184735200862849151*NC*NH)/123115020387559200 + 
         (52841*lm*NC*NH)/1260 + 12*lm^2*NC*NH + (129998*NM*NC*Pi^2)/27 - 
         (416*NC*NL*Pi^2)/27 + (971618944*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (531441*Sqrt[3]) + CF*NC*(283209545820614509/67219492032000 + 
           (79*lm)/140 - 108*lm^2 - (85844191*Pi^2)/30240 + 
           (8719520405*Im[PolyLog[2, (-1)^(1/3)]])/(9920232*Sqrt[3]) - 
           288*Zeta[3]) + CA*NC*(-467368122365214827/188214577689600 - 
           (792931*lm)/2520 - 66*lm^2 + (86280991*Pi^2)/60480 - 
           (8719520405*Im[PolyLog[2, (-1)^(1/3)]])/(19840464*Sqrt[3]) + 
           144*Zeta[3])), (10100628147755113113207527*CF^2*NC)/
        312611614951142707200 - (118856659*CF^2*lm*NC)/6350400 - 
       (27*CF^2*lm^2*NC)/2 - (231205942219490377174393*CF*NM*NC)/
        10611197477354073600 + (418913059*CF*lm*NM*NC)/57153600 + 
       (3*CF*lm^2*NM*NC)/2 + (111821802823*CF*NC*NL)/1000188000 + 
       (418913059*CF*lm*NC*NL)/57153600 + (3*CF*lm^2*NC*NL)/2 + 
       (4183655827157200903244653*CF*NC*NH)/2638661418180644313600 + 
       (418913059*CF*lm*NC*NH)/57153600 + (3*CF*lm^2*NC*NH)/2 - 
       (43793443961461*CF^2*NC*Pi^2)/5029516800 - (CF^2*lm*NC*Pi^2)/6 + 
       (98234077*CF*NM*NC*Pi^2)/17010 + (CF*lm*NM*NC*Pi^2)/54 - 
       (192721*CF*NC*NL*Pi^2)/68040 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (1329802734671*CF^2*NC*Pi^3)/
        (16529940864*Sqrt[3]) - (22095664885*CF*NC*NH*Pi^3)/
        (129140163*Sqrt[3]) - (827*CF^2*NC*Pi^4)/480 - 
       (416617786853111*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (749969539200*Sqrt[3]) + (393983664523*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(502211745*Sqrt[3]) - 
       (361*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (1329802734671*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (446410440*Sqrt[3]) - (10100875376*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (1329802734671*CF^2*NC*Pi*Log[3]^2)/(21427701120*Sqrt[3]) - 
       (631304711*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       (CF*NC*(561*CA*(9010063292873 + 121888166400*lm) + 
          2*(187*CF*(-26178881855443 + 299180044800*lm) - 
            1680*(455*(-4182671545 + 8132256*lm)*NM + 12252240*(389 + 
                302*lm)*NL + 151*(9635051 + 24504480*lm)*NH)))*Log[x]^2)/
        92626934400 + (CF*NC*(111933737*CA + 48*(-5292722*CF + 
            35*(95935*NM + 302*NL)))*Log[x]^3)/5670 + 
       (39*CF^2*NC*PolyGamma[2, 1])/2 - (1022*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (1522*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-36414047197980674732427209/2232940106793876480000 - 
         (33*lm^2)/4 + (3981617500031*Pi^2)/914457600 + (1329802734671*Pi^3)/
          (33059881728*Sqrt[3]) + (7571*Pi^4)/8640 + 
         lm*(-5808269249/114307200 - (11*Pi^2)/108) + 
         (416617786853111*Im[PolyLog[2, (-1)^(1/3)]])/(1499939078400*
           Sqrt[3]) + (361*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (1329802734671*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (892820880*Sqrt[3]) + (1329802734671*Pi*Log[3]^2)/
          (42855402240*Sqrt[3]) - (39*PolyGamma[2, 1])/4 - 
         (1009183577*Zeta[3])/90720) + (1015347497*CF^2*NC*Zeta[3])/45360 - 
       (368902*CF*NM*NC*Zeta[3])/27 - (970*CF*NC*NL*Zeta[3])/9 - 
       (400*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((-85911754448609143*NM*NC)/
          12990927549600 + (529889*lm*NM*NC)/11340 + (40*lm^2*NM*NC)/3 - 
         (32158337*NC*NL)/396900 + (529889*lm*NC*NL)/11340 + 
         (40*lm^2*NC*NL)/3 - (1424477670630920372333*NC*NH)/
          1108035183488032800 + (529889*lm*NC*NH)/11340 + 
         (40*lm^2*NC*NH)/3 + (190738*NM*NC*Pi^2)/27 - 
         (484*NC*NL*Pi^2)/27 + (10100875376*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(5409585278489142743/796681927641600 - (689*lm)/1260 - 
           120*lm^2 - (308152979*Pi^2)/30240 + 
           (1329802734671*Im[PolyLog[2, (-1)^(1/3)]])/(1339231320*Sqrt[3]) - 
           320*Zeta[3]) + CA*NC*(-1487615937162909045391/390374144544384000 - 
           (7945579*lm)/22680 - (220*lm^2)/3 + (308679379*Pi^2)/60480 - 
           (1329802734671*Im[PolyLog[2, (-1)^(1/3)]])/(2678462640*Sqrt[3]) + 
           160*Zeta[3])), (481865967905541325120438687*CF^2*NC)/
        9552021567951582720000 - (125961659*CF^2*lm*NC)/6350400 - 
       (57*CF^2*lm^2*NC)/4 - (36987660557147583880913*CF*NM*NC)/
        421164972131904000 + (442687859*CF*lm*NM*NC)/57153600 + 
       (19*CF*lm^2*NM*NC)/12 + (1074854408839*CF*NC*NL)/8001504000 + 
       (442687859*CF*lm*NC*NL)/57153600 + (19*CF*lm^2*NC*NL)/12 + 
       (35263830986953209563968755729583*CF*NC*NH)/
        18623437448652769488044889600 + (442687859*CF*lm*NC*NH)/57153600 + 
       (19*CF*lm^2*NC*NH)/12 - (9738287023763*CF^2*NC*Pi^2)/718502400 - 
       (CF^2*lm*NC*Pi^2)/6 + (393711977*CF*NM*NC*Pi^2)/17010 + 
       (CF*lm*NM*NC*Pi^2)/54 - (217151*CF*NC*NL*Pi^2)/68040 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (1557894718351*CF^2*NC*Pi^3)/(16529940864*Sqrt[3]) - 
       (107287348175*CF*NC*NH*Pi^3)/(516560652*Sqrt[3]) - 
       (1679*CF^2*NC*Pi^4)/864 - (142871840184517*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(249989846400*Sqrt[3]) + 
       (1399187096401*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1506635235*Sqrt[3]) - (401*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (1557894718351*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (446410440*Sqrt[3]) - (12261411220*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (1557894718351*CF^2*NC*Pi*Log[3]^2)/(21427701120*Sqrt[3]) - 
       (3065352805*CF*NC*NH*Pi*Log[3]^2)/(19131876*Sqrt[3]) + 
       CF*((-446987976890617*CF*NC)/2724321600 + 1428*CF*lm*NC + 
         CA*(152686556848451/1816214400 + (2618*lm)/3)*NC + 
         (149969814641*NM*NC)/540540 - (476*lm*NM*NC)/3 - (608*NC*NL)/3 - 
         (476*lm*NC*NL)/3 - (6750194497*NC*NH)/104756652 - 
         (476*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(172890519*CA - 80*(4787219*CF - 7563717*NM - 7497*NL))*
         Log[x]^3)/5670 + (95*CF^2*NC*PolyGamma[2, 1])/6 - 
       (1150*CF*NM*NC*PolyGamma[2, 1])/27 - (1127*CF*NC*NH*PolyGamma[2, 1])/
        18 + CA*CF*NC*(-485069369206487462935557139/19104043135903165440000 - 
         (209*lm^2)/24 + (9739131908003*Pi^2)/1437004800 + 
         (1557894718351*Pi^3)/(33059881728*Sqrt[3]) + (947*Pi^4)/960 + 
         lm*(-6136471249/114307200 - (11*Pi^2)/108) + 
         (142871840184517*Im[PolyLog[2, (-1)^(1/3)]])/(499979692800*
           Sqrt[3]) + (401*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (1557894718351*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (892820880*Sqrt[3]) + (1557894718351*Pi*Log[3]^2)/
          (42855402240*Sqrt[3]) - (95*PolyGamma[2, 1])/12 - 
         (1515267361*Zeta[3])/90720) + (1522313281*CF^2*NC*Zeta[3])/45360 - 
       (1423040*CF*NM*NC*Zeta[3])/27 - (1160*CF*NC*NL*Zeta[3])/9 - 
       (13*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((-66501689420843*NM*NC)/
          6956749800 + (596809*lm*NM*NC)/11340 + 15*lm^2*NM*NC - 
         (329167571*NC*NL)/3175200 + (596809*lm*NC*NL)/11340 + 
         15*lm^2*NC*NL - (44466910301777603385131*NC*NH)/
          28571478659941417200 + (596809*lm*NC*NH)/11340 + 15*lm^2*NC*NH + 
         (79897*NM*NC*Pi^2)/3 - (193*NC*NL*Pi^2)/9 + 
         (12261411220*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(15546829283991661614037/2147057794994112000 - 
           (1459*lm)/1260 - 135*lm^2 - (1417664401*Pi^2)/90720 + 
           (1557894718351*Im[PolyLog[2, (-1)^(1/3)]])/(1339231320*Sqrt[3]) - 
           360*Zeta[3]) + CA*NC*(-17546178328477091738953/
            4294115589988224000 - (8946299*lm)/22680 - (165*lm^2)/2 + 
           (1419512401*Pi^2)/181440 - (1557894718351*Im[PolyLog[2, (-1)^
                (1/3)]])/(2678462640*Sqrt[3]) + 180*Zeta[3])), 
      (468621442259064601057286422187*CF^2*NC)/2321141241012234600960000 - 
       (133074107*CF^2*lm*NC)/6350400 - 15*CF^2*lm^2*NC - 
       (1885800438708767137440945857581*CF*NM*NC)/
        14192529681948460210368000 + (466470107*CF*lm*NM*NC)/57153600 + 
       (5*CF*lm^2*NM*NC)/3 + (274736662223*CF*NC*NL)/1778112000 + 
       (466470107*CF*lm*NC*NL)/57153600 + (5*CF*lm^2*NC*NL)/3 + 
       (39741250883910330395085459333247*CF*NC*NH)/
        18623437448652769488044889600 + (466470107*CF*lm*NC*NH)/57153600 + 
       (5*CF*lm^2*NC*NH)/3 - (24643722598751*CF^2*NC*Pi^2)/457228800 - 
       (CF^2*lm*NC*Pi^2)/6 + (2393881289*CF*NM*NC*Pi^2)/68040 + 
       (CF*lm*NM*NC*Pi^2)/54 - (48067*CF*NC*NL*Pi^2)/13608 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (1739021814803*CF^2*NC*Pi^3)/(16529940864*Sqrt[3]) - 
       (244890407405*CF*NC*NH*Pi^3)/(1033121304*Sqrt[3]) - 
       (9347*CF^2*NC*Pi^4)/4320 - (1845286197541819*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2892739651200*Sqrt[3]) + 
       (3315740653787*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3013270470*Sqrt[3]) - (441*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (248431687829*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (63772920*Sqrt[3]) - (13993737566*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (248431687829*CF^2*NC*Pi*Log[3]^2)/(3061100160*Sqrt[3]) - 
       (6996868783*CF*NC*NH*Pi*Log[3]^2)/(38263752*Sqrt[3]) + 
       (CF*NC*(323*CA*(1779258703171693 + 5414135126400*lm) + 
          10*(323*CF*(-353325595389973 + 885949384320*lm) - 
            2688*(3*(-9206753965223 + 3942923985*lm)*NM + 43648605*(343 + 
                271*lm)*NL + (4913281024 + 11828771955*lm)*NH)))*Log[x]^2)/
        1759911753600 + (CF*NC*(337138761*CA - 696130532*CF + 
          1260*(360010*NM + 271*NL))*Log[x]^3)/2835 + 
       (65*CF^2*NC*PolyGamma[2, 1])/3 - (1423*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (679*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-469481636421771940242260759561/4642282482024469201920000 - 
         (55*lm^2)/6 + (271088619470461*Pi^2)/10059033600 + 
         (1739021814803*Pi^3)/(33059881728*Sqrt[3]) + (1895*Pi^4)/1728 + 
         lm*(-6464755177/114307200 - (11*Pi^2)/108) + 
         (1845286197541819*Im[PolyLog[2, (-1)^(1/3)]])/(5785479302400*
           Sqrt[3]) + (441*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (248431687829*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (127545840*Sqrt[3]) + (248431687829*Pi*Log[3]^2)/
          (6122200320*Sqrt[3]) - (65*PolyGamma[2, 1])/6 - 
         (1849276943*Zeta[3])/30240) + (1851983423*CF^2*NC*Zeta[3])/15120 - 
       (2140409*CF*NM*NC*Zeta[3])/27 - (1331*CF*NC*NL*Zeta[3])/9 - 
       (88*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((-40388014686871620529*NM*NC)/
          5806325999073600 + (131609*lm*NM*NC)/2268 + (33*lm^2*NM*NC)/2 - 
         (29126231*NC*NL)/235200 + (131609*lm*NC*NL)/2268 + 
         (33*lm^2*NC*NL)/2 - (56780184636394949540389*NC*NH)/
          32000056099134387264 + (131609*lm*NC*NH)/2268 + 
         (33*lm^2*NC*NH)/2 + (79893*NM*NC*Pi^2)/2 - (443*NC*NL*Pi^2)/18 + 
         (13993737566*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(-1777398281369962044803/429411558998822400 - (158*lm)/63 - 
           (297*lm^2)/2 - (1811228023*Pi^2)/30240 + 
           (248431687829*Im[PolyLog[2, (-1)^(1/3)]])/(191318760*Sqrt[3]) - 
           396*Zeta[3]) + CA*NC*(6704173595414537869243/4294115589988224000 - 
           (1971607*lm)/4536 - (363*lm^2)/4 + (1811954903*Pi^2)/60480 - 
           (248431687829*Im[PolyLog[2, (-1)^(1/3)]])/(382637520*Sqrt[3]) + 
           198*Zeta[3])), (169667381039061009123208028293*CF^2*NC)/
        535647978695131061760000 - (28037311*CF^2*lm*NC)/1270080 - 
       (63*CF^2*lm^2*NC)/4 - (66145717412617897286920241*CF*NM*NC)/
        121716676946120256000 + (98050471*CF*lm*NM*NC)/11430720 + 
       (7*CF*lm^2*NM*NC)/4 + (2186263656377*CF*NC*NL)/12002256000 + 
       (98050471*CF*lm*NC*NL)/11430720 + (7*CF*lm^2*NC*NL)/4 + 
       (1259244420675813089059588200108649*CF*NC*NH)/
        502832811113624776177212019200 + (98050471*CF*lm*NC*NH)/11430720 + 
       (7*CF*lm^2*NC*NH)/4 - (1849481165763391*CF^2*NC*Pi^2)/21794572800 - 
       (CF^2*lm*NC*Pi^2)/6 + (4931227747*CF*NM*NC*Pi^2)/34020 + 
       (CF*lm*NM*NC*Pi^2)/54 - (267299*CF*NC*NL*Pi^2)/68040 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (6007462088485*CF^2*NC*Pi^3)/(49589822592*Sqrt[3]) - 
       (655293737245*CF*NC*NH*Pi^3)/(2324522934*Sqrt[3]) - 
       (3469*CF^2*NC*Pi^4)/1440 - (7912436660818063*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12149506535040*Sqrt[3]) + 
       (52330561635994*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (40679151345*Sqrt[3]) - (485*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        2 - (1201492417697*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (267846264*Sqrt[3]) - (149781425656*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (1201492417697*CF^2*NC*Pi*Log[3]^2)/(12856620672*Sqrt[3]) - 
       (18722678207*CF*NC*NH*Pi*Log[3]^2)/(86093442*Sqrt[3]) + 
       CF*((-4751363247601*CF*NC)/4656960 + 1890*CF*lm*NC + 
         CA*(1228232990531/2395008 + 1155*lm)*NC + (34815191617*NM*NC)/
          20020 - 210*lm*NM*NC - (2375*NC*NL)/9 - 210*lm*NC*NL - 
         (46898632511*NC*NH)/523783260 - 210*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(1053893987*CA + 8*(-270071899*CF + 4725*(95756*NM + 21*NL)))*
         Log[x]^3)/5670 + (35*CF^2*NC*PolyGamma[2, 1])/2 - 
       (3179*CF*NM*NC*PolyGamma[2, 1])/54 - (250*CF*NC*NH*PolyGamma[2, 1])/
        3 + CA*CF*NC*(-33976952704552452571299825221/
          214259191478052424704000 - (77*lm^2)/8 + (15807880725683*Pi^2)/
          372556800 + (6007462088485*Pi^3)/(99179645184*Sqrt[3]) + 
         (2107*Pi^4)/1728 + lm*(-1358607821/22861440 - (11*Pi^2)/108) + 
         (7912436660818063*Im[PolyLog[2, (-1)^(1/3)]])/(24299013070080*
           Sqrt[3]) + (485*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (1201492417697*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (535692528*Sqrt[3]) + (1201492417697*Pi*Log[3]^2)/
          (25713241344*Sqrt[3]) - (35*PolyGamma[2, 1])/4 - 
         (1721463029*Zeta[3])/18144) + (1723301621*CF^2*NC*Zeta[3])/9072 - 
       (8595065*CF*NM*NC*Zeta[3])/27 - (1562*CF*NC*NL*Zeta[3])/9 + 
       (364*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((134308079205934477*NM*NC)/
          3311412904800 + (731881*lm*NM*NC)/11340 + (55*lm^2*NM*NC)/3 - 
         (181842341*NC*NL)/1190700 + (731881*lm*NC*NL)/11340 + 
         (55*lm^2*NC*NL)/3 - (7580139246845796903321739*NC*NH)/
          3600006311152618567200 + (731881*lm*NC*NH)/11340 + 
         (55*lm^2*NC*NH)/3 + (1435790*NM*NC*Pi^2)/9 - (260*NC*NL*Pi^2)/9 + 
         (149781425656*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(-2081032578940845693613/
            99094975153574400 - (4231*lm)/1260 - 165*lm^2 - 
           (1695465029*Pi^2)/18144 + (1201492417697*Im[PolyLog[2, (-1)^
                (1/3)]])/(803538792*Sqrt[3]) - 440*Zeta[3]) + 
         CA*NC*(9848372710010447836757/990949751535744000 - 
           (10961291*lm)/22680 - (605*lm^2)/6 + (1695967685*Pi^2)/36288 - 
           (1201492417697*Im[PolyLog[2, (-1)^(1/3)]])/(1607077584*Sqrt[3]) + 
           220*Zeta[3])), (395711136417748238197952222038509851*CF^2*NC)/
        307901706761513932051944960000 - (3564769231*CF^2*lm*NC)/153679680 - 
       (33*CF^2*lm^2*NC)/2 - (11806416759948772392086245097803*CF*NM*NC)/
        14192529681948460210368000 + (12439770751*CF*lm*NM*NC)/1383117120 + 
       (11*CF*lm^2*NM*NC)/6 + (200586755638343*CF*NC*NL)/968181984000 + 
       (12439770751*CF*lm*NC*NL)/1383117120 + (11*CF*lm^2*NC*NL)/6 + 
       (2345289364307012207762681497712593*CF*NC*NH)/
        838054685189374626962020032000 + (12439770751*CF*lm*NC*NH)/
        1383117120 + (11*CF*lm^2*NC*NH)/6 - 
       (249582356406741643*CF^2*NC*Pi^2)/719220902400 - (CF^2*lm*NC*Pi^2)/6 + 
       (83536002413*CF*NM*NC*Pi^2)/374220 + (CF*lm*NM*NC*Pi^2)/54 - 
       (3223159*CF*NC*NL*Pi^2)/748440 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (657385749525779*CF^2*NC*Pi^3)/
        (4909392436608*Sqrt[3]) - (493533711055*CF*NC*NH*Pi^3)/
        (1549681956*Sqrt[3]) - (11467*CF^2*NC*Pi^4)/4320 - 
       (47602542250597987199*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (66154063083292800*Sqrt[3]) + (20320014448418*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(13559717115*Sqrt[3]) - 
       (529*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (657385749525779*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (132583900680*Sqrt[3]) - (56403852692*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) - 
       (657385749525779*CF^2*NC*Pi*Log[3]^2)/(6364027232640*Sqrt[3]) - 
       (14100963173*CF*NC*NH*Pi*Log[3]^2)/(57395628*Sqrt[3]) + 
       CF*((-2122606297985169247*CF*NC)/509448139200 + 2130*CF*lm*NC + 
         CA*(708568464300016109/339632092800 + (3905*lm)/3)*NC + 
         (467614753530487*NM*NC)/174594420 - (710*lm*NM*NC)/3 - 
         295*NC*NL - (710*lm*NC*NL)/3 - (10777604503*NC*NH)/104756652 - 
         (710*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(46598824487*CA - 1848*(50796439*CF - 32879580*NM - 5325*NL))*
         Log[x]^3)/62370 + (143*CF^2*NC*PolyGamma[2, 1])/6 - 
       (1918*CF*NM*NC*PolyGamma[2, 1])/27 - (886*CF*NC*NH*PolyGamma[2, 1])/
        9 + CA*CF*NC*(-4354334188725920196136924366658213833/
          6773837548753306505142789120000 - (121*lm^2)/12 + 
         (19198768053711031*Pi^2)/110649369600 + (657385749525779*Pi^3)/
          (9818784873216*Sqrt[3]) + (773*Pi^4)/576 + 
         lm*(-15667044031/251475840 - (11*Pi^2)/108) + 
         (47602542250597987199*Im[PolyLog[2, (-1)^(1/3)]])/
          (132308126166585600*Sqrt[3]) + (529*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 + (657385749525779*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (265167801360*Sqrt[3]) + (657385749525779*Pi*Log[3]^2)/
          (12728054465280*Sqrt[3]) - (143*PolyGamma[2, 1])/12 - 
         (375013544431*Zeta[3])/997920) + (375128804191*CF^2*NC*Zeta[3])/
        498960 - (13126484*CF*NM*NC*Zeta[3])/27 - (1772*CF*NC*NL*Zeta[3])/
        9 + (368*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((18154153119170743813*NM*NC)/181447687471050 + 
         (8800391*lm*NM*NC)/124740 + 20*lm^2*NM*NC - (6243509431*NC*NL)/
          34927200 + (8800391*lm*NC*NL)/124740 + 20*lm^2*NC*NL - 
         (129630468381055952462729*NC*NH)/54545550168979069200 + 
         (8800391*lm*NC*NH)/124740 + 20*lm^2*NC*NH + 243483*NM*NC*Pi^2 - 
         (295*NC*NL*Pi^2)/9 + (56403852692*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(14348907*Sqrt[3]) + 
         CF*NC*(-40815685139894596551403587823/184288411717729615296000 - 
           (68591*lm)/13860 - 180*lm^2 - (373364802511*Pi^2)/997920 + 
           (657385749525779*Im[PolyLog[2, (-1)^(1/3)]])/(397751702040*
             Sqrt[3]) - 480*Zeta[3]) + CA*NC*(5798805729940078432486959997/
            52653831919351318656000 - (11975591*lm)/22680 - 110*lm^2 + 
           (373396883791*Pi^2)/1995840 - (657385749525779*
             Im[PolyLog[2, (-1)^(1/3)]])/(795503404080*Sqrt[3]) + 
           240*Zeta[3])), (6892406894215677661127983434608780279*CF^2*NC)/
        3386918774376653252571394560000 - (3737023831*CF^2*lm*NC)/153679680 - 
       (69*CF^2*lm^2*NC)/4 - (49401766878482172355326441294289*CF*NM*NC)/
        14192529681948460210368000 + (13015434511*CF*lm*NM*NC)/1383117120 + 
       (23*CF*lm^2*NM*NC)/12 + (698455708205581*CF*NC*NL)/2904545952000 + 
       (13015434511*CF*lm*NC*NL)/1383117120 + (23*CF*lm^2*NC*NL)/12 + 
       (4264301993408058586704441384452173297*CF*NC*NH)/
        1317265581707541958510364778432000 + (13015434511*CF*lm*NC*NH)/
        1383117120 + (23*CF*lm^2*NC*NH)/12 - 
       (79438506536665879*CF^2*NC*Pi^2)/143844180480 - (CF^2*lm*NC*Pi^2)/6 + 
       (88274133698*CF*NM*NC*Pi^2)/93555 + (CF*lm*NM*NC*Pi^2)/54 - 
       (3547609*CF*NC*NL*Pi^2)/748440 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (746517903774187*CF^2*NC*Pi^3)/
        (4909392436608*Sqrt[3]) - (15586265918755*CF*NC*NH*Pi^3)/
        (41841412812*Sqrt[3]) - (2527*CF^2*NC*Pi^4)/864 - 
       (48273646079485861327*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (66154063083292800*Sqrt[3]) + (634216020294179*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) - 
       (577*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (746517903774187*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (132583900680*Sqrt[3]) - (1781287533572*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) - 
       (746517903774187*CF^2*NC*Pi*Log[3]^2)/(6364027232640*Sqrt[3]) - 
       (445321883393*CF*NC*NH*Pi*Log[3]^2)/(1549681956*Sqrt[3]) + 
       CF*((-482493810090696953*CF*NC)/72778305600 + 2442*CF*lm*NC + 
         CA*(3381009750136427911/1018896278400 + (4477*lm)/3)*NC + 
         (1976785167020353*NM*NC)/174594420 - (814*lm*NM*NC)/3 - 
         (3025*NC*NL)/9 - (814*lm*NC*NL)/3 - (76422576787*NC*NH)/
          634053420 - (814*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-73705765591*CA + 40*(3705310177*CF - 
            693*(9095594*NM + 407*NL)))*Log[x]^3)/62370 + 
       (115*CF^2*NC*PolyGamma[2, 1])/6 - (2128*CF*NM*NC*PolyGamma[2, 1])/
        27 - (649*CF*NC*NH*PolyGamma[2, 1])/6 + 
       CA*CF*NC*(-6894055788903816648390858764824649231/
          6773837548753306505142789120000 - (253*lm^2)/24 + 
         (79438888192293463*Pi^2)/287688360960 + (746517903774187*Pi^3)/
          (9818784873216*Sqrt[3]) + (12763*Pi^4)/8640 + 
         lm*(-16389402031/251475840 - (11*Pi^2)/108) + 
         (48273646079485861327*Im[PolyLog[2, (-1)^(1/3)]])/
          (132308126166585600*Sqrt[3]) + (577*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 + (746517903774187*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (265167801360*Sqrt[3]) + (746517903774187*Pi*Log[3]^2)/
          (12728054465280*Sqrt[3]) - (115*PolyGamma[2, 1])/12 - 
         (592167193663*Zeta[3])/997920) + (592296590623*CF^2*NC*Zeta[3])/
        498960 - (54544364*CF*NM*NC*Zeta[3])/27 - (2048*CF*NC*NL*Zeta[3])/
        9 + (307*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((1859487201745972733443*NM*NC)/2540267624594700 + 
         (9688691*lm*NM*NC)/124740 + 22*lm^2*NM*NC - (22487040623*NC*NL)/
          104781600 + (9688691*lm*NC*NL)/124740 + 22*lm^2*NC*NL - 
         (625764460560972416782872239*NC*NH)/225521447992073907874200 + 
         (9688691*lm*NC*NH)/124740 + 22*lm^2*NC*NH + (9094901*NM*NC*Pi^2)/
          9 - (341*NC*NL*Pi^2)/9 + (1781287533572*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(387420489*Sqrt[3]) + 
         CF*NC*(-78240305578574363779898799299/184288411717729615296000 - 
           (83711*lm)/13860 - 198*lm^2 - (590308087183*Pi^2)/997920 + 
           (746517903774187*Im[PolyLog[2, (-1)^(1/3)]])/(397751702040*
             Sqrt[3]) - 528*Zeta[3]) + CA*NC*(15599064184918293808055603203/
            73715364687091846118400 - (13181411*lm)/22680 - 121*lm^2 + 
           (590344603663*Pi^2)/1995840 - (746517903774187*
             Im[PolyLog[2, (-1)^(1/3)]])/(795503404080*Sqrt[3]) + 
           264*Zeta[3])), (5140498368006288004302542190102551406509*CF^2*NC)/
        609556509798965544998497835520000 - (3909379861*CF^2*lm*NC)/
        153679680 - 18*CF^2*lm^2*NC - (186159907173435107065107361932003499*
         CF*NM*NC)/34536101728053383075909491200 + 
       (13591199701*CF*lm*NM*NC)/1383117120 + 2*CF*lm^2*NM*NC + 
       (4720590217022947*CF*NC*NL)/17427275712000 + 
       (13591199701*CF*lm*NC*NL)/1383117120 + 2*CF*lm^2*NC*NL + 
       (593193354064244421111746736343677255047*CF*NC*NH)/
        165185103946125761597199743215372800 + (13591199701*CF*lm*NC*NH)/
        1383117120 + 2*CF*lm^2*NC*NH - (554318487252025829*CF^2*NC*Pi^2)/
        239740300800 - (CF^2*lm*NC*Pi^2)/6 + (366778494101*CF*NM*NC*Pi^2)/
        249480 + (CF*lm*NM*NC*Pi^2)/54 - (482288*CF*NC*NL*Pi^2)/93555 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (7365474785631145*CF^2*NC*Pi^3)/(44184531929472*Sqrt[3]) - 
       (104731360750765*CF*NC*NH*Pi^3)/(251048476872*Sqrt[3]) - 
       (4601*CF^2*NC*Pi^4)/1440 - (95191817534864355791*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(119077313549927040*Sqrt[3]) + 
       (4372145423941403*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2196674172630*Sqrt[3]) - (625*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        2 - (1473094957126229*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (238651021224*Sqrt[3]) - (5984649185758*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (1473094957126229*CF^2*NC*Pi*Log[3]^2)/(11455249018752*Sqrt[3]) - 
       (2992324592879*CF*NC*NH*Pi*Log[3]^2)/(9298091736*Sqrt[3]) + 
       (CF*NC*(23*CA*(53734307412447730669 + 6454730565803520*lm) + 
          66*(69*CF*(-542618232339808367 + 53344880709120*lm) - 
            224*(3*(-35421295190124941 + 608597349360*lm)*NM + 
              22*(334639305*(305 + 248*lm)*NL + 4*(9372834481 + 20747636910*
                   lm)*NH))))*Log[x]^2)/89051534732160 + 
       (CF*NC*(304510583175*CA + 8*(-76242683656*CF + 
            1155*(42226963*NM + 1364*NL)))*Log[x]^3)/62370 + 
       26*CF^2*NC*PolyGamma[2, 1] - (839*CF*NM*NC*PolyGamma[2, 1])/9 - 
       (3395*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-1763302408954677291633903625529200295895899/
          418155765722090363868969515166720000 - 11*lm^2 + 
         (554319225712209829*Pi^2)/479480601600 + (7365474785631145*Pi^3)/
          (88369063858944*Sqrt[3]) + (13931*Pi^4)/8640 + 
         lm*(-17111861461/251475840 - (11*Pi^2)/108) + 
         (95191817534864355791*Im[PolyLog[2, (-1)^(1/3)]])/
          (238154627099854080*Sqrt[3]) + (625*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 + (1473094957126229*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (477302042448*Sqrt[3]) + (1473094957126229*Pi*Log[3]^2)/
          (22910498037504*Sqrt[3]) - 13*PolyGamma[2, 1] - 
         (487788916973*Zeta[3])/199584) + (487818133853*CF^2*NC*Zeta[3])/
        99792 - (28140643*CF*NM*NC*Zeta[3])/9 - (767*CF*NC*NL*Zeta[3])/3 + 
       (988*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((12356783602334785698125201*NM*NC)/9214639360529803200 + 
         (2628629*lm*NM*NC)/31185 + (143*lm^2*NM*NC)/6 - 
         (155442823553*NC*NL)/628689600 + (2628629*lm*NC*NL)/31185 + 
         (143*lm^2*NC*NL)/6 - (319305570286976807300772069509*NC*NH)/
          102837780284385701990635200 + (2628629*lm*NC*NH)/31185 + 
         (143*lm^2*NC*NH)/6 + (84449251*NM*NC*Pi^2)/54 - 
         (2299*NC*NL*Pi^2)/54 + (5984649185758*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CF*NC*(-289495887352077584160207893336587/
            119750609934180704019340800 - (109121*lm)/13860 - (429*lm^2)/2 - 
           (487365256505*Pi^2)/199584 + (1473094957126229*
             Im[PolyLog[2, (-1)^(1/3)]])/(715953063672*Sqrt[3]) - 
           572*Zeta[3]) + CA*NC*(1446624925660182131245530042359939/
            1197506099341807040193408000 - (1787287*lm)/2835 - 
           (1573*lm^2)/12 + (487373616857*Pi^2)/399168 - 
           (1473094957126229*Im[PolyLog[2, (-1)^(1/3)]])/(1431906127344*
             Sqrt[3]) + 286*Zeta[3])), 
      (11501581024319657843138830209873140988659*CF^2*NC)/
        853379113718551762997896969728000 - (4081735891*CF^2*lm*NC)/
        153679680 - (75*CF^2*lm^2*NC)/4 - (2458250353348081815741030785617*CF*
         NM*NC)/106710749488334287296000 + (14166964891*CF*lm*NM*NC)/
        1383117120 + (25*CF*lm^2*NM*NC)/12 + (7436657402259149*CF*NC*NL)/
        23962504104000 + (14166964891*CF*lm*NC*NL)/1383117120 + 
       (25*CF*lm^2*NC*NL)/12 + (115562559388564268216581534791533825810843*
         CF*NC*NH)/28156551808998709363159047138984000000 + 
       (14166964891*CF*lm*NC*NH)/1383117120 + (25*CF*lm^2*NC*NH)/12 - 
       (242844778595175761*CF^2*NC*Pi^2)/65383718400 - (CF^2*lm*NC*Pi^2)/6 + 
       (339205561459*CF*NM*NC*Pi^2)/53460 + (CF*lm*NM*NC*Pi^2)/54 - 
       (4210579*CF*NC*NL*Pi^2)/748440 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (8268756687441053*CF^2*NC*Pi^3)/
        (44184531929472*Sqrt[3]) - (45310295194360*CF*NC*NH*Pi^3)/
        (94143178827*Sqrt[3]) - (15079*CF^2*NC*Pi^4)/4320 - 
       (479772559969062634343*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (595386567749635200*Sqrt[3]) + (82558792476029992*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(36245123848395*Sqrt[3]) - 
       (677*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (8268756687441053*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1193255106120*Sqrt[3]) - (20713277803136*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) - 
       (8268756687441053*CF^2*NC*Pi*Log[3]^2)/(57276245093760*Sqrt[3]) - 
       (1294579862696*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) + 
       CF*((-431446172002783058389*CF*NC)/9679514644800 + 3092*CF*lm*NC + 
         CA*(143843918915136005183/6453009763200 + (17006*lm)/9)*NC + 
         (699662558983943*NM*NC)/9189180 - (3092*lm*NM*NC)/9 - 
         (3782*NC*NL)/9 - (3092*lm*NC*NL)/9 - (1057806311489*NC*NH)/
          6692786100 - (3092*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-973354502061*CA + 1948865442358*CF - 
          36960*(90007210*NM + 773*NL))*Log[x]^3)/124740 + 
       (125*CF^2*NC*PolyGamma[2, 1])/6 - (5551*CF*NM*NC*PolyGamma[2, 1])/
        54 - (3712*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-2818008502280026218739175837071829696188327/
          418155765722090363868969515166720000 - (275*lm^2)/24 + 
         (242845007965206161*Pi^2)/130767436800 + (8268756687441053*Pi^3)/
          (88369063858944*Sqrt[3]) + (5069*Pi^4)/2880 + 
         lm*(-17834320891/251475840 - (11*Pi^2)/108) + 
         (479772559969062634343*Im[PolyLog[2, (-1)^(1/3)]])/
          (1190773135499270400*Sqrt[3]) + (677*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 + (8268756687441053*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2386510212240*Sqrt[3]) + (8268756687441053*Pi*Log[3]^2)/
          (114552490187520*Sqrt[3]) - (125*PolyGamma[2, 1])/12 - 
         (3896630776733*Zeta[3])/997920) + (3896793548573*CF^2*NC*Zeta[3])/
        498960 - (359992429*CF*NM*NC*Zeta[3])/27 - (2626*CF*NC*NL*Zeta[3])/
        9 + (1652*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((23412176118924753209897*NM*NC)/3208759104751200 + 
         (11478941*lm*NM*NC)/124740 + 26*lm^2*NM*NC - (62844921859*NC*NL)/
          216112050 + (11478941*lm*NC*NL)/124740 + 26*lm^2*NC*NL - 
         (13793304828189662431479853993991*NC*NH)/
          3856416760664463824648820000 + (11478941*lm*NC*NH)/124740 + 
         26*lm^2*NC*NH + (180011848*NM*NC*Pi^2)/27 - (1312*NC*NL*Pi^2)/
          27 + (20713277803136*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*(-2560315123805203671871942208965381/
            598753049670903520096704000 - (127601*lm)/13860 - 234*lm^2 - 
           (3894262546253*Pi^2)/997920 + (8268756687441053*
             Im[PolyLog[2, (-1)^(1/3)]])/(3579765318360*Sqrt[3]) - 
           624*Zeta[3]) + CA*NC*(511877819365882225312352579646269/
            239501219868361408038681600 - (15606701*lm)/22680 - 143*lm^2 + 
           (3894309633293*Pi^2)/1995840 - (8268756687441053*
             Im[PolyLog[2, (-1)^(1/3)]])/(7159530636720*Sqrt[3]) + 
           312*Zeta[3])), (199011168769127035623015068781372270269858083*CF^2*
         NC)/3494587470677469469476388091036160000 - 
       (718954874899*CF^2*lm*NC)/25971865920 - (39*CF^2*lm^2*NC)/2 - 
       (778109009637988637476489616279508973579*CF*NM*NC)/
        21585063580033364422443432000000 + (2491534723939*CF*lm*NM*NC)/
        233746793280 + (13*CF*lm^2*NM*NC)/6 + 
       (1403867652212264381*CF*NC*NL)/4049663193576000 + 
       (2491534723939*CF*lm*NC*NL)/233746793280 + (13*CF*lm^2*NC*NL)/6 + 
       (60917417404121267406733328145282922223189*CF*NC*NH)/
        13466176952129817521510848631688000000 + (2491534723939*CF*lm*NC*NH)/
        233746793280 + (13*CF*lm^2*NC*NH)/6 - 
       (29634910201568916247*CF^2*NC*Pi^2)/1869974346240 - 
       (CF^2*lm*NC*Pi^2)/6 + (24293458033079*CF*NM*NC*Pi^2)/2432430 + 
       (CF*lm*NM*NC*Pi^2)/54 - (59138077*CF*NC*NL*Pi^2)/9729720 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (1053192585177534437*CF^2*NC*Pi^3)/(5169590235748224*Sqrt[3]) - 
       (100722682588745*CF*NC*NH*Pi^3)/(188286357654*Sqrt[3]) - 
       (3271*CF^2*NC*Pi^4)/864 - (793637088731599009394771*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(905582969547195139200*Sqrt[3]) + 
       (13397318863962859*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5177874835485*Sqrt[3]) - (729*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        2 - (1053192585177534437*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(139610847416040*Sqrt[3]) - 
       (23022327448856*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) - (1053192585177534437*CF^2*NC*Pi*Log[3]^2)/
        (6701320675969920*Sqrt[3]) - (2877790931107*CF*NC*NH*Pi*Log[3]^2)/
        (6973568802*Sqrt[3]) + CF*((-23930667039934212497549*CF*NC)/
          125833690382400 + 3428*CF*lm*NC + 
         CA*(23931901877459085618469/251667380764800 + (18854*lm)/9)*NC + 
         (2406334985598240707*NM*NC)/20078358300 - (3428*lm*NM*NC)/9 - 
         (4166*NC*NL)/9 - (3428*lm*NC*NL)/9 - (3980549009*NC*NH)/
          22383900 - (3428*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-53440721949021*CA + 130*(822410534059*CF - 
            3696*(140894098*NM + 857*NL)))*Log[x]^3)/1621620 + 
       (169*CF^2*NC*PolyGamma[2, 1])/6 - (3230*CF*NM*NC*PolyGamma[2, 1])/
        27 - (4258*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-55723745745538594317809634877306533341852989/
          1956968983579382902906777330980249600 - (143*lm^2)/12 + 
         (29634917631864428887*Pi^2)/3739948692480 + 
         (1053192585177534437*Pi^3)/(10339180471496448*Sqrt[3]) + 
         (16483*Pi^4)/8640 + lm*(-3136109214499/42499416960 - 
           (11*Pi^2)/108) + (793637088731599009394771*
           Im[PolyLog[2, (-1)^(1/3)]])/(1811165939094390278400*Sqrt[3]) + 
         (729*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (1053192585177534437*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (279221694832080*Sqrt[3]) + (1053192585177534437*Pi*Log[3]^2)/
          (13402641351939840*Sqrt[3]) - (169*PolyGamma[2, 1])/12 - 
         (5482303021267*Zeta[3])/332640) + (5482363765027*CF^2*NC*Zeta[3])/
        166320 - (563536726*CF*NM*NC*Zeta[3])/27 - (2926*CF*NC*NL*Zeta[3])/
        9 + (1792*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((10175337505085117296981974329*NM*NC)/806280944046357780000 + 
         (160951793*lm*NM*NC)/1621620 + 28*lm^2*NM*NC - 
         (7434264546851*NC*NL)/22475653200 + (160951793*lm*NC*NL)/1621620 + 
         28*lm^2*NC*NL - (666081250313987548328135526313*NC*NH)/
          167670293941933209767340000 + (160951793*lm*NC*NH)/1621620 + 
         28*lm^2*NC*NH + (281785330*NM*NC*Pi^2)/27 - (1462*NC*NL*Pi^2)/
          27 + (23022327448856*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*
          (-1510849608640718122249494252378079489/
            70054106811495711851314368000 - (2033033*lm)/180180 - 252*lm^2 - 
           (71258363884951*Pi^2)/4324320 + (1053192585177534437*
             Im[PolyLog[2, (-1)^(1/3)]])/(418832542248120*Sqrt[3]) - 
           672*Zeta[3]) + CA*NC*(215819150731028918047114577705368171/
            20015459088998774814661248000 - (218740433*lm)/294840 - 
           154*lm^2 + (71258594835671*Pi^2)/8648640 - 
           (1053192585177534437*Im[PolyLog[2, (-1)^(1/3)]])/
            (837665084496240*Sqrt[3]) + 336*Zeta[3])), 
      (561254636786610776470442074443913031280902053*CF^2*NC)/
        6115528073685571571583679159313280000 - (748096384219*CF^2*lm*NC)/
        25971865920 - (81*CF^2*lm^2*NC)/4 - 
       (27075649133169470280551815449048604529*CF*NM*NC)/
        172680508640266915379547456000 + (2588852381299*CF*lm*NM*NC)/
        233746793280 + (9*CF*lm^2*NM*NC)/4 + (6363632845245094511*CF*NC*NL)/
        16198652774304000 + (2588852381299*CF*lm*NC*NL)/233746793280 + 
       (9*CF*lm^2*NC*NL)/4 + (14265099537315059515491328371169294132285523*
         CF*NC*NH)/2787498629090872226952745666759416000000 + 
       (2588852381299*CF*lm*NC*NH)/233746793280 + (9*CF*lm^2*NC*NH)/4 - 
       (11425793961074675263*CF^2*NC*Pi^2)/445231987200 - 
       (CF^2*lm*NC*Pi^2)/6 + (9690621742021*CF*NM*NC*Pi^2)/221130 + 
       (CF*lm*NM*NC*Pi^2)/54 - (64079167*CF*NC*NL*Pi^2)/9729720 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (1171047885051135125*CF^2*NC*Pi^3)/(5169590235748224*Sqrt[3]) - 
       (2067606001884185*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) - 
       (657*CF^2*NC*Pi^4)/160 - (159119337452113911513343*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(181116593909439027840*Sqrt[3]) + 
       (957321095326641149*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (326206114635555*Sqrt[3]) - (785*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 - (234209577010227025*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27922169483208*Sqrt[3]) - 
       (236297828786764*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) - (234209577010227025*CF^2*NC*Pi*Log[3]^2)/
        (1340264135193984*Sqrt[3]) - (59074457196691*CF*NC*NH*Pi*Log[3]^2)/
        (125524238436*Sqrt[3]) + CF*((-861135861514174939921*CF*NC)/
          2796304230720 + 3848*CF*lm*NC + 
         CA*(7750499961839396523793/50333476152960 + (21164*lm)/9)*NC + 
         (2111751581584092407*NM*NC)/4015671660 - (3848*lm*NM*NC)/9 - 
         (4654*NC*NL)/9 - (3848*lm*NC*NL)/9 - (1110203491039*NC*NH)/
          5475915900 - (3848*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-86170531244693*CA + 172378028318894*CF - 
          480480*(612667357*NM + 962*NL))*Log[x]^3)/1621620 + 
       (45*CF^2*NC*PolyGamma[2, 1])/2 - (3542*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (9269*CF*NC*NH*PolyGamma[2, 1])/54 + 
       CA*CF*NC*(-2245035297127644231855786526855537090841147971/
          48924224589484572572669433274506240000 - (99*lm^2)/8 + 
         (3808598645905710541*Pi^2)/296821324800 + (1171047885051135125*Pi^3)/
          (10339180471496448*Sqrt[3]) + (17867*Pi^4)/8640 + 
         lm*(-3258218198419/42499416960 - (11*Pi^2)/108) + 
         (159119337452113911513343*Im[PolyLog[2, (-1)^(1/3)]])/
          (362233187818878055680*Sqrt[3]) + 
         (785*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (234209577010227025*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55844338966416*Sqrt[3]) + (234209577010227025*Pi*Log[3]^2)/
          (2680528270387968*Sqrt[3]) - (45*PolyGamma[2, 1])/4 - 
         (68946882887161*Zeta[3])/2594592) + (68947407283033*CF^2*NC*Zeta[3])/
        1297296 - (2450624752*CF*NM*NC*Zeta[3])/27 - 
       (3304*CF*NC*NL*Zeta[3])/9 + (859*CF*NC*NH*Zeta[3])/3 + 
       CF*Log[x]*((510436474752645983156164469*NM*NC)/8062809440463577800 + 
         (174479153*lm*NM*NC)/1621620 + (91*lm^2*NM*NC)/3 - 
         (17204974587847*NC*NL)/44951306400 + (174479153*lm*NC*NL)/
          1621620 + (91*lm^2*NC*NL)/3 - (892265862032293388511316251641*NC*
           NH)/197203129806705536487723750 + (174479153*lm*NC*NH)/1621620 + 
         (91*lm^2*NC*NH)/3 + (1225331581*NM*NC*Pi^2)/27 - 
         (1651*NC*NL*Pi^2)/27 + (236297828786764*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CF*NC*(-521145984552111236478994605431567909/
            14010821362299142370262873600 - (2317163*lm)/180180 - 273*lm^2 - 
           (68939175939913*Pi^2)/2594592 + (234209577010227025*
             Im[PolyLog[2, (-1)^(1/3)]])/(83766508449624*Sqrt[3]) - 
           728*Zeta[3]) + CA*NC*(236873240411262795362044150078043963/
            12737110329362856700238976000 - (237083513*lm)/294840 - 
           (1001*lm^2)/6 + (68939330654473*Pi^2)/5189184 - 
           (234209577010227025*Im[PolyLog[2, (-1)^(1/3)]])/(167533016899248*
             Sqrt[3]) + 364*Zeta[3])), 
      (234639653790936430846676568921640400238504270243367*CF^2*NC)/
        595261040580258794491668994650917422080000 - 
       (777248478619*CF^2*lm*NC)/25971865920 - 21*CF^2*lm^2*NC - 
       (1233512542220471616747244848714935917531*CF*NM*NC)/
        4981168518469237943640792000000 + (2686180623739*CF*lm*NM*NC)/
        233746793280 + (7*CF*lm^2*NM*NC)/3 + (57602958668188169*CF*NC*NL)/
        132233900198400 + (2686180623739*CF*lm*NC*NL)/233746793280 + 
       (7*CF*lm^2*NC*NL)/3 + (21270677649171191663854553541857171290223*CF*
         NC*NH)/3792515141620234322384687981985600000 + 
       (2686180623739*CF*lm*NC*NH)/233746793280 + (7*CF*lm^2*NC*NH)/3 - 
       (1039608316903021131991*CF^2*NC*Pi^2)/9349871731200 - 
       (CF^2*lm*NC*Pi^2)/6 + (19345809311593*CF*NM*NC*Pi^2)/277992 + 
       (CF*lm*NM*NC*Pi^2)/54 - (68841067*CF*NC*NL*Pi^2)/9729720 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (422401360819623091*CF^2*NC*Pi^3)/(1723196745249408*Sqrt[3]) - 
       (1521964460627345*CF*NC*NH*Pi^3)/(2259436291848*Sqrt[3]) - 
       (19123*CF^2*NC*Pi^4)/4320 - (859847446362761047798499*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(905582969547195139200*Sqrt[3]) + 
       (143606963842953001*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (43494148618074*Sqrt[3]) - (841*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        2 - (422401360819623091*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(46536949138680*Sqrt[3]) - 
       (86969397750134*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (422401360819623091*CF^2*NC*Pi*Log[3]^2)/
        (2233773558656640*Sqrt[3]) - (43484698875067*CF*NC*NH*Pi*Log[3]^2)/
        (83682825624*Sqrt[3]) + CF*((-351058077112869788934553*CF*NC)/
          263106807163200 + 4238*CF*lm*NC + 
         CA*(143024962602367099092809/214383324355200 + (23309*lm)/9)*NC + 
         (4191829944585635467*NM*NC)/5019589575 - (4238*lm*NM*NC)/9 - 
         (5096*NC*NL)/9 - (4238*lm*NC*NL)/9 - (32443806464*NC*NH)/
          143416845 - (4238*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(370352194734235*CA - 740746155421878*CF + 
          240240*(1936805675*NM + 2119*NL))*Log[x]^3)/1621620 + 
       (91*CF^2*NC*PolyGamma[2, 1])/3 - (4067*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (5257*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-10665458945526651688201804820275295781965877321889/
          54114640052750799499242635877356129280000 - (77*lm^2)/6 + 
         (1039608363121396114771*Pi^2)/18699743462400 + 
         (422401360819623091*Pi^3)/(3446393490498816*Sqrt[3]) + 
         (713*Pi^4)/320 + lm*(-3380337767419/42499416960 - (11*Pi^2)/108) + 
         (859847446362761047798499*Im[PolyLog[2, (-1)^(1/3)]])/
          (1811165939094390278400*Sqrt[3]) + 
         (841*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (422401360819623091*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (93073898277360*Sqrt[3]) + (422401360819623091*Pi*Log[3]^2)/
          (4467547117313280*Sqrt[3]) - (91*PolyGamma[2, 1])/6 - 
         (1481467052327497*Zeta[3])/12972960) + 
       (1481469966198457*CF^2*NC*Zeta[3])/6486480 - 
       (3873562927*CF*NM*NC*Zeta[3])/27 - (3655*CF*NC*NL*Zeta[3])/9 + 
       (2800*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((24711981746083502018867911811*NM*NC)/230365984013245080000 + 
         (187194713*lm*NM*NC)/1621620 + (65*lm^2*NM*NC)/2 - 
         (38728315479449*NC*NL)/89902612800 + (187194713*lm*NC*NL)/
          1621620 + (65*lm^2*NC*NL)/2 - (23104329819294099133016339732513*NC*
           NH)/4627700112797356589578584000 + (187194713*lm*NC*NH)/
          1621620 + (65*lm^2*NC*NH)/2 + (3873604421*NM*NC*Pi^2)/54 - 
         (3653*NC*NL*Pi^2)/54 + (86969397750134*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-2218255562136023993081464856742748330853/
            12352874167760410523115100224000 - (1367719*lm)/90090 - 
           (585*lm^2)/2 - (211631994802711*Pi^2)/1853280 + 
           (422401360819623091*Im[PolyLog[2, (-1)^(1/3)]])/(139610847416040*
             Sqrt[3]) - 780*Zeta[3]) + 
         CA*NC*(2218232322539791414155993186121401756107/
            24705748335520821046230200448000 - (254270813*lm)/294840 - 
           (715*lm^2)/4 + (211632118697911*Pi^2)/3706560 - 
           (422401360819623091*Im[PolyLog[2, (-1)^(1/3)]])/(279221694832080*
             Sqrt[3]) + 390*Zeta[3])), 
      (1142750443982299836953760176619652156040366201659993*CF^2*NC)/
        1785783121740776383475006983952752266240000 - 
       (806400573019*CF^2*lm*NC)/25971865920 - (87*CF^2*lm^2*NC)/4 - 
       (23586352529442578043430265488900934339521*CF*NM*NC)/
        21585063580033364422443432000000 + (2783508866179*CF*lm*NM*NC)/
        233746793280 + (29*CF*lm^2*NM*NC)/12 + 
       (5149264482423512107*CF*NC*NL)/10529124303297600 + 
       (2783508866179*CF*lm*NC*NL)/233746793280 + (29*CF*lm^2*NC*NL)/12 + 
       (1282691269539310458641099237740717794921520498309*CF*NC*NH)/
        203952912194691848229451542199786190472000000 + 
       (2783508866179*CF*lm*NC*NH)/233746793280 + (29*CF*lm^2*NC*NH)/12 - 
       (823397435912481134609*CF^2*NC*Pi^2)/4541366269440 - 
       (CF^2*lm*NC*Pi^2)/6 + (43011926895563*CF*NM*NC*Pi^2)/138996 + 
       (CF*lm*NM*NC*Pi^2)/54 - (74143507*CF*NC*NL*Pi^2)/9729720 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (4192658457496366079*CF^2*NC*Pi^3)/(15508770707244672*Sqrt[3]) - 
       (3867020149944385*CF*NC*NH*Pi^3)/(5083731656658*Sqrt[3]) - 
       (4123*CF^2*NC*Pi^4)/864 - (2572606917316653170012357*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2716748908641585417600*Sqrt[3]) + 
       (47264847547946426018*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12722038470786645*Sqrt[3]) - (901*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 - (4192658457496366079*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(418832542248120*Sqrt[3]) - 
       (883890319987288*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31381059609*Sqrt[3]) - (4192658457496366079*CF^2*NC*Pi*Log[3]^2)/
        (20103962027909760*Sqrt[3]) - (110486289998411*CF*NC*NH*Pi*Log[3]^2)/
        (188286357654*Sqrt[3]) + CF*((-6296947152198711393058903*CF*NC)/
          2894174878795200 + 4718*CF*lm*NC + 
         CA*(6296986271139049609368863/5788349757590400 + (25949*lm)/9)*NC + 
         (74558290761510526433*NM*NC)/20078358300 - (4718*lm*NM*NC)/9 - 
         (1883*NC*NL)/3 - (4718*lm*NC*NL)/9 - (445866439234379*NC*NH)/
          1746817172100 - (4718*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(601730450831291*CA - 1203508774044890*CF + 
          240240*(8552161634*NM + 2359*NL))*Log[x]^3)/1621620 + 
       (145*CF^2*NC*PolyGamma[2, 1])/6 - (8875*CF*NM*NC*PolyGamma[2, 1])/
        54 - (5698*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-1142751879275139297650360784330665574879938233713391/
          3571566243481552766950013967905504532480000 - (319*lm^2)/24 + 
         (9687028948838370821*Pi^2)/106855676928 + (4192658457496366079*Pi^3)/
          (31017541414489344*Sqrt[3]) + (20743*Pi^4)/8640 + 
         lm*(-3502457336419/42499416960 - (11*Pi^2)/108) + 
         (2572606917316653170012357*Im[PolyLog[2, (-1)^(1/3)]])/
          (5433497817283170835200*Sqrt[3]) + 
         (901*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (4192658457496366079*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (837665084496240*Sqrt[3]) + (4192658457496366079*Pi*Log[3]^2)/
          (40207924055819520*Sqrt[3]) - (145*PolyGamma[2, 1])/12 - 
         (185152789956049*Zeta[3])/997920) + 
       (185153036553169*CF^2*NC*Zeta[3])/498960 - 
       (17104269205*CF*NM*NC*Zeta[3])/27 - (4090*CF*NC*NL*Zeta[3])/9 + 
       (3716*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((420229335967972409836218220121*NM*NC)/806280944046357780000 + 
         (201712073*lm*NM*NC)/1621620 + 35*lm^2*NM*NC - 
         (71864974104559*NC*NL)/146091745800 + (201712073*lm*NC*NL)/
          1621620 + 35*lm^2*NC*NL - (493153174955564581904605234815043957*NC*
           NH)/87567655384407980066300755740000 + (201712073*lm*NC*NH)/
          1621620 + 35*lm^2*NC*NH + (8552157868*NM*NC*Pi^2)/27 - 
         (2044*NC*NL*Pi^2)/27 + (883890319987288*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(-34080402649566316127389636767354253499977/
            111175867509843694708035902016000 - (3063623*lm)/180180 - 
           315*lm^2 - (185149135961089*Pi^2)/997920 + 
           (4192658457496366079*Im[PolyLog[2, (-1)^(1/3)]])/
            (1256497626744360*Sqrt[3]) - 840*Zeta[3]) + 
         CA*NC*(34080179159899626076215866882267104641913/
            222351735019687389416071804032000 - (273947873*lm)/294840 - 
           (385*lm^2)/2 + (185149209881089*Pi^2)/1995840 - 
           (4192658457496366079*Im[PolyLog[2, (-1)^(1/3)]])/
            (2512995253488720*Sqrt[3]) + 420*Zeta[3])), 
      (98199423040705584058959808189068607886804265674386181*CF^2*NC)/
        35245719508041639147533032578014847360000000 - 
       (4177806034607*CF^2*lm*NC)/129859329600 - (45*CF^2*lm^2*NC)/2 - 
       (3532899300388467940747912923667447124996231741*CF*NM*NC)/
        2030547017520387224610323900328000000 + (14404228240607*CF*lm*NM*NC)/
        1168733966400 + (5*CF*lm^2*NM*NC)/2 + 
       (37820316882330077191*CF*NC*NL)/70194162021984000 + 
       (14404228240607*CF*lm*NC*NL)/1168733966400 + (5*CF*lm^2*NC*NL)/2 + 
       (599439169161220693490156443865865684331008632011*CF*NC*NH)/
        87408390940582220669764946657051224488000000 + 
       (14404228240607*CF*lm*NC*NH)/1168733966400 + (5*CF*lm^2*NC*NH)/2 - 
       (1080761608357372280659*CF^2*NC*Pi^2)/1358528371200 - 
       (CF^2*lm*NC*Pi^2)/6 + (2409163319371733*CF*NM*NC*Pi^2)/4864860 + 
       (CF*lm*NM*NC*Pi^2)/54 - (15853325*CF*NC*NL*Pi^2)/1945944 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (13539904870147534745*CF^2*NC*Pi^3)/(46526312121734016*Sqrt[3]) - 
       (25469551076405765*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) - 
       (7369*CF^2*NC*Pi^4)/1440 - (8295446573098639129060643*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8150246725924756252800*Sqrt[3]) + 
       (158223361792794096818*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (38166115412359935*Sqrt[3]) - (961*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 - (2707980974029506949*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(251299525348872*Sqrt[3]) - 
       (2910805837303516*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) - (2707980974029506949*CF^2*NC*Pi*Log[3]^2)/
        (12062377216745856*Sqrt[3]) - (727701459325879*CF*NC*NH*Pi*Log[3]^2)/
        (1129718145924*Sqrt[3]) + CF*((-2423609394905881414269511*CF*NC)/
          253874989368000 + 5166*CF*lm*NC + 
         CA*(660985405954014286217383/138477266928000 + 3157*lm)*NC + 
         (4448849781159605842081*NM*NC)/748635930900 - 574*lm*NM*NC - 
         (2051*NC*NL)/3 - 574*lm*NC*NL - (1481693126060177*NC*NH)/
          5240451516300 - 574*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-2623040204397891*CA + 5246134119802882*CF - 
          720720*(4543888208*NM + 861*NL))*Log[x]^3)/1621620 + 
       (65*CF^2*NC*PolyGamma[2, 1])/2 - (5038*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (2134*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-98199453726530141382775737938408046787662535013701181/
          70491439016083278295066065156029694720000000 - (55*lm^2)/4 + 
         (190722638204780655881*Pi^2)/479480601600 + 
         (13539904870147534745*Pi^3)/(93052624243468032*Sqrt[3]) + 
         (4447*Pi^4)/1728 + lm*(-18122927224607/212497084800 - 
           (11*Pi^2)/108) + (8295446573098639129060643*
           Im[PolyLog[2, (-1)^(1/3)]])/(16300493451849512505600*Sqrt[3]) + 
         (961*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (2707980974029506949*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (502599050697744*Sqrt[3]) + (2707980974029506949*Pi*Log[3]^2)/
          (24124754433491712*Sqrt[3]) - (65*PolyGamma[2, 1])/4 - 
         (2098446429682829*Zeta[3])/2594592) + 
       (2098447137574013*CF^2*NC*Zeta[3])/1297296 - 
       (27263270912*CF*NM*NC*Zeta[3])/27 - (4496*CF*NC*NL*Zeta[3])/9 + 
       448*CF*NC*NH*Zeta[3] + CF*Log[x]*
        ((381679193978657293938746676150709*NM*NC)/
          435910033249063002630000 + (43083553*lm*NM*NC)/324324 + 
         (112*lm^2*NM*NC)/3 - (35629706409071*NC*NL)/64929664800 + 
         (43083553*lm*NC*NL)/324324 + (112*lm^2*NC*NL)/3 - 
         (811549695285200566634412276943707773*NC*NH)/
          131351483076611970099451133610000 + (43083553*lm*NC*NH)/324324 + 
         (112*lm^2*NC*NH)/3 + (1514628943*NM*NC*Pi^2)/3 - 
         (749*NC*NL*Pi^2)/9 + (2910805837303516*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(-4456604345768521737999851609470411404839/
            3068895864276141738352113600000 - (705217*lm)/36036 - 336*lm^2 - 
           (2098435886510189*Pi^2)/2594592 + (2707980974029506949*
             Im[PolyLog[2, (-1)^(1/3)]])/(753898576046616*Sqrt[3]) - 
           896*Zeta[3]) + CA*NC*(637293490563038367557802062978148655367677/
            877704217182976537168704489600000 - (58493857*lm)/58968 - 
           (616*lm^2)/3 + (2098436100227693*Pi^2)/5189184 - 
           (2707980974029506949*Im[PolyLog[2, (-1)^(1/3)]])/
            (1507797152093232*Sqrt[3]) + 448*Zeta[3])), 
      (1016183285303609762783967963800686619943261871863758251*CF^2*NC)/
        223222890217597047934375872994094033280000000 - 
       (4323609204119*CF^2*lm*NC)/129859329600 - (93*CF^2*lm^2*NC)/4 - 
       (4527640988099915862955967338392086031949613*CF*NM*NC)/
        582796716660900839405972664000000 + (14890912150319*CF*lm*NM*NC)/
        1168733966400 + (31*CF*lm^2*NM*NC)/12 + 
       (18050351609602458733*CF*NC*NL)/30083212295136000 + 
       (14890912150319*CF*lm*NC*NL)/1168733966400 + (31*CF*lm^2*NC*NL)/12 + 
       (417316578188229669510406650120129527461922332619832829*CF*NC*NH)/
        54683650864728583655432318043064473603162168000000 + 
       (14890912150319*CF*lm*NC*NH)/1168733966400 + (31*CF*lm^2*NC*NH)/12 - 
       (207454922377868554718111*CF^2*NC*Pi^2)/158947819430400 - 
       (CF^2*lm*NC*Pi^2)/6 + (902494001848808*CF*NM*NC*Pi^2)/405405 + 
       (CF*lm*NM*NC*Pi^2)/54 - (84930283*CF*NC*NL*Pi^2)/9729720 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (4942738338319149595*CF^2*NC*Pi^3)/(15508770707244672*Sqrt[3]) - 
       (85554583483073495*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) - 
       (23707*CF^2*NC*Pi^4)/4320 - (548834030360644360191149*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(543349781728317083520*Sqrt[3]) + 
       (530317353946853853227*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (114498346237079805*Sqrt[3]) - 
       (1025*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (988547667663829919*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (83766508449624*Sqrt[3]) - (9777666683779828*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (988547667663829919*CF^2*NC*Pi*Log[3]^2)/(4020792405581952*Sqrt[3]) - 
       (2444416670944957*CF*NC*NH*Pi*Log[3]^2)/(3389154437772*Sqrt[3]) + 
       CF*((-20604054196342409832428789*CF*NC)/1315534035816000 + 
         5710*CF*lm*NC + CA*(75548277680566092855513173/9647249595984000 + 
           (31405*lm)/9)*NC + (689618848008968202799*NM*NC)/25815032100 - 
         (5710*lm*NM*NC)/9 - (6775*NC*NL)/9 - (5710*lm*NC*NL)/9 - 
         (51367913239960423*NC*NH)/162453997005300 - (5710*lm*NC*NH)/9)*
        Log[x]^2 - (CF*NC*(-4289980692705303*CA + 8580022409275258*CF - 
          240240*(60935012218*NM + 2855*NL))*Log[x]^3)/1621620 + 
       (155*CF^2*NC*PolyGamma[2, 1])/6 - (608*CF*NM*NC*PolyGamma[2, 1])/3 - 
       (13825*CF*NC*NH*PolyGamma[2, 1])/54 + 
       CA*CF*NC*(-1016183494580315993277615095202902109484658464806347251/
          446445780435194095868751745988188066560000000 - (341*lm^2)/24 + 
         (207454923416006650753151*Pi^2)/317895638860800 + 
         (4942738338319149595*Pi^3)/(31017541414489344*Sqrt[3]) + 
         (1589*Pi^4)/576 + lm*(-18733567767119/212497084800 - 
           (11*Pi^2)/108) + (548834030360644360191149*
           Im[PolyLog[2, (-1)^(1/3)]])/(1086699563456634167040*Sqrt[3]) + 
         (1025*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (988547667663829919*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (167533016899248*Sqrt[3]) + (988547667663829919*Pi*Log[3]^2)/
          (8041584811163904*Sqrt[3]) - (155*PolyGamma[2, 1])/12 - 
         (264000018285217*Zeta[3])/199584) + 
       (264000077872129*CF^2*NC*Zeta[3])/99792 - 
       (13541106644*CF*NM*NC*Zeta[3])/3 - (1664*CF*NC*NL*Zeta[3])/3 + 
       (5089*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((7607964804960191496397566380899*NM*NC)/1814132124104305005000 + 
         (230925257*lm*NM*NC)/1621620 + 40*lm^2*NM*NC - 
         (362172156494327*NC*NL)/584366983200 + (230925257*lm*NC*NL)/
          1621620 + 40*lm^2*NC*NL - 
         (2617247849170143897150413041540787217791*NC*NH)/
          378686325709872309796717618197630000 + (230925257*lm*NC*NH)/
          1621620 + 40*lm^2*NC*NH + (60935007743*NM*NC*Pi^2)/27 - 
         (2495*NC*NL*Pi^2)/27 + (9777666683779828*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(-6859998462911442275333352927128883402883817/
            2779396687746092367700897550400000 - (3898457*lm)/180180 - 
           360*lm^2 - (263999129378737*Pi^2)/199584 + 
           (988547667663829919*Im[PolyLog[2, (-1)^(1/3)]])/(251299525348872*
             Sqrt[3]) - 960*Zeta[3]) + 
         CA*NC*(40591669815498053448663568306228504610693/
            32892268494036596067466243200000 - (313480457*lm)/294840 - 
           220*lm^2 + (263999147474353*Pi^2)/399168 - 
           (988547667663829919*Im[PolyLog[2, (-1)^(1/3)]])/(502599050697744*
             Sqrt[3]) + 480*Zeta[3])), 
      (2899948169170174486094979953365589248201296206220160172081*CF^2*NC)/
        144648432861002887061475565700172933565440000000 - 
       (35755578547327*CF^2*lm*NC)/1038874636800 - 24*CF^2*lm^2*NC - 
       (291082019353641514991006918360347338960255880230071*CF*NM*NC)/
        23362437704422013277713827045666214400000 + 
       (123021048038527*CF*lm*NM*NC)/9349871731200 + (8*CF*lm^2*NM*NC)/3 + 
       (1107286164055381485143*CF*NC*NL)/1684659888527616000 + 
       (123021048038527*CF*lm*NC*NL)/9349871731200 + (8*CF*lm^2*NC*NL)/3 + 
       (1812008175830711817127485744191189665934682671986169431*CF*NC*NH)/
        218734603458914334621729272172257894412648672000000 + 
       (123021048038527*CF*lm*NC*NH)/9349871731200 + (8*CF*lm^2*NC*NH)/3 - 
       (3679616600931935669999641*CF^2*NC*Pi^2)/635791277721600 - 
       (CF^2*lm*NC*Pi^2)/6 + (23266951775694103*CF*NM*NC*Pi^2)/6486480 + 
       (CF*lm*NM*NC*Pi^2)/54 - (361658047*CF*NC*NL*Pi^2)/38918880 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (78002293288843286245*CF^2*NC*Pi^3)/(228401895870330624*Sqrt[3]) - 
       (186859046399013415*CF*NC*NH*Pi^3)/(183014339639688*Sqrt[3]) - 
       (25307*CF^2*NC*Pi^4)/4320 - (86458121406818390356222721*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(80020604218170334118400*Sqrt[3]) + 
       (106830675972852255659*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (20817881134014510*Sqrt[3]) - 
       (1089*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (15600458657768657249*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1233652215349008*Sqrt[3]) - (10677659794229338*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (15600458657768657249*CF^2*NC*Pi*Log[3]^2)/(59215306336752384*
         Sqrt[3]) - (5338829897114669*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((-669996924858946604146280587*CF*NC)/
          9647249595984000 + 6220*CF*lm*NC + 
         CA*(2009991291002861970194595691/57883497575904000 + (34210*lm)/9)*
          NC + (96450400675115938816711*NM*NC)/2240744786280 - 
         (6220*lm*NM*NC)/9 - (7345*NC*NL)/9 - (6220*lm*NC*NL)/9 - 
         (56539921766218873*NC*NH)/162453997005300 - (6220*lm*NC*NH)/9)*
        Log[x]^2 - (CF*NC*(-37841000955522591*CA + 75682137990742436*CF - 
          960960*(48921316127*NM + 1555*NL))*Log[x]^3)/3243240 + 
       (104*CF^2*NC*PolyGamma[2, 1])/3 - (2051*CF*NM*NC*PolyGamma[2, 1])/9 - 
       (7703*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-2899948315604049450535969508810019017034637749935639669081/
          289296865722005774122951131400345867130880000000 - (44*lm^2)/3 + 
         (3679616605452998546890201*Pi^2)/1271582555443200 + 
         (78002293288843286245*Pi^3)/(456803791740661248*Sqrt[3]) + 
         (5087*Pi^4)/1728 + lm*(-154753946035327/1699976678400 - 
           (11*Pi^2)/108) + (86458121406818390356222721*
           Im[PolyLog[2, (-1)^(1/3)]])/(160041208436340668236800*Sqrt[3]) + 
         (1089*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (15600458657768657249*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2467304430698016*Sqrt[3]) + (15600458657768657249*Pi*Log[3]^2)/
          (118430612673504768*Sqrt[3]) - (52*PolyGamma[2, 1])/3 - 
         (50454725423436443*Zeta[3])/8648640) + 
       (50454728257787963*CF^2*NC*Zeta[3])/4324320 - 
       (65228398345*CF*NM*NC*Zeta[3])/9 - (1819*CF*NC*NL*Zeta[3])/3 + 
       612*CF*NC*NH*Zeta[3] + CF*Log[x]*
        ((567918080175161752180587011477939417*NM*NC)/
          80892877066660601894952000 + (982484753*lm*NM*NC)/6486480 + 
         (85*lm^2*NM*NC)/2 - (100236164825813*NC*NL)/146091745800 + 
         (982484753*lm*NC*NL)/6486480 + (85*lm^2*NC*NL)/2 - 
         (5713324807151367830334966998295484542637*NC*NH)/
          757372651419744619593435236395260000 + (982484753*lm*NC*NH)/
          6486480 + (85*lm^2*NC*NH)/2 + (195685254733*NM*NC*Pi^2)/54 - 
         (5455*NC*NL*Pi^2)/54 + (10677659794229338*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(-10439018240582334141383464011333399259501475501/
            900524526829733927135090806329600000 - (17620853*lm)/720720 - 
           (765*lm^2)/2 - (16818227652707851*Pi^2)/2882880 + 
           (15600458657768657249*Im[PolyLog[2, (-1)^(1/3)]])/
            (3700956646047024*Sqrt[3]) - 1020*Zeta[3]) + 
         CA*NC*(5219508054234053260930548679979781849557370163/
            900524526829733927135090806329600000 - (1333344353*lm)/1179360 - 
           (935*lm^2)/4 + (16818227941316171*Pi^2)/5765760 - 
           (15600458657768657249*Im[PolyLog[2, (-1)^(1/3)]])/
            (7401913292094048*Sqrt[3]) + 510*Zeta[3])), 
      (1588472098338599894398589694361718144791765053206138296963*CF^2*NC)/
        48216144287000962353825188566724311188480000000 - 
       (18461141730851*CF^2*lm*NC)/519437318400 - (99*CF^2*lm^2*NC)/4 - 
       (53687849340283164491986998533954787257206825231*CF*NM*NC)/
        955551537656652811581328894272000000 + (63457399437251*CF*lm*NM*NC)/
        4674935865600 + (11*CF*lm^2*NM*NC)/4 + 
       (122442948271470634037*CF*NC*NL)/168465988852761600 + 
       (63457399437251*CF*lm*NC*NL)/4674935865600 + (11*CF*lm^2*NC*NL)/4 + 
       (61628453790202408705020481951561765714497705203998669*CF*NC*NH)/
        6730295491043517988360900682223319828081497600000 + 
       (63457399437251*CF*lm*NC*NH)/4674935865600 + (11*CF*lm^2*NC*NH)/4 - 
       (12813290017890977519098561*CF^2*NC*Pi^2)/1342226030745600 - 
       (CF^2*lm*NC*Pi^2)/6 + (52772204796916907*CF*NM*NC*Pi^2)/3243240 + 
       (CF*lm*NM*NC*Pi^2)/54 - (192878561*CF*NC*NL*Pi^2)/19459440 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (23947503777228618325*CF^2*NC*Pi^3)/(64421047553170176*Sqrt[3]) - 
       (25960476471583360*CF*NC*NH*Pi^3)/(22876792454961*Sqrt[3]) - 
       (1801*CF^2*NC*Pi^4)/288 - (24084932535279778560288497*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22569914010253171161600*Sqrt[3]) + 
       (652274627920398965024*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (114498346237079805*Sqrt[3]) - 
       (1157*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (4789500755445723665*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (347953188944592*Sqrt[3]) - (11867646387009536*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (4789500755445723665*CF^2*NC*Pi*Log[3]^2)/(16701753069340416*
         Sqrt[3]) - (741727899188096*CF*NC*NH*Pi*Log[3]^2)/
        (847288609443*Sqrt[3]) + CF*((-135324041554370706249309527*CF*NC)/
          1181295868896000 + 6832*CF*lm*NC + 
         CA*(6630879170520756243580649983/115766995151808000 + (37576*lm)/9)*
          NC + (10943707866598562434363*NM*NC)/56047609800 - 
         (6832*lm*NM*NC)/9 - (2680*NC*NL)/3 - (6832*lm*NC*NL)/9 - 
         (25099108948399159*NC*NH)/64981598802120 - (6832*lm*NC*NH)/9)*
        Log[x]^2 + (CF*NC*(15561930862859407*CA - 31123900079760415*CF + 
          240240*(220895861783*NM + 1708*NL))*Log[x]^3)/810810 + 
       (55*CF^2*NC*PolyGamma[2, 1])/2 - (493*CF*NM*NC*PolyGamma[2, 1])/2 - 
       (8288*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-1588472150757641658530803051851971463187991419726045135963/
          96432288574001924707650377133448622376960000000 - (121*lm^2)/8 + 
         (2023151057086422863681297*Pi^2)/423860851814400 + 
         (23947503777228618325*Pi^3)/(128842095106340352*Sqrt[3]) + 
         (27143*Pi^4)/8640 + lm*(-79819674966851/849988339200 - 
           (11*Pi^2)/108) + (24084932535279778560288497*
           Im[PolyLog[2, (-1)^(1/3)]])/(45139828020506342323200*Sqrt[3]) + 
         (1157*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (4789500755445723665*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (695906377889184*Sqrt[3]) + (4789500755445723665*Pi*Log[3]^2)/
          (33403506138680832*Sqrt[3]) - (55*PolyGamma[2, 1])/4 - 
         (35570154619699261*Zeta[3])/3706560) + 
       (35570155942529341*CF^2*NC*Zeta[3])/1853280 - 
       (98175930073*CF*NM*NC*Zeta[3])/3 - (2006*CF*NC*NL*Zeta[3])/3 + 
       (6716*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((47968551802644348258938602079756033*NM*NC)/
          1435938933055736949840000 + (524237839*lm*NM*NC)/3243240 + 
         (136*lm^2*NM*NC)/3 - (12818724704389*NC*NL)/16696199520 + 
         (524237839*lm*NC*NL)/3243240 + (136*lm^2*NC*NL)/3 - 
         (5075793407198257952590445894728960542673*NC*NH)/
          605898121135795695674748189116208000 + (524237839*lm*NC*NH)/
          3243240 + (136*lm^2*NC*NH)/3 + (441791718302*NM*NC*Pi^2)/27 - 
         (3008*NC*NL*Pi^2)/27 + (11867646387009536*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(-11809206767086750618569789579708755757245063471/
            600349684553155951423393870886400000 - (9643759*lm)/360360 - 
           408*lm^2 - (35570134775120221*Pi^2)/3706560 + 
           (4789500755445723665*Im[PolyLog[2, (-1)^(1/3)]])/
            (1043859566833776*Sqrt[3]) - 1088*Zeta[3]) + 
         CA*NC*(11809205264316088042062428507349112084740317771/
            1200699369106311902846787741772800000 - (711362959*lm)/589680 - 
           (748*lm^2)/3 + (35570135181194461*Pi^2)/7413120 - 
           (4789500755445723665*Im[PolyLog[2, (-1)^(1/3)]])/
            (2087719133667552*Sqrt[3]) + 544*Zeta[3])), 
      (7188762891095057908824703068415052548417664723653534803233452409*CF^2*
         NC)/49068916931290082738088738044982927685391815680000000 - 
       (5503892299701539*CF^2*lm*NC)/150117385017600 - (51*CF^2*lm^2*NC)/2 - 
       (307214826021379264860099024115691428188556213488293039*CF*NM*NC)/
        3387553467141191925268504921621601088000000 + 
       (18901868912522339*CF*lm*NM*NC)/1351056465158400 + 
       (17*CF*lm^2*NM*NC)/6 + (27547004477484702906961*CF*NC*NL)/
        34776193413177216000 + (18901868912522339*CF*lm*NC*NL)/
        1351056465158400 + (17*CF*lm^2*NC*NL)/6 + 
       (12992116400267966058838797734618082105810572753682634289*CF*NC*NH)/
        1312407620753486007730375633033547366475892032000000 + 
       (18901868912522339*CF*lm*NC*NH)/1351056465158400 + 
       (17*CF*lm^2*NC*NH)/6 - (8771252330516730734176975573*CF^2*NC*Pi^2)/
        205360582704076800 - (CF^2*lm*NC*Pi^2)/6 + 
       (41552816818722683*CF*NM*NC*Pi^2)/1575288 + (CF*lm*NM*NC*Pi^2)/54 - 
       (3477674077*CF*NC*NL*Pi^2)/330810480 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (152502604657746215596535*CF^2*NC*Pi^3)/
        (384400390749766440192*Sqrt[3]) - (84656271961756250*CF*NC*NH*Pi^3)/
        (68630377364883*Sqrt[3]) - (28723*CF^2*NC*Pi^4)/4320 - 
       (74345131812624528033753626089*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (65413414493887755127472640*Sqrt[3]) + 
       (430926631138821585721*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (68699007742247883*Sqrt[3]) - 
       (1225*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (4357217275935606159901*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (296605239776054352*Sqrt[3]) - (38700010039660000*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (4357217275935606159901*CF^2*NC*Pi*Log[3]^2)/(14237051509250608896*
         Sqrt[3]) - (2418750627478750*CF*NC*NH*Pi*Log[3]^2)/
        (2541865828329*Sqrt[3]) + 
       CF*((-14626063505515333001310330085207*CF*NC)/28536564304920672000 + 
         7408*CF*lm*NC + CA*(4875354704085182251152086971429/
            19024376203280448000 + (40744*lm)/9)*NC + 
         (9349523138137809277879541*NM*NC)/29537090364600 - 
         (7408*lm*NM*NC)/9 - (8680*NC*NL)/9 - (7408*lm*NC*NL)/9 - 
         (19622029646840987*NC*NH)/46415427715800 - (7408*lm*NC*NH)/9)*
        Log[x]^2 + (CF*NC*(1178293982383651255*CA - 
          561*(4200692847920207*CF - 7280*(356999843519*NM + 1852*NL)))*
         Log[x]^3)/13783770 + (221*CF^2*NC*PolyGamma[2, 1])/6 - 
       (2474*CF*NM*NC*PolyGamma[2, 1])/9 - (9170*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*
        (-79076392433804193981301434976149974450837158535630263717558995499/
          1079516172488381820237952236989624409078619944960000000 - 
         (187*lm^2)/12 + (461644859590681575314267767*Pi^2)/
          21616903442534400 + (152502604657746215596535*Pi^3)/
          (768800781499532880384*Sqrt[3]) + (9617*Pi^4)/2880 + 
         lm*(-23773860408093539/245646630028800 - (11*Pi^2)/108) + 
         (74345131812624528033753626089*Im[PolyLog[2, (-1)^(1/3)]])/
          (130826828987775510254945280*Sqrt[3]) + 
         (1225*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (4357217275935606159901*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (593210479552108704*Sqrt[3]) + (4357217275935606159901*Pi*Log[3]^2)/
          (28474103018501217792*Sqrt[3]) - (221*PolyGamma[2, 1])/12 - 
         (3770541444537793139*Zeta[3])/88216128) + 
       (3770541478917578579*CF^2*NC*Zeta[3])/44108064 - 
       (475999764058*CF*NM*NC*Zeta[3])/9 - (2182*CF*NC*NL*Zeta[3])/3 + 
       (2416*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((1310564239514711093938593847532425865881*NM*NC)/
          23458934349331574549536080000 + (9445376063*lm*NM*NC)/55135080 + 
         48*lm^2*NM*NC - (8388138493848013*NC*NL)/9934238714400 + 
         (9445376063*lm*NC*NL)/55135080 + 48*lm^2*NC*NL - 
         (82720880049205771462594720783436471422681*NC*NH)/
          9088471817036935435121222836743120000 + (9445376063*lm*NC*NH)/
          55135080 + 48*lm^2*NC*NH + (713999681318*NM*NC*Pi^2)/27 - 
         (3272*NC*NL*Pi^2)/27 + (38700010039660000*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(-21331848221922321695908972075402564800537952647324877/
            231746384881524707212507078645697241600000 - (182682623*lm)/
            6126120 - 432*lm^2 - (3770540926885361843*Pi^2)/88216128 + 
           (4357217275935606159901*Im[PolyLog[2, (-1)^(1/3)]])/
            (889815719328163056*Sqrt[3]) - 1152*Zeta[3]) + 
         CA*NC*(21331847614921065265438917364162092767471396881128577/
            463492769763049414425014157291394483200000 - (12813628223*lm)/
            10024560 - 264*lm^2 + (3770540937490900787*Pi^2)/176432256 - 
           (4357217275935606159901*Im[PolyLog[2, (-1)^(1/3)]])/
            (1779631438656326112*Sqrt[3]) + 576*Zeta[3])), 
      (26121390387560935083362051419724099419437632863482759339375548977*CF^2*
         NC)/107951617248838182023795223698962440907861994496000000 - 
       (5672514639187139*CF^2*lm*NC)/150117385017600 - (105*CF^2*lm^2*NC)/4 - 
       (1396981963566447748306513293333710186263574224054039601*CF*NM*NC)/
        3387553467141191925268504921621601088000000 + 
       (19464549387679139*CF*lm*NM*NC)/1351056465158400 + 
       (35*CF*lm^2*NM*NC)/12 + (60545968025371025974487*CF*NC*NL)/
        69552386826354432000 + (19464549387679139*CF*lm*NC*NL)/
        1351056465158400 + (35*CF*lm^2*NC*NL)/12 + 
       (385456892974155040135937293665370322286567556696821537103*CF*NC*NH)/
        35435005760344122208720142091905778894849084864000000 + 
       (19464549387679139*CF*lm*NC*NH)/1351056465158400 + 
       (35*CF*lm^2*NC*NH)/12 - (14537502626220966877175502437*CF^2*NC*Pi^2)/
        205360582704076800 - (CF^2*lm*NC*Pi^2)/6 + 
       (1108002216099866767*CF*NM*NC*Pi^2)/9189180 + 
       (CF*lm*NM*NC*Pi^2)/54 - (3694790977*CF*NC*NL*Pi^2)/330810480 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (165112611685312591980895*CF^2*NC*Pi^3)/(384400390749766440192*
         Sqrt[3]) - (10096002065759493205*CF*NC*NH*Pi^3)/
        (7412080755407364*Sqrt[3]) - (30539*CF^2*NC*Pi^4)/4320 - 
       (2557810449894517813646472403123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2289469507286071429461542400*Sqrt[3]) + 
       (128423670244801377146171*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (18548732090406928410*Sqrt[3]) - 
       (1297*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (33022522337062518396179*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2076236678432380464*
         Sqrt[3]) - (1153828807515370652*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (33022522337062518396179*CF^2*NC*Pi*Log[3]^2)/(99659360564754262272*
         Sqrt[3]) - (288457201878842663*CF*NC*NH*Pi*Log[3]^2)/
        (274521509459532*Sqrt[3]) + 
       CF*((-1616085726362479124474342117009*CF*NC)/1902437620328044800 + 
         8092*CF*lm*NC + CA*(440750664693197782164035624273/
            1037693247451660800 + (44506*lm)/9)*NC + 
         (470116520156357005170881179*NM*NC)/324907994010600 - 
         (8092*lm*NM*NC)/9 - (9452*NC*NL)/9 - (8092*lm*NC*NL)/9 - 
         (151419196966350479*NC*NH)/324907994010600 - (8092*lm*NC*NH)/9)*
        Log[x]^2 + (CF*NC*(1948209222611476607*CA - 3896419254679160651*CF + 
          4084080*(1625595185981*NM + 2023*NL))*Log[x]^3)/13783770 + 
       (175*CF^2*NC*PolyGamma[2, 1])/6 - (2666*CF*NM*NC*PolyGamma[2, 1])/9 - 
       (19669*CF*NC*NH*PolyGamma[2, 1])/54 + 
       CA*CF*NC*
        (-26121390522903279342624006462151278245800528163368377173010283777/
          215903234497676364047590447397924881815723988992000000 - 
         (385*lm^2)/24 + (14537502628054062270721398917*Pi^2)/
          410721165408153600 + (165112611685312591980895*Pi^3)/
          (768800781499532880384*Sqrt[3]) + (30667*Pi^4)/8640 + 
         lm*(-24479834750767139/245646630028800 - (11*Pi^2)/108) + 
         (2557810449894517813646472403123*Im[PolyLog[2, (-1)^(1/3)]])/
          (4578939014572142858923084800*Sqrt[3]) + 
         (1297*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (33022522337062518396179*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4152473356864760928*Sqrt[3]) + (33022522337062518396179*Pi*
           Log[3]^2)/(199318721129508524544*Sqrt[3]) - (175*PolyGamma[2, 1])/
          12 - (31171351374303040399*Zeta[3])/441080640) + 
       (31171351560684115279*CF^2*NC*Zeta[3])/220540320 - 
       (2167460218096*CF*NM*NC*Zeta[3])/9 - (2392*CF*NC*NL*Zeta[3])/3 + 
       (8617*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((1554680105295199482018907953335593558051*NM*NC)/
          5864733587332893637384020000 + (10039970063*lm*NM*NC)/55135080 + 
         51*lm^2*NM*NC - (37247919340812067*NC*NL)/39736954857600 + 
         (10039970063*lm*NC*NL)/55135080 + 51*lm^2*NC*NL - 
         (616119744989826218539503183949682548085903*NC*NH)/
          61347184764999314187068254148016060000 + (10039970063*lm*NC*NH)/
          55135080 + 51*lm^2*NC*NH + (3251190365825*NM*NC*Pi^2)/27 - 
         (3587*NC*NL*Pi^2)/27 + (1153828807515370652*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-7238221958439118353798403371474096312890653488858781/
            46349276976304941442501415729139448320000 - (198358283*lm)/
            6126120 - 459*lm^2 - (31171348565101285039*Pi^2)/441080640 + 
           (33022522337062518396179*Im[PolyLog[2, (-1)^(1/3)]])/
            (6228710035297141392*Sqrt[3]) - 1224*Zeta[3]) + 
         CA*NC*(556786294665760876312055097443405885407738405214917/
            7130657996354606375769448573713761280000 - (13618737983*lm)/
            10024560 - (561*lm^2)/2 + (31171348622833839919*Pi^2)/882161280 - 
           (33022522337062518396179*Im[PolyLog[2, (-1)^(1/3)]])/
            (12457420070594282784*Sqrt[3]) + 612*Zeta[3])), 
      (4710867984335877590958500323891868052209031072665956949132596395473949\
47*CF^2*NC)/434158194977118667890569273744131660406625751534095360000000 - 
       (216339445729657*CF^2*lm*NC)/5559903148800 - 27*CF^2*lm^2*NC - 
       (26068081057648555640821903069197511655022702443008433*CF*NM*NC)/
        38937396174036688796189711742777024000000 + 
       (741750293291257*CF*lm*NM*NC)/50039128339200 + 3*CF*lm^2*NM*NC + 
       (131371116671305073364119*CF*NC*NL)/139104773652708864000 + 
       (741750293291257*CF*lm*NC*NL)/50039128339200 + 3*CF*lm^2*NC*NL + 
       (120536134896589705114665584652193106819923608520873968163*CF*NC*NH)/
        10287582317519261286402621897650064840440056896000000 + 
       (741750293291257*CF*lm*NC*NH)/50039128339200 + 3*CF*lm^2*NC*NH - 
       (5041999953614246991386257097*CF^2*NC*Pi^2)/15796967900313600 - 
       (CF^2*lm*NC*Pi^2)/6 + (394037727034766515*CF*NM*NC*Pi^2)/2004912 + 
       (CF*lm*NM*NC*Pi^2)/54 - (3905801777*CF*NC*NL*Pi^2)/330810480 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (4740690212290087585879045*CF^2*NC*Pi^3)/(10378810550243693885184*
         Sqrt[3]) - (196713007774326958775*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) - (719*CF^2*NC*Pi^4)/96 - 
       (73269070621151255976402550485577*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (61815676696723928595461644800*Sqrt[3]) + 
       (506273261864870968160117*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (66775435525464942276*Sqrt[3]) - 
       (1369*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (948138042458017517175809*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(56058390317674272528*
         Sqrt[3]) - (11240743301390111930*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (948138042458017517175809*CF^2*NC*Pi*Log[3]^2)/(2690802735248365081344*
         Sqrt[3]) - (5620371650695055965*CF*NC*NH*Pi*Log[3]^2)/
        (4941387170271576*Sqrt[3]) + 
       CF*((-10164709748494647700929708265221659*CF*NC)/
          2653900480357622496000 + 8738*CF*lm*NC + 
         CA*(207443057450583922656089578676651/108322468586025408000 + 
           (48059*lm)/9)*NC + (366989499585841635206383*NM*NC)/
          155607276825 - (8738*lm*NM*NC)/9 - (10166*NC*NL)/9 - 
         (8738*lm*NC*NL)/9 - (221635774688044*NC*NH)/436704293025 - 
         (8738*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(8750105114097818914*CA + 35*(-500006032032507365*CF + 
            58344*(5284888014266*NM + 4369*NL)))*Log[x]^3)/13783770 + 
       39*CF^2*NC*PolyGamma[2, 1] - (8855*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (10813*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-47108679901796649846529567486514253593666638828241994500249\
2090852535447/868316389954237335781138547488263320813251503068190720000000 - 
         (33*lm^2)/2 + (5041999953765603784337356217*Pi^2)/
          31593935800627200 + (4740690212290087585879045*Pi^3)/
          (20757621100487387770368*Sqrt[3]) + (32483*Pi^4)/8640 + 
         lm*(-932808783313657/9098023334400 - (11*Pi^2)/108) + 
         (73269070621151255976402550485577*Im[PolyLog[2, (-1)^(1/3)]])/
          (123631353393447857190923289600*Sqrt[3]) + 
         (1369*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (948138042458017517175809*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (112116780635348545056*Sqrt[3]) + (948138042458017517175809*Pi*
           Log[3]^2)/(5381605470496730162688*Sqrt[3]) - (39*PolyGamma[2, 1])/
          2 - (46667228657915030141*Zeta[3])/147026880) + 
       (46667228725441208861*CF^2*NC*Zeta[3])/73513440 - 
       (10569775932841*CF*NM*NC*Zeta[3])/27 - (7771*CF*NC*NL*Zeta[3])/9 + 
       (9272*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((239147479074853916948635522158962289389*NM*NC)/
          539285847111070679299680000 + (10606976503*lm*NM*NC)/55135080 + 
         (323*lm^2*NM*NC)/6 - (81456811795227629*NC*NL)/79473909715200 + 
         (10606976503*lm*NC*NL)/55135080 + (323*lm^2*NC*NL)/6 - 
         (1548319347790722597639943479497164466048479*NC*NH)/
          142483783970320987789319816085714720000 + (10606976503*lm*NC*NH)/
          55135080 + (323*lm^2*NC*NH)/6 + (10569776015255*NM*NC*Pi^2)/54 - 
         (7769*NC*NL*Pi^2)/54 + (11240743301390111930*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(-337650039813259273701059437521391361166550427085090797627/
            462547957578532429080224705355377409830400000 - 
           (218608513*lm)/6126120 - (969*lm^2)/2 - 
           (140001682910740906183*Pi^2)/441080640 + 
           (948138042458017517175809*Im[PolyLog[2, (-1)^(1/3)]])/
            (168175170953022817584*Sqrt[3]) - 1292*Zeta[3]) + 
         CA*NC*(4389450500287281583817712421671378433203950909557654391051/
            12026246897041843156085842339239812655590400000 - 
           (14384564863*lm)/10024560 - (3553*lm^2)/12 + 
           (140001682973750092423*Pi^2)/882161280 - 
           (948138042458017517175809*Im[PolyLog[2, (-1)^(1/3)]])/
            (336350341906045635168*Sqrt[3]) + 646*Zeta[3])), 
      (7816273308836815631401252969080573810630560129661320792880061895335719\
49*CF^2*NC)/434158194977118667890569273744131660406625751534095360000000 - 
       (6009815430214339*CF^2*lm*NC)/150117385017600 - (111*CF^2*lm^2*NC)/4 - 
       (17168060900234494467607515276197028240393227748524261*CF*NM*NC)/
        5599261929158994917799181688630745600000 + 
       (20589966450048739*CF*lm*NM*NC)/1351056465158400 + 
       (37*CF*lm^2*NM*NC)/12 + (474613531525830679696547*CF*NC*NL)/
        459818557352009856000 + (20589966450048739*CF*lm*NC*NL)/
        1351056465158400 + (37*CF*lm^2*NC*NL)/12 + 
       (206884350634226212116264220894240050337202778977586417888034099*CF*NC*
         NH)/16154004121008397400144712216431730765247116260545728000000 + 
       (20589966450048739*CF*lm*NC*NH)/1351056465158400 + 
       (37*CF*lm^2*NC*NH)/12 - (5195404395877605965758267909*CF^2*NC*Pi^2)/
        9779075366860800 - (CF^2*lm*NC*Pi^2)/6 + 
       (49858950881888828431*CF*NM*NC*Pi^2)/55135080 + 
       (CF*lm*NM*NC*Pi^2)/54 - (1378396979*CF*NC*NL*Pi^2)/110270160 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (300499660754138938192465*CF^2*NC*Pi^3)/(610518267661393757952*
         Sqrt[3]) - (53993466926833309295*CF*NC*NH*Pi^3)/
        (33354363399333138*Sqrt[3]) - (34279*CF^2*NC*Pi^4)/4320 - 
       (843266334733944403201026058433*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (727243255255575630534842880*Sqrt[3]) + 
       (11813263956735108685347353*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1418978004916130023365*Sqrt[3]) - 
       (1445*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (60099932150827787638493*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3297552371627898384*
         Sqrt[3]) - (12341363868990470696*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (60099932150827787638493*CF^2*NC*Pi*Log[3]^2)/(158282513838139122432*
         Sqrt[3]) - (1542670483623808837*CF*NC*NH*Pi*Log[3]^2)/
        (1235346792567894*Sqrt[3]) + 
       CF*((-16919496858518976065988100078811143*CF*NC)/
          2653900480357622496000 + 9498*CF*lm*NC + 
         CA*(2417070990126568269533574579123769/758257280102177856000 + 
           (17413*lm)/3)*NC + (705158532630927356696899501*NM*NC)/
          64981598802120 - (3166*lm*NM*NC)/3 - (3673*NC*NL)/3 - 
         (3166*lm*NC*NL)/3 - (6686484633712790497*NC*NH)/
          12021595778392200 - (3166*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-4844557677215741179*CA + 9689115685683403317*CF - 
          2042040*(8079069085100*NM + 1583*NL))*Log[x]^3)/4594590 + 
       (185*CF^2*NC*PolyGamma[2, 1])/6 - (19019*CF*NM*NC*PolyGamma[2, 1])/
        54 - (3854*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*
        (-8589311335254097110092124829542502645680018104734294929921193167150\
439/9541938351145465228364159862508388140804961572177920000000 - 
         (407*lm^2)/24 + (5195404395977713271758294949*Pi^2)/
          19558150733721600 + (300499660754138938192465*Pi^3)/
          (1221036535322787515904*Sqrt[3]) + (3823*Pi^4)/960 + 
         lm*(-25891839548170339/245646630028800 - (11*Pi^2)/108) + 
         (843266334733944403201026058433*Im[PolyLog[2, (-1)^(1/3)]])/
          (1454486510511151261069685760*Sqrt[3]) + 
         (1445*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (60099932150827787638493*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6595104743255796768*Sqrt[3]) + (60099932150827787638493*Pi*
           Log[3]^2)/(316565027676278244864*Sqrt[3]) - (185*PolyGamma[2, 1])/
          12 - (15502584866607747277*Zeta[3])/29405376) + 
       (15502584881192813773*CF^2*NC*Zeta[3])/14702688 - 
       (48474414406409*CF*NM*NC*Zeta[3])/27 - (8474*CF*NC*NL*Zeta[3])/9 + 
       (3604*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((9864907124337583620940584056278760681539*NM*NC)/
          4691786869866314909907216000 + (3745081381*lm*NM*NC)/18378360 + 
         57*lm^2*NM*NC - (95420674314558181*NC*NL)/84441029072400 + 
         (3745081381*lm*NC*NL)/18378360 + 57*lm^2*NC*NL - 
         (2120462750900797501994746000365621723991201549*NC*NH)/
          177849097291660364729145402201813147120000 + (3745081381*lm*NC*NH)/
          18378360 + 57*lm^2*NC*NH + 897674342526*NM*NC*Pi^2 - 
         (1412*NC*NL*Pi^2)/9 + (12341363868990470696*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(-7451479706653669955046773930547764710408677163498558908967/
            6013123448520921578042921169619906327795200000 - 
           (78598561*lm)/2042040 - 513*lm^2 - (5167528215299358031*Pi^2)/
            9801792 + (60099932150827787638493*Im[PolyLog[2, (-1)^(1/3)]])/
            (9892657114883695152*Sqrt[3]) - 1368*Zeta[3]) + 
         CA*NC*(7451479688531409458320993686329812139549666137472840416867/
            12026246897041843156085842339239812655590400000 - 
           (5078347861*lm)/3341520 - (627*lm^2)/2 + 
           (15502584650450461933*Pi^2)/58810752 - (60099932150827787638493*
             Im[PolyLog[2, (-1)^(1/3)]])/(19785314229767390304*Sqrt[3]) + 
           684*Zeta[3])), (28748208910583811944746998574367425833852531720736\
847430223490640850036901*CF^2*NC)/
        3535288159099394867108921229059357806168238262491919360000000 - 
       (2230434734605140379*CF^2*lm*NC)/54192375991353600 - 
       (57*CF^2*lm^2*NC)/2 - 
       (174754904899462910290348492054504311823042301553525793289*CF*NM*NC)/
        34925655560981639444458697291858123328000000 + 
       (7636124239742661979*CF*lm*NM*NC)/487731383922182400 + 
       (19*CF*lm^2*NM*NC)/6 + (370230456334681799553547003*CF*NC*NL)/
        331988998408151116032000 + (7636124239742661979*CF*lm*NC*NL)/
        487731383922182400 + (19*CF*lm^2*NC*NL)/6 + 
       (448667054393827256549725958425645431278738562451553176339283*CF*NC*
         NH)/32634351759612924040696388316023698515650739920294400000 + 
       (7636124239742661979*CF*lm*NC*NH)/487731383922182400 + 
       (19*CF*lm^2*NC*NH)/6 - (9409336594457876041176888302903*CF^2*NC*Pi^2)/
        3901851071377459200 - (CF^2*lm*NC*Pi^2)/6 + 
       (2518982676943644292*CF*NM*NC*Pi^2)/1700595 + 
       (CF*lm*NM*NC*Pi^2)/54 - (27603655301*CF*NC*NL*Pi^2)/2095133040 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (23742230752530828586133545*CF^2*NC*Pi^3)/(45507092412606965496576*
         Sqrt[3]) - (38816802779815544785*CF*NC*NH*Pi^3)/
        (22236242266222092*Sqrt[3]) - (36203*CF^2*NC*Pi^4)/4320 - 
       (485613707391488337910967766190051*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (396132413387881743602869593600*Sqrt[3]) + 
       (2860709848430924842988663*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (315328445536917782970*Sqrt[3]) - 
       (1521*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (4748446150506165717226709*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(245794480623648733392*
         Sqrt[3]) - (4436206031978919404*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (4748446150506165717226709*CF^2*NC*Pi*Log[3]^2)/
        (11798135069935139202816*Sqrt[3]) - (1109051507994729851*CF*NC*NH*Pi*
         Log[3]^2)/(823564528378596*Sqrt[3]) + 
       CF*((-1459176396331059771669128211458349713*CF*NC)/
          50424109126794827424000 + 10218*CF*lm*NC + 
         CA*(12261986536226254859264671116218767/847464018937728192000 + 
           (18733*lm)/3)*NC + (213681857318320864415732972867*NM*NC)/
          12021595778392200 - (3406*lm*NM*NC)/3 - (3937*NC*NL)/3 - 
         (3406*lm*NC*NL)/3 - (1449788341807132097*NC*NH)/2404319155678440 - 
         (3406*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(416413878933685874155*CA + 57*(-14611013417166713583*CF + 
            680680*(13201090309436*NM + 1703*NL)))*Log[x]^3)/87297210 + 
       (247*CF^2*NC*PolyGamma[2, 1])/6 - (10462*CF*NM*NC*PolyGamma[2, 1])/
        27 - (4214*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-20123746241219905142219347331712159311901504670530898380829\
6841628125389307/
          49494034227391528139524897206831009286355335674886871040000000 - 
         (209*lm^2)/12 + (9409336594500522092106588120503*Pi^2)/
          7803702142754918400 + (23742230752530828586133545*Pi^3)/
          (91014184825213930993152*Sqrt[3]) + (36331*Pi^4)/8640 + 
         lm*(-9601829514338124379/88678433440396800 - (11*Pi^2)/108) + 
         (485613707391488337910967766190051*Im[PolyLog[2, (-1)^(1/3)]])/
          (792264826775763487205739187200*Sqrt[3]) + 
         (1521*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (4748446150506165717226709*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (491588961247297466784*Sqrt[3]) + (4748446150506165717226709*Pi*
           Log[3]^2)/(23596270139870278405632*Sqrt[3]) - 
         (247*PolyGamma[2, 1])/12 - (6662622093761072934991*Zeta[3])/
          2793510720) + (6662622095260722606511*CF^2*NC*Zeta[3])/1396755360 - 
       (79206541745708*CF*NM*NC*Zeta[3])/27 - (9140*CF*NC*NL*Zeta[3])/9 + 
       (11600*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((28268280053533148650060252192652559617636111*NM*NC)/
          8028820281058731389578723380000 + (74960866759*lm*NM*NC)/
          349188840 + 60*lm^2*NM*NC - (2254072612396131077*NC*NL)/
          1833576631286400 + (74960866759*lm*NC*NL)/349188840 + 
         60*lm^2*NC*NL - (647631558181366981592120626314652271369714827*NC*
           NH)/50390577565970436673257863957180391684000 + 
         (74960866759*lm*NC*NH)/349188840 + 60*lm^2*NC*NH + 
         (4400363435629*NM*NC*Pi^2)/3 - (1523*NC*NL*Pi^2)/9 + 
         (4436206031978919404*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CF*NC*(-198593605477095151182938830948305602167252358471158705580743\
1/342748036565692529948446506668334660684326400000 - (1631210359*lm)/
            38798760 - 540*lm^2 - (6662622071005227182351*Pi^2)/2793510720 + 
           (4748446150506165717226709*Im[PolyLog[2, (-1)^(1/3)]])/
            (737383441870946200176*Sqrt[3]) - 1440*Zeta[3]) + 
         CA*NC*(1985936053697422636939571809350613474604894244470732042109731/
            685496073131385059896893013336669321368652800000 - 
           (101626196359*lm)/63488880 - 330*lm^2 + 
           (6662622071474950836751*Pi^2)/5587021440 - 
           (4748446150506165717226709*Im[PolyLog[2, (-1)^(1/3)]])/
            (1474766883741892400352*Sqrt[3]) + 720*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["s", 2, 0, "x1"] = SeriesData[x, 1, 
     {-(CF*NC*(10*(2*NL*(27 - 65*lm + 12*lm^3 + 96*Zeta[3]) + 
            NM*(36 - 130*lm + 24*lm^3 + 147*Zeta[3]) + 
            NH*(36 - 130*lm + 24*lm^3 + 147*Zeta[3])) + 
          3*CF*(3780*lm^2 - 720*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
            90*lm*(-31 + 48*Zeta[3]) - 5*(331 + 192*Log[2]^4 + 
              4608*PolyLog[4, 1/2] + 1272*Zeta[3])) - 
          2*CA*(1260*lm^2 + 660*lm^3 - 5*lm*(961 + 648*Zeta[3]) + 
            6*(22*Pi^4 + 120*Pi^2*Log[2]^2 - 5*(21 + 24*Log[2]^4 + 
                576*PolyLog[4, 1/2] + 55*Zeta[3])))))/8640, 
      -(CF*NC*(782*NM - 144*lm^2*NM + 260*NL - 144*lm^2*NL - 262*NH - 
          144*lm^2*NH + 2*CA*(-961 + 504*lm + 396*lm^2 - 648*Zeta[3]) - 
          567*NM*Zeta[3] + 567*NH*Zeta[3] + 54*CF*(-31 - 84*lm + 24*lm^2 + 
            48*Zeta[3])))/1728, (CF*NC*(100246*NM - 75264*lm*NM - 
         10368*lm^2*NM + 31968*NL - 75264*lm*NL - 10368*lm^2*NL - 
         87674*NH - 75264*lm*NH - 10368*lm^2*NH + 
         12*CA*(28966 + 40544*lm + 4752*lm^2 - 27729*Zeta[3]) + 
         72*CF*(136 + 4872*lm + 1296*lm^2 - 11877*Zeta[3]) - 
         61425*NM*Zeta[3] + 142695*NH*Zeta[3]))/622080, 
      -(CF*NC*(13006*NM - 44160*lm*NM - 1728*lm^2*NM - 24336*NL - 
          44160*lm*NL - 1728*lm^2*NL - 113042*NH - 44160*lm*NH - 
          1728*lm^2*NH + 12*CA*(48160 + 21248*lm + 792*lm^2 - 
            21249*Zeta[3]) + 72*CF*(13423 + 4764*lm + 216*lm^2 - 
            14037*Zeta[3]) - 27405*NM*Zeta[3] + 108675*NH*Zeta[3]))/622080, 
      -(CF*NC*(80*CF*(-109586362 - 7544016*lm + 116640*lm^2 + 
            89307765*Zeta[3]) + 8*CA*(-240504682 - 42700320*lm + 
            712800*lm^2 + 123182775*Zeta[3]) - 
          3*(128*(-230723 - 165180*lm + 2700*lm^2)*NL + 
            5*NM*(232690 - 4228608*lm + 69120*lm^2 - 4531275*Zeta[3]) + 
            5*NH*(-17521550 - 4228608*lm + 69120*lm^2 + 14519925*Zeta[3]))))/
       1741824000, (CF*NC*(-54613270*NM + 60334080*lm*NM - 
         4147200*lm^2*NM + 145427968*NL + 60334080*lm*NL - 
         4147200*lm^2*NL + 386381350*NH + 60334080*lm*NH - 
         4147200*lm^2*NH + 158594625*NM*Zeta[3] - 302801625*NH*Zeta[3] + 
         96*CA*(-43913414 - 3154240*lm + 237600*lm^2 + 27093825*Zeta[3]) + 
         320*CF*(-88115530 - 2105136*lm + 116640*lm^2 + 71076825*Zeta[3])))/
       3483648000, -(CF*NC*(-48174873222*NM + 10112040960*lm*NM - 
          1445068800*lm^2*NM + 40594341888*NL + 10112040960*lm*NL - 
          1445068800*lm^2*NL + 104770414378*NH + 10112040960*lm*NH - 
          1445068800*lm^2*NH + 73181579625*NM*Zeta[3] - 
          80263929375*NH*Zeta[3] + 3*CA*(-631580589114 - 15166914560*lm + 
            2649292800*lm^2 + 446854440375*Zeta[3]) + 
          14*CF*(-1269988956574 - 9752002560*lm + 928972800*lm^2 + 
            1036283338125*Zeta[3])))/1365590016000, 
      (CF*NC*(CA*(-2254668687626 - 11133480960*lm + 5960908800*lm^2 + 
           1728192200175*Zeta[3]) + 2*(7*CF*(-1942828185562 - 4626616320*lm + 
             696729600*lm^2 + 1599448839975*Zeta[3]) - 
           3*(21*NM*(586911658 - 27013120*lm + 8601600*lm^2 - 668721375*
                Zeta[3]) + 2*(1024*(-2190743 - 276990*lm + 88200*lm^2)*NL + 
               21*NH*(-278945898 - 13506560*lm + 4300800*lm^2 + 211845375*
                  Zeta[3]))))))/1365590016000, 
      -(CF*NC*(144*CF*(-1659869686130066 - 1095226675200*lm + 
            283481856000*lm^2 + 1373484289030875*Zeta[3]) + 
          8*CA*(-2023800553317086 + 2835304012800*lm + 3118300416000*lm^2 + 
            1618015693762125*Zeta[3]) - 
          35*(16384*(-176604602 - 2875005*lm + 7909650*lm^2)*NL + 
            63*NM*(264108043066 - 747683840*lm + 2057011200*lm^2 - 
              259383576375*Zeta[3]) + 63*NH*(-124845649886 - 747683840*lm + 
              2057011200*lm^2 + 94581766125*Zeta[3]))))/8111604695040000, 
      (CF*NC*(72*CF*(-2383771850674514 - 299987251200*lm + 
           195084288000*lm^2 + 1977747392950875*Zeta[3]) + 
         4*CA*(-2447732969882654 + 6942065356800*lm + 2145927168000*lm^2 + 
           1998597515410125*Zeta[3]) - 
         35*(8192*(-107842871 + 10681020*lm + 5443200*lm^2)*NL + 
           9*NM*(1151371090734 + 9722101760*lm + 4954521600*lm^2 - 
             1043248177125*Zeta[3]) + 63*NH*(-40848900154 + 1388871680*lm + 
             707788800*lm^2 + 30959688375*Zeta[3]))))/4055802347520000, 
      -(CF*NC*(1089*CA*(-30188216956358946 + 80272860774400*lm + 
            15100968960000*lm^2 + 24902423975401875*Zeta[3]) + 
          22*CF*(-30507892869502623706 + 664204404326400*lm + 
            1223178485760000*lm^2 + 25345567110203022375*Zeta[3]) - 
          15*(1310720*(-2591632231 + 614857089*lm + 152078850*lm^2)*NL + 
            11*NM*(7469878183769606 + 73264134881280*lm + 18121162752000*lm^
                2 - 6479700381779625*Zeta[3]) + 11*NH*(-998228051202778 + 
              73264134881280*lm + 18121162752000*lm^2 + 757722164574375*Zeta[
                3]))))/11341825942487040000, 
      (CF*NC*(-893314935137229682*NM - 7357011774013440*lm*NM - 
         1236912419635200*lm^2*NM + 17254473142763520*NL - 
         7357011774013440*lm*NL - 1236912419635200*lm^2*NL + 
         64971201231639582*NH - 7357011774013440*lm*NH - 
         1236912419635200*lm^2*NH + 757364354516644875*NM*Zeta[3] - 
         49402682093890125*NH*Zeta[3] + 1815*CA*(-12915766765378954 + 
           27064436195328*lm + 3748219453440*lm^2 + 10706306820742575*
            Zeta[3]) + 330*CF*(-1666472444917054226 + 82576862871552*lm + 
           33733975080960*lm^2 + 1385413121095940475*Zeta[3])))/
       6805095565492224000, CA*CF*NC*(978118943416755807069157/
          241512841619319029760000 - (221717003*lm)/35416180800 - 
         (61*lm^2)/87360 - (508571642209*Zeta[3])/151145938944) - 
       (CF*NC*(832*CF*(-2007465143879390028248462 + 89003501398219161600*lm + 
            21227258326450176000*lm^2 + 1669454472612462373963125*Zeta[3]) - 
          1155*(143*NM*(14889968399299287554 + 91399973366661120*lm + 
              11881101341491200*lm^2 - 12480132927006619875*Zeta[3]) + 
            3*(6291456*(-951230950983 + 692483912120*lm + 90016126200*lm^2)*
               NL + 143*NH*(-197849129963473066 + 30466657788887040*lm + 
                3960367113830400*lm^2 + 150648414679137375*Zeta[3])))))/
        15456821863636417904640000, 
      (CF*NC*(128*CA*(-379402331172894700320158 + 421192835921726668800*lm + 
           39932678839173120000*lm^2 + 315534216868134877738125*Zeta[3]) + 
         3328*CF*(-439082034928320400791914 + 14513604580255334400*lm + 
           2513245521346560000*lm^2 + 365212110941965821909375*Zeta[3]) - 
         3465*(8388608*(-223093924849 + 296544087840*lm + 31972941000*lm^2)*
            NL + 39*NM*(14822207355357704002 + 63784413015572480*lm + 
             6877140221952000*lm^2 - 12357002465164231875*Zeta[3]) + 
           143*NH*(-88935252822345826 + 17395749004247040*lm + 
             1875583696896000*lm^2 + 67769486355445875*Zeta[3]))))/
       10304547909090945269760000, CA*CF*NC*((-149198321*lm)/34735100400 - 
         (5*lm^2)/13923 + (45685655523905049064997911622 - 
           38011216327708573473570671625*Zeta[3])/
          8408511093818211340124160000) - 
       (CF*NC*(CF*(-769507231955946195963451016122 + 
            17758864260947330570649600*lm + 2470620877304522342400000*lm^2 + 
            640101836281215019475140752375*Zeta[3]) - 
          5005*(268435456*(-671537517757 + 2183819617980*lm + 
              204324120000*lm^2)*NL + 13*NM*(15496597228989439437026 + 
              45093431921092853760*lm + 4219064486461440000*lm^2 - 
              12890181087125985517875*Zeta[3]) + 143*NH*
             (-17253815738453661194 + 4099402901917532160*lm + 
              383551316951040000*lm^2 + 13147668268186827375*Zeta[3]))))/
        4204255546909105670062080000, 
      (CF*NC*(CA*(-7462192979254692143368344646 + 4205766355506453440102400*
            lm + 318500940082141200384000*lm^2 + 6209616334357209807648239625*
            Zeta[3]) + 18*CF*(-15532759016348006655096334442 + 
           244149839307922105958400*lm + 28954630916558290944000*lm^2 + 
           12921227276224330873664229375*Zeta[3]) - 
         2860*(117440512*(68957783593 + 2057229886140*lm + 172410638400*lm^2)*
            NL + 2*NM*(62789075647917684542618 + 120801065564991651840*lm + 
             10123996823971430400*lm^2 - 52188358959411125826375*Zeta[3]) + 
           715*NH*(-1210389074684878370 + 337905078503473152*lm + 
             28318872234885120*lm^2 + 921653679454182675*Zeta[3]))))/
       1201215870545458762874880000, 
      -(CF*NC*(CA*(-558129958203430224191705775338438 + 
            225704299765207970806235136000*lm + 15797033711479575942266880000*
             lm^2 + 464458455144066901566686740727625*Zeta[3]) + 
          34*CF*(-679947609853991953129535681454746 + 
            7234140616471312336945152000*lm + 760285044937519697756160000*
             lm^2 + 565640209748094809578452365538375*Zeta[3]) - 
          6435*(134217728*(13282698547414861 + 43281254557440900*lm + 
              3325480620462000*lm^2)*NL + 51*NM*
             (90824661456808589950563346 + 113904150033124766515200*lm + 
              8751734380126273536000*lm^2 - 75481888608548473531354875*Zeta[
                3]) + 21879*NH*(-831291790876518606582 + 
              265510839238053068800*lm + 20400313240387584000*lm^2 + 
              632111934224646500625*Zeta[3]))))/
       79150516141981368803351592960000, 
      CA*CF*NC*((1742271521*lm)/747962495280 + (1619*lm^2)/10581480 + 
         (-78696349129951586543760861227114 + 
           65487344290314455885891393253375*Zeta[3])/
          9893814517747671100418949120000) + 
       (CF*NC*(544*CF*(-105387513401456676283653529785398 + 
            761454920337970333483008000*lm + 72855962577913251889152000*
             lm^2 + 87671610329112768672865134608625*Zeta[3]) - 
          2145*(51*NM*(693073303247924346556449502 + 
              561623504438251487232000*lm + 40255388111771113881600*lm^2 - 
              576068487922920337674454125*Zeta[3]) + 
            11*(1073741824*(1292245247023357 + 2425062277638000*lm + 
                173820757874400*lm^2)*NL + 663*NH*(
                -10989563966699135228674 + 3927437093973786624000*lm + 
                281506210571825971200*lm^2 + 8340805961837822347875*
                 Zeta[3])))))/158301032283962737606703185920000, 
      -(CF*NC*(12*CA*(-793315420042793814736321192207078582 + 
            170032517240807526078118625280000*lm + 
            10604839744453727779653943296000*lm^2 + 
            660134361345473114600832998649608625*Zeta[3]) + 
          152*CF*(-3117638891939545905998303905954946666 + 
            15427271545348706445211729920000*lm + 
            1370003220575361961964863488000*lm^2 + 
            2593571583259124386704269743297413375*Zeta[3]) - 
          7735*(17179869184*(1860567339509044021 + 2570106309439769100*lm + 
              174117529309323600*lm^2)*NL + 969*NM*
             (87479698176902035131517596658 + 45566656537820699138457600*lm + 
              3087013804102647388569600*lm^2 - 72725262317327955671153692875*
               Zeta[3]) + 37791*NH*(-2977137472657098561710546 + 
              1168375808662069208678400*lm + 79154200105196086886400*lm^2 + 
              2254673369718233812222875*Zeta[3]))))/
       1066737889550863567819037202186240000, 
      CA*CF*NC*(-1329117376523832253433406572983947913/
          133342236193857945977379650273280000 + (800922151*lm)/
          506641262400 + (1999*lm^2)/21162960 + (4738658020310358967*Zeta[3])/
          571335103972638720) + 
       (CF*NC*(8360*CF*(-13770138351235518689647960534969790 + 
            47190004716988272882185404416*lm + 3944551606592143306480680960*
             lm^2 + 11455448219696577685786123959277245*Zeta[3]) - 
          13923*(665*NM*(18327660240779583233493264434 + 
              6119419060986614762176512*lm + 395737259439512113643520*lm^2 - 
              15239237795111945282750757675*Zeta[3]) + 
            13*(17179869184*(16185988092656777 + 18220850103338190*lm + 
                1178325787577400*lm^2)*NL + 323*NH*(
                -2284440361596217801608578 + 969138765314622247403520*lm + 
                62673321630691963699200*lm^2 + 1726111027351012823395875*
                 Zeta[3])))))/213347577910172713563807440437248000, 
      -(CF*NC*(6*CA*(-1995846106036997791486826419121362189478 + 
            236746810319878410126804254510284800*lm + 
            13644085443363426994430404460544000*lm^2 + 
            1660655974681225257989487921632089769625*Zeta[3]) + 
          324*CF*(-2164268027682785430463031770643593307054 + 
            5200827624633836347623279794585600*lm + 
            413457134647376575588800135168000*lm^2 + 
            1800468496516926701092315141057904425125*Zeta[3]) - 
          1616615*(42949672960*(3556644928182385001 + 3446849460151921824*
               lm + 214371242886921120*lm^2)*NL + 
            57*NM*(12149500160396288940289375009034 + 
              2597211527296098144847134720*lm + 161529382000385760795033600*
               lm^2 - 10103641031404143814063052955375*Zeta[3]) + 
            37791*NH*(-8653986887925397219805754 + 3917362786268624652861440*
               lm + 243634060332406879027200*lm^2 + 6524066401104072502056375*
               Zeta[3]))))/1079538744225473930632865648612474880000, 
      (CF*NC*(168*CA*(-158211205800938225242384581729562376362 + 
           14177795298426377500701952573440000*lm + 
           792171807774257151979145920512000*lm^2 + 
           131636347408337434975035006153232737375*Zeta[3]) + 
         16*CF*(-104658148985024182669019458833340138904078 + 
           178638939361887373830134578544640000*lm + 
           13610951969939509247641688997888000*lm^2 + 
           87065858737106889656680841670741398275125*Zeta[3]) - 
         1616615*(240518168576*(1198825103986121231 + 1034579607054364800*
              lm + 62231673833128800*lm^2)*NL + 
           15*NM*(121225552440529421255865667999946 + 
             16589012822319570117533368320*lm + 997856547850874720794705920*
              lm^2 - 100823362686594670881058820895375*Zeta[3]) + 
           37791*NH*(-13777672245410772108885722 + 6584509336476768324812800*
              lm + 396069122747826752716800*lm^2 + 10364389818023649039006375*
              Zeta[3]))))/2159077488450947861265731297224949760000, 
      -(CF*NC*(CA*(-124599936281975310383303778459148307635827334 + 
            8511696825464287427249745602352355737600*lm + 
            462901538489444240507774030742080716800*lm^2 + 
            103667982434523743942943762948052802957810025*Zeta[3]) + 
          46*CF*(-182567495159623781199284320599672072560115862 + 
            224195834992706450469925111429123276800*lm + 
            16466853147845842547707376587662950400*lm^2 + 
            151879258765731563968208793549838143622077825*Zeta[3]) - 
          373065*(1099511627776*(4467638232891988060463 + 
              3511704256028227579320*lm + 205183106867161463040*lm^2)*NL + 
            207*NM*(18652945230983109016146422005760*lm + 
              1089860926684297893853758750720*lm^2 + 
              23*(9253412869797207829418077033389146 - 
                7696674188427697946639993185734375*Zeta[3])) + 
            156009*NH*(-49470267321762145058297425814 + 
              24749595618288070344289812480*lm + 1446078186666472216524226560*
               lm^2 + 37141175204074853073852314625*Zeta[3]))))/
       9137215931124411348876574849855987384320000, 
      (CF*NC*(459*CA*(-27311882519447199671009399367244839026834 + 
           1433336403703512486156464175238348800*lm + 
           76103589279769940668601611793203200*lm^2 + 
           22723162359683376838881100465024692140475*Zeta[3]) + 
         2*(299*CF*(-1502520192519513098172795376641921459588526 + 
             1344069303647641050777557216211763200*lm + 
             95586478356561150775917682674892800*lm^2 + 
             1249957960856384369891062675796694862575525*Zeta[3]) - 
           11305*(7559142440960*(897092301467676908623 + 
               652587105206893507560*lm + 37160542414576316736*lm^2)*NL + 
             161*NM*(545372628369071416247873944158445606 + 
               30639744617345697605937109401600*lm + 
               1744731883820608889291758632960*lm^2 - 
               453647366459905295816299316996465625*Zeta[3]) + 
             14858*NH*(-638242379515282027016411841322 + 
               332009616596625206256284467200*lm + 
               18905763446972542144028344320*lm^2 + 
               478331468040732024026390457375*Zeta[3])))))/
       830655993738582849897870440895998853120000}, 0, 24, 1]
 
CbarSeries["s", 2, 1, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(2*CA*(-5540*Pi^2 + 324*Pi^4 - 660*lm*(3 + 4*Pi^2) + 
            15*(-175 + 3024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1728*Im[PolyLog[2, (-1)^(1/3)]]^2 - 504*PolyGamma[2, 1] - 
              5616*Zeta[3])) + 15*(CF*(-484*Pi^2 + 16*Pi^4 - 
              9*(103 + 1344*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                768*Im[PolyLog[2, (-1)^(1/3)]]^2 - 224*PolyGamma[2, 1] - 
                3168*Zeta[3])) + 4*(NL*(4*lm*(3 + 4*Pi^2) + 
                3*(15 + 4*Pi^2 - 64*Zeta[3])) + NM*(45 + 12*Pi^2 + 
                4*lm*(3 + 4*Pi^2) + 16*PolyGamma[2, 1] - 160*Zeta[3]) + 
              NH*(-891 + 4*lm*(3 + 4*Pi^2) - 3024*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 504*PolyGamma[2, 1] + 6000*Zeta[3])))))/
       155520, (CF*NC*(4*CA*(-6040*Pi^2 + 243*Pi^4 - 660*lm*(51 + 2*Pi^2) - 
           15*(7235 + 2376*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             1296*Im[PolyLog[2, (-1)^(1/3)]]^2 - 396*PolyGamma[2, 1] - 
             4512*Zeta[3])) + 120*(NH*(7383 + 204*lm + 8*lm*Pi^2 + 
             864*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 144*PolyGamma[2, 1] - 
             7776*Zeta[3]) + NL*(495 + 204*lm + 16*Pi^2 + 8*lm*Pi^2 - 
             96*Zeta[3]) + NM*(495 + 16*Pi^2 + 4*lm*(51 + 2*Pi^2) + 
             8*PolyGamma[2, 1] - 80*Zeta[3])) - CF*(36940*Pi^2 + 408*Pi^4 + 
           15*(9083 - 19008*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             10368*Im[PolyLog[2, (-1)^(1/3)]]^2 + 3168*PolyGamma[2, 1] + 
             25056*Zeta[3]))))/155520, 
      (CF*NC*(3*CA*(-3220*Pi^2 + 28*Pi^4 - 220*lm*(291 + 4*Pi^2) + 
           15*(-12429 - 1200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             2880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 328*PolyGamma[2, 1] + 
             1296*Zeta[3])) + 
         10*(3*(NL*(4*lm*(291 + 4*Pi^2) + 3*(823 + 4*Pi^2 - 64*Zeta[3])) + 
             NH*(32349 + 4*lm*(291 + 4*Pi^2) + 18864*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 3480*PolyGamma[2, 1] - 61872*
                Zeta[3]) + NM*(3909 - 84*Pi^2 + 4*lm*(291 + 4*Pi^2) - 80*
                PolyGamma[2, 1] - 352*Zeta[3])) + CF*(-3916*Pi^2 + 60*Pi^4 + 
             3*(-7321 + 3600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 8640*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 984*PolyGamma[2, 1] + 2736*
                Zeta[3])))))/77760, 
      -(CF*NC*(1886355*CF - 1497960*NM - 263520*lm*NM - 616680*NL - 
          263520*lm*NL - 14754600*NH - 263520*lm*NH + 189684*CF*Pi^2 + 
          21600*NM*Pi^2 - 5760*lm*NM*Pi^2 + 30240*NL*Pi^2 - 
          5760*lm*NL*Pi^2 - 5760*lm*NH*Pi^2 + 86800*Sqrt[3]*CF*Pi^3 + 
          274400*Sqrt[3]*NH*Pi^3 + 7128*CF*Pi^4 - 544320*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] - 2125440*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 3888000*CF*Im[PolyLog[2, (-1)^(1/3)]]^
            2 + 3214080*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          10160640*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          66960*Sqrt[3]*CF*Pi*Log[3]^2 + 211680*Sqrt[3]*NH*Pi*Log[3]^2 + 
          25920*(135*CF - 2*CA*(76 + 33*lm) + 4*(5*NM + 3*lm*NM + 5*NL + 
              3*lm*NL + 3*lm*NH))*Log[x]^2 + 103680*(11*CA + 36*CF - 
            2*(NM + NL))*Log[x]^3 + 286560*CF*PolyGamma[2, 1] + 
          11520*NM*PolyGamma[2, 1] + 512640*NH*PolyGamma[2, 1] - 
          4304160*CF*Zeta[3] - 529920*NM*Zeta[3] + 380160*NL*Zeta[3] + 
          8040960*NH*Zeta[3] + 2160*Log[x]*(8*(NM*(-43 + 3*lm + 3*Pi^2) + 
              NL*(11 + 3*lm + 3*Pi^2) + NH*(355 + 3*lm - 196*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) - 4*CA*(145 + 33*lm + 12*Pi^2 - 
              62*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 108*Zeta[3]) + 
            CF*(1209 + 80*Pi^2 - 496*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              864*Zeta[3])) - 4*CA*(-37470*Pi^2 + 10850*Sqrt[3]*Pi^3 + 
            2043*Pi^4 - 1980*lm*(183 + 4*Pi^2) + 8370*Sqrt[3]*Pi*Log[3]^2 - 
            90*(12367 + 756*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              5400*Im[PolyLog[2, (-1)^(1/3)]]^2 - 4464*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 398*PolyGamma[2, 1] + 
              2588*Zeta[3]))))/233280, 
      -(CF*NC*(5346225*CF - 5472900*NM - 969840*lm*NM - 2219940*NL - 
          969840*lm*NL - 51259140*NH - 969840*lm*NH + 309324*CF*Pi^2 + 
          242640*NM*Pi^2 - 14400*lm*NM*Pi^2 + 147600*NL*Pi^2 - 
          14400*lm*NL*Pi^2 - 14400*lm*NH*Pi^2 + 411600*Sqrt[3]*CF*Pi^3 + 
          996800*Sqrt[3]*NH*Pi^3 + 33120*CF*Pi^4 + 2482560*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] - 14811840*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 15552000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 15240960*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 36910080*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 317520*Sqrt[3]*CF*Pi*
           Log[3]^2 + 768960*Sqrt[3]*NH*Pi*Log[3]^2 + 
          103680*(126*CF - 2*CA*(76 + 33*lm) + 23*NM + 12*lm*NM + 20*NL + 
            12*lm*NL + 12*lm*NH)*Log[x]^2 + 414720*(11*CA + 36*CF - 
            2*(NM + NL))*Log[x]^3 + 500640*CF*PolyGamma[2, 1] + 
          223200*NM*PolyGamma[2, 1] + 3388800*NH*PolyGamma[2, 1] - 
          30*CA*(-576723 - 14944*Pi^2 + 6860*Sqrt[3]*Pi^3 + 936*Pi^4 - 
            132*lm*(1347 + 20*Pi^2) + 41376*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 259200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            254016*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
            5292*Sqrt[3]*Pi*Log[3]^2 + 8344*PolyGamma[2, 1] - 
            311920*Zeta[3]) - 27860640*CF*Zeta[3] - 2491200*NM*Zeta[3] + 
          1416960*NL*Zeta[3] + 40715520*NH*Zeta[3] + 
          4320*Log[x]*(4*(3*NL*(13 + 3*lm + 4*Pi^2) + 3*NM*(-71 + 3*lm + 
                6*Pi^2) + NH*(1295 + 9*lm - 712*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) - CA*(1095 + 198*lm + 43*Pi^2 - 
              588*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 864*Zeta[3]) + 
            CF*(46*Pi^2 + 3*(727 - 392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                576*Zeta[3])))))/466560, 
      -(CF*NC*(-35056125*CF - 896265000*NM - 130248000*lm*NM - 
          387423000*NL - 130248000*lm*NL - 10946146248*NH - 
          130248000*lm*NH - 29650500*CF*Pi^2 + 42120000*NM*Pi^2 - 
          1944000*lm*NM*Pi^2 + 34344000*NL*Pi^2 - 1944000*lm*NL*Pi^2 - 
          1944000*lm*NH*Pi^2 + 110915000*Sqrt[3]*CF*Pi^3 + 
          290500000*Sqrt[3]*NH*Pi^3 + 10233000*CF*Pi^4 + 
          170244000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          1676736000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          2671056000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 4107024000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10756800000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 85563000*Sqrt[3]*CF*Pi*
           Log[3]^2 + 224100000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          2332800*(1625*CF - 15*CA*(126 + 55*lm) + 450*NM + 150*lm*NM + 
            235*NL + 150*lm*NL + 8*NH + 150*lm*NH)*Log[x]^2 + 
          23328000*(61*CA + 210*CF - 16*NM - 10*NL)*Log[x]^3 + 
          184524000*CF*PolyGamma[2, 1] + 31104000*NM*PolyGamma[2, 1] + 
          442056000*NH*PolyGamma[2, 1] - 25*CA*(-3451896*Pi^2 + 
            2218300*Sqrt[3]*Pi^3 + 266868*Pi^4 - 427680*lm*(67 + Pi^2) + 
            1711260*Sqrt[3]*Pi*Log[3]^2 + 15*(-7432263 + 226992*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 3561408*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 5476032*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              246032*PolyGamma[2, 1] - 4248704*Zeta[3])) - 
          4623468000*CF*Zeta[3] - 1104192000*NM*Zeta[3] + 
          373248000*NL*Zeta[3] + 3512400000*NH*Zeta[3] - 
          1080*Log[x]*(25*CA*(58761 + 10296*lm + 1686*Pi^2 - 25352*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 31104*Zeta[3]) - 
            2*(4*(150*NM*(-637 + 39*lm + 27*Pi^2) + 75*NL*(427 + 78*lm + 
                  90*Pi^2) + 2*NH*(375633 + 2925*lm - 207500*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 25*CF*(53643 + 582*Pi^2 - 
                25352*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 31104*Zeta[3])))))/
       34992000, -(CF*NC*(3034918125*CF - 5135690250*NM - 903879000*lm*NM - 
          2853488250*NL - 903879000*lm*NL - 77017153482*NH - 
          903879000*lm*NH - 633444300*CF*Pi^2 + 438453000*NM*Pi^2 - 
          10692000*lm*NM*Pi^2 + 271593000*NL*Pi^2 - 10692000*lm*NL*Pi^2 - 
          10692000*lm*NH*Pi^2 + 916405000*Sqrt[3]*CF*Pi^3 + 
          2121980000*Sqrt[3]*NH*Pi^3 + 86022000*CF*Pi^4 + 
          4241376000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          17064972000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          19945440000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 33933168000*Sqrt[3]*
           CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 78573888000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 706941000*Sqrt[3]*CF*Pi*
           Log[3]^2 + 1636956000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          777600*(39760*CF - 15*CA*(3071 + 1298*lm) + 11725*NM + 
            3540*lm*NM + 5430*NL + 3540*lm*NL + 216*NH + 3540*lm*NH)*
           Log[x]^2 + 31104000*(329*CA + 1367*CF - 91*NM - 59*NL)*
           Log[x]^3 + 1257102000*CF*PolyGamma[2, 1] + 691578000*NM*
           PolyGamma[2, 1] + 4368888000*NH*PolyGamma[2, 1] - 
          25*CA*(-26926344*Pi^2 + 18328100*Sqrt[3]*Pi^3 + 2062584*Pi^4 - 
            17820*lm*(11159 + 132*Pi^2) + 14138820*Sqrt[3]*Pi*Log[3]^2 + 
            45*(-16080621 + 1885056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              8864640*Im[PolyLog[2, (-1)^(1/3)]]^2 + 15081408*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 558712*PolyGamma[2, 1] - 
              15662320*Zeta[3])) - 45874872000*CF*Zeta[3] - 
          8636220000*NM*Zeta[3] + 2881008000*NL*Zeta[3] + 
          32524560000*NH*Zeta[3] - 2160*Log[x]*
           (25*CA*(172515 + 34254*lm + 8631*Pi^2 - 104732*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 116640*Zeta[3]) - 
            2*(2*(225*NL*(1119 + 173*lm + 236*Pi^2) + 75*NM*(-11141 + 
                  519*lm + 750*Pi^2) + NH*(5502669 + 38925*lm - 3031400*
                   Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 25*CF*(3825*Pi^2 - 
                104732*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                15*(9965 + 7776*Zeta[3]))))))/157464000, 
      (235685*CF^2*NC)/23328 + (245641*CF*NM*NC)/2916 + 
       (2132*CF*lm*NM*NC)/243 + (18173*CF*NC*NL)/486 + 
       (2132*CF*lm*NC*NL)/243 + (131443635397*CF*NC*NH)/125023500 + 
       (2132*CF*lm*NC*NH)/243 + (146131*CF^2*NC*Pi^2)/11340 - 
       (1060*CF*NM*NC*Pi^2)/243 + (8*CF*lm*NM*NC*Pi^2)/81 - 
       (848*CF*NC*NL*Pi^2)/243 + (8*CF*lm*NC*NL*Pi^2)/81 + 
       (8*CF*lm*NC*NH*Pi^2)/81 - (692335*CF^2*NC*Pi^3)/(17496*Sqrt[3]) - 
       (214165*CF*NC*NH*Pi^3)/(2187*Sqrt[3]) - (1939*CF^2*NC*Pi^4)/1620 - 
       (111973*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(1458*Sqrt[3]) + 
       (366656*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(729*Sqrt[3]) - 
       (676*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (39562*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27*Sqrt[3]) - 
       (97904*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27*Sqrt[3]) - 
       (19781*CF^2*NC*Pi*Log[3]^2)/(648*Sqrt[3]) - 
       (6119*CF*NC*NH*Pi*Log[3]^2)/(81*Sqrt[3]) - 
       (CF*NC*(-105*CA*(28525 + 12232*lm) + 
          4*(644735*CF + 35*(5545 + 1668*lm)*NM + 86310*NL + 58380*lm*NL + 
            5913*NH + 58380*lm*NH))*Log[x]^2)/5670 - 
       (2*CF*NC*(6689*CA + 4*(7319*CF - 964*NM - 278*NL))*Log[x]^3)/81 - 
       (127943*CF^2*NC*PolyGamma[2, 1])/6561 - (38*CF*NM*NC*PolyGamma[2, 1])/
        81 - (296638*CF*NC*NH*PolyGamma[2, 1])/6561 + 
       (CA*CF*NC*(-4833027*Pi^2 + 3461675*Sqrt[3]*Pi^3 + 355590*Pi^4 - 
          47520*lm*(533 + 6*Pi^2) + 2670435*Sqrt[3]*Pi*Log[3]^2 + 
          10*(-10620531 + 671838*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            5913648*Im[PolyLog[2, (-1)^(1/3)]]^2 + 12818088*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 511772*PolyGamma[2, 1] - 
            10532564*Zeta[3])))/524880 + (3405152*CF^2*NC*Zeta[3])/6561 + 
       (11708*CF*NM*NC*Zeta[3])/81 - (1144*CF*NC*NL*Zeta[3])/27 - 
       (1333292*CF*NC*NH*Zeta[3])/6561 - 
       (CF*NC*Log[x]*(-67992400*NM + 6056400*lm*NM + 45672900*NL + 
          6056400*lm*NL + 867850232*NH + 6056400*lm*NH - 
          9937200*NM*Pi^2 + 8173200*NL*Pi^2 - 479729600*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] - 1225*CA*(145906 + 27192*lm + 
            5805*Pi^2 - 79124*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            77760*Zeta[3]) + 1225*CF*(243371 + 4350*Pi^2 - 
            158248*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 155520*Zeta[3])))/
        1190700, -(CF*NC*(3400288584714*CF - 6245272575738*NM - 
          663277450500*lm*NM - 3126243873375*NL - 663277450500*lm*NL - 
          82952695895634*NH - 663277450500*lm*NH - 932200419150*CF*Pi^2 + 
          500399613000*NM*Pi^2 - 6334524000*lm*NM*Pi^2 + 
          289582209000*NL*Pi^2 - 6334524000*lm*NL*Pi^2 - 
          6334524000*lm*NH*Pi^2 + 1142725937500*Sqrt[3]*CF*Pi^3 + 
          2650487910000*Sqrt[3]*NH*Pi^3 + 104069561400*CF*Pi^4 + 
          3707411883000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          16514161692000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          18183417840000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          42313509000000*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          98143780896000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          881531437500*Sqrt[3]*CF*Pi*Log[3]^2 + 2044662102000*Sqrt[3]*NH*Pi*
           Log[3]^2 + 9525600*(4812283*CF - 14*CA*(369851 + 145695*lm) + 
            1376564*NM + 370860*lm*NM + 536445*NL + 370860*lm*NL + 
            42012*NH + 370860*lm*NH)*Log[x]^2 + 1333584000*
           (8989*CA + 52629*CF - 6172*NM - 1766*NL)*Log[x]^3 + 
          2822764462000*CF*PolyGamma[2, 1] + 945511056000*NM*
           PolyGamma[2, 1] + 4399317314000*NH*PolyGamma[2, 1] - 
          343*CA*(-39667449726 - 1770014025*Pi^2 + 1665781250*Sqrt[3]*Pi^3 + 
            166479300*Pi^4 - 4232250*lm*(2513 + 24*Pi^2) + 5404390500*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 26506440000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 61681500000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1285031250*Sqrt[3]*Pi*
             Log[3]^2 + 4114817000*PolyGamma[2, 1] - 59459960000*Zeta[3]) - 
          50414341684000*CF*Zeta[3] - 10887379776000*NM*Zeta[3] + 
          3608678304000*NL*Zeta[3] + 20163437476000*NH*Zeta[3] - 
          3780*Log[x]*(6*(-3675*NL*(40119 + 4628*lm + 7064*Pi^2) + 
              196*NM*(1021352 - 86775*lm + 131550*Pi^2) - 
              2*NH*(1306757747 + 8503950*lm - 721221200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 98*CA*(22572186 + 
              5727150*lm + 2754675*Pi^2 - 19037500*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 17496000*Zeta[3]) - 
            49*CF*(66724869 + 7254900*Pi^2 - 76150000*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 69984000*Zeta[3]))))/54010152000, 
      (-147733322447*CF^2*NC)/2519424000 + (243110491*CF*NM*NC)/1166400 + 
       (66599*CF*lm*NM*NC)/3888 + (2867*CF*NC*NL)/27 + 
       (66599*CF*lm*NC*NL)/3888 + (1209712561783*CF*NC*NH)/432081216 + 
       (66599*CF*lm*NC*NH)/3888 + (558469*CF^2*NC*Pi^2)/13608 + 
       (6427*CF*NM*NC*Pi^2)/486 + (25*CF*lm*NM*NC*Pi^2)/162 - 
       (8735*CF*NC*NL*Pi^2)/972 + (25*CF*lm*NC*NL*Pi^2)/162 + 
       (25*CF*lm*NC*NH*Pi^2)/162 - (219748375*CF^2*NC*Pi^3)/
        (1889568*Sqrt[3]) - (16849000*CF*NC*NH*Pi^3)/(59049*Sqrt[3]) - 
       (4345*CF^2*NC*Pi^4)/1296 - (57084067*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(314928*Sqrt[3]) + 
       (27304606*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) - 
       525*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (6278525*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1458*Sqrt[3]) - (7702400*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (6278525*CF^2*NC*Pi*Log[3]^2)/(69984*Sqrt[3]) - 
       (481400*CF*NC*NH*Pi*Log[3]^2)/(2187*Sqrt[3]) - 
       (CF*NC*(-7*CA*(10883659 + 4414080*lm) + 
          8*(8625792*CF + 35*(19381 + 20064*lm)*NM + 
            15*(66122*NL + 46816*lm*NL + 6785*NH + 46816*lm*NH)))*
         Log[x]^2)/45360 - (4*CF*NC*(9283*CA + 54626*CF - 12086*NM - 
          1672*NL)*Log[x]^3)/81 - (15424439*CF^2*NC*PolyGamma[2, 1])/
        236196 + (9575*CF*NM*NC*PolyGamma[2, 1])/162 - 
       (7325818*CF*NC*NH*PolyGamma[2, 1])/59049 + 
       (CA*CF*NC*(-912531035250*Pi^2 + 769119312500*Sqrt[3]*Pi^3 + 
          71416485000*Pi^4 - 56133000*lm*(66599 + 600*Pi^2) + 
          593320612500*Sqrt[3]*Pi*Log[3]^2 + 21*(-721171315473 + 
            57084067000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            496011600000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1356161400000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 61697756000*
             PolyGamma[2, 1] - 1186130516000*Zeta[3])))/39680928000 + 
       (362724371*CF^2*NC*Zeta[3])/236196 + (36245*CF*NM*NC*Zeta[3])/81 - 
       (3394*CF*NC*NL*Zeta[3])/27 - (18486176*CF*NC*NH*Zeta[3])/59049 - 
       (CF*NC*Log[x]*(-40*(-1323*NM*(515999 + 128100*lm - 1009200*Pi^2) - 
            5*(15876*NL*(20784 + 2135*lm + 3344*Pi^2) + NH*(5455811463 + 
                33895260*lm - 3019340800*Sqrt[3]*Im[PolyLog[2, (-1)^
                    (1/3)]]))) - 49*CA*(3127102743 + 760914000*lm + 
            315827100*Pi^2 - 2511410000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            2099520000*Zeta[3]) + 49*CF*(4470532161 + 385317000*Pi^2 - 
            5022820000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            4199040000*Zeta[3])))/514382400, 
      -(CF*NC*(3723187024783377*CF - 12036823076008800*NM - 
          876832413508800*lm*NM - 6084394351131600*NL - 
          876832413508800*lm*NL - 151422197486179680*NH - 
          876832413508800*lm*NH + 353824777983600*CF*Pi^2 - 
          443151296784000*NM*Pi^2 - 6961308480000*lm*NM*Pi^2 + 
          495889209648000*NL*Pi^2 - 6961308480000*lm*NL*Pi^2 - 
          6961308480000*lm*NH*Pi^2 + 2221255473640000*Sqrt[3]*CF*Pi^3 + 
          5259490381600000*Sqrt[3]*NH*Pi^3 + 191375971920000*CF*Pi^4 + 
          4975396239004800*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          28939335539520000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          28491435383040000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          82249916966784000*Sqrt[3]*CF*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]] + 194751415272960000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1713539936808000*Sqrt[3]*
           CF*Pi*Log[3]^2 + 4057321151520000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          342921600*(369173171*CF - 12*CA*(28482077 + 9536450*lm) + 
            20*(4*(380893 + 260085*lm)*NM + 15*(96117*NL + 69356*lm*NL + 
                10972*NH + 69356*lm*NH)))*Log[x]^2 + 192036096000*
           (92071*CA + 947700*CF - 182500*NM - 24770*NL)*Log[x]^3 + 
          14010652218080000*CF*PolyGamma[2, 1] + 1056198528000000*NM*
           PolyGamma[2, 1] + 7732479331360000*NH*PolyGamma[2, 1] - 
          80*CA*(-248168415666861 + 1500511864635*Pi^2 + 13882846710250*
             Sqrt[3]*Pi^3 + 1265712909300*Pi^4 - 27505170*lm*
             (2191669 + 17400*Pi^2) + 31096226493780*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 178071471144000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 514061981042400*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10709624605050*Sqrt[3]*
             Pi*Log[3]^2 + 87566576363000*PolyGamma[2, 1] - 
            432666192072800*Zeta[3]) - 84870811292288000*CF*Zeta[3] - 
          16547750392320000*NM*Zeta[3] + 7218636848640000*NL*Zeta[3] + 
          21108899524160000*NH*Zeta[3] - 15120*Log[x]*
           (-40*(108*NM*(103609238 + 10530345*lm - 91279650*Pi^2) + 
              19845*NL*(626381 + 57308*lm + 99080*Pi^2) + 
              2*NH*(97056132591 + 568638630*lm - 53668269200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 8*CA*(75545210688 + 
              31275124650*lm + 32446277325*Pi^2 - 113329360900*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 90016920000*Zeta[3]) - 
            CF*(556810094931 + 424733803200*Pi^2 - 1813269774400*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 1440270720000*Zeta[3]))))/
       38887309440000, (-1306358560840471*CF^2*NC)/6481218240000 - 
       (2812050169*CF*NM*NC)/15876000 + (80021*CF*lm*NM*NC)/2700 + 
       (2108951*CF*NC*NL)/8100 + (80021*CF*lm*NC*NL)/2700 + 
       (98173047839200927*CF*NC*NH)/15404466924000 + 
       (80021*CF*lm*NC*NH)/2700 + (7766743*CF^2*NC*Pi^2)/226800 + 
       (25901*CF*NM*NC*Pi^2)/90 + (2*CF*lm*NM*NC*Pi^2)/9 - 
       (1727*CF*NC*NL*Pi^2)/90 + (2*CF*lm*NC*NL*Pi^2)/9 + 
       (2*CF*lm*NC*NH*Pi^2)/9 - (785812741*CF^2*NC*Pi^3)/(2834352*Sqrt[3]) - 
       (244072885*CF*NC*NH*Pi^3)/(354294*Sqrt[3]) - (24521*CF^2*NC*Pi^4)/
        3240 - (3534323503*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (11809800*Sqrt[3]) + (192666974*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (59049*Sqrt[3]) - (3158*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (112258963*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10935*Sqrt[3]) - (55788088*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (112258963*CF^2*NC*Pi*Log[3]^2)/(524880*Sqrt[3]) - 
       (6973511*CF*NC*NH*Pi*Log[3]^2)/(13122*Sqrt[3]) - 
       (CF*NC*(-11*CA*(532661849 + 190436400*lm) + 
          20*(299447401*CF + 126*(33*(-41327 + 4580*lm)*NM + 
              110*(1873 + 1374*lm)*NL + (27767 + 151140*lm)*NH)))*Log[x]^2)/
        1247400 - (2*CF*NC*(182713*CA + 1667342*CF - 
          180*(3535*NM + 229*NL))*Log[x]^3)/405 - 
       (268045045*CF^2*NC*PolyGamma[2, 1])/1062882 + 
       (2378*CF*NM*NC*PolyGamma[2, 1])/3 - 
       (152290384*CF*NC*NH*PolyGamma[2, 1])/531441 + 
       (CA*CF*NC*(-9694427845597191 - 251716365567450*Pi^2 + 
          673834425407500*Sqrt[3]*Pi^3 + 57775109679000*Pi^4 - 
          29705583600*lm*(80021 + 600*Pi^2) + 727363776917400*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 7675382700720000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 24951126152232000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 519815128171500*Sqrt[3]*Pi*
           Log[3]^2 + 1838789008700000*PolyGamma[2, 1] - 23160813651836000*
           Zeta[3]))/14582741040000 + (20026009253*CF^2*NC*Zeta[3])/5314410 + 
       (4844*CF*NM*NC*Zeta[3])/3 - 308*CF*NC*NL*Zeta[3] - 
       (189553316*CF*NC*NH*Zeta[3])/531441 - 
       (CF*NC*Log[x]*(-280*(-882090*NM*(1583753 + 53592*lm - 1282260*Pi^2) - 
            9261945*NL*(61273 + 5104*lm + 9160*Pi^2) - 
            2*NH*(4263197455389 + 23636483640*lm - 2362625526800*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) - 121*CA*(1253648624757 + 
            601655947200*lm + 531984518100*Pi^2 - 2200275674800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 1620304560000*Zeta[3]) + 
          121*CF*(803949766887 + 836045242200*Pi^2 - 4400551349600*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 3240609120000*Zeta[3])))/
        466802028000, (13507236143437397*CF^2*NC)/11666192832000 - 
       (64297574557*CF*NM*NC)/385786800 + (3634481*CF*lm*NM*NC)/97200 + 
       (428498329*CF*NC*NL)/1166400 + (3634481*CF*lm*NC*NL)/97200 + 
       (23670062228163469*CF*NC*NH)/2772804046320 + (3634481*CF*lm*NC*NH)/
        97200 - (140964569*CF^2*NC*Pi^2)/272160 + (3606043*CF*NM*NC*Pi^2)/
        9720 + (41*CF*lm*NM*NC*Pi^2)/162 - (27869*CF*NC*NL*Pi^2)/1080 + 
       (41*CF*lm*NC*NL*Pi^2)/162 + (41*CF*lm*NC*NH*Pi^2)/162 - 
       (4913919745*CF^2*NC*Pi^3)/(12754584*Sqrt[3]) - 
       (5988749515*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) - 
       (1691*CF^2*NC*Pi^4)/162 - (6053757989*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10628820*Sqrt[3]) + 
       (5147974187*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1062882*Sqrt[3]) - 
       1400*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (280795414*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (19683*Sqrt[3]) - (684428516*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (140397707*CF^2*NC*Pi*Log[3]^2)/(472392*Sqrt[3]) - 
       (171107129*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) - 
       (CF*NC*(-99*CA*(384821363 + 89273800*lm) + 
          20*(2583934683*CF + 7*(22*(-4237919 + 521730*lm)*NM + 
              5*(99*(31111 + 23188*lm)*NL + 34*(13289 + 67518*lm)*NH))))*
         Log[x]^2)/3742200 + (2*CF*NC*(13411*CA - 3007245*CF + 906620*NM + 
          57970*NL)*Log[x]^3)/405 - (18286459415*CF^2*NC*PolyGamma[2, 1])/
        6377292 + (22765*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (1355408795*CF*NC*NH*PolyGamma[2, 1])/3188646 + 
       CA*CF*NC*(-46091119435968703/29165482080000 + (4444369*Pi^2)/17010 + 
         (4913919745*Pi^3)/(25509168*Sqrt[3]) + (8783*Pi^4)/1620 - 
         (11*lm*(3634481 + 24600*Pi^2))/194400 + 
         (6053757989*Im[PolyLog[2, (-1)^(1/3)]])/(21257640*Sqrt[3]) + 
         700*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (140397707*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) + 
         (140397707*Pi*Log[3]^2)/(944784*Sqrt[3]) + 
         (18286459415*PolyGamma[2, 1])/12754584 - (3667801321*Zeta[3])/
          6377292) + (3133952969*CF^2*NC*Zeta[3])/1594323 + 
       (22573*CF*NM*NC*Zeta[3])/54 - (3892*CF*NC*NL*Zeta[3])/9 - 
       (988438943*CF*NC*NH*Zeta[3])/1594323 - 
       (CF*NC*Log[x]*(-121*CA*(9928390906929 + 7009810453800*lm + 
            18396243558000*Pi^2 - 27517950572000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 19443654720000*Zeta[3]) + 
          5*(-28*(-39204*NM*(1332199684 + 28097685*lm - 735975450*Pi^2) - 
              5*(20376279*NL*(143139 + 10812*lm + 21080*Pi^2) + 
                2*NH*(20928944469651 + 110154164274*lm - 11594219061040*
                   Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
            121*CF*(-365602782291 + 6759156196800*Pi^2 - 11007180228800*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 7777461888000*Zeta[3]))))/
        4201218252000, (97355510998456507*CF^2*NC)/116661928320000 - 
       (72603598400099*CF*NM*NC)/10802030400 + (4582699*CF*lm*NM*NC)/
        97200 + (1652471699*CF*NC*NL)/2916000 + (4582699*CF*lm*NC*NL)/
        97200 + (5021420674669602438247*CF*NC*NH)/387663212985048000 + 
       (4582699*CF*lm*NC*NH)/97200 - (11418278*CF^2*NC*Pi^2)/25515 + 
       (6212327*CF*NM*NC*Pi^2)/2430 + (49*CF*lm*NM*NC*Pi^2)/162 - 
       (58639*CF*NC*NL*Pi^2)/1620 + (49*CF*lm*NC*NL*Pi^2)/162 + 
       (49*CF*lm*NC*NH*Pi^2)/162 - (29299101965*CF^2*NC*Pi^3)/
        (51018336*Sqrt[3]) - (9310038185*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) - 
       (32081*CF^2*NC*Pi^4)/2160 - (15203397007*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(42515280*Sqrt[3]) + 
       (18172899874*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) - 
       (5705*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (837117199*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (39366*Sqrt[3]) - (1064004364*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (837117199*CF^2*NC*Pi*Log[3]^2)/(1889568*Sqrt[3]) - 
       (266001091*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) - 
       (CF*NC*(-39*CA*(3045835613 + 818202000*lm) + 
          8*(18664825881*CF + 5*(65*(-99331951 + 2231460*lm)*NM + 
              114660*(1677 + 1265*lm)*NL + (31595833 + 145044900*lm)*NH)))*
         Log[x]^2)/8845200 - (2*CF*NC*(130197*CA + 4601828*CF - 3316120*NM - 
          88550*NL)*Log[x]^3)/405 - (27311603261*CF^2*NC*PolyGamma[2, 1])/
        19131876 + (213437*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (5607948605*CF*NC*NH*PolyGamma[2, 1])/9565938 + 
       (CA*CF*NC*(-1824793470123169041 + 240691622269581000*Pi^2 + 
          100495919739950000*Sqrt[3]*Pi^3 + 8051212343412000*Pi^4 - 
          59411167200*lm*(4582699 + 29400*Pi^2) + 62577182080812000*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 998334451598400000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 3721220342370720000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 77525423799390000*Sqrt[3]*
           Pi*Log[3]^2 + 749430393481840000*PolyGamma[2, 1] - 
          3361794616489456000*Zeta[3]))/1049957354880000 + 
       (721873375807*CF^2*NC*Zeta[3])/95659380 + (299926*CF*NM*NC*Zeta[3])/
        27 - (5936*CF*NC*NL*Zeta[3])/9 - (973546889*CF*NC*NH*Zeta[3])/
        4782969 - (CF*NC*Log[x]*
         (-40*(-301158*NM*(25904460049 + 577052910*lm - 41528308500*Pi^2) - 
            199216017*NL*(12497529 + 872340*lm + 1771000*Pi^2) - 
            2*NH*(17463184312836117 + 86892050134890*lm - 9692122152112400*
               Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
          37180*CA*(-537245927832 + 1028308285620*lm + 2197475369145*Pi^2 - 
            4101874275100*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            2722111660800*Zeta[3]) + 1859*CF*(-89241875638059 + 
            78984124795800*Pi^2 - 164074971004000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 108884466432000*Zeta[3])))/
        129091979016000, (9422047554100811317187*CF^2*NC)/
        652163511694464000 - (30890539858939933*CF*NM*NC)/3594375615600 + 
       (54926339*CF*lm*NM*NC)/952560 + (220243651459*CF*NC*NL)/285768000 + 
       (54926339*CF*lm*NC*NL)/952560 + (53859814587916049396323*CF*NC*NH)/
        3198221507126646000 + (54926339*CF*lm*NC*NH)/952560 - 
       (54583728877*CF^2*NC*Pi^2)/11430720 + (220188491*CF*NM*NC*Pi^2)/
        68040 + (55*CF*lm*NM*NC*Pi^2)/162 - (212339*CF*NC*NL*Pi^2)/4536 + 
       (55*CF*lm*NC*NL*Pi^2)/162 + (55*CF*lm*NC*NH*Pi^2)/162 - 
       (29250490705*CF^2*NC*Pi^3)/(38263752*Sqrt[3]) - 
       (36830519215*CF*NC*NH*Pi^3)/(19131876*Sqrt[3]) - 
       (3173*CF^2*NC*Pi^4)/162 - (1041713404181*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1562436540*Sqrt[3]) + 
       (152983775059*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15943230*Sqrt[3]) - 2440*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (11700196282*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (413343*Sqrt[3]) - (4209202196*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (5850098141*CF^2*NC*Pi*Log[3]^2)/(9920232*Sqrt[3]) - 
       (1052300549*CF*NC*NH*Pi*Log[3]^2)/(708588*Sqrt[3]) - 
       (CF*NC*(4988703090787*CF - 13*CA*(227578090613 + 25534305720*lm) + 
          28*(26*(-3449727761 + 82903590*lm)*NM + 315315*(8943 + 6836*lm)*
             NL + 2*(248086561 + 1077746670*lm)*NH))*Log[x]^2)/68108040 + 
       (2*CF*NC*(2251775*CA - 14071176*CF + 98*(63646*NM + 1709*NL))*
         Log[x]^3)/567 - (1425010077827*CF^2*NC*PolyGamma[2, 1])/57395628 + 
       (336209*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (23616015743*CF*NC*NH*PolyGamma[2, 1])/28697814 - 
       (5269599814349*CF^2*NC*Zeta[3])/200884698 - (6031*CF*NM*NC*Zeta[3])/
        54 - (8012*CF*NC*NL*Zeta[3])/9 - (6392367227*CF*NC*NH*Zeta[3])/
        14348907 + CA*CF*NC*(-1451726840967187459303/163040877923616000 + 
         (1712923063*Pi^2)/714420 + (29250490705*Pi^3)/(76527504*Sqrt[3]) + 
         (1087*Pi^4)/108 - (11*lm*(54926339 + 323400*Pi^2))/1905120 + 
         (1041713404181*Im[PolyLog[2, (-1)^(1/3)]])/(3124873080*Sqrt[3]) + 
         1220*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (5850098141*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (413343*Sqrt[3]) + (5850098141*Pi*Log[3]^2)/(19840464*Sqrt[3]) + 
         (1425010077827*PolyGamma[2, 1])/114791256 + (5575658812013*Zeta[3])/
          401769396) - (CF*NC*Log[x]*
         (-56*(-164268*NM*(4124878460558 + 43913625525*lm - 3368074282650*Pi^
                2) - 939161223*NL*(119703021 + 7680900*lm + 16748200*Pi^2) - 
            10*NH*(152003169416340681 + 721360343774070*lm - 
              84352496191883920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
          2366*CA*(6149026597433757 + 939048968226600*lm + 7721005572126000*
             Pi^2 - 3964026500341600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            2540896798809600*Zeta[3]) + 169*CF*(125371107207861297 + 
            209892879429987600*Pi^2 - 110992742009564800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 71145110366668800*Zeta[3])))/
        5964049430539200, (97186774767699195352097*CF^2*NC)/
        7336839506562720000 - (550245683532209683*CF*NM*NC)/8985939039000 + 
       (20988631*CF*lm*NM*NC)/297675 + (8010687217*CF*NC*NL)/7144200 + 
       (20988631*CF*lm*NC*NL)/297675 + (347752498122181502463703*CF*NC*NH)/
        14391996782069907000 + (20988631*CF*lm*NC*NH)/297675 - 
       (16435733849*CF^2*NC*Pi^2)/3742200 + (162155506*CF*NM*NC*Pi^2)/8505 + 
       (32*CF*lm*NM*NC*Pi^2)/81 - (177172*CF*NC*NL*Pi^2)/2835 + 
       (32*CF*lm*NC*NL*Pi^2)/81 + (32*CF*lm*NC*NH*Pi^2)/81 - 
       (370252924007*CF^2*NC*Pi^3)/(344373768*Sqrt[3]) - 
       (120957731720*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (4279*CF^2*NC*Pi^4)/162 - (15801086299829*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(70309644300*Sqrt[3]) + 
       (188429109320*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (14348907*Sqrt[3]) - (9544*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (740505848014*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (18600435*Sqrt[3]) - (55294963072*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (370252924007*CF^2*NC*Pi*Log[3]^2)/(446410440*Sqrt[3]) - 
       (3455935192*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) - 
       (CF*NC*(-65*CA*(124397163197 + 18347646240*lm) + 
          8*(1605403170319*CF + 140*(13*(-2642871409 + 14892570*lm)*NM + 
              630630*(398 + 307*lm)*NL + (47975171 + 193603410*lm)*NH)))*
         Log[x]^2)/170270100 + (2*CF*NC*(9400493*CA + 
          20*(-4582217*CF + 6625388*NM + 60172*NL))*Log[x]^3)/2835 - 
       (473963166926*CF^2*NC*PolyGamma[2, 1])/43046721 + 
       (1971332*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (47166867988*CF*NC*NH*PolyGamma[2, 1])/43046721 + 
       CA*CF*NC*(-8049390902485034345123/917104938320340000 + 
         (9029698739*Pi^2)/4082400 + (370252924007*Pi^3)/
          (688747536*Sqrt[3]) + (21907*Pi^4)/1620 - 
         (11*lm*(20988631 + 117600*Pi^2))/595350 + 
         (15801086299829*Im[PolyLog[2, (-1)^(1/3)]])/(140619288600*Sqrt[3]) + 
         (4772*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (370252924007*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (18600435*Sqrt[3]) + (370252924007*Pi*Log[3]^2)/
          (892820880*Sqrt[3]) + (236981583463*PolyGamma[2, 1])/43046721 - 
         (5905494004021*Zeta[3])/3013270470) + 
       (9003415053706*CF^2*NC*Zeta[3])/1506635235 + 
       (2864200*CF*NM*NC*Zeta[3])/27 - (11504*CF*NC*NL*Zeta[3])/9 + 
       (14981551960*CF*NC*NH*Zeta[3])/43046721 + 
       CF*Log[x]*((6083117856643*NM*NC)/648336150 - (3272*lm*NM*NC)/35 - 
         (982691*NC*NL)/630 - (3272*lm*NC*NL)/35 - 
         (1661436482417888887*NC*NH)/79875662016150 - (3272*lm*NC*NH)/35 + 
         (1860320*NM*NC*Pi^2)/81 - (17192*NC*NL*Pi^2)/81 + 
         (55294963072*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(493578745513533133/132338374938000 - (35088791*Pi^2)/5670 + 
           (740505848014*Im[PolyLog[2, (-1)^(1/3)]])/(55801305*Sqrt[3]) - 
           2688*Zeta[3]) + CA*NC*(-5957879043159067/6616918746900 + 
           (17996*lm)/35 + (36511681*Pi^2)/11340 - 
           (370252924007*Im[PolyLog[2, (-1)^(1/3)]])/(55801305*Sqrt[3]) + 
           1344*Zeta[3])), (1549586725298587209893419231*CF^2*NC)/
        12895229116734636672000 - (13738923457927740204953*CF*NM*NC)/
        180499273770816000 + (1604274461*CF*lm*NM*NC)/19051200 + 
       (1690265424971*CF*NC*NL)/1143072000 + (1604274461*CF*lm*NC*NL)/
        19051200 + (1882798693957471980791429*CF*NC*NH)/
        61405852936831603200 + (1604274461*CF*lm*NC*NH)/19051200 - 
       (1855428785869*CF^2*NC*Pi^2)/50295168 + (1570714021*CF*NM*NC*Pi^2)/
        68040 + (71*CF*lm*NM*NC*Pi^2)/162 - (296539*CF*NC*NL*Pi^2)/3780 + 
       (71*CF*lm*NC*NL*Pi^2)/162 + (71*CF*lm*NC*NH*Pi^2)/162 - 
       (1907500472525*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (103528826975*CF*NC*NH*Pi^3)/(28697814*Sqrt[3]) - 
       (21821*CF^2*NC*Pi^4)/648 - (57813230153477*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(112495430880*Sqrt[3]) + 
       (845323607153*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (47829690*Sqrt[3]) - 3970*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (381500094505*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7440174*Sqrt[3]) - (23663731880*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (381500094505*CF^2*NC*Pi*Log[3]^2)/(357128352*Sqrt[3]) - 
       (2957966485*CF*NC*NH*Pi*Log[3]^2)/(1062882*Sqrt[3]) - 
       (CF*NC*(-21*CA*(16176899865913 + 594541147200*lm) + 
          40*(16106834936811*CF + 343*((-27147530401 + 165456720*lm)*NM + 
              5*(5148*(8241 + 6428*lm)*NL + (8577709 + 33091344*lm)*NH))))*
         Log[x]^2)/1362160800 + (CF*NC*(405656693*CA - 
          70*(17244433*CF - 9576632*NM - 89992*NL))*Log[x]^3)/5670 - 
       (114308802097397*CF^2*NC*PolyGamma[2, 1])/516560652 + 
       (1661147*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (762283948369*CF*NC*NH*PolyGamma[2, 1])/516560652 - 
       (1237525332446749*CF^2*NC*Zeta[3])/3615924564 + 
       (302573*CF*NM*NC*Zeta[3])/27 - (15046*CF*NC*NL*Zeta[3])/9 + 
       (56318007335*CF*NC*NH*Zeta[3])/258280326 + 
       CA*CF*NC*(-16187716275431947332758828719/257904582334692733440000 + 
         (168889021345*Pi^2)/9144576 + (1907500472525*Pi^3)/
          (2754990144*Sqrt[3]) + (111377*Pi^4)/6480 - 
         (11*lm*(1604274461 + 8349600*Pi^2))/38102400 + 
         (57813230153477*Im[PolyLog[2, (-1)^(1/3)]])/(224990861760*Sqrt[3]) + 
         1985*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (381500094505*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (14880348*Sqrt[3]) + (381500094505*Pi*Log[3]^2)/
          (714256704*Sqrt[3]) + (114308802097397*PolyGamma[2, 1])/
          1033121304 + (1247174494107349*Zeta[3])/7231849128) + 
       CF*Log[x]*((-452138597483227*NM*NC)/70124037984 - 
         (144763*lm*NM*NC)/1260 - (155987519*NC*NL)/75600 - 
         (144763*lm*NC*NL)/1260 - (11375830225970790473*NC*NH)/
          426003530752800 - (144763*lm*NC*NH)/1260 + (2350408*NM*NC*Pi^2)/
          81 - (22498*NC*NL*Pi^2)/81 + (23663731880*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-431808088232775844141/7156859316647040 - 
           (59789123*Pi^2)/1512 + (381500094505*Im[PolyLog[2, (-1)^(1/3)]])/
            (22320522*Sqrt[3]) - 3360*Zeta[3]) + 
         CA*NC*(11249797373679231308299/357842965832352000 + 
           (1592393*lm)/2520 + (180889603*Pi^2)/9072 - 
           (381500094505*Im[PolyLog[2, (-1)^(1/3)]])/(44641044*Sqrt[3]) + 
           1680*Zeta[3])), (13970129456916514182983974217*CF^2*NC)/
        128952291167346366720000 - (65181690315944002903007*CF*NM*NC)/
        140388324043968000 + (212891299*CF*lm*NM*NC)/2116800 + 
       (913567957289*CF*NC*NL)/444528000 + (212891299*CF*lm*NC*NL)/
        2116800 + (5448864024345758388799527599*CF*NC*NH)/
        129294409490851571366400 + (212891299*CF*lm*NC*NH)/2116800 - 
       (81131821844477*CF^2*NC*Pi^2)/2514758400 + (24908789*CF*NM*NC*Pi^2)/
        180 + (CF*lm*NM*NC*Pi^2)/2 - (84797*CF*NC*NL*Pi^2)/840 + 
       (CF*lm*NC*NL*Pi^2)/2 + (CF*lm*NC*NH*Pi^2)/2 - 
       (5137758996949*CF^2*NC*Pi^3)/(2754990144*Sqrt[3]) - 
       (216192261530*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (94307*CF^2*NC*Pi^4)/2160 + (340292055175379*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1124954308800*Sqrt[3]) + 
       (1688256362834*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (71744535*Sqrt[3]) - 5017*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (5137758996949*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (74401740*Sqrt[3]) - (98830748128*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (5137758996949*CF^2*NC*Pi*Log[3]^2)/(3571283520*Sqrt[3]) - 
       (6176921758*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) - 
       (CF*NC*(-17*CA*(631743595502909 + 34282863014400*lm) + 
          2*(9920350909894111*CF + 2520*(17*(-894987535087 + 1236755520*lm)*
               NM + 7*(875160*(4369 + 3432*lm)*NL + (823559879 + 
                  3003549120*lm)*NH))))*Log[x]^2)/46313467200 + 
       (CF*NC*(360752627*CA - 462*(2800249*CF - 360*(20375*NM + 52*NL)))*
         Log[x]^3)/5670 - (147965750561507*CF^2*NC*PolyGamma[2, 1])/
        1549681956 + (1322109*CF*NM*NC*PolyGamma[2, 1])/2 - 
       (739808272195*CF*NC*NH*PolyGamma[2, 1])/387420489 - 
       (9657808008146251*CF^2*NC*Zeta[3])/108477736920 + 
       (3106433*CF*NM*NC*Zeta[3])/3 - 2294*CF*NC*NL*Zeta[3] + 
       (614003778166*CF*NC*NH*Zeta[3])/387420489 + 
       CA*CF*NC*(-3709367748342724083009274469/64476145583673183360000 + 
         (27098765341939*Pi^2)/1676505600 + (5137758996949*Pi^3)/
          (5509980288*Sqrt[3]) + (19207*Pi^4)/864 + 
         lm*(-2341804289/4233600 - (11*Pi^2)/4) - 
         (340292055175379*Im[PolyLog[2, (-1)^(1/3)]])/(2249908617600*
           Sqrt[3]) + (5017*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (5137758996949*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (148803480*Sqrt[3]) + (5137758996949*Pi*Log[3]^2)/
          (7142567040*Sqrt[3]) + (147965750561507*PolyGamma[2, 1])/
          3099363912 + (10036891495201111*Zeta[3])/216955473840) + 
       CF*Log[x]*((39077536061548601*NM*NC)/194788994400 - 
         (21237*lm*NM*NC)/140 - (765511219*NC*NL)/264600 - 
         (21237*lm*NC*NL)/140 - (1958933367801915756019*NC*NH)/
          52763580166096800 - (21237*lm*NC*NH)/140 + (446186*NM*NC*Pi^2)/
          3 - (1144*NC*NL*Pi^2)/3 + (98830748128*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(-6070310601491674486433/357842965832352000 - 
           (559956427*Pi^2)/15120 + (5137758996949*Im[PolyLog[2, (-1)^
                (1/3)]])/(223205220*Sqrt[3]) - 4320*Zeta[3]) + 
         CA*NC*(149533699969965183629/14605835340096000 + (233607*lm)/280 + 
           (1700409101*Pi^2)/90720 - (5137758996949*Im[PolyLog[2, (-1)^
                (1/3)]])/(446410440*Sqrt[3]) + 2160*Zeta[3])), 
      (3209638952584189283300267207143*CF^2*NC)/3481711861518351901440000 - 
       (53716930436775134650117*CF*NM*NC)/97191916645824000 + 
       (20212282171*CF*lm*NM*NC)/171460800 + (63401061529753*CF*NC*NL)/
        24004512000 + (20212282171*CF*lm*NC*NL)/171460800 + 
       (1280741108027108430021253465603*CF*NC*NH)/
        24436643393770946988249600 + (20212282171*CF*lm*NC*NH)/171460800 - 
       (19208939699161*CF^2*NC*Pi^2)/68584320 + (4651550239*CF*NM*NC*Pi^2)/
        29160 + (89*CF*lm*NM*NC*Pi^2)/162 - (12632567*CF*NC*NL*Pi^2)/
        102060 + (89*CF*lm*NC*NL*Pi^2)/162 + (89*CF*lm*NC*NH*Pi^2)/162 - 
       (3223483997935*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (4887271681075*CF*NC*NH*Pi^3)/(774840978*Sqrt[3]) - 
       (175643*CF^2*NC*Pi^4)/3240 + (390305421059683*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3037376633760*Sqrt[3]) + 
       (831777262713569*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27119434230*Sqrt[3]) - (18370*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        3 - (644696799587*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7440174*Sqrt[3]) - (1117090669960*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) - 
       (644696799587*CF^2*NC*Pi*Log[3]^2)/(357128352*Sqrt[3]) - 
       (139636333745*CF*NC*NH*Pi*Log[3]^2)/(28697814*Sqrt[3]) - 
       (CF*NC*(237190718396050934*CF - 51*CA*(2356352444617999 + 
            21859653816000*lm) + 840*(663*(-238022038057 + 363963600*lm)*
             NM + 5*(9189180*(6623 + 5252*lm)*NL + (13737277643 + 
                48261573360*lm)*NH)))*Log[x]^2)/69470200800 + 
       (CF*NC*(9398765873*CA - 36*(585135759*CF - 700*(481031*NM + 
              1313*NL)))*Log[x]^3)/17010 - (9239223981283793*CF^2*NC*
         PolyGamma[2, 1])/4649045868 + (45743405*CF*NM*NC*PolyGamma[2, 1])/
        162 - (11576761798837*CF*NC*NH*PolyGamma[2, 1])/4649045868 - 
       (548697421285825061*CF^2*NC*Zeta[3])/162716605380 + 
       (18128183*CF*NM*NC*Zeta[3])/81 - (78958*CF*NC*NL*Zeta[3])/27 + 
       (3952084521587*CF*NC*NH*Zeta[3])/2324522934 + 
       CA*CF*NC*(-647662824769532431043976567731/1392684744607340760576000 + 
         (42272966878075*Pi^2)/301771008 + (3223483997935*Pi^3)/
          (2754990144*Sqrt[3]) + (59497*Pi^4)/2160 + 
         lm*(-222335103881/342921600 - (979*Pi^2)/324) - 
         (390305421059683*Im[PolyLog[2, (-1)^(1/3)]])/(6074753267520*
           Sqrt[3]) + (9185*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (644696799587*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (14880348*Sqrt[3]) + (644696799587*Pi*Log[3]^2)/
          (714256704*Sqrt[3]) + (9239223981283793*PolyGamma[2, 1])/
          9298091736 + (549418831382318231*Zeta[3])/325433210760) + 
       CF*Log[x]*((5791147379188277*NM*NC)/44951306400 - 
         (6222439*lm*NM*NC)/34020 - (17733298111*NC*NL)/4762800 - 
         (6222439*lm*NC*NL)/34020 - (22138973339679727539763*NC*NH)/
          474872221494871200 - (6222439*lm*NC*NH)/34020 + 
         (531800*NM*NC*Pi^2)/3 - (13130*NC*NL*Pi^2)/27 + 
         (1117090669960*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CF*NC*(-55973398376715643072759/
            89460741458088000 - (19251999271*Pi^2)/68040 + 
           (644696799587*Im[PolyLog[2, (-1)^(1/3)]])/(22320522*Sqrt[3]) - 
           5280*Zeta[3]) + CA*NC*(112753671912533319901109/
            357842965832352000 + (68446829*lm)/68040 + (19291970671*Pi^2)/
            136080 - (644696799587*Im[PolyLog[2, (-1)^(1/3)]])/
            (44641044*Sqrt[3]) + 2640*Zeta[3])), 
      (274178474735628130241647198501*CF^2*NC)/348171186151835190144000 - 
       (432879146175584910385601*CF*NM*NC)/126349491639571200 + 
       (236939939*CF*lm*NM*NC)/1714608 + (42483760970381*CF*NC*NL)/
        12002256000 + (236939939*CF*lm*NC*NL)/1714608 + 
       (166722268911219983496827868992131*CF*NC*NH)/
        2394441957683927505605771520 + (236939939*CF*lm*NC*NH)/1714608 - 
       (64426198365071*CF^2*NC*Pi^2)/280215936 + (5218964750*CF*NM*NC*Pi^2)/
        5103 + (50*CF*lm*NM*NC*Pi^2)/81 - (789995*CF*NC*NL*Pi^2)/5103 + 
       (50*CF*lm*NC*NL*Pi^2)/81 + (50*CF*lm*NC*NH*Pi^2)/81 - 
       (12592769425025*CF^2*NC*Pi^3)/(4132485216*Sqrt[3]) - 
       (6557649320075*CF*NC*NH*Pi^3)/(774840978*Sqrt[3]) - 
       (44195*CF^2*NC*Pi^4)/648 + (918497962251875*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(607475326752*Sqrt[3]) + 
       (108133850151644*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2711943423*Sqrt[3]) - 7550*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (2518553885005*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (22320522*Sqrt[3]) - (1498891273160*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) - 
       (2518553885005*CF^2*NC*Pi*Log[3]^2)/(1071385056*Sqrt[3]) - 
       (187361409145*CF*NC*NH*Pi*Log[3]^2)/(28697814*Sqrt[3]) - 
       (CF*NC*(-6783*CA*(56224331784461 + 827579712960*lm) + 
          2*(373430345158691053*CF + 840*(2907*(-662960331071 + 208984776*lm)*
               NM + 69837768*(10908 + 8699*lm)*NL + (180768457505 + 
                607518743832*lm)*NH)))*Log[x]^2)/263986763040 + 
       (2*CF*NC*(397905973*CA - 953209429*CF + 252*(14076857*NM + 8699*NL))*
         Log[x]^3)/1701 - (5946892543218211*CF^2*NC*PolyGamma[2, 1])/
        6973568802 + (482520008*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (10974037049782*CF*NC*NH*PolyGamma[2, 1])/3486784401 - 
       (114524202449728069*CF^2*NC*Zeta[3])/97629963228 + 
       (797782216*CF*NM*NC*Zeta[3])/81 - (104588*CF*NC*NL*Zeta[3])/27 + 
       (13573219135216*CF*NC*NH*Zeta[3])/3486784401 + 
       CA*CF*NC*(-283377321475422633944614043/710553441126194265600 + 
         (4958359312007*Pi^2)/43110144 + (12592769425025*Pi^3)/
          (8264970432*Sqrt[3]) + (14945*Pi^4)/432 + 
         lm*(-2606339329/3429216 - (275*Pi^2)/81) - 
         (918497962251875*Im[PolyLog[2, (-1)^(1/3)]])/(1214950653504*
           Sqrt[3]) + 3775*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (2518553885005*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (44641044*Sqrt[3]) + (2518553885005*Pi*Log[3]^2)/
          (2142770112*Sqrt[3]) + (5946892543218211*PolyGamma[2, 1])/
          13947137604 + (115077178561451461*Zeta[3])/195259926456) + 
       CF*Log[x]*((10264311294133639*NM*NC)/4869724860 - 
         (397165*lm*NM*NC)/1701 - (23887889089*NC*NL)/4762800 - 
         (397165*lm*NC*NL)/1701 - (3749071117704261893130931*NC*NH)/
          60000105185876976120 - (397165*lm*NC*NH)/1701 + 
         (3124870*NM*NC*Pi^2)/3 - (17398*NC*NL*Pi^2)/27 + 
         (1498891273160*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CF*NC*(-34689564228319672720889/
            107352889749705600 - (367165385*Pi^2)/1512 + 
           (2518553885005*Im[PolyLog[2, (-1)^(1/3)]])/(66961566*Sqrt[3]) - 
           6600*Zeta[3]) + CA*NC*(5047677572692473653381/30672254214201600 + 
           (4368815*lm)/3402 + (1104976919*Pi^2)/9072 - 
           (2518553885005*Im[PolyLog[2, (-1)^(1/3)]])/(133923132*Sqrt[3]) + 
           3300*Zeta[3])), (90519441275654686983247920291478111*CF^2*NC)/
        12829237781729747168831040000 - (24173731107372016220348577043*CF*NM*
         NC)/6207550524252133056000 + (5470817083*CF*lm*NM*NC)/34292160 + 
       (106850034431309*CF*NC*NL)/24004512000 + (5470817083*CF*lm*NC*NL)/
        34292160 + (353781793851126110226820653624077*CF*NC*NH)/
        4155643067054750216340595200 + (5470817083*CF*lm*NC*NH)/34292160 - 
       (10604913326134879*CF^2*NC*Pi^2)/4903778880 + 
       (229349191121*CF*NM*NC*Pi^2)/204120 + (109*CF*lm*NM*NC*Pi^2)/162 - 
       (19006933*CF*NC*NL*Pi^2)/102060 + (109*CF*lm*NC*NL*Pi^2)/162 + 
       (109*CF*lm*NC*NH*Pi^2)/162 - (69618852288413*CF^2*NC*Pi^3)/
        (18596183472*Sqrt[3]) - (12127722658345*CF*NC*NH*Pi^3)/
        (1162261467*Sqrt[3]) - (26861*CF^2*NC*Pi^4)/324 + 
       (36250601066828237*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (22780324753200*Sqrt[3]) + (4121766761191651*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(81358302690*Sqrt[3]) - 
       (27148*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (69618852288413*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (502211745*Sqrt[3]) - (5544101786672*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (69618852288413*CF^2*NC*Pi*Log[3]^2)/(24106163760*Sqrt[3]) - 
       (346506361667*CF*NC*NH*Pi*Log[3]^2)/(43046721*Sqrt[3]) - 
       (CF*NC*(17185372120953367873*CF - 19*CA*(453558535986811051 + 
            922016223928800*lm) + 420*(171*(-123810405275269 + 
              44349024720*lm)*NM + 77*(2267460*(54027 + 43436*lm)*NL + 
              (30244517383 + 98489392560*lm)*NH)))*Log[x]^2)/659966907600 + 
       (CF*NC*(72017488729*CA + 30*(-4936553999*CF + 2670713976*NM + 
            1824312*NL))*Log[x]^3)/17010 - (748055057294505275*CF^2*NC*
         PolyGamma[2, 1])/41841412812 + (826665305*CF*NM*NC*PolyGamma[2, 1])/
        324 - (41834803112002*CF*NC*NH*PolyGamma[2, 1])/10460353203 - 
       (23021534296887301747*CF^2*NC*Zeta[3])/732224724210 + 
       (449246597*CF*NM*NC*Zeta[3])/162 - (130526*CF*NC*NL*Zeta[3])/27 + 
       (46406048116768*CF*NC*NH*Zeta[3])/10460353203 + 
       CA*CF*NC*(-72541227747170824748315699376599021/
          20526780450767595470129664000 + (101977319830607*Pi^2)/94303440 + 
         (69618852288413*Pi^3)/(37192366944*Sqrt[3]) + (136049*Pi^4)/3240 - 
         (11*lm*(5470817083 + 23073120*Pi^2))/68584320 - 
         (36250601066828237*Im[PolyLog[2, (-1)^(1/3)]])/(45560649506400*
           Sqrt[3]) + (13574*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (69618852288413*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1004423490*Sqrt[3]) + (69618852288413*Pi*Log[3]^2)/
          (48212327520*Sqrt[3]) + (748055057294505275*PolyGamma[2, 1])/
          83682825624 + (23026695559132218427*Zeta[3])/1464449448420) + 
       CF*Log[x]*((95252108411216586647*NM*NC)/56294019381600 - 
         (9426671*lm*NM*NC)/34020 - (30053572121*NC*NL)/4762800 - 
         (9426671*lm*NC*NL)/34020 - (2291647519003641600385823*NC*NH)/
          29752118273988583200 - (9426671*lm*NC*NH)/34020 + 
         (3528490*NM*NC*Pi^2)/3 - (21718*NC*NL*Pi^2)/27 + 
         (5544101786672*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(-3943992976005063401215754821/
            698062165597460664000 - (72396927383*Pi^2)/34020 + 
           (69618852288413*Im[PolyLog[2, (-1)^(1/3)]])/(1506635235*Sqrt[3]) - 
           7920*Zeta[3]) + CA*NC*(3949258044016966848235254763/
            1396124331194921328000 + (103693381*lm)/68040 + 
           (36214987069*Pi^2)/34020 - (69618852288413*
             Im[PolyLog[2, (-1)^(1/3)]])/(3013270470*Sqrt[3]) + 
           3960*Zeta[3])), (7879017236787688185187413845067349537*CF^2*NC)/
        1385557680426812694233752320000 - (159267560402916837142391682097*CF*
         NM*NC)/6207550524252133056000 + (6316952959*CF*lm*NM*NC)/
        34292160 + (27807333694811*CF*NC*NL)/4800902400 + 
       (6316952959*CF*lm*NC*NL)/34292160 + 
       (1493808284907061270297349957244633227*CF*NC*NH)/
        13576485900067868956784724518400 + (6316952959*CF*lm*NC*NH)/
        34292160 - (54751953194430911*CF^2*NC*Pi^2)/32691859200 + 
       (396084300677*CF*NM*NC*Pi^2)/51030 + (121*CF*lm*NM*NC*Pi^2)/162 - 
       (46480379*CF*NC*NL*Pi^2)/204120 + (121*CF*lm*NC*NL*Pi^2)/162 + 
       (121*CF*lm*NC*NH*Pi^2)/162 - (9531792541249439*CF^2*NC*Pi^3)/
        (2008387814976*Sqrt[3]) - (1706353158122095*CF*NC*NH*Pi^3)/
        (125524238436*Sqrt[3]) - (219989*CF^2*NC*Pi^4)/2160 + 
       (9322358353744031591*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2460275073345600*Sqrt[3]) + (70855948097030267*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1098337086315*Sqrt[3]) - 
       (32813*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (9531792541249439*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (54238868460*Sqrt[3]) - (195011789499668*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (9531792541249439*CF^2*NC*Pi*Log[3]^2)/(2603465686080*Sqrt[3]) - 
       (48752947374917*CF*NC*NH*Pi*Log[3]^2)/(4649045868*Sqrt[3]) - 
       (CF*NC*(-19*CA*(1410796619072837069 + 4750264265947200*lm) + 
          42*(1270325564601665461*CF + 40*(57*(-2567343901508213 + 
                171365954760*lm)*NM + 1920538620*(6297 + 5086*lm)*NL + 
              (3109410220967 + 9767859421320*lm)*NH)))*Log[x]^2)/
        2639867630400 + (CF*NC*(57425002173*CA - 120309060034*CF + 
          2520*(207867328*NM + 27973*NL))*Log[x]^3)/17010 - 
       (961994572864659689*CF^2*NC*PolyGamma[2, 1])/125524238436 + 
       (4343764646*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (311066167042823*CF*NC*NH*PolyGamma[2, 1])/62762119218 - 
       (104102809745542646929*CF^2*NC*Zeta[3])/8786696690520 + 
       (7442988952*CF*NM*NC*Zeta[3])/81 - (168080*CF*NC*NL*Zeta[3])/27 + 
       (243848596807525*CF*NC*NH*Zeta[3])/31381059609 + 
       CA*CF*NC*(-789960265613814999868189375850928697/
          277111536085362538846750464000 + (1659335851663627*Pi^2)/
          1981324800 + (9531792541249439*Pi^3)/(4016775629952*Sqrt[3]) + 
         (667711*Pi^4)/12960 - (11*lm*(6316952959 + 25613280*Pi^2))/
          68584320 - (9322358353744031591*Im[PolyLog[2, (-1)^(1/3)]])/
          (4920550146691200*Sqrt[3]) + (32813*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          6 + (9531792541249439*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (108477736920*Sqrt[3]) + (9531792541249439*Pi*Log[3]^2)/
          (5206931372160*Sqrt[3]) + (961994572864659689*PolyGamma[2, 1])/
          251048476872 + (104180311501968535549*Zeta[3])/17573393381040) + 
       CF*Log[x]*((1609444583755337826769*NM*NC)/84441029072400 - 
         (11719499*lm*NM*NC)/34020 - (26149828013*NC*NL)/3175200 - 
         (11719499*lm*NC*NL)/34020 - (1218002371572273449584443199*NC*NH)/
          12150021300140087664300 - (11719499*lm*NC*NH)/34020 + 
         (69273823*NM*NC*Pi^2)/9 - (27973*NC*NL*Pi^2)/27 + 
         (195011789499668*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(-248063775305983204072898220643/
            75390713884525751712000 - (231665163577*Pi^2)/136080 + 
           (9531792541249439*Im[PolyLog[2, (-1)^(1/3)]])/(162716605380*
             Sqrt[3]) - 9680*Zeta[3]) + CA*NC*(248798159540414843496622505407/
            150781427769051503424000 + (128914489*lm)/68040 + 
           (231833392477*Pi^2)/272160 - (9531792541249439*
             Im[PolyLog[2, (-1)^(1/3)]])/(325433210760*Sqrt[3]) + 
           4840*Zeta[3])), (34783629245017870841001659420935749083087*CF^2*
         NC)/633569342003167217983287144192000 - 
       (91305752046124981046833691031131*CF*NM*NC)/
        3275199157372721587008000 + (871437545933*CF*lm*NM*NC)/4149351360 + 
       (830756711983651*CF*NC*NL)/116181838080 + (871437545933*CF*lm*NC*NL)/
        4149351360 + (1285751506158656136502493192917840403*CF*NC*NH)/
        9697489928619906397703374656000 + (871437545933*CF*lm*NC*NH)/
        4149351360 - (229747327733993471*CF^2*NC*Pi^2)/13485391920 + 
       (2615210936267*CF*NM*NC*Pi^2)/320760 + (131*CF*lm*NM*NC*Pi^2)/162 - 
       (302720017*CF*NC*NL*Pi^2)/1122660 + (131*CF*lm*NC*NL*Pi^2)/162 + 
       (131*CF*lm*NC*NH*Pi^2)/162 - (10548033727455505*CF^2*NC*Pi^3)/
        (1841022163728*Sqrt[3]) - (517769263160765*CF*NC*NH*Pi^3)/
        (31381059609*Sqrt[3]) - (39419*CF^2*NC*Pi^4)/324 + 
       (21379756973428239103*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (4961554731246960*Sqrt[3]) + (176345173114526567*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2196674172630*Sqrt[3]) - 
       (38740*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (2109606745491101*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9943792551*Sqrt[3]) - (236694520302064*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (2109606745491101*CF^2*NC*Pi*Log[3]^2)/(477302042448*Sqrt[3]) - 
       (14793407518879*CF*NC*NH*Pi*Log[3]^2)/(1162261467*Sqrt[3]) - 
       (CF*NC*(-3*CA*(49535145984517675067 + 20288155145338080*lm) + 
          2*(148518479742478945817*CF + 462*(819*(-187685658473219 + 
                14623295280*lm)*NM + 5*(384107724*(7667 + 6236*lm)*NL + 
                (783322797017 + 2395295766864*lm)*NH))))*Log[x]^2)/
        1451927196720 + (CF*NC*(6178994289181*CA - 
          7920*(1569942775*CF - 77*(10160927*NM + 1559*NL)))*Log[x]^3)/
        187110 - (60587548638232179095*CF^2*NC*PolyGamma[2, 1])/
        376572715308 + (7445636677*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (580464734127724*CF*NC*NH*PolyGamma[2, 1])/94143178827 - 
       (2092294830756122140376*CF^2*NC*Zeta[3])/7249024769679 + 
       (4769618905*CF*NM*NC*Zeta[3])/162 - (206050*CF*NC*NL*Zeta[3])/27 + 
       (845603377419220*CF*NC*NH*Zeta[3])/94143178827 + 
       CA*CF*NC*(-1913717174399805727343972134866859055729819/
          69692627620348393978161585861120000 + (229750459135027001*Pi^2)/
          26970783840 + (10548033727455505*Pi^3)/(3682044327456*Sqrt[3]) + 
         (66397*Pi^4)/1080 + lm*(-871437545933/754427520 - (1441*Pi^2)/324) - 
         (21379756973428239103*Im[PolyLog[2, (-1)^(1/3)]])/
          (9923109462493920*Sqrt[3]) + (19370*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 + (2109606745491101*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (19887585102*Sqrt[3]) + (2109606745491101*Pi*Log[3]^2)/
          (954604084896*Sqrt[3]) + (60587548638232179095*PolyGamma[2, 1])/
          753145430616 + (4184746192388919948169*Zeta[3])/28996099078716) + 
       CF*Log[x]*((25060536132889102554901*NM*NC)/1563241615135200 - 
         (150946379*lm*NM*NC)/374220 - (532618941157*NC*NL)/52390800 - 
         (150946379*lm*NC*NL)/374220 - (11824193311068965457704935291*NC*
           NH)/97200170401120701314400 - (150946379*lm*NC*NH)/374220 + 
         8277170*NM*NC*Pi^2 - (34298*NC*NL*Pi^2)/27 + 
         (236694520302064*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(-486557680916156078303131837324859/
            9979217494515058668278400 - (309281874074*Pi^2)/18711 + 
           (2109606745491101*Im[PolyLog[2, (-1)^(1/3)]])/(29831377653*
             Sqrt[3]) - 11440*Zeta[3]) + 
         CA*NC*(1216694215708779418616459888544557/
            49896087472575293341392000 + (150946379*lm)/68040 + 
           (618621133399*Pi^2)/74844 - (2109606745491101*
             Im[PolyLog[2, (-1)^(1/3)]])/(59662755306*Sqrt[3]) + 
           5720*Zeta[3])), (3289551740612729624194631272384600984206233*CF^2*
         NC)/78404206072891943225431784093760000 - 
       (614844664225064133583072329277*CF*NM*NC)/3128864568330789288000 + 
       (1380154607*CF*lm*NM*NC)/5762988 + (732691686478193*CF*NC*NL)/
        80681832000 + (1380154607*CF*lm*NC*NL)/5762988 + 
       (51880236010733197223506897114287794578069*CF*NC*NH)/
        309722069898985802994749518528824000 + (1380154607*CF*lm*NC*NH)/
        5762988 - (3384687245952927323*CF^2*NC*Pi^2)/269707838400 + 
       (53733813685*CF*NM*NC*Pi^2)/891 + (8*CF*lm*NM*NC*Pi^2)/9 - 
       (10093598*CF*NC*NL*Pi^2)/31185 + (8*CF*lm*NC*NL*Pi^2)/9 + 
       (8*CF*lm*NC*NH*Pi^2)/9 - (117741237266773435*CF^2*NC*Pi^3)/
        (16569199473552*Sqrt[3]) - (1975292463238675*CF*NC*NH*Pi^3)/
        (94143178827*Sqrt[3]) - (237497*CF^2*NC*Pi^4)/1620 + 
       (48668880870629474527*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6379141797317520*Sqrt[3]) + (330817613506204196*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3295011258945*Sqrt[3]) - 
       (46060*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (3364035350479241*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (12784876137*Sqrt[3]) - (902990840337680*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) - 
       (3364035350479241*CF^2*NC*Pi*Log[3]^2)/(613674054576*Sqrt[3]) - 
       (56436927521105*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) - 
       (CF*NC*(5034819923624252814202*CF - 23*CA*(109561958517848560309 + 
            76597871190160320*lm) + 66528*(23*(-15793580587740899 + 
              209338709580*lm)*NM + 22086194130*(267 + 218*lm)*NL + 
            3*(540728080171 + 1604930106780*lm)*NH))*Log[x]^2)/
        33394325524560 + (2*CF*NC*(1166478183613*CA + 
          8*(-294726165523*CF + 31185*(44179246*NM + 1199*NL)))*Log[x]^3)/
        93555 - (19475284107627515285*CF^2*NC*PolyGamma[2, 1])/282429536481 + 
       (4343966086*CF*NM*NC*PolyGamma[2, 1])/9 - 
       (2122306707802210*CF*NC*NH*PolyGamma[2, 1])/282429536481 - 
       (4906814151411026084005*CF^2*NC*Zeta[3])/43494148618074 + 
       (7628084516*CF*NM*NC*Zeta[3])/9 - (28808*CF*NC*NL*Zeta[3])/3 + 
       (3909943210151884*CF*NC*NH*Zeta[3])/282429536481 + 
       CA*CF*NC*(-411402058190076468922055368046674623494563/
          19601051518222985806357946023440000 + (3384764131490585483*Pi^2)/
          539415676800 + (117741237266773435*Pi^3)/(33138398947104*Sqrt[3]) + 
         (239801*Pi^4)/3240 + lm*(-1380154607/1047816 - (44*Pi^2)/9) - 
         (48668880870629474527*Im[PolyLog[2, (-1)^(1/3)]])/
          (12758283594635040*Sqrt[3]) + (23030*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 + (3364035350479241*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (25569752274*Sqrt[3]) + (3364035350479241*Pi*Log[3]^2)/
          (1227348109152*Sqrt[3]) + (19475284107627515285*PolyGamma[2, 1])/
          564859072962 + (4907391523346775870259*Zeta[3])/86988297236148) + 
       CF*Log[x]*((166902747193607647008443*NM*NC)/1016107049837880 - 
         (5102896*lm*NM*NC)/10395 - (112935823331*NC*NL)/8731800 - 
         (5102896*lm*NC*NL)/10395 - (5960624216924963512959032167103*NC*NH)/
          38564167606644638246488200 - (5102896*lm*NC*NH)/10395 + 
         (176709460*NM*NC*Pi^2)/3 - (4796*NC*NL*Pi^2)/3 + 
         (902990840337680*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*(-119718386771117381345548105512407/
            4082407156847069455204800 - (934861705727*Pi^2)/74844 + 
           (3364035350479241*Im[PolyLog[2, (-1)^(1/3)]])/(38354628411*
             Sqrt[3]) - 13728*Zeta[3]) + 
         CA*NC*(6587915746761030996985298074413137/
            449064787253177640072528000 + (2551448*lm)/945 + 
           (935004682715*Pi^2)/149688 - (3364035350479241*
             Im[PolyLog[2, (-1)^(1/3)]])/(76709256822*Sqrt[3]) + 
           6864*Zeta[3])), (1174367176101277927428421035287624568812663*CF^2*
         NC)/2701006142224028666139276772608000 - 
       (8714000432536897162115763264966659*CF*NM*NC)/
        42577589045845380631104000 + (224215084309*CF*lm*NM*NC)/829870272 + 
       (28845988534587773*CF*NC*NL)/2614091356800 + 
       (224215084309*CF*lm*NC*NL)/829870272 + 
       (634980280682732070014724921662224998894323*CF*NC*NH)/
        3185712718960996830803137904867904000 + (224215084309*CF*lm*NC*NH)/
        829870272 - (125839574093479009*CF^2*NC*Pi^2)/922078080 + 
       (136500035162581*CF*NM*NC*Pi^2)/2245320 + (155*CF*lm*NM*NC*Pi^2)/
        162 - (21230663*CF*NC*NL*Pi^2)/56133 + (155*CF*lm*NC*NL*Pi^2)/162 + 
       (155*CF*lm*NC*NH*Pi^2)/162 - (2521058049712769525*CF^2*NC*Pi^3)/
        (298245590523936*Sqrt[3]) - (85152736613264635*CF*NC*NH*Pi^3)/
        (3389154437772*Sqrt[3]) - (12427*CF^2*NC*Pi^4)/72 + 
       (1014195600747945810983*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (114824552351715360*Sqrt[3]) + (1456504337857324337*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(11862040532202*Sqrt[3]) - 
       (53690*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (72030229991793415*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (230127770466*Sqrt[3]) - (9731741327230244*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) - 
       (72030229991793415*CF^2*NC*Pi*Log[3]^2)/(11046132982368*Sqrt[3]) - 
       (2432935331807561*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) - 
       (CF*NC*(-437*CA*(125177699285650783049 + 9736204901623200*lm) + 
          18*(6077394928501012199021*CF + 308*(23*(-382097726073601477 + 
                6066768107400*lm)*NM + 7*(350574510*(69217 + 56860*lm)*NL + 
                (6874282254529 + 19933666638600*lm)*NH))))*Log[x]^2)/
        66788651049120 + (CF*NC*(9818586252913*CA + 
          88*(-223430665225*CF + 103116078534*NM + 3283665*NL))*Log[x]^3)/
        37422 - (4907520349156653632009*CF^2*NC*PolyGamma[2, 1])/
        3389154437772 + (16754984663*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (31125637448020939*CF*NC*NH*PolyGamma[2, 1])/3389154437772 - 
       (687236320963594953762641*CF^2*NC*Zeta[3])/260964891708444 + 
       (23694281254*CF*NM*NC*Zeta[3])/81 - (313040*CF*NC*NL*Zeta[3])/27 + 
       (27158362722361949*CF*NC*NH*Zeta[3])/1694577218886 + 
       CA*CF*NC*(-12918783624026448795568735788277499358108103/
          59422135128928630655064088997376000 + (1635918592336827413*Pi^2)/
          23974030080 + (2521058049712769525*Pi^3)/(596491181047872*
           Sqrt[3]) + (112835*Pi^4)/1296 + lm*(-224215084309/150885504 - 
           (1705*Pi^2)/324) - (1014195600747945810983*
           Im[PolyLog[2, (-1)^(1/3)]])/(229649104703430720*Sqrt[3]) + 
         (26845*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (72030229991793415*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (460255540932*Sqrt[3]) + (72030229991793415*Pi*Log[3]^2)/
          (22092265964736*Sqrt[3]) + (4907520349156653632009*PolyGamma[2, 1])/
          6778308875544 + (687240501065401557360131*Zeta[3])/
          521929783416888) + CF*Log[x]*((3178015251215878757721581*NM*NC)/
          22862408621352300 - (42528037*lm*NM*NC)/74844 - 
         (14815192630867*NC*NL)/943034400 - (42528037*lm*NC*NL)/74844 - 
         (18349794401087936361270608707723*NC*NH)/
          99165002417086212633826800 - (42528037*lm*NC*NH)/74844 + 
         (4910042207*NM*NC*Pi^2)/81 - (156365*NC*NL*Pi^2)/81 + 
         (9731741327230244*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*(-551138006060623519145539396502833/
            1329468120157433802846300 - (19641237131735*Pi^2)/149688 + 
           (72030229991793415*Im[PolyLog[2, (-1)^(1/3)]])/(690383311398*
             Sqrt[3]) - 16016*Zeta[3]) + 
         CA*NC*(3527440066191615137073995119274251/
            17017191938015152676432640 + (42528037*lm)/13608 + 
           (19641585821615*Pi^2)/299376 - (72030229991793415*
             Im[PolyLog[2, (-1)^(1/3)]])/(1380766622796*Sqrt[3]) + 
           8008*Zeta[3])), (1637764792948204330530586739387306430960829*CF^2*
         NC)/5162416860766547702086043397120000 - 
       (65398087781610097649156055687323893*CF*NM*NC)/
        42577589045845380631104000 + (1265006974723*CF*lm*NM*NC)/
        4149351360 + (987213858981426449*CF*NC*NL)/71887512312000 + 
       (1265006974723*CF*lm*NC*NL)/4149351360 + 
       (76518354970206420804921173456702533863082273*CF*NC*NH)/
        309722069898985802994749518528824000000 + 
       (1265006974723*CF*lm*NC*NH)/4149351360 - 
       (20786979102541568243*CF^2*NC*Pi^2)/215766270720 + 
       (535951997935813*CF*NM*NC*Pi^2)/1122660 + (169*CF*lm*NM*NC*Pi^2)/
        162 - (1003839811*CF*NC*NL*Pi^2)/2245320 + (169*CF*lm*NC*NL*Pi^2)/
        162 + (169*CF*lm*NC*NH*Pi^2)/162 - (682302507438469831*CF^2*NC*Pi^3)/
        (66276797894208*Sqrt[3]) - (2947971294377270*CF*NC*NH*Pi^3)/
        (94143178827*Sqrt[3]) - (265265*CF^2*NC*Pi^4)/1296 + 
       (150504518192550158419*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (11025677180548800*Sqrt[3]) + (5478938980526484178*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(36245123848395*Sqrt[3]) - 
       (62959*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (682302507438469831*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1789882659180*Sqrt[3]) - (1347644020286752*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) - 
       (682302507438469831*CF^2*NC*Pi*Log[3]^2)/(85914367640640*Sqrt[3]) - 
       (84227751267922*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) - 
       (CF*NC*(-667*CA*(579053635333695830947 + 78743927137075200*lm) + 
          14*(55164788609533859149247*CF + 792*(115*(-3000602780291052481 + 
                7489091850240*lm)*NM + 29002073100*(36033 + 29696*lm)*NL + 
              (304562023427261 + 861245562777600*lm)*NH)))*Log[x]^2)/
        667886510491200 + (CF*NC*(17692563508882*CA - 35464252243995*CF + 
          4287360*(40294445*NM + 208*NL))*Log[x]^3)/93555 - 
       (6309706830673590765455*CF^2*NC*PolyGamma[2, 1])/10167463313316 + 
       (703728281267*CF*NM*NC*PolyGamma[2, 1])/162 - 
       (28045886240201020*CF*NC*NH*PolyGamma[2, 1])/2541865828329 - 
       (8234514486469601099497967*CF^2*NC*Zeta[3])/7828946751253320 + 
       (628947851453*CF*NM*NC*Zeta[3])/81 - (386386*CF*NC*NL*Zeta[3])/27 + 
       (58156498092653644*CF*NC*NH*Zeta[3])/2541865828329 + 
       CA*CF*NC*(-204739764383468014686674591225985152741447/
          1290604215191636925521510849280000 + (1599005261195308157*Pi^2)/
          33194810880 + (682302507438469831*Pi^3)/(132553595788416*Sqrt[3]) + 
         (1337141*Pi^4)/12960 + lm*(-1265006974723/754427520 - 
           (1859*Pi^2)/324) - (150504518192550158419*
           Im[PolyLog[2, (-1)^(1/3)]])/(22051354361097600*Sqrt[3]) + 
         (62959*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (682302507438469831*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3579765318360*Sqrt[3]) + (682302507438469831*Pi*Log[3]^2)/
          (171828735281280*Sqrt[3]) + (6309706830673590765455*
           PolyGamma[2, 1])/20334926626632 + (8234666358902804204110427*
           Zeta[3])/15657893502506640) + CF*Log[x]*
        ((254699637907216724237828063*NM*NC)/182899268970818400 - 
         (254291011*lm*NM*NC)/374220 - (25375705197881*NC*NL)/1296672300 - 
         (254291011*lm*NC*NL)/374220 - (888706027603645267297131722970991*NC*
           NH)/3856416760664463824648820000 - (254291011*lm*NC*NH)/374220 + 
         (37392954436*NM*NC*Pi^2)/81 - (193024*NC*NL*Pi^2)/81 + 
         (1347644020286752*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*(-56259704060652686771771724366427553/
            224532393626588820036264000 - (141590857062271*Pi^2)/1496880 + 
           (682302507438469831*Im[PolyLog[2, (-1)^(1/3)]])/
            (5369647977540*Sqrt[3]) - 18928*Zeta[3]) + 
         CA*NC*(6430265130566871468325119996589693/
            51321689971791730294003200 + (254291011*lm)/68040 + 
           (141595124052691*Pi^2)/2993760 - (682302507438469831*
             Im[PolyLog[2, (-1)^(1/3)]])/(10739295955080*Sqrt[3]) + 
           9464*Zeta[3])), 
      (65693894765273379160770608441206322232757537503811*CF^2*NC)/
        18797717070955540878684284041607918592000 - 
       (61296950480360173874013807358890258479*CF*NM*NC)/
        39849348147753903549126336000 + (239036141264191*CF*lm*NM*NC)/
        701240379840 + (399939586706859466669*CF*NC*NL)/24297979161456000 + 
       (239036141264191*CF*lm*NC*NL)/701240379840 + 
       (810504627041446759643902004049206134410577039*CF*NC*NH)/
        2787498629090872226952745666759416000000 + 
       (239036141264191*CF*lm*NC*NH)/701240379840 - 
       (10788109534678911619*CF^2*NC*Pi^2)/9739449720 + 
       (2705651450899723*CF*NM*NC*Pi^2)/5837832 + (181*CF*lm*NM*NC*Pi^2)/
        162 - (1884706259*CF*NC*NL*Pi^2)/3648645 + (181*CF*lm*NC*NL*Pi^2)/
        162 + (181*CF*lm*NC*NH*Pi^2)/162 - (46886625531055756915*CF^2*NC*
         Pi^3)/(3877192676811168*Sqrt[3]) - (125600609104169605*CF*NC*NH*
         Pi^3)/(3389154437772*Sqrt[3]) - (17137*CF^2*NC*Pi^4)/72 + 
       (307397853173991437440573*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (19405349347439895840*Sqrt[3]) + (118850909106954000113*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(652412229271110*Sqrt[3]) - 
       (72590*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (1339617872315878769*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2991661016058*Sqrt[3]) - (14354355326190812*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) - 
       (1339617872315878769*CF^2*NC*Pi*Log[3]^2)/(143599728770784*Sqrt[3]) - 
       (3588588831547703*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) - 
       (CF*NC*(-475*CA*(60744036533005967345221 + 856535286629262240*lm) + 
          6*(9617610749476298126469775*CF + 12012*(5*(-67000576504572292997 + 
                205276673401800*lm)*NM + 72505182750*(17085 + 14156*lm)*
               NL + (370419045446557 + 1026383367009000*lm)*NH)))*Log[x]^2)/
        4341262318192800 + (CF*NC*(5147108226887103*CA - 
          520*(19801418308745*CF - 231*(36980827274*NM + 230035*NL)))*
         Log[x]^3)/2432430 - (397508161903862713364213*CF^2*NC*
         PolyGamma[2, 1])/30502389939948 + (150798453481*CF*NM*NC*
         PolyGamma[2, 1])/81 - (405176110550300767*CF*NC*NH*PolyGamma[2, 1])/
        30502389939948 - (731193856682036755033193045*CF^2*NC*Zeta[3])/
        30532892329887948 + (227642412170*CF*NM*NC*Zeta[3])/81 - 
       (460432*CF*NC*NL*Zeta[3])/27 + (402738808925525369*CF*NC*NH*Zeta[3])/
        15251194969974 + CA*CF*NC*
        (-82118184687774433130050222883084401907971867468451/
          46994292677388852196710710104019796480000 + 
         (517829487072028885577*Pi^2)/934987173120 + 
         (46886625531055756915*Pi^3)/(7754385353622336*Sqrt[3]) + 
         (776957*Pi^4)/6480 + lm*(-239036141264191/127498250880 - 
           (1991*Pi^2)/324) - (307397853173991437440573*
           Im[PolyLog[2, (-1)^(1/3)]])/(38810698694879791680*Sqrt[3]) + 
         (36295*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1339617872315878769*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (5983322032116*Sqrt[3]) + (1339617872315878769*Pi*Log[3]^2)/
          (287199457541568*Sqrt[3]) + (397508161903862713364213*
           PolyGamma[2, 1])/61004779879896 + (731194562488291787771488481*
           Zeta[3])/61065784659775896) + CF*Log[x]*
        ((707082974265722346470633111*NM*NC)/604710708034768335 - 
         (3788607307*lm*NM*NC)/4864860 - (3161382795652483*NC*NL)/
          134853919200 - (3788607307*lm*NC*NL)/4864860 - 
         (4731896927255778539567768674230019*NC*NH)/
          17353875422990087210919690000 - (3788607307*lm*NC*NH)/4864860 + 
         (36980478913*NM*NC*Pi^2)/81 - (230035*NC*NL*Pi^2)/81 + 
         (14354355326190812*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (-2054073003212929785103191400638595867877/
            585136144788651024779136326400 - (2058921455643695*Pi^2)/
            1945944 + (1339617872315878769*Im[PolyLog[2, (-1)^(1/3)]])/
            (8974983048174*Sqrt[3]) - 21840*Zeta[3]) + 
         CA*NC*(5135222485215017821850603949487535011577/
            2925680723943255123895681632000 + (3788607307*lm)/884520 + 
           (2058928121817209*Pi^2)/3891888 - (1339617872315878769*
             Im[PolyLog[2, (-1)^(1/3)]])/(17949966096348*Sqrt[3]) + 
           10920*Zeta[3])), 
      (2812909609178872766359379300874072672793295710161211*CF^2*NC)/
        1148003435404784817948218775398197885440000 - 
       (3161714910070574855478294079363335746593*CF*NM*NC)/
        259020762960400373069321184000 + (1363873920307*CF*lm*NM*NC)/
        3577757040 + (69890693511758604577*CF*NC*NL)/3471139880208000 + 
       (1363873920307*CF*lm*NC*NL)/3577757040 + 
       (4447859420770357636458854148687789820382171677*CF*NC*NH)/
        12543743830908925021287355500417372000000 + 
       (1363873920307*CF*lm*NC*NH)/3577757040 - 
       (12840549472042661711921*CF^2*NC*Pi^2)/17030123510400 + 
       (2798287180720169*CF*NM*NC*Pi^2)/729729 + (98*CF*lm*NM*NC*Pi^2)/81 - 
       (314164382*CF*NC*NL*Pi^2)/521235 + (98*CF*lm*NC*NL*Pi^2)/81 + 
       (98*CF*lm*NC*NH*Pi^2)/81 - (506080070000774760211*CF^2*NC*Pi^3)/
        (34894734091300512*Sqrt[3]) - (692514295532767855*CF*NC*NH*Pi^3)/
        (15251194969974*Sqrt[3]) - (902293*CF^2*NC*Pi^4)/3240 + 
       (19738911515460906724183721*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (873240720634795312800*Sqrt[3]) + (649380911623056916904*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2935855031719995*Sqrt[3]) - 
       28042*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (72297152857253537173*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (134624745722610*Sqrt[3]) - (158288981836061224*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) - 
       (72297152857253537173*CF^2*NC*Pi*Log[3]^2)/(6461987794685280*
         Sqrt[3]) - (19786122729507653*CF*NC*NH*Pi*Log[3]^2)/
        (564859072962*Sqrt[3]) - 
       (CF*NC*(-3*CA*(935292997940755987860689 + 23529105806294088000*lm) + 
          2*(2805777538156313335929107*CF + 30888*(5*(-92393150151666091069 + 
                41550303394600*lm)*NM + 338357519500*(739 + 614*lm)*NL + 
              (76604895336973 + 207751516973000*lm)*NH)))*Log[x]^2)/
        620180331170400 + (CF*NC*(254708061581189*CA - 509642330050394*CF + 
          17160*(149090625973*NM + 139685*NL))*Log[x]^3)/173745 - 
       (255541204454592805870417*CF^2*NC*PolyGamma[2, 1])/45753584909922 + 
       (3166781685130*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (360580932977699140*CF*NC*NH*PolyGamma[2, 1])/22876792454961 - 
       (57719010438067433853085859*CF^2*NC*Zeta[3])/5947966038289860 + 
       (5737209588452*CF*NM*NC*Zeta[3])/81 - (559132*CF*NC*NL*Zeta[3])/27 + 
       (818950120556559124*CF*NC*NH*Zeta[3])/22876792454961 + 
       CA*CF*NC*(-351619550848849824733855971512560537441682666196209/
          287000858851196204487054693849549471360000 + 
         (755327020105965758443*Pi^2)/2003543942400 + 
         (506080070000774760211*Pi^3)/(69789468182601024*Sqrt[3]) + 
         (60571*Pi^4)/432 + lm*(-1363873920307/650501280 - (539*Pi^2)/81) - 
         (19738911515460906724183721*Im[PolyLog[2, (-1)^(1/3)]])/
          (1746481441269590625600*Sqrt[3]) + 14021*Im[PolyLog[2, (-1)^(1/3)]]^
           2 + (72297152857253537173*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (269249491445220*Sqrt[3]) + (72297152857253537173*Pi*Log[3]^2)/
          (12923975589370560*Sqrt[3]) + (255541204454592805870417*
           PolyGamma[2, 1])/91507169819844 + (57719174784774972571021259*
           Zeta[3])/11895932076579720) + CF*Log[x]*
        ((56836794886908303249873673213*NM*NC)/4837685664278146680 - 
         (159455359*lm*NM*NC)/173745 - (276357569869427*NC*NL)/9632422800 - 
         (159455359*lm*NC*NL)/173745 - (13036290152650651952715192884345021*
           NC*NH)/39046219701727696224569302500 - (159455359*lm*NC*NH)/
          173745 + (298180847542*NM*NC*Pi^2)/81 - (279370*NC*NL*Pi^2)/81 + 
         (158288981836061224*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (282429536481*Sqrt[3]) + CF*NC*
          (-18853192601442846433327540471574413833251/
            8933775067755296896181456412000 - (30875765054821*Pi^2)/42120 + 
           (72297152857253537173*Im[PolyLog[2, (-1)^(1/3)]])/
            (403874237167830*Sqrt[3]) - 25480*Zeta[3]) + 
         CA*NC*(15082791545932510725928868466405769718311/
            14294040108408475033890330259200 + (159455359*lm)/31590 + 
           (30875938969601*Pi^2)/84240 - (72297152857253537173*
             Im[PolyLog[2, (-1)^(1/3)]])/(807748474335660*Sqrt[3]) + 
           12740*Zeta[3])), 
      (335954615391895408360574935182403016295246342279906739*CF^2*NC)/
        11817682423284549596525781511452037056000000 - 
       (763502587746031535978651150892780259710233*CF*NM*NC)/
        64755190740100093267330296000000 + (5392603298165*CF*lm*NM*NC)/
        12749825088 + (579415768718806451849*CF*NC*NL)/24297979161456000 + 
       (5392603298165*CF*lm*NC*NL)/12749825088 + 
       (545714257540260968939014541269363036164047111*CF*NC*NH)/
        1320394087464097370661826894780776000000 + 
       (5392603298165*CF*lm*NC*NH)/12749825088 - 
       (170917571264200672547*CF^2*NC*Pi^2)/18814846050 + 
       (20997475323273227*CF*NM*NC*Pi^2)/5837832 + (209*CF*lm*NM*NC*Pi^2)/
        162 - (457477417*CF*NC*NL*Pi^2)/663390 + (209*CF*lm*NC*NL*Pi^2)/
        162 + (209*CF*lm*NC*NH*Pi^2)/162 - (147012832680156234485*CF^2*NC*
         Pi^3)/(8723683522825128*Sqrt[3]) - (1622368983439539755*CF*NC*NH*
         Pi^3)/(30502389939948*Sqrt[3]) - (14419*CF^2*NC*Pi^4)/45 + 
       (7993411984635910325377457*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (305634252222178359480*Sqrt[3]) + (1545519328474455133153*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5871710063439990*Sqrt[3]) - 
       (96080*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (58805133072062493794*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94237322005827*Sqrt[3]) - (185413598107375972*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) - 
       (29402566536031246897*CF^2*NC*Pi*Log[3]^2)/(2261695728139848*
         Sqrt[3]) - (46353399526843993*CF*NC*NH*Pi*Log[3]^2)/
        (1129718145924*Sqrt[3]) - 
       (CF*NC*(-119*CA*(994213585422448663753469 + 2446008115578627600*lm) + 
          6*(39436998985676937059583517*CF + 
            6006*(11*(-236348620246576643269 + 133509725239800*lm)*NM + 
              19*(5342487150*(17331 + 14468*lm)*NL + (29016675566677 + 
                  77295104086200*lm)*NH))))*Log[x]^2)/2170631159096400 + 
       (CF*NC*(42002435585229305*CA - 364*(230793138578099*CF - 
            330*(284405397466*NM + 329147*NL)))*Log[x]^3)/2432430 - 
       (32198147902919450274643583*CF^2*NC*PolyGamma[2, 1])/274521509459532 + 
       (5428765931675*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (2571171736290471749*CF*NC*NH*PolyGamma[2, 1])/137260754729766 - 
       (29857743796625894370326915851*CF^2*NC*Zeta[3])/137398015484495766 + 
       (4291164729491*CF*NM*NC*Zeta[3])/162 - (658712*CF*NC*NL*Zeta[3])/
        27 + (2822223572192318119*CF*NC*NH*Zeta[3])/68630377364883 + 
       CA*CF*NC*(-167977587111944326422040829173178539537801368603090107/
          11817682423284549596525781511452037056000000 + 
         (29247928812891411107*Pi^2)/6439305600 + 
         (147012832680156234485*Pi^3)/(17447367045650256*Sqrt[3]) + 
         (130607*Pi^4)/810 + lm*(-5392603298165/2318150016 - 
           (2299*Pi^2)/324) - (7993411984635910325377457*
           Im[PolyLog[2, (-1)^(1/3)]])/(611268504444356718960*Sqrt[3]) + 
         (48040*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (29402566536031246897*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (94237322005827*Sqrt[3]) + (29402566536031246897*Pi*Log[3]^2)/
          (4523391456279696*Sqrt[3]) + (32198147902919450274643583*
           PolyGamma[2, 1])/549043018919064 + (14928874135482140069147902511*
           Zeta[3])/137398015484495766) + CF*Log[x]*
        ((226368454669202901424568058677*NM*NC)/23258104155183397500 - 
         (461143633*lm*NM*NC)/442260 - (4579235001297659*NC*NL)/
          134853919200 - (461143633*lm*NC*NL)/442260 - 
         (3214036831793200439984059313851631*NC*NH)/
          8220256779311093942014590000 - (461143633*lm*NC*NH)/442260 + 
         (284404918715*NM*NC*Pi^2)/81 - (329147*NC*NL*Pi^2)/81 + 
         (185413598107375972*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (282429536481*Sqrt[3]) + CF*NC*
          (-1093467783693604668789180729389063129054447/
            36786132631933575454864820520000 - (8400543301852843*Pi^2)/
            972972 + (58805133072062493794*Im[PolyLog[2, (-1)^(1/3)]])/
            (282711966017481*Sqrt[3]) - 29120*Zeta[3]) + 
         CA*NC*(1093469232620697243766483222881959419611257/
            73572265263867150909729641040000 + (5072579963*lm)/884520 + 
           (8400548069409637*Pi^2)/1945944 - (29402566536031246897*
             Im[PolyLog[2, (-1)^(1/3)]])/(282711966017481*Sqrt[3]) + 
           14560*Zeta[3])), 
      (23210020462760349507446713561659459486101546522966920837*CF^2*NC)/
        1205403607175024058845629714168107779712000000 - 
       (141460258013790846425475764273244249464849*CF*NM*NC)/
        1439004238668890961496228800000 + (7314080183615*CF*lm*NM*NC)/
        15583119552 + (2017626500021269744891*CF*NC*NL)/70194162021984000 + 
       (7314080183615*CF*lm*NC*NL)/15583119552 + 
       (7298455588083604755724998113437109450065949995381*CF*NC*NH)/
        14684609678017813072520511038384605713984000 + 
       (7314080183615*CF*lm*NC*NH)/15583119552 - 
       (57147233012783528532893*CF^2*NC*Pi^2)/9536869165824 + 
       (5053398361138027*CF*NM*NC*Pi^2)/162162 + (25*CF*lm*NM*NC*Pi^2)/18 - 
       (516182855*CF*NC*NL*Pi^2)/648648 + (25*CF*lm*NC*NL*Pi^2)/18 + 
       (25*CF*lm*NC*NH*Pi^2)/18 - (4176178998377742426475*CF^2*NC*Pi^3)/
        (209368404547803072*Sqrt[3]) - (5876919983039132125*CF*NC*NH*Pi^3)/
        (91507169819844*Sqrt[3]) - (480335*CF^2*NC*Pi^4)/1296 + 
       (51917658429413502991480967*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1467044410666456125504*Sqrt[3]) + (7229571112289066165621*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(22899669247415961*Sqrt[3]) - 
       (110225*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (835235799675548485295*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1130847864069924*Sqrt[3]) - (671647998061615100*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (835235799675548485295*CF^2*NC*Pi*Log[3]^2)/(54280697475356352*
         Sqrt[3]) - (167911999515403775*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) + ((-3430429466793021366350561*CF^2*NC)/
          47706179320800 + CA*CF*(312171091083321124238561651/
            8682524636385600 + (481789*lm)/3)*NC + 
         CF*NC*((500555884719302093327/1338557220 - (87598*lm)/3)*NM - 
           (14*(22432 + 18771*lm)*NL)/9 - (86697877366493*NH)/7763631876 - 
           (87598*lm*NH)/3))*Log[x]^2 + 
       (CF*NC*(2812774694990522*CA - 5626022955530191*CF + 
          108108*(267727395092*NM + 43799*NL))*Log[x]^3)/243243 - 
       (41397624844402303734980117*CF^2*NC*PolyGamma[2, 1])/823564528378596 + 
       (1055594137279*CF*NM*NC*PolyGamma[2, 1])/3 - 
       (9053866036959809297*CF*NC*NH*PolyGamma[2, 1])/411782264189298 - 
       (20955632811090837433489414627*CF^2*NC*Zeta[3])/235539455116278456 + 
       (1932703797818*CF*NM*NC*Zeta[3])/3 - 29216*CF*NC*NL*Zeta[3] + 
       (11054376995101810483*CF*NC*NH*Zeta[3])/205891132094649 + 
       CA*CF*NC*(-11605043388598479762884730447691396570629026602086092231/
          1205403607175024058845629714168107779712000000 + 
         (57147240531414625059443*Pi^2)/19073738331648 + 
         (4176178998377742426475*Pi^3)/(418736809095606144*Sqrt[3]) + 
         (483215*Pi^4)/2592 + lm*(-7314080183615/2833294464 - 
           (275*Pi^2)/36) - (51917658429413502991480967*
           Im[PolyLog[2, (-1)^(1/3)]])/(2934088821332912251008*Sqrt[3]) + 
         (110225*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (835235799675548485295*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2261695728139848*Sqrt[3]) + (835235799675548485295*Pi*Log[3]^2)/
          (108561394950712704*Sqrt[3]) + (41397624844402303734980117*
           PolyGamma[2, 1])/1647129056757192 + (20955641874688326883737114583*
           Zeta[3])/471078910232556912) + CF*Log[x]*
        ((2663018871724587310841868256037*NM*NC)/26876031468211926000 - 
         (131198255*lm*NM*NC)/108108 - (7973966816156087*NC*NL)/
          194788994400 - (131198255*lm*NC*NL)/108108 - 
         (42497745029255655798472749410051611*NC*NH)/
          90069588395391065211052205904 - (131198255*lm*NC*NH)/108108 + 
         (267727333975*NM*NC*Pi^2)/9 - (43799*NC*NL*Pi^2)/9 + 
         (671647998061615100*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CF*NC*
          (-33205020485322683166425082697586663926946713/
            1876092764228612348198105846520000 - (3214638193949395*Pi^2)/
            555984 + (835235799675548485295*Im[PolyLog[2, (-1)^(1/3)]])/
            (3392543592209772*Sqrt[3]) - 33600*Zeta[3]) + 
         CA*NC*(132820436254099047046278988217153132218944877/
            15008742113828898785584846772160000 + (131198255*lm)/19656 + 
           (3214641435128479*Pi^2)/1111968 - (835235799675548485295*
             Im[PolyLog[2, (-1)^(1/3)]])/(6785087184419544*Sqrt[3]) + 
           16800*Zeta[3])), 
      (12665349681583579949010459942578618952605186680266217466959*CF^2*NC)/
        54243162322876082648053337137564850087040000000 - 
       (160584886840483926102078808104479393820622357*CF*NM*NC)/
        1748390149982702518217917992000000 + (1813649793170161*CF*lm*NM*NC)/
        3506201899200 + (10640450092691356511179*CF*NC*NL)/
        315873729098928000 + (1813649793170161*CF*lm*NC*NL)/3506201899200 + 
       (862562964477073364733937757374305578356346270017751*CF*NC*NH)/
        1501835080706367246053234083471152857112000000 + 
       (1813649793170161*CF*lm*NC*NH)/3506201899200 - 
       (8956339018935880471898423*CF^2*NC*Pi^2)/119210864572800 + 
       (275541625869737131*CF*NM*NC*Pi^2)/9729720 + (239*CF*lm*NM*NC*Pi^2)/
        162 - (6587589653*CF*NC*NL*Pi^2)/7297290 + (239*CF*lm*NC*NL*Pi^2)/
        162 + (239*CF*lm*NC*NH*Pi^2)/162 - (5407664845848226273765*CF^2*NC*
         Pi^3)/(235539455116278456*Sqrt[3]) - 
       (61393697753688990935*CF*NC*NH*Pi^3)/(823564528378596*Sqrt[3]) - 
       (34225*CF^2*NC*Pi^4)/81 + (1681047976039761641137461569*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41260624049994078529800*Sqrt[3]) + 
       (765822444698560252674457*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2060970232267436490*Sqrt[3]) - 41616*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (2163065938339290509506*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2544407694157329*Sqrt[3]) - 
       (7016422600421598964*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2541865828329*Sqrt[3]) - (1081532969169645254753*CF^2*NC*Pi*
         Log[3]^2)/(61065784659775896*Sqrt[3]) - 
       (1754105650105399741*CF*NC*NH*Pi*Log[3]^2)/(30502389939948*Sqrt[3]) - 
       (CF*NC*(-29*CA*(4892406525382676669739582517 + 2032993447141763106000*
             lm) + 4*(70939852013875132453249205519*CF + 
            5005*(319*(-16748168636066668748107 + 1678481392278600*lm)*NM + 
              2037953367450*(312649 + 262732*lm)*NL + (208059804582719669 + 
                535435564136873400*lm)*NH)))*Log[x]^2)/314741518068978000 + 
       (CF*NC*(345990709519741023*CA + 140*(-4942764882670691*CF + 
            858*(2223364172030*NM + 459781*NL)))*Log[x]^3)/2432430 - 
       (2608049808395766609230241035*CF^2*NC*PolyGamma[2, 1])/
        2470693585135788 + (16286308296269*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (31919266512049895129*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 - 
       (6086911888837540954353010466893*CF^2*NC*Zeta[3])/
        3091455348401154735 + (13321832180357*CF*NM*NC*Zeta[3])/54 - 
       (306680*CF*NC*NL*Zeta[3])/9 + (37891888869798431899*CF*NC*NH*
         Zeta[3])/617673396283947 + CA*CF*NC*
        (-3166338279418004857001297593854332864694300603036254925271/
          27121581161438041324026668568782425043520000000 + 
         (4478169563678466938498929*Pi^2)/119210864572800 + 
         (5407664845848226273765*Pi^3)/(471078910232556912*Sqrt[3]) + 
         (172081*Pi^4)/810 + lm*(-1813649793170161/637491254400 - 
           (2629*Pi^2)/324) - (1681047976039761641137461569*
           Im[PolyLog[2, (-1)^(1/3)]])/(82521248099988157059600*Sqrt[3]) + 
         20808*Im[PolyLog[2, (-1)^(1/3)]]^2 + (1081532969169645254753*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2544407694157329*
           Sqrt[3]) + (1081532969169645254753*Pi*Log[3]^2)/
          (122131569319551792*Sqrt[3]) + (2608049808395766609230241035*
           PolyGamma[2, 1])/4941387170271576 + 
         (3043456013838831554852398305434*Zeta[3])/3091455348401154735) + 
       CF*Log[x]*((109927280167901365638453871640759*NM*NC)/
          1360599093078228753750 - (6656549477*lm*NM*NC)/4864860 - 
         (84047888144262241*NC*NL)/1753100949600 - (6656549477*lm*NC*NL)/
          4864860 - (1941869134919671179747869362874436699089*NC*NH)/
          3546490043068523192685180607470000 - (6656549477*lm*NC*NH)/
          4864860 + (2223363528037*NM*NC*Pi^2)/81 - (459781*NC*NL*Pi^2)/
          81 + (7016422600421598964*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7625597484987*Sqrt[3]) + 
         CF*NC*(-85130315754762267989579467634646909139071084739/
            337696697561150222675659052373600000 - (19221727973825887*Pi^2)/
            270270 + (2163065938339290509506*Im[PolyLog[2, (-1)^(1/3)]])/
            (7633223082471987*Sqrt[3]) - 38080*Zeta[3]) + 
         CA*NC*(21282583615358547314738259228122073133978416991/
            168848348780575111337829526186800000 + (6656549477*lm)/884520 + 
           (115330378939135417*Pi^2)/3243240 - (1081532969169645254753*
             Im[PolyLog[2, (-1)^(1/3)]])/(7633223082471987*Sqrt[3]) + 
           19040*Zeta[3])), 
      (160077386360478118046842397769686415123828927719107658213*CF^2*NC)/
        1043137736978386204770256483414708655520000000 - 
       (7950149443282243166727731791179197226226057*CF*NM*NC)/
        9934034943083537035329079500000 + (31236425261861*CF*lm*NM*NC)/
        54784404675 + (57558737376631494467*CF*NC*NL)/1435789677722400 + 
       (31236425261861*CF*lm*NC*NL)/54784404675 + 
       (599655943401873022473934644192729116578713088708257289*CF*NC*NH)/
        878844388897423665890876539977821897193677700000 + 
       (31236425261861*CF*lm*NC*NH)/54784404675 - 
       (4550577133359759851685821*CF^2*NC*Pi^2)/94375267786800 + 
       (310925063580479168*CF*NM*NC*Pi^2)/1216215 + (128*CF*lm*NM*NC*Pi^2)/
        81 - (3764614856*CF*NC*NL*Pi^2)/3648645 + (128*CF*lm*NC*NL*Pi^2)/
        81 + (128*CF*lm*NC*NH*Pi^2)/81 - (6328151825799948777455*CF^2*NC*
         Pi^3)/(235539455116278456*Sqrt[3]) - 
       (18299674591199933680*CF*NC*NH*Pi^3)/(205891132094649*Sqrt[3]) - 
       (65329*CF^2*NC*Pi^4)/135 + (2189374363973668788162314839*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41260624049994078529800*Sqrt[3]) + 
       (64901420734878052549696*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (147212159447674035*Sqrt[3]) - 
       (141968*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (2531260730319979510982*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2544407694157329*Sqrt[3]) - (8365565527405683968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (1265630365159989755491*CF^2*NC*Pi*Log[3]^2)/(61065784659775896*
         Sqrt[3]) - (522847845462855248*CF*NC*NH*Pi*Log[3]^2)/
        (7625597484987*Sqrt[3]) - 
       (CF*NC*(-81809*CA*(17252229124533241368233999 + 13216767284408688000*
             lm) + 8*(352846512607650388381243024239*CF + 
            20020*(899*(-103943801086779397106557 + 1365368521116600*lm)*
               NM + 175*(206290789848*(40377 + 34001*lm)*NL + 
                (2770225433204731 + 7014093145621848*lm)*NH))))*Log[x]^2)/
        4878493530069159000 + (2*CF*NC*(56244832104359769*CA - 
          224*(502193706581548*CF - 2145*(1229871927373*NM + 34001*NL)))*
         Log[x]^3)/1216215 - (838301742931165736131254428*CF^2*NC*
         PolyGamma[2, 1])/1853020188851841 + 
       (85503128254888*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (55663141233148540936*CF*NC*NH*PolyGamma[2, 1])/1853020188851841 - 
       (7533593299860423282448322094934*CF^2*NC*Zeta[3])/
        9274366045203464205 + (157887628218704*CF*NM*NC*Zeta[3])/27 - 
       (362848*CF*NC*NL*Zeta[3])/9 + (144217372029957831280*CF*NC*NH*
         Zeta[3])/1853020188851841 + CA*CF*NC*
        (-4064466824857298512734775392316357700744713810135541137/
          52971838205933674460989587048403173913125000 + 
         (159669376567308953758711*Pi^2)/6622825809600 + 
         (6328151825799948777455*Pi^3)/(471078910232556912*Sqrt[3]) + 
         (197011*Pi^4)/810 + lm*(-31236425261861/9960800850 - 
           (704*Pi^2)/81) - (2189374363973668788162314839*
           Im[PolyLog[2, (-1)^(1/3)]])/(82521248099988157059600*Sqrt[3]) + 
         (70984*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1265630365159989755491*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2544407694157329*Sqrt[3]) + (1265630365159989755491*Pi*Log[3]^2)/
          (122131569319551792*Sqrt[3]) + (419150871465582868065627214*
           PolyGamma[2, 1])/1853020188851841 + 
         (7533593787080999586283244358649*Zeta[3])/18548732090406928410) + 
       CF*Log[x]*((1138682272135453914597124774408609*NM*NC)/
          1360599093078228753750 - (1916262352*lm*NM*NC)/1216215 - 
         (20664601550249*NC*NL)/362210940 - (1916262352*lm*NC*NL)/1216215 - 
         (7942095528122626074516223070626574391997*NC*NH)/
          12172060469245895672037352013495250 - (1916262352*lm*NC*NH)/
          1216215 + (19677950104640*NM*NC*Pi^2)/81 - (544016*NC*NL*Pi^2)/
          81 + (8365565527405683968*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7625597484987*Sqrt[3]) + 
         CF*NC*(-12530746644783353853421416872624473372099792649/
            84424174390287555668914763093400000 - (112489897780818163*Pi^2)/
            2432430 + (2531260730319979510982*Im[PolyLog[2, (-1)^(1/3)]])/
            (7633223082471987*Sqrt[3]) - 43520*Zeta[3]) + 
         CA*NC*(97896501426645860342397697128167877707693833/
            1319127724848243057326793173334375 + (958131176*lm)/110565 + 
           (112489917359987773*Pi^2)/4864860 - (1265630365159989755491*
             Im[PolyLog[2, (-1)^(1/3)]])/(7633223082471987*Sqrt[3]) + 
           21760*Zeta[3])), 
      (6137571806110787000192659510616648179333371685797903694990634149*CF^2*
         NC)/3175047566142299471288094814675365909054764544000000 - 
       (1119262706803695824605480607136921837417831348631*CF*NM*NC)/
        1543583253137669926400608213824000000 + 
       (8760871962505661*CF*lm*NM*NC)/14024807596800 + 
       (1680310440609558171727*CF*NC*NL)/36099854754163200 + 
       (8760871962505661*CF*lm*NC*NL)/14024807596800 + 
       (1848375327589684081524109348658293240993581947452825099963*CF*NC*NH)/
        2362333717356274813914676139460385259656605657600000 + 
       (8760871962505661*CF*lm*NC*NH)/14024807596800 - 
       (1133766691032928064072503513*CF^2*NC*Pi^2)/1812005141506560 + 
       (1097789266235413247*CF*NM*NC*Pi^2)/4864860 + (271*CF*lm*NM*NC*Pi^2)/
        162 - (67818452861*CF*NC*NL*Pi^2)/58378320 + (271*CF*lm*NC*NL*Pi^2)/
        162 + (271*CF*lm*NC*NH*Pi^2)/162 - (173357262317197103352035*CF^2*NC*
         Pi^3)/(5652946922790682944*Sqrt[3]) - 
       (63207424713056457995*CF*NC*NH*Pi^3)/(617673396283947*Sqrt[3]) - 
       (354617*CF^2*NC*Pi^4)/648 + (4812042100730049726237546713*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(79220398175988630777216*Sqrt[3]) + 
       (3177505700151853521214651*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (6182910696802309470*Sqrt[3]) - 53210*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (34671452463439420670407*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(30532892329887948*Sqrt[3]) - 
       (28894822725968666512*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7625597484987*Sqrt[3]) - (34671452463439420670407*CF^2*NC*Pi*
         Log[3]^2)/(1465578831834621504*Sqrt[3]) - 
       (1805926420373041657*CF*NC*NH*Pi*Log[3]^2)/(22876792454961*Sqrt[3]) - 
       (CF*NC*(117214482714072097155593715548386*CF - 
          59675*CA*(982107199830447663271299467 + 67029325402029838848*lm) + 
          16016*(527*(-5008421870807237681022047 + 86164805381054400*lm)*
             NM + 65*(1110796560720*(744027 + 628916*lm)*NL + 
              (279864936169502437 + 698597729781779520*lm)*NH)))*Log[x]^2)/
        15611179296221308800 + (CF*NC*(5743996360697864729*CA + 
          20*(-574400453645337481*CF + 24024*(8806757819693*NM + 
              314458*NL)))*Log[x]^3)/4864860 - 
       (211252032303997648256058736061*CF^2*NC*PolyGamma[2, 1])/
        22236242266222092 + (73288394788097*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (777261318141556363189*CF*NC*NH*PolyGamma[2, 1])/22236242266222092 - 
       (793291417353741583114853041025569*CF^2*NC*Zeta[3])/
        44516957016976628184 + (61546057458863*CF*NM*NC*Zeta[3])/27 - 
       (419458*CF*NC*NL*Zeta[3])/9 + (983322537088089940835*CF*NC*NH*
         Zeta[3])/11118121133111046 + CA*CF*NC*
        (-6137572071654625890827638044685391777808593318110294078590317299/
          6350095132284598942576189629350731818109529088000000 + 
         (59671931220991264225882567*Pi^2)/190737383316480 + 
         (173357262317197103352035*Pi^3)/(11305893845581365888*Sqrt[3]) + 
         (21997*Pi^4)/80 + lm*(-8760871962505661/2549965017600 - 
           (2981*Pi^2)/324) - (4812042100730049726237546713*
           Im[PolyLog[2, (-1)^(1/3)]])/(158440796351977261554432*Sqrt[3]) + 
         26605*Im[PolyLog[2, (-1)^(1/3)]]^2 + (34671452463439420670407*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(61065784659775896*
           Sqrt[3]) + (34671452463439420670407*Pi*Log[3]^2)/
          (2931157663669243008*Sqrt[3]) + (211252032303997648256058736061*
           PolyGamma[2, 1])/44472484532444184 + 
         (793291420059576210849283897153033*Zeta[3])/89033914033953256368) + 
       CF*Log[x]*((2890895216649031656172282838118696347*NM*NC)/
          4307816799167210849520000 - (17167422431*lm*NM*NC)/9729720 - 
         (5802358775143267*NC*NL)/87655047480 - (17167422431*lm*NC*NL)/
          9729720 - (1755275043709089625289833296204468051390341*NC*NH)/
          2337035610095211969031171586591088000 - (17167422431*lm*NC*NH)/
          9729720 + (17613514789118*NM*NC*Pi^2)/81 - (628916*NC*NL*Pi^2)/
          81 + (28894822725968666512*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (22876792454961*Sqrt[3]) + 
         CF*NC*(-730186981517021175527406763616627682061809552681163/
            340803507178712804724275115655437120000 - 
           (765866325651123989*Pi^2)/1297296 + (34671452463439420670407*
             Im[PolyLog[2, (-1)^(1/3)]])/(91598676989663844*Sqrt[3]) - 
           48960*Zeta[3]) + CA*NC*
          (1460374015011259737096050605488650879623971418265561/
            1363214028714851218897100462621748480000 + (17167422431*lm)/
            1769040 + (255288779263410323*Pi^2)/864864 - 
           (34671452463439420670407*Im[PolyLog[2, (-1)^(1/3)]])/
            (183197353979327688*Sqrt[3]) + 24480*Zeta[3])), 
      (22097394706435991747565771304566081696658038329196704496742176917*CF^2*
         NC)/17859642559550434525995533332548933238433050560000000 - 
       (118023807865724801417877337493169872577607941333827*CF*NM*NC)/
        17954310470706581775501811329216000000 + 
       (9599886593613059*CF*lm*NM*NC)/14024807596800 + 
       (138425059712558470854313*CF*NC*NL)/2526989832791424000 + 
       (9599886593613059*CF*lm*NC*NL)/14024807596800 + 
       (19553119919424401402179027361473707709165187993094355190939*CF*NC*
         NH)/21261003456206473325232085255143467336909450918400000 + 
       (9599886593613059*CF*lm*NC*NH)/14024807596800 - 
       (7102889101969074564250842659*CF^2*NC*Pi^2)/18120051415065600 + 
       (6855536798392043353*CF*NM*NC*Pi^2)/3243240 + (289*CF*lm*NM*NC*Pi^2)/
        162 - (76864765889*CF*NC*NL*Pi^2)/58378320 + (289*CF*lm*NC*NL*Pi^2)/
        162 + (289*CF*lm*NC*NH*Pi^2)/162 - (278110344839963758657715*CF^2*NC*
         Pi^3)/(7827157277710176384*Sqrt[3]) - 
       (670778040619327335940*CF*NC*NH*Pi^3)/(5559060566555523*Sqrt[3]) - 
       (4026433*CF^2*NC*Pi^4)/6480 + (42147585299437073903311929061*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(548448910449152059226880*Sqrt[3]) + 
       (16801077005557467704842426*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) - 
       (180115*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (55622068967992751731543*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(42276312456767928*Sqrt[3]) - 
       (306641389997406782144*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (55622068967992751731543*CF^2*NC*Pi*Log[3]^2)/(2029262997924860544*
         Sqrt[3]) - (19165086874837923884*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) - 
       (CF*NC*(-279*CA*(1316008030860894513390386114569 + 
            167848548208913155584000*lm) + 
          14*(52452310402371722244498000493753*CF + 
            11440*(4123*(-5996694714473567869349989 + 12894120010886400*lm)*
               NM + 2454860399191200*(25573 + 21656*lm)*NL + 
              5*(4321049190157992613 + 10632491360976925440*lm)*NH)))*
         Log[x]^2)/156111792962213088000 - 
       (CF*NC*(-3640019627397996973*CA + 96*(75833947311631489*CF - 
            5005*(81048994995071*NM + 368152*NL)))*Log[x]^3)/4864860 - 
       (271609756728215195640999922619*CF^2*NC*PolyGamma[2, 1])/
        66708726798666276 + (1539056317385651*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (671983992916780881733*CF*NC*NH*PolyGamma[2, 1])/16677181699666569 - 
       (25651921452457459911901019588581*CF^2*NC*Zeta[3])/
        3468853793530646352 + (1430990998267901*CF*NM*NC*Zeta[3])/27 - 
       (491062*CF*NC*NL*Zeta[3])/9 + (1829169316056710501410*CF*NC*NH*
         Zeta[3])/16677181699666569 + CA*CF*NC*
        (-88389585674504547393432221390655188135490486372585707360309754293/
          142877140476403476207964266660391465907464404480000000 + 
         (417817007450403846654181867*Pi^2)/2131770754713600 + 
         (278110344839963758657715*Pi^3)/(15654314555420352768*Sqrt[3]) + 
         (4044929*Pi^4)/12960 + lm*(-9599886593613059/2549965017600 - 
           (3179*Pi^2)/324) - (42147585299437073903311929061*
           Im[PolyLog[2, (-1)^(1/3)]])/(1096897820898304118453760*Sqrt[3]) + 
         (180115*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (55622068967992751731543*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (84552624913535856*Sqrt[3]) + (55622068967992751731543*Pi*Log[3]^2)/
          (4058525995849721088*Sqrt[3]) + (271609756728215195640999922619*
           PolyGamma[2, 1])/133417453597332552 + 
         (25651921696881056434288479922477*Zeta[3])/6937707587061292704) + 
       CF*Log[x]*((27306246314019598527091108996387464523*NM*NC)/
          3854362399254872865360000 - (19585543889*lm*NM*NC)/9729720 - 
         (136544947358781719*NC*NL)/1753100949600 - (19585543889*lm*NC*NL)/
          9729720 - (130330837969748062127283985295002349855841811*NC*NH)/
          147233243435998354048963809955238544000 - (19585543889*lm*NC*NH)/
          9729720 + (162097989029438*NM*NC*Pi^2)/81 - (736304*NC*NL*Pi^2)/
          81 + (306641389997406782144*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CF*NC*(-76485945358496552826145370400186915175124448660743203/
            61344631292168304850369520817978681600000 - 
           (37818398919379073*Pi^2)/101088 + (55622068967992751731543*
             Im[PolyLog[2, (-1)^(1/3)]])/(126828937370303784*Sqrt[3]) - 
           55488*Zeta[3]) + CA*NC*
          (10926564405585571768870215087959907529771913823454579/
            17527037512048087100105577376565337600000 + (19585543889*lm)/
            1769040 + (37818400021082585*Pi^2)/202176 - 
           (55622068967992751731543*Im[PolyLog[2, (-1)^(1/3)]])/
            (253657874740607568*Sqrt[3]) + 27744*Zeta[3])), 
      (4662982130654205206253594141605263681400432383553651901235592279496571\
1*CF^2*NC)/2894387966514124452603795158294211069377505010227302400000 - 
       (11766512519345293382824717598161266794762587885877120159*CF*NM*NC)/
        2032532080284715155161102952972960652800000 + 
       (604739727632380679*CF*lm*NM*NC)/810633879095040 + 
       (27193168595142944604733*CF*NC*NL)/431109835700544000 + 
       (604739727632380679*CF*lm*NC*NL)/810633879095040 + 
       (7422479646978369134646659498089289684542995953736637085591*CF*NC*NH)/
        7087001152068824441744028418381155778969816972800000 + 
       (604739727632380679*CF*lm*NC*NH)/810633879095040 - 
       (161460249705296890257491916671*CF^2*NC*Pi^2)/30804087405611520 + 
       (150209003426872937429*CF*NM*NC*Pi^2)/82702620 + 
       (305*CF*lm*NM*NC*Pi^2)/162 - (292293263767*CF*NC*NL*Pi^2)/
        198486288 + (305*CF*lm*NC*NL*Pi^2)/162 + (305*CF*lm*NC*NH*Pi^2)/
        162 - (34819199063392012410720905*CF^2*NC*Pi^3)/
        (864900879186974490432*Sqrt[3]) - (255562717417117394935*CF*NC*NH*
         Pi^3)/(1853020188851841*Sqrt[3]) - (452099*CF^2*NC*Pi^4)/648 + 
       (90112199234108276143222618153319*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1030261278278732143257694080*Sqrt[3]) + 
       (12945463460396832554048903*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (18548732090406928410*Sqrt[3]) - 67070*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (6963839812678402482144181*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) - (116828670819253666256*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (6963839812678402482144181*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) - (7301791926203354141*CF*NC*NH*Pi*Log[3]^2)/
        (68630377364883*Sqrt[3]) - 
       (CF*NC*(-(CA*(1669256848547091200077559077206767 + 
             18261611088177676078379520*lm)) + 
          26*(128404370927101891411195943344249*CF + 
            10472*(11*(-386257479972126858505178729 + 1108614956274745920*lm)*
               NM + 7*(35069434274160*(58461 + 49676*lm)*NL + 
                (717110989529614529 + 1742109217003172160*lm)*NH))))*
         Log[x]^2)/53078009607152449920 - 
       (CF*NC*(-163150057836923646795*CA + 136*(2399266134020488583*CF - 
            12012*(70540236004819*NM + 422246*NL)))*Log[x]^3)/16540524 - 
       (17111414589658232512554915687161*CF^2*NC*PolyGamma[2, 1])/
        200126180395998828 + (659595563435989*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (9301950024715948146457*CF*NC*NH*PolyGamma[2, 1])/
        200126180395998828 - (1097557460895214957876556867488159343*CF^2*NC*
         Zeta[3])/6811094423597424112152 + (565541924024743*CF*NM*NC*
         Zeta[3])/27 - (563198*CF*NC*NL*Zeta[3])/9 + 
       (12405894887227493417135*CF*NC*NH*Zeta[3])/100063090197999414 + 
       CA*CF*NC*(-46629821621955827989468672991655533043199879503151292404817\
754579258011/5788775933028248905207590316588422138755010020454604800000 + 
         (32292049950557622391502904235*Pi^2)/12321634962244608 + 
         (34819199063392012410720905*Pi^3)/(1729801758373948980864*Sqrt[3]) + 
         (454051*Pi^4)/1296 + lm*(-604739727632380679/147387978017280 - 
           (3355*Pi^2)/324) - (90112199234108276143222618153319*
           Im[PolyLog[2, (-1)^(1/3)]])/(2060522556557464286515388160*
           Sqrt[3]) + 33535*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (6963839812678402482144181*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) + (6963839812678402482144181*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) + 
         (17111414589658232512554915687161*PolyGamma[2, 1])/
          400252360791997656 + (1097557461446173593391962181919397347*
           Zeta[3])/13622188847194848224304) + 
       CF*Log[x]*((11231848239529836764661324260811361388263*NM*NC)/
          2010765801371277818531664000 - (74120995453*lm*NM*NC)/33081048 - 
         (60706362480401347*NC*NL)/677334457800 - (74120995453*lm*NC*NL)/
          33081048 - (3818842346974993102163186011946601292951963*NC*NH)/
          3775211370153803949973431024493296000 - (74120995453*lm*NC*NH)/
          33081048 + (141080470905250*NM*NC*Pi^2)/81 - (844492*NC*NL*Pi^2)/
          81 + (116828670819253666256*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (68630377364883*Sqrt[3]) + 
         CF*NC*(-91462394609905264569390076946199767276316636498517842841/
            5010936207100767981702434308016588606496000 - 
           (36255569508985804297*Pi^2)/7351344 + (6963839812678402482144181*
             Im[PolyLog[2, (-1)^(1/3)]])/(14014597579418568132*Sqrt[3]) - 
           62016*Zeta[3]) + CA*NC*
          (52264225786339393200815753948785933977381267898180763077/
            5726784236686591979088496352018958407424000 + (74120995453*lm)/
            6014736 + (108766708803991314035*Pi^2)/44108064 - 
           (6963839812678402482144181*Im[PolyLog[2, (-1)^(1/3)]])/
            (28029195158837136264*Sqrt[3]) + 31008*Zeta[3])), 
      (1822175018254470448984880579220401141913762376223520704660166711601573\
57*CF^2*NC)/18089924790713277828773719739338819183609406313920640000000 - 
       (6142798516293144627304812875124753911048405452014110629*CF*NM*NC)/
        112918448904706397508950164054053369600000 + 
       (10172711317044019*CF*lm*NM*NC)/12509782084800 + 
       (180748022345126978506189*CF*NC*NL)/2458922766588288000 + 
       (10172711317044019*CF*lm*NC*NL)/12509782084800 + 
       (64817357293662705070938300847332694288850092522866078806047*CF*NC*
         NH)/53152508640516183313080213137858668342273627296000000 + 
       (10172711317044019*CF*lm*NC*NH)/12509782084800 - 
       (23573816545284329175798067853*CF^2*NC*Pi^2)/7334306525145600 + 
       (161669448607828507613*CF*NM*NC*Pi^2)/9189180 + 2*CF*lm*NM*NC*Pi^2 - 
       (5074699507*CF*NC*NL*Pi^2)/3063060 + 2*CF*lm*NC*NL*Pi^2 + 
       2*CF*lm*NC*NH*Pi^2 - (39990510045058291660202605*CF^2*NC*Pi^3)/
        (864900879186974490432*Sqrt[3]) - (1790492296460076974485*CF*NC*NH*
         Pi^3)/(11118121133111046*Sqrt[3]) - (169813*CF^2*NC*Pi^4)/216 + 
       (557147038714452881720007555109871*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5151306391393660716288470400*Sqrt[3]) + 
       (22618409548729341528736697*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) - 75158*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (7998102009011658332040521*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) - (409255382048017594168*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (7998102009011658332040521*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) - (51156922756002199271*CF*NC*NH*Pi*Log[3]^2)/
        (411782264189298*Sqrt[3]) + 
       ((-25590380627622928843888033628310949*CF^2*NC)/
          663475120089405624000 + CA*CF*(25590381395622066891558841001665729/
            1326950240178811248000 + 399058*lm)*NC + 
         CF*NC*((457300400786552337599134051/2166053293404 - 72556*lm)*NM - 
           (68*(3761 + 3201*lm)*NL)/3 - (1638088260420093679*NH)/
            54151332335100 - 72556*lm*NH))*Log[x]^2 - 
       (4*CF*NC*(-10527549542756942844*CA + 5*(4211021766227217569*CF - 
            918918*(24906577640365*NM + 18139*NL)))*Log[x]^3)/6891885 - 
       (11000195098753056087810631969663*CF^2*NC*PolyGamma[2, 1])/
        300189270593998242 + 256509386454644*CF*NM*NC*PolyGamma[2, 1] - 
       (7981138330152105184090*CF*NC*NH*PolyGamma[2, 1])/
        150094635296999121 - (6863364296941098001935236728327714447*CF^2*NC*
         Zeta[3])/102166416353961361682280 + 
       (1439430009275888*CF*NM*NC*Zeta[3])/3 - 72580*CF*NC*NL*Zeta[3] + 
       (22653470730366535486216*CF*NC*NH*Zeta[3])/150094635296999121 + 
       CA*CF*NC*(-11388594004420637552141662156997938495662332887126127139662\
268560650327/2261240598839159728596714967417352397951175789240080000000 + 
         (7857938852687857006617605591*Pi^2)/4889537683430400 + 
         (39990510045058291660202605*Pi^3)/(1729801758373948980864*Sqrt[3]) + 
         (852521*Pi^4)/2160 + lm*(-10172711317044019/2274505833600 - 
           11*Pi^2) - (557147038714452881720007555109871*
           Im[PolyLog[2, (-1)^(1/3)]])/(10302612782787321432576940800*
           Sqrt[3]) + 37579*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (7998102009011658332040521*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) + (7998102009011658332040521*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) + 
         (11000195098753056087810631969663*PolyGamma[2, 1])/
          600378541187996484 + (6863364306444920766488438033085051247*
           Zeta[3])/204332832707922723364560) + 
       CF*Log[x]*((2938348708686792416241926370703592433701*NM*NC)/
          48872779894440780311533500 - (1294372957*lm*NM*NC)/510510 - 
         (427659495974093*NC*NL)/4095748800 - (1294372957*lm*NC*NL)/
          510510 - (9876894967752029903508365878710652726662727*NC*NH)/
          8365525195227179207327489202002190000 - (1294372957*lm*NC*NH)/
          510510 + (49813155234830*NM*NC*Pi^2)/3 - (36278*NC*NL*Pi^2)/3 + 
         (409255382048017594168*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CF*NC*(-5261192528798841468770662448515663220841340938318867365237/
            501093620710076798170243430801658860649600000 - 
           (336881604548559486673*Pi^2)/110270160 + 
           (7998102009011658332040521*Im[PolyLog[2, (-1)^(1/3)]])/
            (14014597579418568132*Sqrt[3]) - 69768*Zeta[3]) + 
         CA*NC*(3400900186625462335217118945940922096451398617577450071/
            647826271118392757815440763803049593600000 + (1294372957*lm)/
            92820 + (112293868715924754611*Pi^2)/73513440 - 
           (7998102009011658332040521*Im[PolyLog[2, (-1)^(1/3)]])/
            (28029195158837136264*Sqrt[3]) + 34884*Zeta[3])), 
      (2293939538913522980349367292848429609899555667593551019125132597705469\
253*CF^2*NC)/16988798933887252221804884624770369320259268538290688000000 - 
       (8622017754825340199822321116905968473731246294962499731*CF*NM*NC)/
        184775643662246832287372995724814604800000 + 
       (325040977793221549*CF*lm*NM*NC)/368469945043200 + 
       (243478396971215984296099*CF*NC*NL)/2898016117764768000 + 
       (325040977793221549*CF*lm*NC*NL)/368469945043200 + 
       (3961165726370143210360274642383224531085366686465410013295601*CF*NC*
         NH)/2870235466587873898906331509444368090482775873984000000 + 
       (325040977793221549*CF*lm*NC*NH)/368469945043200 - 
       (30894389027371908778239152377*CF^2*NC*Pi^2)/700092895582080 + 
       (304852975235892803101*CF*NM*NC*Pi^2)/20675655 + 
       (341*CF*lm*NM*NC*Pi^2)/162 - (55394713559*CF*NC*NL*Pi^2)/30073680 + 
       (341*CF*lm*NC*NL*Pi^2)/162 + (341*CF*lm*NC*NH*Pi^2)/162 - 
       (607658095127806015089084335*CF^2*NC*Pi^3)/(11676161869024155620832*
         Sqrt[3]) - (54893803010682782783245*CF*NC*NH*Pi^3)/
        (300189270593998242*Sqrt[3]) - (284195*CF^2*NC*Pi^4)/324 + 
       (1702526745400888909613693872365353*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(13908527256762883933978870080*
         Sqrt[3]) + (107763775881886565958106201*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(115572869178689323170*Sqrt[3]) - 
       (250420*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (121531619025561203017816867*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(63065689107383556594*
         Sqrt[3]) - (12547154973870350350456*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (121531619025561203017816867*CF^2*NC*Pi*Log[3]^2)/
        (3027153077154410716512*Sqrt[3]) - (1568394371733793793807*CF*NC*NH*
         Pi*Log[3]^2)/(11118121133111046*Sqrt[3]) - 
       (CF*NC*(-805*CA*(65467417441697373765848922114277 + 
            112366695800138911971840*lm) + 
          4*(26350635454558923742649073372858626*CF + 
            51051*(65*(-2653265449599488014248990773 + 1239062461179459840*
                 lm)*NM + 3682290598786800*(25619 + 21872*lm)*NL + 
              (33969358650920574149 + 80539059976664889600*lm)*NH)))*
         Log[x]^2)/199042536026821687200 + 
       (CF*NC*(2283923068088480148741*CA - 340*(13434842110862825161*CF - 
            24024*(190100260010693*NM + 185912*NL)))*Log[x]^3)/27567540 - 
       (1386024581434610493764198379511523*CF^2*NC*PolyGamma[2, 1])/
        1801135623563989452 + (35618160509922829*CF*NM*NC*PolyGamma[2, 1])/
        324 - (27406225862571542585167*CF*NC*NH*PolyGamma[2, 1])/
        450283905890997363 - (11158166807237747235975833733552680527*CF^2*NC*
         Zeta[3])/7662481226547102126171 + (31055754337488433*CF*NM*NC*
         Zeta[3])/162 - (2231626*CF*NC*NL*Zeta[3])/27 + 
       (76432765601444496884278*CF*NC*NH*Zeta[3])/450283905890997363 + 
       CA*CF*NC*(-17645688779206865313845405048908699853428843433177741187716\
5578287304331/2613661374444192649508443788426210664655272082813952000000 + 
         (15447194514370827044093398367*Pi^2)/700092895582080 + 
         (607658095127806015089084335*Pi^3)/(23352323738048311241664*
           Sqrt[3]) + (475477*Pi^4)/1080 + 
         lm*(-325040977793221549/66994535462400 - (3751*Pi^2)/324) - 
         (1702526745400888909613693872365353*Im[PolyLog[2, (-1)^(1/3)]])/
          (27817054513525767867957740160*Sqrt[3]) + 
         (125210*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (121531619025561203017816867*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (126131378214767113188*Sqrt[3]) + (121531619025561203017816867*Pi*
           Log[3]^2)/(6054306154308821433024*Sqrt[3]) + 
         (1386024581434610493764198379511523*PolyGamma[2, 1])/
          3602271247127978904 + (5579083404025148731158880109255097248*
           Zeta[3])/7662481226547102126171) + 
       CF*Log[x]*((656239374911760369100771910548772598911909*NM*NC)/
          14075360609598944729721648000 - (14068604189*lm*NM*NC)/5012280 - 
         (3554356939836460517*NC*NL)/29802716143200 - 
         (14068604189*lm*NC*NL)/5012280 - 
         (1567178181867496859556859396151511922912120487*NC*NH)/
          1169205168462339870388830255526894320000 - (14068604189*lm*NC*NH)/
          5012280 + (126733506516704*NM*NC*Pi^2)/9 - (371824*NC*NL*Pi^2)/
          27 + (12547154973870350350456*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CF*NC*(-18336895032867672449682490763510029682908460533869558664487/
            117648067471061509135622370709954689022080000 - 
           (57098076975571863760*Pi^2)/1378377 + (121531619025561203017816867*
             Im[PolyLog[2, (-1)^(1/3)]])/(189197067322150669782*Sqrt[3]) - 
           77520*Zeta[3]) + CA*NC*
          (2292111881120837280203213556147483708842265386240661647779/
            29412016867765377283905592677488672255520000 + 
           (154754646079*lm)/10024560 + (76130769331249898303*Pi^2)/3675672 - 
           (121531619025561203017816867*Im[PolyLog[2, (-1)^(1/3)]])/
            (378394134644301339564*Sqrt[3]) + 38760*Zeta[3])), 
      (4038293361079805188571461198944649313783627766338227922065296285691724\
1673*CF^2*NC)/488427969349258501376890432962148117957453970475857280000000 - 
       (131554105288882936686405487616537784218287535260215227507*CF*NM*NC)/
        290361725754959307880157564710422950400000 + 
       (3879221127170612539*CF*lm*NM*NC)/4053169395475200 + 
       (267771519001769198580443173*CF*NC*NL)/2758911344112059136000 + 
       (3879221127170612539*CF*lm*NC*NL)/4053169395475200 + 
       (231662386066292127909829511366014183634012730133015244896671955247*CF*
         NC*NH)/
        145386037089075576601302409947885576887224046344911552000000 + 
       (3879221127170612539*CF*lm*NC*NH)/4053169395475200 - 
       (1635580722212005661533377785089*CF^2*NC*Pi^2)/61608174811223040 + 
       (66918005198280503449*CF*NM*NC*Pi^2)/454410 + (361*CF*lm*NM*NC*Pi^2)/
        162 - (681041846699*CF*NC*NL*Pi^2)/330810480 + 
       (361*CF*lm*NC*NL*Pi^2)/162 + (361*CF*lm*NC*NH*Pi^2)/162 - 
       (2769981682739707153825852115*CF^2*NC*Pi^3)/(46704647476096622483328*
         Sqrt[3]) - (127088129052270220677815*CF*NC*NH*Pi^3)/
        (600378541187996484*Sqrt[3]) - (6361751*CF^2*NC*Pi^4)/6480 + 
       (843510570822831283897764647750449*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5676949900719544462848518400*Sqrt[3]) + 
       (27523518802155039044601131081*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (25541604088490340420570*Sqrt[3]) - 92967*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (79142333792563061537881489*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(36037536632790603768*
         Sqrt[3]) - (14524357605973739506036*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (79142333792563061537881489*CF^2*NC*Pi*Log[3]^2)/
        (1729801758373948980864*Sqrt[3]) - (3631089401493434876509*CF*NC*NH*
         Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) - 
       (CF*NC*(93847455207853070745279714629461518382*CF - 
          37*CA*(1268208860206480907205740092975280363 + 
            4162022775362020653852768000*lm) + 8168160*
           (185*(-344499026822729924586956543851 + 18528809761370628720*lm)*
             NM + 76136773263150600*(52659 + 45022*lm)*NL + 
            (1462396461261701024497 + 3427829805853566313200*lm)*NH))*
         Log[x]^2)/294582953319696097056000 - 
       (CF*NC*(-1386454207099077456187*CA + 8*(346613578539192107909*CF - 
            510510*(3742599352881416*NM + 427709*NL)))*Log[x]^3)/27567540 - 
       (1782031604828189794864615526494145*CF^2*NC*PolyGamma[2, 1])/
        5403406870691968356 + (186995342749848020*CF*NM*NC*PolyGamma[2, 1])/
        81 - (186836663677906176675611*CF*NC*NH*PolyGamma[2, 1])/
        2701703435345984178 - (65912039701838700599151897964669156747*CF^2*NC*
         Zeta[3])/108176205551253206487120 + 
       (351535089421470100*CF*NM*NC*Zeta[3])/81 - 
       (2566976*CF*NC*NL*Zeta[3])/27 + (274861839164337771477025*CF*NC*NH*
         Zeta[3])/1350851717672992089 + CA*CF*NC*
        (-8076586737677205315763306045151840510835612609049051811203432364027\
1032471/1953711877397034005507561731848592471829815881903429120000000 + 
         (86083195913011797995956984483*Pi^2)/6485071032760320 + 
         (2769981682739707153825852115*Pi^3)/(93409294952193244966656*
           Sqrt[3]) + (425657*Pi^4)/864 + 
         lm*(-3879221127170612539/736939890086400 - (3971*Pi^2)/324) - 
         (843510570822831283897764647750449*Im[PolyLog[2, (-1)^(1/3)]])/
          (11353899801439088925697036800*Sqrt[3]) + 
         (92967*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (79142333792563061537881489*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (72075073265581207536*Sqrt[3]) + (79142333792563061537881489*Pi*
           Log[3]^2)/(3459603516747897961728*Sqrt[3]) + 
         (1782031604828189794864615526494145*PolyGamma[2, 1])/
          10806813741383936712 + (65912039714935359423463429292117386387*
           Zeta[3])/216352411102506412974240) + 
       CF*Log[x]*((211763292538409631964353627624334286863699*NM*NC)/
          413981194399968962638872000 - (173864455979*lm*NM*NC)/55135080 - 
         (39874282474373126033*NC*NL)/289512099676800 - 
         (173864455979*lm*NC*NL)/55135080 - 
         (1918359478430684117223111529713468327600967439767*NC*NH)/
          1236859631164728900161783933494427795880000 - 
         (173864455979*lm*NC*NH)/55135080 + (1247533117451927*NM*NC*Pi^2)/
          9 - (427709*NC*NL*Pi^2)/27 + (14524357605973739506036*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CF*NC*(-239898381350189448130197480746790407831836622669327365410531\
1/27059055518344147101193145263289578475078400000 - 
           (326224522280787103637*Pi^2)/12972960 + 
           (79142333792563061537881489*Im[PolyLog[2, (-1)^(1/3)]])/
            (108112609898371811304*Sqrt[3]) - 86640*Zeta[3]) + 
         CA*NC*(2398983817763821512360294181897134733009388833780267269690661/
            54118111036688294202386290526579156950156800000 + 
           (173864455979*lm)/10024560 + (326224522527311341597*Pi^2)/
            25945920 - (79142333792563061537881489*Im[PolyLog[2, (-1)^
                (1/3)]])/(216225219796743622608*Sqrt[3]) + 43320*Zeta[3])), 
      (1266415675702711096122321344654862448327957019362576132280056357901489\
99868431*CF^2*NC)/
        111361577011630938313931018715369770894299505268495459840000000 - 
       (3853844093796122073128771824032081739736475072163053398347*CF*NM*NC)/
        10162660401423575775805514764864803264000000 + 
       (1512806647537939230121*CF*lm*NM*NC)/1463194151766547200 + 
       (4572784116999304453762522283*CF*NC*NL)/41498624801018889504000 + 
       (1512806647537939230121*CF*lm*NC*NL)/1463194151766547200 + 
       (782072757795801973856123629494392854441135050103801869890864306881*CF*
         NC*NH)/
        436158111267226729803907229843656730661672139034734656000000 + 
       (1512806647537939230121*CF*lm*NC*NH)/1463194151766547200 - 
       (2132718746272330310690763935366*CF^2*NC*Pi^2)/5715602155338075 + 
       (3643962376991486429678*CF*NM*NC*Pi^2)/30218265 + 
       (379*CF*lm*NM*NC*Pi^2)/162 - (14309702922569*CF*NC*NL*Pi^2)/
        6285399120 + (379*CF*lm*NC*NL*Pi^2)/162 + (379*CF*lm*NC*NH*Pi^2)/
        162 - (44165267352981662855357320945*CF^2*NC*Pi^3)/
        (665541226534376870387424*Sqrt[3]) - (215177873578814868754865*CF*NC*
         NH*Pi^3)/(900567811781994726*Sqrt[3]) - (1764409*CF^2*NC*Pi^4)/
        1620 + (359937247484400626461357241157139171*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2151847859867743328642730899520*
         Sqrt[3]) + (13437339336477308477001220111*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10946401752210145894530*Sqrt[3]) - 
       (308140*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (1261864781513761795867352027*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(513534897017266103694*
         Sqrt[3]) - (49183513960871970001112*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (1261864781513761795867352027*CF^2*NC*Pi*Log[3]^2)/
        (24649675056828772977312*Sqrt[3]) - (6147939245108996250139*CF*NC*NH*
         Pi*Log[3]^2)/(33354363399333138*Sqrt[3]) + 
       ((-84668593029268936853922075038946941497*CF^2*NC)/
          18909040922548060284000 + 
         CA*CF*(42334296530911949235187516190953710401/
            18909040922548060284000 + (5323648*lm)/9)*NC + 
         CF*NC*((18317935744569856919850843319/12658753013400 - 
             (967936*lm)/9)*NM - (38*(29709 + 25472*lm)*NL)/9 - 
           (238893231070697380681*NH)/5152112476453800 - (967936*lm*NH)/9))*
        Log[x]^2 + (CF*NC*(366185740876567992497985*CA + 
          152*(-4818233463515492912509*CF + 1021020*(1549242796690195*NM + 
              241984*NL)))*Log[x]^3)/523783260 - 
       (112267991092288918446811573828828127*CF^2*NC*PolyGamma[2, 1])/
        16210220612075905068 + (320563444702004057*CF*NM*NC*PolyGamma[2, 1])/
        324 - (318562634532579380817697*CF*NC*NH*PolyGamma[2, 1])/
        4052555153018976267 - (34466739838263233997977361663485422145471*CF^2*
         NC*Zeta[3])/2620568579479108927150482 + 
       (283381617669350261*CF*NM*NC*Zeta[3])/162 - 
       (2904566*CF*NC*NL*Zeta[3])/27 + (922960171347473666028058*CF*NC*NH*
         Zeta[3])/4052555153018976267 + CA*CF*NC*
        (-1266415675901626236719673896765179472240513328055199725302672882332\
75981424431/222723154023261876627862037430739541788599010536990919680000000 + 
         (34123499940581151409554213465071*Pi^2)/182899268970818400 + 
         (44165267352981662855357320945*Pi^3)/(1331082453068753740774848*
           Sqrt[3]) + (1770473*Pi^4)/3240 + 
         lm*(-1512806647537939230121/266035300321190400 - (4169*Pi^2)/324) - 
         (359937247484400626461357241157139171*Im[PolyLog[2, (-1)^(1/3)]])/
          (4303695719735486657285461799040*Sqrt[3]) + 
         (154070*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1261864781513761795867352027*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1027069794034532207388*Sqrt[3]) + (1261864781513761795867352027*Pi*
           Log[3]^2)/(49299350113657545954624*Sqrt[3]) + 
         (112267991092288918446811573828828127*PolyGamma[2, 1])/
          32420441224151810136 + (8616684959655652594360465693744985751398*
           Zeta[3])/1310284289739554463575241) + 
       CF*Log[x]*((27469434796146187381911694542832780450016663*NM*NC)/
          70376803047994723648608240000 - (3639044854499*lm*NM*NC)/
          1047566520 - (1504266108102762197789*NC*NL)/9626277314253600 - 
         (3639044854499*lm*NC*NL)/1047566520 - 
         (142887018015736023929315848684908181381025197251227*NC*NH)/
          81632735656872107410677739610632234528080000 - 
         (3639044854499*lm*NC*NH)/1047566520 + 
         (1032828530928272*NM*NC*Pi^2)/9 - (483968*NC*NL*Pi^2)/27 + 
         (49183513960871970001112*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*
          (-1028737792658522711501153925683090537705971163593338124978783849/
            771183082272808192384004640003752986539734400000 - 
           (4068730457195841378563*Pi^2)/11639628 + 
           (1261864781513761795867352027*Im[PolyLog[2, (-1)^(1/3)]])/
            (1540604691051798311082*Sqrt[3]) - 95760*Zeta[3]) + 
         CA*NC*
          (257184448199154554944993050127694684084166113283250037239047031/
            385591541136404096192002320001876493269867200000 + 
           (3639044854499*lm)/190466640 + (36618574117024040904355*Pi^2)/
            209513304 - (1261864781513761795867352027*
             Im[PolyLog[2, (-1)^(1/3)]])/(3081209382103596622164*Sqrt[3]) + 
           47880*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["s", 2, 1, "x1"] = SeriesData[x, 1, 
     {-(CF*NC*(121118*NM + 23424*lm*NM - 137088*NL + 23424*lm*NL + 
          121118*NH + 23424*lm*NH - 193725*NM*Zeta[3] - 
          193725*NH*Zeta[3] + 3024*CF*(-1416 + 1175*Zeta[3]) - 
          24*CA*(5368*lm - 5*(764 + 4779*Zeta[3]))))/3732480, 
      (CF*NC*(12182*NM + 23424*lm*NM - 113664*NL + 23424*lm*NL + 
         276902*NH + 23424*lm*NH - 24*CA*(1548 + 5368*lm - 23895*Zeta[3]) - 
         91665*NM*Zeta[3] - 295785*NH*Zeta[3] + 
         3024*CF*(-1416 + 1175*Zeta[3])))/3732480, 
      -(CF*NC*(74572450*NM + 40719360*lm*NM - 101282304*NL + 
          40719360*lm*NL + 630484450*NH + 40719360*lm*NH - 
          16*CA*(400636498 + 13997280*lm - 359567775*Zeta[3]) - 
          155617875*NM*Zeta[3] - 584269875*NH*Zeta[3] + 
          160*CF*(-327368654 + 272580525*Zeta[3])))/5225472000, 
      (CF*NC*(468689390*NM + 97290240*lm*NM - 81949696*NL + 
         97290240*lm*NL + 1551943650*NH + 97290240*lm*NH - 
         192*CA*(133144646 + 2786960*lm - 111492675*Zeta[3]) - 
         507205125*NM*Zeta[3] - 1367485875*NH*Zeta[3] + 
         640*CF*(-308634974 + 257035275*Zeta[3])))/10450944000, 
      -(CF*NC*(602359428930*NM + 78596259840*lm*NM + 13349691392*NL + 
          78596259840*lm*NL + 1272754418530*NH + 78596259840*lm*NH - 
          4*CA*(10577138028934 + 108069857280*lm - 8723154558825*Zeta[3]) - 
          528575047875*NM*Zeta[3] - 1094514757875*NH*Zeta[3] + 
          280*CF*(-1571465833022 + 1307802839805*Zeta[3])))/8193540096000, 
      (CF*NC*(381474353260*NM + 35405045760*lm*NM + 31759986688*NL + 
         35405045760*lm*NL + 597232439370*NH + 35405045760*lm*NH - 
         2*CA*(19198320064402 + 97363875840*lm - 15837595724475*Zeta[3]) - 
         303892769250*NM*Zeta[3] - 506177319375*NH*Zeta[3] + 
         140*CF*(-3348498192826 + 2785819031415*Zeta[3])))/4096770048000, 
      -(CF*NC*(5*(32768*(3151751692 + 2077680465*lm)*NL + 
            63*NH*(19566054084794 + 1080657674240*lm - 16420548288375*Zeta[
                3]) + 63*NM*(16155315679874 + 1080657674240*lm - 
              12284229139875*Zeta[3])) - 4*CA*(191611010425847938 + 
            468059855155200*lm - 158501882546035875*Zeta[3]) + 
          72*CF*(-155857850505993998 + 129653229666547125*Zeta[3])))/
       48669628170240000, (CF*NC*(5*(40960*(655358855 + 308016828*lm)*NL + 
           63*NH*(4015188731162 + 200259829760*lm - 3345812922375*Zeta[3]) + 
           63*NM*(4288091366874 + 200259829760*lm - 3210120750375*
              Zeta[3])) - 4*CA*(75954087426185278 + 86737538764800*lm - 
           62973839587168125*Zeta[3]) + 72*CF*(-72939247248450098 + 
           60674839173592875*Zeta[3])))/12167407042560000, 
      -(CF*NC*(5*(65536*(18676991479081 + 6645407256180*lm)*NL + 
            99*NM*(142440916923630578 + 4399125352939520*lm - 
              107081724583708875*Zeta[3]) + 495*NH*(20230643329135690 + 
              879825070587904*lm - 16768829348045775*Zeta[3])) - 
          847*CA*(27337142662475399846 + 14140045777305600*lm - 
            22699015244064329625*Zeta[3]) + 286*CF*(-1632156832186379881946 + 
            1357734219748409262375*Zeta[3])))/612458600894300160000, 
      (CF*NC*(14476048546519455126*NM + 276376038223380480*lm*NM + 
         1016217320783544320*NL + 276376038223380480*lm*NL + 
         7626647792494513926*NH + 276376038223380480*lm*NH - 
         121*CA*(55790838222920245514 + 12562547191971840*lm - 
           46365455069857716975*Zeta[3]) - 11042538634392890625*NM*Zeta[3] - 
         6296337698085059625*NH*Zeta[3] + 286*CF*(-549054339544720904282 + 
           456746705137779539175*Zeta[3])))/122491720178860032000, 
      -(CF*NC*(35*(16777216*(511177335126817 + 103169930793930*lm)*NL + 
            429*NM*(4034741756724510720*lm + 1859*(199387686283044158 - 
                154795131316720125*Zeta[3])) + 1287*NH*
             (47649441086958627774 + 1344913918908170240*lm - 
              39219098911331464125*Zeta[3])) - 
          88*CA*(41010581907054502780106002 + 3786352967326158028800*lm - 
            34098674307958209269194875*Zeta[3]) + 
          208*CF*(-461327643083839033769898146 + 383773735160719108476145875*
             Zeta[3])))/46370465590909253713920000, 
      (CF*NC*(35*(8388608*(1520981622700433 + 208309026105180*lm)*NL + 
           429*NM*(735245273889337619402 + 4073246533468815360*lm - 
             579980200915627887375*Zeta[3]) + 9009*NH*(9946666802277135502 + 
             193964120641372160*lm - 8168293307492443125*Zeta[3])) - 
         352*CA*(28187680180992414378599102 + 955621823438035353600*lm - 
           23443038088002090865432125*Zeta[3]) + 
         832*CF*(-359457431206806864216104366 + 299031553858325334426505125*
            Zeta[3])))/92740931181818507427840000, 
      -(CF*NC*(35*(603979776*(4109570639514199 + 294183454144580*lm)*NL + 
            143*NM*(564279318378276239041654 + 1242523473686361538560*lm - 
              450487063789769313932625*Zeta[3]) + 143*NH*
             (123082257148006276881046 + 1242523473686361538560*lm - 
              100906870888384282346625*Zeta[3])) - 
          6*CA*(604184537578674536841551021434 + 5700594153650219542118400*
             lm - 502555080511589062055711988375*Zeta[3]) + 
          12*CF*(-10247188107548080183667382024838 + 
            8524650477724985199967709963625*Zeta[3])))/
       25225533281454634020372480000, 
      (CF*NC*(5*(167772160*(5110306479389885 + 1443530772684*lm)*NL + 
           143*NM*(235124252989197415582982 + 1693596333983662080*lm - 
             188949584445498006755625*Zeta[3]) + 286*NH*
            (22074695651063170660402 + 846798166991831040*lm - 
             18075670698768728920875*Zeta[3])) - 
         9*CA*(37878971524210577618506700158 + 740007509265639014400*lm - 
           31509610977759548538055276125*Zeta[3]) + 
         14*CF*(-923495755756527924956035621982 + 
           768259850169087969868880830125*Zeta[3])))/
       1801823805818188144312320000, 
      -(CF*NC*(170*CF*(-20176775886375464658951761105193994 + 
            16785171328033727705448334460062575*Zeta[3]) + 
          CA*(-81372139761516820114037694985994414 + 
            243555210398898753756022702080*lm + 
            67691836008123144076982704994137125*Zeta[3]) - 
          21*(805306368*(-31246939482631957813 + 2618510425508998020*lm)*
             NL + 17017*NM*(-50553397155365990852491406 + 
              123917442577233692590080*lm + 40400043620395010341915125*Zeta[
                3]) + 2431*NH*(-81683847557828611556531642 + 
              867422098040635848130560*lm + 66829523591745296991984375*Zeta[
                3]))))/332432167796321748974076690432000, 
      (CF*NC*(4*CA*(-64789775717640690048745906449949054 + 
           224166254420062567187192217600*lm + 
           53898278512785123530819245467052125*Zeta[3]) + 
         136*CF*(-88805956834356690409030091248916578 + 
           73878239858891626894730622462709875*Zeta[3]) - 
         105*(536870912*(-15103412564548052357 + 2892067092064430280*lm)*
            NL + 2431*NM*(60428102398707891658665502 + 
             638694651288284100034560*lm - 54008437274005884458914125*
              Zeta[3]) + 2431*NH*(638694651288284100034560*lm + 
             2431*(-12057606971622718674386 + 9859304243266265662875*
                Zeta[3])))))/831080419490804372435191726080000, 
      -(CF*NC*(8*CA*(-313517182390062936200753057499539015102 + 
            953656514670425964239577415680000*lm + 
            260815630880684039354942839995698920125*Zeta[3]) + 
          304*CF*(-423033447931748485669958545088825194742 + 
            351924408098335028206433546221446212625*Zeta[3]) - 
          35*(42949672960*(-2688679726738057850767 + 922765548614737627800*
               lm)*NL + 4199*NM*(6383313420550340138590820588674 + 
              9438551686534403941466112000*lm - 
              5340828748545881581690676851875*Zeta[3]) + 
            29393*NH*(1348364526647771991638016000*lm + 205751*(
                -196595389517067185589502 + 160693854772095219700125*
                 Zeta[3])))))/6400427337305181406914223213117440000, 
      (CF*NC*(2736*CF*(-63916872419644856779904980530586544662 + 
           53172897866447871677922752406572786625*Zeta[3]) + 
         8*CA*(-389218123211548293915370279687147889486 + 
           940047635550623987288652329779200*lm + 
           323792770198694030867648983792370671125*Zeta[3]) - 
         35*(8589934592*(-7769312946131540247113 + 4547987450401039805160*lm)*
            NL + 4199*NM*(15780133870568845262293470161618 + 
             9303861568035669467757281280*lm - 
             13144732190478494587779313390875*Zeta[3]) + 
           4199*NH*(9303861568035669467757281280*lm + 
             4199*(-49169282993213670627952802 + 40180958049089356145521875*
                Zeta[3])))))/6400427337305181406914223213117440000, 
      -(CF*NC*(2*CA*(-5804306721097858312631393203974701296607038 + 
            10613292697709685184121339171674521600*lm + 
            4828644877249537902423662353991255608912125*Zeta[3]) + 
          CF*(-711214604187137601900796248758006673884480264 + 
            591664553743190914625009139550243053291199500*Zeta[3]) - 
          1155*(46189*NM*(260790296400750564355054665820342 + 
              72343064812165447558071582720*lm - 
              217022016074758613094309180872625*Zeta[3]) + 
            7*(206158430208*(-2195268850133159887739 + 2315454892238395444680*
                 lm)*NL + 4199*NH*(113681958990545703305541058560*lm + 
                71383*(-28065435774035042871994606 + 
                  22931606861161918623829125*Zeta[3]))))))/
       19431697396058530751391581675024547840000, 
      (CF*NC*(52*CA*(-54292857228619308356158432710008081820262 + 
           73430710817906822789068655217868800*lm + 
           45166656228717782010369636576494694682425*Zeta[3]) + 
         200*CF*(-939846124698630909100377713703092718678434 + 
           781864834150271721091444063655355881898579*Zeta[3]) - 
         231*(137438953472*(-9051173392505062927673 + 21867370683591830997600*
              lm)*NL + 146965*NM*(147000317692004714136344234404682 + 
             20449961160392981283424174080*lm - 
             122297086745689233194952726365775*Zeta[3]) + 
           4199*NH*(715748640613754344919846092800*lm + 
             4199*(-2502021318808646731025134762 + 
               2044121949023626423978401375*Zeta[3])))))/
       3886339479211706150278316335004909568000, 
      -(CF*NC*(228*CA*(-210536790428487566684457512110937898795992206 + 
            208463832352420851452954591082892492800*lm + 
            175147257554093209018823916695860549688155125*Zeta[3]) + 
          184*CF*(-18808876689325576182883283248712098611729969646 + 
            15647242244676452207074223834564148690338245125*Zeta[3]) - 
          385*(21440476741632*(-12266710169302155804751 + 
              1046906045134597044852840*lm)*NL + 37145*NM*
             (8370358819384979586437675170929075962 + 
              604284956558951912103909412306944*lm - 
              6963263130114967444240406361848796375*Zeta[3]) + 
            7429*NH*(3021424782794759560519547061534720*lm + 
              170867*(-223904475172306112046936769162 + 
                182908814844261645933117699375*Zeta[3])))))/
       54823295586746468093259449099135924305920000, 
      (CF*NC*(2*CA*(-782671632392857405006417575174291752885682946 + 
           565826708037533404818279400426186997760*lm + 
           651110856232555794274686950564797528979621475*Zeta[3]) + 
         92*CF*(-1323921696879190599936151288446037139753442226 + 
           1101380184062064449171569408195767876951789675*Zeta[3]) - 
         21*(274877906944*(10896001812666478476306757 + 
             35644425494840116446852360*lm)*NL + 59432*NM*
            (4302118400598334483187631986333421406 + 
             164858410860193207040584313733120*lm - 
             3578874220874816537436044574621454125*Zeta[3]) + 
           22287*NH*(439622428960515218774891503288320*lm + 
             141151*(-34958085574221237367600887922 + 
               28554195279554669260730068875*Zeta[3])))))/
       1495180788729449129816166793612797935616000}, 0, 22, 1]
 
CbarSeries["s", 2, 2, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(15*CA*(4665 + 15840*lm^2 - 10732*Pi^2 + 432*Pi^4 - 
            80*lm*(-483 + 44*Pi^2) - 244512*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 34560*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            40752*PolyGamma[2, 1] + 434496*Zeta[3]) + 
          2*(CF*(-194400*lm^2 - 72892*Pi^2 + 1200*Pi^4 + 43200*lm*(-6 + 
                Pi^2) + 15*(-16097 + 244512*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 34560*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                40752*PolyGamma[2, 1] - 396480*Zeta[3])) + 
            60*(NL*(15 - 420*lm - 360*lm^2 + 52*Pi^2 + 80*lm*Pi^2 - 
                960*Zeta[3]) + NM*(15 - 360*lm^2 + 52*Pi^2 + 
                20*lm*(-21 + 4*Pi^2) + 80*PolyGamma[2, 1] - 800*Zeta[3]) + 
              NH*(-10593 - 420*lm - 360*lm^2 + 80*lm*Pi^2 - 68976*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 11496*PolyGamma[2, 1] + 
                132432*Zeta[3])))))/6220800, 
      (CF*NC*(-2*(CF*(388800*lm^2 + 335524*Pi^2 + 7320*Pi^4 - 
             43200*lm*(33 + 2*Pi^2) + 15*(158939 + 92064*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 120960*Im[PolyLog[2, 
                   (-1)^(1/3)]]^2 - 15104*PolyGamma[2, 1] - 307744*
                Zeta[3])) - 120*(NH*(-360*lm^2 + 20*lm*(69 + 4*Pi^2) + 3*
                (58211 + 16272*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                 2712*PolyGamma[2, 1] - 77744*Zeta[3])) + 
             NL*(5865 - 360*lm^2 + 108*Pi^2 + 20*lm*(69 + 4*Pi^2) - 960*
                Zeta[3]) + NM*(5865 - 360*lm^2 + 108*Pi^2 + 20*lm*
                (69 + 4*Pi^2) + 80*PolyGamma[2, 1] - 800*Zeta[3]))) + 
         15*CA*(-628455 + 31680*lm^2 - 38396*Pi^2 + 1512*Pi^4 - 
           160*lm*(507 + 44*Pi^2) + 92064*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 120960*Im[PolyLog[2, (-1)^(1/3)]]^
             2 - 15104*PolyGamma[2, 1] - 180832*Zeta[3])))/6220800, 
      -(CF*NC*(CA*(-126720*lm^2 + 160*lm*(1929 + 44*Pi^2) + 
            3*(721235 + 6204*Pi^2 + 408*Pi^4 - 299616*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 213120*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 55072*PolyGamma[2, 1] + 686240*Zeta[3])) - 
          2*(8*(NH*(470151 + 5340*lm - 1440*lm^2 + 80*lm*Pi^2 + 
                379152*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 67024*
                 PolyGamma[2, 1] - 1080608*Zeta[3]) + NM*(27615 - 
                1440*lm^2 - 1084*Pi^2 + 20*lm*(267 + 4*Pi^2) - 
                160*PolyGamma[2, 1] - 1280*Zeta[3]) + NL*(19515 + 5340*lm - 
                1440*lm^2 - 364*Pi^2 + 80*lm*Pi^2 - 960*Zeta[3])) + 
            CF*(-676965 - 103680*lm^2 - 74068*Pi^2 + 2248*Pi^4 + 
              1440*lm*(255 + 4*Pi^2) - 898848*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 639360*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              165216*PolyGamma[2, 1] + 2468640*Zeta[3]))))/414720, 
      -(CF*NC*(12441600*(27*CF*(5 + 2*lm) - CA*(76 + 33*lm) + 
            2*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          24883200*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          5*CA*(-174070215 + 29937600*lm^2 - 9555948*Pi^2 + 
            2237200*Sqrt[3]*Pi^3 + 471960*Pi^4 - 12960*lm*
             (-2291 + 132*Pi^2) - 32111136*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 139501440*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            82840320*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
            1725840*Sqrt[3]*Pi*Log[3]^2 + 9083904*PolyGamma[2, 1] - 
            31513056*Zeta[3]) - 21600*Log[x]*
           (CA*(57531 + 29016*lm + 4752*lm^2 + 978*Pi^2 - 6392*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 10368*Zeta[3]) - 
            2*(24*(3*NM*(-14 + 29*lm + 6*lm^2 + 6*Pi^2) + 3*NL*
                 (58 + 29*lm + 6*lm^2 + 6*Pi^2) + NH*(3296 + 87*lm + 
                  18*lm^2 - 1864*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
              CF*(37803 + 19440*lm + 3888*lm^2 + 426*Pi^2 - 6392*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 10368*Zeta[3]))) + 
          2*(CF*(122472000*lm^2 + 14306148*Pi^2 + 11186000*Sqrt[3]*Pi^3 + 
              1115640*Pi^4 - 6998400*lm*(2 + Pi^2) + 8629200*Sqrt[3]*Pi*
               Log[3]^2 + 15*(34419483 - 10703712*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 46500480*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
                27613440*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                3027968*PolyGamma[2, 1] - 37474976*Zeta[3])) - 
            120*(27*NL*(20815 - 4200*lm^2 - 2812*Pi^2 + 20*lm*
                 (59 + 12*Pi^2) - 20160*Zeta[3]) + 27*NM*(65815 - 
                4200*lm^2 - 2332*Pi^2 + 20*lm*(59 + 12*Pi^2) - 
                1040*PolyGamma[2, 1] + 12320*Zeta[3]) - NH*(-29044701 + 
                113400*lm^2 + 652400*Sqrt[3]*Pi^3 - 540*lm*(59 + 12*Pi^2) - 
                7378992*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 24157440*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 503280*Sqrt[3]*Pi*
                 Log[3]^2 + 1614168*PolyGamma[2, 1] + 18002736*Zeta[3])))))/
       55987200, -(CF*NC*(2332800*(-10*CA*(76 + 33*lm) + 9*CF*(139 + 60*lm) + 
            4*(28*NM + 15*lm*NM + 25*NL + 15*lm*NL + 15*lm*NH))*
           Log[x]^2 + 46656000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          135*CA*(-13375485 + 1865160*lm^2 - 475020*Pi^2 + 
            205450*Sqrt[3]*Pi^3 + 24372*Pi^4 - 180*lm*(-8359 + 396*Pi^2) + 
            233616*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            9875520*Im[PolyLog[2, (-1)^(1/3)]]^2 + 7607520*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 158490*Sqrt[3]*Pi*
             Log[3]^2 + 253396*PolyGamma[2, 1] - 8488024*Zeta[3]) - 
          2700*Log[x]*(2*(-8*(18*NL*(403 + 201*lm + 45*lm^2 + 45*Pi^2) + 
                9*NM*(-409 + 402*lm + 90*lm^2 + 120*Pi^2) + 
                2*NH*(63222 + 1809*lm + 405*lm^2 - 35680*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 27*CF*(-19511 - 10008*lm - 
                2160*lm^2 + 182*Pi^2 + 4696*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 5760*Zeta[3])) + 9*CA*(93143 + 45456*lm + 
              7920*lm^2 + 342*Pi^2 - 14088*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 17280*Zeta[3])) + 
          2*(54*CF*(3815100*lm^2 + 24342*Pi^2 + 513625*Sqrt[3]*Pi^3 + 
              35010*Pi^4 - 24300*lm*(47 + 6*Pi^2) + 396225*Sqrt[3]*Pi*Log[3]^
                2 + 10*(1204758 + 58404*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                2468880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1901880*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 63349*PolyGamma[2, 
                  1] - 3444790*Zeta[3])) - 5*(243*NL*(98075 - 18840*lm^2 - 
                15036*Pi^2 + 20*lm*(439 + 36*Pi^2) - 95040*Zeta[3]) + 
              243*NM*(316835 - 18840*lm^2 - 19516*Pi^2 + 20*lm*
                 (439 + 36*Pi^2) - 9528*PolyGamma[2, 1] + 87504*Zeta[3]) - 
              NH*(-1086519177 + 4578120*lm^2 + 24976000*Sqrt[3]*Pi^3 - 
                4860*lm*(439 + 36*Pi^2) - 441301104*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 924825600*Sqrt[3]*Im[PolyLog[3, 
                   -((-1)^(5/6)/Sqrt[3])]] + 19267200*Sqrt[3]*Pi*Log[3]^2 + 
                93530112*PolyGamma[2, 1] + 964815744*Zeta[3])))))/41990400, 
      -(CF*NC*(-4082400*(65*CA*(587 + 264*lm) - 2*(15*CF*(2189 + 936*lm) + 
              4*(10*(107 + 39*lm)*NM + 5*(121 + 78*lm)*NL + 6*(2 + 65*lm)*
                 NH)))*Log[x]^2 + 326592000*(161*CA + 558*CF - 44*NM - 
            26*NL)*Log[x]^3 - 175*CA*(-497865555 + 71850240*lm^2 - 
            26316333*Pi^2 + 13021750*Sqrt[3]*Pi^3 + 1734372*Pi^4 - 
            38880*lm*(-2473 + 66*Pi^2) - 102500172*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 410806080*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 482176800*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10045350*Sqrt[3]*Pi*
             Log[3]^2 + 39812448*PolyGamma[2, 1] - 149343312*Zeta[3]) - 
          7560*Log[x]*(2*(-12*(225*NM*(-52 + 299*lm + 60*lm^2 + 40*Pi^2) + 
                225*NL*(680 + 299*lm + 60*lm^2 + 72*Pi^2) + 
                NH*(2607591 + 67275*lm + 13500*lm^2 - 1470400*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 25*CF*(-626898 - 
                300348*lm - 58320*lm^2 + 7047*Pi^2 + 148820*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 155520*Zeta[3])) + 
            25*CA*(986808 + 445932*lm + 71280*lm^2 + 4041*Pi^2 - 
              148820*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 155520*Zeta[3])) + 
          2*(5*CF*(2057529600*lm^2 - 460285443*Pi^2 + 455761250*Sqrt[3]*Pi^
                3 + 47639340*Pi^4 - 36741600*lm*(-13 + 2*Pi^2) + 
              351587250*Sqrt[3]*Pi*Log[3]^2 - 420*(-6551379 + 8541681*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 34233840*Im[PolyLog[2, 
                    (-1)^(1/3)]]^2 - 40181400*Sqrt[3]*Im[PolyLog[3, 
                   -((-1)^(5/6)/Sqrt[3])]] - 3317704*PolyGamma[2, 1] + 
                29960068*Zeta[3])) - 84*(2025*NL*(35085 - 6720*lm^2 - 
                7096*Pi^2 + 40*lm*(-11 + 6*Pi^2) - 54720*Zeta[3]) + 
              2025*NM*(133515 - 6720*lm^2 - 6476*Pi^2 + 40*lm*(-11 + 
                  6*Pi^2) - 3802*PolyGamma[2, 1] + 104716*Zeta[3]) - 
              NH*(-4131422631 + 13608000*lm^2 + 128660000*Sqrt[3]*Pi^3 - 
                81000*lm*(-11 + 6*Pi^2) - 981241200*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 4764096000*Sqrt[3]*Im[PolyLog[3, 
                   -((-1)^(5/6)/Sqrt[3])]] + 99252000*Sqrt[3]*Pi*Log[3]^2 + 
                238548750*PolyGamma[2, 1] + 1367449500*Zeta[3])))))/
       734832000, -(CF*NC*(2721600*(-12*CA*(6388 + 2717*lm) + 
            19*CF*(6755 + 2808*lm) + 4*(4661*NM + 1482*lm*NM + 2247*NL + 
              1482*lm*NL + 54*NH + 1482*lm*NH))*Log[x]^2 + 
          21772800*(2789*CA + 11738*CF - 808*NM - 494*NL)*Log[x]^3 - 
          7560*Log[x]*(2*(-2*(45*NL*(24529 + 10442*lm + 2160*lm^2 + 
                  2696*Pi^2) + 15*NM*(-13529 + 31326*lm + 6480*lm^2 + 
                  7032*Pi^2) + NH*(17534019 + 469890*lm + 97200*lm^2 - 
                  9867520*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
              15*CF*(-1138605 - 583308*lm - 116640*lm^2 + 9483*Pi^2 + 
                343172*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 311040*
                 Zeta[3])) + 15*CA*(1882170 + 870612*lm + 142560*lm^2 + 
              13521*Pi^2 - 343172*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              311040*Zeta[3])) - 105*CA*(130870080*lm^2 - 47605239*Pi^2 + 
            30027550*Sqrt[3]*Pi^3 + 3477492*Pi^4 - 8640*lm*
             (-18607 + 429*Pi^2) + 23164110*Sqrt[3]*Pi*Log[3]^2 - 
            36*(27050100 + 2643021*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              22842000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 30885480*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1969402*PolyGamma[2, 
                1] + 19411480*Zeta[3])) + 
          2*(3*CF*(3747643200*lm^2 - 1146285297*Pi^2 + 1050964250*Sqrt[3]*Pi^
                3 + 102842460*Pi^4 - 1360800*lm*(-337 + 78*Pi^2) + 
              810743850*Sqrt[3]*Pi*Log[3]^2 - 315*(-15174353 + 10572084*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 91368000*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 123541920*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 7877608*PolyGamma[2, 
                  1] + 123577024*Zeta[3])) - 56*(405*NL*(324215 - 
                55080*lm^2 - 64756*Pi^2 + 40*lm*(61 + 39*Pi^2) - 
                504000*Zeta[3]) + 135*NM*(3181715 - 165240*lm^2 - 
                243798*Pi^2 + 120*lm*(61 + 39*Pi^2) - 179802*PolyGamma[2, 
                  1] + 3174156*Zeta[3]) - NH*(-6775913421 + 22307400*lm^2 + 
                215852000*Sqrt[3]*Pi^3 - 16200*lm*(61 + 39*Pi^2) - 
                2068575240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 7992691200*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                166514400*Sqrt[3]*Pi*Log[3]^2 + 491746910*PolyGamma[2, 1] + 
                2969095420*Zeta[3])))))/440899200, 
      (75550289*CF^2*NC)/1679616 - (986*CF^2*lm*NC)/27 - 105*CF^2*lm^2*NC + 
       (3705545*CF*NM*NC)/11664 - (1027*CF*lm*NM*NC)/486 - 
       (35*CF*lm^2*NM*NC)/3 + (112103*CF*NC*NL)/1296 - 
       (1027*CF*lm*NC*NL)/486 - (35*CF*lm^2*NC*NL)/3 + 
       (2270866302371*CF*NC*NH)/500094000 - (1027*CF*lm*NC*NH)/486 - 
       (35*CF*lm^2*NC*NH)/3 + (31508957*CF^2*NC*Pi^2)/544320 + 
       (25*CF^2*lm*NC*Pi^2)/9 - (5567*CF*NM*NC*Pi^2)/972 + 
       (25*CF*lm*NM*NC*Pi^2)/81 - (7973*CF*NC*NL*Pi^2)/486 + 
       (25*CF*lm*NC*NL*Pi^2)/81 + (25*CF*lm*NC*NH*Pi^2)/81 - 
       (75702235*CF^2*NC*Pi^3)/(629856*Sqrt[3]) - (2119915*CF*NC*NH*Pi^3)/
        (4374*Sqrt[3]) - (1763*CF^2*NC*Pi^4)/432 + 
       (68982785*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(104976*Sqrt[3]) + 
       (2258443*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(729*Sqrt[3]) - 
       (2615*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (2162921*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (486*Sqrt[3]) - (484552*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27*Sqrt[3]) - 
       (2162921*CF^2*NC*Pi*Log[3]^2)/(23328*Sqrt[3]) - 
       (60569*CF*NC*NH*Pi*Log[3]^2)/(162*Sqrt[3]) - 
       (CF*NC*(-105*CA*(73987 + 32780*lm) + 35*CF*(379943 + 160920*lm) + 
          1362760*NM + 625800*lm*NM + 913500*NL + 625800*lm*NL + 
          40284*NH + 625800*lm*NH)*Log[x]^2)/5670 - 
       (10*CF*NC*(3695*CA + 16280*CF - 2320*NM - 596*NL)*Log[x]^3)/81 - 
       (64636687*CF^2*NC*PolyGamma[2, 1])/590490 + 
       (23087*CF*NM*NC*PolyGamma[2, 1])/3240 - 
       (69191483*CF*NC*NH*PolyGamma[2, 1])/262440 + 
       (1168904507*CF^2*NC*Zeta[3])/1180980 + (611087*CF*NM*NC*Zeta[3])/
        1620 - (3980*CF*NC*NL*Zeta[3])/27 - (106645883*CF*NC*NH*Zeta[3])/
        131220 + (CF*NC*Log[x]*(72*(-1225*NM*(25991 + 41709*lm + 8100*lm^2 - 
              13620*Pi^2) - 3675*NL*(36327 + 13903*lm + 2700*lm^2 + 
              3880*Pi^2) - NH*(2109986972 + 51093525*lm + 9922500*lm^2 - 
              1187152400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          1225*CF*(-56808159 - 27902232*lm - 5248800*lm^2 + 666630*Pi^2 + 
            17303368*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 13996800*Zeta[3]) + 
          1225*CA*(46708473 + 20599164*lm + 3207600*lm^2 + 252585*Pi^2 - 
            8651684*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 6998400*Zeta[3])))/
        42865200 + (CA*CF*NC*(16974619200*lm^2 - 8765273655*Pi^2 + 
          5299156450*Sqrt[3]*Pi^3 + 605113740*Pi^4 - 
          272160*lm*(-90677 + 1650*Pi^2) + 4087920690*Sqrt[3]*Pi*Log[3]^2 - 
          7*(20232113535 + 4138967100*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            16470734400*Im[PolyLog[2, (-1)^(1/3)]]^2 - 28031456160*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 2068373984*
             PolyGamma[2, 1] + 10389422672*Zeta[3])))/264539520, 
      (10354456121*CF^2*NC)/279936000 - (80627*CF^2*lm*NC)/1728 - 
       (2715*CF^2*lm^2*NC)/16 + (3102895033*CF*NM*NC)/5832000 - 
       (31757*CF*lm*NM*NC)/15552 - (905*CF*lm^2*NM*NC)/48 + 
       (10054807*CF*NC*NL)/62208 - (31757*CF*lm*NC*NL)/15552 - 
       (905*CF*lm^2*NC*NL)/48 + (136448752674239*CF*NC*NH)/18003384000 - 
       (31757*CF*lm*NC*NH)/15552 - (905*CF*lm^2*NC*NH)/48 + 
       (82829881*CF^2*NC*Pi^2)/1088640 + (275*CF^2*lm*NC*Pi^2)/72 - 
       (181969*CF*NM*NC*Pi^2)/7776 + (275*CF*lm*NM*NC*Pi^2)/648 - 
       (224345*CF*NC*NL*Pi^2)/7776 + (275*CF*lm*NC*NL*Pi^2)/648 + 
       (275*CF*lm*NC*NH*Pi^2)/648 - (24230605*CF^2*NC*Pi^3)/
        (104976*Sqrt[3]) - (259372645*CF*NC*NH*Pi^3)/(314928*Sqrt[3]) - 
       (1091*CF^2*NC*Pi^4)/144 + (53789627*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(69984*Sqrt[3]) + 
       (316089167*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(52488*Sqrt[3]) - 
       (4565*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (692303*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) - 
       (7410647*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (243*Sqrt[3]) - (692303*CF^2*NC*Pi*Log[3]^2)/(3888*Sqrt[3]) - 
       (7410647*CF*NC*NH*Pi*Log[3]^2)/(11664*Sqrt[3]) - 
       (CF*NC*(-21*CA*(6228029 + 2444420*lm) + 
          14*CF*(15913837 + 5999940*lm) + 26490632*NM + 9333240*lm*NM + 
          13320930*NL + 9333240*lm*NL + 690768*NH + 9333240*lm*NH)*
         Log[x]^2)/45360 - (CF*NC*(116425*CA + 688445*CF - 85532*NM - 
          22222*NL)*Log[x]^3)/162 - (721213619*CF^2*NC*PolyGamma[2, 1])/
        3149280 + (2791*CF*NM*NC*PolyGamma[2, 1])/1620 - 
       (2390426759*CF*NC*NH*PolyGamma[2, 1])/4723920 + 
       (3728473591*CF^2*NC*Zeta[3])/1574640 + (571651*CF*NM*NC*Zeta[3])/
        810 - (7268*CF*NC*NL*Zeta[3])/27 - (4141922159*CF*NC*NH*Zeta[3])/
        2361960 + (CA*CF*NC*(457203285000*lm^2 - 175799109375*Pi^2 + 
          169614235000*Sqrt[3]*Pi^3 + 18198999000*Pi^4 - 
          141750*lm*(-4454407 + 72600*Pi^2) + 130845267000*Sqrt[3]*Pi*
           Log[3]^2 - 28*(140571088452 + 20171110125*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 119803860000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 224306172000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 18030340475*
             PolyGamma[2, 1] + 125717662550*Zeta[3])))/4408992000 - 
       (CF*NC*Log[x]*(-147*CA*(2627419551 + 1187599500*lm + 187110000*lm^2 + 
            51233400*Pi^2 - 553842400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            408240000*Zeta[3]) + 2*(34624001475*NL + 12688231500*lm*NL + 
            2500470000*lm^2*NL + 517123569192*NH + 12688231500*lm*NH + 
            2500470000*lm^2*NH + 3773460600*NL*Pi^2 + 
            882*NM*(14775409 + 14385750*lm + 2835000*lm^2 - 4146900*Pi^2) - 
            290497362400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            294*CF*(765376413 + 401172750*lm + 76545000*lm^2 + 7231500*Pi^2 - 
              276921200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 204120000*Zeta[
                3]))))/171460800, (13967764737283*CF^2*NC)/30233088000 - 
       (11353*CF^2*lm*NC)/96 - (2365*CF^2*lm^2*NC)/8 + 
       (639395533*CF*NM*NC)/648000 - (6623*CF*lm*NM*NC)/864 - 
       (2365*CF*lm^2*NM*NC)/72 + (3768821*CF*NC*NL)/10368 - 
       (6623*CF*lm*NC*NL)/864 - (2365*CF*lm^2*NC*NL)/72 + 
       (88678054349909*CF*NC*NH)/5401015200 - (6623*CF*lm*NC*NH)/864 - 
       (2365*CF*lm^2*NC*NH)/72 + (43877213*CF^2*NC*Pi^2)/181440 + 
       (25*CF^2*lm*NC*Pi^2)/4 + (23681*CF*NM*NC*Pi^2)/144 + 
       (25*CF*lm*NM*NC*Pi^2)/36 - (8263*CF*NC*NL*Pi^2)/144 + 
       (25*CF*lm*NC*NL*Pi^2)/36 + (25*CF*lm*NC*NH*Pi^2)/36 - 
       (11430024025*CF^2*NC*Pi^3)/(22674816*Sqrt[3]) - 
       (888995975*CF*NC*NH*Pi^3)/(472392*Sqrt[3]) - (84361*CF^2*NC*Pi^4)/
        5184 + (8459671235*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (3779136*Sqrt[3]) + (859112341*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (78732*Sqrt[3]) - (34135*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (326572115*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (17496*Sqrt[3]) - (50799770*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (326572115*CF^2*NC*Pi*Log[3]^2)/(839808*Sqrt[3]) - 
       (25399885*CF*NC*NH*Pi*Log[3]^2)/(17496*Sqrt[3]) - 
       (CF*NC*(14*CF*(68551859 + 27702000*lm) - 
          7*CA*(80075489 + 33858000*lm) + 24*(126*(-30641 + 14250*lm)*NM + 
            5*(63*(7957 + 5700*lm)*NL + 4*(8821 + 89775*lm)*NH)))*Log[x]^2)/
        90720 - (CF*NC*(304105*CA + 1743080*CF - 108*(3968*NM + 475*NL))*
         Log[x]^3)/162 - (1265282809*CF^2*NC*PolyGamma[2, 1])/2657205 + 
       (39551*CF*NM*NC*PolyGamma[2, 1])/120 - 
       (186610831*CF*NC*NH*PolyGamma[2, 1])/196830 + 
       (175276816237*CF^2*NC*Zeta[3])/42515280 + (106391*CF*NM*NC*Zeta[3])/
        60 - 600*CF*NC*NL*Zeta[3] - (141667981*CF*NC*NH*Zeta[3])/98415 + 
       (CF*NC*Log[x]*(2*(48*(-47628*NM*(1251746 + 832575*lm + 157500*lm^2 - 
                1307850*Pi^2) - 5*(59535*NL*(397843 + 133212*lm + 
                  25200*lm^2 + 42600*Pi^2) + 4*NH*(88608902028 + 1982694105*
                   lm + 375070500*lm^2 - 49783774600*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]]))) + 49*CF*(-676508146071 - 
              360624052800*lm - 66134880000*lm^2 + 1187735400*Pi^2 + 
              261257692000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              176359680000*Zeta[3])) + 49*CA*(1180707428571 + 
            530167291200*lm + 80831520000*lm^2 + 16188514200*Pi^2 - 
            261257692000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            176359680000*Zeta[3])))/12345177600 + 
       (CA*CF*NC*(688199561280000*lm^2 - 447357463488000*Pi^2 + 
          320040672700000*Sqrt[3]*Pi^3 + 33111897336000*Pi^4 - 
          24249456000*lm*(-42743 + 600*Pi^2) + 246888518940000*Sqrt[3]*Pi*
           Log[3]^2 - 7*(948161009734047 + 203032109640000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 774004844160000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 1692949844160000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 129564959641600*
             PolyGamma[2, 1] + 720117491564800*Zeta[3])))/3809369088000, 
      (22450157046253697*CF^2*NC)/17283248640000 - (122889*CF^2*lm*NC)/800 - 
       (883*CF^2*lm^2*NC)/2 + (92905615739*CF*NM*NC)/55566000 - 
       (192067*CF*lm*NM*NC)/21600 - (883*CF*lm^2*NM*NC)/18 + 
       (270795229*CF*NC*NL)/432000 - (192067*CF*lm*NC*NL)/21600 - 
       (883*CF*lm^2*NC*NL)/18 + (12487881360026479*CF*NC*NH)/486091368000 - 
       (192067*CF*lm*NC*NH)/21600 - (883*CF*lm^2*NC*NH)/18 - 
       (42874057*CF^2*NC*Pi^2)/907200 + (33*CF^2*lm*NC*Pi^2)/4 + 
       (404597*CF*NM*NC*Pi^2)/2160 + (11*CF*lm*NM*NC*Pi^2)/12 - 
       (66257*CF*NC*NL*Pi^2)/720 + (11*CF*lm*NC*NL*Pi^2)/12 + 
       (11*CF*lm*NC*NH*Pi^2)/12 - (6527391409*CF^2*NC*Pi^3)/
        (7558272*Sqrt[3]) - (12695545765*CF*NC*NH*Pi^3)/(4251528*Sqrt[3]) - 
       (46969*CF^2*NC*Pi^4)/1728 + (88811677043*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(31492800*Sqrt[3]) + 
       (13386788423*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(708588*Sqrt[3]) - 
       (18151*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (932484487*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (29160*Sqrt[3]) - (725459758*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (932484487*CF^2*NC*Pi*Log[3]^2)/(1399680*Sqrt[3]) - 
       (362729879*CF*NC*NH*Pi*Log[3]^2)/(157464*Sqrt[3]) - 
       (CF*NC*(5*CF*(361083679 + 109998000*lm) - 
          CA*(1030339921 + 336105000*lm) + 20*(90*(-28157 + 33950*lm)*NM + 
            21*(199327 + 145500*lm)*NL + 4*(83597 + 763875*lm)*NH))*
         Log[x]^2)/75600 - (CF*NC*(287339*CA + 2911044*CF - 597360*NM - 
          72750*NL)*Log[x]^3)/135 - (18906608117*CF^2*NC*PolyGamma[2, 1])/
        14171760 + (98387*CF*NM*NC*PolyGamma[2, 1])/180 - 
       (2597729696*CF*NC*NH*PolyGamma[2, 1])/1594323 + 
       (CA*CF*NC*(-37714761373679235 + 3357443880806400*lm^2 + 
          487584170879904*Pi^2 + 1791116202629600*Sqrt[3]*Pi^3 + 
          178245743901120*Pi^4 - 288054144*lm*(-16947137 + 217800*Pi^2) - 
          5848781803343808*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          28233742145817600*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          66322474245941760*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          1381718213457120*Sqrt[3]*Pi*Log[3]^2 + 8300757227687680*
           PolyGamma[2, 1] - 35782079329158400*Zeta[3]))/12443939020800 + 
       (115490040323*CF^2*NC*Zeta[3])/14171760 + (273827*CF*NM*NC*Zeta[3])/
        90 - 1006*CF*NC*NL*Zeta[3] - (4786958410*CF*NC*NH*Zeta[3])/
        1594323 - (CF*NC*Log[x]*(-9*CA*(160698062554077 + 68823164894400*lm + 
            10561985280000*lm^2 + 7750678282200*Pi^2 - 36553391890400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 23044331520000*Zeta[3]) + 
          10*(-16*(-4374*NM*(439179737 + 129490830*lm + 24696000*lm^2 - 
                207519900*Pi^2) - 107163*NL*(16532101 + 5285340*lm + 
                1008000*lm^2 + 1791000*Pi^2) - 2*NH*(12668376178641 + 
                283196445210*lm + 54010152000*lm^2 - 7109505628400*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 9*CF*(18635027032311 + 
              9350340390720*lm + 1728324864000*lm^2 + 1064076675480*Pi^2 - 
              7310678378080*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              4608866304000*Zeta[3]))))/185177664000, 
      (63393875687921287*CF^2*NC)/31109847552000 - (711541*CF^2*lm*NC)/2400 - 
       (5551*CF^2*lm^2*NC)/8 - (378506148107*CF*NM*NC)/222264000 - 
       (433991*CF*lm*NM*NC)/21600 - (5551*CF*lm^2*NM*NC)/72 + 
       (1607877829*CF*NC*NL)/1296000 - (433991*CF*lm*NC*NL)/21600 - 
       (5551*CF*lm^2*NC*NL)/72 + (1052022285113919947*CF*NC*NH)/
        21566253693600 - (433991*CF*lm*NC*NH)/21600 - 
       (5551*CF*lm^2*NC*NH)/72 + (126429439*CF^2*NC*Pi^2)/226800 + 
       (49*CF^2*lm*NC*Pi^2)/4 + (5549143*CF*NM*NC*Pi^2)/2160 + 
       (49*CF*lm*NM*NC*Pi^2)/36 - (23135*CF*NC*NL*Pi^2)/144 + 
       (49*CF*lm*NC*NL*Pi^2)/36 + (49*CF*lm*NC*NH*Pi^2)/36 - 
       (110423780299*CF^2*NC*Pi^3)/(68024448*Sqrt[3]) - 
       (8280006595*CF*NC*NH*Pi^3)/(1417176*Sqrt[3]) - 
       (1284521*CF^2*NC*Pi^4)/25920 + (1824813914333*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(283435200*Sqrt[3]) + 
       (7547437991*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(236196*Sqrt[3]) - 
       (91147*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (15774825757*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (262440*Sqrt[3]) - (473143234*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (15774825757*CF^2*NC*Pi*Log[3]^2)/(12597120*Sqrt[3]) - 
       (236571617*CF*NC*NH*Pi*Log[3]^2)/(52488*Sqrt[3]) - 
       (CF*NC*(-440*CA*(127859357 + 49490595*lm) + 
          11*CF*(8826302011 + 3239384400*lm) + 
          60*(198*(-5737339 + 333270*lm)*NM + 693*(128633 + 95220*lm)*NL + 
            20*(429776 + 3299373*lm)*NH))*Log[x]^2)/2494800 - 
       (2*CF*NC*(1132979*CA + 8893735*CF - 3919320*NM - 214245*NL)*
         Log[x]^3)/405 - (10545834041*CF^2*NC*PolyGamma[2, 1])/5314410 + 
       (323603*CF*NM*NC*PolyGamma[2, 1])/72 - 
       (7413354224*CF*NC*NH*PolyGamma[2, 1])/2657205 + 
       (565180410589*CF^2*NC*Zeta[3])/42515280 + (285443*CF*NM*NC*Zeta[3])/
        36 - 1930*CF*NC*NL*Zeta[3] - (3637513438*CF*NC*NH*Zeta[3])/
        2657205 + CF*Log[x]*((232995647*NM*NC)/264600 - 
         (158627*lm*NM*NC)/180 - (490*lm^2*NM*NC)/3 - 
         (32176417*NC*NL)/10800 - (158627*lm*NC*NL)/180 - 
         (490*lm^2*NC*NL)/3 - (66626350888697*NC*NH)/1556006760 - 
         (158627*lm*NC*NH)/180 - (490*lm^2*NC*NH)/3 + (77153*NM*NC*Pi^2)/
          18 - (5741*NC*NL*Pi^2)/18 + (473143234*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
         CF*NC*(-409227686525731/30862944000 - (163527*lm)/20 - 1470*lm^2 - 
           (5170333*Pi^2)/12960 + (15774825757*Im[PolyLog[2, (-1)^(1/3)]])/
            (787320*Sqrt[3]) - 3920*Zeta[3]) + 
         CA*NC*(780893495032297/61725888000 + (2156497*lm)/360 + 
           (2695*lm^2)/3 + (10934417*Pi^2)/25920 - 
           (15774825757*Im[PolyLog[2, (-1)^(1/3)]])/(1574640*Sqrt[3]) + 
           1960*Zeta[3])) + (CA*CF*NC*(1187249000857920000*lm^2 - 
          674271543023114400*Pi^2 + 757507132851140000*Sqrt[3]*Pi^3 + 
          72425939517288000*Pi^4 - 64812182400*lm*(-28088101 + 323400*Pi^2) + 
          584362645342308000*Sqrt[3]*Pi*Log[3]^2 - 
          3*(4509946381710637383 + 1001457876185950400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 3544461593527680000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 9349802325476928000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 926008595472128000*
             PolyGamma[2, 1] + 4265919620984672000*Zeta[3])))/
        2799886279680000, (2083079028800577359*CF^2*NC)/155549237760000 - 
       (16419763*CF^2*lm*NC)/43200 - (15673*CF^2*lm^2*NC)/16 - 
       (25848017431039*CF*NM*NC)/15431472000 - (9366913*CF*lm*NM*NC)/
        388800 - (15673*CF*lm^2*NM*NC)/144 + (46701183749*CF*NC*NL)/
        23328000 - (9366913*CF*lm*NC*NL)/388800 - (15673*CF*lm^2*NC*NL)/
        144 + (4832209923899073703*CF*NC*NH)/66547297111680 - 
       (9366913*CF*lm*NC*NH)/388800 - (15673*CF*lm^2*NC*NH)/144 - 
       (40383384523*CF^2*NC*Pi^2)/10886400 + (1127*CF^2*lm*NC*Pi^2)/72 + 
       (127470427*CF*NM*NC*Pi^2)/38880 + (1127*CF*lm*NM*NC*Pi^2)/648 - 
       (3127271*CF*NC*NL*Pi^2)/12960 + (1127*CF*lm*NC*NL*Pi^2)/648 + 
       (1127*CF*lm*NC*NH*Pi^2)/648 - (87404634317*CF^2*NC*Pi^3)/
        (34012224*Sqrt[3]) - (672981971795*CF*NC*NH*Pi^3)/
        (76527504*Sqrt[3]) - (497441*CF^2*NC*Pi^4)/6480 + 
       (1182030156439*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (141717600*Sqrt[3]) + (651869979901*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(12754584*Sqrt[3]) - 
       11361*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (12486376331*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (131220*Sqrt[3]) - (19228056337*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (12486376331*CF^2*NC*Pi*Log[3]^2)/(6298560*Sqrt[3]) - 
       (19228056337*CF*NC*NH*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (CF*NC*(-99*CA*(19410009033 + 4193327600*lm) + 
          2*(363*CF*(4854111421 + 935701200*lm) + 
            140*(22*(-164739263 + 12253230*lm)*NM + 1089*(329323 + 
                247540*lm)*NL + 10*(3819241 + 26957106*lm)*NH)))*Log[x]^2)/
        29937600 + (CF*NC*(57159*CA - 148181792*CF + 47453800*NM + 
          2722940*NL)*Log[x]^3)/1620 - (756964969531*CF^2*NC*
         PolyGamma[2, 1])/85030560 + (16262627*CF*NM*NC*PolyGamma[2, 1])/
        2160 - (509777934755*CF*NC*NH*PolyGamma[2, 1])/114791256 + 
       (CA*CF*NC*(-6931595222995875867 + 335214440469216000*lm^2 + 
          1079680461713748720*Pi^2 + 239838316565848000*Sqrt[3]*Pi^3 + 
          22272620065516800*Pi^4 - 720135360*lm*(-695475443 + 7438200*Pi^2) - 
          778437779824467840*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          3180950802344448000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          8880870236266828800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          185018129922225600*Sqrt[3]*Pi*Log[3]^2 + 2492534251671676800*
           PolyGamma[2, 1] - 4089195368003961600*Zeta[3]))/559977255936000 + 
       (891924962051*CF^2*NC*Zeta[3])/42515280 + (15162227*CF*NM*NC*Zeta[3])/
        1080 - (27289*CF*NC*NL*Zeta[3])/9 - (191432729759*CF*NC*NH*Zeta[3])/
        57395628 + CF*Log[x]*((-5199732739*NM*NC)/765450 - 
         (157843*lm*NM*NC)/120 - 245*lm^2*NM*NC - (100546753*NC*NL)/
          21600 - (157843*lm*NC*NL)/120 - 245*lm^2*NC*NL - 
         (154844333352509*NC*NH)/2400696144 - (157843*lm*NC*NH)/120 - 
         245*lm^2*NC*NH + (2074219*NM*NC*Pi^2)/324 - (162607*NC*NL*Pi^2)/
          324 + (19228056337*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (177147*Sqrt[3]) + CF*NC*(-1090526103135169/30862944000 - 
           (488229*lm)/40 - 2205*lm^2 - (16580081*Pi^2)/3240 + 
           (12486376331*Im[PolyLog[2, (-1)^(1/3)]])/(393660*Sqrt[3]) - 
           5880*Zeta[3]) + CA*NC*(332199792409649/12345177600 + 
           (2147873*lm)/240 + (2695*lm^2)/2 + (46617*Pi^2)/16 - 
           (12486376331*Im[PolyLog[2, (-1)^(1/3)]])/(787320*Sqrt[3]) + 
           2940*Zeta[3])), (690165200684831009*CF^2*NC)/65622334680000 - 
       (3430349*CF^2*lm*NC)/5400 - 1435*CF^2*lm^2*NC - 
       (781575322744493*CF*NM*NC)/13502538000 - (2138849*CF*lm*NM*NC)/
        48600 - (1435*CF*lm^2*NM*NC)/9 + (5223471089*CF*NC*NL)/1458000 - 
       (2138849*CF*lm*NC*NL)/48600 - (1435*CF*lm^2*NC*NL)/9 + 
       (53513143726040389459297*CF*NC*NH)/426429534283552800 - 
       (2138849*CF*lm*NC*NH)/48600 - (1435*CF*lm^2*NC*NH)/9 - 
       (8537670557*CF^2*NC*Pi^2)/29937600 + (196*CF^2*lm*NC*Pi^2)/9 + 
       (31827827*CF*NM*NC*Pi^2)/1215 + (196*CF*lm*NM*NC*Pi^2)/81 - 
       (312389*CF*NC*NL*Pi^2)/810 + (196*CF*lm*NC*NL*Pi^2)/81 + 
       (196*CF*lm*NC*NH*Pi^2)/81 - (1002397108097*CF^2*NC*Pi^3)/
        (229582512*Sqrt[3]) - (24686711875*CF*NC*NH*Pi^3)/
        (1594323*Sqrt[3]) - (204323*CF^2*NC*Pi^4)/1620 + 
       (31328539868963*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1913187600*Sqrt[3]) + (217005812624*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) - 
       17612*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (143199586871*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (885735*Sqrt[3]) - (11285354000*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (143199586871*CF^2*NC*Pi*Log[3]^2)/(42515280*Sqrt[3]) - 
       (705334625*CF*NC*NH*Pi*Log[3]^2)/(59049*Sqrt[3]) - 
       (CF*NC*(-429*CA*(1059406763 + 346003350*lm) + 
          429*CF*(1865583241 + 566187300*lm) + 
          5*(143*(-2587195817 + 37745820*lm)*NM + 9009*(789639 + 599140*lm)*
             NL + 2*(430747111 + 2698826130*lm)*NH))*Log[x]^2)/6081075 - 
       (CF*NC*(9159411*CA + 121661210*CF - 109417040*NM - 2396560*NL)*
         Log[x]^3)/810 - (2166196874933*CF^2*NC*PolyGamma[2, 1])/215233605 + 
       (25321001*CF*NM*NC*PolyGamma[2, 1])/540 - 
       (679014653251*CF*NC*NH*PolyGamma[2, 1])/95659380 + 
       CA*CF*NC*(-7281507341533601189/524978677440000 + (15785*lm^2)/18 + 
         (214045829*Pi^2)/777600 + (1002397108097*Pi^3)/(459165024*Sqrt[3]) + 
         (42119*Pi^4)/648 + lm*(132013339/97200 - (1078*Pi^2)/81) - 
         (31328539868963*Im[PolyLog[2, (-1)^(1/3)]])/(3826375200*Sqrt[3]) + 
         8806*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (143199586871*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1771470*Sqrt[3]) + (143199586871*Pi*Log[3]^2)/(85030560*Sqrt[3]) + 
         (2166196874933*PolyGamma[2, 1])/430467210 - (9287422871959*Zeta[3])/
          860934420) + (13706047614061*CF^2*NC*Zeta[3])/430467210 + 
       (13795001*CF*NM*NC*Zeta[3])/270 - (47260*CF*NC*NL*Zeta[3])/9 + 
       (79221745949*CF*NC*NH*Zeta[3])/47829690 + 
       CF*Log[x]*((281667122351*NM*NC)/5358150 - (290171*lm*NM*NC)/135 - 
         392*lm^2*NM*NC - (48851*NC*NL)/6 - (290171*lm*NC*NL)/135 - 
         392*lm^2*NC*NL - (671662803492472633*NC*NH)/5916715704900 - 
         (290171*lm*NC*NH)/135 - 392*lm^2*NC*NH + (2618908*NM*NC*Pi^2)/
          81 - (70498*NC*NL*Pi^2)/81 + (11285354000*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(59049*Sqrt[3]) + 
         CF*NC*(-656421718361861/26040609000 - (298991*lm)/15 - 3528*lm^2 - 
           (5665711*Pi^2)/1620 + (143199586871*Im[PolyLog[2, (-1)^(1/3)]])/
            (2657205*Sqrt[3]) - 9408*Zeta[3]) + 
         CA*NC*(2913558238005619/104162436000 + (3932761*lm)/270 + 
           2156*lm^2 + (56479*Pi^2)/24 - (143199586871*
             Im[PolyLog[2, (-1)^(1/3)]])/(5314410*Sqrt[3]) + 4704*Zeta[3])), 
      (206941260725997818503519*CF^2*NC)/1630408779236160000 - 
       (211694789*CF^2*lm*NC)/264600 - 1942*CF^2*lm^2*NC - 
       (1329238361326361191*CF*NM*NC)/17971878078000 - 
       (126052589*CF*lm*NM*NC)/2381400 - (1942*CF*lm^2*NM*NC)/9 + 
       (195652954513*CF*NC*NL)/35721000 - (126052589*CF*lm*NC*NL)/2381400 - 
       (1942*CF*lm^2*NC*NL)/9 + (86116764174135503060827*CF*NC*NH)/
        479733226068996900 - (126052589*CF*lm*NC*NH)/2381400 - 
       (1942*CF*lm^2*NC*NH)/9 - (27651522197623*CF^2*NC*Pi^2)/628689600 + 
       (244*CF^2*lm*NC*Pi^2)/9 + (266968502*CF*NM*NC*Pi^2)/8505 + 
       (244*CF*lm*NM*NC*Pi^2)/81 - (3126437*CF*NC*NL*Pi^2)/5670 + 
       (244*CF*lm*NC*NL*Pi^2)/81 + (244*CF*lm*NC*NH*Pi^2)/81 - 
       (249515717651*CF^2*NC*Pi^3)/(38263752*Sqrt[3]) - 
       (320681445035*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) - 
       (149617*CF^2*NC*Pi^4)/810 + (667828946787517*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(31248730800*Sqrt[3]) + 
       (589575072848*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (4782969*Sqrt[3]) - 25096*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (499031435302*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2066715*Sqrt[3]) - (146597232016*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (249515717651*CF^2*NC*Pi*Log[3]^2)/(49601160*Sqrt[3]) - 
       (9162327001*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) - 
       (CF*NC*(-78*CA*(819518259929 + 80253165300*lm) + 
          117*CF*(1051005021041 + 87548907600*lm) + 
          140*(13*(-33841079059 + 625349340*lm)*NM + 
            9009*(1174541 + 902380*lm)*NL + 5*(277468141 + 1625908284*lm)*
             NH))*Log[x]^2)/170270100 + 
       (CF*NC*(354822879*CA + 14*(-160492239*CF + 73941400*NM + 
            1804760*NL))*Log[x]^3)/5670 - 
       (4105618104875*CF^2*NC*PolyGamma[2, 1])/57395628 + 
       (20769307*CF*NM*NC*PolyGamma[2, 1])/270 - 
       (1531771455517*CF*NC*NH*PolyGamma[2, 1])/143489070 + 
       CA*CF*NC*(-24707059498134150624847/326081755847232000 + 
         (10681*lm^2)/9 + (846115054273*Pi^2)/38102400 + 
         (249515717651*Pi^3)/(76527504*Sqrt[3]) + (153521*Pi^4)/1620 + 
         lm*(8580523279/4762800 - (1342*Pi^2)/81) - 
         (667828946787517*Im[PolyLog[2, (-1)^(1/3)]])/(62497461600*Sqrt[3]) + 
         12548*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (249515717651*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2066715*Sqrt[3]) + (249515717651*Pi*Log[3]^2)/(99202320*Sqrt[3]) + 
         (4105618104875*PolyGamma[2, 1])/114791256 - (4545077408681*Zeta[3])/
          2008846980) + (1968291867056*CF^2*NC*Zeta[3])/100442349 + 
       (13458307*CF*NM*NC*Zeta[3])/135 - (70564*CF*NC*NL*Zeta[3])/9 + 
       (18789149603*CF*NC*NH*Zeta[3])/71744535 + 
       CF*Log[x]*((9356621931529*NM*NC)/1296672300 - (2892343*lm*NM*NC)/
          945 - 560*lm^2*NM*NC - (228950737*NC*NL)/18900 - 
         (2892343*lm*NC*NL)/945 - 560*lm^2*NC*NL - 
         (872966500287016229*NC*NH)/5325044134410 - (2892343*lm*NC*NH)/
          945 - 560*lm^2*NC*NH + (3515116*NM*NC*Pi^2)/81 - 
         (105358*NC*NL*Pi^2)/81 + (146597232016*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-6535843633412907733/29408527764000 - (2980543*lm)/105 - 
           5040*lm^2 - (25596388*Pi^2)/567 + 
           (499031435302*Im[PolyLog[2, (-1)^(1/3)]])/(6200145*Sqrt[3]) - 
           13440*Zeta[3]) + CA*NC*(2290187963656243/17147829600 + 
           (39224573*lm)/1890 + 3080*lm^2 + (657597*Pi^2)/28 - 
           (249515717651*Im[PolyLog[2, (-1)^(1/3)]])/(6200145*Sqrt[3]) + 
           6720*Zeta[3])), (4854787384108951994071*CF^2*NC)/
        73368395065627200 - (35905781*CF^2*lm*NC)/29400 - 2703*CF^2*lm^2*NC - 
       (283048733506158043*CF*NM*NC)/443750076000 - (22661081*CF*lm*NM*NC)/
        264600 - (901*CF*lm^2*NM*NC)/3 + (71983747643*CF*NC*NL)/7938000 - 
       (22661081*CF*lm*NC*NL)/264600 - (901*CF*lm^2*NC*NL)/3 + 
       (166444016607623539688593*CF*NC*NH)/575679871282796280 - 
       (22661081*CF*lm*NC*NH)/264600 - (901*CF*lm^2*NC*NH)/3 - 
       (711339296399*CF^2*NC*Pi^2)/57153600 + 36*CF^2*lm*NC*Pi^2 + 
       (24906254*CF*NM*NC*Pi^2)/105 + 4*CF*lm*NM*NC*Pi^2 - 
       (34721*CF*NC*NL*Pi^2)/42 + 4*CF*lm*NC*NL*Pi^2 + 
       4*CF*lm*NC*NH*Pi^2 - (262751593181*CF^2*NC*Pi^3)/(25509168*Sqrt[3]) - 
       (1569013634405*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (152413*CF^2*NC*Pi^4)/540 + (1518579157232651*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(40176939600*Sqrt[3]) + 
       (13482720103804*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (71744535*Sqrt[3]) - 36764*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (37535941883*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (98415*Sqrt[3]) - (717263375728*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (37535941883*CF^2*NC*Pi*Log[3]^2)/(4723920*Sqrt[3]) - 
       (44828960983*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) - 
       (CF*NC*(-91*CA*(476134187299 + 111925459800*lm) + 
          10*(13*CF*(607714458359 + 128205526680*lm) + 
            378*(130*(-977634335 + 3768534*lm)*NM + 3003*(210947 + 
                163140*lm)*NL + 3*(30406297 + 163303140*lm)*NH)))*Log[x]^2)/
        170270100 - (CF*NC*(5036819*CA + 6*(442081621*CF - 
            2520*(375693*NM + 2719*NL)))*Log[x]^3)/5670 - 
       (132287574862453*CF^2*NC*PolyGamma[2, 1])/1937102445 + 
       (80433989*CF*NM*NC*PolyGamma[2, 1])/180 - 
       (928018834163*CF*NC*NH*PolyGamma[2, 1])/57395628 + 
       (447328999377887*CF^2*NC*Zeta[3])/27119434230 + 
       (40926869*CF*NM*NC*Zeta[3])/90 - 12604*CF*NC*NL*Zeta[3] + 
       (357031013005*CF*NC*NH*Zeta[3])/28697814 + 
       CA*CF*NC*(-747843626844510785093047/14673679013125440000 + 
         (9911*lm^2)/6 + (2752297519667*Pi^2)/419126400 + 
         (262751593181*Pi^3)/(51018336*Sqrt[3]) + (155869*Pi^4)/1080 + 
         lm*(1361826691/529200 - 22*Pi^2) - (1518579157232651*
           Im[PolyLog[2, (-1)^(1/3)]])/(80353879200*Sqrt[3]) + 
         18382*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (37535941883*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (196830*Sqrt[3]) + (37535941883*Pi*Log[3]^2)/(9447840*Sqrt[3]) + 
         (132287574862453*PolyGamma[2, 1])/3874204890 + 
         (35118430183727*Zeta[3])/10847773692) + 
       CF*Log[x]*((2911796293468*NM*NC)/4002075 - (489917*lm*NM*NC)/105 - 
         840*lm^2*NM*NC - (37072501*NC*NL)/1890 - (489917*lm*NC*NL)/105 - 
         840*lm^2*NC*NL - (8538409132724224603*NC*NH)/31950264806460 - 
         (489917*lm*NC*NH)/105 - 840*lm^2*NC*NH + 247180*NM*NC*Pi^2 - 
         (6278*NC*NL*Pi^2)/3 + (717263375728*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(-78932141203467803/2450710647000 - (1513851*lm)/35 - 
           7560*lm^2 - (84675167*Pi^2)/3780 + 
           (37535941883*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
           20160*Zeta[3]) + CA*NC*(124686489942497383/2450710647000 + 
           (6623887*lm)/210 + 4620*lm^2 + (286884187*Pi^2)/22680 - 
           (37535941883*Im[PolyLog[2, (-1)^(1/3)]])/(590490*Sqrt[3]) + 
           10080*Zeta[3])), (494120984879482718872784317*CF^2*NC)/
        418676270023851840000 - (474081473*CF^2*lm*NC)/313600 - 
       (56631*CF^2*lm^2*NC)/16 - (85604453463333581494567*CF*NM*NC)/
        112310659235174400 - (96362291*CF*lm*NM*NC)/940800 - 
       (18877*CF*lm^2*NM*NC)/48 + (320971086673*CF*NC*NL)/24192000 - 
       (96362291*CF*lm*NC*NL)/940800 - (18877*CF*lm^2*NC*NL)/48 + 
       (884989896104583972994842977*CF*NC*NH)/2210610705725937715200 - 
       (96362291*CF*lm*NC*NH)/940800 - (18877*CF*lm^2*NC*NH)/48 - 
       (721954186178723*CF^2*NC*Pi^2)/1676505600 + (351*CF^2*lm*NC*Pi^2)/8 + 
       (7786649467*CF*NM*NC*Pi^2)/30240 + (39*CF*lm*NM*NC*Pi^2)/8 - 
       (318453*CF*NC*NL*Pi^2)/280 + (39*CF*lm*NC*NL*Pi^2)/8 + 
       (39*CF*lm*NC*NH*Pi^2)/8 - (81046327322455*CF^2*NC*Pi^3)/
        (5509980288*Sqrt[3]) - (17509332093715*CF*NC*NH*Pi^3)/
        (344373768*Sqrt[3]) - (569987*CF^2*NC*Pi^4)/1440 + 
       (22134680027336783*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (449981723520*Sqrt[3]) + (467174619933983*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1721868840*Sqrt[3]) - 
       (100875*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (16209265464491*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (29760696*Sqrt[3]) - (1000533262498*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (16209265464491*CF^2*NC*Pi*Log[3]^2)/(1428513408*Sqrt[3]) - 
       (500266631249*CF*NC*NH*Pi*Log[3]^2)/(12754584*Sqrt[3]) - 
       (CF*NC*(-11*CA*(117477212033899 + 3564093733200*lm) + 
          11*CF*(232140812469299 + 5832153381600*lm) + 
          210*((-6604695169201 + 33943749840*lm)*NM + 
            108108*(401833 + 313980*lm)*NL + (6674000617 + 33943749840*lm)*
             NH))*Log[x]^2)/454053600 + 
       (CF*NC*(2788669577*CA - 8239846803*CF + 2520*(1788601*NM + 
            15699*NL))*Log[x]^3)/3780 - (2628318847046627*CF^2*NC*
         PolyGamma[2, 1])/4132485216 + (28690473*CF*NM*NC*PolyGamma[2, 1])/
        40 - (2163708403833307*CF*NC*NH*PolyGamma[2, 1])/92980917360 - 
       (10970602312645529*CF^2*NC*Zeta[3])/36159245640 + 
       (55615069*CF*NM*NC*Zeta[3])/60 - (36135*CF*NC*NL*Zeta[3])/2 + 
       (649072824043613*CF*NC*NH*Zeta[3])/46490458680 + 
       CA*CF*NC*(-1441516873565606905194241813/2344587112133570304000 + 
         (207647*lm^2)/96 + (9648854101561*Pi^2)/44706816 + 
         (81046327322455*Pi^3)/(11019960576*Sqrt[3]) + (581219*Pi^4)/2880 + 
         lm*(2079944667/627200 - (429*Pi^2)/16) - 
         (22134680027336783*Im[PolyLog[2, (-1)^(1/3)]])/
          (899963447040*Sqrt[3]) + (100875*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (16209265464491*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (59521392*Sqrt[3]) + (16209265464491*Pi*Log[3]^2)/
          (2857026816*Sqrt[3]) + (2628318847046627*PolyGamma[2, 1])/
          8264970432 + (12146722556680223*Zeta[3])/72318491280) + 
       CF*Log[x]*((6360414138782801*NM*NC)/15901142400 - 
         (10754249*lm*NM*NC)/1680 - 1155*lm^2*NM*NC - (403972837*NC*NL)/
          14400 - (10754249*lm*NC*NL)/1680 - 1155*lm^2*NC*NL - 
         (1906368630559235505703*NC*NH)/5112042369033600 - 
         (10754249*lm*NC*NH)/1680 - 1155*lm^2*NC*NH + (879691*NM*NC*Pi^2)/
          3 - (6003*NC*NL*Pi^2)/2 + (1000533262498*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(-126911556505764536742637/65062357424064000 - 
           (33232947*lm)/560 - 10395*lm^2 - (4052285099*Pi^2)/10080 + 
           (16209265464491*Im[PolyLog[2, (-1)^(1/3)]])/(89282088*Sqrt[3]) - 
           27720*Zeta[3]) + CA*NC*(16657795113160987161587/
            16265589356016000 + (145462339*lm)/3360 + (12705*lm^2)/2 + 
           (12283694849*Pi^2)/60480 - (16209265464491*
             Im[PolyLog[2, (-1)^(1/3)]])/(178564176*Sqrt[3]) + 
           13860*Zeta[3])), (10816781171267581955022203*CF^2*NC)/
        25185994368622337250 - (40777445*CF^2*lm*NC)/18816 - 
       (37905*CF^2*lm^2*NC)/8 - (15780467947510342915721*CF*NM*NC)/
        2674063315123200 - (25918685*CF*lm*NM*NC)/169344 - 
       (12635*CF*lm^2*NM*NC)/24 + (7351232815091*CF*NC*NL)/355622400 - 
       (25918685*CF*lm*NC*NL)/169344 - (12635*CF*lm^2*NC*NL)/24 + 
       (1105105339847368538601275713583*CF*NC*NH)/
        1810121732871921999129600 - (25918685*CF*lm*NC*NH)/169344 - 
       (12635*CF*lm^2*NC*NH)/24 - (2593659617482613*CF^2*NC*Pi^2)/
        26153487360 + (225*CF^2*lm*NC*Pi^2)/4 + (6353778779*CF*NM*NC*Pi^2)/
        3024 + (25*CF*lm*NM*NC*Pi^2)/4 - (272903*CF*NC*NL*Pi^2)/168 + 
       (25*CF*lm*NC*NL*Pi^2)/4 + (25*CF*lm*NC*NH*Pi^2)/4 - 
       (242293176659825*CF^2*NC*Pi^3)/(11019960576*Sqrt[3]) - 
       (4490005827265*CF*NC*NH*Pi^3)/(57395628*Sqrt[3]) - 
       (990539*CF^2*NC*Pi^4)/1728 + (72497618567262251*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(899963447040*Sqrt[3]) + 
       (799041474976231*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2008846980*Sqrt[3]) - (282965*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        4 - (48458635331965*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (59521392*Sqrt[3]) - (513143523116*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (48458635331965*CF^2*NC*Pi*Log[3]^2)/(2857026816*Sqrt[3]) - 
       (128285880779*CF*NC*NH*Pi*Log[3]^2)/(2125764*Sqrt[3]) + 
       CF*((-2055458303853803*CF*NC)/1089728640 - 216630*CF*lm*NC + 
         CA*(433245162329635/435891456 + 132385*lm)*NC + 
         (604414863275*NM*NC)/24024 - 24070*lm*NM*NC - (183941*NC*NL)/6 - 
         24070*lm*NC*NL - (10331787509*NC*NH)/2042040 - 24070*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(733477847*CA - 6645209646*CF + 
          30240*(1213203*NM + 2407*NL))*Log[x]^3)/4536 - 
       (6449786544327697*CF^2*NC*PolyGamma[2, 1])/11622614670 + 
       (372086849*CF*NM*NC*PolyGamma[2, 1])/90 - 
       (523182224405299*CF*NC*NH*PolyGamma[2, 1])/15496819560 - 
       (113297285530587299*CF^2*NC*Zeta[3])/185961834720 + 
       (196335074*CF*NM*NC*Zeta[3])/45 - 27445*CF*NC*NL*Zeta[3] + 
       (309074470064501*CF*NC*NH*Zeta[3])/7748409780 + 
       CA*CF*NC*(-25736552873593865695183638757/103161832933877093376000 + 
         (138985*lm^2)/48 + (67519364053003*Pi^2)/1341204480 + 
         (242293176659825*Pi^3)/(22039921152*Sqrt[3]) + (1007819*Pi^4)/3456 + 
         lm*(1533241375/338688 - (275*Pi^2)/8) - 
         (72497618567262251*Im[PolyLog[2, (-1)^(1/3)]])/(1799926894080*
           Sqrt[3]) + (282965*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (48458635331965*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (119042784*Sqrt[3]) + (48458635331965*Pi*Log[3]^2)/
          (5714053632*Sqrt[3]) + (6449786544327697*PolyGamma[2, 1])/
          23245229340 + (122122379896239299*Zeta[3])/371923669440) + 
       CF*Log[x]*((40461513870969769*NM*NC)/5194373184 - 
         (1556099*lm*NM*NC)/168 - 1650*lm^2*NM*NC - (9070526299*NC*NL)/
          211680 - (1556099*lm*NC*NL)/168 - 1650*lm^2*NC*NL - 
         (141213869028017837397673*NC*NH)/246230040775118400 - 
         (1556099*lm*NC*NH)/168 - 1650*lm^2*NC*NH + (6045700*NM*NC*Pi^2)/
          3 - (13685*NC*NL*Pi^2)/3 + (513143523116*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(9210848596840412683141/286274372665881600 - (4806897*lm)/56 - 
           14850*lm^2 - (228362809*Pi^2)/1728 + 
           (48458635331965*Im[PolyLog[2, (-1)^(1/3)]])/(178564176*Sqrt[3]) - 
           39600*Zeta[3]) + CA*NC*(4554231363562695545693/81792677904537600 + 
           (20997889*lm)/336 + 9075*lm^2 + (717735299*Pi^2)/10368 - 
           (48458635331965*Im[PolyLog[2, (-1)^(1/3)]])/(357128352*Sqrt[3]) + 
           19800*Zeta[3])), (5097533105856442240125681361543*CF^2*NC)/
        464228248202446920192000 - (4024954141*CF^2*lm*NC)/1524096 - 
       (12085*CF^2*lm^2*NC)/2 - (49768987351004490990041*CF*NM*NC)/
        7775353331665920 - (2490062461*CF*lm*NM*NC)/13716864 - 
       (12085*CF*lm^2*NM*NC)/18 + (1400416357844503*CF*NC*NL)/48009024000 - 
       (2490062461*CF*lm*NC*NL)/13716864 - (12085*CF*lm^2*NC*NL)/18 + 
       (9279104177483700977748677419631*CF*NC*NH)/
        11278450797125052456115200 - (2490062461*CF*lm*NC*NH)/13716864 - 
       (12085*CF*lm^2*NC*NH)/18 - (319207361438965477*CF^2*NC*Pi^2)/
        78460462080 + (2425*CF^2*lm*NC*Pi^2)/36 + 
       (832601525387*CF*NM*NC*Pi^2)/408240 + (2425*CF*lm*NM*NC*Pi^2)/324 - 
       (44228095*CF*NC*NL*Pi^2)/20412 + (2425*CF*lm*NC*NL*Pi^2)/324 + 
       (2425*CF*lm*NC*NH*Pi^2)/324 - (3004917243091355*CF^2*NC*Pi^3)/
        (99179645184*Sqrt[3]) - (493167971893835*CF*NC*NH*Pi^3)/
        (4649045868*Sqrt[3]) - (4026227*CF^2*NC*Pi^4)/5184 + 
       (842448302245595513*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8099671023360*Sqrt[3]) + (90200849114417269*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(162716605380*Sqrt[3]) - 
       (1129645*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (600983448618271*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (535692528*Sqrt[3]) - (56362053930724*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (600983448618271*CF^2*NC*Pi*Log[3]^2)/(25713241344*Sqrt[3]) - 
       (14090513482681*CF*NC*NH*Pi*Log[3]^2)/(172186884*Sqrt[3]) - 
       (CF*NC*(-153*CA*(18141120550209263 + 134104508778240*lm) + 
          34*CF*(162787937540410211 + 987496837367040*lm) + 
          8736*(255*(-1217429353549 + 1674631728*lm)*NM + 
            706860*(762863 + 604124*lm)*NL + (93910823777 + 427031090640*lm)*
             NH))*Log[x]^2)/111152321280 + 
       (CF*NC*(98169460435*CA + 6*(-36466015217*CF + 
            336*(56995679*NM + 151031*NL)))*Log[x]^3)/13608 - 
       (60463922961510859*CF^2*NC*PolyGamma[2, 1])/10331213040 + 
       (2633301623*CF*NM*NC*PolyGamma[2, 1])/405 - 
       (9813861868629629*CF*NC*NH*PolyGamma[2, 1])/209207064060 - 
       (579089893649262547*CF^2*NC*Zeta[3])/144636982560 + 
       (3634143691*CF*NM*NC*Zeta[3])/405 - (1027411*CF*NC*NL*Zeta[3])/27 + 
       (5112635989513471*CF*NC*NH*Zeta[3])/104603532030 + 
       CA*CF*NC*(-2570485783512886303038062782271/464228248202446920192000 + 
         (132935*lm^2)/36 + (24567233501754529*Pi^2)/12070840320 + 
         (3004917243091355*Pi^3)/(198359290368*Sqrt[3]) + 
         (1362769*Pi^4)/3456 + lm*(156321588191/27433728 - 
           (26675*Pi^2)/648) - (842448302245595513*
           Im[PolyLog[2, (-1)^(1/3)]])/(16199342046720*Sqrt[3]) + 
         (1129645*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (600983448618271*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1071385056*Sqrt[3]) + (600983448618271*Pi*Log[3]^2)/
          (51426482688*Sqrt[3]) + (60463922961510859*PolyGamma[2, 1])/
          20662426080 + (588521881541317387*Zeta[3])/289273965120) + 
       CF*Log[x]*((430985954849598361*NM*NC)/89902612800 - 
         (167791555*lm*NM*NC)/13608 - 2200*lm^2*NM*NC - 
         (565096907341*NC*NL)/9525600 - (167791555*lm*NC*NL)/13608 - 
         2200*lm^2*NC*NL - (170484370460883329599487*NC*NH)/
          219171794536094400 - (167791555*lm*NC*NH)/13608 - 
         2200*lm^2*NC*NH + (6303914*NM*NC*Pi^2)/3 - (170831*NC*NL*Pi^2)/
          27 + (56362053930724*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(-6843366836420497014502571/
            368067050570419200 - (172781155*lm)/1512 - 19800*lm^2 - 
           (400500905437*Pi^2)/108864 + (600983448618271*
             Im[PolyLog[2, (-1)^(1/3)]])/(1607077584*Sqrt[3]) - 
           52800*Zeta[3]) + CA*NC*(48406407165381484497830597/
            5152938707985868800 + (2264833505*lm)/27216 + 12100*lm^2 + 
           (401459124517*Pi^2)/217728 - (600983448618271*
             Im[PolyLog[2, (-1)^(1/3)]])/(3214155168*Sqrt[3]) + 
           26400*Zeta[3])), (323764341676212535125970962133*CF^2*NC)/
        120520795206404488896000 - (5509058125*CF^2*lm*NC)/1524096 - 
       (62755*CF^2*lm^2*NC)/8 - (26689248905378784346407913*CF*NM*NC)/
        505397966558284800 - (3516461365*CF*lm*NM*NC)/13716864 - 
       (62755*CF*lm^2*NM*NC)/72 + (415801002022099*CF*NC*NL)/9601804800 - 
       (3516461365*CF*lm*NC*NL)/13716864 - (62755*CF*lm^2*NC*NL)/72 + 
       (4424829339170748869420995180495597*CF*NC*NH)/
        3683756857975273085547340800 - (3516461365*CF*lm*NC*NH)/13716864 - 
       (62755*CF*lm^2*NC*NH)/72 - (9563990822950919*CF^2*NC*Pi^2)/
        15692092416 + (3025*CF^2*lm*NC*Pi^2)/36 + 
       (7662523604633*CF*NM*NC*Pi^2)/408240 + (3025*CF*lm*NM*NC*Pi^2)/324 - 
       (121619861*CF*NC*NL*Pi^2)/40824 + (3025*CF*lm*NC*NL*Pi^2)/324 + 
       (3025*CF*lm*NC*NH*Pi^2)/324 - (38714515445051765*CF^2*NC*Pi^3)/
        (892616806656*Sqrt[3]) - (120799266514325*CF*NC*NH*Pi^3)/
        (774840978*Sqrt[3]) - (5594237*CF^2*NC*Pi^4)/5184 + 
       (35114107861455396589*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (218691117630720*Sqrt[3]) + (8529911326063669*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10847773692*Sqrt[3]) - 
       (1530595*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (7742903089010353*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4821232752*Sqrt[3]) - (27611260917560*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) - 
       (7742903089010353*CF^2*NC*Pi*Log[3]^2)/(231419172096*Sqrt[3]) - 
       (3451407614695*CF*NC*NH*Pi*Log[3]^2)/(28697814*Sqrt[3]) + 
       CF*((-2196083261047481*CF*NC)/251475840 - 442090*CF*lm*NC + 
         CA*(617060744133/137984 + (2431495*lm)/9)*NC + 
         (48675981937379*NM*NC)/216216 - (442090*lm*NM*NC)/9 - 
         (123607*NC*NL)/2 - (442090*lm*NC*NL)/9 - (550707963643*NC*NH)/
          48349224 - (442090*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(17561676919*CA - 69673775778*CF + 
          2016*(469126739*NM + 221045*NL))*Log[x]^3)/13608 - 
       (755160506027608877*CF^2*NC*PolyGamma[2, 1])/156905298045 + 
       (15355646258*CF*NM*NC*PolyGamma[2, 1])/405 - 
       (9164241874591121*CF*NC*NH*PolyGamma[2, 1])/139471376040 - 
       (268748141345101914131*CF^2*NC*Zeta[3])/35146786762080 + 
       (16752449971*CF*NM*NC*Zeta[3])/405 - (1492645*CF*NC*NL*Zeta[3])/27 + 
       (6908052079769479*CF*NC*NH*Zeta[3])/69735688020 + 
       CA*CF*NC*(-678348456667694891242718689649/482083180825617955584000 + 
         (690305*lm^2)/144 + (4368631524264953*Pi^2)/14265538560 + 
         (38714515445051765*Pi^3)/(1785233613312*Sqrt[3]) + 
         (1890559*Pi^4)/3456 - (55*lm*(-3746530961 + 25613280*Pi^2))/
          27433728 - (35114107861455396589*Im[PolyLog[2, (-1)^(1/3)]])/
          (437382235261440*Sqrt[3]) + (1530595*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          24 + (7742903089010353*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9642465504*Sqrt[3]) + (7742903089010353*Pi*Log[3]^2)/
          (462838344192*Sqrt[3]) + (755160506027608877*PolyGamma[2, 1])/
          313810596090 + (271975612520918994491*Zeta[3])/70293573524160) + 
       CF*Log[x]*((9916027145994623683*NM*NC)/129859329600 - 
         (233117071*lm*NM*NC)/13608 - 3025*lm^2*NM*NC - 
         (82456959203*NC*NL)/952560 - (233117071*lm*NC*NL)/13608 - 
         3025*lm^2*NC*NL - (42191070660663153684774533*NC*NH)/
          36923141652847369920 - (233117071*lm*NC*NH)/13608 - 
         3025*lm^2*NC*NH + (52086461*NM*NC*Pi^2)/3 - (248270*NC*NL*Pi^2)/
          27 + (27611260917560*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CF*NC*(1573326440981342949212029/
            1783709552764339200 - (239977771*lm)/1512 - 27225*lm^2 - 
           (81778589251*Pi^2)/108864 + (7742903089010353*
             Im[PolyLog[2, (-1)^(1/3)]])/(14463698256*Sqrt[3]) - 
           72600*Zeta[3]) + CA*NC*(-154574038492597313779639/
            509631300789811200 + (3140586581*lm)/27216 + (33275*lm^2)/2 + 
           (83157099811*Pi^2)/217728 - (7742903089010353*
             Im[PolyLog[2, (-1)^(1/3)]])/(28927396512*Sqrt[3]) + 
           36300*Zeta[3])), (120693873086920442279929822031383667*CF^2*NC)/
        1172958882901005455435980800 - (13241354759*CF^2*lm*NC)/3048192 - 
       (156629*CF^2*lm^2*NC)/16 - (255237055269697270488036007969*CF*NM*NC)/
        4966040419401706444800 - (8268070751*CF*lm*NM*NC)/27433728 - 
       (156629*CF*lm^2*NM*NC)/144 + (1897754643905569*CF*NC*NL)/
        32006016000 - (8268070751*CF*lm*NC*NL)/27433728 - 
       (156629*CF*lm^2*NC*NL)/144 + (15909360118416401091813122147392031879*
         CF*NC*NH)/10056656222272495523544240384000 - 
       (8268070751*CF*lm*NC*NH)/27433728 - (156629*CF*lm^2*NC*NH)/144 - 
       (7522510453939530067*CF^2*NC*Pi^2)/196151155200 + 
       (7139*CF^2*lm*NC*Pi^2)/72 + (1894720318039*CF*NM*NC*Pi^2)/116640 + 
       (7139*CF*lm*NM*NC*Pi^2)/648 - (79076965*CF*NC*NL*Pi^2)/20412 + 
       (7139*CF*lm*NC*NL*Pi^2)/648 + (7139*CF*lm*NC*NH*Pi^2)/648 - 
       (8636730477466241*CF^2*NC*Pi^3)/(148769467776*Sqrt[3]) - 
       (1919321703704545*CF*NC*NH*Pi^3)/(9298091736*Sqrt[3]) - 
       (3684901*CF^2*NC*Pi^4)/2592 + (37395550398134641889*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(182242598025600*Sqrt[3]) + 
       (346505214619470227*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (325433210760*Sqrt[3]) - (993179*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/6 - (8636730477466241*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4017693960*Sqrt[3]) - 
       (109675525925974*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) - (8636730477466241*CF^2*NC*Pi*Log[3]^2)/
        (192849310080*Sqrt[3]) - (54837762962987*CF*NC*NH*Pi*Log[3]^2)/
        (344373768*Sqrt[3]) - 
       (CF*NC*(-171*CA*(7138913296793339953 + 11302295652648000*lm) + 
          38*CF*(64209146268333179419 + 83225995260408000*lm) + 
          840*(57*(-21478985265500281 + 7339153021200*lm)*NM + 
            384107724*(1360379 + 1089100*lm)*NL + 
            (100768468025317 + 418331722208400*lm)*NH))*Log[x]^2)/
        5279735260800 + (CF*NC*(929697024511*CA + 
          120*(-15898529419*CF + 7252275702*NM + 5031642*NL))*Log[x]^3)/
        13608 - (90905806431631855853*CF^2*NC*PolyGamma[2, 1])/
        1673656512480 + (378904665719*CF*NM*NC*PolyGamma[2, 1])/6480 - 
       (55672738561555153*CF*NC*NH*PolyGamma[2, 1])/627621192180 - 
       (115265891981319260761*CF^2*NC*Zeta[3])/2928898896840 + 
       (276535020179*CF*NM*NC*Zeta[3])/3240 - (4025879*CF*NC*NL*Zeta[3])/
        54 + (38719663991813657*CF*NC*NH*Zeta[3])/313810596090 + 
       CA*CF*NC*(-846239982408928533133107162179696297/
          16421424360614076376103731200 + (1722919*lm^2)/288 + 
         (136787319775595821*Pi^2)/7132769280 + (8636730477466241*Pi^3)/
          (297538935552*Sqrt[3]) + (6217651*Pi^4)/8640 + 
         lm*(508704634933/54867456 - (78529*Pi^2)/1296) - 
         (37395550398134641889*Im[PolyLog[2, (-1)^(1/3)]])/
          (364485196051200*Sqrt[3]) + (993179*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          12 + (8636730477466241*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (8035387920*Sqrt[3]) + (8636730477466241*Pi*Log[3]^2)/
          (385698620160*Sqrt[3]) + (90905806431631855853*PolyGamma[2, 1])/
          3347313024960 + (23125242607411885175*Zeta[3])/1171559558736) + 
       CF*Log[x]*((30943428234009947855569*NM*NC)/675528232579200 - 
         (3026957461*lm*NM*NC)/136080 - (7865*lm^2*NM*NC)/2 - 
         (370316767943*NC*NL)/3175200 - (3026957461*lm*NC*NL)/136080 - 
         (7865*lm^2*NC*NL)/2 - (21789515958546883410318192559*NC*NH)/
          14400025244610474268800 - (3026957461*lm*NC*NH)/136080 - 
         (7865*lm^2*NC*NH)/2 + (47911415*NM*NC*Pi^2)/3 - 
         (334895*NC*NL*Pi^2)/27 + (109675525925974*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(-248786622085640077356735238723/1396124331194921328000 - 
           (3116146561*lm)/15120 - (70785*lm^2)/2 - (9336189373207*Pi^2)/
            272160 + (8636730477466241*Im[PolyLog[2, (-1)^(1/3)]])/
            (12053081880*Sqrt[3]) - 94380*Zeta[3]) + 
         CA*NC*(142454866846833631862504439757/1595570664222767232000 + 
           (40788416471*lm)/272160 + (86515*lm^2)/4 + (9340868270311*Pi^2)/
            544320 - (8636730477466241*Im[PolyLog[2, (-1)^(1/3)]])/
            (24106163760*Sqrt[3]) + 47190*Zeta[3])), 
      (65306733693547614098238108130039002089*CF^2*NC)/
        4156673041280438082701256960000 - (1214588597*CF^2*lm*NC)/211680 - 
       12397*CF^2*lm^2*NC - (163641850912830399046897269259*CF*NM*NC)/
        344863918014007392000 - (777222437*CF*lm*NM*NC)/1905120 - 
       (12397*CF*lm^2*NM*NC)/9 + (56441719690261*CF*NC*NL)/666792000 - 
       (777222437*CF*lm*NC*NL)/1905120 - (12397*CF*lm^2*NC*NL)/9 + 
       (37828360691004718236042219603001699129*CF*NC*NH)/
        16970607375084836195980905648000 - (777222437*CF*lm*NC*NH)/1905120 - 
       (12397*CF*lm^2*NC*NH)/9 - (302368016558171723*CF^2*NC*Pi^2)/
        98075577600 + 121*CF^2*lm*NC*Pi^2 + (1926423510173*CF*NM*NC*Pi^2)/
        11340 + (121*CF*lm*NM*NC*Pi^2)/9 - (58576463*CF*NC*NL*Pi^2)/11340 + 
       (121*CF*lm*NC*NL*Pi^2)/9 + (121*CF*lm*NC*NH*Pi^2)/9 - 
       (483595823077104637*CF^2*NC*Pi^3)/(6025163444928*Sqrt[3]) - 
       (9174101596169230*CF*NC*NH*Pi^3)/(31381059609*Sqrt[3]) - 
       (12384889*CF^2*NC*Pi^4)/6480 + (2231302994529469375843*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7380825220036800*Sqrt[3]) + 
       (1612966528617762959*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1098337086315*Sqrt[3]) - (654203*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (483595823077104637*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(162716605380*Sqrt[3]) - 
       (4193875015391648*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) - (483595823077104637*CF^2*NC*Pi*Log[3]^2)/
        (7810397058240*Sqrt[3]) - (262117188461978*CF*NC*NH*Pi*Log[3]^2)/
        (1162261467*Sqrt[3]) - 
       (CF*NC*(-133*CA*(398083135003416257 + 10243983183033600*lm) + 
          10*(19*CF*(551627474353180063 + 11734017100565760*lm) + 
            9072*(19*(-3121778694419557 + 143714691120*lm)*NM + 
              14*(508079*(478157 + 383880*lm)*NL + 2*(24526542581 + 
                  97520683260*lm)*NH))))*Log[x]^2)/2639867630400 + 
       (CF*NC*(127732562305*CA - 344777597798*CF + 
          15120*(696371035*NM + 70378*NL))*Log[x]^3)/17010 - 
       (119985915141586906301*CF^2*NC*PolyGamma[2, 1])/2824295364810 + 
       (74920407769*CF*NM*NC*PolyGamma[2, 1])/216 - 
       (16830979110986267*CF*NC*NH*PolyGamma[2, 1])/139471376040 - 
       (860243127946425269431*CF^2*NC*Zeta[3])/11297181459240 + 
       (41553283177*CF*NM*NC*Zeta[3])/108 - (313456*CF*NC*NL*Zeta[3])/3 + 
       (14910288571866373*CF*NC*NH*Zeta[3])/69735688020 + 
       CA*CF*NC*(-13248251897167263662738999646195947047/
          1662669216512175233080502784000 + (136367*lm^2)/18 + 
         (27536848652549281*Pi^2)/17831923200 + (483595823077104637*Pi^3)/
          (12050326889856*Sqrt[3]) + (12524281*Pi^4)/12960 + 
         lm*(45288204247/3810240 - (1331*Pi^2)/18) - 
         (2231302994529469375843*Im[PolyLog[2, (-1)^(1/3)]])/
          (14761650440073600*Sqrt[3]) + (654203*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          6 + (483595823077104637*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (325433210760*Sqrt[3]) + (483595823077104637*Pi*Log[3]^2)/
          (15620794116480*Sqrt[3]) + (119985915141586906301*PolyGamma[2, 1])/
          5648590729620 + (862143383115407641291*Zeta[3])/22594362918480) + 
       CF*Log[x]*((2914421028657382942681*NM*NC)/4021001384400 - 
         (28268482*lm*NM*NC)/945 - (15730*lm^2*NM*NC)/3 - 
         (130207056101*NC*NL)/793800 - (28268482*lm*NC*NL)/945 - 
         (15730*lm^2*NC*NL)/3 - (52052817939298686452221792043*NC*NH)/
          24300042600280175328600 - (28268482*lm*NC*NH)/945 - 
         (15730*lm^2*NC*NH)/3 + (464178064*NM*NC*Pi^2)/3 - 
         (52162*NC*NL*Pi^2)/3 + (4193875015391648*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CF*NC*(2589529281605512454848171524163/226172141653577255136000 - 
           (29094307*lm)/105 - 47190*lm^2 - (76961288491*Pi^2)/19440 + 
           (483595823077104637*Im[PolyLog[2, (-1)^(1/3)]])/
            (488149816140*Sqrt[3]) - 125840*Zeta[3]) + 
         CA*NC*(-2476837725396752076178472646307/452344283307154510272000 + 
           (190161301*lm)/945 + (86515*lm^2)/3 + (77425781731*Pi^2)/38880 - 
           (483595823077104637*Im[PolyLog[2, (-1)^(1/3)]])/
            (976299632280*Sqrt[3]) + 62920*Zeta[3])), 
      (113843577493198053095799122128164285022477*CF^2*NC)/
        117327655926512447774682804480000 - (58156490683*CF^2*lm*NC)/
        8537760 - 15193*CF^2*lm^2*NC - (977260159562190665858948504203459*CF*
         NM*NC)/2365421613658076701728000 - (36537459403*CF*lm*NM*NC)/
        76839840 - (15193*CF*lm^2*NM*NC)/9 + (54697941309336497*CF*NC*NL)/
        484090992000 - (36537459403*CF*lm*NC*NL)/76839840 - 
       (15193*CF*lm^2*NC*NL)/9 + (879303363043091050932913759754047429613*CF*
         NC*NH)/305470932751527051527656301664000 - 
       (36537459403*CF*lm*NC*NH)/76839840 - (15193*CF*lm^2*NC*NH)/9 - 
       (130337811022317659911*CF^2*NC*Pi^2)/359610451200 + 
       141*CF^2*lm*NC*Pi^2 + (2340474625897*CF*NM*NC*Pi^2)/17820 + 
       (47*CF*lm*NM*NC*Pi^2)/3 - (273421739*CF*NC*NL*Pi^2)/41580 + 
       (47*CF*lm*NC*NL*Pi^2)/3 + (47*CF*lm*NC*NH*Pi^2)/3 - 
       (257421440628992741*CF^2*NC*Pi^3)/(2454696218304*Sqrt[3]) - 
       (107116131138091810*CF*NC*NH*Pi^3)/(282429536481*Sqrt[3]) - 
       (5313307*CF^2*NC*Pi^4)/2160 + (1404197593584275831861*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3675225726849600*Sqrt[3]) + 
       (3838079138254779361*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1977006755367*Sqrt[3]) - 277121*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (257421440628992741*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(66291950340*Sqrt[3]) - 
       (48967374234556256*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (257421440628992741*CF^2*NC*Pi*Log[3]^2)/
        (3182013616320*Sqrt[3]) - (3060460889659766*CF*NC*NH*Pi*Log[3]^2)/
        (10460353203*Sqrt[3]) - 
       (CF*NC*(-(CA*(21069605210236655750737 + 6607249602560006400*lm)) + 
          2*(CF*(21066911809025303471101 + 5405931493003641600*lm) + 
            55440*(7*(-19652014564182131 + 1547771219280*lm)*NM + 
              21339318*(628499 + 507720*lm)*NL + (2815028227463 + 
                10834398534960*lm)*NH)))*Log[x]^2)/9679514644800 + 
       (CF*NC*(40252710159155*CA - 80952611088514*CF + 
          55440*(568840549*NM + 93082*NL))*Log[x]^3)/62370 - 
       (1900554144510911993509*CF^2*NC*PolyGamma[2, 1])/3765727153080 + 
       (94460377517*CF*NM*NC*PolyGamma[2, 1])/180 - 
       (2694984199300447573*CF*NC*NH*PolyGamma[2, 1])/16945772188860 - 
       (105035258261285884303951*CF^2*NC*Zeta[3])/289960990787160 + 
       (71770849277*CF*NM*NC*Zeta[3])/90 - 137644*CF*NC*NL*Zeta[3] + 
       (2254393843989964187*CF*NC*NH*Zeta[3])/8472886094430 + 
       CA*CF*NC*(-178950629820428593833925617529086787418303/
          368744061483324835863288814080000 + (167123*lm^2)/18 + 
         (130340388043424820103*Pi^2)/719220902400 + 
         (257421440628992741*Pi^3)/(4909392436608*Sqrt[3]) + 
         (5367451*Pi^4)/4320 + lm*(201628243723/13970880 - (517*Pi^2)/6) - 
         (1404197593584275831861*Im[PolyLog[2, (-1)^(1/3)]])/
          (7350451453699200*Sqrt[3]) + (277121*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          2 + (257421440628992741*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (132583900680*Sqrt[3]) + (257421440628992741*Pi*Log[3]^2)/
          (6364027232640*Sqrt[3]) + (1900554144510911993509*PolyGamma[2, 1])/
          7531454306160 + (105099196473621539896963*Zeta[3])/
          579921981574320) + CF*Log[x]*((76500478634944382945957*NM*NC)/
          188167972192200 - (43933873*lm*NM*NC)/1155 - (20020*lm^2*NM*NC)/
          3 - (3771457084057*NC*NL)/17463600 - (43933873*lm*NC*NL)/1155 - 
         (20020*lm^2*NC*NL)/3 - (1215616895799967299841333143037*NC*NH)/
          437400766805043155914800 - (43933873*lm*NC*NH)/1155 - 
         (20020*lm^2*NC*NH)/3 + (1137402446*NM*NC*Pi^2)/9 - 
         (68728*NC*NL*Pi^2)/3 + (48967374234556256*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-8076058246815840910838470625525443/
            4752008330721456508704000 - (135655469*lm)/385 - 60060*lm^2 - 
           (161146124965421*Pi^2)/498960 + (257421440628992741*
             Im[PolyLog[2, (-1)^(1/3)]])/(198875851020*Sqrt[3]) - 
           160160*Zeta[3]) + CA*NC*(56553886688495690899983505403790793/
            66528116630100391121856000 + (53743673*lm)/210 + 
           (110110*lm^2)/3 + (161161920470069*Pi^2)/997920 - 
           (257421440628992741*Im[PolyLog[2, (-1)^(1/3)]])/
            (397751702040*Sqrt[3]) + 80080*Zeta[3])), 
      (37627789761470569529792233572244833088817863*CF^2*NC)/
        470425236437351659352590704562560000 - (224029998701*CF^2*lm*NC)/
        25613280 - 18850*CF^2*lm^2*NC - (134116592965959708624505762429351*CF*
         NM*NC)/31123968600764167128000 - (143561610701*CF*lm*NM*NC)/
        230519520 - (18850*CF*lm^2*NM*NC)/9 + (37803433318114529*CF*NC*NL)/
        242045496000 - (143561610701*CF*lm*NC*NL)/230519520 - 
       (18850*CF*lm^2*NC*NL)/9 + 
       (4878752851097369742521115431715228422523727*CF*NC*NH)/
        1238888279595943211978998074115296000 - (143561610701*CF*lm*NC*NH)/
        230519520 - (18850*CF*lm^2*NC*NH)/9 - 
       (10116631428356880949*CF^2*NC*Pi^2)/1078831353600 + 
       169*CF^2*lm*NC*Pi^2 + (64587911526511*CF*NM*NC*Pi^2)/41580 + 
       (169*CF*lm*NM*NC*Pi^2)/9 - (1066404313*CF*NC*NL*Pi^2)/124740 + 
       (169*CF*lm*NC*NL*Pi^2)/9 + (169*CF*lm*NC*NH*Pi^2)/9 - 
       (28013566532814192577*CF^2*NC*Pi^3)/(198830393682624*Sqrt[3]) - 
       (98094656567284685*CF*NC*NH*Pi^3)/(188286357654*Sqrt[3]) - 
       (20860957*CF^2*NC*Pi^4)/6480 + (1452120339450731559264773*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2679239554873358400*Sqrt[3]) + 
       (1230373309972598813*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (470715894135*Sqrt[3]) - (1069991*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (28013566532814192577*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5369647977540*Sqrt[3]) - 
       (22421635786807928*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) - (28013566532814192577*CF^2*NC*Pi*Log[3]^2)/
        (257743102921920*Sqrt[3]) - (2802704473350991*CF*NC*NH*Pi*Log[3]^2)/
        (6973568802*Sqrt[3]) + CF*((-1704759111545037957559*CF*NC)/
          14519271967200 - 1527240*CF*lm*NC + 
         CA*(1715645996133489200827/29038543934400 + (2799940*lm)/3)*NC + 
         (1585961573689186*NM*NC)/85085 - (509080*lm*NM*NC)/3 - 
         (9431851*NC*NL)/45 - (509080*lm*NC*NL)/3 - (91759465236977*NC*NH)/
          2007835830 - (509080*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(6010378066433*CA + 14*(-995210760671*CF + 
            11880*(6321682429*NM + 127270*NL)))*Log[x]^3)/187110 - 
       (638042889503583882271*CF^2*NC*PolyGamma[2, 1])/1694577218886 + 
       (3424271360299*CF*NM*NC*PolyGamma[2, 1])/1080 - 
       (2384884358214794557*CF*NC*NH*PolyGamma[2, 1])/11297181459240 - 
       (170470540570160009040751*CF^2*NC*Zeta[3])/237240810644040 + 
       (1907598386059*CF*NM*NC*Zeta[3])/540 - (561808*CF*NC*NL*Zeta[3])/3 + 
       (2372835746377226243*CF*NC*NH*Zeta[3])/5648590729620 + 
       CA*CF*NC*(-8115627786283229248160549069978423767093/
          201964253058860860514152926720000 + (103675*lm^2)/9 + 
         (778985229909454081*Pi^2)/165974054400 + (28013566532814192577*Pi^3)/
          (397660787365248*Sqrt[3]) + (4211129*Pi^4)/2592 + 
         lm*(758047482701/41912640 - (1859*Pi^2)/18) - 
         (1452120339450731559264773*Im[PolyLog[2, (-1)^(1/3)]])/
          (5358479109746716800*Sqrt[3]) + (1069991*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/6 + (28013566532814192577*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(10739295955080*Sqrt[3]) + 
         (28013566532814192577*Pi*Log[3]^2)/(515486205843840*Sqrt[3]) + 
         (638042889503583882271*PolyGamma[2, 1])/3389154437772 + 
         (170540310408234582250891*Zeta[3])/474481621288080) + 
       CF*Log[x]*((3636108228395968315183327*NM*NC)/534793184125200 - 
         (517738208*lm*NM*NC)/10395 - (26026*lm^2*NM*NC)/3 - 
         (2573100660227*NC*NL)/8731800 - (517738208*lm*NC*NL)/10395 - 
         (26026*lm^2*NC*NL)/3 - (2943302356835767380476010846853*NC*NH)/
          771283352132892764929764 - (517738208*lm*NC*NH)/10395 - 
         (26026*lm^2*NC*NH)/3 + (12643011934*NM*NC*Pi^2)/9 - 
         31174*NC*NL*Pi^2 + (22421635786807928*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3486784401*Sqrt[3]) + 
         CF*NC*(376493912747255800234884068464398859/
            2694388723519065840435168000 - (532768223*lm)/1155 - 78078*lm^2 - 
           (2236253882929*Pi^2)/136080 + (28013566532814192577*
             Im[PolyLog[2, (-1)^(1/3)]])/(16108943932620*Sqrt[3]) - 
           208208*Zeta[3]) + CA*NC*(-374181408310280254076686250283013027/
            5388777447038131680870336000 + (316256434*lm)/945 + 
           (143143*lm^2)/3 + (2242073127409*Pi^2)/272160 - 
           (28013566532814192577*Im[PolyLog[2, (-1)^(1/3)]])/
            (32217887865240*Sqrt[3]) + 104104*Zeta[3])), 
      (3455862972039797970824391458316918892683608663*CF^2*NC)/
        376340189149881327482072563650048000 - (18942779393743*CF^2*lm*NC)/
        1844156160 - (363987*CF^2*lm^2*NC)/16 - 
       (81759115472767293715292959474103189*CF*NM*NC)/
        24330050883340217503488000 - (11950603683223*CF*lm*NM*NC)/
        16597405440 - (40443*CF*lm^2*NM*NC)/16 + 
       (10665822351900824341*CF*NC*NL)/52281827136000 - 
       (11950603683223*CF*lm*NC*NL)/16597405440 - (40443*CF*lm^2*NC*NL)/
        16 + (148648936589602318554362986884229738645817783*CF*NC*NH)/
        29733318710302637087495953778767104000 - 
       (11950603683223*CF*lm*NC*NH)/16597405440 - (40443*CF*lm^2*NC*NH)/
        16 - (616871738754387571643*CF^2*NC*Pi^2)/179805225600 + 
       (14027*CF^2*lm*NC*Pi^2)/72 + (9669202430370883*CF*NM*NC*Pi^2)/
        8981280 + (14027*CF*lm*NM*NC*Pi^2)/648 - 
       (47997314287*CF*NC*NL*Pi^2)/4490640 + (14027*CF*lm*NC*NL*Pi^2)/648 + 
       (14027*CF*lm*NC*NH*Pi^2)/648 - (8965519196741438569*CF^2*NC*Pi^3)/
        (49707598420656*Sqrt[3]) - (3000904723038167435*CF*NC*NH*Pi^3)/
        (4518872583696*Sqrt[3]) - (4387721*CF^2*NC*Pi^4)/1080 + 
       (259263276991981419900797*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (382748507839051200*Sqrt[3]) + (53549095691447802269*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(15816054042936*Sqrt[3]) - 
       (1335698*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (1280788456677348367*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (191773142055*Sqrt[3]) - (85740134943947641*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3486784401*Sqrt[3]) - 
       (1280788456677348367*CF^2*NC*Pi*Log[3]^2)/(9205110818640*Sqrt[3]) - 
       (85740134943947641*CF*NC*NH*Pi*Log[3]^2)/(167365651248*Sqrt[3]) - 
       (CF*NC*(-23*CA*(298927582811472019497823 + 17556915939871908600*lm) + 
          45*(23*CF*(13285349573697989404709 + 638433306904433040*lm) + 
            154*(23*(-27066366431076023773 + 460630091561640*lm)*NM + 
              6380456082*(2039957 + 1660460*lm)*NL + (2934731699426831 + 
                10594492105917720*lm)*NH)))*Log[x]^2)/333943255245600 + 
       (CF*NC*(4569627390020615*CA - 9149468189882168*CF + 
          9240*(332102301658*NM + 11872289*NL))*Log[x]^3)/748440 - 
       (211806723108796405109177*CF^2*NC*PolyGamma[2, 1])/45188725836960 + 
       (3813052617503*CF*NM*NC*PolyGamma[2, 1])/810 - 
       (166283382779433001649*CF*NC*NH*PolyGamma[2, 1])/610047798798960 - 
       (516499176512733487206803*CF^2*NC*Zeta[3])/158160540429360 + 
       (2983308233048*CF*NM*NC*Zeta[3])/405 - (6528743*CF*NC*NL*Zeta[3])/
        27 + (158411873167853312311*CF*NC*NH*Zeta[3])/305023899399480 + 
       CA*CF*NC*(-34560449231386000240909726991597633105895081521/
          7526803782997626549641451273000960000 + (444873*lm^2)/32 + 
         (11862959697692541797*Pi^2)/6915585600 + (8965519196741438569*Pi^3)/
          (99415196841312*Sqrt[3]) + (13275379*Pi^4)/6480 + 
         lm*(65345400018103/3017710080 - (154297*Pi^2)/1296) - 
         (259263276991981419900797*Im[PolyLog[2, (-1)^(1/3)]])/
          (765497015678102400*Sqrt[3]) + (667849*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/3 + (1280788456677348367*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(383546284110*Sqrt[3]) + 
         (1280788456677348367*Pi*Log[3]^2)/(18410221637280*Sqrt[3]) + 
         (211806723108796405109177*PolyGamma[2, 1])/90377451673920 + 
         (516559017313839979072151*Zeta[3])/316321080858720) + 
       CF*Log[x]*((1284764537417003034932800493*NM*NC)/365798537941636800 - 
         (93128063873*lm*NM*NC)/1496880 - (65065*lm^2*NM*NC)/6 - 
         (1434819303372397*NC*NL)/3772137600 - (93128063873*lm*NC*NL)/
          1496880 - (65065*lm^2*NC*NL)/6 - 
         (1125542835333747180385844578470983*NC*NH)/
          231385005639867829478929200 - (93128063873*lm*NC*NH)/1496880 - 
         (65065*lm^2*NC*NH)/6 + (332085662321*NM*NC*Pi^2)/324 - 
         (13043459*NC*NL*Pi^2)/324 + (85740134943947641*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-86974022360817081924841121578415190643/
            5388777447038131680870336000 - (95833466573*lm)/166320 - 
           (195195*lm^2)/2 - (415486511340451*Pi^2)/136080 + 
           (1280788456677348367*Im[PolyLog[2, (-1)^(1/3)]])/
            (575319426165*Sqrt[3]) - 260260*Zeta[3]) + 
         CA*NC*(21744976338195038708803835100135462019/
            2694388723519065840435168000 + (113787502673*lm)/272160 + 
           (715715*lm^2)/12 + (415494062346067*Pi^2)/272160 - 
           (1280788456677348367*Im[PolyLog[2, (-1)^(1/3)]])/
            (1150638852330*Sqrt[3]) + 130130*Zeta[3])), 
      (5043610939351583776239505274577563601229502647*CF^2*NC)/
        19354638299136753984792303273431040000 - (242558230709*CF^2*lm*NC)/
        18817920 - (221949*CF^2*lm^2*NC)/8 - 
       (134468424319951177475151032317027981*CF*NM*NC)/
        3406207123667630450488320 - (155545344749*CF*lm*NM*NC)/169361280 - 
       (24661*CF*lm^2*NM*NC)/8 + (19731446187396968743*CF*NC*NL)/
        71887512312000 - (155545344749*CF*lm*NC*NL)/169361280 - 
       (24661*CF*lm^2*NC*NL)/8 + 
       (459176231420584359688604348285207631374209769*CF*NC*NH)/
        68827126644219067332166559673072000000 - (155545344749*CF*lm*NC*NH)/
        169361280 - (24661*CF*lm^2*NC*NH)/8 + 
       (66814233680205397259*CF^2*NC*Pi^2)/1164452889600 + 
       (8281*CF^2*lm*NC*Pi^2)/36 + (64215241342772507*CF*NM*NC*Pi^2)/
        4490640 + (8281*CF*lm*NM*NC*Pi^2)/324 - (545465284*CF*NC*NL*Pi^2)/
        40095 + (8281*CF*lm*NC*NL*Pi^2)/324 + (8281*CF*lm*NC*NH*Pi^2)/324 - 
       (1693408510043324412149*CF^2*NC*Pi^3)/(7157894172574464*Sqrt[3]) - 
       (669665970467998105*CF*NC*NH*Pi^3)/(753145430616*Sqrt[3]) - 
       (14974141*CF^2*NC*Pi^4)/2880 + (12832722640911672010931863*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(13778946282205843200*Sqrt[3]) + 
       (71914192696034033353*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (16108943932620*Sqrt[3]) - (6742463*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - (241915501434760630307*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27615332455920*Sqrt[3]) - 
       (38266626883885606*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) - (241915501434760630307*CF^2*NC*Pi*Log[3]^2)/
        (1325535957884160*Sqrt[3]) - (19133313441942803*CF*NC*NH*Pi*
         Log[3]^2)/(27894275208*Sqrt[3]) - 
       (CF*NC*(-23*CA*(-5631924282119644368187 + 26739846958115491200*lm) + 
          6*(23*CF*(-1880927266207741573433 + 7292685534031497600*lm) + 
            528*(115*(-179759235629668098319 + 306931209344760*lm)*NM + 
              2900207310*(14925543 + 12170540*lm)*NL + (10078719131691187 + 
                35297089074647400*lm)*NH)))*Log[x]^2)/381649434566400 + 
       (CF*NC*(1347397595099*CA - 4715287054994*CF + 
          2640*(2087446249424*NM + 7910851*NL))*Log[x]^3)/106920 - 
       (381973980168555805665572*CF^2*NC*PolyGamma[2, 1])/114383962274805 + 
       (93871818151367*CF*NM*NC*PolyGamma[2, 1])/3240 - 
       (3602341710900751883*CF*NC*NH*PolyGamma[2, 1])/10167463313316 - 
       (268238382859969110054286201*CF^2*NC*Zeta[3])/40263154720731360 + 
       (52125640602647*CF*NM*NC*Zeta[3])/1620 - (8664422*CF*NC*NL*Zeta[3])/
        27 + (3913810060875753793*CF*NC*NH*Zeta[3])/5083731656658 + 
       CA*CF*NC*(-5055641553911233595490735429580934995797495211/
          38709276598273507969584606546862080000 + (271271*lm^2)/16 - 
         (100748443968547637*Pi^2)/3512678400 + (1693408510043324412149*Pi^3)/
          (14315788345148928*Sqrt[3]) + (135827237*Pi^4)/51840 + 
         lm*(820007382989/30792960 - (91091*Pi^2)/648) - 
         (12832722640911672010931863*Im[PolyLog[2, (-1)^(1/3)]])/
          (27557892564411686400*Sqrt[3]) + 
         (6742463*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (241915501434760630307*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55230664911840*Sqrt[3]) + (241915501434760630307*Pi*Log[3]^2)/
          (2651071915768320*Sqrt[3]) + (190986990084277902832786*
           PolyGamma[2, 1])/114383962274805 + (268258272593335382767978081*
           Zeta[3])/80526309441462720) + CF*Log[x]*
        ((5806829351840325333202892351*NM*NC)/91449634485409200 - 
         (8518228537*lm*NM*NC)/106920 - (41405*lm^2*NM*NC)/3 - 
         (10498750621326241*NC*NL)/20746756800 - (8518228537*lm*NC*NL)/
          106920 - (41405*lm^2*NC*NL)/3 - 
         (6276847572141606354909935886420529*NC*NH)/
          964104190166115956162205000 - (8518228537*lm*NC*NH)/106920 - 
         (41405*lm^2*NC*NH)/3 + (2087435926813*NM*NC*Pi^2)/162 - 
         (8656141*NC*NL*Pi^2)/162 + (38266626883885606*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3486784401*Sqrt[3]) + 
         CF*NC*(11221758735327219562204166070090868297/
            6928428146191883589690432000 - (8764174237*lm)/11880 - 
           124215*lm^2 - (5942967503861*Pi^2)/855360 + 
           (241915501434760630307*Im[PolyLog[2, (-1)^(1/3)]])/
            (82845997367760*Sqrt[3]) - 331240*Zeta[3]) + 
         CA*NC*(-2242385921408154991636365087260208653/
            2771371258476753435876172800 + (10396359337*lm)/19440 + 
           (455455*lm^2)/6 + (6005569335461*Pi^2)/1710720 - 
           (241915501434760630307*Im[PolyLog[2, (-1)^(1/3)]])/
            (165691994735520*Sqrt[3]) + 165620*Zeta[3])), 
      (12686191140252724210375424000376192956128490486221339*CF^2*NC)/
        145778214019655214977551590526755287040000 - 
       (47680404166061*CF^2*lm*NC)/3180228480 - (66087*CF^2*lm^2*NC)/2 - 
       (4092467087630619442933386016254889608809*CF*NM*NC)/
        148011864548800213182469248000 - (30166090869581*CF*lm*NM*NC)/
        28622056320 - (7343*CF*lm^2*NM*NC)/2 + 
       (65767547626745793107*CF*NC*NL)/186907532011200 - 
       (30166090869581*CF*lm*NC*NL)/28622056320 - (7343*CF*lm^2*NC*NL)/2 + 
       (3987283521490495685488698714444014092775449553*CF*NC*NH)/
        477856907844149524620470685730185600000 - 
       (30166090869581*CF*lm*NC*NH)/28622056320 - (7343*CF*lm^2*NC*NH)/2 - 
       (1475134831977668200204993*CF^2*NC*Pi^2)/45413662694400 + 
       (9457*CF^2*lm*NC*Pi^2)/36 + (74355217985806919*CF*NM*NC*Pi^2)/
        8339760 + (9457*CF*lm*NM*NC*Pi^2)/324 - (13966078441*CF*NC*NL*Pi^2)/
        833976 + (9457*CF*lm*NC*NL*Pi^2)/324 + (9457*CF*lm*NC*NH*Pi^2)/
        324 - (9231191981009806754065*CF^2*NC*Pi^3)/(31017541414489344*
         Sqrt[3]) - (22695288730715726545*CF*NC*NH*Pi^3)/
        (20334926626632*Sqrt[3]) - (55746677*CF^2*NC*Pi^4)/8640 + 
       (35750460633553577873163575*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (31048558955903833344*Sqrt[3]) + (635519907729329772331*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(111842096446476*Sqrt[3]) - 
       (8288525*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (263748342314565907259*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (23933288128464*Sqrt[3]) - (1296873641755184374*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (263748342314565907259*CF^2*NC*Pi*Log[3]^2)/(1148797830166272*
         Sqrt[3]) - (648436820877592187*CF*NC*NH*Pi*Log[3]^2)/
        (753145430616*Sqrt[3]) - 
       (CF*NC*(-11*CA*(17581485468712993857481147 + 185018499264489770880*
             lm) + 6*(CF*(64465165752540309385236995 + 555055497793469312640*
               lm) + 144144*(13*(-9442410811323176341 + 32911977492680*lm)*
               NM + 27621022*(18908179 + 15490220*lm)*NL + 
              (125214113147771 + 427855707404840*lm)*NH)))*Log[x]^2)/
        992288529872640 + (CF*NC*(80342512331793509*CA + 
          26*(-6181516294929763*CF + 1320*(1366947945956*NM + 
              10068643*NL)))*Log[x]^3)/1389960 - 
       (26532467308684603931636689*CF^2*NC*PolyGamma[2, 1])/610047798798960 + 
       (68401133339497*CF*NM*NC*PolyGamma[2, 1])/1620 - 
       (102828795476350951453*CF*NC*NH*PolyGamma[2, 1])/228767924549610 - 
       (5090720836730112664272229769*CF^2*NC*Zeta[3])/174473670456502560 + 
       (54733388235757*CF*NM*NC*Zeta[3])/810 - (10995380*CF*NC*NL*Zeta[3])/
        27 + (107956323639462018317*CF*NC*NH*Zeta[3])/114383962274805 + 
       CA*CF*NC*(-88804133030860246991024285590713279484863929579510959/
          2040894996275173009685722267374574018560000 + (80773*lm^2)/4 + 
         (86772688906699095317117*Pi^2)/5342783846400 + 
         (9231191981009806754065*Pi^3)/(62035082828978688*Sqrt[3]) + 
         (168450527*Pi^4)/51840 + lm*(163911756042701/5204010240 - 
           (104027*Pi^2)/648) - (35750460633553577873163575*
           Im[PolyLog[2, (-1)^(1/3)]])/(62097117911807666688*Sqrt[3]) + 
         (8288525*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (263748342314565907259*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (47866576256928*Sqrt[3]) + (263748342314565907259*Pi*Log[3]^2)/
          (2297595660332544*Sqrt[3]) + (26532467308684603931636689*
           PolyGamma[2, 1])/1220095597597920 + (5090829917194249066153107953*
           Zeta[3])/348947340913005120) + CF*Log[x]*
        ((415061086922960783028150086017*NM*NC)/13821959040794704800 - 
         (136216490557*lm*NM*NC)/1389960 - (50960*lm^2*NM*NC)/3 - 
         (13321108004295127*NC*NL)/20746756800 - (136216490557*lm*NC*NL)/
          1389960 - (50960*lm^2*NC*NL)/3 - 
         (24311194815963747821536290417830213*NC*NH)/
          2974950072512586379014804000 - (136216490557*lm*NC*NH)/1389960 - 
         (50960*lm^2*NC*NH)/3 + (1366934692963*NM*NC*Pi^2)/162 - 
         (10985923*NC*NL*Pi^2)/162 + (1296873641755184374*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(-2426940383505768681471134228693932503226969/
            15882266787120527815433700288000 - (140151621757*lm)/154440 - 
           152880*lm^2 - (321379230026106827*Pi^2)/11119680 + 
           (263748342314565907259*Im[PolyLog[2, (-1)^(1/3)]])/
            (71799864385392*Sqrt[3]) - 407680*Zeta[3]) + 
         CA*NC*(1213484293251180644323143136252472483429639/
            15882266787120527815433700288000 + (166266583357*lm)/252720 + 
           (280280*lm^2)/3 + (64276053446077159*Pi^2)/4447872 - 
           (263748342314565907259*Im[PolyLog[2, (-1)^(1/3)]])/
            (143599728770784*Sqrt[3]) + 203840*Zeta[3])), 
      (-6702465829583327746259453271890021262177148069477991*CF^2*NC)/
        5510416489942967126151450121911349850112000 - 
       (1304469025369*CF^2*lm*NC)/70671744 - (317695*CF^2*lm^2*NC)/8 - 
       (2792339876008557807063278927699407215269*CF*NM*NC)/
        7674689272900751794646553600 - (836717781409*CF*lm*NM*NC)/
        636045696 - (317695*CF*lm^2*NM*NC)/72 + 
       (499670706786267745507*CF*NC*NL)/1079910184953600 - 
       (836717781409*CF*lm*NC*NL)/636045696 - (317695*CF*lm^2*NC*NL)/72 + 
       (546932820471529999966275594058069687616395578661*CF*NC*NH)/
        50174975323635700085149422001669488000000 - 
       (836717781409*CF*lm*NC*NH)/636045696 - (317695*CF*lm^2*NC*NH)/72 + 
       (44781197464726597010119*CF^2*NC*Pi^2)/27248197616640 + 
       (1225*CF^2*lm*NC*Pi^2)/4 + (171495729125024119*CF*NM*NC*Pi^2)/
        1297296 + (1225*CF*lm*NM*NC*Pi^2)/36 - (242487077*CF*NC*NL*Pi^2)/
        11583 + (1225*CF*lm*NC*NL*Pi^2)/36 + (1225*CF*lm*NC*NH*Pi^2)/36 - 
       (320329736720550353991005*CF^2*NC*Pi^3)/(837473618191212288*Sqrt[3]) - 
       (89196434062039508155*CF*NC*NH*Pi^3)/(61004779879896*Sqrt[3]) - 
       (42004333*CF^2*NC*Pi^4)/5184 + (1292810689773273073031074291*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(838311091809403500288*Sqrt[3]) + 
       (86392110090725853936197*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (11743420126879980*Sqrt[3]) - (10285555*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - (9152278192015724399743*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(646198779468528*Sqrt[3]) - 
       (5096939089259400466*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) - (9152278192015724399743*CF^2*NC*Pi*Log[3]^2)/
        (31017541414489344*Sqrt[3]) - (2548469544629700233*CF*NC*NH*Pi*
         Log[3]^2)/(2259436291848*Sqrt[3]) + 
       CF*((150427303961480485011665*CF*NC)/7632988691328 - 
         4376385*CF*lm*NC + CA*(-279333918674819534180339/28351100853504 + 
           (5348915*lm)/2)*NC + (2548081984697540486947*NM*NC)/1606268664 - 
         486265*lm*NM*NC - (2370797*NC*NL)/4 - 486265*lm*NC*NL - 
         (17595985709174347*NC*NH)/120470149800 - 486265*lm*NC*NH)*
        Log[x]^2 + (5*CF*NC*(-114526870371785*CA + 227194458921478*CF + 
          185328*(142656955236*NM + 97253*NL))*Log[x]^3)/277992 - 
       (60978565682575281694689791*CF^2*NC*PolyGamma[2, 1])/
        2058911320946490 + (95286100811069*CF*NM*NC*PolyGamma[2, 1])/360 - 
       (87506779992170855969*CF*NC*NH*PolyGamma[2, 1])/152511949699740 - 
       (288709891988027308053972857201*CF^2*NC*Zeta[3])/4710789102325569120 + 
       (52489520148869*CF*NM*NC*Zeta[3])/180 - 529140*CF*NC*NL*Zeta[3] + 
       (101884338451046106331*CF*NC*NH*Zeta[3])/76255974849870 + 
       CA*CF*NC*(6697030485041968696507547851976684456381276302775537/
          11020832979885934252302900243822699700224000 + (3494645*lm^2)/144 - 
         (8956106644319740982759*Pi^2)/10899279046656 + 
         (320329736720550353991005*Pi^3)/(1674947236382424576*Sqrt[3]) + 
         (42286573*Pi^4)/10368 + lm*(4408636371649/115644672 - 
           (13475*Pi^2)/72) - (1292810689773273073031074291*
           Im[PolyLog[2, (-1)^(1/3)]])/(1676622183618807000576*Sqrt[3]) + 
         (10285555*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (9152278192015724399743*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1292397558937056*Sqrt[3]) + (9152278192015724399743*Pi*Log[3]^2)/
          (62035082828978688*Sqrt[3]) + (60978565682575281694689791*
           PolyGamma[2, 1])/4117822641892980 + 
         (288713667237182725759639209281*Zeta[3])/9421578204651138240) + 
       CF*Log[x]*((1272638646477104476857778573339*NM*NC)/
          2150082517456954080 - (3803826341*lm*NM*NC)/30888 - 
         (63700*lm^2*NM*NC)/3 - (5010802291155439*NC*NL)/5993507520 - 
         (3803826341*lm*NC*NL)/30888 - (63700*lm^2*NC*NL)/3 - 
         (3342958329627674197125786822583361581*NC*NH)/
          312369757613821569796554420000 - (3803826341*lm*NC*NH)/30888 - 
         (63700*lm^2*NC*NH)/3 + (2139852532915*NM*NC*Pi^2)/18 - 
         (1586195*NC*NL*Pi^2)/18 + (5096939089259400466*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(1537405712795651332758043198236356890801019/
            85764240650450850203341981555200 - (3913135541*lm)/3432 - 
           191100*lm^2 + (2288136661818655*Pi^2)/2223936 + 
           (9152278192015724399743*Im[PolyLog[2, (-1)^(1/3)]])/
            (1938596338405584*Sqrt[3]) - 509600*Zeta[3]) + 
         CA*NC*(-34936626484392970926174036212822081505937/
            3898374575020493191060999161600 + (4638551141*lm)/5616 + 
           (350350*lm^2)/3 - (2287868570867527*Pi^2)/4447872 - 
           (9152278192015724399743*Im[PolyLog[2, (-1)^(1/3)]])/
            (3877192676811168*Sqrt[3]) + 254800*Zeta[3])), 
      (1325422627956413081041454106951092145624441479024261081933*CF^2*NC)/
        1607204809566698745127506285557477039616000000 - 
       (49143054847309*CF^2*lm*NC)/2308610304 - (748145*CF^2*lm^2*NC)/16 - 
       (508152941715479160651244065308541939698071*CF*NM*NC)/
        2213852674875216863840352000000 - (31151645931829*CF*lm*NM*NC)/
        20777492736 - (748145*CF*lm^2*NM*NC)/144 + 
       (40397915932108918243*CF*NC*NL)/69225011856000 - 
       (31151645931829*CF*lm*NC*NL)/20777492736 - (748145*CF*lm^2*NC*NL)/
        144 + (12151935347397593527339536565265884323142858548487*CF*NC*NH)/
        903149555825442601532689596030050784000000 - 
       (31151645931829*CF*lm*NC*NH)/20777492736 - (748145*CF*lm^2*NC*NH)/
        144 - (9769984700634361447928599*CF^2*NC*Pi^2)/31789563886080 + 
       (2775*CF^2*lm*NC*Pi^2)/8 + (192955489064862947*CF*NM*NC*Pi^2)/
        2594592 + (925*CF*lm*NM*NC*Pi^2)/24 - (10994163655*CF*NC*NL*Pi^2)/
        432432 + (925*CF*lm*NC*NL*Pi^2)/24 + (925*CF*lm*NC*NH*Pi^2)/24 - 
       (33075948389182217888315*CF^2*NC*Pi^3)/(69789468182601024*Sqrt[3]) - 
       (1988149465244120718085*CF*NC*NH*Pi^3)/(1098086037838128*Sqrt[3]) - 
       (2140547*CF^2*NC*Pi^4)/216 + (922853601200291482584156127*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(489014803555485375168*Sqrt[3]) + 
       (1949453118237442669603529*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (211381562283839640*Sqrt[3]) - 1039690*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (6615189677836443577663*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(376949288023308*Sqrt[3]) - 
       (56804270435546306231*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (847288609443*Sqrt[3]) - (6615189677836443577663*CF^2*NC*Pi*Log[3]^2)/
        (18093565825118784*Sqrt[3]) - (56804270435546306231*CF*NC*NH*Pi*
         Log[3]^2)/(40669853253264*Sqrt[3]) - 
       (CF*NC*(-91*CA*(58647071301983983761931411 + 106593115420821229200*
             lm) + 4*(8*CF*(333554965280586338870648266 + 
              496021372327571515425*lm) + 3003*(3*(-71673220389844025361707 + 
                48940824343811400*lm)*NM + 43503109650*(4096861 + 
                3374988*lm)*NL + (45069282624159161 + 146822473031434200*lm)*
               NH)))*Log[x]^2)/2894174878795200 + 
       (CF*NC*(354851442737806571*CA + 28*(-25347529099288975*CF + 
            2574*(2524496067854*NM + 3656237*NL)))*Log[x]^3)/648648 - 
       (4427608477251211220169276457*CF^2*NC*PolyGamma[2, 1])/
        10980860378381280 + (272663433602573*CF*NM*NC*PolyGamma[2, 1])/720 - 
       (17711658269996252918693*CF*NC*NH*PolyGamma[2, 1])/
        24706935851357880 - (1425373189528318466239403823437*CF^2*NC*Zeta[3])/
        5495920619379830640 + (222174770691413*CF*NM*NC*Zeta[3])/360 - 
       661402*CF*NC*NL*Zeta[3] + (20055494270106395727007*CF*NC*NH*Zeta[3])/
        12353467925678940 + CA*CF*NC*
        (-1325424589840118375187058416057228823223826583350058745933/
          3214409619133397490255012571114954079232000000 + 
         (8229595*lm^2)/288 + (9769985654622218440258759*Pi^2)/
          63579127772160 + (33075948389182217888315*Pi^3)/
          (139578936365202048*Sqrt[3]) + (2153867*Pi^4)/432 + 
         lm*(168540586740949/3777725952 - (10175*Pi^2)/48) - 
         (922853601200291482584156127*Im[PolyLog[2, (-1)^(1/3)]])/
          (978029607110970750336*Sqrt[3]) + 519845*Im[PolyLog[2, (-1)^(1/3)]]^
           2 + (6615189677836443577663*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (753898576046616*Sqrt[3]) + (6615189677836443577663*Pi*Log[3]^2)/
          (36187131650237568*Sqrt[3]) + (4427608477251211220169276457*
           PolyGamma[2, 1])/21961720756762560 + 
         (1425378683854662873064944618617*Zeta[3])/10991841238759661280) + 
       CF*Log[x]*((34354468723267258936024815061481*NM*NC)/
          134380157341059630000 - (21545429855*lm*NM*NC)/144144 - 
         (77350*lm^2*NM*NC)/3 - (1605911927916283*NC*NL)/1536796800 - 
         (21545429855*lm*NC*NL)/144144 - (77350*lm^2*NC*NL)/3 - 
         (74510430182504794245429319269801831127*NC*NH)/
          5622655637048788256337979560000 - (21545429855*lm*NC*NH)/144144 - 
         (77350*lm^2*NC*NH)/3 + (2524491535573*NM*NC*Pi^2)/36 - 
         (1321879*NC*NL*Pi^2)/12 + (56804270435546306231*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(-14441250345186966287081452209490912697112901493/
            10005828075885932523723231181440000 - (22164848655*lm)/16016 - 
           232050*lm^2 - (354853201852773629*Pi^2)/1297296 + 
           (6615189677836443577663*Im[PolyLog[2, (-1)^(1/3)]])/
            (1130847864069924*Sqrt[3]) - 618800*Zeta[3]) + 
         CA*NC*(1312843482045434619128959591213543529278893013/
            1819241468342896822495132942080000 + (26275537055*lm)/26208 + 
           (425425*lm^2)/3 + (354853398067760597*Pi^2)/2594592 - 
           (6615189677836443577663*Im[PolyLog[2, (-1)^(1/3)]])/
            (2261695728139848*Sqrt[3]) + 309400*Zeta[3])), 
      (-1551369372519203835480195231242244494772401794405423001*CF^2*NC)/
        39306639364402958440618360244612210208000000 - 
       (5581400094451*CF^2*lm*NC)/216432216 - 55490*CF^2*lm^2*NC - 
       (4504863526362593323244619073658938471733*CF*NM*NC)/
        1338359596976275075796343750 - (3579762816811*CF*lm*NM*NC)/
        1947889944 - (55490*CF*lm^2*NM*NC)/9 + 
       (5281609710133287660299*CF*NC*NL)/7019416202198400 - 
       (3579762816811*CF*lm*NC*NL)/1947889944 - (55490*CF*lm^2*NC*NL)/9 + 
       (1583860317309673975471964107554105476442193643020789*CF*NC*NH)/
        91778810487611331703253193989903785712400000 - 
       (3579762816811*CF*lm*NC*NH)/1947889944 - (55490*CF*lm^2*NC*NH)/9 + 
       (494154553779649240923551*CF^2*NC*Pi^2)/20590967517120 + 
       400*CF^2*lm*NC*Pi^2 + (33112157162351243*CF*NM*NC*Pi^2)/27027 + 
       (400*CF*lm*NM*NC*Pi^2)/9 - (2537334551*CF*NC*NL*Pi^2)/81081 + 
       (400*CF*lm*NC*NL*Pi^2)/9 + (400*CF*lm*NC*NH*Pi^2)/9 - 
       (903704989375541034535*CF^2*NC*Pi^3)/(1509868302027426*Sqrt[3]) - 
       (53253019974110790400*CF*NC*NH*Pi^3)/(22876792454961*Sqrt[3]) - 
       (991852*CF^2*NC*Pi^4)/81 + (29886937077056684585217703*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12091025362635627408*Sqrt[3]) + 
       (269053043842145304259604*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (22899669247415961*Sqrt[3]) - 
       (3814720*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (206561140428695093608*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9320174703873*Sqrt[3]) - (24344237702450647040*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (25820142553586886701*CF^2*NC*Pi*Log[3]^2)/(55921048223238*Sqrt[3]) - 
       (1521514856403165440*CF*NC*NH*Pi*Log[3]^2)/(847288609443*Sqrt[3]) + 
       CF*((6794098624286525279063243*CF*NC)/23593816946700 - 
         7018920*CF*lm*NC + CA*(-6794015003401021168943213/47187633893400 + 
           4289340*lm)*NC + (958403338573817292634*NM*NC)/65189475 - 
         779880*lm*NM*NC - 945550*NC*NL - 779880*lm*NC*NL - 
         (1645146159143747*NC*NH)/6718527585 - 779880*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-8774379552308333*CA + 2*(8767450926423107*CF + 
            130378248*(4106327919*NM + 485*NL)))*Log[x]^3)/243243 - 
       (90119488521764396084837846*CF^2*NC*PolyGamma[2, 1])/343151886824415 + 
       (217574875727111*CF*NM*NC*PolyGamma[2, 1])/90 - 
       (1854539510049753604639*CF*NC*NH*PolyGamma[2, 1])/2058911320946490 - 
       (192806229413763953697616553747*CF^2*NC*Zeta[3])/343495038711239415 + 
       (118530448786631*CF*NM*NC*Zeta[3])/45 - 843880*CF*NC*NL*Zeta[3] + 
       (2283469613505483981761*CF*NC*NH*Zeta[3])/1029455660473245 + 
       CA*CF*NC*(110807818102899793887794263343962237639020116066719009/
          5615234194914708348659765749230315744000000 + (305195*lm^2)/9 - 
         (26008094162494335622727*Pi^2)/2167470264960 + 
         (903704989375541034535*Pi^3)/(3019736604054852*Sqrt[3]) + 
         (498806*Pi^4)/81 + lm*(18864992936971/354161808 - (2200*Pi^2)/9) - 
         (29886937077056684585217703*Im[PolyLog[2, (-1)^(1/3)]])/
          (24182050725271254816*Sqrt[3]) + 
         (1907360*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (103280570214347546804*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9320174703873*Sqrt[3]) + (25820142553586886701*Pi*Log[3]^2)/
          (111842096446476*Sqrt[3]) + (45059744260882198042418923*
           PolyGamma[2, 1])/343151886824415 + (96403331290407991234766837506*
           Zeta[3])/343495038711239415) + CF*Log[x]*
        ((4809738577585570937389951098451*NM*NC)/872598424292595000 - 
         (4994933446*lm*NM*NC)/27027 - (95200*lm^2*NM*NC)/3 - 
         (26017970068560181*NC*NL)/19478899440 - (4994933446*lm*NC*NL)/
          27027 - (95200*lm^2*NC*NL)/3 - 
         (1386687261537399300813579328369391383*NC*NH)/
          81416208518561138491395330750 - (4994933446*lm*NC*NH)/27027 - 
         (95200*lm^2*NC*NH)/3 + (9904461579328*NM*NC*Pi^2)/9 - 
         (1265020*NC*NL*Pi^2)/9 + (24344237702450647040*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(46839567097545519290917950368464114600109171/
            244707751855905958460622501720000 - (5137876246*lm)/3003 - 
           285600*lm^2 + (4386766721613559*Pi^2)/243243 + 
           (206561140428695093608*Im[PolyLog[2, (-1)^(1/3)]])/
            (27960524111619*Sqrt[3]) - 761600*Zeta[3]) + 
         CA*NC*(-46838709724824947521742452940074737963151871/
            489415503711811916921245003440000 + (3043248323*lm)/2457 + 
           (523600*lm^2)/3 - (4386720002080699*Pi^2)/486486 - 
           (103280570214347546804*Im[PolyLog[2, (-1)^(1/3)]])/
            (27960524111619*Sqrt[3]) + 380800*Zeta[3])), 
      (10084528854070431387217515035227111529047735019975981223017*CF^2*NC)/
        1291503864830382920191746122322972621120000000 - 
       (130656496630637*CF^2*lm*NC)/4427022600 - 64684*CF^2*lm^2*NC - 
       (83822580820621263547196094000535501129092601*CF*NM*NC)/
        43709753749567562955447949800000 - (82930241654237*CF*lm*NM*NC)/
        39843203400 - (64684*CF*lm^2*NM*NC)/9 + 
       (295502370294893956341097*CF*NC*NL)/315873729098928000 - 
       (82930241654237*CF*lm*NC*NL)/39843203400 - (64684*CF*lm^2*NC*NL)/9 + 
       (26085792465132777805646069914514571669846290380512983*CF*NC*NH)/
        1239013941582752977993918118863701107117400000 - 
       (82930241654237*CF*lm*NC*NH)/39843203400 - (64684*CF*lm^2*NC*NH)/9 - 
       (3289346856677270641404565207*CF^2*NC*Pi^2)/1132503213441600 + 
       (4048*CF^2*lm*NC*Pi^2)/9 + (151637334188928691*CF*NM*NC*Pi^2)/
        243243 + (4048*CF*lm*NM*NC*Pi^2)/81 - (12457356167*CF*NC*NL*Pi^2)/
        331695 + (4048*CF*lm*NC*NL*Pi^2)/81 + (4048*CF*lm*NC*NH*Pi^2)/81 - 
       (10447424537607119902285*CF^2*NC*Pi^3)/(14275118491895664*Sqrt[3]) - 
       (1759198204573732362160*CF*NC*NH*Pi^3)/(617673396283947*Sqrt[3]) - 
       (2395541*CF^2*NC*Pi^4)/162 + (3745792441907227059729354937*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1250321940908911470600*Sqrt[3]) + 
       (1283698592251992460641764*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (88327295668604421*Sqrt[3]) - 1524424*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (2089484907521423980457*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(77103263459313*Sqrt[3]) - 
       (804204893519420508416*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (2089484907521423980457*CF^2*NC*Pi*Log[3]^2)/(3700956646047024*
         Sqrt[3]) - (50262805844963781776*CF*NC*NH*Pi*Log[3]^2)/
        (22876792454961*Sqrt[3]) - 
       (CF*NC*(-203*CA*(27019659739466718396886656691 + 
            8221159854724897080000*lm) + 
          8*(8497*CF*(161380199694711296146993921 + 40174765036275870000*
               lm) + 100100*(58*(-50693106528916446855289 + 6533025949399950*
                 lm)*NM + 5822723907*(78613091 + 65075300*lm)*NL + 
              4*(30322445295100862 + 94728876266299275*lm)*NH)))*Log[x]^2)/
        314741518068978000 + (2*CF*NC*(3145595661590132640*CA - 
          6291235265036978287*CF + 120120*(11875060067699*NM + 3253765*NL))*
         Log[x]^3)/1216215 - (1537978257957045776874788345*CF^2*NC*
         PolyGamma[2, 1])/411782264189298 + (458529519825247*CF*NM*NC*
         PolyGamma[2, 1])/135 - (30863021059293838729193*CF*NC*NH*
         PolyGamma[2, 1])/27795302832777615 - 
       (182085579165068285925124178081*CF^2*NC*Zeta[3])/79268085856439865 + 
       (758725651004414*CF*NM*NC*Zeta[3])/135 - (9367544*CF*NC*NL*Zeta[3])/
        9 + (74264468644327932833774*CF*NC*NH*Zeta[3])/27795302832777615 + 
       CA*CF*NC*(-17647929709988236993734112040498076229516591523507800321811/
          4520263526906340220671111428130404173920000000 + (355762*lm^2)/9 + 
         (86561760729518826603246653*Pi^2)/59605432286400 + 
         (10447424537607119902285*Pi^3)/(28550236983791328*Sqrt[3]) + 
         (12042473*Pi^4)/1620 + lm*(447385279655837/7244218800 - 
           (22264*Pi^2)/81) - (3745792441907227059729354937*
           Im[PolyLog[2, (-1)^(1/3)]])/(2500643881817822941200*Sqrt[3]) + 
         762212*Im[PolyLog[2, (-1)^(1/3)]]^2 + (2089484907521423980457*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(154206526918626*Sqrt[3]) + 
         (2089484907521423980457*Pi*Log[3]^2)/(7401913292094048*Sqrt[3]) + 
         (1537978257957045776874788345*PolyGamma[2, 1])/823564528378596 + 
         (364171404548761933444588457809*Zeta[3])/317072343425759460) + 
       CF*Log[x]*((2364155811992050485296525871565609*NM*NC)/
          1088479274462583003000 - (24511659502*lm*NM*NC)/110565 - 
         38080*lm^2*NM*NC - (1444139414699623727*NC*NL)/876550474800 - 
         (24511659502*lm*NC*NL)/110565 - 38080*lm^2*NC*NL - 
         (22170290083083520009402851268071150300793*NC*NH)/
          1063947012920556957805554182241000 - (24511659502*lm*NC*NH)/
          110565 - 38080*lm^2*NC*NH + (47500225038496*NM*NC*Pi^2)/81 - 
         (14043220*NC*NL*Pi^2)/81 + (804204893519420508416*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-765670059156043723209714014920643549476817627999/
            56282782926858370445943175395600000 - (25213378702*lm)/12285 - 
           342720*lm^2 - (322625464809114763*Pi^2)/124740 + 
           (2089484907521423980457*Im[PolyLog[2, (-1)^(1/3)]])/
            (231309790377939*Sqrt[3]) - 913920*Zeta[3]) + 
         CA*NC*(191417574892728582021770727706852724453164610381/
            28141391463429185222971587697800000 + (164286333661*lm)/110565 + 
           209440*lm^2 + (322625494458705041*Pi^2)/249480 - 
           (2089484907521423980457*Im[PolyLog[2, (-1)^(1/3)]])/
            (462619580755878*Sqrt[3]) + 456960*Zeta[3])), 
      (-71945326538851851845550392887573098336749961792291831459881*CF^2*NC)/
        122047115226471185958120008559520912695840000000 - 
       (1717311408006451*CF^2*lm*NC)/48697248600 - 75922*CF^2*lm^2*NC - 
       (13642207131718634960880799884207717306358958911*CF*NM*NC)/
        437097537495675629554479498000000 - (1101112656638251*CF*lm*NM*NC)/
        438275237400 - (75922*CF*lm^2*NM*NC)/9 + 
       (53508560093789671418497*CF*NC*NL)/45124818442704000 - 
       (1101112656638251*CF*lm*NC*NL)/438275237400 - (75922*CF*lm^2*NC*NL)/
        9 + (32695993493597493711859757122769755481656857295870140493*CF*NC*
         NH)/1230382144456393132247227155968950656071148780000 - 
       (1101112656638251*CF*lm*NC*NH)/438275237400 - (75922*CF*lm^2*NC*NH)/
        9 + (331618613842521111340212029*CF^2*NC*Pi^2)/1132503213441600 + 
       (4624*CF^2*lm*NC*Pi^2)/9 + (13829214635906342983*CF*NM*NC*Pi^2)/
        1216215 + (4624*CF*lm*NM*NC*Pi^2)/81 - (33281783099*CF*NC*NL*Pi^2)/
        729729 + (4624*CF*lm*NC*NL*Pi^2)/81 + (4624*CF*lm*NC*NH*Pi^2)/81 - 
       (241209884835722624800205*CF^2*NC*Pi^3)/(264981887005813263*Sqrt[3]) - 
       (741708406040928997160*CF*NC*NH*Pi^3)/(205891132094649*Sqrt[3]) - 
       (7296944*CF^2*NC*Pi^4)/405 + (2858959583518514609546223414427*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(742691232899893413536400*Sqrt[3]) + 
       (2687032730989954429736924*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (147212159447674035*Sqrt[3]) - 1840896*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (771871631474312399360656*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22899669247415961*Sqrt[3]) - 
       (339066699904424684416*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (48241976967144524960041*CF^2*NC*Pi*Log[3]^2)/(68699007742247883*
         Sqrt[3]) - (21191668744026542776*CF*NC*NH*Pi*Log[3]^2)/
        (7625597484987*Sqrt[3]) + CF*((9533941083809384993225634779*CF*NC)/
          2713288948870500 - (32776952*CF*lm*NC)/3 + 
         CA*(-733378923762810754959084673/417429069057000 + 
           (180273236*lm)/27)*NC + (18492702084680728909431821*NM*NC)/
          135528918525 - (32776952*lm*NM*NC)/27 - (65926238*NC*NL)/45 - 
         (32776952*lm*NC*NL)/27 - (9658634080006640842*NC*NH)/
          24368099550795 - (32776952*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-571018743844140435*CA + 1141923321149780278*CF + 
          240240*(206695996576739*NM + 4097119*NL))*Log[x]^3)/1216215 - 
       (194143863203484484876036536962*CF^2*NC*PolyGamma[2, 1])/
        83385908498332845 + (1192081521027655*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (25496067981587626980353*CF*NC*NH*PolyGamma[2, 1])/
        18530201888518410 - (427863846533943317618915380418957*CF^2*NC*
         Zeta[3])/83469294406831177845 + (640892385514087*CF*NM*NC*Zeta[3])/
        27 - (11764136*CF*NC*NL*Zeta[3])/9 + 
       (32877585502853239323007*CF*NC*NH*Zeta[3])/9265100944259205 + 
       CA*CF*NC*(5138931837906749630883379525072958517259593587173448759929/
          17435302175210169422588572651360130385120000000 + (417571*lm^2)/9 - 
         (19506973623070743263522071*Pi^2)/133235672169600 + 
         (241209884835722624800205*Pi^3)/(529963774011626526*Sqrt[3]) + 
         (3666968*Pi^4)/405 + lm*(5806630394359051/79686406800 - 
           (25432*Pi^2)/81) - (2858959583518514609546223414427*
           Im[PolyLog[2, (-1)^(1/3)]])/(1485382465799786827072800*Sqrt[3]) + 
         920448*Im[PolyLog[2, (-1)^(1/3)]]^2 + (385935815737156199680328*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22899669247415961*
           Sqrt[3]) + (48241976967144524960041*Pi*Log[3]^2)/
          (137398015484495766*Sqrt[3]) + (97071931601742242438018268481*
           PolyGamma[2, 1])/83385908498332845 + 
         (213932003880837459324747002032732*Zeta[3])/83469294406831177845) + 
       CF*Log[x]*((34893972454602124640918233827503089*NM*NC)/
          680299546539114376875 - (328730483726*lm*NM*NC)/1216215 - 
         46240*lm^2*NM*NC - (1816487372208657569*NC*NL)/876550474800 - 
         (328730483726*lm*NC*NL)/1216215 - 46240*lm^2*NC*NL - 
         (256572950515601530595279773922355640969531*NC*NH)/
          9737648375396716537629881610796200 - (328730483726*lm*NC*NH)/
          1216215 - 46240*lm^2*NC*NH + (826783968239968*NM*NC*Pi^2)/81 - 
         (17636956*NC*NL*Pi^2)/81 + (339066699904424684416*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(215982324252146325272535080370090271248001343993/
            108545367073226857288604695405800000 - (338103447326*lm)/135135 - 
           416160*lm^2 + (6344579255021545*Pi^2)/27027 + 
           (771871631474312399360656*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) - 1109760*Zeta[3]) + 
         CA*NC*(-137442932536638497215917103702039330088674011541/
            138148649002288727458224157789200000 + (200152921063*lm)/110565 + 
           254320*lm^2 - (95168568314865107*Pi^2)/810810 - 
           (385935815737156199680328*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) + 554880*Zeta[3])), 
      (18532818998885465652059962442543455076943122931217756293315901393*CF^2*
         NC)/250991902461841855437794056496076356447016960000000 - 
       (1747142543252461*CF^2*lm*NC)/43589145600 - (1403503*CF^2*lm^2*NC)/
        16 - (111688901590702221546968737109044778392806692627*CF*NM*NC)/
        6939746195924730908776288167936000 - (1109876953491661*CF*lm*NM*NC)/
        392302310400 - (1403503*CF*lm^2*NM*NC)/144 + 
       (919669131899875144244381*CF*NC*NL)/631747458197856000 - 
       (1109876953491661*CF*lm*NC*NL)/392302310400 - 
       (1403503*CF*lm^2*NC*NL)/144 + 
       (181890358003261065668786055089809284698005080410595644461909*CF*NC*
         NH)/5669600921655059553395222734704924623175853578240000 - 
       (1109876953491661*CF*lm*NC*NH)/392302310400 - 
       (1403503*CF*lm^2*NC*NH)/144 - (993365116480132405701484005221*CF^2*NC*
         Pi^2)/36240102830131200 + (41327*CF^2*lm*NC*Pi^2)/72 + 
       (708525847418344058*CF*NM*NC*Pi^2)/135135 + (41327*CF*lm*NM*NC*Pi^2)/
        648 - (88449260951*CF*NC*NL*Pi^2)/1632960 + 
       (41327*CF*lm*NC*NL*Pi^2)/648 + (41327*CF*lm*NC*NH*Pi^2)/648 - 
       (24875870502084695240737375*CF^2*NC*Pi^3)/(22611787691162731776*
         Sqrt[3]) - (32320392336216871341175*CF*NC*NH*Pi^3)/
        (7412080755407364*Sqrt[3]) - (278842177*CF^2*NC*Pi^4)/12960 + 
       (36631047427057003335508017504553*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (7922039817598863077721600*Sqrt[3]) + 
       (127342914736448407982970707*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5707302181663670280*Sqrt[3]) - 
       (4368337*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (4975174100416939048147475*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(122131569319551792*
         Sqrt[3]) - (3693759124139071010420*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (4975174100416939048147475*CF^2*NC*Pi*Log[3]^2)/(5862315327338486016*
         Sqrt[3]) - (923439781034767752605*CF*NC*NH*Pi*Log[3]^2)/
        (274521509459532*Sqrt[3]) + 
       CF*((-72018980219615639499963406391401*CF*NC)/218950621265376000 - 
         (40031498*CF*lm*NC)/3 + CA*(72018981725065188851303569855151/
            437901242530752000 + (220173239*lm)/27)*NC + 
         (1582628651853716259676797811*NM*NC)/25154167278240 - 
         (40031498*lm*NM*NC)/27 - (481544431*NC*NL)/270 - 
         (40031498*lm*NC*NL)/27 - (384059806130352254993*NC*NH)/
          779779185625440 - (40031498*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(86413475282014517445*CA + 4*(-43206789603065849041*CF + 
            10920*(797744029208389*NM + 40031498*NL)))*Log[x]^3)/1769040 - 
       (6149414777551298811486255085051*CF^2*NC*PolyGamma[2, 1])/
        177889938129776736 + (32899617912693533*CF*NM*NC*PolyGamma[2, 1])/
        1080 - (248466290651040181864373*CF*NC*NH*PolyGamma[2, 1])/
        148241615108147280 - (18064634440639043091188512659981059*CF^2*NC*
         Zeta[3])/890339140339532563680 + (27581328963562163*CF*NM*NC*
         Zeta[3])/540 - (28678201*CF*NC*NL*Zeta[3])/18 + 
       (314194383300982772369107*CF*NC*NH*Zeta[3])/74120807554073640 + 
       CA*CF*NC*
        (-18532819698210592351756923295300111803266647025882991126726056893/
          501983804923683710875588112992152712894033920000000 + 
         (15438533*lm^2)/288 + (58433242286366228173460761429*Pi^2)/
          4263541509427200 + (24875870502084695240737375*Pi^3)/
          (45223575382325463552*Sqrt[3]) + (280164641*Pi^4)/25920 + 
         lm*(5976268729846861/71327692800 - (454597*Pi^2)/1296) - 
         (36631047427057003335508017504553*Im[PolyLog[2, (-1)^(1/3)]])/
          (15844079635197726155443200*Sqrt[3]) + 
         (4368337*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (4975174100416939048147475*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (244263138639103584*Sqrt[3]) + (4975174100416939048147475*Pi*
           Log[3]^2)/(11724630654676972032*Sqrt[3]) + 
         (6149414777551298811486255085051*PolyGamma[2, 1])/
          355779876259553472 + (18064636534553375049578558442330731*Zeta[3])/
          1780678280679065127360) + CF*Log[x]*
        ((6169326767975336540869009896375702601*NM*NC)/
          334778905535280386019840 - (87328607249*lm*NM*NC)/272160 - 
         54910*lm^2*NM*NC - (8857282143588523217*NC*NL)/3506201899200 - 
         (87328607249*lm*NC*NL)/272160 - 54910*lm^2*NC*NL - 
         (178873456548745464179643232845822311087686283*NC*NH)/
          5608885464228508725674811807818611200 - (87328607249*lm*NC*NH)/
          272160 - 54910*lm^2*NC*NH + (797743984871675*NM*NC*Pi^2)/162 - 
         (21498319*NC*NL*Pi^2)/81 + (3693759124139071010420*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-37930290853318118499042589591060652106170033566616651/
            296350875807576351934152274482988800000 - (89819324849*lm)/
            30240 - 494190*lm^2 - (633698905016383461517*Pi^2)/25945920 + 
           (4975174100416939048147475*Im[PolyLog[2, (-1)^(1/3)]])/
            (366394707958655376*Sqrt[3]) - 1317840*Zeta[3]) + 
         CA*NC*(75860585480529390877516324657451416779751858627421677/
            1185403503230305407736609097931955200000 + (1169834958139*lm)/
            544320 + 302005*lm^2 + (211232971481776462639*Pi^2)/17297280 - 
           (4975174100416939048147475*Im[PolyLog[2, (-1)^(1/3)]])/
            (732789415917310752*Sqrt[3]) + 658920*Zeta[3])), 
      (-4153245155256208420181725310748951190322580108027632999786702235841*
         CF^2*NC)/571508561905613904831857066641565863629857617920000000 - 
       (1820944684963661*CF^2*lm*NC)/38476838400 - (815745*CF^2*lm^2*NC)/8 - 
       (44379016852230469011177593802998521957156112864227*CF*NM*NC)/
        153145633644635265425155741977600000 - 
       (1167042840367661*CF*lm*NM*NC)/346291545600 - (271915*CF*lm^2*NM*NC)/
        24 + (170138680099164089007631*CF*NC*NL)/93592216029312000 - 
       (1167042840367661*CF*lm*NC*NL)/346291545600 - (271915*CF*lm^2*NC*NL)/
        24 + (242534111641196497851416002444514908524577161900462775624537*CF*
         NC*NH)/6074572416058992378637738644326704953402700262400000 - 
       (1167042840367661*CF*lm*NC*NH)/346291545600 - (271915*CF*lm^2*NC*NH)/
        24 + (7218888805270680082640522629*CF^2*NC*Pi^2)/2196369868492800 + 
       (2601*CF^2*lm*NC*Pi^2)/4 + (12685802458514665871*CF*NM*NC*Pi^2)/
        120120 + (289*CF*lm*NM*NC*Pi^2)/4 - (93698424731*CF*NC*NL*Pi^2)/
        1441440 + (289*CF*lm*NC*NL*Pi^2)/4 + (289*CF*lm*NC*NH*Pi^2)/4 - 
       (549535745014599401193727435*CF^2*NC*Pi^3)/(407012178440929171968*
         Sqrt[3]) - (60447037464646938967505*CF*NC*NH*Pi^3)/
        (11118121133111046*Sqrt[3]) - (223734671*CF^2*NC*Pi^4)/8640 + 
       (833222061860228152092854513839873*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (142596716716779535398988800*Sqrt[3]) + 
       (615837255494674786502874557*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (22258478508488314092*Sqrt[3]) - 
       (10433053*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (109907149002919880238745487*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2198368247751932256*
         Sqrt[3]) - (13816465706205014621144*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (109907149002919880238745487*CF^2*NC*Pi*Log[3]^2)/
        (105521675892092748288*Sqrt[3]) - (1727058213275626827643*CF*NC*NH*
         Pi*Log[3]^2)/(411782264189298*Sqrt[3]) + 
       CF*((397236875327584417159072970057251*CF*NC)/10071728578207296000 - 
         16565004*CF*lm*NC + CA*(-397236789956823748453398708755731/
            20143457156414592000 + 10123058*lm)*NC + 
         (39355804226352296665065145*NM*NC)/31054527504 - 
         1840556*lm*NM*NC - (33182113*NC*NL)/15 - 1840556*lm*NC*NL - 
         (2995092348019107709*NC*NH)/4813451763120 - 1840556*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-17657638923871650927*CA + 
          52*(679130590824082267*CF + 83160*(284316928048689*NM + 
              920278*NL)))*Log[x]^3)/3243240 - 
       (30973858325065937278187584242929*CF^2*NC*PolyGamma[2, 1])/
        1500946352969991210 + (36277755847930351*CF*NM*NC*PolyGamma[2, 1])/
        180 - (456184230145429475459063*CF*NC*NH*PolyGamma[2, 1])/
        222362422662220920 - (2246067730815920113977891167494018309*CF^2*NC*
         Zeta[3])/48078313578334758438720 + (19218741116450221*CF*NM*NC*
         Zeta[3])/90 - 1973207*CF*NC*NL*Zeta[3] + 
       (611553797973834086355937*CF*NC*NH*Zeta[3])/111181211331110460 + 
       CA*CF*NC*
        (4153243212413260345121699249211876209128382000476091458908622946341/
          1143017123811227809663714133283131727259715235840000000 + 
         (2991065*lm^2)/48 - (141546835901804128184360471*Pi^2)/
          86132151705600 + (549535745014599401193727435*Pi^3)/
          (814024356881858343936*Sqrt[3]) + (44946691*Pi^4)/3456 + 
         lm*(6160475108191661/62962099200 - (3179*Pi^2)/8) - 
         (833222061860228152092854513839873*Im[PolyLog[2, (-1)^(1/3)]])/
          (285193433433559070797977600*Sqrt[3]) + 
         (10433053*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (109907149002919880238745487*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4396736495503864512*Sqrt[3]) + (109907149002919880238745487*Pi*
           Log[3]^2)/(211043351784185496576*Sqrt[3]) + 
         (30973858325065937278187584242929*PolyGamma[2, 1])/
          3001892705939982420 + (449213573938338855854877176778040097*
           Zeta[3])/19231325431333903375488) + 
       CF*Log[x]*((172502257130522091241412039279637386353*NM*NC)/
          361643879436259676256000 - (92834880049*lm*NM*NC)/240240 - 
         65892*lm^2*NM*NC - (6357076511788153*NC*NL)/2029052025 - 
         (92834880049*lm*NC*NL)/240240 - 65892*lm^2*NC*NL - 
         (11705431525631964526499510511480304017361222391*NC*NH)/
          294466486871996708097927619910477088000 - (92834880049*lm*NC*NH)/
          240240 - 65892*lm^2*NC*NH + 94772309028569*NM*NC*Pi^2 - 
         (986170*NC*NL*Pi^2)/3 + (13816465706205014621144*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(4974270295412851417313101088894251575702256449792044143/
            245378525168673219401478083271914726400000 - (286419587187*lm)/
            80080 - 593028*lm^2 + (141260896848701730949*Pi^2)/51891840 + 
           (109907149002919880238745487*Im[PolyLog[2, (-1)^(1/3)]])/
            (6595104743255796768*Sqrt[3]) - 1581408*Zeta[3]) + 
         CA*NC*(-4974268388315451074369185484176879476457704689117194843/
            490757050337346438802956166543829452800000 + (112982017969*lm)/
            43680 + 362406*lm^2 - (47086957859943517799*Pi^2)/34594560 - 
           (109907149002919880238745487*Im[PolyLog[2, (-1)^(1/3)]])/
            (13190209486511593536*Sqrt[3]) + 790704*Zeta[3])), 
      (2882804562223770720694571422287427195547714848643184280171504357931099\
5351*CF^2*NC)/41348399521630349322911359404203015276821500146104320000000 - 
       (198140329187055727*CF^2*lm*NC)/3706602099200 - 
       (233769*CF^2*lm^2*NC)/2 - 
       (128827270971897026137629933541585824097335709798073773*CF*NM*NC)/
        950892201302790715864843486770975744000 - 
       (125932940343065327*CF*lm*NM*NC)/33359418892800 - 
       (77923*CF*lm^2*NM*NC)/6 + (42512080983591231764207*CF*NC*NL)/
        19265064410592000 - (125932940343065327*CF*lm*NC*NL)/
        33359418892800 - (77923*CF*lm^2*NC*NL)/6 + 
       (243645731743767186966972368576081094916643416779925427325781*CF*NC*
         NH)/5102640829489553598055700461234432160858268220416000 - 
       (125932940343065327*CF*lm*NC*NH)/33359418892800 - 
       (77923*CF*lm^2*NC*NH)/6 - (35361925519039219759267956884609*CF^2*NC*
         Pi^2)/136907055136051200 + (2889*CF^2*lm*NC*Pi^2)/4 + 
       (406080092049253007189*CF*NM*NC*Pi^2)/9189180 + 
       (321*CF*lm*NM*NC*Pi^2)/4 - (624705690461*CF*NC*NL*Pi^2)/8168160 + 
       (321*CF*lm*NC*NL*Pi^2)/4 + (321*CF*lm*NC*NH*Pi^2)/4 - 
       (11173659587167138366847757185*CF^2*NC*Pi^3)/(6919207033495795923456*
         Sqrt[3]) - (217391854052580804437225*CF*NC*NH*Pi^3)/
        (33354363399333138*Sqrt[3]) - (88179071*CF^2*NC*Pi^4)/2880 + 
       (286852927542722811522995108801833171*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41210451131149285730307763200*
         Sqrt[3]) + (11173253639602770019305743977*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(333877177627324711380*Sqrt[3]) - 
       (12264519*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (2234731917433427673369551437*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37372260211782848352*
         Sqrt[3]) - (49689566640589898157080*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (2234731917433427673369551437*CF^2*NC*Pi*Log[3]^2)/
        (1793868490165576720896*Sqrt[3]) - (6211195830073737269635*CF*NC*NH*
         Pi*Log[3]^2)/(1235346792567894*Sqrt[3]) + 
       CF*((-5483839116868125593715466327981964179*CF*NC)/
          1769266986905081664000 - 20014236*CF*lm*NC + 
         CA*(5483839135200912660696232950615504019/3538533973810163328000 + 
           12230922*lm)*NC + (1209098591922657915122645273*NM*NC)/
          2280056098320 - 2223804*lm*NM*NC - (13325059*NC*NL)/5 - 
         2223804*lm*NC*NL - (33079172140700272541*NC*NH)/43321065868080 - 
         2223804*lm*NC*NH)*Log[x]^2 + 
       ((188114189119352998795*CA*CF*NC)/408408 - 
         (248974712277327697313*CF^2*NC)/270270 + 
         (44*CF*NC*(11308113772771*NM + 101082*NL))/3)*Log[x]^3 - 
       (1279632074901417190952831434087679*CF^2*NC*PolyGamma[2, 1])/
        4002523607919976560 + (1639255288256095*CF*NM*NC*PolyGamma[2, 1])/
        6 - (22268704270068574163752627*CF*NC*NH*PolyGamma[2, 1])/
        9005678117819947260 - (9743080645941760018127404545625321121*CF^2*NC*
         Zeta[3])/54488755388779392897216 + 463492274446552*CF*NM*NC*
        Zeta[3] - 2379807*CF*NC*NL*Zeta[3] + 
       (29356294508158272524496233*CF*NC*NH*Zeta[3])/4502839058909973630 + 
       CA*CF*NC*(-20179632053615916615765429243106597618248756951086053472883\
2310551417644957/
          578877593302824890520759031658842213875501002045460480000000 + 
         (857153*lm^2)/12 + (11787308510641077707202666984251*Pi^2)/
          91271370090700800 + (11173659587167138366847757185*Pi^3)/
          (13838414066991591846912*Sqrt[3]) + (88548863*Pi^4)/5760 + 
         lm*(677334818788082927/6065348889600 - (3531*Pi^2)/8) - 
         (286852927542722811522995108801833171*Im[PolyLog[2, (-1)^(1/3)]])/
          (82420902262298571460615526400*Sqrt[3]) + 
         (12264519*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (2234731917433427673369551437*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74744520423565696704*Sqrt[3]) + (2234731917433427673369551437*Pi*
           Log[3]^2)/(3587736980331153441792*Sqrt[3]) + 
         (1279632074901417190952831434087679*PolyGamma[2, 1])/
          8005047215839953120 + (9743080835618853598758219275380136753*
           Zeta[3])/108977510777558785794432) + 
       CF*Log[x]*((205663993714561919770084535324009869015*NM*NC)/
          1316992805576509448395008 - (1856228154337*lm*NM*NC)/4084080 - 
         77520*lm^2*NM*NC - (35653617125725933*NC*NL)/9434224800 - 
         (1856228154337*lm*NC*NL)/4084080 - 77520*lm^2*NC*NL - 
         (1683773390932709994517416549014697400317508877*NC*NH)/
          35335978424639604971751314389257250560 - (1856228154337*lm*NC*NH)/
          4084080 - 77520*lm^2*NC*NH + 41463083444205*NM*NC*Pi^2 - 
         396474*NC*NL*Pi^2 + (49689566640589898157080*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(-438099907801320845028909243054410072928654918712939316669021/
            364431724152783125941995222401206444108800000 - 
           (5726983403811*lm)/1361360 - 697680*lm^2 - 
           (67721109554247443602387*Pi^2)/294053760 + 
           (2234731917433427673369551437*Im[PolyLog[2, (-1)^(1/3)]])/
            (112116780635348545056*Sqrt[3]) - 1860480*Zeta[3]) + 
         CA*NC*(4819099023021299440734557079252905118813106714522856670142531/
            8017497931361228770723894892826541770393600000 + 
           (2259170912737*lm)/742560 + 426360*lm^2 + 
           (22573703237900665267777*Pi^2)/196035840 - 
           (2234731917433427673369551437*Im[PolyLog[2, (-1)^(1/3)]])/
            (224233561270697090112*Sqrt[3]) + 930240*Zeta[3])), 
      (-237551391407594415306703536227458134575864685280760441620050016596885\
16967*CF^2*NC)/289438796651412445260379515829421106937750501022730240000000 - 
       (694570915883941781*CF^2*lm*NC)/11119806297600 - 
       (1077699*CF^2*lm^2*NC)/8 - 
       (81070017766076996904188530504280001854473061921943976661*CF*NM*NC)/
        30111586374588372669053377081080898560000 - 
       (444908329902332981*CF*lm*NM*NC)/100078256678400 - 
       (359233*CF*lm^2*NM*NC)/24 + (29423365648641817999338007*CF*NC*NL)/
        10819260172988467200 - (444908329902332981*CF*lm*NC*NL)/
        100078256678400 - (359233*CF*lm^2*NC*NL)/24 + 
       (733949340032685096738782126033675618909842690686684752176219*CF*NC*
         NH)/12506472621297925485430638385378510198182029952000000 - 
       (444908329902332981*CF*lm*NC*NH)/100078256678400 - 
       (359233*CF*lm^2*NC*NH)/24 + (2888917167574454655636432199871*CF^2*NC*
         Pi^2)/82144233081630720 + (3249*CF^2*lm*NC*Pi^2)/4 + 
       (1001774032763859062369*CF*NM*NC*Pi^2)/1021020 + 
       (361*CF*lm*NM*NC*Pi^2)/4 - (445137715751*CF*NC*NL*Pi^2)/4900896 + 
       (361*CF*lm*NC*NL*Pi^2)/4 + (361*CF*lm*NC*NH*Pi^2)/4 - 
       (13552118118849558771522821375*CF^2*NC*Pi^3)/(6919207033495795923456*
         Sqrt[3]) - (178419403366645765730455*CF*NC*NH*Pi^3)/
        (22236242266222092*Sqrt[3]) - (314954963*CF^2*NC*Pi^4)/8640 + 
       (357232552311166489901536640390971549*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41210451131149285730307763200*
         Sqrt[3]) + (4565812414704371778429627319*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(111292392542441570460*Sqrt[3]) - 
       (14501161*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (2710423623769911754304564275*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37372260211782848352*
         Sqrt[3]) - (20390788956188087512052*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (2710423623769911754304564275*CF^2*NC*Pi*Log[3]^2)/
        (1793868490165576720896*Sqrt[3]) - (5097697239047021878013*CF*NC*NH*
         Pi*Log[3]^2)/(823564528378596*Sqrt[3]) + 
       CF*((203639077141555958968371406663310107*CF*NC)/
          482527360065022272000 - 24535080*CF*lm*NC + 
         CA*(-320004254507290411144106626515251351/1516514560204355712000 + 
           14993660*lm)*NC + (170017899121572994725434857937*NM*NC)/
          14440355289360 - 2726120*lm*NM*NC - (48969061*NC*NL)/15 - 
         2726120*lm*NC*NL - (754397203407476117*NC*NH)/793426114800 - 
         2726120*lm*NC*NH)*Log[x]^2 + 
       ((-14177417094923028331*CA*CF*NC)/238680 + 
         (1637488447293186029807*CF^2*NC)/13783770 + 3521462800288012*CF*NM*
          NC + (5452240*CF*NC*NL)/3)*Log[x]^3 - 
       (411701641305749106486682374234056*CF^2*NC*PolyGamma[2, 1])/
        2251419529454986815 + (331137585765856499*CF*NM*NC*PolyGamma[2, 1])/
        180 - (3594576412130254461877715*CF*NC*NH*PolyGamma[2, 1])/
        1200757082375992968 - (1042405188540862030827371814287021579587*CF^2*
         NC*Zeta[3])/2451993992495072680374720 + 
       (172671761158798109*CF*NM*NC*Zeta[3])/90 - 2911313*CF*NC*NL*
        Zeta[3] + (4981099787677108332344773*CF*NC*NH*Zeta[3])/
        600378541187996484 + CA*CF*NC*(23755137714724453353138277257312160789\
022361071544320343721967302518487967/
          578877593302824890520759031658842213875501002045460480000000 + 
         (3951563*lm^2)/48 - (253413785821843941325277484019*Pi^2)/
          14411268961689600 + (13552118118849558771522821375*Pi^3)/
          (13838414066991591846912*Sqrt[3]) + (316202579*Pi^4)/17280 + 
         lm*(2351422622852800181/18196046668800 - (3971*Pi^2)/8) - 
         (357232552311166489901536640390971549*Im[PolyLog[2, (-1)^(1/3)]])/
          (82420902262298571460615526400*Sqrt[3]) + 
         (14501161*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (2710423623769911754304564275*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74744520423565696704*Sqrt[3]) + (2710423623769911754304564275*Pi*
           Log[3]^2)/(3587736980331153441792*Sqrt[3]) + 
         (205850820652874553243341187117028*PolyGamma[2, 1])/
          2251419529454986815 + (1042405198907507118611433876974973861619*
           Zeta[3])/4903987984990145360749440) + 
       CF*Log[x]*((184879229880636789103703187172578885834293*NM*NC)/
          41704772176589465865841920 - (2211305231777*lm*NM*NC)/4084080 - 
         92055*lm^2*NM*NC - (20437907887240563373*NC*NL)/4415217206400 - 
         (2211305231777*lm*NC*NL)/4084080 - 92055*lm^2*NC*NL - 
         (86346789363990364099471416956726109446154325117*NC*NH)/
          1472332434359983540489638099552385440000 - 
         (2211305231777*lm*NC*NH)/4084080 - 92055*lm^2*NC*NH + 
         (2641097098859732*NM*NC*Pi^2)/3 - (1455115*NC*NL*Pi^2)/3 + 
         (20390788956188087512052*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CF*NC*(116459099534153389678627612707288694714961228644620288507773/
            572678423668659197908849635201895840742400000 - 
           (6821895687531*lm)/1361360 - 828495*lm^2 + 
           (26199861373746484592321*Pi^2)/882161280 + 
           (2710423623769911754304564275*Im[PolyLog[2, (-1)^(1/3)]])/
            (112116780635348545056*Sqrt[3]) - 2209320*Zeta[3]) + 
         CA*NC*(-815213651826841718370689130065828464928082446969163637788911/
            8017497931361228770723894892826541770393600000 + 
           (2689799757377*lm)/742560 + (1012605*lm^2)/2 - 
           (8733286930161258064651*Pi^2)/588107520 - 
           (2710423623769911754304564275*Im[PolyLog[2, (-1)^(1/3)]])/
            (224233561270697090112*Sqrt[3]) + 1104660*Zeta[3])), 
      (5707218185856996340346711632213305106529790351169376189499395281801570\
743061*CF^2*NC)/
        868316389954237335781138547488263320813251503068190720000000 - 
       (126378685481641539439*CF^2*lm*NC)/1801408620211200 - 
       (2453261*CF^2*lm^2*NC)/16 - 
       (49681848614659059783395806651123762800996983976380797873*CF*NM*NC)/
        43476622038175725244087763699956377600000 - 
       (80344044720933740239*CF*lm*NM*NC)/16212677581900800 - 
       (2453261*CF*lm^2*NM*NC)/144 + (32142846445550723598040487*CF*NC*NL)/
        9835691066353152000 - (80344044720933740239*CF*lm*NC*NL)/
        16212677581900800 - (2453261*CF*lm^2*NC*NL)/144 + 
       (1894698365379851427269269761679614087010828761925193838429553*CF*NC*
         NH)/27227530117829633823617374002634321806951233587200000 - 
       (80344044720933740239*CF*lm*NC*NH)/16212677581900800 - 
       (2453261*CF*lm^2*NC*NH)/144 - (1497160900034157057989185976120323*
         CF^2*NC*Pi^2)/616081748112230400 + (64619*CF^2*lm*NC*Pi^2)/72 + 
       (8811665493622401833921*CF*NM*NC*Pi^2)/23629320 + 
       (64619*CF*lm*NM*NC*Pi^2)/648 - (140228015787127*CF*NC*NL*Pi^2)/
        1323241920 + (64619*CF*lm*NC*NL*Pi^2)/648 + 
       (64619*CF*lm*NC*NH*Pi^2)/648 - (2676497180273571190662817115*CF^2*NC*
         Pi^3)/(1153201172249299320576*Sqrt[3]) - 
       (17174490861070375685699105*CF*NC*NH*Pi^3)/(1801135623563989452*
         Sqrt[3]) - (553652723*CF^2*NC*Pi^4)/12960 + 
       (126684946184272692266072885655539029*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12363135339344785719092328960*
         Sqrt[3]) + (886195941698164304145036367141*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(18029367591875534414520*Sqrt[3]) - 
       (25358825*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (535299436054714238132563423*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6228710035297141392*
         Sqrt[3]) - (1962798955550900078365612*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (535299436054714238132563423*CF^2*NC*Pi*Log[3]^2)/
        (298978081694262786816*Sqrt[3]) - (490699738887725019591403*CF*NC*NH*
         Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) + 
       CF*((-21106906383109832928774945517328188573*CF*NC)/
          723791040097533408000 - 29358116*CF*lm*NC + 
         CA*(232175970335738467770461846933052260993/
            15923402882145734976000 + (161469638*lm)/9)*NC + 
         (498495936435540651294507853553*NM*NC)/111397026517920 - 
         (29358116*lm*NM*NC)/9 - (350652353*NC*NL)/90 - 
         (29358116*lm*NC*NL)/9 - (39119642165671011209*NC*NH)/
          33903442853280 - (29358116*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(478193472448263845455631*CA + 
          32*(-29887093015254522341026*CF + 255255*(18883513954510409*NM + 
              29358116*NL)))*Log[x]^3)/110270160 - 
       (23652138240448011333959473806004861*CF^2*NC*PolyGamma[2, 1])/
        8005047215839953120 + (3175581621140297095*CF*NM*NC*PolyGamma[2, 1])/
        1296 - (144840244333793477031341083*CF*NC*NH*PolyGamma[2, 1])/
        40525551530189762670 - (42848418858309507122530334877924407221*CF^2*
         NC*Zeta[3])/27244377694389696448608 + 
       (2722377298275337195*CF*NM*NC*Zeta[3])/648 - 
       (187812245*CF*NC*NL*Zeta[3])/54 + (197806102875060549682058432*CF*NC*
         NH*Zeta[3])/20262775765094881335 + 
       CA*CF*NC*(-57072181909463433395324687615006237697584782592807019614264\
74466949460171561/
          1736632779908474671562277094976526641626503006136381440000000 + 
         (26985871*lm^2)/288 + (78797942111329732382395663968097*Pi^2)/
          64850710327603200 + (2676497180273571190662817115*Pi^3)/
          (2306402344498598641152*Sqrt[3]) + (185240177*Pi^4)/8640 + 
         lm*(431881301439066025039/2947759560345600 - (710809*Pi^2)/1296) - 
         (126684946184272692266072885655539029*Im[PolyLog[2, (-1)^(1/3)]])/
          (24726270678689571438184657920*Sqrt[3]) + 
         (25358825*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (535299436054714238132563423*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (12457420070594282784*Sqrt[3]) + (535299436054714238132563423*Pi*
           Log[3]^2)/(597956163388525573632*Sqrt[3]) + 
         (23652138240448011333959473806004861*PolyGamma[2, 1])/
          16010094431679906240 + (214242094979203641240980084048120336993*
           Zeta[3])/272443776943896964486080) + 
       CF*Log[x]*((74405274193366113659211319650086895148297529*NM*NC)/
          56301442438395778918886592000 - (139282398828841*lm*NM*NC)/
          220540320 - (214795*lm^2*NM*NC)/2 - (10898389201606481503*NC*NL)/
          1970427513600 - (139282398828841*lm*NC*NL)/220540320 - 
         (214795*lm^2*NC*NL)/2 - 
         (11118401603815675617389432621701874078307714079*NC*NH)/
          159543715295195540842355432861194944000 - 
         (139282398828841*lm*NC*NH)/220540320 - (214795*lm^2*NC*NH)/2 + 
         (6294504641736811*NM*NC*Pi^2)/18 - (31291271*NC*NL*Pi^2)/54 + 
         (1962798955550900078365612*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*(-188298060131117159183414557376295344245235568555397899721912\
9/167031206903358932723414476933886286883200000 - (143229978665041*lm)/
            24504480 - (1933155*lm^2)/2 - (106265216460285854341751*Pi^2)/
            49008960 + (535299436054714238132563423*Im[PolyLog[2, (-1)^
                (1/3)]])/(18686130105891424176*Sqrt[3]) - 2577540*Zeta[3]) + 
         CA*NC*(7531922414105612571597079193502147844683823752479539435523491/
            1336249655226871461787315815471090295065600000 + 
           (169427553941641*lm)/40098240 + (2362745*lm^2)/4 + 
           (191277389698363162824515*Pi^2)/176432256 - 
           (535299436054714238132563423*Im[PolyLog[2, (-1)^(1/3)]])/
            (37372260211782848352*Sqrt[3]) + 1288770*Zeta[3])), 
      (-310124018640977865324530241963258393984824208554865248616788264446639\
0869443*CF^2*NC)/
        3516681379314661209913611117327466449293668587426172416000000 - 
       (731606821872935693*CF^2*lm*NC)/9007043101056 - 175370*CF^2*lm^2*NC - 
       (1955879555588370226444303312168697964207361683373763227997*CF*NM*NC)/
        78174310780181352121580882806652332800000 - 
       (468345963767570573*CF*lm*NM*NC)/81063387909504 - 
       (175370*CF*lm^2*NM*NC)/9 + (610115313367046019483383*CF*NC*NL)/
        153272852450669952 - (468345963767570573*CF*lm*NC*NL)/
        81063387909504 - (175370*CF*lm^2*NC*NL)/9 + 
       (1537031199516494617222641265754192835065452788539726254363397141153*
         CF*NC*NH)/
        18173254636134447075162801243485697110903005793113944000000 - 
       (468345963767570573*CF*lm*NC*NH)/81063387909504 - 
       (175370*CF*lm^2*NC*NH)/9 + (517055002147205583112628257272931*CF^2*NC*
         Pi^2)/1416988020658129920 + (9025*CF^2*lm*NC*Pi^2)/9 + 
       (37691318531811112939154*CF*NM*NC*Pi^2)/4135131 + 
       (9025*CF*lm*NM*NC*Pi^2)/81 - (4124658520051*CF*NC*NL*Pi^2)/
        33081048 + (9025*CF*lm*NC*NL*Pi^2)/81 + (9025*CF*lm*NC*NH*Pi^2)/
        81 - (1170856104747560843095610703865*CF^2*NC*Pi^3)/
        (420341827284869602349952*Sqrt[3]) - (1742106407635934464881400*CF*NC*
         NH*Pi^3)/(150094635296999121*Sqrt[3]) - (65285501*CF^2*NC*Pi^4)/
        1296 + (6307578328953131238057141199883631451*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(500706981243463821623239322880*
         Sqrt[3]) + (152326943678282496794279064889*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2554160408849034042057*Sqrt[3]) - 
       (14859235*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (234171220949512168619122140773*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2270364807865808037384*
         Sqrt[3]) - (796391500633570041088640*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (234171220949512168619122140773*CF^2*NC*Pi*Log[3]^2)/
        (108977510777558785794432*Sqrt[3]) - (49774468789598127568040*CF*NC*
         NH*Pi*Log[3]^2)/(5559060566555523*Sqrt[3]) + 
       CF*((3486243262549207984317757648120541803*CF*NC)/
          796170144107286748800 - 35588900*CF*lm*NC + 
         CA*(-3486243247898003434178845550005116763/1592340288214573497600 + 
           (195738950*lm)/9)*NC + (10661417619426956445588028898689*NM*NC)/
          97472398203180 - (35588900*lm*NM*NC)/9 - 4720056*NC*NL - 
         (35588900*lm*NC*NL)/9 - (6394774470673810741483*NC*NH)/
          4508098416897075 - (35588900*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-860443540110410332646*CA + 21*(81946980418216691829*CF + 
            97240*(22082681795823754*NM + 1779445*NL)))*Log[x]^3)/1378377 - 
       (196954518705883226690380408514271967*CF^2*NC*PolyGamma[2, 1])/
        121576654590569288010 + (54395609516639069893*CF*NM*NC*
         PolyGamma[2, 1])/3240 - (231506573389804550348314913*CF*NC*NH*
         PolyGamma[2, 1])/54034068706919683560 - 
       (63957036564810905824748538240465923283349*CF^2*NC*Zeta[3])/
        16550959449341740592529360 + (27896391398271035893*CF*NM*NC*Zeta[3])/
        1620 - (113625700*CF*NC*NL*Zeta[3])/27 + 
       (330106766176001455872538687*CF*NC*NH*Zeta[3])/27017034353459841780 + 
       CA*CF*NC*(310124016173531014263563752734354635332118815065784078864589\
3434780329457943/
          7033362758629322419827222234654932898587337174852344832000000 + 
         (964535*lm^2)/9 - (1183192224089791201728682472471*Pi^2)/
          6485071032760320 + (1170856104747560843095610703865*Pi^3)/
          (840683654569739204699904*Sqrt[3]) + (21838847*Pi^4)/864 + 
         lm*(2478701607481267853/14738797801728 - (99275*Pi^2)/162) - 
         (6307578328953131238057141199883631451*Im[PolyLog[2, (-1)^(1/3)]])/
          (1001413962486927643246478645760*Sqrt[3]) + 
         (14859235*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (234171220949512168619122140773*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4540729615731616074768*Sqrt[3]) + 
         (234171220949512168619122140773*Pi*Log[3]^2)/
          (217955021555117571588864*Sqrt[3]) + 
         (196954518705883226690380408514271967*PolyGamma[2, 1])/
          243153309181138576020 + (63957036665270385461621480559154973177149*
           Zeta[3])/33101918898683481185058720) + 
       CF*Log[x]*((289762856379425846019819207559146858816956569*NM*NC)/
          7037680304799472364860824000 - (4108264104013*lm*NM*NC)/5513508 - 
         126350*lm^2*NM*NC - (678894605783380092917*NC*NL)/
          101329234886880 - (4108264104013*lm*NC*NL)/5513508 - 
         126350*lm^2*NC*NL - 
         (18028495062013707429659387605449764719510530848161*NC*NH)/
          212585249106437779715306613569354777416875 - 
         (4108264104013*lm*NC*NH)/5513508 - 126350*lm^2*NC*NH + 
         (73608939313790920*NM*NC*Pi^2)/9 - (18931600*NC*NL*Pi^2)/27 + 
         (796391500633570041088640*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CF*NC*(9816361940054261912942178205764745904329935964030130208962456\
9/48706299933019464782147661473921241255141120000 - (4224369393313*lm)/
            612612 - 1137150*lm^2 + (13767096247851334587041*Pi^2)/44108064 + 
           (234171220949512168619122140773*Im[PolyLog[2, (-1)^(1/3)]])/
            (6811094423597424112152*Sqrt[3]) - 3032400*Zeta[3]) + 
         CA*NC*(-755104758680879347945451190793188728710488102062159135278931\
3/7493276912772225351099640226757114039252480000 + (4994886313213*lm)/
            1002456 + 694925*lm^2 - (13767096205719099482081*Pi^2)/88216128 - 
           (234171220949512168619122140773*Im[PolyLog[2, (-1)^(1/3)]])/
            (13622188847194848224304*Sqrt[3]) + 1516200*Zeta[3])), 
      (2755757400663367504300452237185435195635146694253836345054504052643014\
92730089*CF^2*NC)/
        4454463080465237532557240748614790835771980210739818393600000 - 
       (295111599051957767753*CF^2*lm*NC)/3251542559481216 - 
       198335*CF^2*lm^2*NC - 
       (49030842675703223313492177522041658855800360796472628867071*CF*NM*
         NC)/5081330200711787887902757382432401632000000 - 
       (187629150129506605193*CF*lm*NM*NC)/29263883035330944 - 
       (198335*CF*lm^2*NM*NC)/9 + (5828150605172232363495802807*CF*NC*NL)/
        1229588882993152281600 - (187629150129506605193*CF*lm*NC*NL)/
        29263883035330944 - (198335*CF*lm^2*NC*NL)/9 + 
       (7233923790006949989247903553335715589289861258304004415166424101063*
         CF*NC*NH)/
        72693018544537788300651204973942788443612023172455776000000 - 
       (187629150129506605193*CF*lm*NC*NH)/29263883035330944 - 
       (198335*CF*lm^2*NC*NH)/9 - (614621236864833944010407100249550307*CF^2*
         NC*Pi^2)/26922772392504468480 + (9925*CF^2*lm*NC*Pi^2)/9 + 
       (380547815024260552690279*CF*NM*NC*Pi^2)/120873060 + 
       (9925*CF*lm*NM*NC*Pi^2)/81 - (90747931889845*CF*NC*NL*Pi^2)/
        628539912 + (9925*CF*lm*NC*NL*Pi^2)/81 + (9925*CF*lm*NC*NH*Pi^2)/
        81 - (8713846502143827853261966664165*CF^2*NC*Pi^3)/
        (2662164906137507481549696*Sqrt[3]) - 
       (228216358774668576343850*CF*NC*NH*Pi^3)/(16677181699666569*
         Sqrt[3]) - (75901001*CF^2*NC*Pi^4)/1296 + 
       (18180372067419150743720933949614289077*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1229627348495853330652989085440*
         Sqrt[3]) + (16449495252590192761252134629*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(232196400804457640187*Sqrt[3]) - 
       (17194135*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (248967042918395081521770476119*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2054139588069064414776*
         Sqrt[3]) - (104327478296991349185760*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (248967042918395081521770476119*CF^2*NC*Pi*Log[3]^2)/
        (98598700227315091909248*Sqrt[3]) - (6520467393561959324110*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((-828816738315392547138185581410756228271*CF*NC)/
          3025446547607689645440 - 42214124*CF*lm*NC + 
         CA*(828816738382054217070851383743522883423/6050893095215379290880 + 
           (232177682*lm)/9)*NC + (18412493976793164410458388994329*NM*NC)/
          487361991015900 - (42214124*lm*NM*NC)/9 - (50269288*NC*NL)/9 - 
         (42214124*lm*NC*NL)/9 - (30732323057681618366743*NC*NH)/
          18032393667588300 - (42214124*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(1067627348349030053525464*CA + 
          57*(-37460608912520225665993*CF + 136136*(39847744844990522*NM + 
              10553531*NL)))*Log[x]^3)/26189163 - 
       (4423371379378625094395455852885611731*CF^2*NC*PolyGamma[2, 1])/
        162102206120759050680 + (35600073171778472159*CF*NM*NC*
         PolyGamma[2, 1])/1620 - (1233146581341149984220544861*CF*NC*NH*
         PolyGamma[2, 1])/243153309181138576020 - 
       (1447507144941130035361204532121681937988237*CF^2*NC*Zeta[3])/
        104822743179164357086019280 + (30818343811982711279*CF*NM*NC*
         Zeta[3])/810 - (134582272*CF*NC*NL*Zeta[3])/27 + 
       (1736030357170270250172975539*CF*NC*NH*Zeta[3])/
        121576654590569288010 + CA*CF*NC*
        (-2755757401032306680428543401703232880723160714813398497061324803106\
12917060989/8908926160930475065114481497229581671543960421479636787200000 + 
         (2181685*lm^2)/18 + (26722662472595755931042292730119733*Pi^2)/
          2341110642826475520 + (8713846502143827853261966664165*Pi^3)/
          (5324329812275014963099392*Sqrt[3]) + (25385027*Pi^4)/864 + 
         lm*(1008404214628224573833/5320706006423808 - (109175*Pi^2)/162) - 
         (18180372067419150743720933949614289077*Im[PolyLog[2, (-1)^(1/3)]])/
          (2459254696991706661305978170880*Sqrt[3]) + 
         (17194135*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (248967042918395081521770476119*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4108279176138128829552*Sqrt[3]) + 
         (248967042918395081521770476119*Pi*Log[3]^2)/
          (197197400454630183818496*Sqrt[3]) + 
         (4423371379378625094395455852885611731*PolyGamma[2, 1])/
          324204412241518101360 + 
         (1447507145694448394733632364276048670124837*Zeta[3])/
          209645486358328714172038560) + CF*Log[x]*
        ((1292469481883316076967369668502075662409921*NM*NC)/
          115751320802622900737842500 - (90365269419655*lm*NM*NC)/
          104756652 - 146300*lm^2*NM*NC - (30561991315744713056347*NC*NL)/
          3850510925701440 - (90365269419655*lm*NC*NL)/104756652 - 
         146300*lm^2*NC*NL - 
         (1249080024720478262863145656488408487561351832339*NC*NH)/
          12493531627926554547088726600953816120000 - 
         (90365269419655*lm*NC*NH)/104756652 - 146300*lm^2*NC*NH + 
         (8855054407769882*NM*NC*Pi^2)/3 - (22423762*NC*NL*Pi^2)/27 + 
         (104327478296991349185760*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CF*NC*
          (-383086080305376500881050287898594181836767958176637812745895031/
            3629096857754391493571786541194131701363456000 - 
           (92919585784255*lm)/11639628 - 1316700*lm^2 - 
           (17082037582473728028325705*Pi^2)/838053216 + 
           (248967042918395081521770476119*Im[PolyLog[2, (-1)^(1/3)]])/
            (6162418764207193244328*Sqrt[3]) - 3511200*Zeta[3]) + 
         CA*NC*
          (6512463366339861692409770848525529146526023169330659611501500347/
            123389293163649310781440742400600477846357504000 + 
           (109870958022055*lm)/19046664 + 804650*lm^2 + 
           (17082037583423971723222201*Pi^2)/1676106432 - 
           (248967042918395081521770476119*Im[PolyLog[2, (-1)^(1/3)]])/
            (12324837528414386488656*Sqrt[3]) + 1755600*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["s", 2, 2, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-671280150*NM - 9768960*lm*NM + 49766400*lm^2*NM + 
         309141504*NL - 9768960*lm*NL + 49766400*lm^2*NL - 671280150*NH - 
         9768960*lm*NH + 49766400*lm^2*NH + 80*CF*(1241720570 - 165888*lm + 
           5598720*lm^2 - 1022968575*Zeta[3]) + 645458625*NM*Zeta[3] + 
         645458625*NH*Zeta[3] - 8*CA*(36829440*lm + 34214400*lm^2 + 
           79*(-21452674 + 19284075*Zeta[3]))))/83607552000, 
      -(CF*NC*(320*CF*(1241637626 + 5432832*lm + 5598720*lm^2 - 
            1022968575*Zeta[3]) - 32*CA*(-1676346526 + 71043840*lm + 
            34214400*lm^2 + 1523441925*Zeta[3]) + 
          3*(24576*(16507 + 2170*lm + 2700*lm^2)*NL + 
            5*NM*(-46545986 + 10665984*lm + 13271040*lm^2 + 73591875*Zeta[
                3]) + 5*NH*(-314075150 + 10665984*lm + 13271040*lm^2 + 
              270652725*Zeta[3]))))/167215104000, 
      (CF*NC*(28084468286*NM + 25021022208*lm*NM + 19074908160*lm^2*NM + 
         124432908288*NL + 25021022208*lm*NL + 19074908160*lm^2*NL - 
         758451273874*NH + 25021022208*lm*NH + 19074908160*lm^2*NH + 
         126*CF*(3285599947346 + 2014298112*lm + 1362493440*lm^2 - 
           2730598298715*Zeta[3]) + 56945657475*NM*Zeta[3] + 
         636304556475*NH*Zeta[3] - 3*CA*(-12222127720262 + 90379993088*lm + 
           34970664960*lm^2 + 10318158066825*Zeta[3])))/13109664153600, 
      -(CF*NC*(-(CA*(-99597952590454 + 262920978432*lm + 100143267840*lm^2 + 
             83308394847825*Zeta[3])) + 
          2*(7*CF*(83142253428646 + 17784520704*lm + 11705057280*lm^2 - 
              69143254849305*Zeta[3]) + 9*(7*NM*(145748702 + 195477504*lm + 
                144506880*lm^2 + 746205075*Zeta[3]) + 
              96*(512*(142847 + 27839*lm + 20580*lm^2)*NL + 
                7*NH*(-96395278 + 2036224*lm + 1505280*lm^2 + 80493525*
                   Zeta[3]))))))/13109664153600, 
      (CF*NC*(-103424695324650*NM + 12852142571520*lm*NM + 
         14631321600000*lm^2*NM + 101631017172992*NL + 
         12852142571520*lm*NL + 14631321600000*lm^2*NL - 
         1481891359060350*NH + 12852142571520*lm*NH + 14631321600000*lm^2*
          NH + 108*CF*(35113769029650938 + 1274224680960*lm + 
           1219276800000*lm^2 - 29209531818425175*Zeta[3]) + 
         197255733357375*NM*Zeta[3] + 1237687610284125*NH*Zeta[3] - 
         2*CA*(-127448032348238498 + 86553017671680*lm + 40236134400000*
            lm^2 + 106186115435281875*Zeta[3])))/12978567512064000, 
      (CF*NC*(605359095948810*NM + 5543944519680*lm*NM - 
         20913035673600*lm^2*NM - 125568629211136*NL + 
         5543944519680*lm*NL - 20913035673600*lm^2*NL + 
         3353395258788246*NH + 5543944519680*lm*NH - 20913035673600*lm^2*
          NH - 720*CF*(27399069005799766 - 25730482176*lm + 
           261412945920*lm^2 - 22793378906013345*Zeta[3]) - 
         681920666571375*NM*Zeta[3] - 2802663478778625*NH*Zeta[3] + 
         8*CA*(-142235230562477026 + 14487444357120*lm + 14377712025600*
            lm^2 + 118358246232407475*Zeta[3])))/25957135024128000, 
      (CF*NC*(-363*CA*(-299483299124133491074 - 11289287039385600*lm + 
           9476414373888000*lm^2 + 249123428915637283875*Zeta[3]) + 
         2*(11*CF*(100108499318250179452478 - 587810942956339200*lm + 
             255863188094976000*lm^2 - 83281396087864954720125*Zeta[3]) + 
           15*(131072*(499540722881 - 391924985760*lm + 159058468800*lm^2)*
              NL + 1386*NM*(-1237791759638786 - 37063774699520*lm + 
               15041927577600*lm^2 + 1149494651179875*Zeta[3]) + 
             693*NH*(-7844652439348714 - 74127549399040*lm + 30083855155200*
                lm^2 + 6557458337805375*Zeta[3])))))/1224917201788600320000, 
      (CF*NC*(-22*CF*(43424096093983713323006 - 186774788688445440*lm + 
           28089328258252800*lm^2 - 36124958965478379536925*Zeta[3]) + 
         1815*CA*(-22486583399893632602 - 1153379920379904*lm + 
           208069098209280*lm^2 + 18704358460586636775*Zeta[3]) - 
         6*(231*NM*(-11181823800790442 - 337665508638720*lm + 
             49540261478400*lm^2 + 9496199939601375*Zeta[3]) + 
           4*(8192*(-1439084054357 - 2380393447740*lm + 349237072800*lm^2)*
              NL + 3465*NH*(-376238023247262 - 5627758477312*lm + 
               825671024640*lm^2 + 314387095747725*Zeta[3])))))/
       244983440357720064000, 
      (CF*NC*(1248*CF*(4688169004373651466943218194 - 11385774539280639590400*
            lm + 644628143567536128000*lm^2 - 3900129176594119380199162875*
            Zeta[3]) - 880*CA*(-248147284770494339655980494 - 
           9249739844906259578880*lm + 558677724425197977600*lm^2 + 
           206414327349629439738823125*Zeta[3]) + 
         35*(16777216*(-3896260649889539 - 2714098309502580*lm + 
             152227599123600*lm^2)*NL + 1287*NH*(-1906727211670887925462 - 
             35380740935322173440*lm + 1984425261583564800*lm^2 + 
             1592075802502575014625*Zeta[3]) + 1287*NM*
            (-35380740935322173440*lm + 1984425261583564800*lm^2 + 
             1287*(-1129332363499934458 + 921956122028316375*Zeta[3])))))/
       741927449454548059422720000, 
      -(CF*NC*(1664*CF*(13417668707823168651756902786 - 
            16547465083031440588800*lm + 167034163880263680000*lm^2 - 
            11162264067488838115516579875*Zeta[3]) - 
          31680*CA*(-23172781043563444748042234 - 525222956218428948480*lm + 
            5361590445539328000*lm^2 + 19276293022641102077004375*Zeta[3]) + 
          105*(134217728*(-435807339551621 - 217456871551920*lm + 
              2191376187000*lm^2)*NL + 1287*NH*(-1101167795051327958526 - 
              22677985421667860480*lm + 228532659683328000*lm^2 + 
              918557349322363876125*Zeta[3]) + 429*NM*
             (-3941597914118419024406 - 68033956265003581440*lm + 
              685597979049984000*lm^2 + 3178823518378245362625*Zeta[3]))))/
       1483854898909096118845440000, 
      -(CF*NC*(-121*CA*(177373514035198924302042993314 + 
            2241630398251776564264960*lm + 41925687614864621568000*lm^2 - 
            147552231325623854743111173075*Zeta[3]) + 
          2*(77*(268435456*(2906452090726889 + 1164563230210380*lm + 
                22312193904000*lm^2)*NL + 13*NM*(
                2166307196582167681140254 + 24046927826335102402560*lm + 
                460721841921589248000*lm^2 - 1749630901326903888418125*
                 Zeta[3]) + 1001*NH*(14618290863064232184646 + 
                312297763978377953280*lm + 5983400544436224000*lm^2 - 
                12181116477419392127625*Zeta[3])) + 
            9*CF*(-40857714858461986633159044498814 + 
              24147838514788689311170560*lm + 461182563763510837248000*lm^2 + 
              33989836761202602307396915871325*Zeta[3]))))/
       26907235500218276288397312000, 
      (CF*NC*(-11*CA*(6505984404275057579359827076714 + 
           43464968814304473749913600*lm + 1717669752792667914240000*lm^2 - 
           5412247405340911164631488261375*Zeta[3]) + 
         2*(10*(134217728*(91922207170240061 + 30755135174383620*lm + 
               1279763693208000*lm^2)*NL + 5148*NM*
              (121607604070346126797578 + 801842340217298616320*lm + 
               33365768313765888000*lm^2 - 98857153362044297595375*Zeta[3]) + 
             3003*NH*(65186989032149103724462 + 1374586868943940485120*lm + 
               57198459966455808000*lm^2 - 54261047955066604777125*
                Zeta[3])) + CF*(-1372339676060449681164693141018994 + 
             374086097698667796784742400*lm + 15459027775134011228160000*
              lm^2 + 1141659386256954536792740201156875*Zeta[3]))))/
       57658361786182020617994240000, 
      -(CF*NC*(945*(134217728*(99435430430338271431 + 28090380718373353380*
               lm + 1750181062573944000*lm^2)*NL + 2431*NH*
             (77794067265270398324228518 + 1550895548611715074621440*lm + 
              96629093297943478272000*lm^2 - 64689717514717595821145625*Zeta[
                3]) + 48620*NM*(21141090221805878519514134 + 
              77544777430585753731072*lm + 4831454664897173913600*lm^2 - 
              17305776330032255992351425*Zeta[3])) - 
          CA*(6227743192638202161643931451350907466 + 
            21149653971629018343356655206400*lm + 
            1220920430883444846042808320000*lm^2 - 
            5180836681836312789969430657023495375*Zeta[3]) + 
          34*CF*(-7815481503321289981776363647258525782 + 
            952904694219511718692572364800*lm + 58760876352679163713290240000*
             lm^2 + 6501755901863886019310712892043534625*Zeta[3])))/
       3324321677963217489740766904320000, 
      (CF*NC*(-4*CA*(4576691442371195789306424674153157454 + 
           7635207689200329927643732377600*lm + 
           585916141163750308876124160000*lm^2 - 
           3807355860924927681341327376662767125*Zeta[3]) + 
         136*CF*(-6355569964927077217406090935658640274 + 
           336279894882548373366453043200*lm + 28199172569378357111685120000*
            lm^2 + 5287244989387777994573491143487714875*Zeta[3]) + 
         315*(34359738368*(1951775265050969753 + 462939637306611465*lm + 
             39370629805006500*lm^2)*NL + 85085*NM*
            (96904030205704678291490302 + 186948167338919693647872*lm + 
             15898977957141754675200*lm^2 - 79769057364826039555069725*
              Zeta[3]) + 109395*NH*(145404130152493095059456*lm + 
             12365871744443586969600*lm^2 - 80223*(-100467328895039874914 + 
               83467243794630661875*Zeta[3])))))/
       6648643355926434979481533808640000, 
      -(CF*NC*(-(CA*(50610436078639330735541879644702494726278 + 
             40016990579471147533278506699980800*lm + 
             4000211639333842370921590947840000*lm^2 - 
             42103032760359124136893014487014466859625*Zeta[3])) + 
          38*CF*(-69246243685358706002082061508658559725022 + 
            1532691993414783760843261398220800*lm + 
            172257917483275508795666595840000*lm^2 + 
            57606456652142142849717376548184721446125*Zeta[3]) + 
          35*(309237645312*(3010866872945758340113 + 586709907519814758680*
               lm + 67198546229278464000*lm^2)*NL + 4199*NM*
             (44881842312511560034061235640178 + 
              43208571155667729925370019840*lm + 4948873589981340481093632000*
               lm^2 - 37091241446264058804346453732875*Zeta[3]) + 
            4199*NH*(43208571155667729925370019840*lm + 
              4948873589981340481093632000*lm^2 - 4199*(
                -663761445775149412095978142 + 551005662485707553305306125*
                 Zeta[3])))))/12800854674610362813828446426234880000, 
      (CF*NC*(-143*CA*(497806513991412839363257186248165997162 + 
           178320025966713031321192916582400*lm + 
           23670325189324577643184521216000*lm^2 - 
           414128073133674964402962252073915845375*Zeta[3]) + 
         3*(35*(17179869184*(13960702638364992265813 + 2135970638700330552120*
                lm + 341168103053566588800*lm^2)*NL + 4199*NM*
              (19303605288994029950538176292646 + 
               8739151263095167102400593920*lm + 1395861724270946639727820800*
                lm^2 - 15993672943926138124541013761625*Zeta[3]) + 
             4199*NH*(704430683980655271066393917158 + 
               8739151263095167102400593920*lm + 1395861724270946639727820800*
                lm^2 - 584373189787023970681432709625*Zeta[3])) + 
           1482*CF*(-912632760627711804162272585211245448278 + 
             8007326933797739951552043417600*lm + 
             1245806588911819875957080064000*lm^2 + 
             759225887868016510773678352603206734625*Zeta[3]))))/
       12800854674610362813828446426234880000, 
      -(CF*NC*(-52*CA*(7652394679352715691437769612566705973488146 + 
            1159955255163751373037141681713971200*lm + 
            216698840823494588532107671240704000*lm^2 - 
            6366076933494797450333870711016360074362875*Zeta[3]) + 
          5*(104*CF*(-47624795304045473058234960147202359214684054 + 
              150590160646345005762663200807976960*lm + 
              35459810316571841759799437112115200*lm^2 + 
              39619417228028605227857071939209449526247425*Zeta[3]) + 
            231*(687194767360*(96245872233395860692289 + 
                10531932894250939787616*lm + 2581281769554356188320*lm^2)*
               NL + 4199*NM*(8859221567106224058145009869682106 + 
                1723622094573923803003606794240*lm + 
                422444230797693482187934924800*lm^2 - 
                7351718948498981412186062697840375*Zeta[3]) + 
              29393*NH*(246231727796274829000515256320*lm + 
                60349175828241926026847846400*lm^2 - 4199*
                 (-6644397034884952400092163482 + 
                  5508991322763639853802034375*Zeta[3]))))))/
       51817859722822748670377551133398794240000, 
      (CF*NC*(385*(1099511627776*(263114100613674304786837 + 
             16261881209306168075640*lm + 7826015853569358244800*lm^2)*NL + 
           4199*NM*(62828856747410485885938728122183702 + 
             4258187063382751183711355535360*lm + 
             2049248733069499200632468275200*lm^2 - 
             52186356019921574869895522671250625*Zeta[3]) + 
           4199*NH*(880295543153105674060803643968922 + 
             4258187063382751183711355535360*lm + 
             2049248733069499200632468275200*lm^2 - 
             729566317180961897623029182514375*Zeta[3])) - 
         48*CA*(22520762212756904003805552284598980712846946 + 
           1271897783778454663089971574236774400*lm + 
           379596965070027426588906611539968000*lm^2 - 
           18735178295395578094452105517393791506197875*Zeta[3]) + 
         32*CF*(-2286969268946475282478880324267954075993406682 + 
           2091372221129727481845171369069772800*lm + 
           931738005171885501627316228325376000*lm^2 + 
           1902546563905719745933870338541939549010622375*Zeta[3])))/
       103635719445645497340755102266797588480000, 
      -(CF*NC*(3465*(1649267441664*(175743639666359928822168581 + 
              1243864477200032259291720*lm + 5896429297524300008073600*lm^2)*
             NL + 408595*NM*(981020895208528690618824522913777270 + 
              5020778972058948499762172657664*lm + 
              23800557673198543700211605176320*lm^2 - 
              815270913082140184681021853944326225*Zeta[3]) + 
            572033*NH*(6851370666400830197091564166347218 + 
              3586270694327820356972980469760*lm + 
              17000398337998959785865432268800*lm^2 - 
              5676561424900517744036038118398875*Zeta[3])) - 
          CA*(18366120988933139376971793936280096391990167204414 + 
            274970551605231137333650132104770066841600*lm + 
            185330163746723252440954563270329499648000*lm^2 - 
            15278907524319148280288489390159559316343144224125*Zeta[3]) + 
          782*CF*(-1723686077679724869635981580142552142308372241582 + 
            146444414166931294070022582491833958400*lm + 
            387810154317718965814599179128799232000*lm^2 + 
            1433947141936594938810020887714356176735220121125*Zeta[3])))/
       1315759094081915234238226778379262183342080000, 
      CA*CF*NC*(-1102194884207105136723568300378889610442080663263/
          59807231549177965192646671744511917424640000 + 
         (151702849855177*lm)/5212321254441100800 - (24331*lm^2)/216332480 + 
         (495118957300378148920126495*Zeta[3])/32294602485032609120256) + 
       (CF*NC*(28405*CF*(-615497788776154979367337113612523512010506034 - 
            105776131013151210547225298523389952*lm + 
            77500936656099541852081578427023360*lm^2 + 
            512037145366486222088900460503223032517045675*Zeta[3]) + 
          63*(22287*NM*(7942152960420626710954013231651768902 - 
              266799529560324620660298838179840*lm + 
              174207590090482076992264155955200*lm^2 - 
              6601728671673417066534674702360207625*Zeta[3]) + 
            2*(962072674304*(52087293554045194119721903 - 
                3090286874436296691344760*lm + 2017812512529455774932800*
                 lm^2)*NL + 37145*NH*(-80039858868097386198089651453952*
                 lm + 52262277027144623097679246786560*lm^2 - 
                7429*(-2678453849621447738581817217826 + 
                  2218759566466871282170933091475*Zeta[3]))))))/
        11961446309835593038529334348902383484928000}, 0, 20, 1]
 
CbarSeries["s", 2, 3, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(4*CA*(59400*lm^2 - 24777*Pi^2 + 810*Pi^4 - 
            150*lm*(-1285 + 44*Pi^2) + 10*(16688 + 6294*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 6480*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              1049*PolyGamma[2, 1] - 17506*Zeta[3])) + 
          CF*(-1296625 - 777600*lm^2 - 39668*Pi^2 + 1200*Pi^4 + 
            86400*lm*(-11 + Pi^2) - 503520*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 518400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            83920*PolyGamma[2, 1] + 2015360*Zeta[3]) + 
          20*(NL*(-2365 - 2160*lm^2 - 12*Pi^2 + 60*lm*(-71 + 4*Pi^2) - 
              2880*Zeta[3]) + NM*(-2365 - 2160*lm^2 - 12*Pi^2 + 
              60*lm*(-71 + 4*Pi^2) + 240*PolyGamma[2, 1] - 2400*Zeta[3]) + 
            NH*(-33577 - 2160*lm^2 + 60*lm*(-71 + 4*Pi^2) - 
              598704*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 99784*PolyGamma[2, 
                1] + 1103888*Zeta[3]))))/7776000, 
      (CF*NC*(3*CA*(712800*lm^2 - 507468*Pi^2 + 19440*Pi^4 - 
           600*lm*(-841 + 132*Pi^2) + 5*(-1417631 - 452736*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 311040*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 76896*PolyGamma[2, 1] + 799776*Zeta[3])) - 
         4*(-5*(NH*(8738277 - 19440*lm^2 + 180*lm*(61 + 12*Pi^2) + 4473264*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 745544*PolyGamma[2, 1] - 
               15297808*Zeta[3]) + 3*NL*(53015 - 6480*lm^2 + 324*Pi^2 + 60*
                lm*(61 + 12*Pi^2) - 8640*Zeta[3]) + 3*NM*(53015 - 6480*
                lm^2 + 324*Pi^2 + 60*lm*(61 + 12*Pi^2) + 720*PolyGamma[2, 
                 1] - 7200*Zeta[3])) + 9*CF*(194400*lm^2 + 26784*Pi^2 + 
             1320*Pi^4 - 3600*lm*(71 + 6*Pi^2) + 5*(57065 - 75456*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 51840*Im[PolyLog[2, (-1)^(1/3)]]^
                 2 + 12816*PolyGamma[2, 1] + 80448*Zeta[3])))))/23328000, 
      -(CF*NC*(CA*(-8019000*lm^2 + 218079*Pi^2 + 86670*Pi^4 + 
            1350*lm*(-4051 + 132*Pi^2) + 10*(6866019 - 555258*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 2624400*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 16589*PolyGamma[2, 1] + 2451514*Zeta[3])) - 
          5*(3*(NH*(27953187 - 97200*lm^2 + 180*lm*(319 + 12*Pi^2) + 
                30775824*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 5328872*
                 PolyGamma[2, 1] - 78896464*Zeta[3]) + 3*NM*(299405 - 
                32400*lm^2 - 18036*Pi^2 + 60*lm*(319 + 12*Pi^2) - 
                720*PolyGamma[2, 1] - 10080*Zeta[3]) + 3*NL*(219485 - 
                32400*lm^2 - 9396*Pi^2 + 60*lm*(319 + 12*Pi^2) - 
                8640*Zeta[3])) + 2*CF*(-4411899 - 2624400*lm^2 - 
              440721*Pi^2 + 22518*Pi^4 + 19440*lm*(181 + 3*Pi^2) - 
              1110516*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              5248800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 33178*PolyGamma[2, 1] + 
              7846244*Zeta[3]))))/17496000, 
      -(CF*NC*(74551782375*CF + 29111594400*CF*lm + 44530819200*CF*lm^2 - 
          16158592800*NM + 3472761600*lm*NM + 2473934400*lm^2*NM - 
          2307009600*NL + 3472761600*lm*NL + 2473934400*lm^2*NL - 
          455171935680*NH + 3472761600*lm*NH + 2473934400*lm^2*NH - 
          975005748*CF*Pi^2 - 1175731200*CF*lm*Pi^2 + 1097349120*NM*Pi^2 - 
          65318400*lm*NM*Pi^2 + 1244315520*NL*Pi^2 - 65318400*lm*NL*Pi^2 - 
          65318400*lm*NH*Pi^2 + 746760000*Sqrt[3]*CF*Pi^3 + 
          11975600000*Sqrt[3]*NH*Pi^3 + 102400200*CF*Pi^4 - 
          39979306080*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          180060572160*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          73336233600*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 27651456000*Sqrt[3]*
           CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 443439360000*Sqrt[3]*
           NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 576072000*Sqrt[3]*CF*
           Pi*Log[3]^2 + 9238320000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          48988800*(-10*CA*(76 + 33*lm) + 9*CF*(227 + 120*lm) + 
            20*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          979776000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          8416638720*CF*PolyGamma[2, 1] + 400075200*NM*PolyGamma[2, 1] + 
          37108360800*NH*PolyGamma[2, 1] - 84*CA*(161983800*lm^2 - 
            30974643*Pi^2 + 4445000*Sqrt[3]*Pi^3 + 1231605*Pi^4 - 
            32400*lm*(-13381 + 132*Pi^2) + 3429000*Sqrt[3]*Pi*Log[3]^2 - 
            540*(219207 + 440689*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              808380*Im[PolyLog[2, (-1)^(1/3)]]^2 - 304800*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 92776*PolyGamma[2, 1] - 
              439352*Zeta[3])) - 214008480*CF*Zeta[3] - 1355356800*NM*
           Zeta[3] + 6662476800*NL*Zeta[3] + 343785758400*NH*Zeta[3] - 
          37800*Log[x]*(16*(-2*(27*NM*(122 + 204*lm + 45*lm^2 + 30*Pi^2) + 
                27*NL*(392 + 204*lm + 45*lm^2 + 30*Pi^2) + 
                NH*(214710 + 5508*lm + 1215*lm^2 - 122200*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 3*CF*(-68361 - 55161*lm - 
                14580*lm^2 + 351*Pi^2 + 5080*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 9720*Zeta[3])) + 3*CA*(767505 + 413856*lm + 
              71280*lm^2 + 4356*Pi^2 - 40640*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 77760*Zeta[3]))))/2204496000, 
      (-2*CF*NC*(27*CF*(7 + 4*lm) - CA*(76 + 33*lm) + 11*NM + 6*lm*NM + 
          10*NL + 6*lm*NL + 6*lm*NH)*Log[x]^2)/3 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/3 + 
       (CF*NC*Log[x]*(2*(-18*(9*NL*(2917 + 1530*lm + 360*lm^2 + 240*Pi^2) + 
              9*NM*(527 + 1530*lm + 360*lm^2 + 300*Pi^2) + NH*(464871 + 
                13770*lm + 3240*lm^2 - 264400*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) + CF*(-4558719 - 3674160*lm - 
              1049760*lm^2 + 78300*Pi^2 + 575216*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 699840*Zeta[3])) + 
          CA*(6728331 + 3542940*lm + 641520*lm^2 - 19440*Pi^2 - 
            575216*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 699840*Zeta[3])))/
        58320 - (CF*NC*(-28*CA*(1313512200*lm^2 - 198373293*Pi^2 + 
            62914250*Sqrt[3]*Pi^3 + 6790635*Pi^4 - 24300*lm*
             (-136303 + 924*Pi^2) + 48533850*Sqrt[3]*Pi*Log[3]^2 - 
            20*(109156104 + 55393269*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              203522220*Im[PolyLog[2, (-1)^(1/3)]]^2 - 116481240*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 15154420*PolyGamma[2, 
                1] + 26871004*Zeta[3])) - 
          840*(54*NL*(177145 - 147420*lm^2 - 83916*Pi^2 + 30*lm*(-6137 + 
                84*Pi^2) - 419040*Zeta[3]) + 27*NM*(2178005 - 294840*lm^2 - 
              199692*Pi^2 + 60*lm*(-6137 + 84*Pi^2) - 77814*PolyGamma[2, 1] + 
              367092*Zeta[3]) - NH*(-1317371571 + 7960680*lm^2 + 
              34702500*Sqrt[3]*Pi^3 - 1620*lm*(-6137 + 84*Pi^2) - 
              721511952*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1284984000*Sqrt[
                3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 26770500*Sqrt[
                3]*Pi*Log[3]^2 + 146017462*PolyGamma[2, 1] + 1364811884*Zeta[
                3])) + CF*(120365481600*lm^2 - 5046331428*Pi^2 + 
            3523198000*Sqrt[3]*Pi^3 + 197384040*Pi^4 - 12247200*lm*
             (-4903 + 168*Pi^2) + 2717895600*Sqrt[3]*Pi*Log[3]^2 - 
            35*(-4419235737 + 1772584608*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              6512711040*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3727399680*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 484941440*PolyGamma[2, 
                1] + 4114478048*Zeta[3]))))/2204496000, 
      (CF*NC*(-18370800*(9*CF*(8437 + 4800*lm) - CA*(28513 + 13200*lm) + 
           4*(40*(37 + 15*lm)*NM + 925*NL + 600*lm*NL + 12*NH + 
             600*lm*NH))*Log[x]^2 - 7348320000*(25*CA + 87*CF - 7*NM - 
           4*NL)*Log[x]^3 + 15*CA*(6769639800*lm^2 - 1534682295*Pi^2 + 
           514292975*Sqrt[3]*Pi^3 + 80173233*Pi^4 - 
           68040*lm*(-281939 + 1650*Pi^2) + 396740295*Sqrt[3]*Pi*Log[3]^2 - 
           14*(603347625 + 752125890*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             1572278040*Im[PolyLog[2, (-1)^(1/3)]]^2 - 1360252440*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 193861436*
              PolyGamma[2, 1] - 495541972*Zeta[3])) + 
         1890*Log[x]*(2*(-2*(1215*NM*(8439 + 8386*lm + 1800*lm^2 + 
                 800*Pi^2) + 1215*NL*(17277 + 8386*lm + 1800*lm^2 + 
                 1400*Pi^2) + NH*(377312619 + 10188990*lm + 2187000*lm^2 - 
                 214277600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             15*CF*(-26112759 - 20516976*lm - 5248800*lm^2 + 461322*Pi^2 + 
               3358648*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 3499200*
                Zeta[3])) - 15*CA*(-38065389 - 19026252*lm - 3207600*lm^2 + 
             74574*Pi^2 + 3358648*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             3499200*Zeta[3])) - 3*CF*(110775924000*lm^2 - 12385824453*Pi^2 + 
           5142929750*Sqrt[3]*Pi^3 + 638436330*Pi^4 - 3061800*lm*
            (-29341 + 600*Pi^2) + 3967402950*Sqrt[3]*Pi*Log[3]^2 - 
           280*(-365664411 + 376062945*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             786139020*Im[PolyLog[2, (-1)^(1/3)]]^2 - 680126220*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 96930718*
              PolyGamma[2, 1] + 138604117*Zeta[3])) + 
         28*(6075*NL*(95363 - 108540*lm^2 - 76500*Pi^2 + 
             12*lm*(-14119 + 150*Pi^2) - 475200*Zeta[3]) + 
           1215*NM*(4819900 - 542700*lm^2 - 308250*Pi^2 + 
             60*lm*(-14119 + 150*Pi^2) - 151569*PolyGamma[2, 1] + 
             3152862*Zeta[3]) - NH*(-131509757556 + 659380500*lm^2 + 
             4687322500*Sqrt[3]*Pi^3 - 72900*lm*(-14119 + 150*Pi^2) - 
             44618259000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             173564856000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             3615934500*Sqrt[3]*Pi*Log[3]^2 + 10212175115*PolyGamma[2, 1] + 
             49511450230*Zeta[3]))))/1653372000, 
      -(CF*NC*(-12247200*(3*CA*(227979 + 97900*lm) - 
            2*(CF*(861557 + 480600*lm) + (78254 + 26700*lm)*NM + 
              12*(25*(134 + 89*lm)*NL + (54 + 2225*lm)*NH)))*Log[x]^2 + 
          2449440000*(1015*CA + 4288*CF - 302*NM - 178*NL)*Log[x]^3 + 
          3780*Log[x]*(4*(145380825*NL + 69628410*lm*NL + 15309000*lm^
                2*NL + 2382358551*NH + 69628410*lm*NH + 15309000*lm^2*
               NH + 12312000*NL*Pi^2 + 135*NM*(504341 + 515766*lm + 
                113400*lm^2 + 73500*Pi^2) - 1351418800*Sqrt[3]*NH*Im[
                PolyLog[2, (-1)^(1/3)]] - 180*CF*(-7306845 - 5814666*lm - 
                1530900*lm^2 + 119232*Pi^2 + 1199888*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 1020600*Zeta[3])) + 
            45*CA*(-87738519 - 43566156*lm - 7484400*lm^2 + 56844*Pi^2 + 
              9599104*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 8164800*Zeta[
                3])) - 30*CA*(43345902600*lm^2 - 9112426371*Pi^2 + 
            4409588400*Sqrt[3]*Pi^3 + 543842019*Pi^4 - 374220*lm*
             (-317689 + 1500*Pi^2) + 3401682480*Sqrt[3]*Pi*Log[3]^2 - 
            140*(560896731 + 385329321*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              1107837972*Im[PolyLog[2, (-1)^(1/3)]]^2 - 1166291136*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 124385954*PolyGamma[2, 
                1] + 149588684*Zeta[3])) + 
          7*(3*CF*(202656168000*lm^2 - 24623646354*Pi^2 + 12598824000*Sqrt[
                3]*Pi^3 + 1320554340*Pi^4 - 874800*lm*(-166793 + 3000*Pi^2) + 
              9719092800*Sqrt[3]*Pi*Log[3]^2 - 5*(-29758643703 + 
                30826345680*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                88627037760*Im[PolyLog[2, (-1)^(1/3)]]^2 - 93303290880*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                9950876320*PolyGamma[2, 1] + 54491717584*Zeta[3])) - 
            4*(36450*NL*(292561 - 231660*lm^2 - 177580*Pi^2 + 
                lm*(-340538 + 3000*Pi^2) - 1130400*Zeta[3]) + 
              6075*NM*(12619861 - 1389960*lm^2 - 1152948*Pi^2 + 
                12*lm*(-170269 + 1500*Pi^2) - 660006*PolyGamma[2, 1] + 
                10192788*Zeta[3]) - NH*(-1646450875683 + 8444007000*lm^2 + 
                59124572500*Sqrt[3]*Pi^3 - 72900*lm*(-170269 + 1500*Pi^2) - 
                661695942000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                2189298456000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                45610384500*Sqrt[3]*Pi*Log[3]^2 + 149374009190*PolyGamma[2, 
                  1] + 800988194380*Zeta[3])))))/9920232000, 
      (-4924313813*CF^2*NC)/15746400 - (55727*CF^2*lm*NC)/60 - 
       1077*CF^2*lm^2*NC + (1234273*CF*NM*NC)/1620 - 
       (13024*CF*lm*NM*NC)/135 - (359*CF*lm^2*NM*NC)/6 + 
       (125561*CF*NC*NL)/1215 - (13024*CF*lm*NC*NL)/135 - 
       (359*CF*lm^2*NC*NL)/6 + (36709923120448*CF*NC*NH)/2531725875 - 
       (13024*CF*lm*NC*NH)/135 - (359*CF*lm^2*NC*NH)/6 + 
       (1415834083*CF^2*NC*Pi^2)/6804000 + (40*CF^2*lm*NC*Pi^2)/3 - 
       (91*CF*NM*NC*Pi^2)/405 + (20*CF*lm*NM*NC*Pi^2)/27 - 
       (4313*CF*NC*NL*Pi^2)/81 + (20*CF*lm*NC*NL*Pi^2)/27 + 
       (20*CF*lm*NC*NH*Pi^2)/27 - (63192605*CF^2*NC*Pi^3)/(236196*Sqrt[3]) - 
       (307748000*CF*NC*NH*Pi^3)/(177147*Sqrt[3]) - (112871*CF^2*NC*Pi^4)/
        10800 + (681802631*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (196830*Sqrt[3]) + (3936455416*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (295245*Sqrt[3]) - (12517*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (7222012*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (729*Sqrt[3]) - (140684800*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (1805503*CF^2*NC*Pi*Log[3]^2)/(8748*Sqrt[3]) - 
       (8792800*CF*NC*NH*Pi*Log[3]^2)/(6561*Sqrt[3]) - 
       (CF*NC*(-385*CA*(7117 + 3270*lm) + 7*CF*(1038191 + 588600*lm) + 
          6*(7*(5409 + 5450*lm)*NM + 350*(158 + 109*lm)*NL + 
            (1707 + 38150*lm)*NH))*Log[x]^2)/945 - 
       (10*CF*NC*(2763*CA + 12164*CF - 1820*NM - 436*NL)*Log[x]^3)/27 - 
       (318723242*CF^2*NC*PolyGamma[2, 1])/885735 + 
       (60943*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (28668623333*CF*NC*NH*PolyGamma[2, 1])/26572050 + 
       (CA*CF*NC*(326458301400*lm^2 - 98756040780*Pi^2 + 44234823500*Sqrt[3]*
           Pi^3 + 5771692017*Pi^4 - 3674160*lm*(-256349 + 1100*Pi^2) + 
          34124006700*Sqrt[3]*Pi*Log[3]^2 - 280*(2577788001 + 
            2045407893*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            4434697998*Im[PolyLog[2, (-1)^(1/3)]]^2 - 5849829720*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 637446484*
             PolyGamma[2, 1] - 543210248*Zeta[3])))/992023200 + 
       (CF*NC*Log[x]*(2*(8*(-119070*NM*(84062 + 68205*lm + 14175*lm^2 - 
                13620*Pi^2) - 59535*NL*(305647 + 136410*lm + 28350*lm^2 + 
                25800*Pi^2) - 2*NH*(152051248344 + 4060584675*lm + 
                843908625*lm^2 - 86169440000*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) + 735*CF*(-1702754817 - 1343080440*lm - 
              330674400*lm^2 + 32200416*Pi^2 + 288880480*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 220449600*Zeta[3])) - 
          735*CA*(-2544043821 - 1229521680*lm - 202078800*lm^2 + 
            4954284*Pi^2 + 288880480*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            220449600*Zeta[3])))/385786800 + (16274880727*CF^2*NC*Zeta[3])/
        17714700 + (1055143*CF*NM*NC*Zeta[3])/1350 - 
       (3520*CF*NC*NL*Zeta[3])/9 - (36484742633*CF*NC*NH*Zeta[3])/13286025, 
      (CF*NC*(-2314720800*(-35*CA*(779239 + 307626*lm) + 
           3*(7*CF*(3245843 + 1677960*lm) + 28*(44452 + 23305*lm)*NM + 
             924805*NL + 652540*lm*NL + 34248*NH + 652540*lm*NH))*
          Log[x]^2 - 324060912000*(50095*CA + 294875*CF - 38012*NM - 
           9322*NL)*Log[x]^3 - 49*CF*(356503377384000*lm^2 - 
           54995970475422*Pi^2 + 36077956400500*Sqrt[3]*Pi^3 + 
           3905529203520*Pi^4 - 744017400*lm*(-384423 + 5000*Pi^2) + 
           27831566366100*Sqrt[3]*Pi*Log[3]^2 + 7*(7805291017113 - 
             48880961884200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             127709098675200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             190845026510400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             20302402905800*PolyGamma[2, 1] - 93704336587280*Zeta[3])) + 
         3780*Log[x]*(18*(-15876*NM*(9329807 + 5397915*lm + 1134000*lm^2 - 
               947550*Pi^2) - 19845*NL*(9911539 + 4318332*lm + 907200*lm^2 + 
               861720*Pi^2) - 2*NH*(1537074261489 + 42848649270*lm + 
               9001692000*lm^2 - 870103211600*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]])) + 49*CF*(-617105039109 - 477369437040*lm - 
             119042784000*lm^2 + 4757118660*Pi^2 + 117805571920*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 79361856000*Zeta[3]) + 
           98*CA*(232937148561 + 109718968770*lm + 18187092000*lm^2 + 
             1362665025*Pi^2 - 29451392980*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 19840464000*Zeta[3])) + 
         49*CA*(108931587534000*lm^2 - 23502840345585*Pi^2 + 
           18038978200250*Sqrt[3]*Pi^3 + 2118101801760*Pi^4 - 
           227338650*lm*(-1353633 + 5000*Pi^2) + 13915783183050*Sqrt[3]*Pi*
            Log[3]^2 - 7*(41425339133511 + 24440480942100*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 63854549337600*
              Im[PolyLog[2, (-1)^(1/3)]]^2 - 95422513255200*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 10151201452900*
              PolyGamma[2, 1] + 15674948194600*Zeta[3])) + 
         3*(18753525*NL*(39381181 - 17249760*lm^2 - 16467000*Pi^2 + 
             36*lm*(-743793 + 5000*Pi^2) - 126247680*Zeta[3]) + 
           4500846*NM*(952930737 - 71874000*lm^2 - 28374100*Pi^2 + 
             150*lm*(-743793 + 5000*Pi^2) + 14966520*PolyGamma[2, 1] + 
             1104173040*Zeta[3]) - 2*NH*(-39747201543253809 + 
             161746902702000*lm^2 + 1598814651315000*Sqrt[3]*Pi^3 - 
             337563450*lm*(-743793 + 5000*Pi^2) - 13474444520653200*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 59201822517264000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1233371302443000*
              Sqrt[3]*Pi*Log[3]^2 + 3244963157060800*PolyGamma[2, 1] + 
             9652220713721600*Zeta[3]))))/8749644624000, 
      (9271709398829*CF^2*NC)/7558272000 - (871543*CF^2*lm*NC)/240 - 
       (8197*CF^2*lm^2*NC)/2 + (33025664*CF*NM*NC)/10125 - 
       (1609273*CF*lm*NM*NC)/4320 - (8197*CF*lm^2*NM*NC)/36 + 
       (113571223*CF*NC*NL)/155520 - (1609273*CF*lm*NC*NL)/4320 - 
       (8197*CF*lm^2*NC*NL)/36 + (135540932713139*CF*NC*NH)/1984046400 - 
       (1609273*CF*lm*NC*NH)/4320 - (8197*CF*lm^2*NC*NH)/36 + 
       (15083945711*CF^2*NC*Pi^2)/13608000 + (245*CF^2*lm*NC*Pi^2)/6 + 
       (5294633*CF*NM*NC*Pi^2)/6480 + (245*CF*lm*NM*NC*Pi^2)/108 - 
       (316247*CF*NC*NL*Pi^2)/1296 + (245*CF*lm*NC*NL*Pi^2)/108 + 
       (245*CF*lm*NC*NH*Pi^2)/108 - (726682481*CF^2*NC*Pi^3)/
        (472392*Sqrt[3]) - (12267076745*CF*NC*NH*Pi^3)/(1417176*Sqrt[3]) - 
       (1828183*CF^2*NC*Pi^4)/32400 + (35723462587*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2361960*Sqrt[3]) + 
       (207522438349*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3542940*Sqrt[3]) - (163541*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        15 - (207623566*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3645*Sqrt[3]) - (700975814*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (103811783*CF^2*NC*Pi*Log[3]^2)/(87480*Sqrt[3]) - 
       (350487907*CF*NC*NH*Pi*Log[3]^2)/(52488*Sqrt[3]) - 
       (CF*NC*(56*CF*(2642423 + 1466910*lm) - CA*(56318069 + 25100460*lm) + 
          6*(6*(-665029 + 126770*lm)*NM + 105*(10059 + 7244*lm)*NL + 
            20*(2719 + 38031*lm)*NH))*Log[x]^2)/3240 - 
       (7*CF*NC*(67724*CA + 376963*CF - 99240*NM - 10866*NL)*Log[x]^3)/81 - 
       (304199397673*CF^2*NC*PolyGamma[2, 1])/159432300 + 
       (5648261*CF*NM*NC*PolyGamma[2, 1])/5400 - 
       (586075348709*CF*NC*NH*PolyGamma[2, 1])/119574225 + 
       (CA*CF*NC*(-1692556695914733 + 511130033568000*lm^2 - 
          197230685518800*Pi^2 + 104642277264000*Sqrt[3]*Pi^3 + 
          12255630972480*Pi^4 - 47239200*lm*(-31472963 + 107800*Pi^2) - 
          1028835722505600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          2224957250073600*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          3874754038118400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          80724042460800*Sqrt[3]*Pi*Log[3]^2 + 389375229021440*
           PolyGamma[2, 1] - 128573486213120*Zeta[3]))/408146688000 + 
       (977841006727*CF^2*NC*Zeta[3])/159432300 + 
       (13493861*CF*NM*NC*Zeta[3])/2700 - (18802*CF*NC*NL*Zeta[3])/9 - 
       (675209075668*CF*NC*NH*Zeta[3])/119574225 + 
       (CF*NC*Log[x]*(2*(4*(-486*NM*(7659997 + 26165310*lm + 5292000*lm^2 - 
                26054700*Pi^2) - 5*(243*NL*(25598377 + 10466124*lm + 
                  2116800*lm^2 + 2226840*Pi^2) + 2*NH*(49560001455 + 
                  1271634066*lm + 257191200*lm^2 - 28039032560*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]]))) + 3*CF*(-318961435341 - 
              258897759840*lm - 61725888000*lm^2 + 5366165760*Pi^2 + 
              66439541120*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              41150592000*Zeta[3])) + 3*CA*(489531085221 + 234515353680*lm + 
            37721376000*lm^2 + 412426080*Pi^2 - 66439541120*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 41150592000*Zeta[3])))/62985600, 
      (17101921833273966757*CF^2*NC)/3499857849600000 - 
       (11647553*CF^2*lm*NC)/2000 - (69069*CF^2*lm^2*NC)/10 + 
       (2168680198151*CF*NM*NC)/370440000 - (22007903*CF*lm*NM*NC)/36000 - 
       (23023*CF*lm^2*NM*NC)/60 + (29636485481*CF*NC*NL)/19440000 - 
       (22007903*CF*lm*NC*NL)/36000 - (23023*CF*lm^2*NC*NL)/60 + 
       (3536942103897917*CF*NC*NH)/29760696000 - (22007903*CF*lm*NC*NH)/
        36000 - (23023*CF*lm^2*NC*NH)/60 + (3763541983*CF^2*NC*Pi^2)/
        27216000 + (1813*CF^2*lm*NC*Pi^2)/30 + (34752223*CF*NM*NC*Pi^2)/
        32400 + (1813*CF*lm*NM*NC*Pi^2)/540 - (14167337*CF*NC*NL*Pi^2)/
        32400 + (1813*CF*lm*NC*NL*Pi^2)/540 + (1813*CF*lm*NC*NH*Pi^2)/540 - 
       (2314485664477*CF^2*NC*Pi^3)/(765275040*Sqrt[3]) - 
       (193220191241*CF*NC*NH*Pi^3)/(12754584*Sqrt[3]) - 
       (569303*CF^2*NC*Pi^4)/5400 + (76963344961529*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3188646000*Sqrt[3]) + 
       (231373228657*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2125764*Sqrt[3]) - 19586*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (330640809211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2952450*Sqrt[3]) - (55205768926*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(98415*Sqrt[3]) - 
       (330640809211*CF^2*NC*Pi*Log[3]^2)/(141717600*Sqrt[3]) - 
       (27602884463*CF*NC*NH*Pi*Log[3]^2)/(2361960*Sqrt[3]) - 
       (CF*NC*(-30*CA*(579515591 + 187407220*lm) + 
          37*CF*(1136642963 + 497296800*lm) + 
          60*(4*(-13210033 + 4259255*lm)*NM + 
            7*((3318047 + 2433860*lm)*NL + 20*(9836 + 121693*lm)*NH)))*
         Log[x]^2)/378000 - (CF*NC*(5089835*CA + 
          2*(24926952*CF - 65*(82010*NM + 9361*NL)))*Log[x]^3)/675 - 
       (28409919386447*CF^2*NC*PolyGamma[2, 1])/5739562800 + 
       (10364903*CF*NM*NC*PolyGamma[2, 1])/5400 - 
       (1083812679038*CF*NC*NH*PolyGamma[2, 1])/119574225 + 
       (CA*CF*NC*(-6991958720003140143 + 1661905312471404000*lm^2 + 
          71437358826551970*Pi^2 + 396934291457805500*Sqrt[3]*Pi^3 + 
          43625071871917200*Pi^4 - 40102537860*lm*(-118767309 + 
            362600*Pi^2) - 3167811278616533640*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 7711674282254880000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 14697909763694740800*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 306206453410307100*Sqrt[3]*
           Pi*Log[3]^2 + 1948920469910264200*PolyGamma[2, 1] - 
          2970154838488978000*Zeta[3]))/787468016160000 + 
       (10071004274753*CF^2*NC*Zeta[3])/573956280 + 
       (26591303*CF*NM*NC*Zeta[3])/2700 - (176426*CF*NC*NL*Zeta[3])/45 - 
       (1598960458966*CF*NC*NH*Zeta[3])/119574225 - 
       (CF*NC*Log[x]*(-120*(-8748*NM*(12383135392 + 5738636715*lm + 
              1166886000*lm^2 - 5664652350*Pi^2) - 
            49*(2187*NL*(1179436363 + 468460140*lm + 95256000*lm^2 + 
                104767800*Pi^2) + 10*NH*(3906873163023 + 102452232618*lm + 
                20832487200*lm^2 - 2208230757040*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]]))) - 20*CA*(4903149328106523 + 
            2085385188009060*lm + 336861318024000*lm^2 + 101069361396990*
             Pi^2 - 648055986053560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            367485074208000*Zeta[3]) + CF*(133187637473840193 + 
            91898614663531200*lm + 22049104452480000*lm^2 + 
            1884599380944000*Pi^2 - 25922239442142400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 14699402968320000*Zeta[3])))/
        2083248720000, (20283864332391673061*CF^2*NC)/1749928924800000 - 
       (8420131*CF^2*lm*NC)/750 - (62454*CF^2*lm^2*NC)/5 - 
       (3048620120687*CF*NM*NC)/555660000 - (7723103*CF*lm*NM*NC)/6750 - 
       (10409*CF*lm^2*NM*NC)/15 + (555453829*CF*NC*NL)/151875 - 
       (7723103*CF*lm*NC*NL)/6750 - (10409*CF*lm^2*NC*NL)/15 + 
       (2240976028100923098529*CF*NC*NH)/8734332745908000 - 
       (7723103*CF*lm*NC*NH)/6750 - (10409*CF*lm^2*NC*NH)/15 + 
       (31993946561*CF^2*NC*Pi^2)/7484400 + (1568*CF^2*lm*NC*Pi^2)/15 + 
       (28074556*CF*NM*NC*Pi^2)/2025 + (784*CF*lm*NM*NC*Pi^2)/135 - 
       (1760024*CF*NC*NL*Pi^2)/2025 + (784*CF*lm*NC*NL*Pi^2)/135 + 
       (784*CF*lm*NC*NH*Pi^2)/135 - (4957943539843*CF^2*NC*Pi^3)/
        (765275040*Sqrt[3]) - (481546258571*CF*NC*NH*Pi^3)/
        (14348907*Sqrt[3]) - (1205869*CF^2*NC*Pi^4)/5400 + 
       (169746365295701*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (3188646000*Sqrt[3]) + (5008910830912*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) - 
       (187054*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (708277648549*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2952450*Sqrt[3]) - (1100677162448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(885735*Sqrt[3]) - 
       (708277648549*CF^2*NC*Pi*Log[3]^2)/(141717600*Sqrt[3]) - 
       (68792322653*CF*NC*NH*Pi*Log[3]^2)/(2657205*Sqrt[3]) - 
       (CF*NC*(-55*CA*(5895586861 + 2540408640*lm) + 
          8*(11*CF*(9589004749 + 5196290400*lm) + 
            10*(33*(-241792361 + 9622760*lm)*NM + 462*(925993 + 687340*lm)*
               NL + 5*(6218561 + 63510216*lm)*NH)))*Log[x]^2)/4158000 - 
       (8*CF*NC*(2068475*CA + 14386656*CF - 6999400*NM - 343670*NL)*
         Log[x]^3)/675 - (3087236867372*CF^2*NC*PolyGamma[2, 1])/358722675 + 
       (2204294*CF*NM*NC*PolyGamma[2, 1])/135 - 
       (38405009312171*CF*NC*NH*PolyGamma[2, 1])/2152336050 + 
       (CA*CF*NC*(-34596617169339414846 + 7513691698525320000*lm^2 - 
          3505440470729247225*Pi^2 + 2125718292707686250*Sqrt[3]*Pi^3 + 
          228957237119835000*Pi^4 - 145827410400*lm*(-150530833 + 
            431200*Pi^2) - 17466900988927632900*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 36824760573698160000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 78712311638547468000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1639839825803072250*
           Sqrt[3]*Pi*Log[3]^2 + 8471377964068768000*PolyGamma[2, 1] - 
          7533198444869062000*Zeta[3]))/1968670040400000 + 
       (19750982282833*CF^2*NC*Zeta[3])/717445350 + 
       (3357988*CF*NM*NC*Zeta[3])/135 - (383912*CF*NC*NL*Zeta[3])/45 - 
       (4378712754491*CF*NC*NH*Zeta[3])/1076168025 + 
       CF*Log[x]*((76320871511*NM*NC)/1984500 - (4011952*lm*NM*NC)/675 - 
         1176*lm^2*NM*NC - (320909147*NC*NL)/20250 - (4011952*lm*NC*NL)/
          675 - 1176*lm^2*NC*NL - (76994667681235067*NC*NH)/315091368900 - 
         (4011952*lm*NC*NH)/675 - 1176*lm^2*NC*NH + (2514476*NM*NC*Pi^2)/
          135 - (190388*NC*NL*Pi^2)/135 + (1100677162448*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) + 
         CF*NC*(-36143187613385917/347208120000 - (6833204*lm)/75 - 
           21168*lm^2 + (746969*Pi^2)/600 + (708277648549*
             Im[PolyLog[2, (-1)^(1/3)]])/(8857350*Sqrt[3]) - 14112*Zeta[3]) + 
         CA*NC*(28936550522991773/347208120000 + (27622336*lm)/675 + 
           6468*lm^2 + (1767919*Pi^2)/3600 - 
           (708277648549*Im[PolyLog[2, (-1)^(1/3)]])/(17714700*Sqrt[3]) + 
           7056*Zeta[3])), (924665687241999656929*CF^2*NC)/
        15749360323200000 - (229794283*CF^2*lm*NC)/13500 - 
       19642*CF^2*lm^2*NC - (324040942491361*CF*NM*NC)/38578680000 - 
       (428669533*CF*lm*NM*NC)/243000 - (9821*CF*lm^2*NM*NC)/9 + 
       (49871142907*CF*NC*NL)/7290000 - (428669533*CF*lm*NC*NL)/243000 - 
       (9821*CF*lm^2*NC*NL)/9 + (22025171208452682472061*CF*NC*NH)/
        52405996475448000 - (428669533*CF*lm*NC*NH)/243000 - 
       (9821*CF*lm^2*NC*NH)/9 - (70585836731*CF^2*NC*Pi^2)/4158000 + 
       (6664*CF^2*lm*NC*Pi^2)/45 + (223799201*CF*NM*NC*Pi^2)/12150 + 
       (3332*CF*lm*NM*NC*Pi^2)/405 - (5846923*CF*NC*NL*Pi^2)/4050 + 
       (3332*CF*lm*NC*NL*Pi^2)/405 + (3332*CF*lm*NC*NH*Pi^2)/405 - 
       (15915453742363*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (2378046066053*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (6210323*CF^2*NC*Pi^4)/16200 + (470200235747381*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5739562800*Sqrt[3]) + 
       (5156267512106*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (14348907*Sqrt[3]) - (310982*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (2273636248909*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5314410*Sqrt[3]) - (5435533865264*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (2273636248909*CF^2*NC*Pi*Log[3]^2)/(255091680*Sqrt[3]) - 
       (339720866579*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-33*CA*(325616541067 + 67416333600*lm) + 
          8*(66*CF*(46238498207 + 13789704600*lm) + 
            385*(-2416486427 + 131330520*lm)*NM + 67124832390*NL + 
            50562250200*lm*NL + 5446652275*NH + 50562250200*lm*NH))*
         Log[x]^2)/37422000 - (4*CF*NC*(1017417*CA + 203387753*CF - 
          67817600*NM - 3648070*NL)*Log[x]^3)/2025 - 
       (214531920808919*CF^2*NC*PolyGamma[2, 1])/6457008150 + 
       (78061639*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (394028753559703*CF*NC*NH*PolyGamma[2, 1])/12914016300 + 
       (CA*CF*NC*(-873757178311900893174 + 106338696567226200000*lm^2 + 
          162118693584178992675*Pi^2 + 34118753960190681250*Sqrt[3]*Pi^3 + 
          3512747716689519000*Pi^4 - 36456852600*lm*(-8427702863 + 
            21991200*Pi^2) - 241918021292027524500*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 550998851853305520000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 1263368718068774940000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 26320181626432811250*
           Sqrt[3]*Pi*Log[3]^2 + 294337795349836868000*PolyGamma[2, 1] - 
          292850662217567174000*Zeta[3]))/17718030363600000 + 
       (431067069882299*CF^2*NC*Zeta[3])/6457008150 + 
       (67948039*CF*NM*NC*Zeta[3])/1350 - (667252*CF*NC*NL*Zeta[3])/45 - 
       (93013301046823*CF*NC*NH*Zeta[3])/6457008150 + 
       CF*Log[x]*((-320448349*NM*NC)/7654500 - (2222599*lm*NM*NC)/225 - 
         1960*lm^2*NM*NC - (550064287*NC*NL)/20250 - (2222599*lm*NC*NL)/
          225 - 1960*lm^2*NC*NL - (380520910374303029*NC*NH)/945274106700 - 
         (2222599*lm*NC*NH)/225 - 1960*lm^2*NC*NH + (11975348*NM*NC*Pi^2)/
          405 - (994214*NC*NL*Pi^2)/405 + (5435533865264*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-1012541013784499777/3124873080000 - (3783698*lm)/25 - 
           35280*lm^2 - (302671057*Pi^2)/16200 + 
           (2273636248909*Im[PolyLog[2, (-1)^(1/3)]])/(15943230*Sqrt[3]) - 
           23520*Zeta[3]) + CA*NC*(673919164614516277/3124873080000 + 
           (30622589*lm)/450 + 10780*lm^2 + (121849889*Pi^2)/10800 - 
           (2273636248909*Im[PolyLog[2, (-1)^(1/3)]])/(31886460*Sqrt[3]) + 
           11760*Zeta[3])), (874768377670873972409*CF^2*NC)/
        15749360323200000 - (132689651*CF^2*lm*NC)/4500 - 
       (162666*CF^2*lm^2*NC)/5 - (891940750023733*CF*NM*NC)/3214890000 - 
       (242489201*CF*lm*NM*NC)/81000 - (9037*CF*lm^2*NM*NC)/5 + 
       (8679952631*CF*NC*NL)/607500 - (242489201*CF*lm*NC*NL)/81000 - 
       (9037*CF*lm^2*NC*NL)/5 + (3348617254197941105209493*CF*NC*NH)/
        4111999080591402000 - (242489201*CF*lm*NC*NH)/81000 - 
       (9037*CF*lm^2*NC*NH)/5 + (588995083847*CF^2*NC*Pi^2)/37422000 + 
       (1176*CF^2*lm*NC*Pi^2)/5 + (340485541*CF*NM*NC*Pi^2)/2025 + 
       (196*CF*lm*NM*NC*Pi^2)/15 - (1165477*CF*NC*NL*Pi^2)/450 + 
       (196*CF*lm*NC*NL*Pi^2)/15 + (196*CF*lm*NC*NH*Pi^2)/15 - 
       (151795911169903*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) - 
       (4677438945928*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (1288931*CF^2*NC*Pi^4)/1800 + (4603214065851761*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(28697814000*Sqrt[3]) + 
       (46065880641364*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (71744535*Sqrt[3]) - 108318*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (21685130167129*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) - (10691289019264*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (21685130167129*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) - 
       (668205563704*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-2145*CA*(20288486177 + 8945761440*lm) + 
          16*(429*CF*(16567002751 + 9149074200*lm) + 
            35*(143*(-3985585207 + 43567020*lm)*NM + 1287*(6379721 + 
                4840780*lm)*NL + 5*(153189433 + 1246016772*lm)*NH)))*
         Log[x]^2)/162162000 - (CF*NC*(57367903*CA + 473193370*CF - 
          502483800*NM - 9681560*NL)*Log[x]^3)/675 - 
       (24703534226323*CF^2*NC*PolyGamma[2, 1])/645700815 + 
       (516438833*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (142392376833491*CF*NC*NH*PolyGamma[2, 1])/2582803260 + 
       CA*CF*NC*(-61077770593517878663/984335020200000 + (99407*lm^2)/10 - 
         (94232350691*Pi^2)/14256000 + (151795911169903*Pi^3)/
          (13774950720*Sqrt[3]) + (1326563*Pi^4)/3600 + 
         lm*(4716972811/162000 - (1078*Pi^2)/15) - 
         (4603214065851761*Im[PolyLog[2, (-1)^(1/3)]])/(57395628000*
           Sqrt[3]) + 54159*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (21685130167129*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (53144100*Sqrt[3]) + (21685130167129*Pi*Log[3]^2)/
          (2550916800*Sqrt[3]) + (24703534226323*PolyGamma[2, 1])/
          1291401630 - (57828019887901*Zeta[3])/5165606520) + 
       (107957080617233*CF^2*NC*Zeta[3])/1291401630 + 
       (181614833*CF*NM*NC*Zeta[3])/1350 - (1292732*CF*NC*NL*Zeta[3])/45 + 
       (6049265110025*CF*NC*NH*Zeta[3])/258280326 + 
       CF*Log[x]*((920391533431*NM*NC)/1275750 - (1361293*lm*NM*NC)/75 - 
         3528*lm^2*NM*NC - (236596051*NC*NL)/4500 - (1361293*lm*NC*NL)/
          75 - 3528*lm^2*NC*NL - (18071873627907696799*NC*NH)/
          22821617718900 - (1361293*lm*NC*NH)/75 - 3528*lm^2*NC*NH + 
         (8069992*NM*NC*Pi^2)/45 - (642838*NC*NL*Pi^2)/135 + 
         (10691289019264*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7971615*Sqrt[3]) + CF*NC*(-757916435724833941/3124873080000 - 
           (6977058*lm)/25 - 63504*lm^2 + (4058047*Pi^2)/1800 + 
           (21685130167129*Im[PolyLog[2, (-1)^(1/3)]])/(79716150*Sqrt[3]) - 
           42336*Zeta[3]) + CA*NC*(689795802228688559/3124873080000 + 
           (18678623*lm)/150 + 19404*lm^2 + (5595317*Pi^2)/2160 - 
           (21685130167129*Im[PolyLog[2, (-1)^(1/3)]])/(159432300*Sqrt[3]) + 
           21168*Zeta[3])), (267599976208214614989844319*CF^2*NC)/
        440210370393763200000 - (9430046417*CF^2*lm*NC)/220500 - 
       (242658*CF^2*lm^2*NC)/5 - (48277715046890672657*CF*NM*NC)/
        119812520520000 - (17455959767*CF*lm*NM*NC)/3969000 - 
       (13481*CF*lm^2*NM*NC)/5 + (2937954295463*CF*NC*NL)/119070000 - 
       (17455959767*CF*lm*NC*NL)/3969000 - (13481*CF*lm^2*NC*NL)/5 + 
       (13304765320492584515956597*CF*NC*NH)/10466906750596296000 - 
       (17455959767*CF*lm*NC*NH)/3969000 - (13481*CF*lm^2*NC*NH)/5 - 
       (23183334580277*CF^2*NC*Pi^2)/87318000 + (1608*CF^2*lm*NC*Pi^2)/5 + 
       (5669949527*CF*NM*NC*Pi^2)/28350 + (268*CF*lm*NM*NC*Pi^2)/15 - 
       (12787277*CF*NC*NL*Pi^2)/3150 + (268*CF*lm*NC*NL*Pi^2)/15 + 
       (268*CF*lm*NC*NH*Pi^2)/15 - (251942871849047*CF^2*NC*Pi^3)/
        (6887475360*Sqrt[3]) - (7330645203119*CF*NC*NH*Pi^3)/
        (43046721*Sqrt[3]) - (691321*CF^2*NC*Pi^4)/600 + 
       (1008482452757197123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (4218578658000*Sqrt[3]) + (74420151271366*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) - 
       (848934*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (251942871849047*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (186004350*Sqrt[3]) - (16755760464272*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (251942871849047*CF^2*NC*Pi*Log[3]^2)/(8928208800*Sqrt[3]) - 
       (1047235029017*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-39*CA*(64031671478741 + 5716272223200*lm) + 
          40*(39*CF*(3390987813901 + 467695000080*lm) + 
            7*(13*(-723421515679 + 11135595240*lm)*NM + 
              11*(1638*(10464293 + 8034340*lm)*NL + 5*(349149901 + 
                  2632049784*lm)*NH))))*Log[x]^2)/1135134000 + 
       (2*CF*NC*(794933799*CA + 28*(-183926261*CF + 86908650*NM + 
            2008585*NL))*Log[x]^3)/4725 - (5371719412386529*CF^2*NC*
         PolyGamma[2, 1])/19371024450 + (857173961*CF*NM*NC*PolyGamma[2, 1])/
        2700 - (3441039436652939*CF*NC*NH*PolyGamma[2, 1])/38742048900 + 
       CA*CF*NC*(-1974957291135237195166577/5502629629922040000 + 
         (148291*lm^2)/10 + (18841253198137*Pi^2)/139708800 + 
         (251942871849047*Pi^3)/(13774950720*Sqrt[3]) + (708473*Pi^4)/1200 + 
         lm*(341832606637/7938000 - (1474*Pi^2)/15) - 
         (1008482452757197123*Im[PolyLog[2, (-1)^(1/3)]])/
          (8437157316000*Sqrt[3]) + (424467*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (251942871849047*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (372008700*Sqrt[3]) + (251942871849047*Pi*Log[3]^2)/
          (17856417600*Sqrt[3]) + (5371719412386529*PolyGamma[2, 1])/
          38742048900 - (6553853799190981*Zeta[3])/108477736920) + 
       (29711332243598359*CF^2*NC*Zeta[3])/135597171150 + 
       (438498761*CF*NM*NC*Zeta[3])/1350 - (2115476*CF*NC*NL*Zeta[3])/45 + 
       (406851853734181*CF*NC*NH*Zeta[3])/19371024450 + 
       CF*Log[x]*((17815785144173*NM*NC)/44104500 - (14951663*lm*NM*NC)/
          525 - 5544*lm^2*NM*NC - (2010817862*NC*NL)/23625 - 
         (14951663*lm*NC*NL)/525 - 5544*lm^2*NC*NL - 
         (18034553268696097963*NC*NH)/14522847639300 - (14951663*lm*NC*NH)/
          525 - 5544*lm^2*NC*NH + (11062636*NM*NC*Pi^2)/45 - 
         (1052914*NC*NL*Pi^2)/135 + (16755760464272*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-6098128089888296580359/2646767498760000 - 
           (76612278*lm)/175 - 99792*lm^2 - (989898437*Pi^2)/4200 + 
           (251942871849047*Im[PolyLog[2, (-1)^(1/3)]])/(558013050*Sqrt[3]) - 
           66528*Zeta[3]) + CA*NC*(496190010999936733201/378109642680000 + 
           (205216693*lm)/1050 + 30492*lm^2 + (9370199159*Pi^2)/75600 - 
           (251942871849047*Im[PolyLog[2, (-1)^(1/3)]])/(1116026100*
             Sqrt[3]) + 33264*Zeta[3])), (14392834434554843126116199*CF^2*NC)/
        88042074078752640000 - (302709817*CF^2*lm*NC)/4410 - 
       75342*CF^2*lm^2*NC - (9114468332920919281*CF*NM*NC)/2396250410400 - 
       (275951741*CF*lm*NM*NC)/39690 - (12557*CF*lm^2*NM*NC)/3 + 
       (110735707651*CF*NC*NL)/2381400 - (275951741*CF*lm*NC*NL)/39690 - 
       (12557*CF*lm^2*NC*NL)/3 + (235173833966218277750993279*CF*NC*NH)/
        103622376830903330400 - (275951741*CF*lm*NC*NH)/39690 - 
       (12557*CF*lm^2*NC*NH)/3 + (270265846921111*CF^2*NC*Pi^2)/2554051500 + 
       480*CF^2*lm*NC*Pi^2 + (5210233514*CF*NM*NC*Pi^2)/2835 + 
       (80*CF*lm*NM*NC*Pi^2)/3 - (425428*CF*NC*NL*Pi^2)/63 + 
       (80*CF*lm*NC*NL*Pi^2)/3 + (80*CF*lm*NC*NH*Pi^2)/3 - 
       (441527225583907*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) - 
       (39633687581915*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) - 
       (10641061*CF^2*NC*Pi^4)/5400 + (1810675055734537523*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4218578658000*Sqrt[3]) + 
       (1127331396310552*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (645700815*Sqrt[3]) - (1380094*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (441527225583907*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (186004350*Sqrt[3]) - (18118257180304*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (441527225583907*CF^2*NC*Pi*Log[3]^2)/(8928208800*Sqrt[3]) - 
       (1132391073769*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) - 
       (CF*NC*(-13*CA*(118450280051273 + 93374492904000*lm) + 
          16*(13*CF*(22886623229329 + 19099328094000*lm) + 
            525*(13*(-682917753559 + 2021092920*lm)*NM + 18018*(1890359 + 
                1458220*lm)*NL + (3841513759 + 26274207960*lm)*NH)))*
         Log[x]^2)/3405402000 - (2*CF*NC*(2303825767*CA + 
          6*(2682466047*CF - 700*(11701452*NM + 72911*NL)))*Log[x]^3)/
        14175 - (5448481212176396*CF^2*NC*PolyGamma[2, 1])/29056536675 + 
       (2720839687*CF*NM*NC*PolyGamma[2, 1])/1350 - 
       (13081777030662898*CF*NC*NH*PolyGamma[2, 1])/87169610025 + 
       (647631228763723*CF^2*NC*Zeta[3])/16271660538 + 
       (640421887*CF*NM*NC*Zeta[3])/675 - (752488*CF*NC*NL*Zeta[3])/9 + 
       (11877263753584204*CF*NC*NH*Zeta[3])/87169610025 + 
       CA*CF*NC*(-58959384090045373959667/343914351870127500 + 
         (138127*lm^2)/6 - (103267342894649*Pi^2)/2095632000 + 
         (441527225583907*Pi^3)/(13774950720*Sqrt[3]) + 
         (10871461*Pi^4)/10800 + lm*(5361276691/79380 - (440*Pi^2)/3) - 
         (1810675055734537523*Im[PolyLog[2, (-1)^(1/3)]])/
          (8437157316000*Sqrt[3]) + (690047*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (441527225583907*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (372008700*Sqrt[3]) + (441527225583907*Pi*Log[3]^2)/
          (17856417600*Sqrt[3]) + (2724240606088198*PolyGamma[2, 1])/
          29056536675 + (103213096945568917*Zeta[3])/1627166053800) + 
       CF*Log[x]*((816241773668117*NM*NC)/86444820 - (5064572*lm*NM*NC)/
          105 - 9240*lm^2*NM*NC - (142852177*NC*NL)/945 - 
         (5064572*lm*NC*NL)/105 - 9240*lm^2*NC*NL - 
         (1072552435114098214733*NC*NH)/479253972096900 - 
         (5064572*lm*NC*NH)/105 - 9240*lm^2*NC*NH + (15434612*NM*NC*Pi^2)/
          9 - (374804*NC*NL*Pi^2)/27 + (18118257180304*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(75339176313347656499/378109642680000 - (26021532*lm)/35 - 
           166320*lm^2 + (57317431*Pi^2)/1512 + 
           (441527225583907*Im[PolyLog[2, (-1)^(1/3)]])/(558013050*Sqrt[3]) - 
           110880*Zeta[3]) + CA*NC*(92408460856580143327/529353499752000 + 
           (34646546*lm)/105 + 50820*lm^2 - (1862665463*Pi^2)/226800 - 
           (441527225583907*Im[PolyLog[2, (-1)^(1/3)]])/(1116026100*
             Sqrt[3]) + 55440*Zeta[3])), 
      (23227573158672520196703562915223*CF^2*NC)/3481711861518351901440000 - 
       (13554476273*CF^2*lm*NC)/141120 - (215631*CF^2*lm^2*NC)/2 - 
       (4110016607119323956546353*CF*NM*NC)/842329944263808000 - 
       (24965668793*CF*lm*NM*NC)/2540160 - (23959*CF*lm^2*NM*NC)/4 + 
       (11514045366577*CF*NC*NL)/152409600 - (24965668793*CF*lm*NC*NL)/
        2540160 - (23959*CF*lm^2*NC*NL)/4 + (5132095780803743010744041017*CF*
         NC*NH)/1507234572085866624000 - (24965668793*CF*lm*NC*NH)/
        2540160 - (23959*CF*lm^2*NC*NH)/4 - (1204411146121121*CF^2*NC*Pi^2)/
        370656000 + (1275*CF^2*lm*NC*Pi^2)/2 + (17042475559*CF*NM*NC*Pi^2)/
        9072 + (425*CF*lm*NM*NC*Pi^2)/12 - (5094953*CF*NC*NL*Pi^2)/504 + 
       (425*CF*lm*NC*NL*Pi^2)/12 + (425*CF*lm*NC*NH*Pi^2)/12 - 
       (12479759231629531*CF^2*NC*Pi^3)/(123974556480*Sqrt[3]) - 
       (238658031374735*CF*NC*NH*Pi^3)/(516560652*Sqrt[3]) - 
       (3615973*CF^2*NC*Pi^4)/1200 + (94453493683671695233*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(151868831688000*Sqrt[3]) + 
       (6948441447428911*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2582803260*Sqrt[3]) - (2065239*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (12479759231629531*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3348078300*Sqrt[3]) - (27275203585684*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (12479759231629531*CF^2*NC*Pi*Log[3]^2)/(160707758400*Sqrt[3]) - 
       (6818800896421*CF*NC*NH*Pi*Log[3]^2)/(19131876*Sqrt[3]) - 
       (CF*NC*(-(CA*(96355802475935627 + 2552329627848000*lm)) + 
          8*(CF*(24514208909897327 + 1044134847756000*lm) + 
            175*(5*(-14467537007431 + 66294276048*lm)*NM + 
              11*(3276*(11810123 + 9198340*lm)*NL + 5*(937434065 + 
                  6026752368*lm)*NH))))*Log[x]^2)/4540536000 + 
       (CF*NC*(95560041063*CA - 281649669202*CF + 
          2800*(54076521*NM + 459917*NL))*Log[x]^3)/18900 - 
       (152605324717065083*CF^2*NC*PolyGamma[2, 1])/55788550416 + 
       (837338549*CF*NM*NC*PolyGamma[2, 1])/270 - 
       (5957028737475667*CF*NC*NH*PolyGamma[2, 1])/25828032600 + 
       CA*CF*NC*(-48372148102278798606451981560961/
          13926847446073407605760000 + (263549*lm^2)/8 + 
         (650795775423809*Pi^2)/399168000 + (12479759231629531*Pi^3)/
          (247949112960*Sqrt[3]) + (1227991*Pi^4)/800 + 
         lm*(487631283763/5080320 - (4675*Pi^2)/24) - 
         (94453493683671695233*Im[PolyLog[2, (-1)^(1/3)]])/
          (303737663376000*Sqrt[3]) + (2065239*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          10 + (12479759231629531*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6696156600*Sqrt[3]) + (12479759231629531*Pi*Log[3]^2)/
          (321415516800*Sqrt[3]) + (152605324717065083*PolyGamma[2, 1])/
          111577100832 - (685948499747150461*Zeta[3])/2440749080700) + 
       (1996907066297732903*CF^2*NC*Zeta[3])/2440749080700 + 
       (377906174*CF*NM*NC*Zeta[3])/135 - (1173139*CF*NC*NL*Zeta[3])/9 + 
       (2260960503224933*CF*NC*NH*Zeta[3])/12914016300 + 
       CF*Log[x]*((6739225382835013171*NM*NC)/1168733966400 - 
         (60726773*lm*NM*NC)/840 - 13860*lm^2*NM*NC - (1413175307*NC*NL)/
          6048 - (60726773*lm*NC*NL)/840 - 13860*lm^2*NC*NL - 
         (2349631754278400837827*NC*NH)/697096686686400 - 
         (60726773*lm*NC*NH)/840 - 13860*lm^2*NC*NH + 
         (17753540*NM*NC*Pi^2)/9 - (584657*NC*NL*Pi^2)/27 + 
         (27275203585684*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CF*NC*(-360670123932706837273108193/
            16102933462455840000 - (155984919*lm)/140 - 249480*lm^2 - 
           (13740402719*Pi^2)/5040 + (12479759231629531*
             Im[PolyLog[2, (-1)^(1/3)]])/(10044234900*Sqrt[3]) - 
           166320*Zeta[3]) + CA*NC*(74844333224588640568819471/
            6441173384982336000 + (830988103*lm)/1680 + 76230*lm^2 + 
           (208644078763*Pi^2)/151200 - (12479759231629531*
             Im[PolyLog[2, (-1)^(1/3)]])/(20088469800*Sqrt[3]) + 
           83160*Zeta[3])), (-41114866691849775212167606961*CF^2*NC)/
        57548956388733089280000 - (20542237517*CF^2*lm*NC)/141120 - 
       (318483*CF^2*lm^2*NC)/2 - (7234524718455573418239413*CF*NM*NC)/
        168465988852761600 - (37396357877*CF*lm*NM*NC)/2540160 - 
       (35387*CF*lm^2*NM*NC)/4 + (28093907277869*CF*NC*NL)/213373440 - 
       (37396357877*CF*lm*NC*NL)/2540160 - (35387*CF*lm^2*NC*NL)/4 + 
       (4180474327021776519451285020906893*CF*NC*NH)/
        733099301813128409647488000 - (37396357877*CF*lm*NC*NH)/2540160 - 
       (35387*CF*lm^2*NC*NH)/4 + (1645319445696307*CF^2*NC*Pi^2)/
        1238328000 + (1815*CF^2*lm*NC*Pi^2)/2 + (888144143501*CF*NM*NC*Pi^2)/
        45360 + (605*CF*lm*NM*NC*Pi^2)/12 - (333223*CF*NC*NL*Pi^2)/21 + 
       (605*CF*lm*NC*NL*Pi^2)/12 + (605*CF*lm*NC*NH*Pi^2)/12 - 
       (640559491010423*CF^2*NC*Pi^3)/(3874204890*Sqrt[3]) - 
       (3619369174299865*CF*NC*NH*Pi^3)/(4649045868*Sqrt[3]) - 
       (1085854*CF^2*NC*Pi^4)/225 + (79352108292678175319*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(75934415844000*Sqrt[3]) + 
       (701549495715919811*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (162716605380*Sqrt[3]) - (3182784*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (5124475928083384*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(837019575*Sqrt[3]) - 
       (413642191348556*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) - (640559491010423*CF^2*NC*Pi*Log[3]^2)/
        (5022117450*Sqrt[3]) - (103410547837139*CF*NC*NH*Pi*Log[3]^2)/
        (172186884*Sqrt[3]) - 
       (CF*NC*(-187*CA*(-524785930060627 + 98136748710000*lm) + 
          14*(748*CF*(-16323585980761 + 5735264535000*lm) + 
            125*(119*(-21733447736353 + 16022326320*lm)*NM + 
              6738732*(362147 + 282940*lm)*NL + (319661012249 + 
                1906656832080*lm)*NH)))*Log[x]^2)/19297278000 - 
       (CF*NC*(44603746447*CA + 8*(9142144859*CF - 1750*(92847345*NM + 
              155617*NL)))*Log[x]^3)/18900 - 
       (68614858253978753*CF^2*NC*PolyGamma[2, 1])/69735688020 + 
       (27689462563*CF*NM*NC*PolyGamma[2, 1])/1350 - 
       (772634199567955657*CF*NC*NH*PolyGamma[2, 1])/2092070640600 - 
       (2871503782168219591*CF^2*NC*Zeta[3])/1220374540350 + 
       (5184049888*CF*NM*NC*Zeta[3])/675 - (1953655*CF*NC*NL*Zeta[3])/9 + 
       (493827959637582143*CF*NC*NH*Zeta[3])/1046035320300 + 
       CA*CF*NC*(16335068311959366251374991747/115097912777466178560000 + 
         (389257*lm^2)/8 - (540914177250539*Pi^2)/825552000 + 
         (640559491010423*Pi^3)/(7748409780*Sqrt[3]) + (552002*Pi^4)/225 + 
         lm*(725970183367/5080320 - (6655*Pi^2)/24) - 
         (79352108292678175319*Im[PolyLog[2, (-1)^(1/3)]])/
          (151868831688000*Sqrt[3]) + (1591392*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          5 + (2562237964041692*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (837019575*Sqrt[3]) + (640559491010423*Pi*Log[3]^2)/
          (10044234900*Sqrt[3]) + (68614858253978753*PolyGamma[2, 1])/
          139471376040 + (6746930881470681533*Zeta[3])/4881498161400) + 
       CF*Log[x]*((25517061599022204359*NM*NC)/233746793280 - 
         (6444295*lm*NM*NC)/56 - 21780*lm^2*NM*NC - (16448820151*NC*NL)/
          42336 - (6444295*lm*NC*NL)/56 - 21780*lm^2*NC*NL - 
         (113269646897948815637848063*NC*NH)/19944633302784590400 - 
         (6444295*lm*NC*NH)/56 - 21780*lm^2*NC*NH + (154338014*NM*NC*Pi^2)/
          9 - (974105*NC*NL*Pi^2)/27 + (413642191348556*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(1408580976834228058722097/133082094731040000 - 
           (49765815*lm)/28 - 392040*lm^2 + (705953299*Pi^2)/840 + 
           (5124475928083384*Im[PolyLog[2, (-1)^(1/3)]])/(2511058725*
             Sqrt[3]) - 261360*Zeta[3]) + CA*NC*(-122841314225946623897953/
            26616418946208000 + (87962765*lm)/112 + 119790*lm^2 - 
           (29672388731*Pi^2)/75600 - (2562237964041692*
             Im[PolyLog[2, (-1)^(1/3)]])/(2511058725*Sqrt[3]) + 
           130680*Zeta[3])), (14279217761037051948586074448217519*CF^2*NC)/
        188012440521991002677760000 - (107641770473*CF^2*lm*NC)/544320 - 
       (440671*CF^2*lm^2*NC)/2 - (9209321557794769185816731*CF*NM*NC)/
        194383833291648000 - (197591534993*CF*lm*NM*NC)/9797760 - 
       (440671*CF*lm^2*NM*NC)/36 + (3261566147371601*CF*NC*NL)/
        16003008000 - (197591534993*CF*lm*NC*NL)/9797760 - 
       (440671*CF*lm^2*NC*NL)/36 + (4964506665291772878628534944944417*CF*NC*
         NH)/599808519665286880620672000 - (197591534993*CF*lm*NC*NH)/
        9797760 - (440671*CF*lm^2*NC*NH)/36 - 
       (18377431017613258543*CF^2*NC*Pi^2)/490377888000 + 
       (21175*CF^2*lm*NC*Pi^2)/18 + (6868931380931*CF*NM*NC*Pi^2)/408240 + 
       (21175*CF*lm*NM*NC*Pi^2)/324 - (133459073*CF*NC*NL*Pi^2)/5832 + 
       (21175*CF*lm*NC*NL*Pi^2)/324 + (21175*CF*lm*NC*NH*Pi^2)/324 - 
       (831508677887583887*CF^2*NC*Pi^3)/(3347313024960*Sqrt[3]) - 
       (47416727298429335*CF*NC*NH*Pi^3)/(41841412812*Sqrt[3]) - 
       (229484321*CF^2*NC*Pi^4)/32400 + (6057034758775612535801*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4100458455576000*Sqrt[3]) + 
       (1872702317701745525*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (292889889684*Sqrt[3]) - (13762067*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/15 - (831508677887583887*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(90398114100*Sqrt[3]) - 
       (5419054548391924*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) - (831508677887583887*CF^2*NC*Pi*Log[3]^2)/
        (4339109476800*Sqrt[3]) - (1354763637097981*CF*NC*NH*Pi*Log[3]^2)/
        (1549681956*Sqrt[3]) - 
       (CF*NC*(-153*CA*(1040886515394036737 + 6530531343336000*lm) + 
          2*(17*CF*(9407304779329193567 + 96176916147312000*lm) + 
            2100*(663*(-50217770968187 + 65240073360*lm)*NM + 
              121*(167076*(2716857 + 2139580*lm)*NL + 5*(12618702025 + 
                  71494493616*lm)*NH))))*Log[x]^2)/694702008000 + 
       (CF*NC*(10375719685187*CA + 12*(-1920319980289*CF + 
            2100*(441949109*NM + 1176769*NL)))*Log[x]^3)/170100 - 
       (217898425134121584823*CF^2*NC*PolyGamma[2, 1])/7531454306160 + 
       (117267591539*CF*NM*NC*PolyGamma[2, 1])/4050 - 
       (2056921148967486361*CF*NC*NH*PolyGamma[2, 1])/3765727153080 + 
       CA*CF*NC*(-2879810660228842982732675535266143/
          75204976208796401071104000 + (4847381*lm^2)/72 + 
         (1671884318591075213*Pi^2)/89159616000 + (831508677887583887*Pi^3)/
          (6694626049920*Sqrt[3]) + (77624107*Pi^4)/21600 + 
         lm*(3852569155963/19595520 - (232925*Pi^2)/648) - 
         (6057034758775612535801*Im[PolyLog[2, (-1)^(1/3)]])/
          (8200916911152000*Sqrt[3]) + (13762067*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/30 + (831508677887583887*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(180796228200*Sqrt[3]) + 
         (831508677887583887*Pi*Log[3]^2)/(8678218953600*Sqrt[3]) + 
         (217898425134121584823*PolyGamma[2, 1])/15062908612320 - 
         (185984591005311954367*Zeta[3])/65900225178900) + 
       (206061327648786064603*CF^2*NC*Zeta[3])/32950112589450 + 
       (54153871814*CF*NM*NC*Zeta[3])/2025 - (8780629*CF*NC*NL*Zeta[3])/
        27 + (1191079190612591039*CF*NC*NH*Zeta[3])/1882863576540 + 
       CF*Log[x]*((1091416844615383919*NM*NC)/17980522560 - 
         (1615061591*lm*NM*NC)/9720 - 31460*lm^2*NM*NC - 
         (1835495127887*NC*NL)/3175200 - (1615061591*lm*NC*NL)/9720 - 
         31460*lm^2*NC*NL - (2754086070887864777708827*NC*NH)/
          333027272217182400 - (1615061591*lm*NC*NH)/9720 - 
         31460*lm^2*NC*NH + 16298288*NM*NC*Pi^2 - (1459909*NC*NL*Pi^2)/
          27 + (5419054548391924*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(-26479539124126224461381111269/
            108694800871576920000 - (1385718191*lm)/540 - 566280*lm^2 - 
           (844138520989*Pi^2)/27216 + (831508677887583887*
             Im[PolyLog[2, (-1)^(1/3)]])/(271194342300*Sqrt[3]) - 
           377520*Zeta[3]) + CA*NC*(21357279264657000586937391347/
            173911681394523072000 + (22046754301*lm)/19440 + 173030*lm^2 + 
           (21160096655737*Pi^2)/1360800 - (831508677887583887*
             Im[PolyLog[2, (-1)^(1/3)]])/(542388684600*Sqrt[3]) + 
           188760*Zeta[3])), (-150955042667045956598584753335143*CF^2*NC)/
        6267081350733033422592000 - (5687058154*CF^2*lm*NC)/19845 - 
       312807*CF^2*lm^2*NC - (2502513937708466271997763*CF*NM*NC)/
        5399550924768000 - (41371197361*CF*lm*NM*NC)/1428840 - 
       (104269*CF*lm^2*NM*NC)/6 + (95481849420677*CF*NC*NL)/285768000 - 
       (41371197361*CF*lm*NC*NL)/1428840 - (104269*CF*lm^2*NC*NL)/6 + 
       (446901101639513645084223506090570620739*CF*NC*NH)/
        33941214750169672391961811296000 - (41371197361*CF*lm*NC*NH)/
        1428840 - (104269*CF*lm^2*NC*NH)/6 + 
       (422216054737925377*CF^2*NC*Pi^2)/23351328000 + 
       (4840*CF^2*lm*NC*Pi^2)/3 + (1770677868559*CF*NM*NC*Pi^2)/8505 + 
       (2420*CF*lm*NM*NC*Pi^2)/27 - (58349390*CF*NC*NL*Pi^2)/1701 + 
       (2420*CF*lm*NC*NL*Pi^2)/27 + (2420*CF*lm*NC*NH*Pi^2)/27 - 
       (432505840297542859*CF^2*NC*Pi^3)/(1115771008320*Sqrt[3]) - 
       (56813060313531760*CF*NC*NH*Pi^3)/(31381059609*Sqrt[3]) - 
       (116423197*CF^2*NC*Pi^4)/10800 + (3218607760053487454917*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1366819485192000*Sqrt[3]) + 
       (10804123623401697296*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1098337086315*Sqrt[3]) - (6774119*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (432505840297542859*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(30132704700*Sqrt[3]) - 
       (25971684714757376*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) - (432505840297542859*CF^2*NC*Pi*Log[3]^2)/
        (1446369825600*Sqrt[3]) - (1623230294672336*CF*NC*NH*Pi*Log[3]^2)/
        (1162261467*Sqrt[3]) + CF*((1361383012855965581*CF*NC)/6810804000 - 
         7534472*CF*lm*NC + CA*(-460990708472005253/4540536000 + 
           (20719798*lm)/9)*NC + (22250953793029*NM*NC)/8910 - 
         (3767236*lm*NM*NC)/9 - (23867602*NC*NL)/45 - (3767236*lm*NC*NL)/
          9 - (978076349333*NC*NH)/12471030 - (3767236*lm*NC*NH)/9)*
        Log[x]^2 + (CF*NC*(-402448483074*CA + 482710293161*CF + 
          4200*(2402994039*NM + 941809*NL))*Log[x]^3)/14175 - 
       (3338957606608366882*CF^2*NC*PolyGamma[2, 1])/784526490225 + 
       (279619752983*CF*NM*NC*PolyGamma[2, 1])/1350 - 
       (23640928220498407673*CF*NC*NH*PolyGamma[2, 1])/28242953648100 - 
       (282270529085405166407*CF^2*NC*Zeta[3])/8786696690520 + 
       (41052037283*CF*NM*NC*Zeta[3])/675 - (1542112*CF*NC*NL*Zeta[3])/3 + 
       (18562088541376099327*CF*NC*NH*Zeta[3])/14121476824050 + 
       CA*CF*NC*(90579996211568297642082616148483/7833851688416291778240000 + 
         (1146959*lm^2)/12 - (38295657997768307*Pi^2)/4245696000 + 
         (432505840297542859*Pi^3)/(2231542016640*Sqrt[3]) + 
         (39323999*Pi^4)/7200 + lm*(802711846211/2857680 - (13310*Pi^2)/27) - 
         (3218607760053487454917*Im[PolyLog[2, (-1)^(1/3)]])/
          (2733638970384000*Sqrt[3]) + (6774119*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          10 + (432505840297542859*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (60265409400*Sqrt[3]) + (432505840297542859*Pi*Log[3]^2)/
          (2892739651200*Sqrt[3]) + (1669478803304183441*PolyGamma[2, 1])/
          784526490225 + (1452495156566891244193*Zeta[3])/87866966905200) + 
       CF*Log[x]*((1079117426905523567*NM*NC)/899026128 - 
         (714084206*lm*NM*NC)/2835 - 47190*lm^2*NM*NC - 
         (14780321419*NC*NL)/16200 - (714084206*lm*NC*NL)/2835 - 
         47190*lm^2*NC*NL - (128400465974127559383668225957*NC*NH)/
          9720017040112070131440 - (714084206*lm*NC*NH)/2835 - 
         47190*lm^2*NC*NH + (1601093608*NM*NC*Pi^2)/9 - 
         (2308328*NC*NL*Pi^2)/27 + (25971684714757376*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CF*NC*(20916992134626326277946103023/144926401162102560000 - 
           (1227492937*lm)/315 - 849420*lm^2 + (606010561117*Pi^2)/45360 + 
           (432505840297542859*Im[PolyLog[2, (-1)^(1/3)]])/
            (90398114100*Sqrt[3]) - 566280*Zeta[3]) + 
         CA*NC*(-818936862289744752179858737/11594112092968204800 + 
           (4863948683*lm)/2835 + 259545*lm^2 - (3000428826641*Pi^2)/453600 - 
           (432505840297542859*Im[PolyLog[2, (-1)^(1/3)]])/
            (180796228200*Sqrt[3]) + 283140*Zeta[3])), 
      (18090310579004852705249776876560134714729*CF^2*NC)/
        20783365206402190413506284800000 - (602952674567*CF^2*lm*NC)/
        1587600 - (2104707*CF^2*lm^2*NC)/5 - (45081162649357949232914676611*
         CF*NM*NC)/104504217580002240000 - (1104167599547*CF*lm*NM*NC)/
        28576800 - (701569*CF*lm^2*NM*NC)/30 + (4973241595360489*CF*NC*NL)/
        10001880000 - (1104167599547*CF*lm*NC*NL)/28576800 - 
       (701569*CF*lm^2*NC*NL)/30 + (2102267635965238747281801103241862676637*
         CF*NC*NH)/113137382500565574639872704320000 - 
       (1104167599547*CF*lm*NC*NH)/28576800 - (701569*CF*lm^2*NC*NH)/30 - 
       (69221611057984690597*CF^2*NC*Pi^2)/163459296000 + 
       (30734*CF^2*lm*NC*Pi^2)/15 + (12640259987599*CF*NM*NC*Pi^2)/85050 + 
       (15367*CF*lm*NM*NC*Pi^2)/135 - (8158523549*CF*NC*NL*Pi^2)/170100 + 
       (15367*CF*lm*NC*NL*Pi^2)/135 + (15367*CF*lm*NC*NH*Pi^2)/135 - 
       (16922765449834777429*CF^2*NC*Pi^3)/(30125817224640*Sqrt[3]) - 
       (107169653004109591*CF*NC*NH*Pi^3)/(41841412812*Sqrt[3]) - 
       (165188177*CF^2*NC*Pi^4)/10800 + (120168956650671928720243*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(36904126100184000*Sqrt[3]) + 
       (1034757830143180882*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (73222472421*Sqrt[3]) - (9465027*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (16922765449834777429*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(813583026900*Sqrt[3]) - 
       (61239801716634052*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (645700815*Sqrt[3]) - (16922765449834777429*CF^2*NC*Pi*Log[3]^2)/
        (39051985291200*Sqrt[3]) - (15309950429158513*CF*NC*NH*Pi*Log[3]^2)/
        (7748409780*Sqrt[3]) - 
       (CF*NC*(-19*CA*(590746473078481407869 + 778689669396038400*lm) + 
          14*(19*CF*(84466998605968837129 + 182031351287385600*lm) + 
            120*(209*(-22329890398415947 + 7661252158560*lm)*NM + 
              3*(42678636*(15741151 + 12505880*lm)*NL + (104439089187449 + 
                  533733900379680*lm)*NH))))*Log[x]^2)/4399779384000 + 
       (CF*NC*(9895840963971*CA - 20278805723263*CF + 
          18480*(427412559*NM + 312647*NL))*Log[x]^3)/14175 - 
       (13218059135701662758279*CF^2*NC*PolyGamma[2, 1])/42364430472150 + 
       (53091905513*CF*NM*NC*PolyGamma[2, 1])/200 - 
       (67733794993423337821*CF*NC*NH*PolyGamma[2, 1])/56485907296200 + 
       CA*CF*NC*(-9059508024061799706786910459643857915693/
          20783365206402190413506284800000 + (7717259*lm^2)/60 + 
         (6293751107951489759*Pi^2)/29719872000 + (16922765449834777429*Pi^3)/
          (60251634449280*Sqrt[3]) + (167155153*Pi^4)/21600 + 
         lm*(21501855527977/57153600 - (169037*Pi^2)/270) - 
         (120168956650671928720243*Im[PolyLog[2, (-1)^(1/3)]])/
          (73808252200368000*Sqrt[3]) + (9465027*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/10 + (16922765449834777429*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1627166053800*Sqrt[3]) + 
         (16922765449834777429*Pi*Log[3]^2)/(78103970582400*Sqrt[3]) + 
         (13218059135701662758279*PolyGamma[2, 1])/84728860944300 - 
         (3795247453707432450953*Zeta[3])/94896324257616) + 
       (96476813507913306788387*CF^2*NC*Zeta[3])/1186204053220200 + 
       (230422883497*CF*NM*NC*Zeta[3])/900 - (11173448*CF*NC*NL*Zeta[3])/
        15 + (49833088742716339139*CF*NC*NH*Zeta[3])/28242953648100 + 
       CF*Log[x]*((5464784426734851910019*NM*NC)/9595571485500 - 
         (4997900149*lm*NM*NC)/14175 - 66066*lm^2*NM*NC - 
         (5217907637069*NC*NL)/3969000 - (4997900149*lm*NC*NL)/14175 - 
         66066*lm^2*NC*NL - (1514210170258303825802415089189*NC*NH)/
          81000142000933917762000 - (4997900149*lm*NC*NH)/14175 - 
         66066*lm^2*NC*NH + (6261991439*NM*NC*Pi^2)/45 - 
         (16729438*NC*NL*Pi^2)/135 + (61239801716634052*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1937102445*Sqrt[3]) + 
         CF*NC*(-608875313059887382832099238770023/226172141653577255136000 - 
           (8591071973*lm)/1575 - 1189188*lm^2 - (1059270924049*Pi^2)/3024 + 
           (16922765449834777429*Im[PolyLog[2, (-1)^(1/3)]])/
            (2440749080700*Sqrt[3]) - 792792*Zeta[3]) + 
         CA*NC*(3049317818222988373104889784125049/
            2261721416535772551360000 + (68087699339*lm)/28350 + 
           363363*lm^2 + (5299222303637*Pi^2)/30240 - 
           (16922765449834777429*Im[PolyLog[2, (-1)^(1/3)]])/
            (4881498161400*Sqrt[3]) + 396396*Zeta[3])), 
      (-44618042279169091606966833308200229053*CF^2*NC)/
        115677357364019612691129600000 - (842878038329*CF^2*lm*NC)/1587600 - 
       (2893319*CF^2*lm^2*NC)/5 - (8563722507038447084978349765413*CF*NM*NC)/
        1724319590070036960000 - (1531893024989*CF*lm*NM*NC)/28576800 - 
       (2893319*CF*lm^2*NM*NC)/90 + (46574796283334953*CF*NC*NL)/
        60011280000 - (1531893024989*CF*lm*NC*NL)/28576800 - 
       (2893319*CF*lm^2*NC*NL)/90 + 
       (129850709744814634439959684103361676852577*CF*NC*NH)/
        4582063991272905772914844524960000 - (1531893024989*CF*lm*NC*NH)/
        28576800 - (2893319*CF*lm^2*NC*NH)/90 + 
       (10341879979955633947*CF^2*NC*Pi^2)/44579808000 + 
       (40898*CF^2*lm*NC*Pi^2)/15 + (376932399401741*CF*NM*NC*Pi^2)/170100 + 
       (20449*CF*lm*NM*NC*Pi^2)/135 - (11779936883*CF*NC*NL*Pi^2)/170100 + 
       (20449*CF*lm*NC*NL*Pi^2)/135 + (20449*CF*lm*NC*NH*Pi^2)/135 - 
       (75995095511975515451*CF^2*NC*Pi^3)/(90377451673920*Sqrt[3]) - 
       (6639619474821860401*CF*NC*NH*Pi^3)/(1694577218886*Sqrt[3]) - 
       (724081787*CF^2*NC*Pi^4)/32400 + (4404836346498450840709*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(885699026404416*Sqrt[3]) + 
       (622859166399932150929*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29655101330505*Sqrt[3]) - (40490593*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (75995095511975515451*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2440749080700*Sqrt[3]) - 
       (7588136542653554744*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (52301766015*Sqrt[3]) - (75995095511975515451*CF^2*NC*Pi*Log[3]^2)/
        (117155955873600*Sqrt[3]) - (948517067831694343*CF*NC*NH*Pi*
         Log[3]^2)/(313810596090*Sqrt[3]) - 
       (CF*NC*(-1463*CA*(-12418174737798205261 + 46436100850339200*lm) + 
          2*(209*CF*(-86703868465401615793 + 531904427922067200*lm) + 
            5040*(19*(-1832491600654771867 + 64494584514360*lm)*NM + 
              9*(92470378*(1850609 + 1472420*lm)*NL + (27976493455213 + 
                  136155233974760*lm)*NH))))*Log[x]^2)/13199338152000 + 
       (CF*NC*(-15553918661723*CA + 28762542967063*CF + 
          2520*(126833811876*NM + 10527803*NL))*Log[x]^3)/42525 + 
       (50648376343465218289*CF^2*NC*PolyGamma[2, 1])/14121476824050 + 
       (2260365759229*CF*NM*NC*PolyGamma[2, 1])/1080 - 
       (33358519173528704867*CF*NC*NH*PolyGamma[2, 1])/18828635765400 - 
       (27513050901749516000063*CF^2*NC*Zeta[3])/79080270214680 + 
       (46829671193*CF*NM*NC*Zeta[3])/108 - (16927196*CF*NC*NL*Zeta[3])/
        15 + (30121376370951807373*CF*NC*NH*Zeta[3])/9414317882700 + 
       CA*CF*NC*(1087415782945293706773571916049814921343/
          5668190510836961021865350400000 + (31826509*lm^2)/180 - 
         (795233658984491911*Pi^2)/6858432000 + (75995095511975515451*Pi^3)/
          (180754903347840*Sqrt[3]) + (731934203*Pi^4)/64800 + 
         lm*(29712436359199/57153600 - (224939*Pi^2)/270) - 
         (4404836346498450840709*Im[PolyLog[2, (-1)^(1/3)]])/
          (1771398052808832*Sqrt[3]) + (40490593*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/30 + (75995095511975515451*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4881498161400*Sqrt[3]) + 
         (75995095511975515451*Pi*Log[3]^2)/(234311911747200*Sqrt[3]) - 
         (50648376343465218289*PolyGamma[2, 1])/28242953648100 + 
         (5534133070703870694433*Zeta[3])/31632108085872) + 
       CF*Log[x]*((5448233245858195190070877*NM*NC)/422205145362000 - 
         (7283016598*lm*NM*NC)/14175 - (286286*lm^2*NM*NC)/3 - 
         (47362714589623*NC*NL)/23814000 - (7283016598*lm*NC*NL)/14175 - 
         (286286*lm^2*NC*NL)/3 - (93797666936457762878940816821039*NC*NH)/
          3280505751037823669361000 - (7283016598*lm*NC*NH)/14175 - 
         (286286*lm^2*NC*NH)/3 + (28182210736*NM*NC*Pi^2)/15 - 
         (25349896*NC*NL*Pi^2)/135 + (7588136542653554744*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(156905298045*Sqrt[3]) + 
         CF*NC*(529369529737306926183507348155677/308416556800332620640000 - 
           (12536981171*lm)/1575 - 1717716*lm^2 + (123143430448219*Pi^2)/
            680400 + (75995095511975515451*Im[PolyLog[2, (-1)^(1/3)]])/
            (7322247242100*Sqrt[3]) - 1145144*Zeta[3]) + 
         CA*NC*(-527383546113417985962848536654159/616833113600665241280000 + 
           (49525500739*lm)/14175 + (1574573*lm^2)/3 - (24589828320047*Pi^2)/
            272160 - (75995095511975515451*Im[PolyLog[2, (-1)^(1/3)]])/
            (14644494484200*Sqrt[3]) + 572572*Zeta[3])), 
      (1412508534062593585067512930606061783323594481*CF^2*NC)/
        142553101950712624046239607443200000 - (132344572368791*CF^2*lm*NC)/
        192099600 - 760695*CF^2*lm^2*NC - 
       (30386708381590746162419231164709473*CF*NM*NC)/
        7884738712193589005760000 - (241941476285291*CF*lm*NM*NC)/
        3457792800 - (253565*CF*lm^2*NM*NC)/6 + 
       (225458737169624303*CF*NC*NL)/201704580000 - 
       (241941476285291*CF*lm*NC*NL)/3457792800 - (253565*CF*lm^2*NC*NL)/
        6 + (119251019848218965424916275906081226002613*CF*NC*NH)/
        3054709327515270515276563016640000 - (241941476285291*CF*lm*NC*NH)/
        3457792800 - (253565*CF*lm^2*NC*NH)/6 - 
       (8495383824542251160527*CF^2*NC*Pi^2)/1798052256000 + 
       (51038*CF^2*lm*NC*Pi^2)/15 + (609835664642044*CF*NM*NC*Pi^2)/467775 + 
       (25519*CF*lm*NM*NC*Pi^2)/135 - (176514843583*CF*NC*NL*Pi^2)/
        1871100 + (25519*CF*lm*NC*NL*Pi^2)/135 + (25519*CF*lm*NC*NH*Pi^2)/
        135 - (1175504585739620593429*CF^2*NC*Pi^3)/(994151968413120*
         Sqrt[3]) - (6111049078017075479*CF*NC*NH*Pi^3)/
        (1129718145924*Sqrt[3]) - (332898553*CF^2*NC*Pi^4)/10800 + 
       (4301831647391369995617157*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (637914179731752000*Sqrt[3]) + (290372250989131045204*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9885033776835*Sqrt[3]) - 
       (18371899*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (167929226534231513347*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3835462841100*Sqrt[3]) - (3492028044581185988*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(17433922005*Sqrt[3]) - 
       (167929226534231513347*CF^2*NC*Pi*Log[3]^2)/(184102216372800*
         Sqrt[3]) - (873007011145296497*CF*NC*NH*Pi*Log[3]^2)/
        (209207064060*Sqrt[3]) - 
       (CF*NC*(-3*CA*(457690563906545889515287 + 117764824030460006400*lm) + 
          2*(CF*(1373309274389253867636343 + 578118227058621849600*lm) + 
            9240*((-40963082417248861601 + 3475939316129280*lm)*NM + 
              1664466804*(2609899 + 2088320*lm)*NL + 3*(247085835780923 + 
                1158646438709760*lm)*NH)))*Log[x]^2)/48397573224000 + 
       (CF*NC*(1221959490991733*CA + 33*(-74439946372521*CF + 
            6160*(3707173263*NM + 678704*NL)))*Log[x]^3)/155925 - 
       (128564111823531332719094*CF^2*NC*PolyGamma[2, 1])/38127987424935 + 
       (13021245502621*CF*NM*NC*PolyGamma[2, 1])/5400 - 
       (1255901892486205009067*CF*NC*NH*PolyGamma[2, 1])/508373165665800 + 
       CA*CF*NC*(-1554202813440374217302083673577689792550898657/
          313616824291567772901727136375040000 + (2789215*lm^2)/12 + 
         (653507590071150285643*Pi^2)/276623424000 + 
         (1175504585739620593429*Pi^3)/(1988303936826240*Sqrt[3]) + 
         (2490111*Pi^4)/160 + lm*(427924101113291/628689600 - 
           (280709*Pi^2)/270) - (4301831647391369995617157*
           Im[PolyLog[2, (-1)^(1/3)]])/(1275828359463504000*Sqrt[3]) + 
         (18371899*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (167929226534231513347*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (7670925682200*Sqrt[3]) + (167929226534231513347*Pi*Log[3]^2)/
          (368204432745600*Sqrt[3]) + (64282055911765666359547*
           PolyGamma[2, 1])/38127987424935 - (129860914688229033904999963*
           Zeta[3])/234868402537599600) + (26037673708276710469745837*CF^2*NC*
         Zeta[3])/23486840253759960 + (6518591882101*CF*NM*NC*Zeta[3])/
        2700 - (23846576*CF*NC*NL*Zeta[3])/15 + 
       (1082082105379577805013*CF*NC*NH*Zeta[3])/254186582832900 + 
       CF*Log[x]*((384138263492704215834956321*NM*NC)/76208028737841000 - 
         (109246171073*lm*NM*NC)/155925 - 130130*lm^2*NM*NC - 
         (30438422618627*NC*NL)/10914750 - (109246171073*lm*NC*NL)/155925 - 
         130130*lm^2*NC*NL - (7849788404904678734165334832391*NC*NH)/
          198818530365928707234000 - (109246171073*lm*NC*NH)/155925 - 
         130130*lm^2*NC*NH + (54358541633*NM*NC*Pi^2)/45 - 
         (35718826*NC*NL*Pi^2)/135 + (3492028044581185988*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(52301766015*Sqrt[3]) + 
         CF*NC*(-397755860727591010363093765558086459251/
            13471943617595329202175840000 - (188056561771*lm)/17325 - 
           2342340*lm^2 - (9782409708922393*Pi^2)/2494800 + 
           (167929226534231513347*Im[PolyLog[2, (-1)^(1/3)]])/
            (11506388523300*Sqrt[3]) - 1561560*Zeta[3]) + 
         CA*NC*(397876347863882519723980232008346106473/
            26943887235190658404351680000 + (135070469573*lm)/28350 + 
           715715*lm^2 + (9783415170688009*Pi^2)/4989600 - 
           (167929226534231513347*Im[PolyLog[2, (-1)^(1/3)]])/
            (23012777046600*Sqrt[3]) + 780780*Zeta[3])), 
      (-806502971974228960173615456619489762964079913*CF^2*NC)/
        155085242781544503083271660844800000 - (229103954957*CF^2*lm*NC)/
        245025 - (5090631*CF^2*lm^2*NC)/5 - 
       (89848427691160599524141003233135031*CF*NM*NC)/
        1689586866898626215520000 - (1664814936293*CF*lm*NM*NC)/17641800 - 
       (1696877*CF*lm^2*NM*NC)/30 + (54325968189225077*CF*NC*NL)/
        32416807500 - (1664814936293*CF*lm*NC*NL)/17641800 - 
       (1696877*CF*lm^2*NC*NL)/30 + 
       (1373302570765467810248569180808707930103576071*CF*NC*NH)/
        23892845392207476231023534286509280000 - (1664814936293*CF*lm*NC*NH)/
        17641800 - (1696877*CF*lm^2*NC*NH)/30 + 
       (947450444303382177619*CF^2*NC*Pi^2)/335899872000 + 
       (66248*CF^2*lm*NC*Pi^2)/15 + (1574169684423007*CF*NM*NC*Pi^2)/66825 + 
       (33124*CF*lm*NM*NC*Pi^2)/135 - (8823827116*CF*NC*NL*Pi^2)/66825 + 
       (33124*CF*lm*NC*NL*Pi^2)/135 + (33124*CF*lm*NC*NH*Pi^2)/135 - 
       (5100257790545321168191*CF^2*NC*Pi^3)/(2982455905239360*Sqrt[3]) - 
       (20290006471156571009*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) - 
       (470406937*CF^2*NC*Pi^4)/10800 + (57063026937444437187334181*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5741227617585768000*Sqrt[3]) + 
       (538726460228990641816*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12709329141645*Sqrt[3]) - (25445147*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (728608255792188738313*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11506388523300*Sqrt[3]) - 
       (46377157648357876592*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (156905298045*Sqrt[3]) - (728608255792188738313*CF^2*NC*Pi*Log[3]^2)/
        (552306649118400*Sqrt[3]) - (2898572353022367287*CF*NC*NH*Pi*
         Log[3]^2)/(470715894135*Sqrt[3]) - 
       (CF*NC*(-897*CA*(-2994531386436629763491 + 1908917159131382400*lm) + 
          10*(299*CF*(-1795932988090619506279 + 1874209574419902720*lm) + 
            3696*(253*(-4807150002314690909 + 33293875534920*lm)*NM + 
              3*(12760912164*(274701 + 220030*lm)*NL + (623698312192231 + 
                  2807783503444920*lm)*NH))))*Log[x]^2)/159020597736000 + 
       (CF*NC*(-100810695653376*CA + 198848870532469*CF + 
          9240*(192341980473*NM + 3146429*NL))*Log[x]^3)/22275 + 
       (88511555374008657104306*CF^2*NC*PolyGamma[2, 1])/190639937124675 + 
       (57221948488261*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (809656378613945118653*CF*NC*NH*PolyGamma[2, 1])/228767924549610 - 
       (11994589685276773516073221*CF^2*NC*Zeta[3])/3355262893394280 + 
       (3382625760301*CF*NM*NC*Zeta[3])/1350 - (11625432*CF*NC*NL*Zeta[3])/
        5 + (809488406226482412943*CF*NC*NH*Zeta[3])/114383962274805 + 
       CA*CF*NC*(1151254918608352723306919967806261930259061/
          443100693661555723095061888128000 + (18665647*lm^2)/60 - 
         (55729047617536919459*Pi^2)/39517632000 + 
         (5100257790545321168191*Pi^3)/(5964911810478720*Sqrt[3]) + 
         (158215603*Pi^4)/7200 + lm*(2934825558173/3207600 - 
           (182182*Pi^2)/135) - (57063026937444437187334181*
           Im[PolyLog[2, (-1)^(1/3)]])/(11482455235171536000*Sqrt[3]) + 
         (25445147*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (728608255792188738313*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (23012777046600*Sqrt[3]) + (728608255792188738313*Pi*Log[3]^2)/
          (1104613298236800*Sqrt[3]) - (44255777687004328552153*
           PolyGamma[2, 1])/190639937124675 + (60040150835087296387210427*
           Zeta[3])/33552628933942800) + CF*Log[x]*
        ((426252285157813768153812073*NM*NC)/3110531785218000 - 
         (22012715504*lm*NM*NC)/22275 - 182182*lm^2*NM*NC - 
         (38108074048361*NC*NL)/9355500 - (22012715504*lm*NC*NL)/22275 - 
         182182*lm^2*NC*NL - (86648764595468996079483617258790733*NC*NH)/
          1487475036256293189507402000 - (22012715504*lm*NC*NH)/22275 - 
         182182*lm^2*NC*NH + (299192721716*NM*NC*Pi^2)/15 - 
         (52248196*NC*NL*Pi^2)/135 + (46377157648357876592*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) + 
         CF*NC*(8708723829615609823705090460696650633/
            444130009371274589082720000 - (37938274933*lm)/2475 - 
           3279276*lm^2 + (805059248044393*Pi^2)/356400 + 
           (728608255792188738313*Im[PolyLog[2, (-1)^(1/3)]])/
            (34519165569900*Sqrt[3]) - 2186184*Zeta[3]) + 
         CA*NC*(-1740611406129433263244759882025224211/
            177652003748509835633088000 + (13588787602*lm)/2025 + 
           1002001*lm^2 - (804850294170121*Pi^2)/712800 - 
           (728608255792188738313*Im[PolyLog[2, (-1)^(1/3)]])/
            (69038331139800*Sqrt[3]) + 1093092*Zeta[3])), 
      (1349196839092773702049835251438301119422313990793*CF^2*NC)/
        12096648936960471240495189545894400000 - (56055210994927*CF^2*lm*NC)/
        47044800 - (13119561*CF^2*lm^2*NC)/10 - 
       (14529929131502251690327659935410135181*CF*NM*NC)/
        425775890458453806311040000 - (102345745244887*CF*lm*NM*NC)/
        846806400 - (1457729*CF*lm^2*NM*NC)/20 + 
       (306861133716385957057*CF*NC*NL)/130704567840000 - 
       (102345745244887*CF*lm*NC*NL)/846806400 - (1457729*CF*lm^2*NC*NL)/
        20 + (1307658650429695685867579904920010837928763593*CF*NC*NH)/
        16865537923911159692487200672830080000 - 
       (102345745244887*CF*lm*NC*NH)/846806400 - (1457729*CF*lm^2*NC*NH)/
        20 - (7586099660832038450513*CF^2*NC*Pi^2)/145556611200 + 
       (488579*CF^2*lm*NC*Pi^2)/90 + (254252192651735581*CF*NM*NC*Pi^2)/
        22453200 + (488579*CF*lm*NM*NC*Pi^2)/1620 - 
       (70529405713*CF*NC*NL*Pi^2)/400950 + (488579*CF*lm*NC*NL*Pi^2)/
        1620 + (488579*CF*lm*NC*NH*Pi^2)/1620 - 
       (2621790271583062194223*CF^2*NC*Pi^3)/(1118420964464760*Sqrt[3]) - 
       (658170694739905502813*CF*NC*NH*Pi^3)/(61004779879896*Sqrt[3]) - 
       (105565369*CF^2*NC*Pi^4)/1800 + (1425526440847324745013451*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(107648017829733150*Sqrt[3]) + 
       (8835789878550336290783*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (152511949699740*Sqrt[3]) - (101615878*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (749082934738017769778*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(8629791392475*Sqrt[3]) - 
       (188048769925687286518*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) - 
       (374541467369008884889*CF^2*NC*Pi*Log[3]^2)/(207114993419400*
         Sqrt[3]) - (94024384962843643259*CF*NC*NH*Pi*Log[3]^2)/
        (11297181459240*Sqrt[3]) - 
       (CF*NC*(-23*CA*(3243522297472389376971269 + 154443014024063965200*
             lm) + 660*(805*CF*(280833448766531412865 + 21880946496915792*
               lm) + 3*(69*(-237234685574323304977 + 4727364983901560*lm)*
               NM + 14399*(443118*(63516449 + 51123020*lm)*NL + 
                83*(62611322321 + 272934100920*lm)*NH))))*Log[x]^2)/
        238530896604000 + (CF*NC*(23219960322107807*CA + 
          20*(-2324368305703705*CF + 726*(773033558186*NM + 33229963*NL)))*
         Log[x]^3)/267300 - (332355769714684750929407351*CF^2*NC*
         PolyGamma[2, 1])/9150716981984400 + 
       (352366787536321*CF*NM*NC*PolyGamma[2, 1])/16200 - 
       (33093925416912936412477*CF*NC*NH*PolyGamma[2, 1])/6863037736488300 + 
       CA*CF*NC*(-24532063801817765972000054220276568094337408047/
          439878143162198954199825074396160000 + (16035019*lm^2)/40 + 
         (19070218226787548453*Pi^2)/731808000 + 
         (2621790271583062194223*Pi^3)/(2236841928929520*Sqrt[3]) + 
         (191581117*Pi^4)/6480 + lm*(180899379123607/153964800 - 
           (5374369*Pi^2)/3240) - (1425526440847324745013451*
           Im[PolyLog[2, (-1)^(1/3)]])/(215296035659466300*Sqrt[3]) + 
         (50807939*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (374541467369008884889*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (8629791392475*Sqrt[3]) + (374541467369008884889*Pi*Log[3]^2)/
          (414229986838800*Sqrt[3]) + (332355769714684750929407351*
           PolyGamma[2, 1])/18301433963968800 - (717403218098884275293599709*
           Zeta[3])/100657886801828400) + (717678909491151105190721693*CF^2*
         NC*Zeta[3])/50328943400914200 + (182434700276041*CF*NM*NC*Zeta[3])/
        8100 - (431603692*CF*NC*NL*Zeta[3])/135 + 
       (31925851836865487804663*CF*NC*NH*Zeta[3])/3431518868244150 + 
       CF*Log[x]*((19580101113039153716910731173*NM*NC)/457248172427046000 - 
         (704475307523*lm*NM*NC)/534600 - (728728*lm^2*NM*NC)/3 - 
         (52611297760110979*NC*NL)/9430344000 - (704475307523*lm*NC*NL)/
          534600 - (728728*lm^2*NC*NL)/3 - 
         (41340189576674025993686987610791387*NC*NH)/
          524991189266927008061436000 - (704475307523*lm*NC*NH)/534600 - 
         (728728*lm^2*NC*NH)/3 + (8502921069137*NM*NC*Pi^2)/810 - 
         (431115113*NC*NL*Pi^2)/810 + (188048769925687286518*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(-5547450525240053304647547763623274437121/
            17321070365479708974226080000 - (607080810323*lm)/29700 - 
           4372368*lm^2 - (23222932907373227*Pi^2)/534600 + 
           (749082934738017769778*Im[PolyLog[2, (-1)^(1/3)]])/
            (25889374177425*Sqrt[3]) - 2914912*Zeta[3]) + 
         CA*NC*(1386937591334559478870025126519940129943/
            8660535182739854487113040000 + (869750817923*lm)/97200 + 
           (4008004*lm^2)/3 + (23223364618139351*Pi^2)/1069200 - 
           (374541467369008884889*Im[PolyLog[2, (-1)^(1/3)]])/
            (25889374177425*Sqrt[3]) + 1457456*Zeta[3])), 
      (-4704084036830185314551207736684351227385778952119*CF^2*NC)/
        72579893621762827442971137275366400000 - (989593790837*CF^2*lm*NC)/
        627264 - (3433521*CF^2*lm^2*NC)/2 - 
       (1466160113914973657840307472909179547*CF*NM*NC)/
        2580459942172447310976000 - (1797240334541*CF*lm*NM*NC)/11290752 - 
       (1144507*CF*lm^2*NM*NC)/12 + (163125793335130242733*CF*NC*NL)/
        47925008208000 - (1797240334541*CF*lm*NC*NL)/11290752 - 
       (1144507*CF*lm^2*NC*NL)/12 + 
       (16678227445844953604699934092565436884845192505053*CF*NC*NH)/
        150524925970907100255448266005008464000000 - 
       (1797240334541*CF*lm*NC*NH)/11290752 - (1144507*CF*lm^2*NC*NH)/12 + 
       (4118546555405239188631*CF^2*NC*Pi^2)/124762809600 + 
       (41405*CF^2*lm*NC*Pi^2)/6 + (373530555483697489*CF*NM*NC*Pi^2)/
        1496880 + (41405*CF*lm*NM*NC*Pi^2)/108 - (5128865651*CF*NC*NL*Pi^2)/
        21384 + (41405*CF*lm*NC*NL*Pi^2)/108 + (41405*CF*lm*NC*NH*Pi^2)/
        108 - (88404259033593438802657*CF^2*NC*Pi^3)/(26842103147154240*
         Sqrt[3]) - (2826566009435194479215*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) - (870361583*CF^2*NC*Pi^4)/10800 + 
       (195718059418208635974904003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (10334209711654382400*Sqrt[3]) + (2871005404719287269249063*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(35230260380639940*Sqrt[3]) - 
       (45768541*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (12629179861941919828951*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(103557496709700*Sqrt[3]) - 
       (161518057682011113098*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (12629179861941919828951*CF^2*NC*Pi*Log[3]^2)/(4970759842065600*
         Sqrt[3]) - (80759028841005556549*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((54755014085588994553729*CF*NC)/
          138278780640 - 69694638*CF*lm*NC + 
         CA*(-1368976255784439087731489/6913939032000 + (127773503*lm)/6)*
          NC + (116181492367388461099*NM*NC)/38798760 - 
         (11615773*lm*NM*NC)/3 - (288424097*NC*NL)/60 - 
         (11615773*lm*NC*NL)/3 - (110773699980039997*NC*NH)/120470149800 - 
         (11615773*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-4788007686648737*CA + 9552478857520340*CF + 
          75385773358104000*NM + 229992305400*NL)*Log[x]^3)/89100 + 
       (59925261658911476694126251*CF^2*NC*PolyGamma[2, 1])/
        6863037736488300 + (386914801839749*CF*NM*NC*PolyGamma[2, 1])/1800 - 
       (138533300776846306591657*CF*NC*NH*PolyGamma[2, 1])/
        20589113209464900 - (5470287211580379937906252973*CF^2*NC*Zeta[3])/
        150986830202742600 + (6200322813149*CF*NM*NC*Zeta[3])/900 - 
       (40851044*CF*NC*NL*Zeta[3])/9 + (149709346581290764325843*CF*NC*NH*
         Zeta[3])/10294556604732450 + CA*CF*NC*
        (4703527653251813793397046113180090430058080586397/
          145159787243525654885942274550732800000 + (12589577*lm^2)/24 - 
         (443531585025399767957*Pi^2)/26871989760 + 
         (88404259033593438802657*Pi^3)/(53684206294308480*Sqrt[3]) + 
         (876986383*Pi^4)/21600 + lm*(3167792045069/2052864 - 
           (455455*Pi^2)/216) - (195718059418208635974904003*
           Im[PolyLog[2, (-1)^(1/3)]])/(20668419423308764800*Sqrt[3]) + 
         (45768541*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (12629179861941919828951*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (207114993419400*Sqrt[3]) + (12629179861941919828951*Pi*Log[3]^2)/
          (9941519684131200*Sqrt[3]) - (59925261658911476694126251*
           PolyGamma[2, 1])/13726075472976600 + (5471444370816182348659733783*
           Zeta[3])/301973660405485200) + CF*Log[x]*
        ((87962289489116387595670071053*NM*NC)/60966422990272800 - 
         (64453967669*lm*NM*NC)/35640 - 331240*lm^2*NM*NC - 
         (54710984784353603*NC*NL)/6915585600 - (64453967669*lm*NC*NL)/
          35640 - 331240*lm^2*NC*NL - 
         (105617129930823675626276408814112684613*NC*NH)/
          937109272841464709389663260000 - (64453967669*lm*NC*NH)/35640 - 
         331240*lm^2*NC*NH + (11422048176263*NM*NC*Pi^2)/54 - 
         (13603213*NC*NL*Pi^2)/18 + (161518057682011113098*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(2276923220807456838793857931631081346539/
            10392642219287825384535648000 - (55599922469*lm)/1980 - 
           5962320*lm^2 + (9573170101156253*Pi^2)/356400 + 
           (12629179861941919828951*Im[PolyLog[2, (-1)^(1/3)]])/
            (310672490129100*Sqrt[3]) - 3974880*Zeta[3]) + 
         CA*NC*(-2845841844912500528901153750341525545939/
            25981605548219563461339120000 + (79479014069*lm)/6480 + 
           1821820*lm^2 - (9572763379331909*Pi^2)/712800 - 
           (12629179861941919828951*Im[PolyLog[2, (-1)^(1/3)]])/
            (621344980258200*Sqrt[3]) + 1987440*Zeta[3])), 
      (13487930161038618626751899827056871143499697837772395587*CF^2*NC)/
        10875822019624277222667335766930295756800000 - 
       (1048934566241293*CF^2*lm*NC)/530038080 - (4348869*CF^2*lm^2*NC)/2 - 
       (421611740741741649767614842483927743153*CF*NM*NC)/
        1409636805226668696975897600 - (1913334381840613*CF*lm*NM*NC)/
        9540685440 - (1449623*CF*lm^2*NM*NC)/12 + 
       (75431202146308617478607*CF*NC*NL)/16198652774304000 - 
       (1913334381840613*CF*lm*NC*NL)/9540685440 - (1449623*CF*lm^2*NC*NL)/
        12 + (7362619601873958835740485175778824780640512858803*CF*NC*NH)/
        50174975323635700085149422001669488000000 - 
       (1913334381840613*CF*lm*NC*NH)/9540685440 - (1449623*CF*lm^2*NC*NH)/
        12 - (922389839928380878953797*CF^2*NC*Pi^2)/1621916524800 + 
       (50225*CF^2*lm*NC*Pi^2)/6 + (269123228473879057*CF*NM*NC*Pi^2)/
        2779920 + (50225*CF*lm*NM*NC*Pi^2)/108 - 
       (43563500599*CF*NC*NL*Pi^2)/138996 + (50225*CF*lm*NC*NL*Pi^2)/108 + 
       (50225*CF*lm*NC*NH*Pi^2)/108 - (630530236416366844847597*CF^2*NC*
         Pi^3)/(142751184918956640*Sqrt[3]) - 
       (1249986698197643266385*CF*NC*NH*Pi^3)/(61004779879896*Sqrt[3]) - 
       (286979987*CF^2*NC*Pi^4)/2700 + (17745588668475801615597700703*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(714469680519377983200*Sqrt[3]) + 
       (1282147396407905248290331*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (11743420126879980*Sqrt[3]) - (59763396*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (90075748059480977835371*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(550737596137950*Sqrt[3]) - 
       (71427811325579615222*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) - (90075748059480977835371*CF^2*NC*Pi*Log[3]^2)/
        (26435404614621600*Sqrt[3]) - (35713905662789807611*CF*NC*NH*Pi*
         Log[3]^2)/(2259436291848*Sqrt[3]) + 
       CF*((-18563671312818951873845087*CF*NC)/2720089171800 - 
         94309254*CF*lm*NC + CA*(92817827832401026319097869/27200891718000 + 
           (57633433*lm)/2)*NC + (1332864099078339649669*NM*NC)/1147334760 - 
         5239403*lm*NM*NC - (1165948433*NC*NL)/180 - 5239403*lm*NC*NL - 
         (154182449186411521*NC*NH)/120470149800 - 5239403*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-1102926584263503369*CA + 
          260*(8485689945464881*CF - 330*(4877042003182*NM + 47154627*NL)))*
         Log[x]^3)/1158300 - (19232077511712009820723984819*CF^2*NC*
         PolyGamma[2, 1])/49413871702715760 + 
       (23379560804257*CF*NM*NC*PolyGamma[2, 1])/120 - 
       (184990990688148373448117*CF*NC*NH*PolyGamma[2, 1])/
        20589113209464900 + CA*CF*NC*
        (-3372010513120469702310176280448838241079937678168305999/
          5437911009812138611333667883465147878400000 + (15945853*lm^2)/24 + 
         (40354584792853771370603*Pi^2)/141917695920 + 
         (630530236416366844847597*Pi^3)/(285502369837913280*Sqrt[3]) + 
         (288988987*Pi^4)/5400 + lm*(3380194674978853/1734670080 - 
           (552475*Pi^2)/216) - (17745588668475801615597700703*
           Im[PolyLog[2, (-1)^(1/3)]])/(1428939361038755966400*Sqrt[3]) + 
         (29881698*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (90075748059480977835371*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1101475192275900*Sqrt[3]) + (90075748059480977835371*Pi*Log[3]^2)/
          (52870809229243200*Sqrt[3]) + (19232077511712009820723984819*
           PolyGamma[2, 1])/98827743405431520 - 
         (3070906417133988449501576393231*Zeta[3])/35330918267441768400) + 
       (3071087898819198272668304179601*CF^2*NC*Zeta[3])/
        17665459133720884200 + (12543637397977*CF*NM*NC*Zeta[3])/60 - 
       (55001732*CF*NC*NL*Zeta[3])/9 + (194340904094548487936983*CF*NC*NH*
         Zeta[3])/10294556604732450 + CF*Log[x]*
        ((50267988580992533097626200336*NM*NC)/143978740008278175 - 
         (1095882223661*lm*NM*NC)/463320 - 433160*lm^2*NM*NC - 
         (954417631372274807*NC*NL)/89902612800 - (1095882223661*lm*NC*NL)/
          463320 - 433160*lm^2*NC*NL - 
         (46711625888456484725867130940043079113*NC*NH)/
          312369757613821569796554420000 - (1095882223661*lm*NC*NH)/463320 - 
         433160*lm^2*NC*NH + (4876989003131*NM*NC*Pi^2)/54 - 
         (2035241*NC*NL*Pi^2)/2 + (71427811325579615222*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(-232777289680899303694226183364427679960816383/
            67708611039829618581585774912000 - (945363455261*lm)/25740 - 
           7796880*lm^2 - (367650570007333651*Pi^2)/772200 + 
           (90075748059480977835371*Im[PolyLog[2, (-1)^(1/3)]])/
            (1652212788413850*Sqrt[3]) - 5197920*Zeta[3]) + 
         CA*NC*(290974316167309326058725603194167337992952969/
            169271527599574046453964437280000 + (1351308012461*lm)/84240 + 
           2382380*lm^2 + (30637646529140249*Pi^2)/128700 - 
           (90075748059480977835371*Im[PolyLog[2, (-1)^(1/3)]])/
            (3304425576827700*Sqrt[3]) + 2598960*Zeta[3])), 
      (-2042351475450200915946264249267785620111582651684536529*CF^2*NC)/
        2649238697087964964495889481688148966400000 - 
       (21249578440414*CF^2*lm*NC)/8281845 - 2790956*CF^2*lm^2*NC - 
       (143404085951556331368807225044871237187*CF*NM*NC)/
        23719850087948752112575200 - (38585277185779*CF*lm*NM*NC)/
        149073210 - (1395478*CF*lm^2*NM*NC)/9 + 
       (759258253645866719707*CF*NC*NL)/115704662673600 - 
       (38585277185779*CF*lm*NC*NL)/149073210 - (1395478*CF*lm^2*NC*NL)/9 + 
       (412056585689982876333865448374812679783031053843*CF*NC*NH)/
        2015958829967505806992610705424220500000 - 
       (38585277185779*CF*lm*NC*NH)/149073210 - (1395478*CF*lm^2*NC*NH)/9 + 
       (60803911723248367205094533*CF^2*NC*Pi^2)/161786173348800 + 
       (31360*CF^2*lm*NC*Pi^2)/3 + (8310043795485907*CF*NM*NC*Pi^2)/3159 + 
       (15680*CF*lm*NM*NC*Pi^2)/27 - (14520663736*CF*NC*NL*Pi^2)/34749 + 
       (15680*CF*lm*NC*NL*Pi^2)/27 + (15680*CF*lm*NC*NH*Pi^2)/27 - 
       (3168839870264114105817079*CF^2*NC*Pi^3)/(523421011369507680*
         Sqrt[3]) - (1961484988317731364040*CF*NC*NH*Pi^3)/
        (68630377364883*Sqrt[3]) - (1155323491*CF^2*NC*Pi^4)/8100 + 
       (90686688202508766513698410849*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2619722161904385938400*Sqrt[3]) + (566914173844855336761652*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(3774670755068565*Sqrt[3]) - 
       (237181028*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (452691410037730586545297*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2019371185839150*Sqrt[3]) - 
       (896678851802391480704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (452691410037730586545297*CF^2*NC*Pi*Log[3]^2)/(96929816920279200*
         Sqrt[3]) - (56042428237649467544*CF*NC*NH*Pi*Log[3]^2)/
        (2541865828329*Sqrt[3]) - 
       (CF*NC*(CA*(6992078584772132950133055149 - 124449809205681479520000*
             lm) + 320*(4*CF*(-10924989649324026007401053 + 
              318195534900890146500*lm) + 9009*(15*(-2263627054927640703601 + 
                523255402870200*lm)*NM + 31073649750*(312115 + 252588*lm)*
               NL + (1975230130601243 + 7848831043053000*lm)*NH)))*
         Log[x]^2)/3100901655852000 + (7*CF*NC*(-153522791067002857*CA + 
          80*(3836419875800581*CF + 25740*(1077202855039*NM + 586365*NL)))*
         Log[x]^3)/1737450 + (390148606016745126783116584*CF^2*NC*
         PolyGamma[2, 1])/3088366981419735 + 
       (490876879439792*CF*NM*NC*PolyGamma[2, 1])/225 - 
       (567703507680968651078387*CF*NC*NH*PolyGamma[2, 1])/
        46325504721296025 - (1615449301209492180097067961551*CF^2*NC*Zeta[3])/
        4416364783430221050 - (23625298253216*CF*NM*NC*Zeta[3])/225 - 
       (76131440*CF*NC*NL*Zeta[3])/9 + (1304759448496139388004826*CF*NC*NH*
         Zeta[3])/46325504721296025 + CA*CF*NC*
        (1659380406871925822131641635043728598619022435709131431/
          4305012882767943067305820407743242070400000 + (7675129*lm^2)/9 - 
         (6400402341572107825291663*Pi^2)/34060247020800 + 
         (3168839870264114105817079*Pi^3)/(1046842022739015360*Sqrt[3]) + 
         (1162849891*Pi^4)/16200 + lm*(68003432632459/27104220 - 
           (86240*Pi^2)/27) - (90686688202508766513698410849*
           Im[PolyLog[2, (-1)^(1/3)]])/(5239444323808771876800*Sqrt[3]) + 
         (118590514*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (452691410037730586545297*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4038742371678300*Sqrt[3]) + (452691410037730586545297*Pi*Log[3]^2)/
          (193859633840558400*Sqrt[3]) - (195074303008372563391558292*
           PolyGamma[2, 1])/3088366981419735 + 
         (3231022685920948664823464531557*Zeta[3])/17665459133720884200) + 
       CF*Log[x]*((17372893605655691089901673875957*NM*NC)/
          1151829920066225400 - (36732460064*lm*NM*NC)/11583 - 
         (1732640*lm^2*NM*NC)/3 - (4713009466890563*NC*NL)/321080760 - 
         (36732460064*lm*NC*NL)/11583 - (1732640*lm^2*NC*NL)/3 - 
         (20939186378706755791824819445849314149*NC*NH)/
          100404564947299790291749635000 - (36732460064*lm*NC*NH)/11583 - 
         (1732640*lm^2*NC*NH)/3 + (60323326336672*NM*NC*Pi^2)/27 - 
         1408680*NC*NL*Pi^2 + (896678851802391480704*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(516071205699581107701059480782170039012535669/
            214410601626127125508354953888000 - (63430335568*lm)/1287 - 
           10395840*lm^2 + (2149213763067293771*Pi^2)/6949800 + 
           (452691410037730586545297*Im[PolyLog[2, (-1)^(1/3)]])/
            (6058113557517450*Sqrt[3]) - 6930560*Zeta[3]) + 
         CA*NC*(-645077394037300103579216103509077132319227169/
            536026504065317813770887384720000 + (22623326512*lm)/1053 + 
           (9529520*lm^2)/3 - (2149199019113877293*Pi^2)/13899600 - 
           (452691410037730586545297*Im[PolyLog[2, (-1)^(1/3)]])/
            (12116227115034900*Sqrt[3]) + 3465280*Zeta[3])), 
      (19281240516645319775206161574989064452192997103993119560761*CF^2*NC)/
        1415039017118506503862260968806039567488000000 - 
       (5152661644474837*CF^2*lm*NC)/1623241620 - 3482292*CF^2*lm^2*NC - 
       (27867507536136996159101242002677900643231893*CF*NM*NC)/
        10792531790016682211221716000000 - (9392112625019617*CF*lm*NM*NC)/
        29218349160 - (580382*CF*lm^2*NM*NC)/3 + 
       (14246103549483313795739*CF*NC*NL)/1619865277430400 - 
       (9392112625019617*CF*lm*NC*NL)/29218349160 - (580382*CF*lm^2*NC*NL)/
        3 + (90199402349439082323265616402785548387307509600817*CF*NC*NH)/
        338681083434540975574758598511269044000000 - 
       (9392112625019617*CF*lm*NC*NH)/29218349160 - (580382*CF*lm^2*NC*NH)/
        3 - (2318848540963579680994241923*CF^2*NC*Pi^2)/377501071147200 + 
       (37600*CF^2*lm*NC*Pi^2)/3 + (196661755359044891*CF*NM*NC*Pi^2)/
        243243 + (18800*CF*lm*NM*NC*Pi^2)/27 - (130604556391*CF*NC*NL*Pi^2)/
        243243 + (18800*CF*lm*NC*NL*Pi^2)/27 + (18800*CF*lm*NC*NH*Pi^2)/
        27 - (112585087504881962928572833*CF^2*NC*Pi^3)/
        (14132367306976707360*Sqrt[3]) - (7679576778469456770140*CF*NC*NH*
         Pi^3)/(205891132094649*Sqrt[3]) - (498861637*CF^2*NC*Pi^4)/2700 + 
       (22159137742657799025183403550593*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (495127488599928942357600*Sqrt[3]) + (15673235112496704979401644*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(79268085856439865*Sqrt[3]) - 
       (101513596*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (112585087504881962928572833*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(381661154123599350*
         Sqrt[3]) - (3510663670157465952064*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (112585087504881962928572833*CF^2*NC*Pi*Log[3]^2)/
        (18319735397932768800*Sqrt[3]) - (219416479384841622004*CF*NC*NH*Pi*
         Log[3]^2)/(7625597484987*Sqrt[3]) + 
       CF*((-144928801542359428285350331*CF*NC)/1966151412225 - 
         174378672*CF*lm*NC + CA*(42469937011434217647471101/1152323172000 + 
           53282372*lm)*NC + (97399797534950758075439*NM*NC)/10039179150 - 
         9687704*lm*NM*NC - (536705078*NC*NL)/45 - 9687704*lm*NC*NL - 
         (75278093002736737*NC*NH)/30117537450 - 9687704*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(41872446498211082449*CA - 
          3360*(24924950876278719*CF - 715*(5146645181192*NM + 
              10898667*NL)))*Log[x]^3)/4054050 - 
       (115245482257777911160011080377*CF^2*NC*PolyGamma[2, 1])/
        27795302832777615 + (779209913776009*CF*NM*NC*PolyGamma[2, 1])/450 - 
       (297938270141056345627181*CF*NC*NH*PolyGamma[2, 1])/
        18530201888518410 + CA*CF*NC*
        (-1205079167197412841435700985585386947515263306987361391461/
          176879877139813312982782621100754945936000000 + (3192101*lm^2)/3 + 
         (244089348600882578078570561*Pi^2)/79473909715200 + 
         (112585087504881962928572833*Pi^3)/(28264734613953414720*Sqrt[3]) + 
         (55763293*Pi^4)/600 + lm*(16586332470792577/5312427120 - 
           (103400*Pi^2)/27) - (22159137742657799025183403550593*
           Im[PolyLog[2, (-1)^(1/3)]])/(990254977199857884715200*Sqrt[3]) + 
         (50756798*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (112585087504881962928572833*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (763322308247198700*Sqrt[3]) + (112585087504881962928572833*Pi*
           Log[3]^2)/(36639470795865537600*Sqrt[3]) + 
         (115245482257777911160011080377*PolyGamma[2, 1])/55590605665555230 - 
         (1133066541097935693062613525162289*Zeta[3])/
          1112923925424415704600) + (566538418578717987783268144538207*CF^2*
         NC*Zeta[3])/278230981356103926150 + 
       (436113781106809*CF*NM*NC*Zeta[3])/225 - 
       (100630616*CF*NC*NL*Zeta[3])/9 + (334586108405179578649219*CF*NC*NH*
         Zeta[3])/9265100944259205 + CF*Log[x]*
        ((83694919607145143247365925617911*NM*NC)/31010805540244530000 - 
         (1653260568046*lm*NM*NC)/405405 - 742560*lm^2*NM*NC - 
         (434827441328508929*NC*NL)/22475653200 - (1653260568046*lm*NC*NL)/
          405405 - 742560*lm^2*NC*NL - 
         (163972924561916528577046252154243297027*NC*NH)/
          602427389683798741750497810000 - (1653260568046*lm*NC*NH)/405405 - 
         742560*lm^2*NC*NH + (20586535727920*NM*NC*Pi^2)/27 - 
         (5586412*NC*NL*Pi^2)/3 + (3510663670157465952064*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(-322031360001564684535863714988083210320781773441/
            8809479066812614504582410061920000 - (2854964830892*lm)/45045 - 
           13366080*lm^2 - (83745220360403306261*Pi^2)/16216200 + 
           (112585087504881962928572833*Im[PolyLog[2, (-1)^(1/3)]])/
            (1144983462370798050*Sqrt[3]) - 8910720*Zeta[3]) + 
         CA*NC*(476378489070180532887730530230228655689078033/
            26063547534948563623024881840000 + (1018199625623*lm)/36855 + 
           4084080*lm^2 + (83745265899185377043*Pi^2)/32432400 - 
           (112585087504881962928572833*Im[PolyLog[2, (-1)^(1/3)]])/
            (2289966924741596100*Sqrt[3]) + 4455360*Zeta[3])), 
      (-289077315494173170770445158407706937337049161380934734811721*CF^2*NC)/
        32545897393725649588832002282538910052224000000 - 
       (1312201164914291*CF^2*lm*NC)/324648324 - 4395588*CF^2*lm^2*NC - 
       (345293383462559045524926077393024309434733197*CF*NM*NC)/
        5396265895008341105610858000000 - (2382466372810175*CF*lm*NM*NC)/
        5843669832 - (732598*CF*lm^2*NM*NC)/3 + 
       (50939018802882991504249*CF*NC*NL)/4211649721319040 - 
       (2382466372810175*CF*lm*NC*NL)/5843669832 - (732598*CF*lm^2*NC*NL)/
        3 + (2697303401612187611798445982816368631068613832929671787*CF*NC*
         NH)/7434083649496517867963508713182206642704400000 - 
       (2382466372810175*CF*lm*NC*NH)/5843669832 - (732598*CF*lm^2*NC*NH)/
        3 + (83244977333144570343345103*CF^2*NC*Pi^2)/19868477428800 + 
       (46240*CF^2*lm*NC*Pi^2)/3 + (2580215279448147112*CF*NM*NC*Pi^2)/
        93555 + (23120*CF*lm*NM*NC*Pi^2)/27 - (170792664865*CF*NC*NL*Pi^2)/
        243243 + (23120*CF*lm*NC*NL*Pi^2)/27 + (23120*CF*lm*NC*NH*Pi^2)/
        27 - (151051808733997634880152233*CF^2*NC*Pi^3)/
        (14132367306976707360*Sqrt[3]) - (94266551971976491243360*CF*NC*NH*
         Pi^3)/(1853020188851841*Sqrt[3]) - (655934477*CF^2*NC*Pi^4)/2700 + 
       (6040264949957528023094273398469*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (99025497719985788471520*Sqrt[3]) + (190272109783318218147908128*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(713412772707958785*Sqrt[3]) - 
       (131844316*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (151051808733997634880152233*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(381661154123599350*
         Sqrt[3]) - (43093280901474967425536*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (151051808733997634880152233*CF^2*NC*Pi*Log[3]^2)/
        (18319735397932768800*Sqrt[3]) - (2693330056342185464096*CF*NC*NH*Pi*
         Log[3]^2)/(68630377364883*Sqrt[3]) + 
       CF*((2273604433884748306928788721*CF*NC)/45221482481175 - 
         237389904*CF*lm*NC + CA*(-13991439522523117911431446097/
            556572092076000 + 72535804*lm)*NC + 
         (1661262861721567231194751*NM*NC)/5019589575 - 13188328*lm*NM*NC - 
         (730379126*NC*NL)/45 - 13188328*lm*NC*NL - 
         (101666897407083469*NC*NH)/29113619535 - 13188328*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-28193170097678930011*CA + 
          40*(1409554869262006879*CF + 60060*(158475454037477*NM + 
              14836869*NL)))*Log[x]^3)/4054050 + 
       (226924098886195046623633462594*CF^2*NC*PolyGamma[2, 1])/
        138976514163888075 + (3320927622655213*CF*NM*NC*PolyGamma[2, 1])/
        150 - (17926254816385739088867689*CF*NC*NH*PolyGamma[2, 1])/
        833859084983328450 - (1026262193626272178041566398746397*CF^2*NC*
         Zeta[3])/278230981356103926150 - (200742933628787*CF*NM*NC*Zeta[3])/
        75 - (136266152*CF*NC*NL*Zeta[3])/9 + 
       (21651738780726331303160311*CF*NC*NH*Zeta[3])/416929542491664225 + 
       CA*CF*NC*(18067281933301362860975823139131779245055374825192576301261/
          4068237174215706198604000285317363756528000000 + (4029289*lm^2)/3 - 
         (186076966348185287011068373*Pi^2)/88823781446400 + 
         (151051808733997634880152233*Pi^3)/(28264734613953414720*Sqrt[3]) + 
         (659633677*Pi^4)/5400 + lm*(4198673998330463/1062485424 - 
           (127160*Pi^2)/27) - (6040264949957528023094273398469*
           Im[PolyLog[2, (-1)^(1/3)]])/(198050995439971576943040*Sqrt[3]) + 
         (65922158*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (151051808733997634880152233*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (763322308247198700*Sqrt[3]) + (151051808733997634880152233*Pi*
           Log[3]^2)/(36639470795865537600*Sqrt[3]) - 
         (113462049443097523311816731297*PolyGamma[2, 1])/
          138976514163888075 + (2052538187893039257618615203616719*Zeta[3])/
          1112923925424415704600) + CF*Log[x]*
        ((2429193051076629697981884383176019*NM*NC)/15505402770122265000 - 
         (2172470940862*lm*NM*NC)/405405 - 971040*lm^2*NM*NC - 
         (7646985081624500279*NC*NL)/292183491600 - 
         (2172470940862*lm*NC*NL)/405405 - 971040*lm^2*NC*NL - 
         (8284650127404068338782353153173937798687*NC*NH)/
          22320566704627069044871766061000 - (2172470940862*lm*NC*NH)/
          405405 - 971040*lm^2*NC*NH + (633901760320480*NM*NC*Pi^2)/27 - 
         (7565204*NC*NL*Pi^2)/3 + (43093280901474967425536*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(5282939392299507210104988829543077500069454364481/
            202618018536690133605395431424160000 - (3754445174924*lm)/45045 - 
           17478720*lm^2 + (56385893410094773219*Pi^2)/16216200 + 
           (151051808733997634880152233*Im[PolyLog[2, (-1)^(1/3)]])/
            (1144983462370798050*Sqrt[3]) - 11652480*Zeta[3]) + 
         CA*NC*(-20318939036569041216549020801985993918827515861/
            1558600142589924104656887934032000 + (1336749224831*lm)/36855 + 
           5340720*lm^2 - (56385831963944826037*Pi^2)/32432400 - 
           (151051808733997634880152233*Im[PolyLog[2, (-1)^(1/3)]])/
            (2289966924741596100*Sqrt[3]) + 5826240*Zeta[3])), 
      (43364361346131996182277331233425699576263779172306197102698711*CF^2*
         NC)/292913076543530846299488020542850190470016000000 - 
       (601368065979549719*CF^2*lm*NC)/121743121500 - (27061892*CF^2*lm^2*NC)/
        5 - (1003904015090449811142958388594959272817109621*CF*NM*NC)/
        46010267104807961005734684000000 - (1095557946845931419*CF*lm*NM*NC)/
        2191376187000 - (13530946*CF*lm^2*NM*NC)/45 + 
       (25144180122760937440751357*CF*NC*NL)/1579368645494640000 - 
       (1095557946845931419*CF*lm*NC*NL)/2191376187000 - 
       (13530946*CF*lm^2*NC*NL)/45 + 
       (20783849918979392153248858862344140119147945726584720793*CF*NC*NH)/
        44604501896979107207781052279093239856226400000 - 
       (1095557946845931419*CF*lm*NC*NH)/2191376187000 - 
       (13530946*CF*lm^2*NC*NH)/45 - (372150284042945307889438450037*CF^2*NC*
         Pi^2)/5662516067208000 + (823072*CF^2*lm*NC*Pi^2)/45 + 
       (39694572145077521513*CF*NM*NC*Pi^2)/6081075 + 
       (411536*CF*lm*NM*NC*Pi^2)/405 - (16216596235013*CF*NC*NL*Pi^2)/
        18243225 + (411536*CF*lm*NC*NL*Pi^2)/405 + 
       (411536*CF*lm*NC*NH*Pi^2)/405 - (1759341359961774530128592777*CF^2*NC*
         Pi^3)/(127191305762790366240*Sqrt[3]) - 
       (363713001297220696825900*CF*NC*NH*Pi^3)/(5559060566555523*Sqrt[3]) - 
       (2509124911*CF^2*NC*Pi^4)/8100 + (1734428899262326720113481236780541*
         CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(22280736986996802406092000*
         Sqrt[3]) + (48095621896334382963067318604*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(139115490678051963075*Sqrt[3]) - 
       (166800124*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (1759341359961774530128592777*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3434950387112394150*
         Sqrt[3]) - (166268800593015175691840*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (1759341359961774530128592777*CF^2*NC*Pi*Log[3]^2)/
        (164877618581394919200*Sqrt[3]) - (10391800037063448480740*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) - 
       (CF*NC*(-29*CA*(8559462659295523135431049193777 + 
            2055508265136467764022400*lm) + 
          112*(58*CF*(76423786149170143914998045587 + 30031776601019821227600*
               lm) + 715*(2755*(-223496213046997913468465 + 49125713165697168*
                 lm)*NM + 395945225676*(419305793 + 341818340*lm)*NL + 
              101*(362770594930634507 + 1340013265064313840*lm)*NH)))*
         Log[x]^2)/629483036137956000 + 
       (CF*NC*(1349344112652331932843*CA + 16*(-168669055656169448267*CF + 
            30030*(633473010911242*NM + 290545589*NL)))*Log[x]^3)/
        12162150 - (54909494241925037185628547155629*CF^2*NC*PolyGamma[2, 1])/
        1250788627474992675 + (20590441659375221*CF*NM*NC*PolyGamma[2, 1])/
        1350 - (69469081304555030447612213*CF*NC*NH*PolyGamma[2, 1])/
        2501577254949985350 + CA*CF*NC*
        (-2710273171950996780729969130523015913893594874727867476494171/
          36614134567941355787436002567856273808752000000 + 
         (74420203*lm^2)/45 + (8756477431607967351587329657*Pi^2)/
          266471344339200 + (1759341359961774530128592777*Pi^3)/
          (254382611525580732480*Sqrt[3]) + (2522294063*Pi^4)/16200 + 
         lm*(1934183199225245819/398432034000 - (2263448*Pi^2)/405) - 
         (1734428899262326720113481236780541*Im[PolyLog[2, (-1)^(1/3)]])/
          (44561473973993604812184000*Sqrt[3]) + 
         (83400062*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (1759341359961774530128592777*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6869900774224788300*Sqrt[3]) + (1759341359961774530128592777*Pi*
           Log[3]^2)/(329755237162789838400*Sqrt[3]) + 
         (54909494241925037185628547155629*PolyGamma[2, 1])/
          2501577254949985350 - (16560225181972880752241661897010079*Zeta[3])/
          1430902189831391620200) + (8280124094945117294197360928165953*CF^2*
         NC*Zeta[3])/357725547457847905050 + 
       (12144207222844901*CF*NM*NC*Zeta[3])/675 - 
       (886035512*CF*NC*NL*Zeta[3])/45 + (82314948693752192882974267*CF*NC*
         NH*Zeta[3])/1250788627474992675 + CF*Log[x]*
        ((1000088419814600108549104584388787*NM*NC)/52080348060410670000 - 
         (41285132014474*lm*NM*NC)/6081075 - 1229984*lm^2*NM*NC - 
         (148798092646740317707*NC*NL)/4382752374000 - 
         (41285132014474*lm*NC*NL)/6081075 - 1229984*lm^2*NC*NL - 
         (1306057181442502340070632313333913254432887*NC*NH)/
          2735863747510003605785710754334000 - (41285132014474*lm*NC*NH)/
          6081075 - 1229984*lm^2*NC*NH + (506778188140720*NM*NC*Pi^2)/81 - 
         (1328230196*NC*NL*Pi^2)/405 + (166268800593015175691840*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-702739641116232647581817319127454337268651647630383/
            1823562166830211202448558882817440000 - (71350826599748*lm)/
            675675 - 22139712*lm^2 - (128509046687637087587*Pi^2)/2316600 + 
           (1759341359961774530128592777*Im[PolyLog[2, (-1)^(1/3)]])/
            (10304851161337182450*Sqrt[3]) - 14759808*Zeta[3]) + 
         CA*NC*(13514227260483956869225282303811692876870084233563/
            70137006416546584709559957031440000 + (25402327340837*lm)/
            552825 + 6764912*lm^2 + (42836352706048959143*Pi^2)/1544400 - 
           (1759341359961774530128592777*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) + 7379904*Zeta[3])), 
      (-146368805609079594743504973177142423246212934318544944587915529*CF^2*
         NC)/1464565382717654231497440102714250952350080000000 - 
       (6979713153202046*CF^2*lm*NC)/1127251125 - (33664284*CF^2*lm^2*NC)/5 - 
       (875834750840852165072000714239180100490903841*CF*NM*NC)/
        1300885528260939373674046125000 - (12671928454899971*CF*lm*NM*NC)/
        20290520250 - (1870238*CF*lm^2*NM*NC)/5 + 
       (73282168374271861767577*CF*NC*NL)/3418546851720000 - 
       (12671928454899971*CF*lm*NC*NL)/20290520250 - 
       (1870238*CF*lm^2*NC*NL)/5 + 
       (51706195738448661025115293333886511964410648931613921404877*CF*NC*
         NH)/83050794750806536426687833027904169284802542650000 - 
       (12671928454899971*CF*lm*NC*NH)/20290520250 - 
       (1870238*CF*lm^2*NC*NH)/5 + (825683330531697066669157369*CF^2*NC*
         Pi^2)/17976241483200 + (110976*CF^2*lm*NC*Pi^2)/5 + 
       (194270046761856500839*CF*NM*NC*Pi^2)/675675 + 
       (18496*CF*lm*NM*NC*Pi^2)/15 - (772251999808*CF*NC*NL*Pi^2)/675675 + 
       (18496*CF*lm*NC*NL*Pi^2)/15 + (18496*CF*lm*NC*NH*Pi^2)/15 - 
       (2316858594571912746628991077*CF^2*NC*Pi^3)/(127191305762790366240*
         Sqrt[3]) - (486430121690070259931320*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (72027487*CF^2*NC*Pi^4)/180 + 
       (2318109723243433363391644493146289*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22280736986996802406092000*Sqrt[3]) + 
       (5796053227847872256462374468*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12646862788913814825*Sqrt[3]) - 
       (213175308*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (2316858594571912746628991077*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3434950387112394150*
         Sqrt[3]) - (222368055629746404540032*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (2316858594571912746628991077*CF^2*NC*Pi*Log[3]^2)/
        (164877618581394919200*Sqrt[3]) - (13898003476859150283752*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((16616849194753392428061517693*CF*NC)/30147654987450 - 
         (2068069856*CF*lm*NC)/5 + CA*(-6713880567858431165365753577/
            24361741404000 + (5687192104*lm)/45)*NC + 
         (22267010419154898622120502*NM*NC)/6453758025 - 
         (1034034928*lm*NM*NC)/45 - (6340641028*NC*NL)/225 - 
         (1034034928*lm*NC*NL)/45 - (258477146570695418854*NC*NH)/
          40613499251325 - (1034034928*lm*NC*NH)/45)*Log[x]^2 + 
       (CF*NC*(-103735149772330695369*CA + 320*(648336710206027210*CF + 
            1001*(4140210792584889*NM + 64627183*NL)))*Log[x]^3)/1351350 + 
       (990488644846001691343635262216*CF^2*NC*PolyGamma[2, 1])/
        50031545098999707 + (30304417956656051*CF*NM*NC*PolyGamma[2, 1])/
        135 - (15212042512987040701594624*CF*NC*NH*PolyGamma[2, 1])/
        416929542491664225 - (8461341983730811957711428702316019*CF^2*NC*
         Zeta[3])/227643530200448666850 - (5634517303989146*CF*NM*NC*
         Zeta[3])/135 - (1177027504*CF*NC*NL*Zeta[3])/45 + 
       (38291715240930882682775872*CF*NC*NH*Zeta[3])/416929542491664225 + 
       CA*CF*NC*
        (9148046484653384488103665524077504321060958342300021630475219/
          183070672839706778937180012839281369043760000000 + 
         (10286309*lm^2)/5 - (23128383828901120764200461*Pi^2)/
          1007072352000 + (2316858594571912746628991077*Pi^3)/
          (254382611525580732480*Sqrt[3]) + (361913051*Pi^4)/1800 + 
         lm*(22331445330508571/3689185500 - (101728*Pi^2)/15) - 
         (2318109723243433363391644493146289*Im[PolyLog[2, (-1)^(1/3)]])/
          (44561473973993604812184000*Sqrt[3]) + 
         (106587654*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (2316858594571912746628991077*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6869900774224788300*Sqrt[3]) + (2316858594571912746628991077*Pi*
           Log[3]^2)/(329755237162789838400*Sqrt[3]) - 
         (495244322423000845671817631108*PolyGamma[2, 1])/50031545098999707 + 
         (16922703249794820842774950375920169*Zeta[3])/
          910574120801794667400) + CF*Log[x]*
        ((2934754071679371693904150316049521039*NM*NC)/
          1814132124104305005000 - (1974394668824*lm*NM*NC)/225225 - 
         1581408*lm^2*NM*NC - (2992257345714971639*NC*NL)/66405339000 - 
         (1974394668824*lm*NC*NL)/225225 - 1581408*lm^2*NC*NL - 
         (839155265601130205890600589364467645174596429*NC*NH)/
          1314582530678556732580034017457487000 - (1974394668824*lm*NC*NH)/
          225225 - 1581408*lm^2*NC*NH + (2208112392833312*NM*NC*Pi^2)/9 - 
         (588180824*NC*NL*Pi^2)/135 + (222368055629746404540032*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(2544510389775710805327124736398080673867748781414289/
            9117810834151056012242794414087200000 - (3414530412448*lm)/
            25025 - 28465344*lm^2 + (18860912613112367039*Pi^2)/491400 + 
           (2316858594571912746628991077*Im[PolyLog[2, (-1)^(1/3)]])/
            (10304851161337182450*Sqrt[3]) - 18976896*Zeta[3]) + 
         CA*NC*(-57829755402737956691281270807412277911855903845991/
            414445947006866182374672473367600000 + (1213852636012*lm)/20475 + 
           8697744*lm^2 - (18860909402265741689*Pi^2)/982800 - 
           (2316858594571912746628991077*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) + 9488448*Zeta[3])), 
      (6824011629330495105206467805176574751740744496749858605853807383439243*
         CF^2*NC)/4286314214292104286238927999811743977223932134400000000 - 
       (308568184433692223*CF^2*lm*NC)/41225184000 - (16387371*CF^2*lm^2*NC)/
        2 - (1627630267949574609750827369117343881622329923085021*CF*NM*NC)/
        9096850638491334766254251073469440000 - 
       (561907828715416223*CF*lm*NM*NC)/742053312000 - 
       (1820819*CF*lm^2*NM*NC)/4 + (116964823174785078730998239*CF*NC*NL)/
        4211649721319040000 - (561907828715416223*CF*lm*NC*NL)/
        742053312000 - (1820819*CF*lm^2*NC*NL)/4 + 
       (1766299711285505380887724461927728419186403595967618930896553*CF*NC*
         NH)/2238000363811207718445482658436154456516784307200000 - 
       (561907828715416223*CF*lm*NC*NH)/742053312000 - 
       (1820819*CF*lm^2*NC*NH)/4 - (93562370485780494230014131311*CF^2*NC*
         Pi^2)/134222603074560 + (260967*CF^2*lm*NC*Pi^2)/10 + 
       (270806293164961895687*CF*NM*NC*Pi^2)/5405400 + 
       (86989*CF*lm*NM*NC*Pi^2)/60 - (4410810019793*CF*NC*NL*Pi^2)/
        3088800 + (86989*CF*lm*NC*NL*Pi^2)/60 + (86989*CF*lm*NC*NH*Pi^2)/
        60 - (35454055687467501493709476829*CF^2*NC*Pi^3)/
        (1526295669153484394880*Sqrt[3]) - (1234927796685819484493735*CF*NC*
         NH*Pi^3)/(11118121133111046*Sqrt[3]) - (603783611*CF^2*NC*Pi^4)/
        1200 + (2806713519403174331776849280532347*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(21389507507516930309848320*Sqrt[3]) + 
       (29640946249391743871542832977*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (50587451155655259300*Sqrt[3]) - 
       (266173641*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (35454055687467501493709476829*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(41219404645348729800*
         Sqrt[3]) - (282269210671044453598568*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (35454055687467501493709476829*CF^2*NC*Pi*Log[3]^2)/
        (1978531422976739030400*Sqrt[3]) - (35283651333880556699821*CF*NC*NH*
         Pi*Log[3]^2)/(411782264189298*Sqrt[3]) + 
       CF*((-11701145618437874758866218426091187*CF*NC)/1398851191417680000 - 
         (2659904456*CF*lm*NC)/5 + CA*(900088100829915312130748549709439/
            215207875602720000 + (7314737254*lm)/45)*NC + 
         (12602038872660186908216016793*NM*NC)/20961806065200 - 
         (1329952228*lm*NM*NC)/45 - (8131697023*NC*NL)/225 - 
         (1329952228*lm*NC*NL)/45 - (285576146306653814461*NC*NH)/
          34200841474800 - (1329952228*lm*NC*NH)/45)*Log[x]^2 - 
       (CF*NC*(-6384037685615479046205*CA + 4*(3192022208122247460341*CF - 
            40040*(6645973814900847*NM + 664976114*NL)))*Log[x]^3)/
        5405400 - (9245033205891986157982610397172177*CF^2*NC*
         PolyGamma[2, 1])/20012618039599882800 + 
       (358940045906033827*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (1395329798962278280329332479*CF*NC*NH*PolyGamma[2, 1])/
        30018927059399824200 + CA*CF*NC*(-68240118612323662072578409149261354\
39498159361166966795022558205165493/
          8572628428584208572477855999623487954447864268800000000 + 
         (20029009*lm^2)/8 + (137591721687043771537387128163*Pi^2)/
          394772361984000 + (35454055687467501493709476829*Pi^3)/
          (3052591338306968789760*Sqrt[3]) + (606567259*Pi^4)/2400 + 
         lm*(991817528102584223/134918784000 - (956879*Pi^2)/120) - 
         (2806713519403174331776849280532347*Im[PolyLog[2, (-1)^(1/3)]])/
          (42779015015033860619696640*Sqrt[3]) + 
         (266173641*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (35454055687467501493709476829*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(82438809290697459600*Sqrt[3]) + 
         (35454055687467501493709476829*Pi*Log[3]^2)/(3957062845953478060800*
           Sqrt[3]) + (9245033205891986157982610397172177*PolyGamma[2, 1])/
          40025236079199765600 - (5150950670172989876469990981148759169*
           Zeta[3])/40065261315278965365600) + 
       (5150951755054780938126635574702876269*CF^2*NC*Zeta[3])/
        20032630657639482682800 + (226020818424976297*CF*NM*NC*Zeta[3])/
        1350 - (1508643529*CF*NC*NL*Zeta[3])/45 + 
       (1727930107506609171347294441*CF*NC*NH*Zeta[3])/
        15009463529699912100 + CF*Log[x]*
        ((227534151884944462507355047273265486173*NM*NC)/
          1952876948955802251782400 - (5642289794747*lm*NM*NC)/514800 - 
         1976760*lm^2*NM*NC - (42097132113209380729*NC*NL)/730458729000 - 
         (5642289794747*lm*NC*NL)/514800 - 1976760*lm^2*NC*NL - 
         (12558502810439962862604339798160039329672539537*NC*NH)/
          15498236151157721478838295784761952000 - (5642289794747*lm*NC*NH)/
          514800 - 1976760*lm^2*NC*NH + (443064882274115*NM*NC*Pi^2)/9 - 
         (753930314*NC*NL*Pi^2)/135 + (282269210671044453598568*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-1854653458242389964355640339719746966870404055984557808641/
            460084734691262286377771406134840112000000 - (4879062758747*lm)/
            28600 - 35581680*lm^2 - (4256025572177875752341*Pi^2)/7207200 + 
           (35454055687467501493709476829*Im[PolyLog[2, (-1)^(1/3)]])/
            (123658213936046189400*Sqrt[3]) - 23721120*Zeta[3]) + 
         CA*NC*(3709307063959308177898125694911079209365553888545441911807/
            1840338938765049145511085624539360448000000 + (6937462946747*lm)/
            93600 + 10872180*lm^2 + (12768076897836320192387*Pi^2)/43243200 - 
           (35454055687467501493709476829*Im[PolyLog[2, (-1)^(1/3)]])/
            (247316427872092378800*Sqrt[3]) + 11860560*Zeta[3])), 
      (-473115833738858999692502038679771871141270455371225429574753039062376\
9*CF^2*NC)/4286314214292104286238927999811743977223932134400000000 - 
       (2670472227620774261*CF^2*lm*NC)/288576288000 - 
       (100623867*CF^2*lm^2*NC)/10 - 
       (320272582736619643183721438829374380782354547991753461*CF*NM*NC)/
        45484253192456673831271255367347200000 - 
       (4848296879350701461*CF*lm*NM*NC)/5194373184000 - 
       (33541289*CF*lm^2*NM*NC)/60 + (638863824375535048408537*CF*NC*NL)/
        17403511245120000 - (4848296879350701461*CF*lm*NC*NL)/
        5194373184000 - (33541289*CF*lm^2*NC*NL)/60 + 
       (1983514231720546119623649255468195890899705782151281377139455393*CF*
         NC*NH)/1913490311058582599270887672962912060321850582656000000 - 
       (4848296879350701461*CF*lm*NC*NH)/5194373184000 - 
       (33541289*CF*lm^2*NC*NH)/60 + (149978980220602908644367192511*CF^2*NC*
         Pi^2)/302000856917760 + (312987*CF^2*lm*NC*Pi^2)/10 + 
       (8055927341588710626941*CF*NM*NC*Pi^2)/2702700 + 
       (104329*CF*lm*NM*NC*Pi^2)/60 - (39111636972311*CF*NC*NL*Pi^2)/
        21621600 + (104329*CF*lm*NC*NL*Pi^2)/60 + (104329*CF*lm*NC*NH*Pi^2)/
        60 - (22964597956994432898706394867*CF^2*NC*Pi^3)/
        (763147834576742197440*Sqrt[3]) - (14609725569424144231381085*CF*NC*
         NH*Pi^3)/(100063090197999414*Sqrt[3]) - (3455681069*CF^2*NC*Pi^4)/
        5400 + (46088092084515419670299819755837787*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(267368843843961628873104000*Sqrt[3]) + 
       (547150783923248758795579299239*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (715451094915695810100*Sqrt[3]) - 
       (335370254*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (22964597956994432898706394867*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(20609702322674364900*
         Sqrt[3]) - (3339365844439804395744248*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (22964597956994432898706394867*CF^2*NC*Pi*Log[3]^2)/
        (989265711488369515200*Sqrt[3]) - (417420730554975549468031*CF*NC*NH*
         Pi*Log[3]^2)/(3706040377703682*Sqrt[3]) + 
       CF*((487188086270280355659603706387871*CF*NC)/81751043654280000 - 
         (3488552456*CF*lm*NC)/5 + CA*(-9378371119319233315289868226108093/
            3147415180689780000 + (9593519254*lm)/45)*NC + 
         (57674560047377967388541017921*NM*NC)/1612446620400 - 
         (1744276228*lm*NM*NC)/45 - (10663228393*NC*NL)/225 - 
         (1744276228*lm*NC*NL)/45 - (1037391326783802295543*NC*NH)/
          92830855431600 - (1744276228*lm*NC*NH)/45)*Log[x]^2 + 
       (CF*NC*(-13536280074421403872125*CA + 8*(3384063194251240672027*CF + 
            60060*(344187456806889387*NM + 872138114*NL)))*Log[x]^3)/
        16216200 + (10366789587709638628685430140533957*CF^2*NC*
         PolyGamma[2, 1])/45028390589099736300 + 
       (6136624648952049919*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (3249024459864679149841214809*CF*NC*NH*PolyGamma[2, 1])/
        54034068706919683560 - (602505995603815928473009974284760941*CF^2*NC*
         Zeta[3])/1609764963560315572725 - (747124158692712611*CF*NM*NC*
         Zeta[3])/1350 - (1970565829*CF*NC*NL*Zeta[3])/45 + 
       (4233291364040506612385377727*CF*NC*NH*Zeta[3])/
        27017034353459841780 + CA*CF*NC*(473115803685280094515268998003850740\
7874351577669220368399612002637769/
          8572628428584208572477855999623487954447864268800000000 + 
         (368954179*lm^2)/120 - (3869426715009463199776441463*Pi^2)/
          15583119552000 + (22964597956994432898706394867*Pi^3)/
          (1526295669153484394880*Sqrt[3]) + (694140889*Pi^4)/2160 + 
         lm*(8543999318649971861/944431488000 - (1147619*Pi^2)/120) - 
         (46088092084515419670299819755837787*Im[PolyLog[2, (-1)^(1/3)]])/
          (534737687687923257746208000*Sqrt[3]) + 
         (167685127*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (22964597956994432898706394867*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(41219404645348729800*Sqrt[3]) + 
         (22964597956994432898706394867*Pi*Log[3]^2)/(1978531422976739030400*
           Sqrt[3]) - (10366789587709638628685430140533957*PolyGamma[2, 1])/
          90056781178199472600 + (2410024434532977544168800503186323193*
           Zeta[3])/12878119708482524581800) + 
       CF*Log[x]*((162209300240631891703673663543772138727829*NM*NC)/
          9764384744779011258912000 - (50219103120089*lm*NM*NC)/3603600 - 
         2503896*lm^2*NM*NC - (19978745977628657111*NC*NL)/265621356000 - 
         (50219103120089*lm*NC*NL)/3603600 - 2503896*lm^2*NC*NL - 
         (83503061244784182089904687602054290470589448113*NC*NH)/
          78408236149348235884063567431783840000 - (50219103120089*lm*NC*NH)/
          3603600 - 2503896*lm^2*NC*NH + (22945830407327267*NM*NC*Pi^2)/9 - 
         (984813434*NC*NL*Pi^2)/135 + (3339365844439804395744248*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*(2720044508532903299108536882476232927199963086164562865581/
            920169469382524572755542812269680224000000 - (43451823400889*lm)/
            200200 - 45070128*lm^2 + (966876958813799916323*Pi^2)/2316600 + 
           (22964597956994432898706394867*Im[PolyLog[2, (-1)^(1/3)]])/
            (61829106968023094700*Sqrt[3]) - 30046752*Zeta[3]) + 
         CA*NC*(-1360022159449219140080034656428795009210510462043721720653/
            920169469382524572755542812269680224000000 + (61702971734489*lm)/
            655200 + 13771428*lm^2 - (322292311170550622477*Pi^2)/1544400 - 
           (22964597956994432898706394867*Im[PolyLog[2, (-1)^(1/3)]])/
            (123658213936046189400*Sqrt[3]) + 15023376*Zeta[3])), 
      (3012352632563840971690518528411478918035844071529542381816220847145461\
0824037*CF^2*NC)/
        1776101706724576368643237938044174974390741710821299200000000 - 
       (923868393529662923957*CF^2*lm*NC)/83398547232000 - 
       (121181031*CF^2*lm^2*NC)/10 - 
       (1903673559928686775225701919646989461477683316031883055139*CF*NM*NC)/
        1355021386856476770107401968648640435200000 - 
       (1681842538840359638357*CF*lm*NM*NC)/1501173850176000 - 
       (13464559*CF*lm^2*NM*NC)/20 + (57071523750713393507285171933*CF*NC*
         NL)/1217166769461202560000 - (1681842538840359638357*CF*lm*NC*NL)/
        1501173850176000 - (13464559*CF*lm^2*NC*NL)/20 + 
       (2485178794856440219955952254309412084820686009004889389183467191*CF*
         NC*NH)/1913490311058582599270887672962912060321850582656000000 - 
       (1681842538840359638357*CF*lm*NC*NH)/1501173850176000 - 
       (13464559*CF*lm^2*NC*NH)/20 - (59769853133696350591084646281547*CF^2*
         NC*Pi^2)/8149229472384000 + (364971*CF^2*lm*NC*Pi^2)/10 + 
       (32511350961040041837997*CF*NM*NC*Pi^2)/91891800 + 
       (121657*CF*lm*NM*NC*Pi^2)/60 - (821008560725491*CF*NC*NL*Pi^2)/
        367567200 + (121657*CF*lm*NC*NL*Pi^2)/60 + 
       (121657*CF*lm*NC*NH*Pi^2)/60 - (8844402495276170936415166162567*CF^2*
         NC*Pi^3)/(233523237380483112416640*Sqrt[3]) - 
       (18327699814079874430660175*CF*NC*NH*Pi^3)/(100063090197999414*
         Sqrt[3]) - (38146129*CF^2*NC*Pi^4)/48 + 
       (299137192103598201029045534146612565201*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1390852725676288393397887008000*
         Sqrt[3]) + (4836416845021436239238554452179*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5008157664409870670700*Sqrt[3]) - 
       (413859843*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (8844402495276170936415166162567*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6306568910738355659400*
         Sqrt[3]) - (4189188528932542727008040*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (8844402495276170936415166162567*CF^2*NC*Pi*Log[3]^2)/
        (302715307715441071651200*Sqrt[3]) - (523648566116567840876005*CF*NC*
         NH*Pi*Log[3]^2)/(3706040377703682*Sqrt[3]) - 
       (CF*NC*(-(CA*(194648150935468544857194212988376492601 + 
             1196758742904951488227982016000*lm)) + 
          CF*(389296303491312559681648431155286226702 + 
            3916664976779841234200668416000*lm) + 
          6806800*((-2758861418604323533908264692059 + 
              31966929939177172779840*lm)*NM + 932846951692656*
             (41790173 + 34268140*lm)*NL + (9382853082670296083551 + 
              31966929939177172779840*lm)*NH))*Log[x]^2)/
        4423167467262704160000 + (CF*NC*(1145771407885155504686193*CA - 
          1496*(1531780225820714849207*CF - 1820*(48963735790764291*NM + 
              1106860922*NL)))*Log[x]^3)/91891800 - 
       (10744644940465404976283820952224587*CF^2*NC*PolyGamma[2, 1])/
        2223624226622209200 + (3089607664500836641*CF*NM*NC*PolyGamma[2, 1])/
        2700 - (6813315960217495738593784187*CF*NC*NH*PolyGamma[2, 1])/
        90056781178199472600 + CA*CF*NC*(-25489137793468520074348254786464784\
801926954359541173791020983216265404580839/
          3005710580610821546934710356690142264353562895236044800000000 + 
         (148110149*lm^2)/40 + (629156349039149981985153692869*Pi^2)/
          171562725734400 + (8844402495276170936415166162567*Pi^3)/
          (467046474760966224833280*Sqrt[3]) + (319182083*Pi^4)/800 + 
         lm*(2968101694519117699157/272940700032000 - (1338227*Pi^2)/120) - 
         (299137192103598201029045534146612565201*Im[PolyLog[2, (-1)^(1/3)]])/
          (2781705451352576786795774016000*Sqrt[3]) + 
         (413859843*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (8844402495276170936415166162567*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(12613137821476711318800*Sqrt[3]) + 
         (8844402495276170936415166162567*Pi*Log[3]^2)/
          (605430615430882143302400*Sqrt[3]) + 
         (10744644940465404976283820952224587*PolyGamma[2, 1])/
          4447248453244418400 - (106125116631750221276795779339608282047*
           Zeta[3])/75678826928860267912800) + 
       (106125119986743069466069470368268425159*CF^2*NC*Zeta[3])/
        37839413464430133956400 + (2110333363205515951*CF*NM*NC*Zeta[3])/
        1350 - (2493191077*CF*NC*NL*Zeta[3])/45 + 
       (8754726477826611799757624893*CF*NC*NH*Zeta[3])/
        45028390589099736300 + CF*Log[x]*
        ((4132199673195435501130225892091771386204861*NM*NC)/
          9383573739732629819814432000 - (1054820385490009*lm*NM*NC)/
          61261200 - 3093048*lm^2*NM*NC - (2358956167671232245373*NC*NL)/
          24835596786000 - (1054820385490009*lm*NC*NL)/61261200 - 
         3093048*lm^2*NC*NL - 
         (2529065459110496467693121593400540188105367300377*NC*NH)/
          1892998844177121694915248985138781280000 - 
         (1054820385490009*lm*NC*NH)/61261200 - 3093048*lm^2*NC*NH + 
         (3264248993366111*NM*NC*Pi^2)/9 - (1246048082*NC*NL*Pi^2)/135 + 
         (4189188528932542727008040*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1853020188851841*Sqrt[3]) + 
         CF*NC*
          (-2832428420077642533623467680819911223184243230399263979925327639/
            67647638795860367752982863158223946187696000000 - 
           (912707511386809*lm)/3403400 - 55674864*lm^2 - 
           (152769523599388630739891*Pi^2)/24504480 + 
           (8844402495276170936415166162567*Im[PolyLog[2, (-1)^(1/3)]])/
            (18919706732215066978200*Sqrt[3]) - 37116576*Zeta[3]) + 
         CA*NC*
          (514986988644415841930513664071273899297802443118714247303062023/
            24599141380312861001084677512081434977344000000 + 
           (1295981626392409*lm)/11138400 + 17011764*lm^2 + 
           (2291542859075938469709997*Pi^2)/735134400 - 
           (8844402495276170936415166162567*Im[PolyLog[2, (-1)^(1/3)]])/
            (37839413464430133956400*Sqrt[3]) + 18558288*Zeta[3])), 
      (-837797365979709441226000890918147313459246116827341292701707869413743\
2782163*CF^2*NC)/
        697754241927512144824129189945925882796362814965510400000000 - 
       (564192478860462589*CF^2*lm*NC)/41699273616 - 14712669*CF^2*lm^2*NC - 
       (24800056882415796735675299426111569047924318380844353161849*CF*NM*
         NC)/338755346714119192526850492162160108800000 - 
       (1024323186549943417*CF*lm*NM*NC)/750586925088 - 
       (1634741*CF*lm^2*NM*NC)/2 + (296862884098475731144722359*CF*NC*NL)/
        4868667077844810240 - (1024323186549943417*CF*lm*NC*NL)/
        750586925088 - (1634741*CF*lm^2*NC*NL)/2 + 
       (1446623068361614572702081599383446921298414329095748649886897933*CF*
         NC*NH)/861070639976362169671899452833310427144832762195200000 - 
       (1024323186549943417*CF*lm*NC*NH)/750586925088 - 
       (1634741*CF*lm^2*NC*NH)/2 + (321356446135213827216021429035083*CF^2*
         NC*Pi^2)/60555043617868800 + 43320*CF^2*lm*NC*Pi^2 + 
       (47069998839163161374879*CF*NM*NC*Pi^2)/1531530 + 
       (7220*CF*lm*NM*NC*Pi^2)/3 - (2565845067427*CF*NC*NL*Pi^2)/918918 + 
       (7220*CF*lm*NC*NL*Pi^2)/3 + (7220*CF*lm*NC*NH*Pi^2)/3 - 
       (11291962795300961848996444522057*CF^2*NC*Pi^3)/
        (233523237380483112416640*Sqrt[3]) - (106761972237103713516712985*CF*
         NC*NH*Pi^3)/(450283905890997363*Sqrt[3]) - 
       (3589065173*CF^2*NC*Pi^4)/3600 + 
       (386978478948616918202039782133434568591*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1390852725676288393397887008000*
         Sqrt[3]) + (2801316239629009717573960253894*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2253670948984441801815*Sqrt[3]) - 
       (514887213*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (11291962795300961848996444522057*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6306568910738355659400*
         Sqrt[3]) - (48805473022675983321925936*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (11291962795300961848996444522057*CF^2*NC*Pi*Log[3]^2)/
        (302715307715441071651200*Sqrt[3]) - (3050342063917248957620371*CF*NC*
         NH*Pi*Log[3]^2)/(16677181699666569*Sqrt[3]) + 
       CF*((140838473849433123457707363727918662467*CF*NC)/
          2211583733631352080000 - 1143546616*CF*lm*NC + 
         CA*(-140838474905406927795551744879820518327/
            4423167467262704160000 + (3144753194*lm)/9)*NC + 
         (11982855493939233303354064166873*NM*NC)/32490799401060 - 
         (571773308*lm*NM*NC)/9 - (3486040808*NC*NL)/45 - 
         (571773308*lm*NC*NL)/9 - (123383407327026950017*NC*NH)/
          6498159880212 - (571773308*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-102960524828536927338453*CA + 4*(51480245717709747616409*CF + 
            850850*(355710586042648827*NM + 142943327*NL)))*Log[x]^3)/
        11486475 + (87777662773404707704328521584472426*CF^2*NC*
         PolyGamma[2, 1])/33771292941824802225 + 
       (31010314556004281819*CF*NM*NC*PolyGamma[2, 1])/1350 - 
       (39115920100479786780566544253*CF*NC*NH*PolyGamma[2, 1])/
        405255515301897626700 - (6924316013506652017273898528105115324617*
         CF^2*NC*Zeta[3])/1838995494371304510281040 - 
       (4560743779027553281*CF*NM*NC*Zeta[3])/675 - 
       (641626808*CF*NC*NL*Zeta[3])/9 + (52492717279562889676289840747*CF*NC*
         NH*Zeta[3])/202627757650948813350 + 
       CA*CF*NC*(862438456831679255243317844506900381009184922727973749242040\
533751474343287/
          143655285102723088640261892047690622928662932492899200000000 + 
         (17982151*lm^2)/4 - (408538578568932345113634369619*Pi^2)/
          153966548736000 + (11291962795300961848996444522057*Pi^3)/
          (467046474760966224833280*Sqrt[3]) + (3602927573*Pi^4)/7200 + 
         lm*(1805151054144213913/136470350016 - (39710*Pi^2)/3) - 
         (386978478948616918202039782133434568591*Im[PolyLog[2, (-1)^(1/3)]])/
          (2781705451352576786795774016000*Sqrt[3]) + 
         (514887213*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (11291962795300961848996444522057*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(12613137821476711318800*Sqrt[3]) + 
         (11291962795300961848996444522057*Pi*Log[3]^2)/
          (605430615430882143302400*Sqrt[3]) - 
         (43888831386702353852164260792236213*PolyGamma[2, 1])/
          33771292941824802225 + (34621581109881814099700481789746734968769*
           Zeta[3])/18389954943713045102810400) + 
       CF*Log[x]*((398134608826131276728184664032053061152946731*NM*NC)/
          2345893434933157454953608000 - (16537802871797*lm*NM*NC)/765765 - 
         3866310*lm^2*NM*NC - (1213252916142075058819*NC*NL)/
          9934238714400 - (16537802871797*lm*NC*NL)/765765 - 
         3866310*lm^2*NC*NL - 
         (937353912034256013678198243313400571857575978517*NC*NH)/
          542086032650721212634821300289741912000 - 
         (16537802871797*lm*NC*NH)/765765 - 3866310*lm^2*NC*NH + 
         (237140390624873204*NM*NC*Pi^2)/9 - (320683444*NC*NL*Pi^2)/27 + 
         (48805473022675983321925936*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*
          (322908775089605129150979732240148425723642834951877493482168087/
            10407329045516979654305055870495991721184000000 - 
           (28634578427869*lm)/85085 - 69593580*lm^2 + 
           (1647368347829839197699827*Pi^2)/367567200 + 
           (11291962795300961848996444522057*Im[PolyLog[2, (-1)^(1/3)]])/
            (18919706732215066978200*Sqrt[3]) - 46395720*Zeta[3]) + 
         CA*NC*
          (-4197814031859051987969650118211157158983070783258901498528388031/
            270590555183441471011931452632895784750784000000 + 
           (20305947260897*lm)/139230 + 21264705*lm^2 - 
           (1647368341302872003544419*Pi^2)/735134400 - 
           (11291962795300961848996444522057*Im[PolyLog[2, (-1)^(1/3)]])/
            (37839413464430133956400*Sqrt[3]) + 23197860*Zeta[3])), 
      (1181234738012829410793661107781148910200991815719611571285512473463922\
2227111549*CF^2*NC)/
        65937775862149897685880208449889995924256286014240732800000000 - 
       (361505701977171068857*CF^2*lm*NC)/22517607752640 - 
       17552561*CF^2*lm^2*NC - 
       (104756751140517694469443832838442423973330096059447912507163*CF*NM*
         NC)/10162660401423575775805514764864803264000000 - 
       (657936964716385952137*CF*lm*NM*NC)/405316939547520 - 
       (17552561*CF*lm^2*NM*NC)/18 + (936023298223295243695969913*CF*NC*NL)/
        12171667694612025600 - (657936964716385952137*CF*lm*NC*NL)/
        405316939547520 - (17552561*CF*lm^2*NC*NL)/18 + 
       (161404242099199649987498875939542286776343469432254529212939603217*CF*
         NC*NH)/77496357597872595270470950754997938443034948597568000000 - 
       (657936964716385952137*CF*lm*NC*NH)/405316939547520 - 
       (17552561*CF*lm^2*NC*NH)/18 - (542754534788296484541172190432935717*
         CF^2*NC*Pi^2)/7084940103290649600 + (451250*CF^2*lm*NC*Pi^2)/9 + 
       (70117416044982426287395*CF*NM*NC*Pi^2)/33081048 + 
       (225625*CF*lm*NM*NC*Pi^2)/81 - (112856426114155*CF*NC*NL*Pi^2)/
        33081048 + (225625*CF*lm*NC*NL*Pi^2)/81 + (225625*CF*lm*NC*NH*Pi^2)/
        81 - (379240249721587025943809650017439*CF^2*NC*Pi^3)/
        (6305127409273044035249280*Sqrt[3]) - 
       (4770275756742875921391355415*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) - (39668588417*CF^2*NC*Pi^4)/32400 + 
       (1844055648400875639105896241308548344671*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5364717656179969517391849888000*
         Sqrt[3]) + (62964480662977367648884194803503*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40566077081719952432670*Sqrt[3]) - 
       (1886155859*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (54177178531655289420544235716777*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(24325337227133657543400*
         Sqrt[3]) - (545174372199185819587583476*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (54177178531655289420544235716777*CF^2*NC*Pi*Log[3]^2)/
        (1167616186902415562083200*Sqrt[3]) - 
       (136293593049796454896895869*CF*NC*NH*Pi*Log[3]^2)/
        (600378541187996484*Sqrt[3]) + 
       CF*((-18297612317486289063310712169179236115417*CF*NC)/
          19904253602682168720000 - 1434008888*CF*lm*NC + 
         CA*(18297612305670223067765366320245012513677/
            39808507205364337440000 + (3943524442*lm)/9)*NC + 
         (24791884421262422603170798101877*NM*NC)/974723982031800 - 
         (717004444*lm*NM*NC)/9 - (484597546*NC*NL)/5 - 
         (717004444*lm*NC*NL)/9 - (23588906472255942379349*NC*NH)/
          974723982031800 - (717004444*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-9003429356306622887720927*CA + 
          24*(750285801109884138442171*CF - 850850*(32055854814093860*NM + 
              179251111*NL)))*Log[x]^3)/68918850 - 
       (9163768328360368257878840045444794288*CF^2*NC*PolyGamma[2, 1])/
        182364981885853932015 + (31428035011496631247*CF*NM*NC*
         PolyGamma[2, 1])/3240 - (876019497811025371851174316109*CF*NC*NH*
         PolyGamma[2, 1])/7294599275434157280600 + 
       CA*CF*NC*(-82230054921576803213577789906750542986709316270997611977454\
74325272173326701/
          91803377462095228243480972432843711694056785261734400000000 + 
         (193078171*lm^2)/36 + (6210006119241968126467897913699653*Pi^2)/
          162126775819008000 + (379240249721587025943809650017439*Pi^3)/
          (12610254818546088070498560*Sqrt[3]) + (13270996139*Pi^4)/21600 + 
         lm*(1160971834819296057097/73693989008640 - (2481875*Pi^2)/162) - 
         (1844055648400875639105896241308548344671*
           Im[PolyLog[2, (-1)^(1/3)]])/(10729435312359939034783699776000*
           Sqrt[3]) + (1886155859*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (54177178531655289420544235716777*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(48650674454267315086800*Sqrt[3]) + 
         (54177178531655289420544235716777*Pi*Log[3]^2)/
          (2335232373804831124166400*Sqrt[3]) + 
         (4581884164180184128939420022722397144*PolyGamma[2, 1])/
          182364981885853932015 - 
         (7482419583437141109005807228785988345924129*Zeta[3])/
          496528783480252217775880800) + 
       (7482419618574316299141113478442919087938637*CF^2*NC*Zeta[3])/
        248264391740126108887940400 + (23734630662056208967*CF*NM*NC*
         Zeta[3])/1620 - (2407092292*CF*NC*NL*Zeta[3])/27 + 
       (1161481253036949242120890935091*CF*NC*NH*Zeta[3])/
        3647299637717078640300 + CF*Log[x]*
        ((-43749483187036879529735153614363456471159937*NM*NC)/
          17594200761998680912152060000 - (727813175333861*lm*NM*NC)/
          27567540 - 4725490*lm^2*NM*NC - (4543943086352811948791*NC*NL)/
          29802716143200 - (727813175333861*lm*NC*NL)/27567540 - 
         4725490*lm^2*NC*NL - 
         (71984814162977967700616714574559400385964780573423*NC*NH)/
          33541573270263375031779567955427780805000 - 
         (727813175333861*lm*NC*NH)/27567540 - 4725490*lm^2*NC*NH + 
         (21370569787513523*NM*NC*Pi^2)/9 - (401031632*NC*NL*Pi^2)/27 + 
         (545174372199185819587583476*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*
          (
           -15784526334138010937576648994466704741868525599146233375581761719\
43/3652972494976459858661074610544093094135584000000 - (630110574387911*lm)/
            1531530 - 85058820*lm^2 - (72027435036783588680753179*Pi^2)/
            1102701600 + (54177178531655289420544235716777*
             Im[PolyLog[2, (-1)^(1/3)]])/(72976011681400972630200*Sqrt[3]) - 
           56705880*Zeta[3]) + CA*NC*(157845263489602031577710851052006880739\
7331295713202695018783507143/
            7305944989952919717322149221088186188271168000000 + 
           (893611528454261*lm)/5012280 + 25990195*lm^2 + 
           (72027435061295586752418283*Pi^2)/2205403200 - 
           (54177178531655289420544235716777*Im[PolyLog[2, (-1)^(1/3)]])/
            (145952023362801945260400*Sqrt[3]) + 28352940*Zeta[3])), 
      (-202464036675546468001972249624671553182476927391153153625369140943947\
346232483*CF^2*NC)/
        1569947044336902325854290677378333236291816333672398400000000 - 
       (2971189068573484157*CF^2*lm*NC)/153181005120 - 
       21093933*CF^2*lm^2*NC - 
       (61043572065406728974439203654129716574728162565076748137161*CF*NM*
         NC)/80656034931933141077821545752895264000000 - 
       (5394581462728936877*CF*lm*NM*NC)/2757258092160 - 
       (7031311*CF*lm^2*NM*NC)/6 + (11653803780450721889803353409*CF*NC*NL)/
        118239057604802534400 - (5394581462728936877*CF*lm*NC*NL)/
        2757258092160 - (7031311*CF*lm^2*NC*NL)/6 + 
       (223550714798225812651990743200004305828393507180828419043281983058297\
1*CF*NC*NH)/841162071729651550336106800412766551990367696709845408000000 - 
       (5394581462728936877*CF*lm*NC*NH)/2757258092160 - 
       (7031311*CF*lm^2*NC*NH)/6 + (36075553961539240028184812620403*CF^2*NC*
         Pi^2)/642624952679424 + (176890*CF^2*lm*NC*Pi^2)/3 + 
       (620794094162877555220583*CF*NM*NC*Pi^2)/1969110 + 
       (88445*CF*lm*NM*NC*Pi^2)/27 - (6639164045153*CF*NC*NL*Pi^2)/
        1575288 + (88445*CF*lm*NC*NL*Pi^2)/27 + (88445*CF*lm*NC*NH*Pi^2)/
        27 - (159311600034144802741294196063413*CF^2*NC*Pi^3)/
        (2101709136424348011749760*Sqrt[3]) - 
       (9136428153460690210601086565*CF*NC*NH*Pi^3)/(24315330918113857602*
         Sqrt[3]) - (16386081859*CF^2*NC*Pi^4)/10800 + 
       (784343868759675084081523390967420496797*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1788239218726656505797283296000*
         Sqrt[3]) + (291542586781735763380665259722098*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(147776423654836969576155*Sqrt[3]) - 
       (773371193*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (22758800004877828963042028009059*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(8108445742377885847800*
         Sqrt[3]) - (2088326435076729190994534072*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) - (22758800004877828963042028009059*CF^2*NC*Pi*Log[3]^2)/
        (389205395634138520694400*Sqrt[3]) - (261040804384591148874316759*CF*
         NC*NH*Pi*Log[3]^2)/(900567811781994726*Sqrt[3]) + 
       CF*((638503480442887110242561753657400874403*CF*NC)/
          947821600127722320000 - 1826579440*CF*lm*NC + 
         CA*(-91214783023651255708453742499477724649/270806171465063520000 + 
           (5023093460*lm)/9)*NC + (29266443624244633181290854933889*NM*NC)/
          7735904619300 - (913289720*lm*NM*NC)/9 - (1111003264*NC*NL)/9 - 
         (913289720*lm*NC*NL)/9 - (332142145474258725167*NC*NH)/
          10601054478300 - (913289720*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-312508190167478164696933*CA + 
          28*(22322012439345897051067*CF + 1215500*(104482850088527463*NM + 
              6523498*NL)))*Log[x]^3)/3281850 + 
       (3488718905985026634398052348373390267*CF^2*NC*PolyGamma[2, 1])/
        121576654590569288010 + (417001150436569058473*CF*NM*NC*
         PolyGamma[2, 1])/1800 - (3311381504590593290076333343747*CF*NC*NH*
         PolyGamma[2, 1])/21883797826302471841800 - 
       (40659381960534445441557213333753272471573*CF^2*NC*Zeta[3])/
        1074737626580632506008400 - (70585482736584710327*CF*NM*NC*Zeta[3])/
        900 - (1018716160*CF*NC*NL*Zeta[3])/9 + 
       (4558406278629862521103791399053*CF*NC*NH*Zeta[3])/
        10941898913151235920900 + CA*CF*NC*(476385967986183659452850267360844\
48122428294808324236602613724770001502057121/
          738798609099718741578489730530980346490266509963481600000000 + 
         (77344421*lm^2)/12 - (553791398474768290625334691573289*Pi^2)/
          19729713459456000 + (159311600034144802741294196063413*Pi^3)/
          (4203418272848696023499520*Sqrt[3]) + (5480895553*Pi^4)/7200 + 
         lm*(9507004919477583917/501319653120 - (972895*Pi^2)/54) - 
         (784343868759675084081523390967420496797*Im[PolyLog[2, (-1)^(1/3)]])/
          (3576478437453313011594566592000*Sqrt[3]) + 
         (773371193*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (22758800004877828963042028009059*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(16216891484755771695600*Sqrt[3]) + 
         (22758800004877828963042028009059*Pi*Log[3]^2)/
          (778410791268277041388800*Sqrt[3]) - 
         (3488718905985026634398052348373390267*PolyGamma[2, 1])/
          243153309181138576020 + (40659382152584443273631003817562980597401*
           Zeta[3])/2149475253161265012016800) + 
       CF*Log[x]*((963785922334263204660939970280485118431009519*NM*NC)/
          558546055936466060703240000 - (8588797578143*lm*NM*NC)/262548 - 
         5837370*lm^2*NM*NC - (373366980725909125547*NC*NL)/1930080664512 - 
         (8588797578143*lm*NC*NL)/262548 - 5837370*lm^2*NC*NL - 
         (215675794514148784555327687295639811190710047922911291*NC*NH)/
          78717280811983817860296391767395369009220000 - 
         (8588797578143*lm*NC*NH)/262548 - 5837370*lm^2*NC*NH + 
         (2437933168628871508*NM*NC*Pi^2)/9 - (509181190*NC*NL*Pi^2)/27 + 
         (2088326435076729190994534072*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CF*NC*
          (56194516267031948131253923729203482697727255989567194061556959037/
            173951071189355231364813076692575861625504000000 - 
           (7439355214073*lm)/14586 - 105072660*lm^2 + 
           (227278682729556243492691*Pi^2)/4773600 + 
           (22758800004877828963042028009059*Im[PolyLog[2, (-1)^(1/3)]])/
            (24325337227133657543400*Sqrt[3]) - 70048440*Zeta[3]) + 
         CA*NC*
          (-56194516178608332713865185270750566915546310515763395791561988837/
            347902142378710462729626153385151723251008000000 + 
           (10539366438383*lm)/47736 + 32105535*lm^2 - 
           (75759560865044499196129*Pi^2)/3182400 - 
           (22758800004877828963042028009059*Im[PolyLog[2, (-1)^(1/3)]])/
            (48650674454267315086800*Sqrt[3]) + 35024220*Zeta[3])), 
      (3024181538839573872527508974409786428931846242853868259471068426069710\
358944243817*CF^2*NC)/
        1610765667489661786326502234990169900435403558347880758400000000 - 
       (1262583583722840776531*CF^2*lm*NC)/55298342848320 - 
       24952641*CF^2*lm^2*NC - 
       (1162430483135273305523172245785534616472055235973851105953*CF*NM*NC)/
        17372069062262522693684640623700518400000 - 
       (2297463356464625586371*CF*lm*NM*NC)/995370171269760 - 
       (8317547*CF*lm^2*NM*NC)/6 + (282460888837952688704643281797*CF*NC*
         NL)/2298385373594892341760 - (2297463356464625586371*CF*lm*NC*NL)/
        995370171269760 - (8317547*CF*lm^2*NC*NL)/6 + 
       (182982714663492860783409418235039000485994413057473401069701921695033\
7*CF*NC*NH)/560774714486434366890737866941844367993578464473230272000000 - 
       (2297463356464625586371*CF*lm*NC*NH)/995370171269760 - 
       (8317547*CF*lm^2*NC*NH)/6 - (5094633048256196997124943536104326987*
         CF^2*NC*Pi^2)/6410183902977254400 + (203350*CF^2*lm*NC*Pi^2)/3 + 
       (7988821338278143720461161*CF*NM*NC*Pi^2)/1047566520 + 
       (101675*CF*lm*NM*NC*Pi^2)/27 - (152651773123973*CF*NC*NL*Pi^2)/
        29930472 + (101675*CF*lm*NC*NL*Pi^2)/27 + (101675*CF*lm*NC*NH*Pi^2)/
        27 - (9144257898716638078405917863657239*CF^2*NC*Pi^3)/
        (98016071544153684547966080*Sqrt[3]) - 
       (7486628569133892643352023885*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) - (19921755539*CF^2*NC*Pi^4)/10800 + 
       (121552952189417480406876614273736186134387*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(226363216427645726779300263456000*
         Sqrt[3]) + (240250006347120417942482757768847*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(98517615769891313050770*Sqrt[3]) - 
       (935379753*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (1306322556959519725486559694808177*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(378148424167259585447400*
         Sqrt[3]) - (855614693615302016383088444*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (1306322556959519725486559694808177*CF^2*NC*Pi*Log[3]^2)/
        (18151124360028460101475200*Sqrt[3]) - 
       (213903673403825504095772111*CF*NC*NH*Pi*Log[3]^2)/
        (600378541187996484*Sqrt[3]) + 
       CF*((-171752816729886229728174837763168660588343*CF*NC)/
          18008610402426724080000 - 2265823720*CF*lm*NC + 
         CA*(171752816712984586078940099580967130317283/
            36017220804853448160000 + (6231015230*lm)/9)*NC + 
         (1982218300366749914193896722283*NM*NC)/21660532934040 - 
         (1132911860*lm*NM*NC)/9 - (6876431246*NC*NL)/45 - 
         (1132911860*lm*NC*NL)/9 - (278776672433675948149*NC*NH)/
          7067369652200 - (1132911860*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(84753563242137343136830493*CA - 
          304*(557589234394209951684119*CF - 1154725*(8330849708806986*NM + 
              14906735*NL)))*Log[x]^3)/62355150 - 
       (1705827699291467851507405521442832749993*CF^2*NC*PolyGamma[2, 1])/
        3282569673945370776270 + (435546014241260862199*CF*NM*NC*
         PolyGamma[2, 1])/5400 - (815668406034335806044637201493*CF*NC*NH*
         PolyGamma[2, 1])/4376759565260494368360 + 
       CA*CF*NC*(-60483630783941377908159595039597968358838688288713202872727\
82249095198387745748009/
          6443062669958647145306008939960679601741614233391523033600000000 + 
         (91493017*lm^2)/12 + (25473165241508529096155837854940629159*Pi^2)/
          64101839029772544000 + (9144257898716638078405917863657239*Pi^3)/
          (196032143088307369095932160*Sqrt[3]) + (19986827539*Pi^4)/21600 + 
         lm*(4053622970814321021251/180976394776320 - (1118425*Pi^2)/54) - 
         (121552952189417480406876614273736186134387*
           Im[PolyLog[2, (-1)^(1/3)]])/(452726432855291453558600526912000*
           Sqrt[3]) + (935379753*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (1306322556959519725486559694808177*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(756296848334519170894800*
           Sqrt[3]) + (1306322556959519725486559694808177*Pi*Log[3]^2)/
          (36302248720056920202950400*Sqrt[3]) + 
         (1705827699291467851507405521442832749993*PolyGamma[2, 1])/
          6565139347890741552540 - 
         (1940005706036588246158504046577085969019808757*Zeta[3])/
          12129488853589018462810802400) + 
       (1940005707375767985035702668850536995024927601*CF^2*NC*Zeta[3])/
        6064744426794509231405401200 + (372231558577115274799*CF*NM*NC*
         Zeta[3])/2700 - (1260511780*CF*NC*NL*Zeta[3])/9 + 
       (1111000097857141086810097263307*CF*NC*NH*Zeta[3])/
        2188379782630247184180 + CF*Log[x]*
        ((-4387926805222358706825935870250157768367207*NM*NC)/
          48872779894440780311533500 - (987910830257251*lm*NM*NC)/24942060 - 
         7066290*lm^2*NM*NC - (14748238296874628709577*NC*NL)/
          61706905860600 - (987910830257251*lm*NC*NL)/24942060 - 
         7066290*lm^2*NC*NL - 
         (44181931708300274479276179757901383925370897467629663*NC*NH)/
          13119546801997302976716065294565894834870000 - 
         (987910830257251*lm*NC*NH)/24942060 - 7066290*lm^2*NC*NH + 
         (105524096182643557*NM*NC*Pi^2)/9 - (630052540*NC*NL*Pi^2)/27 + 
         (855614693615302016383088444*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*(-395586236129507318767758887252528429399870350640373266688835\
787088019/89236899520139233690149108343291417013883552000000 - 
           (855724958389201*lm)/1385670 - 127193220*lm^2 - 
           (25112166896454451967778143*Pi^2)/36951200 + 
           (1306322556959519725486559694808177*Im[PolyLog[2, (-1)^(1/3)]])/
            (1134445272501778756342200*Sqrt[3]) - 84795480*Zeta[3]) + 
         CA*NC*(3955862361851509251769889686054322143172431079821742927523850\
58751619/178473799040278467380298216686582834027767104000000 + 
           (1212226249184851*lm)/4534920 + 38864595*lm^2 + 
           (678028506239066879260607957*Pi^2)/1995364800 - 
           (1306322556959519725486559694808177*Im[PolyLog[2, (-1)^(1/3)]])/
            (2268890545003557512684400*Sqrt[3]) + 42397740*Zeta[3]))}, 0, 39, 
     1]
 
CbarSeries["s", 2, 3, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-1347334788170*NM + 78976450560*lm*NM + 
         86704128000*lm^2*NM + 400301654016*NL + 78976450560*lm*NL + 
         86704128000*lm^2*NL - 1347334788170*NH + 78976450560*lm*NH + 
         86704128000*lm^2*NH + 420*CF*(3231875895374 + 597786624*lm + 
           3715891200*lm^2 - 2685567744405*Zeta[3]) + 1132665447375*NM*
          Zeta[3] + 1132665447375*NH*Zeta[3] - 
         6*CA*(-22228514268502 + 173549895680*lm + 79478784000*lm^2 + 
           18659802456225*Zeta[3])))/655483207680000, 
      -(CF*NC*(-313652016160*NM + 68389601280*lm*NM + 43352064000*lm^2*
           NM + 213313568768*NL + 68389601280*lm*NL + 
          43352064000*lm^2*NL - 1007357288490*NH + 68389601280*lm*NH + 
          43352064000*lm^2*NH + 210*CF*(3232075157582 + 3075047424*lm + 
            3715891200*lm^2 - 2685567744405*Zeta[3]) + 308706174000*NM*
           Zeta[3] + 823959273375*NH*Zeta[3] - CA*(-66511992909826 + 
            679607255040*lm + 238436352000*lm^2 + 55979407368675*Zeta[3])))/
       109247201280000, 
      (CF*NC*(36*CF*(588948951809799674 + 115512730583040*lm + 
           88958435328000*lm^2 - 489859697707961175*Zeta[3]) - 
         14*CA*(-94810326952098458 + 232140373032960*lm + 
           69895913472000*lm^2 + 79107171139938375*Zeta[3]) + 
         7*(262144*(524809871 + 198616635*lm + 96957000*lm^2)*NL + 
           315*NM*(-134092975934 + 165289394176*lm + 80687923200*lm^2 + 
             299307548925*Zeta[3]) + 315*NH*(-2750352860150 + 
             165289394176*lm + 80687923200*lm^2 + 2242547809425*Zeta[3]))))/
       259571350241280000, 
      -(CF*NC*(72*CF*(536679953387362094 + 45890616360960*lm + 
            28872474624000*lm^2 - 446434067280932325*Zeta[3]) - 
          140*CA*(-16332349703526454 + 16388704862208*lm + 
            4537103155200*lm^2 + 13604649696188145*Zeta[3]) + 
          7*(65536*(1500221917 + 588945420*lm + 251748000*lm^2)*NL + 
            45*NM*(447700266290 + 857713934336*lm + 366634598400*lm^2 + 
              975483587925*Zeta[3]) + 315*NH*(-2561540554582 + 
              122530562048*lm + 52376371200*lm^2 + 2096511365025*Zeta[3]))))/
       129785675120640000, 
      (CF*NC*(22*CF*(410846929332353968455454 + 10915761575087308800*lm + 
           6415120513105920000*lm^2 - 341778706678950797458125*Zeta[3]) - 
         121*CA*(-3641194628543956223462 + 1327322266376601600*lm + 
           356395584061440000*lm^2 + 3030653618702003093625*Zeta[3]) + 
         5*(262144*(38583008657411 + 14665232472660*lm + 5981981544000*lm^2)*
            NL + 3465*NM*(411970232852882 + 1109495729094656*lm + 
             452565821030400*lm^2 + 1939330622153925*Zeta[3]) + 
           3465*NH*(-31347438704519806 + 1109495729094656*lm + 
             452565821030400*lm^2 + 25783020643304925*Zeta[3]))))/
       8166114678590668800000, 
      -(CF*NC*(-6164631484825964766*NM + 3502997277345054720*lm*NM + 
          1477496606294016000*lm^2*NM + 10007906320315580416*NL + 
          3502997277345054720*lm*NL + 1477496606294016000*lm^2*NL - 
          144130109538182161086*NH + 3502997277345054720*lm*NH + 
          1477496606294016000*lm^2*NH + 110*CF*(49661338117227374407526 + 
            391888607338561536*lm + 241772171939020800*lm^2 - 
            41313362744495311029945*Zeta[3]) + 14466197882473462125*NM*
           Zeta[3] + 119053915773083416125*NH*Zeta[3] - 
          121*CA*(-1915055951863170494534 + 244702159251701760*lm + 
            67158936649728000*lm^2 + 1593440446052759394825*Zeta[3])))/
       1633222935718133760000, 
      (CF*NC*(624*CF*(3835440265299630418681078154 + 7658481878407367884800*
            lm + 5840009285295144960000*lm^2 - 3190726446229348625315091375*
            Zeta[3]) - 88*CA*(-1006754906029507941635778094 + 
           42187660520967792230400*lm + 12653353451472814080000*lm^2 + 
           837577220026062820916737125*Zeta[3]) + 
         5*(16777216*(16386392863985929 + 4975012300838580*lm + 
             2413435640616000*lm^2)*NL + 9009*NH*(-619396257996388132546 + 
             9264830277924945920*lm + 4494475640438784000*lm^2 + 
             513299080524314959875*Zeta[3]) + 9009*NM*
            (9264830277924945920*lm + 4494475640438784000*lm^2 + 
             143*(-570384264288243742 + 706609561318786125*Zeta[3])))))/
       264974089090910021222400000, 
      -(CF*NC*(832*CF*(4708585472099362143731378662 + 1559103335309928038400*
             lm + 2237727528808611840000*lm^2 - 3917106620446279341558101625*
             Zeta[3]) - 1056*CA*(-120906201939645633470823698 + 
            1465007516257930444800*lm + 538712182861332480000*lm^2 + 
            100584347140877481745738875*Zeta[3]) + 
          15*(67108864*(645221459501833 + 148653760715460*lm + 
              102751194546000*lm^2)*NL + 429*NM*(-834291351584956445578 + 
              23254044314550927360*lm + 16073463731060736000*lm^2 + 
              823527633956383731375*Zeta[3]) + 1287*NH*
             (7751348104850309120*lm + 5357821243686912000*lm^2 + 
              4719*(-224173559524898174 + 186201117310060125*Zeta[3])))))/
       176649392727273347481600000, 
      (CF*NC*(2*CF*(16948545451631908137961403228172262 - 
           958659186795818305506508800*lm + 2464691387198991488778240000*
            lm^2 - 14099622106342253154970863323381625*Zeta[3]) - 
         165*CA*(-5939409423912912998513146071698 + 
           14913849262768875173314560*lm + 9128486619255524032512000*lm^2 + 
           4941045246691760123103141030075*Zeta[3]) + 
         105*(536870912*(23463452284399319 + 1753960008981180*lm + 
             4858037520336000*lm^2)*NL + 429*NM*
            (-829600921429348027259222 + 2194988600543716311040*lm + 
             6079578168002347008000*lm^2 + 738811762476411437438625*
              Zeta[3]) + 143*NH*(-5319208666234527922626626 + 
             6584965801631148933120*lm + 18238734504007041024000*lm^2 + 
             4424891625043169645239875*Zeta[3]))))/
       672680887505456907209932800000, 
      (CF*NC*(11*CA*(-72626987077669081568412268054442 - 
           12248290694440651692441600*lm + 36376951202978967060480000*lm^2 + 
           60418788384089044184302205553375*Zeta[3]) - 
         2*(3*CF*(5156828774384354276313705796641766 - 
             514973651948252283115929600*lm + 218261707217873802362880000*
              lm^2 - 4290004446646807127675848993205625*Zeta[3]) + 
           35*(429*NM*(-901856131594587469333958 - 3899182723219524157440*
                lm + 2422707372825772032000*lm^2 + 765974244926707959767625*
                Zeta[3]) + 16*(16777216*(5700908876701427 - 6231477067847460*
                  lm + 3871848668688000*lm^2)*NL + 1287*NH*
                (-23090261353016334488726 - 81232973400406753280*lm + 
                 50473070267203584000*lm^2 + 19225829545899089738625*
                  Zeta[3]))))))/288291808930910103089971200000, 
      (CF*NC*(68*CF*(141033000571418096334382938253647995306 - 
           10142651758730370866899373260800*lm + 
           1543268389766515272135475200000*lm^2 - 
           117326401995350688763876956299791569375*Zeta[3]) - 
         110*CA*(-2022598255147751126491812904901452538 - 
           1326196576215550454974686167040*lm + 
           291506251400341773625589760000*lm^2 + 
           1682610220272514129747991399397813975*Zeta[3]) + 
         105*(6442450944*(-59404797098541997819 - 50179203012611012340*lm + 
             8618614367322960000*lm^2)*NL + 17017*NM*
            (-3815033044231997740359241106 - 18997299983414436172922880*lm + 
             3262913572705633566720000*lm^2 + 3177508213012714830208834875*
              Zeta[3]) + 17017*NH*(-18997299983414436172922880*lm + 
             3262913572705633566720000*lm^2 + 
             2431*(-1094759083115992163108006 + 911984784721587721769625*
                Zeta[3])))))/44324289039509566529876892057600000, 
      -(CF*NC*(-44*CA*(-548980422915337990544329993255635778 - 
            305528523308070310589025484800*lm + 15732007852353519951544320000*
             lm^2 + 456700014504985182297020587473415875*Zeta[3]) + 
          5*(136*CF*(1694918661307171157652681672645064066 - 
              71438841454401610948898979840*lm + 3331484015792510107385856000*
               lm^2 - 1410015383139382658314149215955888675*Zeta[3]) + 
            21*(1610612736*(-29269514727227414483 - 15400282861529846280*lm + 
                744206936224752000*lm^2)*NL + 19448*NM*(
                -337215634562204672946591442 - 1275395501582810307624960*lm + 
                61632515924677361664000*lm^2 + 279153104293856709344302875*
                 Zeta[3]) + 2431*NH*(-10203164012662482460999680*lm + 
                493060127397418893312000*lm^2 + 2431*
                 (-428523467954588582728066 + 357045483467413341475875*
                   Zeta[3]))))))/2770268064969347908117305753600000, 
      -(CF*NC*(-2*CA*(934937853340468254774605212187591529274382 + 
            345277979327644492145082625739980800*lm + 
            3685678869305576539337030369280000*lm^2 - 
            777780755248305213202149765964012788451125*Zeta[3]) + 
          5*(76*CF*(-258619007526101271225170909720305065171278 + 
              5818958287926639933947096932024320*lm + 
              63485377653110409290015834112000*lm^2 + 
              215147062465340491867373049660044850933525*Zeta[3]) + 
            7*(103079215104*(80876763780278915778073 + 
                34328622198418188721080*lm + 371488737420728928000*lm^2)*
               NL + 29393*NM*(49684573064289884370896354037758 + 
                120388100289684545426675466240*lm + 
                1302785271095318317891584000*lm^2 - 
                41108869816072631438139561412125*Zeta[3]) + 
              4199*NH*(842716702027791817986728263680*lm + 
                9119496897667228225241088000*lm^2 - 79781*
                 (-908213677541728408981076746 + 756704154064745959941243375*
                   Zeta[3]))))))/128008546746103628138284464262348800000, 
      (CF*NC*(-6*CA*(168598419033242136599303052782786972590414 + 
           37176862332586917254537877336883200*lm + 
           1674819792543671906642574704640000*lm^2 - 
           140258165388676581210351204843379019791125*Zeta[3]) + 
         228*CF*(-255706590757654668975638378552695134777542 + 
           2910071080877976954235819288166400*lm + 
           144242852946344948897446625280000*lm^2 + 
           212724199265199823182381917537861615399625*Zeta[3]) + 
         35*(34359738368*(86923651758146499818173 + 31790702288419860665880*
              lm + 1519283260917598176000*lm^2)*NL + 
           29393*NM*(26454657203953428293828086769666 + 
             37162596984489003797320826880*lm + 1776007054469110092005376000*
              lm^2 - 21915703848685651038601431739875*Zeta[3]) + 
           4199*NH*(260138178891423026581245788160*lm + 
             12432049381283770644037632000*lm^2 - 
             4199*(-4853607936704163350573341618 + 
               4043272180948147725671968875*Zeta[3])))))/
       42669515582034542712761488087449600000, 
      -(CF*NC*(-4*CA*(1211722627683362382389203646624581328872166698 + 
            150368490526033868275075514421687091200*lm + 
            10393420852814016138880219757936640000*lm^2 - 
            1008040560881407695721696741189095807819417375*Zeta[3]) + 
          7*(104*CF*(-419056533484911693035786937921700064443570274 + 
              2325891932849213736703607650752921600*lm + 
              186894680669982308191652303339520000*lm^2 + 
              348616220197995267806522077894838868459253875*Zeta[3]) + 
            165*(1924145348608*(139041929711237294435329 + 
                44879000066678237957640*lm + 3401229643737333408000*lm^2)*
               NL + 4199*NM*(27015292197956165664572470511119786 + 
                20565305841504418532881732730880*lm + 
                1558575898677026681190875136000*lm^2 - 
                22411606311002371350247057500177375*Zeta[3]) + 
              4199*NH*(20565305841504418532881732730880*lm + 
                1558575898677026681190875136000*lm^2 - 4199*
                 (-368472794486189748215541271334 + 
                  306880152976615344742632641625*Zeta[3]))))))/
       129544649307056871675943877833496985600000, 
      (CF*NC*(385*(1099511627776*(664646497445076548635196 + 
             190877097879976670617455*lm + 19226790298370488333500*lm^2)*
            NL + 20995*NM*(9996265234349703633603378806784*lm + 
             1006910192801578487634513100800*lm^2 + 
             65*(391681903739834719995326809645226 - 
               325287079949638243784311345315935*Zeta[3])) + 
           20995*NH*(752080615408155646490648683691038 + 
             9996265234349703633603378806784*lm + 
             1006910192801578487634513100800*lm^2 - 
             626189097982848282136520938997325*Zeta[3])) - 
         240*CA*(31088258900878004021242240661145169954956022 + 
           2089065012904308758656632771638722560*lm + 
           186517159736407936194374503759872000*lm^2 - 
           25862545621919963196884324938620617714084625*Zeta[3]) + 
         32*CF*(-15967777165534350295876968637923263676087481238 + 
           42016704555448977987789210747351859200*lm + 
           4578148466257285706589192365015040000*lm^2 + 
           13283711545077397734252557545649903433338714625*Zeta[3])))/
       129544649307056871675943877833496985600000, 
      -(CF*NC*(-34*CA*(3728259313763754100508318405285695956291190446182 + 
            131903660093637510821757829264218626457600*lm + 
            14352723293228369526388151916265734144000*lm^2 - 
            3101566003424456325570555508080363135877770605625*Zeta[3]) + 
          5*(3927*(1099511627776*(127408434706402070759994241 + 
                32538952278457833459331080*lm + 4109791669800581311747200*
                 lm^2)*NL + 2185*NM*(
                84035895659791519943967623585718953926 + 
                16373893082751833631966788497440768*lm + 
                2068084086353630324663711296389120*lm^2 - 
                69840757737283683370679685453975172425*Zeta[3]) + 
              111435*NH*(25027343050259230520879805313295266 + 
                321056727112781051607191931322368*lm + 
                40550668359875104405170809733120*lm^2 - 
                20831926195055312638547558837800275*Zeta[3])) + 
            460*CF*(-4092592878348590242814242321399949591423365676102 + 
              4976891172594157491996020423736466341888*lm + 
              694376810707965387363600709308666347520*lm^2 + 
              3404658186487996889232787329122400246767187250185*Zeta[3]))))/
       1461954548979905815820251975976957981491200000, 
      (CF*NC*(-(CA*(25505032461610435824133156797406600254291342666578 + 
            464359515988482910338844081933923228057600*lm + 
            60390654264601563310354436579659874304000*lm^2 - 
            21217823037635720110908599153908772376427838950875*Zeta[3])) + 
         5*(46*CF*(-8900584683802622433321625507328113588567873016602 + 
             4869330013133071515723620292688682680320*lm + 
             859313657520022244732316093623618764800*lm^2 + 
             7404462014639317717064878400480756118591407936775*Zeta[3]) + 
           21*(549755813888*(5413174518882367078452877361 + 
               1220529868032884946416759880*lm + 190216381264955205867907200*
                lm^2)*NL + 520030*NM*
              (13785500415807238387924976690340366562 + 
               1290297465482821947322287362408448*lm + 
               201089478486136500151479561093120*lm^2 - 
               11461874276711712005553316196432826675*Zeta[3]) + 
             37145*NH*(18064164516759507262512023073718272*lm + 
               2815252698805911002120713855303680*lm^2 - 7429*
                (-203348127840245523052918694296546 + 
                 169213105690636584176642772004275*Zeta[3]))))))/
       199357438497259883975488905815039724748800000}, 0, 18, 1]
 
CbarSeries["s", 2, 4, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(CF*(-1157360400*lm^2 + 16218036*Pi^2 + 793800*Pi^4 + 
            7144200*lm*(-221 + 12*Pi^2) + 35*(-35804493 + 124743552*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] - 9797760*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 20790592*PolyGamma[2, 1] - 
              207349952*Zeta[3])) + 35*CA*(21043251 + 6735960*lm^2 - 
            2241432*Pi^2 + 61236*Pi^4 - 15120*lm*(-1645 + 33*Pi^2) - 
            62371776*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            4898880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 10395296*PolyGamma[2, 1] + 
            109713040*Zeta[3]) + 70*(9*NL*(-131005 - 68040*lm^2 - 
              4932*Pi^2 + 1680*lm*(-98 + 3*Pi^2) - 60480*Zeta[3]) + 
            9*NM*(-131005 - 68040*lm^2 - 4932*Pi^2 + 1680*lm*(-98 + 
                3*Pi^2) + 5040*PolyGamma[2, 1] - 50400*Zeta[3]) + 
            NH*(3319767 - 612360*lm^2 + 15120*lm*(-98 + 3*Pi^2) - 
              257432016*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              42905336*PolyGamma[2, 1] + 459939952*Zeta[3]))))/10287648000, 
      -(CF*NC*(2*(-280*(NL*(-34020*lm^2 - 1476*Pi^2 + 105*lm*(-217 + 
                  24*Pi^2) + 35*(4805 - 864*Zeta[3])) + NM*(-34020*lm^2 - 
                1476*Pi^2 + 105*lm*(-217 + 24*Pi^2) + 35*(4805 + 
                  72*PolyGamma[2, 1] - 720*Zeta[3])) + NH*(16189219 - 
                34020*lm^2 + 105*lm*(-217 + 24*Pi^2) + 13397568*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 2232928*PolyGamma[2, 1] - 
                37508096*Zeta[3])) + CF*(257191200*lm^2 + 3186909*Pi^2 + 
              1014300*Pi^4 - 793800*lm*(125 + 24*Pi^2) + 70*(2849936 + 
                2038602*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 2449440*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 321497*PolyGamma[2, 1] - 
                6323074*Zeta[3]))) - 35*CA*(-17097414 + 2993760*lm^2 - 
            1655433*Pi^2 + 61236*Pi^4 - 840*lm*(-6923 + 264*Pi^2) + 
            4077204*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            4898880*Im[PolyLog[2, (-1)^(1/3)]]^2 - 642994*PolyGamma[2, 1] - 
            7797380*Zeta[3])))/1143072000, 
      -(CF*NC*(CA*(2405879496 - 484989120*lm^2 - 1424061*Pi^2 + 
            5422788*Pi^4 + 22680*lm*(-39899 + 264*Pi^2) - 1671330492*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1308000960*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 256446454*PolyGamma[2, 1] + 
            3797078732*Zeta[3]) + 2*(CF*(1190427840*lm^2 + 77632101*Pi^2 - 
              6293700*Pi^4 - 612360*lm*(899 + 24*Pi^2) + 2*(510576777 + 
                835665246*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 654000480*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 128223227*PolyGamma[2, 1] - 
                2230030246*Zeta[3])) - 4*(NH*(3244859811 - 11022480*lm^2 + 
                5670*lm*(-1153 + 24*Pi^2) + 4827213792*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 825988300*PolyGamma[2, 1] - 
                11405102360*Zeta[3]) + 27*NL*(1650005 - 408240*lm^2 - 
                124272*Pi^2 + 210*lm*(-1153 + 24*Pi^2) - 60480*Zeta[3]) + 
              27*NM*(-408240*lm^2 - 199872*Pi^2 + 210*lm*(-1153 + 24*Pi^2) - 
                35*(-64405 + 72*PolyGamma[2, 1] + 1872*Zeta[3]))))))/
       881798400, -(CF*NC*(32648738035725*CF + 27990375487200*CF*lm + 
          27998862796800*CF*lm^2 - 3248486791200*NM + 2131286320800*lm*NM + 
          1036994918400*lm^2*NM + 718773199200*NL + 2131286320800*lm*NL + 
          1036994918400*lm^2*NL - 169478939095200*NH + 
          2131286320800*lm*NH + 1036994918400*lm^2*NH - 
          1084816726452*CF*Pi^2 - 462944160000*CF*lm*Pi^2 + 
          422773344000*NM*Pi^2 - 17146080000*lm*NM*Pi^2 + 
          463923936000*NL*Pi^2 - 17146080000*lm*NL*Pi^2 - 
          17146080000*lm*NH*Pi^2 + 111125140000*Sqrt[3]*CF*Pi^3 + 
          5185034960000*Sqrt[3]*NH*Pi^3 + 28402481520*CF*Pi^4 - 
          11634520099440*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          97860111014400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          23165725766400*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          4114805184000*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          191994437376000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          85725108000*Sqrt[3]*CF*Pi*Log[3]^2 + 3999884112000*Sqrt[3]*NH*Pi*
           Log[3]^2 + 61725888000*(-2*CA*(76 + 33*lm) + 9*CF*(61 + 36*lm) + 
            4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          246903552000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          2311015559720*CF*PolyGamma[2, 1] + 133053580800*NM*
           PolyGamma[2, 1] + 19381750366720*NH*PolyGamma[2, 1] + 
          3503558028880*CF*Zeta[3] + 101504793600*NM*Zeta[3] + 
          2057529600000*NL*Zeta[3] + 161282529981440*NH*Zeta[3] - 
          529200*Log[x]*(-4*(243*NM*(4859 + 4800*lm + 1080*lm^2 + 
                600*Pi^2) + 243*NL*(9179 + 4800*lm + 1080*lm^2 + 600*Pi^2) + 
              NH*(53023659 + 1166400*lm + 262440*lm^2 - 30233440*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + CF*(-97433481 - 96053040*lm - 
              28343520*lm^2 + 1102248*Pi^2 + 2591840*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 8398080*Zeta[3]) + 
            4*CA*(14923374 + 8252280*lm + 1443420*lm^2 + 2187*Pi^2 - 
              323980*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1049760*Zeta[3])) - 
          70*CA*(81478172160*lm^2 - 13023613431*Pi^2 + 793751000*Sqrt[3]*
             Pi^3 + 398830068*Pi^4 - 204120*lm*(-1328423 + 6600*Pi^2) + 
            612322200*Sqrt[3]*Pi*Log[3]^2 + 2*(51785280306 - 41551857498*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 82734734880*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 14695732800*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 8253626999*PolyGamma[2, 1] + 
              55661727358*Zeta[3]))))/555532992000, 
      -(CF*NC*(-35*CA*(76 + 33*lm) + 18*CF*(494 + 315*lm) + 
           10*(38*NM + 21*lm*NM + 35*NL + 21*lm*NL + 21*lm*NH))*
          Log[x]^2)/45 - (14*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + (CF*NC*Log[x]*(-4*(729*NL*(19945 + 10564*lm + 2520*lm^2 + 
              1400*Pi^2) + 243*NM*(26629 + 31692*lm + 7560*lm^2 + 
              5040*Pi^2) + NH*(290567235 + 7701156*lm + 1837080*lm^2 - 
              165690560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          CF*(-627831201 - 622297728*lm - 198404640*lm^2 + 12264696*Pi^2 + 
            42001184*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 58786560*Zeta[3]) - 
          4*CA*(-101875011 - 55215918*lm - 10103940*lm^2 + 652455*Pi^2 + 
            5250148*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 7348320*Zeta[3])))/
        2099520 - (CF*NC*(-140*CA*(126030814317 + 257892964560*lm^2 - 
            32807724273*Pi^2 + 6431431300*Sqrt[3]*Pi^3 + 653633064*Pi^4 - 
            204120*lm*(-4018123 + 13200*Pi^2) - 168399010236*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 608176356480*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 238146713280*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 4961389860*Sqrt[3]*Pi*
             Log[3]^2 + 40815749084*PolyGamma[2, 1] + 33936702328*Zeta[3]) + 
          CF*(177242801097600*lm^2 - 7686265218552*Pi^2 + 1800800764000*
             Sqrt[3]*Pi^3 + 73282345920*Pi^4 - 3086294400*lm*
             (-48931 + 600*Pi^2) + 1389189160800*Sqrt[3]*Pi*Log[3]^2 - 
            35*(-4691485754883 + 1347192081888*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 4865410851840*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              1905173706240*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              326525992672*PolyGamma[2, 1] + 2031584923072*Zeta[3])) - 
          1120*(486*NM*(46721780 - 12060090*lm^2 - 6768360*Pi^2 + 
              105*lm*(-219101 + 1200*Pi^2) - 2281617*PolyGamma[2, 1] + 
              3450366*Zeta[3]) - 2*NH*(-423603070650 + 2930601870*lm^2 + 
              12685683500*Sqrt[3]*Pi^3 - 25515*lm*(-219101 + 1200*Pi^2) - 
              306161347200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              469732737600*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              9786098700*Sqrt[3]*Pi*Log[3]^2 + 60012832399*PolyGamma[2, 1] + 
              524942591198*Zeta[3]) + 1215*NL*(-4824036*lm^2 + 
              42*lm*(-219101 + 1200*Pi^2) - 5*(384587 + 475092*Pi^2 + 
                2026080*Zeta[3])))))/1111065984000, 
      (-6246524409613*CF^2*NC)/10581580800 - (62337*CF^2*lm*NC)/80 - 
       (7209*CF^2*lm^2*NC)/10 + (270371*CF*NM*NC)/2160 - 
       (41071*CF*lm*NM*NC)/720 - (267*CF*lm^2*NM*NC)/10 - 
       (15037*CF*NC*NL)/720 - (41071*CF*lm*NC*NL)/720 - 
       (267*CF*lm^2*NC*NL)/10 + (3683096202509*CF*NC*NH)/826686000 - 
       (41071*CF*lm*NC*NH)/720 - (267*CF*lm^2*NC*NH)/10 + 
       (405023917*CF^2*NC*Pi^2)/7056000 + (15*CF^2*lm*NC*Pi^2)/2 - 
       (45443*CF*NM*NC*Pi^2)/3780 + (5*CF*lm*NM*NC*Pi^2)/18 - 
       (11827*CF*NC*NL*Pi^2)/756 + (5*CF*lm*NC*NL*Pi^2)/18 + 
       (5*CF*lm*NC*NH*Pi^2)/18 - (195142087*CF^2*NC*Pi^3)/
        (5668704*Sqrt[3]) - (191944445*CF*NC*NH*Pi^3)/(354294*Sqrt[3]) - 
       (39367*CF^2*NC*Pi^4)/21600 + (380613052609*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(330674400*Sqrt[3]) + 
       (12806421398*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2066715*Sqrt[3]) - 
       (7109*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (27877441*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (21870*Sqrt[3]) - (43873016*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (27877441*CF^2*NC*Pi*Log[3]^2)/(1049760*Sqrt[3]) - 
       (5484127*CF*NC*NH*Pi*Log[3]^2)/(13122*Sqrt[3]) - 
       (CF*NC*(-(CA*(26369 + 12540*lm)) + CF*(96834 + 61560*lm) + 
          4*(1255*NM + 570*lm*NM + 875*NL + 570*lm*NL + 8*NH + 
            570*lm*NH))*Log[x]^2)/60 - 
       (2*CF*NC*(239*CA + 834*CF - 68*NM - 38*NL)*Log[x]^3)/3 - 
       (516478838801*CF^2*NC*PolyGamma[2, 1])/5952139200 - 
       (898*CF*NM*NC*PolyGamma[2, 1])/175 - 
       (6001680472*CF*NC*NH*PolyGamma[2, 1])/13286025 - 
       (84298449997*CF^2*NC*Zeta[3])/595213920 + (41162*CF*NM*NC*Zeta[3])/
        525 - (250*CF*NC*NL*Zeta[3])/3 - (26730181544*CF*NC*NH*Zeta[3])/
        13286025 + (CA*CF*NC*(25171071707763 + 27970292528640*lm^2 - 
          5309387335800*Pi^2 + 1092795687200*Sqrt[3]*Pi^3 + 
          215895111264*Pi^4 - 132269760*lm*(-720917 + 2200*Pi^2) - 
          36538853050464*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          67702012116480*Im[PolyLog[2, (-1)^(1/3)]]^2 + 40464663160320*
           Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          843013815840*Sqrt[3]*Pi*Log[3]^2 + 8263661420816*PolyGamma[2, 1] + 
          45685834515232*Zeta[3]))/190468454400 + 
       (CF*NC*Log[x]*(2*(-16*(3645*NM*(72005 + 51714*lm + 11340*lm^2 + 
                4320*Pi^2) + 3645*NL*(103433 + 51714*lm + 11340*lm^2 + 
                7200*Pi^2) + 2*NH*(3852250233 + 94248765*lm + 20667150*
                 lm^2 - 2193650800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            5*CF*(-12801277839 - 12516498432*lm - 3571283520*lm^2 + 
              248145768*Pi^2 + 892078112*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              1058158080*Zeta[3])) + 5*CA*(16302512721 + 8486889696*lm + 
            1454967360*lm^2 - 87602472*Pi^2 - 892078112*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 1058158080*Zeta[3])))/62985600, 
      -(CF*NC*(-3*CA*(368211 + 159830*lm) + 2*(CF*(1875193 + 1176930*lm) + 
             118167*NM + 43590*lm*NM + 65325*NL + 43590*lm*NL + 756*NH + 
             43590*lm*NH))*Log[x]^2)/810 - 
       (2*CF*NC*(16703*CA + 70598*CF - 5056*NM - 2906*NL)*Log[x]^3)/81 + 
       (CF*NC*Log[x]*(2*(-8*(3645*NM*(3493823 + 2428932*lm + 544320*lm^2 + 
                279240*Pi^2) + 3645*NL*(4881557 + 2428932*lm + 544320*lm^2 + 
                355800*Pi^2) + NH*(324568696983 + 8853457140*lm + 
                1984046400*lm^2 - 184726151200*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) + 5*CF*(-300037298151 - 291996832608*lm - 
              85710804480*lm^2 + 5576867496*Pi^2 + 28765360544*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 25395793920*Zeta[3])) - 
          5*CA*(-392413457523 - 200263485024*lm - 34919216640*lm^2 + 
            1821036168*Pi^2 + 28765360544*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 25395793920*Zeta[3])))/566870400 - 
       (CF*NC*(-35*CA*(231351191259057 + 616289254479360*lm^2 - 
            105668055277272*Pi^2 + 35237566666400*Sqrt[3]*Pi^3 + 
            4823124209568*Pi^4 - 132269760*lm*(-15477217 + 37400*Pi^2) - 
            702326580457056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            1644533205557760*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            1304796754275840*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
            27183265714080*Sqrt[3]*Pi*Log[3]^2 + 186166370101936*
             PolyGamma[2, 1] + 435555947081312*Zeta[3]) + 
          2*(CF*(52944849589363200*lm^2 - 4232632601388168*Pi^2 + 
              1233314833324000*Sqrt[3]*Pi^3 + 143625185030880*Pi^4 - 
              624974616000*lm*(-84163 + 680*Pi^2) + 951414299992800*Sqrt[
                3]*Pi*Log[3]^2 - 35*(-1017984488576805 + 702326580457056*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1644533205557760*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 1304796754275840*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 186166370101936*
                 PolyGamma[2, 1] + 324087212819872*Zeta[3])) - 
            224*(164025*NL*(-25199699 - 53370576*lm^2 - 33512280*Pi^2 + 
                126*lm*(-867923 + 3400*Pi^2) - 184464000*Zeta[3]) + 
              98415*NM*(445461275 - 88950960*lm^2 - 55469080*Pi^2 + 
                210*lm*(-867923 + 3400*Pi^2) - 26857452*PolyGamma[2, 1] + 
                339001896*Zeta[3]) - NH*(-1407496518654903 + 8754108728400*
                 lm^2 + 56572383805000*Sqrt[3]*Pi^3 - 20667150*lm*
                 (-867923 + 3400*Pi^2) - 727178785420800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 2094794554608000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 43641553221000*
                 Sqrt[3]*Pi*Log[3]^2 + 157852657198280*PolyGamma[2, 1] + 
                790679409068560*Zeta[3])))))/59997563136000, 
      (-34382946557021*CF^2*NC)/13604889600 - (1385581*CF^2*lm*NC)/240 - 
       (104643*CF^2*lm^2*NC)/20 + (5596783*CF*NM*NC)/3888 - 
       (2711059*CF*lm*NM*NC)/6480 - (11627*CF*lm^2*NM*NC)/60 - 
       (3554213*CF*NC*NL)/58320 - (2711059*CF*lm*NC*NL)/6480 - 
       (11627*CF*lm^2*NC*NL)/60 + (13796761436817361*CF*NC*NH)/
        364568526000 - (2711059*CF*lm*NC*NH)/6480 - (11627*CF*lm^2*NC*NH)/
        60 + (49715161031*CF^2*NC*Pi^2)/81648000 + (245*CF^2*lm*NC*Pi^2)/6 + 
       (22132*CF*NM*NC*Pi^2)/1215 + (245*CF*lm*NM*NC*Pi^2)/162 - 
       (67253*CF*NC*NL*Pi^2)/486 + (245*CF*lm*NC*NL*Pi^2)/162 + 
       (245*CF*lm*NC*NH*Pi^2)/162 - (24552891545*CF^2*NC*Pi^3)/
        (51018336*Sqrt[3]) - (32276596415*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) - 
       (1452311*CF^2*NC*Pi^4)/64800 + (4148165337323*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(425152800*Sqrt[3]) + 
       (120668971993*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2657205*Sqrt[3]) - (178997*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        30 - (701511187*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (39366*Sqrt[3]) - (3688753876*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (701511187*CF^2*NC*Pi*Log[3]^2)/(1889568*Sqrt[3]) - 
       (922188469*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) - 
       (CF*NC*(-21*CA*(1451889 + 692230*lm) + 35*CF*(3205415 + 2038932*lm) + 
          6*(35*(-1753 + 12586*lm)*NM + 245*(2595 + 1798*lm)*NL + 
            2*(7263 + 220255*lm)*NH))*Log[x]^2)/5670 - 
       (28*CF*NC*(5792*CA + 25427*CF - 3934*NM - 899*NL)*Log[x]^3)/81 - 
       (45588023727179*CF^2*NC*PolyGamma[2, 1])/53569252800 + 
       (97373*CF*NM*NC*PolyGamma[2, 1])/2025 - 
       (5895745117919*CF*NC*NH*PolyGamma[2, 1])/1674039150 - 
       (3467820328471*CF^2*NC*Zeta[3])/5356925280 + 
       (2832346*CF*NM*NC*Zeta[3])/2025 - (23660*CF*NC*NL*Zeta[3])/27 - 
       (6882105518819*CF*NC*NH*Zeta[3])/837019575 + 
       (CA*CF*NC*(255339794244087 + 1827025793429760*lm^2 - 
          444770335024344*Pi^2 + 137496192652000*Sqrt[3]*Pi^3 + 
          21283672578336*Pi^4 - 1454967360*lm*(-4309243 + 9800*Pi^2) - 
          2787567106681056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          5113992289835520*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          5091287590771200*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          106068491474400*Sqrt[3]*Pi*Log[3]^2 + 729408379634864*
           PolyGamma[2, 1] + 2991435462733408*Zeta[3]))/1714216089600 + 
       (CF*NC*Log[x]*(-245*CA*(-1454765722629 - 731055033504*lm - 
            122217258240*lm^2 + 8418952728*Pi^2 + 112241789920*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 88885278720*Zeta[3]) + 
          2*(8*(-178605*NM*(11364967 + 8970972*lm + 1905120*lm^2 - 
                1289400*Pi^2) - 178605*NL*(19015753 + 8970972*lm + 
                1905120*lm^2 + 1390200*Pi^2) - NH*(63581079406503 + 
                1602260454060*lm + 340263957600*lm^2 - 36149787984800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) - 245*CF*(1095951329568*lm + 
              299987815680*lm^2 + 5*(224689442061 - 4619381400*Pi^2 - 
                22448357984*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                17777055744*Zeta[3])))))/27776649600, 
      (-1679903687718349*CF^2*NC)/408146688000 - (3661537*CF^2*lm*NC)/320 - 
       (875637*CF^2*lm^2*NC)/80 + (6013233661*CF*NM*NC)/1944000 - 
       (7358671*CF*lm*NM*NC)/8640 - (32431*CF*lm^2*NM*NC)/80 + 
       (24738733*CF*NC*NL)/933120 - (7358671*CF*lm*NC*NL)/8640 - 
       (32431*CF*lm^2*NC*NL)/80 + (12385617938440589*CF*NC*NH)/
        156243654000 - (7358671*CF*lm*NC*NH)/8640 - (32431*CF*lm^2*NC*NH)/
        80 + (84978993349*CF^2*NC*Pi^2)/81648000 + (1715*CF^2*lm*NC*Pi^2)/
        24 - (2699101*CF*NM*NC*Pi^2)/38880 + (1715*CF*lm*NM*NC*Pi^2)/648 - 
       (2390873*CF*NC*NL*Pi^2)/7776 + (1715*CF*lm*NC*NL*Pi^2)/648 + 
       (1715*CF*lm*NC*NH*Pi^2)/648 - (97996643675*CF^2*NC*Pi^3)/
        (76527504*Sqrt[3]) - (808023769735*CF*NC*NH*Pi^3)/
        (76527504*Sqrt[3]) - (841561*CF^2*NC*Pi^4)/16200 + 
       (6137369681251*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (318864600*Sqrt[3]) + (6443399022097*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(63772920*Sqrt[3]) - 
       (67298*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (2799904105*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (59049*Sqrt[3]) - (23086393421*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (2799904105*CF^2*NC*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (23086393421*CF*NC*NH*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (CF*NC*(-35*CA*(2868755 + 1144308*lm) + 
          2*(140*CF*(1191376 + 702189*lm) + 3648864*NM + 3640980*lm*NM + 
            5138595*NL + 3640980*lm*NL + 142992*NH + 3640980*lm*NH))*
         Log[x]^2)/6480 - (7*CF*NC*(95141*CA + 555471*CF - 73508*NM - 
          17338*NL)*Log[x]^3)/162 - (1984959892189*CF^2*NC*PolyGamma[2, 1])/
        956593800 + (14545073*CF*NM*NC*PolyGamma[2, 1])/226800 - 
       (6534928824292*CF*NC*NH*PolyGamma[2, 1])/837019575 + 
       (CF*NC*Log[x]*(2*(4*(-61236*NM*(181978952 + 99979275*lm + 
                21432600*lm^2 - 12567450*Pi^2) - 76545*NL*(172020769 + 
                79983420*lm + 17146080*lm^2 + 12997320*Pi^2) - 
              2*NH*(113774994441489 + 3061165441950*lm + 656223346800*lm^2 - 
                64641901578800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            7*CF*(-78257474240817 - 73084687484400*lm - 20249177558400*lm^2 + 
              1035451771200*Pi^2 + 8959693136000*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 5999756313600*Zeta[3])) - 
          7*CA*(-102203792095377 - 48982796247600*lm - 8249664931200*lm^2 + 
            23460036480*Pi^2 + 8959693136000*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 5999756313600*Zeta[3])))/23808556800 + 
       (2767792136029*CF^2*NC*Zeta[3])/956593800 + 
       (395275073*CF*NM*NC*Zeta[3])/113400 - (55013*CF*NC*NL*Zeta[3])/27 - 
       (17949506100059*CF*NC*NH*Zeta[3])/837019575 + 
       (CA*CF*NC*(-4408161941327769 + 16380298982678400*lm^2 - 
          2898008099033040*Pi^2 + 1567946298800000*Sqrt[3]*Pi^3 + 
          206377332053760*Pi^4 - 141717600*lm*(-389943159 + 754600*Pi^2) - 
          23567499576003840*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          49441420456243200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          58058811521280000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          1209558573360000*Sqrt[3]*Pi*Log[3]^2 + 7622245986005760*
           PolyGamma[2, 1] + 12756640637752320*Zeta[3]))/7346640384000, 
      (-322092366544837*CF^2*NC)/91833004800 - (6911969*CF^2*lm*NC)/240 - 
       (129402*CF^2*lm^2*NC)/5 + (17737808527*CF*NM*NC)/1944000 - 
       (13468337*CF*lm*NM*NC)/6480 - (14378*CF*lm^2*NM*NC)/15 + 
       (11618311*CF*NC*NL)/23328 - (13468337*CF*lm*NC*NL)/6480 - 
       (14378*CF*lm^2*NC*NL)/15 + (8883158943027877973*CF*NC*NH)/
        39373400808000 - (13468337*CF*lm*NC*NH)/6480 - 
       (14378*CF*lm^2*NC*NH)/15 + (1209055511261*CF^2*NC*Pi^2)/299376000 + 
       (490*CF^2*lm*NC*Pi^2)/3 + (6808151*CF*NM*NC*Pi^2)/2430 + 
       (490*CF*lm*NM*NC*Pi^2)/81 - (391679*CF*NC*NL*Pi^2)/486 + 
       (490*CF*lm*NC*NL*Pi^2)/81 + (490*CF*lm*NC*NH*Pi^2)/81 - 
       (5109536447701*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (2707465849235*CF*NC*NH*Pi^3)/(86093442*Sqrt[3]) - 
       (2556617*CF^2*NC*Pi^4)/16200 + (635715658145731*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(11479125600*Sqrt[3]) + 
       (17491605581252*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (71744535*Sqrt[3]) - (501718*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        15 - (729933778243*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5314410*Sqrt[3]) - (618849336968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (729933778243*CF^2*NC*Pi*Log[3]^2)/(255091680*Sqrt[3]) - 
       (77356167121*CF*NC*NH*Pi*Log[3]^2)/(3188646*Sqrt[3]) - 
       (CF*NC*(-7*CA*(265476437 + 125331360*lm) + 
          6*(147*CF*(7727927 + 4883040*lm) + 4*(7*(-7769367 + 949480*lm)*
               NM + 490*(18785 + 13564*lm)*NL + (362377 + 6646360*lm)*
               NH)))*Log[x]^2)/45360 - 
       (7*CF*NC*(175711*CA + 953114*CF - 8*(32930*NM + 3391*NL))*Log[x]^3)/
        81 - (4056689747570423*CF^2*NC*PolyGamma[2, 1])/723184912800 + 
       (37608512*CF*NM*NC*PolyGamma[2, 1])/14175 - 
       (88928199746431*CF*NC*NH*PolyGamma[2, 1])/4519905705 + 
       (CF*NC*Log[x]*(2*(8*(-38578680*NL*(15629045 + 6918708*lm + 
                1428840*lm^2 + 1188390*Pi^2) + 964467*NM*(187488211 - 
                276748320*lm - 57153600*lm^2 + 209672400*Pi^2) - 
              NH*(10682089032942141 + 266914621945440*lm + 55122761131200*
                 lm^2 - 6064723502286400*Sqrt[3]*Im[PolyLog[2, (-1)^
                    (1/3)]])) + 245*CF*(-185555659991313 - 184022729805312*
               lm - 48598026140160*lm^2 + 3859464842424*Pi^2 + 
              23357880903776*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              14399415152640*Zeta[3])) - 245*CA*(-244167067338483 - 
            121070350930176*lm - 19799195834880*lm^2 + 1217455748280*Pi^2 + 
            23357880903776*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            14399415152640*Zeta[3])))/749969539200 + 
       (3838320891589*CF^2*NC*Zeta[3])/361592456400 + 
       (165166324*CF*NM*NC*Zeta[3])/14175 - (160412*CF*NC*NL*Zeta[3])/27 - 
       (91278665938382*CF*NC*NH*Zeta[3])/4519905705 + 
       (CA*CF*NC*(-95714844158026359 + 122002644734530560*lm^2 - 
          38086918947707868*Pi^2 + 14306702053562800*Sqrt[3]*Pi^3 + 
          1938076282997568*Pi^4 - 1785641760*lm*(-235109851 + 431200*Pi^2) - 
          213600461136965616*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          387023880618869760*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          529756738897639680*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          11036598727034160*Sqrt[3]*Pi*Log[3]^2 + 64907035961126768*
           PolyGamma[2, 1] + 190310321946419296*Zeta[3]))/23141917209600, 
      (2562305716269758411*CF^2*NC)/7874680161600000 - 
       (312296113*CF^2*lm*NC)/6000 - (242928*CF^2*lm^2*NC)/5 + 
       (222363310409*CF*NM*NC)/13720000 - (620004913*CF*lm*NM*NC)/162000 - 
       (26992*CF*lm^2*NM*NC)/15 + (13149834793*CF*NC*NL)/7290000 - 
       (620004913*CF*lm*NC*NL)/162000 - (26992*CF*lm^2*NC*NL)/15 + 
       (5676310585734496283*CF*NC*NH)/13124466936000 - 
       (620004913*CF*lm*NC*NH)/162000 - (26992*CF*lm^2*NC*NH)/15 + 
       (246562105213*CF^2*NC*Pi^2)/128304000 + (4018*CF^2*lm*NC*Pi^2)/15 + 
       (50145149*CF*NM*NC*Pi^2)/12150 + (4018*CF*lm*NM*NC*Pi^2)/405 - 
       (19405981*CF*NC*NL*Pi^2)/12150 + (4018*CF*lm*NC*NL*Pi^2)/405 + 
       (4018*CF*lm*NC*NH*Pi^2)/405 - (57237630728159*CF^2*NC*Pi^3)/
        (6887475360*Sqrt[3]) - (1726143453643*CF*NC*NH*Pi^3)/
        (28697814*Sqrt[3]) - (5271763*CF^2*NC*Pi^4)/16200 + 
       (5832580234770791*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (57395628000*Sqrt[3]) + (2320106820328*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) - 
       (334278*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (8176804389737*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) - (1972735375592*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(885735*Sqrt[3]) - 
       (8176804389737*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) - 
       (246591921949*CF*NC*NH*Pi*Log[3]^2)/(5314410*Sqrt[3]) - 
       (CF*NC*(-15*CA*(9662216057 + 3124758560*lm) + 
          CF*(448551149194 + 230095857600*lm) + 120*(-373644729*NM + 
            71017240*lm*NM + 96602058*NL + 71017240*lm*NL + 4428595*NH + 
            71017240*lm*NH))*Log[x]^2)/1134000 - 
       (CF*NC*(44508995*CA + 421557366*CF - 40*(2321870*NM + 253633*NL))*
         Log[x]^3)/2025 - (2172169062159391*CF^2*NC*PolyGamma[2, 1])/
        144636982560 + (14987534*CF*NM*NC*PolyGamma[2, 1])/2835 - 
       (392530645591507*CF*NC*NH*PolyGamma[2, 1])/10044234900 + 
       (7273447029814513*CF^2*NC*Zeta[3])/361592456400 + 
       (73475728*CF*NM*NC*Zeta[3])/2835 - (1665644*CF*NC*NL*Zeta[3])/135 - 
       (259220782333747*CF*NC*NH*Zeta[3])/5022117450 + 
       (CA*CF*NC*(-71711143264366016499 + 56114088867383500800*lm^2 - 
          789191056211642028*Pi^2 + 7853002935903414800*Sqrt[3]*Pi^3 + 
          967520828126059200*Pi^4 - 17499289248*lm*(-10901244443 + 
            17679200*Pi^2) - 96027600985266303024*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 189527928124271385600*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 290785480140880730880*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6058030836268348560*
           Sqrt[3]*Pi*Log[3]^2 + 42574513618324063600*PolyGamma[2, 1] + 
          36878712336152163680*Zeta[3]))/5669769716352000 - 
       (CF*NC*Log[x]*(-5*CA*(694080773337400599 + 295606367711182080*lm + 
            48508029795456000*lm^2 + 6823738008755640*Pi^2 - 
            64106146415538080*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            35278567123968000*Zeta[3]) + 
          2*(-120*(-6561*NM*(177246479111 + 135020111520*lm + 28005264000*
                 lm^2 - 99498478800*Pi^2) - 642978*NL*(3174251353 + 
                1377756240*lm + 285768000*lm^2 + 247435800*Pi^2) - 
              5*NH*(6815209727789535 + 177173390336544*lm + 36748507420800*
                 lm^2 - 3866561336160320*Sqrt[3]*Im[PolyLog[2, (-1)^
                    (1/3)]])) + CF*(2712437603655791523 + 2241809446556332800*
               lm + 595325820216960000*lm^2 + 765130381759800*Pi^2 - 
              320530732077690400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              176392835619840000*Zeta[3]))))/18749238480000, 
      (381779474233964493917*CF^2*NC)/15749360323200000 - 
       (222159391*CF^2*lm*NC)/2000 - (993951*CF^2*lm^2*NC)/10 + 
       (621941530993*CF*NM*NC)/370440000 - (431993491*CF*lm*NM*NC)/54000 - 
       (36813*CF*lm^2*NM*NC)/10 + (10067936299*CF*NC*NL)/1620000 - 
       (431993491*CF*lm*NC*NL)/54000 - (36813*CF*lm^2*NC*NL)/10 + 
       (7831739077067892860333*CF*NC*NH)/7486570925064000 - 
       (431993491*CF*lm*NC*NH)/54000 - (36813*CF*lm^2*NC*NH)/10 + 
       (19334465836771*CF^2*NC*Pi^2)/898128000 + (2646*CF^2*lm*NC*Pi^2)/5 + 
       (4144267*CF*NM*NC*Pi^2)/75 + (98*CF*lm*NM*NC*Pi^2)/5 - 
       (2403757*CF*NC*NL*Pi^2)/675 + (98*CF*lm*NC*NL*Pi^2)/5 + 
       (98*CF*lm*NC*NH*Pi^2)/5 - (8608862382659*CF^2*NC*Pi^3)/
        (430467210*Sqrt[3]) - (12811510764689*CF*NC*NH*Pi^3)/
        (86093442*Sqrt[3]) - (532252*CF^2*NC*Pi^4)/675 + 
       (13918978029139381*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (57395628000*Sqrt[3]) + (75104778595342*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) - 
       (717248*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (9838699865896*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (13286025*Sqrt[3]) - (14641726588216*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (1229837483237*CF^2*NC*Pi*Log[3]^2)/(79716150*Sqrt[3]) - 
       (1830215823527*CF*NC*NH*Pi*Log[3]^2)/(15943230*Sqrt[3]) - 
       (CF*NC*(-55*CA*(24484628011 + 11969551440*lm) + 
          11*CF*(457023926287 + 293798080800*lm) + 
          180*(11*(-1970033083 + 60452280*lm)*NM + 
            21*(22*(1938173 + 1439340*lm)*NL + 5*(484849 + 6333096*lm)*
               NH)))*Log[x]^2)/6237000 - 
       (CF*NC*(57202675*CA + 362217482*CF - 360*(526740*NM + 23989*NL))*
         Log[x]^3)/675 - (62053852997321767*CF^2*NC*PolyGamma[2, 1])/
        2169554738400 + (230942281*CF*NM*NC*PolyGamma[2, 1])/4725 - 
       (5874861806443321*CF*NC*NH*PolyGamma[2, 1])/67798585575 + 
       (14407462651446773*CF^2*NC*Zeta[3])/1084777369200 + 
       (300799862*CF*NM*NC*Zeta[3])/4725 - (150052*CF*NC*NL*Zeta[3])/5 - 
       (888064770560882*CF*NC*NH*Zeta[3])/67798585575 + 
       CF*Log[x]*((86539129109*NM*NC)/330750 - (5900176*lm*NM*NC)/225 - 
         5292*lm^2*NM*NC - (1706895629*NC*NL)/27000 - (5900176*lm*NC*NL)/
          225 - 5292*lm^2*NC*NL - (72898936935191537*NC*NH)/67519579050 - 
         (5900176*lm*NC*NH)/225 - 5292*lm^2*NC*NH + (317882*NM*NC*Pi^2)/
          5 - (74438*NC*NL*Pi^2)/15 + (14641726588216*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-407314238120068799/781218270000 - (13929978*lm)/25 - 
           142884*lm^2 + (99402149*Pi^2)/8100 + 
           (9838699865896*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) - 
           42336*Zeta[3]) + CA*NC*(441640613980949407/1249949232000 + 
           (40785868*lm)/225 + 29106*lm^2 - (14929981*Pi^2)/8100 - 
           (4919349932948*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) + 
           21168*Zeta[3])) + CA*CF*NC*((404943*lm^2)/20 - 
         (27942135367*Pi^2)/3168000 + (8608862382659*Pi^3)/
          (860934420*Sqrt[3]) + (55342*Pi^4)/135 + 
         lm*(7534991201/108000 - (539*Pi^2)/5) + (1229837483237*Pi*Log[3]^2)/
          (159432300*Sqrt[3]) + (-3219322201312111431129 - 
           3437430814076261531760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           6099946484271058944000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           10496586177568841011200*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                Sqrt[3])]] + 1216255518747506633200*PolyGamma[2, 1] + 
           2590908381020652677600*Zeta[3])/85046545745280000), 
      (36155924948822851722121*CF^2*NC)/283488485817600000 - 
       (1684529747*CF^2*lm*NC)/9000 - (3446037*CF^2*lm^2*NC)/20 - 
       (255443454353639*CF*NM*NC)/11022480000 - (1660698661*CF*lm*NM*NC)/
        121500 - (127631*CF*lm^2*NM*NC)/20 + (213367706251*CF*NC*NL)/
        14580000 - (1660698661*CF*lm*NC*NL)/121500 - (127631*CF*lm^2*NC*NL)/
        20 + (252189129138748741373737*CF*NC*NH)/134758276651152000 - 
       (1660698661*CF*lm*NC*NH)/121500 - (127631*CF*lm^2*NC*NH)/20 - 
       (1490373331781*CF^2*NC*Pi^2)/25660800 + (4116*CF^2*lm*NC*Pi^2)/5 + 
       (471617302*CF*NM*NC*Pi^2)/6075 + (1372*CF*lm*NM*NC*Pi^2)/45 - 
       (13132046*CF*NC*NL*Pi^2)/2025 + (1372*CF*lm*NC*NL*Pi^2)/45 + 
       (1372*CF*lm*NC*NH*Pi^2)/45 - (183190176665671*CF^2*NC*Pi^3)/
        (4591650240*Sqrt[3]) - (68660539590307*CF*NC*NH*Pi^3)/
        (258280326*Sqrt[3]) - (16027907*CF^2*NC*Pi^4)/10800 + 
       (108315978531233267*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (258280326000*Sqrt[3]) + (1239631438549276*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(645700815*Sqrt[3]) - 
       (1312633*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (26170025237953*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (17714700*Sqrt[3]) - (78469188103208*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) - 
       (26170025237953*CF^2*NC*Pi*Log[3]^2)/(850305600*Sqrt[3]) - 
       (9808648512901*CF*NC*NH*Pi*Log[3]^2)/(47829690*Sqrt[3]) - 
       (CF*NC*(-495*CA*(154439452879 + 31101852320*lm) + 
          4*(33*CF*(1559131977521 + 572556826800*lm) + 
            70*(11*(-20900564611 + 908820360*lm)*NM + 198*(67032829 + 
                50490020*lm)*NL + 5*(169941355 + 1999404792*lm)*NH)))*
         Log[x]^2)/74844000 - (CF*NC*(28919095*CA + 2854691782*CF - 
          140*(7004490*NM + 360643*NL))*Log[x]^3)/2025 - 
       (17085641889542167*CF^2*NC*PolyGamma[2, 1])/154968195600 + 
       (10284637249*CF*NM*NC*PolyGamma[2, 1])/113400 - 
       (17222480031583619*CF*NC*NH*PolyGamma[2, 1])/108477736920 + 
       (CA*CF*NC*(6567018286409578166400*lm^2 + 6136214191164452011176*Pi^2 + 
          1244117765807238029400*Sqrt[3]*Pi^3 + 143399740856513248800*Pi^4 - 
          769968726912*lm*(-29122701821 + 40748400*Pi^2) + 
          959747990765583622680*Sqrt[3]*Pi*Log[3]^2 - 
          11*(1932826541835463093677 + 1188876180358816338592*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2232698049625282444800*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 4187991232431637626240*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 937660026898074124960*
             PolyGamma[2, 1] - 146770047943915948160*Zeta[3])))/
        187102400639616000 + (1869077078022877*CF^2*NC*Zeta[3])/15496819560 + 
       (8313661249*CF*NM*NC*Zeta[3])/56700 - (7717934*CF*NC*NL*Zeta[3])/
        135 - (3152440251017171*CF*NC*NH*Zeta[3])/54238868460 + 
       CF*Log[x]*((578961282953*NM*NC)/4374000 - (64773481*lm*NM*NC)/1350 - 
         9702*lm^2*NM*NC - (19162966889*NC*NL)/162000 - 
         (64773481*lm*NC*NL)/1350 - 9702*lm^2*NC*NL - 
         (3127485309138701051*NC*NH)/1620469897200 - (64773481*lm*NC*NH)/
          1350 - 9702*lm^2*NC*NH + (14512414*NM*NC*Pi^2)/135 - 
         (3834271*NC*NL*Pi^2)/405 + (78469188103208*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
         CF*NC*(-3712408877094984673/2083248720000 - (50948131*lm)/50 - 
           261954*lm^2 - (1707849451*Pi^2)/32400 + 
           (26170025237953*Im[PolyLog[2, (-1)^(1/3)]])/(53144100*Sqrt[3]) - 
           77616*Zeta[3]) + CA*NC*(55654373068085873/52081218000 + 
           (895876091*lm)/2700 + 53361*lm^2 + (745035319*Pi^2)/21600 - 
           (26170025237953*Im[PolyLog[2, (-1)^(1/3)]])/(106288200*Sqrt[3]) + 
           38808*Zeta[3])), (1155502101512133871037*CF^2*NC)/
        5669769716352000 - (256817543*CF^2*lm*NC)/720 - 
       (3184083*CF^2*lm^2*NC)/10 - (43778465981609533*CF*NM*NC)/
        54010152000 - (498807851*CF*lm*NM*NC)/19440 - 
       (117929*CF*lm^2*NM*NC)/10 + (21903091211*CF*NC*NL)/583200 - 
       (498807851*CF*lm*NC*NL)/19440 - (117929*CF*lm^2*NC*NL)/10 + 
       (16993623545772244595843701*CF*NC*NH)/4229484768608299200 - 
       (498807851*CF*lm*NC*NH)/19440 - (117929*CF*lm^2*NC*NH)/10 + 
       (520888233406201*CF^2*NC*Pi^2)/3891888000 + 1470*CF^2*lm*NC*Pi^2 + 
       (1939653119*CF*NM*NC*Pi^2)/2430 + (490*CF*lm*NM*NC*Pi^2)/9 - 
       (2090159*CF*NC*NL*Pi^2)/162 + (490*CF*lm*NC*NL*Pi^2)/9 + 
       (490*CF*lm*NC*NH*Pi^2)/9 - (145419562905659*CF^2*NC*Pi^3)/
        (1721868840*Sqrt[3]) - (149205267699005*CF*NC*NH*Pi^3)/
        (258280326*Sqrt[3]) - (1400959*CF^2*NC*Pi^4)/450 + 
       (455808717689789521*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (516560652000*Sqrt[3]) + (2450825267329024*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(645700815*Sqrt[3]) - 
       (2536632*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (41548446544474*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (13286025*Sqrt[3]) - (34104061188344*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (20774223272237*CF^2*NC*Pi*Log[3]^2)/(318864600*Sqrt[3]) - 
       (4263007648543*CF*NC*NH*Pi*Log[3]^2)/(9565938*Sqrt[3]) - 
       (CF*NC*(-2574*CA*(62053557637 + 43141021000*lm) + 
          429*CF*(1665874657921 + 1270699164000*lm) + 
          100*(143*(-159694459397 + 1411887960*lm)*NM + 
            7*(2574*(14793223 + 11205460*lm)*NL + 5*(565279661 + 
                5768570808*lm)*NH)))*Log[x]^2)/243243000 - 
       (CF*NC*(1731501247*CA + 2*(5260330001*CF - 200*(31856304*NM + 
              560273*NL)))*Log[x]^3)/4050 - 
       (751652977980033469*CF^2*NC*PolyGamma[2, 1])/6508664215200 + 
       (1885384847*CF*NM*NC*PolyGamma[2, 1])/2835 - 
       (9272299892898661*CF*NC*NH*PolyGamma[2, 1])/29056536675 + 
       (138706282938709223*CF^2*NC*Zeta[3])/3254332107600 + 
       (694071874*CF*NM*NC*Zeta[3])/2835 - (3306548*CF*NC*NL*Zeta[3])/27 + 
       (4350711368537878*CF*NC*NH*Zeta[3])/29056536675 + 
       CF*Log[x]*((105500045616541*NM*NC)/21432600 - (2645887*lm*NM*NC)/
          27 - 19404*lm^2*NM*NC - (204086807*NC*NL)/810 - 
         (2645887*lm*NC*NL)/27 - 19404*lm^2*NC*NL - 
         (82067292305893743569*NC*NH)/19561386616200 - (2645887*lm*NC*NH)/
          27 - 19404*lm^2*NC*NH + (20546818*NM*NC*Pi^2)/27 - 
         (1644454*NC*NL*Pi^2)/81 + (34104061188344*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(-2055312777811845619/1562436540000 - 2092873*lm - 
           523908*lm^2 + (122729827*Pi^2)/1620 + 
           (41548446544474*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) - 
           155232*Zeta[3]) + CA*NC*(1274059107289342993/1249949232000 + 
           (36439469*lm)/54 + 106722*lm^2 - (83381599*Pi^2)/4050 - 
           (20774223272237*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) + 
           77616*Zeta[3])) + CA*CF*NC*((1297219*lm^2)/20 - 
         (5062793619841*Pi^2)/85536000 + (145419562905659*Pi^3)/
          (3443737680*Sqrt[3]) + (480053*Pi^4)/300 + 
         lm*(1739288405/7776 - (2695*Pi^2)/9) + (20774223272237*Pi*Log[3]^2)/
          (637729200*Sqrt[3]) + (-50605960308771631060683 - 
           37522173640223473368720*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           64719536828082329088000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           132980024487757955558400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                Sqrt[3])]] + 14732398368408655992400*PolyGamma[2, 1] + 
           30086029498796640471200*Zeta[3])/255139637235840000), 
      (97708729569774589334443643*CF^2*NC)/56598476193483840000 - 
       (20068572803*CF^2*lm*NC)/35280 - (2595564*CF^2*lm^2*NC)/5 - 
       (22719430684919027791*CF*NM*NC)/14377502462400 - 
       (7880066695*CF*lm*NM*NC)/190512 - (96132*CF*lm^2*NM*NC)/5 + 
       (7545569878417*CF*NC*NL)/100018800 - (7880066695*CF*lm*NC*NL)/
        190512 - (96132*CF*lm^2*NC*NL)/5 + (21135850105406737102604054197*CF*
         NC*NH)/3108671304927099912000 - (7880066695*CF*lm*NC*NH)/190512 - 
       (96132*CF*lm^2*NC*NH)/5 - (99223777911620407*CF^2*NC*Pi^2)/
        81729648000 + 2190*CF^2*lm*NC*Pi^2 + (1171409119*CF*NM*NC*Pi^2)/
        1215 + (730*CF*lm*NM*NC*Pi^2)/9 - (4159133*CF*NC*NL*Pi^2)/189 + 
       (730*CF*lm*NC*NL*Pi^2)/9 + (730*CF*lm*NC*NH*Pi^2)/9 - 
       (9593622122380787*CF^2*NC*Pi^3)/(61987278240*Sqrt[3]) - 
       (756744330356945*CF*NC*NH*Pi^3)/(774840978*Sqrt[3]) - 
       (29458969*CF^2*NC*Pi^4)/5400 + (110374918258475113661*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(75934415844000*Sqrt[3]) + 
       (88649713775770802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (13559717115*Sqrt[3]) - (4339126*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (9593622122380787*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1674039150*Sqrt[3]) - 
       (172970132653016*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4782969*Sqrt[3]) - (9593622122380787*CF^2*NC*Pi*Log[3]^2)/
        (80353879200*Sqrt[3]) - (21621266581627*CF*NC*NH*Pi*Log[3]^2)/
        (28697814*Sqrt[3]) - 
       (CF*NC*(-13*CA*(2601898370106067 + 216764975196000*lm) + 
          26*CF*(2978633728124713 + 532059484572000*lm) + 
          1400*(65*(-420361896113 + 5630259096*lm)*NM + 
            2574*(185599699 + 142178260*lm)*NL + 
            (38980540783 + 365966841240*lm)*NH))*Log[x]^2)/3405402000 + 
       (CF*NC*(39945578203*CA - 264930092002*CF + 
          2800*(45537168*NM + 1015559*NL))*Log[x]^3)/28350 - 
       (19841418138633796081*CF^2*NC*PolyGamma[2, 1])/19525992645600 + 
       (62756144551*CF*NM*NC*PolyGamma[2, 1])/56700 - 
       (47873283845864812*CF*NC*NH*PolyGamma[2, 1])/87169610025 + 
       CA*CF*NC*(-821959148266155077248166069/792378666708773760000 + 
         (528726*lm^2)/5 + (867204032985691*Pi^2)/1397088000 + 
         (9593622122380787*Pi^3)/(123974556480*Sqrt[3]) + 
         (30159769*Pi^4)/10800 + lm*(689803862401/1905120 - (4015*Pi^2)/9) - 
         (110374918258475113661*Im[PolyLog[2, (-1)^(1/3)]])/
          (151868831688000*Sqrt[3]) + (2169563*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          5 + (9593622122380787*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3348078300*Sqrt[3]) + (9593622122380787*Pi*Log[3]^2)/
          (160707758400*Sqrt[3]) + (19841418138633796081*PolyGamma[2, 1])/
          39051985291200 - (3075442754026724531*Zeta[3])/19525992645600) + 
       (7818539020361897507*CF^2*NC*Zeta[3])/9762996322800 + 
       (23973096751*CF*NM*NC*Zeta[3])/28350 - (5884772*CF*NC*NL*Zeta[3])/
        27 + (14713367418189976*CF*NC*NH*Zeta[3])/87169610025 + 
       CF*Log[x]*((441643978644821*NM*NC)/129667230 - (52875521*lm*NM*NC)/
          315 - 33264*lm^2*NM*NC - (70157234657*NC*NL)/158760 - 
         (52875521*lm*NC*NL)/315 - 33264*lm^2*NC*NL - 
         (5101620903674995759457*NC*NH)/718880958145350 - 
         (52875521*lm*NC*NH)/315 - 33264*lm^2*NC*NH + 
         (29058466*NM*NC*Pi^2)/27 - (2929246*NC*NL*Pi^2)/81 + 
         (172970132653016*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CF*NC*(-347987579922298173955877/
            23820907488840000 - (125445723*lm)/35 - 898128*lm^2 - 
           (621391355*Pi^2)/648 + (9593622122380787*Im[PolyLog[2, (-1)^
                (1/3)]])/(5022117450*Sqrt[3]) - 266112*Zeta[3]) + 
         CA*NC*(10818895781047212639379/1361194713648000 + 
           (728324971*lm)/630 + 182952*lm^2 + (115699243193*Pi^2)/226800 - 
           (9593622122380787*Im[PolyLog[2, (-1)^(1/3)]])/(10044234900*
             Sqrt[3]) + 133056*Zeta[3])), 
      (823430594161620960900847787*CF^2*NC)/1782852000094740960000 - 
       (35198315723*CF^2*lm*NC)/35280 - (4446684*CF^2*lm^2*NC)/5 - 
       (1047239525917100582747*CF*NM*NC)/71887512312000 - 
       (13663443631*CF*lm*NM*NC)/190512 - (164692*CF*lm^2*NM*NC)/5 + 
       (32998820810657*CF*NC*NL)/200037600 - (13663443631*CF*lm*NC*NL)/
        190512 - (164692*CF*lm^2*NC*NL)/5 + (372867955891971388392893790407*
         CF*NC*NH)/27978041744343899208000 - (13663443631*CF*lm*NC*NH)/
        190512 - (164692*CF*lm^2*NC*NH)/5 + (12539972919919553*CF^2*NC*Pi^2)/
        9081072000 + 3630*CF^2*lm*NC*Pi^2 + (88550486194*CF*NM*NC*Pi^2)/
        8505 + (1210*CF*lm*NM*NC*Pi^2)/9 - (3257540*CF*NC*NL*Pi^2)/81 + 
       (1210*CF*lm*NC*NL*Pi^2)/9 + (1210*CF*lm*NC*NH*Pi^2)/9 - 
       (166275069616735117*CF^2*NC*Pi^3)/(557885504160*Sqrt[3]) - 
       (13440661031421925*CF*NC*NH*Pi^3)/(6973568802*Sqrt[3]) - 
       (18611197*CF^2*NC*Pi^4)/1800 + (1906741551595801032841*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(683409742596000*Sqrt[3]) + 
       (1470510362184368038*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (122037454035*Sqrt[3]) - (7750314*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (166275069616735117*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(15066352350*Sqrt[3]) - 
       (3072151092896440*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) - (166275069616735117*CF^2*NC*Pi*Log[3]^2)/
        (723184912800*Sqrt[3]) - (384018886612055*CF*NC*NH*Pi*Log[3]^2)/
        (258280326*Sqrt[3]) - 
       (CF*NC*(-13*CA*(-805923574432217 + 433942537644000*lm) + 
          2*(13*CF*(-30764587327253 + 1065131683308000*lm) + 
            700*(91*(-3319709059741 + 8050881960*lm)*NM + 12870*(74073519 + 
                56925428*lm)*NL + (86704279267 + 732630258360*lm)*NH)))*
         Log[x]^2)/3405402000 - (CF*NC*(80071252063*CA + 
          14*(16889689757*CF - 200*(363434574*NM + 2033051*NL)))*Log[x]^3)/
        28350 - (5121026194478681947*CF^2*NC*PolyGamma[2, 1])/
        25104847687200 + (16395574477*CF*NM*NC*PolyGamma[2, 1])/2025 - 
       (801680171667220636*CF*NC*NH*PolyGamma[2, 1])/784526490225 - 
       (54384407272576901881*CF^2*NC*Zeta[3])/87866966905200 + 
       (175057454*CF*NM*NC*Zeta[3])/2025 - (11468900*CF*NC*NL*Zeta[3])/27 + 
       (744265094297411128*CF*NC*NH*Zeta[3])/784526490225 + 
       CF*Log[x]*((23214464789593433*NM*NC)/324168075 - 
         (295678339*lm*NM*NC)/945 - 60984*lm^2*NM*NC - 
         (135978249671*NC*NL)/158760 - (295678339*lm*NC*NL)/945 - 
         60984*lm^2*NC*NL - (181257532882786710332597*NC*NH)/
          12939857246616300 - (295678339*lm*NC*NH)/945 - 60984*lm^2*NC*NH + 
         (240056830*NM*NC*Pi^2)/27 - (5712670*NC*NL*Pi^2)/81 + 
         (3072151092896440*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (129140163*Sqrt[3]) + CF*NC*(1169707164894766295737073/
            214388167399560000 - (234846799*lm)/35 - 1646568*lm^2 + 
           (20184115373*Pi^2)/22680 + (166275069616735117*
             Im[PolyLog[2, (-1)^(1/3)]])/(45199057050*Sqrt[3]) - 
           487872*Zeta[3]) + CA*NC*(-130926387634932941484847/
            85755266959824000 + (4059280049*lm)/1890 + 335412*lm^2 - 
           (12494561399*Pi^2)/32400 - (166275069616735117*
             Im[PolyLog[2, (-1)^(1/3)]])/(90398114100*Sqrt[3]) + 
           243936*Zeta[3])) + CA*CF*NC*((905806*lm^2)/5 - 
         (3293300577932269*Pi^2)/4953312000 + (166275069616735117*Pi^3)/
          (1115771008320*Sqrt[3]) + (2110933*Pi^4)/400 + 
         lm*(1190750631961/1905120 - (6655*Pi^2)/9) + 
         (166275069616735117*Pi*Log[3]^2)/(1446369825600*Sqrt[3]) + 
         (-35251717519597562878328272089 - 29845386540846371414605722960*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           49743586138544179879181184000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           118055319646930398464990227200*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           6546168864603021094867302800*PolyGamma[2, 1] + 
           48952971626279768011749584800*Zeta[3])/64182672003410674560000), 
      (46443763993337019947484821287597*CF^2*NC)/1989549635153343943680000 - 
       (859099234267*CF^2*lm*NC)/564480 - (110468259*CF^2*lm^2*NC)/80 - 
       (23137146895638998978677291*CF*NM*NC)/1010795933116569600 - 
       (1681866827299*CF*lm*NM*NC)/15240960 - (4091417*CF*lm^2*NM*NC)/80 + 
       (1928049778766807*CF*NC*NL)/6401203200 - (1681866827299*CF*lm*NC*NL)/
        15240960 - (4091417*CF*lm^2*NC*NL)/80 + 
       (250485229249474776727876730809*CF*NC*NH)/11627238127519542528000 - 
       (1681866827299*CF*lm*NC*NH)/15240960 - (4091417*CF*lm^2*NC*NH)/80 - 
       (5982327930346498231*CF^2*NC*Pi^2)/326918592000 + 
       (41745*CF^2*lm*NC*Pi^2)/8 + (2805293845771*CF*NM*NC*Pi^2)/272160 + 
       (13915*CF*lm*NM*NC*Pi^2)/72 - (36909004*CF*NC*NL*Pi^2)/567 + 
       (13915*CF*lm*NC*NL*Pi^2)/72 + (13915*CF*lm*NC*NH*Pi^2)/72 - 
       (126862478288815361*CF^2*NC*Pi^3)/(247949112960*Sqrt[3]) - 
       (86850870921950135*CF*NC*NH*Pi^3)/(27894275208*Sqrt[3]) - 
       (369643087*CF^2*NC*Pi^4)/21600 + (1340671913564942917033*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(303737663376000*Sqrt[3]) + 
       (3854524955351420333*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (195259926456*Sqrt[3]) - (25132349*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/10 - (126862478288815361*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6696156600*Sqrt[3]) - 
       (4962906909825722*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) - (126862478288815361*CF^2*NC*Pi*Log[3]^2)/
        (321415516800*Sqrt[3]) - (2481453454912861*CF*NC*NH*Pi*Log[3]^2)/
        (1033121304*Sqrt[3]) - 
       (CF*NC*(-3*CA*(1078019073344965447 + 25723059514152000*lm) + 
          2*(9*CF*(374375750235896641 + 21046139602488000*lm) + 
            700*(5*(-476547800185229 + 2004394247856*lm)*NM + 
              11*(2340*(502055599 + 389353972*lm)*NL + 7*(16487763593 + 
                  130155470640*lm)*NH))))*Log[x]^2)/27243216000 + 
       (CF*NC*(2987851381009*CA - 8797751753036*CF + 
          2800*(1660658055*NM + 13905499*NL))*Log[x]^3)/113400 - 
       (171122391738446509513*CF^2*NC*PolyGamma[2, 1])/14644494484200 + 
       (666021302969*CF*NM*NC*PolyGamma[2, 1])/56700 - 
       (146945778709353811781*CF*NC*NH*PolyGamma[2, 1])/87866966905200 + 
       CA*CF*NC*(-340231908233376456696096655421593/
          27853694892146815211520000 + (45005587*lm^2)/160 + 
         (60708292726891189*Pi^2)/6604416000 + (126862478288815361*Pi^3)/
          (495898225920*Sqrt[3]) + (376322287*Pi^4)/43200 + 
         lm*(5882606319469/6096384 - (153065*Pi^2)/144) - 
         (1340671913564942917033*Im[PolyLog[2, (-1)^(1/3)]])/
          (607475326752000*Sqrt[3]) + (25132349*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          20 + (126862478288815361*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (13392313200*Sqrt[3]) + (126862478288815361*Pi*Log[3]^2)/
          (642831033600*Sqrt[3]) + (171122391738446509513*PolyGamma[2, 1])/
          29288988968400 - (37130717770813465993*Zeta[3])/11715595587360) + 
       (229676463770872222031*CF^2*NC*Zeta[3])/29288988968400 + 
       (86737257247*CF*NM*NC*Zeta[3])/14175 - (38638925*CF*NC*NL*Zeta[3])/
        54 + (58985322394883851219*CF*NC*NH*Zeta[3])/43933483452600 + 
       CF*Log[x]*((63092567138504875729*NM*NC)/1402480759680 - 
         (7686300149*lm*NM*NC)/15120 - 99099*lm^2*NM*NC - 
         (1810438636133*NC*NL)/1270080 - (7686300149*lm*NC*NL)/15120 - 
         99099*lm^2*NC*NL - (24348733602434857992863*NC*NH)/
          1075520602316160 - (7686300149*lm*NC*NH)/15120 - 
         99099*lm^2*NC*NH + (272835833*NM*NC*Pi^2)/27 - 
         (19256845*NC*NL*Pi^2)/162 + (4962906909825722*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(129140163*Sqrt[3]) + 
         CF*NC*(-94002936735784680067305893/575104766516280000 - 
           (6104680109*lm)/560 - 2675673*lm^2 - (1277293531531*Pi^2)/90720 + 
           (126862478288815361*Im[PolyLog[2, (-1)^(1/3)]])/
            (20088469800*Sqrt[3]) - 792792*Zeta[3]) + 
         CA*NC*(215765687208999109410021811/2576469353992934400 + 
           (105526577959*lm)/30240 + (1090089*lm^2)/2 + (2158979337733*Pi^2)/
            302400 - (126862478288815361*Im[PolyLog[2, (-1)^(1/3)]])/
            (40176939600*Sqrt[3]) + 396396*Zeta[3])), 
      (-2133392144583252424727480067365941*CF^2*NC)/
        188012440521991002677760000 - (39272445013*CF^2*lm*NC)/15680 - 
       (44613261*CF^2*lm^2*NC)/20 - (729672273619640202189329*CF*NM*NC)/
        3599700616512000 - (15238479401*CF*lm*NM*NC)/84672 - 
       (1652343*CF*lm^2*NM*NC)/20 + (2629371232373*CF*NC*NL)/4445280 - 
       (15238479401*CF*lm*NC*NL)/84672 - (1652343*CF*lm^2*NC*NL)/20 + 
       (129659483699699357396325729516500771*CF*NC*NH)/
        3298946858159077843413696000 - (15238479401*CF*lm*NC*NH)/84672 - 
       (1652343*CF*lm^2*NC*NH)/20 + (6279714519950948653*CF^2*NC*Pi^2)/
        326918592000 + (16335*CF^2*lm*NC*Pi^2)/2 + 
       (49726747463*CF*NM*NC*Pi^2)/378 + (605*CF*lm*NM*NC*Pi^2)/2 - 
       (168391399*CF*NC*NL*Pi^2)/1512 + (605*CF*lm*NC*NL*Pi^2)/2 + 
       (605*CF*lm*NC*NH*Pi^2)/2 - (6132345066698736409*CF^2*NC*Pi^3)/
        (6694626049920*Sqrt[3]) - (119300115116845705*CF*NC*NH*Pi^3)/
        (20920706406*Sqrt[3]) - (649351769*CF^2*NC*Pi^4)/21600 + 
       (64751049833970681467617*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8200916911152000*Sqrt[3]) + (359387752567705484*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) - 
       (42209563*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (6132345066698736409*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (180796228200*Sqrt[3]) - (27268597740993304*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) - 
       (6132345066698736409*CF^2*NC*Pi*Log[3]^2)/(8678218953600*Sqrt[3]) - 
       (3408574717624163*CF*NC*NH*Pi*Log[3]^2)/(774840978*Sqrt[3]) + 
       CF*((49816279826967893*CF*NC)/277992000 - 25719444*CF*lm*NC + 
         CA*(-2696889496136097533/27243216000 + 5239146*lm)*NC + 
         (7281969622009*NM*NC)/4620 - 952572*lm*NM*NC - 
         (77244553*NC*NL)/63 - 952572*lm*NC*NL - (26735641021*NC*NH)/
          204204 - 952572*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-579078566867*CA + 6*(39019281703*CF + 
            25200*(53546675*NM + 79381*NL)))*Log[x]^3)/18900 + 
       (1508921687392716445847*CF^2*NC*PolyGamma[2, 1])/351467867620800 + 
       (902514601133*CF*NM*NC*PolyGamma[2, 1])/9450 - 
       (16059481806037934669*CF*NC*NH*PolyGamma[2, 1])/5491685431575 - 
       (2397465656260825207987*CF^2*NC*Zeta[3])/175733933810400 - 
       (81257945617*CF*NM*NC*Zeta[3])/4725 - 1295970*CF*NC*NL*Zeta[3] + 
       (20554141803524669762*CF*NC*NH*Zeta[3])/5491685431575 + 
       CA*CF*NC*(1778420750298749733178325511711541/
          376024881043982005355520000 + (18175773*lm^2)/40 - 
         (188832356307746701*Pi^2)/19813248000 + (6132345066698736409*Pi^3)/
          (13389252099840*Sqrt[3]) + (659806169*Pi^4)/43200 + 
         lm*(1327791519791/846720 - (6655*Pi^2)/4) - 
         (64751049833970681467617*Im[PolyLog[2, (-1)^(1/3)]])/
          (16401833822304000*Sqrt[3]) + (42209563*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/20 + (6132345066698736409*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(361592456400*Sqrt[3]) + 
         (6132345066698736409*Pi*Log[3]^2)/(17356437907200*Sqrt[3]) - 
         (1508921687392716445847*PolyGamma[2, 1])/702935735241600 + 
         (2860280725601831179699*Zeta[3])/351467867620800) + 
       CF*Log[x]*((4714456561950826763*NM*NC)/4994589600 - 
         (1112894497*lm*NM*NC)/1260 - 169884*lm^2*NM*NC - 
         (5663665138*NC*NL)/2205 - (1112894497*lm*NC*NL)/1260 - 
         169884*lm^2*NC*NL - (3721775814650252660535906277*NC*NH)/
          89750849862530656800 - (1112894497*lm*NC*NH)/1260 - 
         169884*lm^2*NC*NH + 106859988*NM*NC*Pi^2 - 215390*NC*NL*Pi^2 + 
         (27268597740993304*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(134618918327320153873819393813/
            869558406972615360000 - (2660846331*lm)/140 - 4586868*lm^2 + 
           (176457355751*Pi^2)/12960 + (6132345066698736409*
             Im[PolyLog[2, (-1)^(1/3)]])/(542388684600*Sqrt[3]) - 
           1359072*Zeta[3]) + CA*NC*(-734272547322859527665311471/
            9937810365401318400 + (15238593227*lm)/2520 + 934362*lm^2 - 
           (6013182088357*Pi^2)/907200 - (6132345066698736409*
             Im[PolyLog[2, (-1)^(1/3)]])/(1084777369200*Sqrt[3]) + 
           679536*Zeta[3])), (1690059990466060744456616550085972859*CF^2*NC)/
        5076335894093757072299520000 - (4678058632013*CF^2*lm*NC)/1270080 - 
       (33283503*CF^2*lm^2*NC)/10 - (932377306019920361627149*CF*NM*NC)/
        3599700616512000 - (1828035635641*CF*lm*NM*NC)/6858432 - 
       (3698167*CF*lm^2*NM*NC)/30 + (12114788745119777*CF*NC*NL)/
        12002256000 - (1828035635641*CF*lm*NC*NL)/6858432 - 
       (3698167*CF*lm^2*NC*NL)/30 + (777988350844707755982803924861737433*CF*
         NC*NH)/12724509310042157396024256000 - (1828035635641*CF*lm*NC*NH)/
        6858432 - (3698167*CF*lm^2*NC*NH)/30 - 
       (19113589724886991813*CF^2*NC*Pi^2)/75442752000 + 
       (68365*CF^2*lm*NC*Pi^2)/6 + (2107184623013*CF*NM*NC*Pi^2)/20412 + 
       (68365*CF*lm*NM*NC*Pi^2)/162 - (7050435271*CF*NC*NL*Pi^2)/40824 + 
       (68365*CF*lm*NC*NL*Pi^2)/162 + (68365*CF*lm*NC*NH*Pi^2)/162 - 
       (269818478753387787787*CF^2*NC*Pi^3)/(180754903347840*Sqrt[3]) - 
       (5008642943491956055*CF*NC*NH*Pi^3)/(564859072962*Sqrt[3]) - 
       (3077638883*CF^2*NC*Pi^4)/64800 + (2672843910120711947065291*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(221424756601104000*Sqrt[3]) + 
       (533957642815575369961*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) - (196551641*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - (269818478753387787787*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4881498161400*Sqrt[3]) - 
       (1144832672798161384*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (269818478753387787787*CF^2*NC*Pi*Log[3]^2)/
        (234311911747200*Sqrt[3]) - (143104084099770173*CF*NC*NH*Pi*
         Log[3]^2)/(20920706406*Sqrt[3]) - 
       (CF*NC*(-51*CA*(42135506102165807083 + 232642145447712000*lm) + 
          34*CF*(127639350692357951561 + 1713092161933152000*lm) + 
          16800*(221*(-462124124924537 + 581024339280*lm)*NM + 
            3*(29172*(1874503591 + 1467233180*lm)*NL + 35*(177872325451 + 
                1222917895056*lm)*NH)))*Log[x]^2)/1389404016000 + 
       (CF*NC*(65327922809353*CA + 42*(-3445811421891*CF + 
            400*(3861883599*NM + 10480237*NL)))*Log[x]^3)/170100 - 
       (602828641028882607760079*CF^2*NC*PolyGamma[2, 1])/4066985325326400 + 
       (6642378753589*CF*NM*NC*PolyGamma[2, 1])/56700 - 
       (16339550137357955145587*CF*NC*NH*PolyGamma[2, 1])/3558612159660600 + 
       CA*CF*NC*(-341132695674671230347156979449188287/
          2030534357637502828919808000 + (40679837*lm^2)/60 + 
         (22609589250750242339*Pi^2)/178319232000 + 
         (269818478753387787787*Pi^3)/(361509806695680*Sqrt[3]) + 
         (115607129*Pi^4)/4800 + lm*(159723756046591/68584320 - 
           (752015*Pi^2)/324) - (2672843910120711947065291*
           Im[PolyLog[2, (-1)^(1/3)]])/(442849513202208000*Sqrt[3]) + 
         (196551641*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (269818478753387787787*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9762996322800*Sqrt[3]) + (269818478753387787787*Pi*Log[3]^2)/
          (468623823494400*Sqrt[3]) + (602828641028882607760079*
           PolyGamma[2, 1])/8133970650652800 - (1395782816932266863255773*
           Zeta[3])/28468897277284800) + (1455373546795865650970941*CF^2*NC*
         Zeta[3])/14234448638642400 + (1510183820689*CF*NM*NC*Zeta[3])/
        28350 - (18775978*CF*NC*NL*Zeta[3])/9 + 
       (9639871149602672833213*CF*NC*NH*Zeta[3])/1779306079830300 + 
       CF*Log[x]*((12963253462577804249*NM*NC)/26970783840 - 
         (9349844911*lm*NM*NC)/6804 - 264264*lm^2*NM*NC - 
         (9747542931239*NC*NL)/2381400 - (9349844911*lm*NC*NL)/6804 - 
         264264*lm^2*NC*NL - (22330250344606191329970086191*NC*NH)/
          346181849469761104800 - (9349844911*lm*NC*NH)/6804 - 
         264264*lm^2*NC*NH + (2564037760*NM*NC*Pi^2)/27 - 
         (28095602*NC*NL*Pi^2)/81 + (1144832672798161384*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-48525566568101406216864930217661/23478076988260614720000 - 
           (7451900863*lm)/252 - 7135128*lm^2 - (10605401644681*Pi^2)/54432 + 
           (269818478753387787787*Im[PolyLog[2, (-1)^(1/3)]])/
            (14644494484200*Sqrt[3]) - 2114112*Zeta[3]) + 
         CA*NC*(9758073733294728039502838364133/9391230795304245888000 + 
           (128021025605*lm)/13608 + 1453452*lm^2 + (265920080135761*Pi^2)/
            2721600 - (269818478753387787787*Im[PolyLog[2, (-1)^(1/3)]])/
            (29288988968400*Sqrt[3]) + 1057056*Zeta[3])), 
      (-239016447699583066019835480540338389*CF^2*NC)/
        846055982348959512049920000 - (7319470401877*CF^2*lm*NC)/1270080 - 
       (51298533*CF^2*lm^2*NC)/10 - (371394961255296908339291993*CF*NM*NC)/
        140388324043968000 - (14196756929989*CF*lm*NM*NC)/34292160 - 
       (5699837*CF*lm^2*NM*NC)/30 + (14654365417324547*CF*NC*NL)/
        8001504000 - (14196756929989*CF*lm*NC*NL)/34292160 - 
       (5699837*CF*lm^2*NC*NL)/30 + 
       (21435660512451659769357634416098204484319*CF*NC*NH)/
        203647288501018034351770867776000 - (14196756929989*CF*lm*NC*NH)/
        34292160 - (5699837*CF*lm^2*NC*NH)/30 + 
       (38665635365051261731*CF^2*NC*Pi^2)/140107968000 + 
       (102245*CF^2*lm*NC*Pi^2)/6 + (83824855215919*CF*NM*NC*Pi^2)/51030 + 
       (102245*CF*lm*NM*NC*Pi^2)/162 - (1634623133*CF*NC*NL*Pi^2)/5832 + 
       (102245*CF*lm*NC*NL*Pi^2)/162 + (102245*CF*lm*NC*NH*Pi^2)/162 - 
       (151938115775710859663*CF^2*NC*Pi^3)/(60251634449280*Sqrt[3]) - 
       (5761351864258368595*CF*NC*NH*Pi^3)/(376572715308*Sqrt[3]) - 
       (5095574341*CF^2*NC*Pi^4)/64800 + (1506746410582686414680459*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(73808252200368000*Sqrt[3]) + 
       (295364495179865226662*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3295011258945*Sqrt[3]) - (104716469*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - (151938115775710859663*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1627166053800*Sqrt[3]) - 
       (658440213058099268*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) - (151938115775710859663*CF^2*NC*Pi*Log[3]^2)/
        (78103970582400*Sqrt[3]) - (164610053264524817*CF*NC*NH*Pi*Log[3]^2)/
        (13947137604*Sqrt[3]) - 
       (CF*NC*(-969*CA*(-43868786351796984359 + 404128005240960000*lm) + 
          2*(323*CF*(-129425392727658757073 + 2975851674956160000*lm) + 
            8400*(323*(-95861497722850273 + 13121039131200*lm)*NM + 
              9*(2401828*(250241653 + 196058800*lm)*NL + (73113803607787 + 
                  470899515486400*lm)*NH))))*Log[x]^2)/26398676304000 + 
       (CF*NC*(-71298773840459*CA + 116802487382606*CF + 
          117600*(7596839541*NM + 2600780*NL))*Log[x]^3)/170100 + 
       (957189169223543021823503*CF^2*NC*PolyGamma[2, 1])/9489632425761600 + 
       (15931420153574*CF*NM*NC*PolyGamma[2, 1])/14175 - 
       (32323764769797179056*CF*NC*NH*PolyGamma[2, 1])/4236443047215 - 
       (917339579393728507591051*CF^2*NC*Zeta[3])/4744816212880800 - 
       (5116926268352*CF*NM*NC*Zeta[3])/14175 - (32071832*CF*NC*NL*Zeta[3])/
        9 + (50305908171248189848*CF*NC*NH*Zeta[3])/4236443047215 + 
       CA*CF*NC*(469380908548171587852597857547440057/
          3384223929395838048199680000 + (62698207*lm^2)/60 - 
         (1890099627855028739*Pi^2)/13716864000 + 
         (151938115775710859663*Pi^3)/(120503268898560*Sqrt[3]) + 
         (1720337047*Pi^4)/43200 - (55*lm*(-899559503053 + 865728864*Pi^2))/
          13716864 - (1506746410582686414680459*Im[PolyLog[2, (-1)^(1/3)]])/
          (147616504400736000*Sqrt[3]) + 
         (104716469*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (151938115775710859663*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3254332107600*Sqrt[3]) + (151938115775710859663*Pi*Log[3]^2)/
          (156207941164800*Sqrt[3]) - (957189169223543021823503*
           PolyGamma[2, 1])/18979264851523200 + 
         (950405789630222821795843*Zeta[3])/9489632425761600) + 
       CF*Log[x]*((10424989693791058477099*NM*NC)/876550474800 - 
         (76815810643*lm*NM*NC)/34020 - 429429*lm^2*NM*NC - 
         (22096480722223*NC*NL)/3175200 - (76815810643*lm*NC*NL)/34020 - 
         429429*lm^2*NC*NL - (3245597283105281105160200380709*NC*NH)/
          29160051120336210394320 - (76815810643*lm*NC*NH)/34020 - 
         429429*lm^2*NC*NH + (35435988971*NM*NC*Pi^2)/27 - 
         (48005503*NC*NL*Pi^2)/81 + (658440213058099268*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3486784401*Sqrt[3]) + 
         CF*NC*(18170102131506479992256710868711/7826025662753538240000 - 
           (61395015253*lm)/1260 - 11594583*lm^2 + (18564744679783*Pi^2)/
            90720 + (151938115775710859663*Im[PolyLog[2, (-1)^(1/3)]])/
            (4881498161400*Sqrt[3]) - 3435432*Zeta[3]) + 
         CA*NC*(-3604839605542983181618359979519/3130410265101415296000 + 
           (1049502361193*lm)/68040 + (4723719*lm^2)/2 - 
           (13197026352613*Pi^2)/129600 - (151938115775710859663*
             Im[PolyLog[2, (-1)^(1/3)]])/(9762996322800*Sqrt[3]) + 
           1717716*Zeta[3])), (1182800257824806986427807050984154037054671*
         CF^2*NC)/249400382476826284962075417600000 - 
       (1043816720809*CF^2*lm*NC)/127008 - (59239323*CF^2*lm^2*NC)/8 - 
       (187388229029975011322718712627*CF*NM*NC)/69669478386668160000 - 
       (2036549295643*CF*lm*NM*NC)/3429216 - (2194049*CF*lm^2*NM*NC)/8 + 
       (712295687145879743*CF*NC*NL)/240045120000 - 
       (2036549295643*CF*lm*NC*NL)/3429216 - (2194049*CF*lm^2*NC*NL)/8 + 
       (968235520032682986981542778890757467992679*CF*NC*NH)/
        6109418655030541030553126033280000 - (2036549295643*CF*lm*NC*NH)/
        3429216 - (2194049*CF*lm^2*NC*NH)/8 - 
       (1657416019444454504849*CF^2*NC*Pi^2)/490377888000 + 
       (347633*CF^2*lm*NC*Pi^2)/15 + (507159184876117*CF*NM*NC*Pi^2)/
        510300 + (347633*CF*lm*NM*NC*Pi^2)/405 - 
       (428010252527*CF*NC*NL*Pi^2)/1020600 + (347633*CF*lm*NC*NL*Pi^2)/
        405 + (347633*CF*lm*NC*NH*Pi^2)/405 - 
       (44489500568536826579*CF^2*NC*Pi^3)/(11297181459240*Sqrt[3]) - 
       (26016158680527656921*CF*NC*NH*Pi^3)/(1129718145924*Sqrt[3]) - 
       (242033077*CF^2*NC*Pi^4)/2025 + (19173895776003108585889*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(632642161717440*Sqrt[3]) + 
       (1345880014938185692939*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) - (235130896*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (12711285876724807594*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(87169610025*Sqrt[3]) - 
       (14866376388872946812*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (17433922005*Sqrt[3]) - (6355642938362403797*CF^2*NC*Pi*Log[3]^2)/
        (2092070640600*Sqrt[3]) - (3716594097218236703*CF*NC*NH*Pi*Log[3]^2)/
        (209207064060*Sqrt[3]) - 
       (CF*NC*(-19*CA*(14137642011761609096383 + 16137430506791193600*lm) + 
          8*(152*CF*(442697531667060267421 + 1237814271827733600*lm) + 
            105*(209*(-895849226532371941 + 317540938740480*lm)*NM + 
              21616452*(3894329767 + 3070164160*lm)*NL + 
              3*(3603235792382617 + 22122018732253440*lm)*NH)))*Log[x]^2)/
        13199338152000 + (CF*NC*(887632370340035*CA - 1817093634871236*CF + 
          1680*(363300718809*NM + 285086672*NL))*Log[x]^3)/170100 - 
       (82010874994817773570278533*CF^2*NC*PolyGamma[2, 1])/
        42703345915927200 + (10261164152537*CF*NM*NC*PolyGamma[2, 1])/9072 - 
       (247033926403620151304177*CF*NC*NH*PolyGamma[2, 1])/
        21351672957963600 + CA*CF*NC*
        (-118479654523417475799360012192931138422503/
          49880076495365256992415083520000 + (24134539*lm^2)/16 + 
         (11592313563577520917*Pi^2)/6858432000 + (44489500568536826579*Pi^3)/
          (22594362918480*Sqrt[3]) + (244814141*Pi^4)/4050 + 
         lm*(35568811139345/6858432 - (3823963*Pi^2)/810) - 
         (19173895776003108585889*Im[PolyLog[2, (-1)^(1/3)]])/
          (1265284323434880*Sqrt[3]) + (117565448*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/15 + (6355642938362403797*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(87169610025*Sqrt[3]) + 
         (6355642938362403797*Pi*Log[3]^2)/(4184141281200*Sqrt[3]) + 
         (82010874994817773570278533*PolyGamma[2, 1])/85406691831854400 - 
         (30028903431212674111932523*Zeta[3])/42703345915927200) + 
       (1210286102519683074649117*CF^2*NC*Zeta[3])/854066918318544 + 
       (11224928168173*CF*NM*NC*Zeta[3])/22680 - 
       (248494207*CF*NC*NL*Zeta[3])/45 + (182189663580696778738063*CF*NC*NH*
         Zeta[3])/10675836478981800 + CF*Log[x]*
        ((2101626093829567900984141*NM*NC)/460587431304000 - 
         (576318245789*lm*NM*NC)/170100 - (1288287*lm^2*NM*NC)/2 - 
         (145496378180809*NC*NL)/13608000 - (576318245789*lm*NC*NL)/
          170100 - (1288287*lm^2*NC*NL)/2 - 
         (1466038438661541774678334477904401*NC*NH)/
          8748015336100863118296000 - (576318245789*lm*NC*NH)/170100 - 
         (1288287*lm^2*NC*NH)/2 + (120972563041*NM*NC*Pi^2)/135 - 
         (744092089*NC*NL*Pi^2)/810 + (14866376388872946812*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(52301766015*Sqrt[3]) + 
         CF*NC*(-89892702293566824472958038413244349/
            3392582124803658827040000 - (115165570091*lm)/1575 - 
           (34783749*lm^2)/2 - (890290046458501*Pi^2)/340200 + 
           (12711285876724807594*Im[PolyLog[2, (-1)^(1/3)]])/
            (261508830075*Sqrt[3]) - 5153148*Zeta[3]) + 
         CA*NC*(719921186020891955446636513364353/54281313996858541232640 + 
           (7873464034579*lm)/340200 + (14171157*lm^2)/4 + 
           (890806097335321*Pi^2)/680400 - (6355642938362403797*
             Im[PolyLog[2, (-1)^(1/3)]])/(261508830075*Sqrt[3]) + 
           2576574*Zeta[3])), (-185278285422951224439587960936599922708503*
         CF^2*NC)/38478916153567483965577350144000 - 
       (1599454651121*CF^2*lm*NC)/129600 - 10981971*CF^2*lm^2*NC - 
       (16677202905296199990831980770747*CF*NM*NC)/492662740020010560000 - 
       (3101788283921*CF*lm*NM*NC)/3499200 - (1220219*CF*lm^2*NM*NC)/3 + 
       (5426283040306397*CF*NC*NL)/1071630000 - (3101788283921*CF*lm*NC*NL)/
        3499200 - (1220219*CF*lm^2*NC*NL)/3 + 
       (21451349829715734181271963792119283128012499*CF*NC*NH)/
        82477151842912303912467201449280000 - (3101788283921*CF*lm*NC*NH)/
        3499200 - (1220219*CF*lm^2*NC*NH)/3 + 
       (9114214115413055895251*CF^2*NC*Pi^2)/2381835456000 + 
       (1002001*CF^2*lm*NC*Pi^2)/30 + (740496521544893*CF*NM*NC*Pi^2)/
        36450 + (1002001*CF*lm*NM*NC*Pi^2)/810 - 
       (95035105451*CF*NC*NL*Pi^2)/145800 + (1002001*CF*lm*NC*NL*Pi^2)/
        810 + (1002001*CF*lm*NC*NH*Pi^2)/810 - 
       (30965883928180569973703*CF^2*NC*Pi^3)/(4880382390391680*Sqrt[3]) - 
       (288561141382676514058*CF*NC*NH*Pi^3)/(7625597484987*Sqrt[3]) - 
       (12226983769*CF^2*NC*Pi^4)/64800 + (1672481179740892281400601*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(34162676732741760*Sqrt[3]) + 
       (57928026581501921002352*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (266895911974545*Sqrt[3]) - (240529289*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - (4423697704025795710529*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(18828635765400*Sqrt[3]) - 
       (659568323160403460704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) - 
       (4423697704025795710529*CF^2*NC*Pi*Log[3]^2)/(903774516739200*
         Sqrt[3]) - (41223020197525216294*CF*NC*NH*Pi*Log[3]^2)/
        (1412147682405*Sqrt[3]) - 
       (CF*NC*(-57*CA*(-1511311145801380430449 + 2537051016214915200*lm) + 
          10*(19*CF*(-904039757951557998107 + 3736384223880147840*lm) + 
            48*(133*(-14400103626576502369 + 411858931203720*lm)*NM + 
              302630328*(229492314 + 181003795*lm)*NL + 
              3*(3137846439805331 + 18259079283364920*lm)*NH)))*Log[x]^2)/
        3771239472000 + (CF*NC*(-141973221750995*CA + 
          14*(19541987099569*CF + 120*(937094007072*NM + 67229981*NL)))*
         Log[x]^3)/24300 + (253881918603098843719612703*CF^2*NC*
         PolyGamma[2, 1])/153732045297337920 + 
       (26882814405953*CF*NM*NC*PolyGamma[2, 1])/2025 - 
       (221292944540216285546293*CF*NC*NH*PolyGamma[2, 1])/
        12010316038854525 - (951925227782422673637148943*CF^2*NC*Zeta[3])/
        384330113243344800 - (11739267278504*CF*NM*NC*Zeta[3])/2025 - 
       (404588002*CF*NC*NL*Zeta[3])/45 + (393589291208751578841934*CF*NC*NH*
         Zeta[3])/12010316038854525 + CA*CF*NC*
        (923926754717705653850466101464368154073549/
          384789161535674839655773501440000 + (13422409*lm^2)/6 - 
         (3748271308396385093*Pi^2)/1959552000 + 
         (30965883928180569973703*Pi^3)/(9760764780783360*Sqrt[3]) + 
         (1372804433*Pi^4)/14400 - (11*lm*(-4913214482321 + 4328644320*Pi^2))/
          6998400 - (1672481179740892281400601*Im[PolyLog[2, (-1)^(1/3)]])/
          (68325353465483520*Sqrt[3]) + (240529289*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/20 + (4423697704025795710529*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(37657271530800*Sqrt[3]) + 
         (4423697704025795710529*Pi*Log[3]^2)/(1807549033478400*Sqrt[3]) - 
         (253881918603098843719612703*PolyGamma[2, 1])/307464090594675840 + 
         (958479107544118489541643047*Zeta[3])/768660226486689600) + 
       CF*Log[x]*((52874645598802564541355469*NM*NC)/361890124596000 - 
         (129271555127*lm*NM*NC)/24300 - 1002001*lm^2*NM*NC - 
         (1228595059372*NC*NL)/70875 - (129271555127*lm*NC*NL)/24300 - 
         1002001*lm^2*NC*NL - (32521615606064459701508147358462721*NC*NH)/
          118098207037361652096996000 - (129271555127*lm*NC*NH)/24300 - 
         1002001*lm^2*NC*NH + (2186368854796*NM*NC*Pi^2)/135 - 
         (605880002*NC*NL*Pi^2)/405 + (659568323160403460704*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(813917193535322098459024376671616819/
            26171347819913939522880000 - (103570229477*lm)/900 - 
           27054027*lm^2 + (188454350711053*Pi^2)/64800 + 
           (4423697704025795710529*Im[PolyLog[2, (-1)^(1/3)]])/
            (56485907296200*Sqrt[3]) - 8016008*Zeta[3]) + 
         CA*NC*(-23220801219207604677676481099615749/
            1495505589709367972736000 + (1762867846597*lm)/48600 + 
           (11022011*lm^2)/2 - (188295067370861*Pi^2)/129600 - 
           (4423697704025795710529*Im[PolyLog[2, (-1)^(1/3)]])/
            (112971814592400*Sqrt[3]) + 4008004*Zeta[3])), 
      (62054882907787664413597463041363732519671920221*CF^2*NC)/
        942596021061854901856768016563200000 - (268867713630097*CF^2*lm*NC)/
        15681600 - (30829617*CF^2*lm^2*NC)/2 - 
       (90493758555098457792972654941059273*CF*NM*NC)/
        3379173733797252431040000 - (524025955768897*CF*lm*NM*NC)/
        423403200 - (3425513*CF*lm^2*NM*NC)/6 + 
       (5442099903853475339*CF*NC*NL)/691558560000 - 
       (524025955768897*CF*lm*NC*NL)/423403200 - (3425513*CF*lm^2*NC*NL)/
        6 + (236106856390471619008709600928374200825133*CF*NC*NH)/
        620128961224904540695242116160000 - (524025955768897*CF*lm*NC*NH)/
        423403200 - (3425513*CF*lm^2*NC*NH)/6 - 
       (1150953472005326130269593*CF^2*NC*Pi^2)/26200190016000 + 
       (1333241*CF^2*lm*NC*Pi^2)/30 + (7364594153261431*CF*NM*NC*Pi^2)/
        801900 + (1333241*CF*lm*NM*NC*Pi^2)/810 - 
       (1517422574681*CF*NC*NL*Pi^2)/1603800 + (1333241*CF*lm*NC*NL*Pi^2)/
        810 + (1333241*CF*lm*NC*NH*Pi^2)/810 - 
       (513369858264443061299663*CF^2*NC*Pi^3)/(53684206294308480*Sqrt[3]) - 
       (1689370614376473686707*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) - 
       (17988371219*CF^2*NC*Pi^4)/64800 + (1464388800385130362800227963*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(20668419423308764800*Sqrt[3]) + 
       (12205155653612445967193*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (38127987424935*Sqrt[3]) - (1047587177*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - (73338551180634723042809*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(207114993419400*Sqrt[3]) - 
       (965354636786556392404*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) - 
       (73338551180634723042809*CF^2*NC*Pi*Log[3]^2)/(9941519684131200*
         Sqrt[3]) - (241338659196639098101*CF*NC*NH*Pi*Log[3]^2)/
        (5648590729620*Sqrt[3]) - 
       (CF*NC*(-3*CA*(3647131706693734772524889 + 802595119128071068800*lm) + 
          10*(CF*(2189139255353102587261687 + 1182003720897704664960*lm) + 
            3696*((-123665515007936678681 + 11844674131169880*lm)*NM + 
              57*(758472*(345546659 + 273973595*lm)*NL + (37208608717487 + 
                  207801300546840*lm)*NH))))*Log[x]^2)/41483634192000 + 
       (CF*NC*(18327545981566895*CA + 66*(-558080690449993*CF + 
            280*(481747796592*NM + 101761621*NL)))*Log[x]^3)/267300 - 
       (2714951490817126524522400753*CF^2*NC*PolyGamma[2, 1])/
        109808603783812800 + (1207428021823853*CF*NM*NC*PolyGamma[2, 1])/
        113400 - (260585397335386583768627*CF*NC*NH*PolyGamma[2, 1])/
        9608252831083620 + CA*CF*NC*
        (-191185351022237823308878062511667496900607899221/
          5806391489741026195437690982029312000 + (37680643*lm^2)/12 + 
         (5208092587947831181757*Pi^2)/237105792000 + 
         (513369858264443061299663*Pi^3)/(107368412588616960*Sqrt[3]) + 
         (224185507*Pi^4)/1600 + lm*(831680869735297/76982400 - 
           (14665651*Pi^2)/1620) - (1464388800385130362800227963*
           Im[PolyLog[2, (-1)^(1/3)]])/(41336838846617529600*Sqrt[3]) + 
         (1047587177*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (73338551180634723042809*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (414229986838800*Sqrt[3]) + (73338551180634723042809*Pi*Log[3]^2)/
          (19883039368262400*Sqrt[3]) + (2714951490817126524522400753*
           PolyGamma[2, 1])/219617207567625600 - 
         (11590006928845093470466537351*Zeta[3])/1207894641621940800) + 
       (11605330170799454883187772167*CF^2*NC*Zeta[3])/603947320810970400 + 
       (267060255531773*CF*NM*NC*Zeta[3])/56700 - 
       (606947432*CF*NC*NL*Zeta[3])/45 + (222958304832813459776821*CF*NC*NH*
         Zeta[3])/4804126415541810 + CF*Log[x]*
        ((1275114722374063785551798441*NM*NC)/32660583744789000 - 
         (2069259793757*lm*NM*NC)/267300 - 1457456*lm^2*NM*NC - 
         (1932109913708537*NC*NL)/74844000 - (2069259793757*lm*NC*NL)/
          267300 - 1457456*lm^2*NC*NL - (89494044584984760254281154681803*NC*
           NH)/221989110972484308453000 - (2069259793757*lm*NC*NH)/267300 - 
         1457456*lm^2*NC*NH + (1123794168581*NM*NC*Pi^2)/135 - 
         (909087907*NC*NL*Pi^2)/405 + (965354636786556392404*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(-34764814461048626683147746270500430914749/
            103926422192878253845356480000 - (1658038583357*lm)/9900 - 
           39351312*lm^2 - (14670529155689149*Pi^2)/427680 + 
           (73338551180634723042809*Im[PolyLog[2, (-1)^(1/3)]])/
            (621344980258200*Sqrt[3]) - 11659648*Zeta[3]) + 
         CA*NC*(993481529002497298259534568694645679531/
            5938652696735900219734656000 + (2565086324957*lm)/48600 + 
           8016008*lm^2 + (73360524836398577*Pi^2)/4276800 - 
           (73338551180634723042809*Im[PolyLog[2, (-1)^(1/3)]])/
            (1242689960516400*Sqrt[3]) + 5829824*Zeta[3])), 
      (-15752599436528854326821965766275709393456720679451*CF^2*NC)/
        217739680865288482328913411826099200000 - (8671474963837*CF^2*lm*NC)/
        348480 - (442768599*CF^2*lm^2*NC)/20 - 
       (96346951316563930097438259929888953*CF*NM*NC)/
        225278248919816828736000 - (3362975007329*CF*lm*NM*NC)/1881792 - 
       (16398837*CF*lm^2*NM*NC)/20 + (1767960032129970689*CF*NC*NL)/
        138311712000 - (3362975007329*CF*lm*NC*NL)/1881792 - 
       (16398837*CF*lm^2*NC*NL)/20 + 
       (361407961509042239729108130640042228454716314013*CF*NC*NH)/
        602099703883628401021793064020033856000 - 
       (3362975007329*CF*lm*NC*NH)/1881792 - (16398837*CF*lm^2*NC*NH)/20 + 
       (89180158151926591577173*CF^2*NC*Pi^2)/1746679334400 + 
       (124215*CF^2*lm*NC*Pi^2)/2 + (2213640042968963*CF*NM*NC*Pi^2)/8910 + 
       (41405*CF*lm*NM*NC*Pi^2)/18 - (10110795799*CF*NC*NL*Pi^2)/7128 + 
       (41405*CF*lm*NC*NL*Pi^2)/18 + (41405*CF*lm*NC*NH*Pi^2)/18 - 
       (2385457788542961127093721*CF^2*NC*Pi^3)/(161052618882925440*
         Sqrt[3]) - (7995565181542755273905*CF*NC*NH*Pi^3)/
        (91507169819844*Sqrt[3]) - (3034051111*CF^2*NC*Pi^4)/7200 + 
       (6829561115723014338357107789*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (62005258269926294400*Sqrt[3]) + (394786547427331814314942*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(800687735923635*Sqrt[3]) - 
       (517817391*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (340779684077565875299103*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(621344980258200*Sqrt[3]) - 
       (913778877890600602732*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (340779684077565875299103*CF^2*NC*Pi*Log[3]^2)/(29824559052393600*
         Sqrt[3]) - (228444719472650150683*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) + CF*((281994680996582453771933*CF*NC)/
          460929268800 - 450877518*CF*lm*NC + 
         CA*(-1410739544488280515230793/4609292688000 + (275536261*lm)/3)*
          NC + (6759956289131758417*NM*NC)/2267460 - (50097502*lm*NM*NC)/
          3 - (947663548*NC*NL)/45 - (50097502*lm*NC*NL)/3 - 
         (2511794957086183*NC*NH)/803134332 - (50097502*lm*NC*NH)/3)*
        Log[x]^2 + (CF*NC*(-7035602122795231*CA + 
          90*(155254429273157*CF + 3080*(255404710794*NM + 3578393*NL)))*
         Log[x]^3)/89100 + (55418472375202542554222395411*CF^2*NC*
         PolyGamma[2, 1])/2305980679460068800 + 
       (148414947270332*CF*NM*NC*PolyGamma[2, 1])/945 - 
       (3002327424389006523589547*CF*NC*NH*PolyGamma[2, 1])/
        72061896233127150 - (389959054167260055048188724493*CF^2*NC*Zeta[3])/
        12682893737030378400 - (78511440290876*CF*NM*NC*Zeta[3])/945 - 
       (63297416*CF*NC*NL*Zeta[3])/3 + (2943257970233858151394753*CF*NC*NH*
         Zeta[3])/36030948116563575 + CA*CF*NC*
        (15746065354303868424165750430973218744582630041223/
          435479361730576964657826823652198400000 + (180387207*lm^2)/40 - 
         (6859741609158500081753*Pi^2)/268719897600 + 
         (2385457788542961127093721*Pi^3)/(322105237765850880*Sqrt[3]) + 
         (1020183437*Pi^4)/4800 + lm*(26633711488069/1710720 - 
           (455455*Pi^2)/36) - (6829561115723014338357107789*
           Im[PolyLog[2, (-1)^(1/3)]])/(124010516539852588800*Sqrt[3]) + 
         (517817391*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (340779684077565875299103*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1242689960516400*Sqrt[3]) + (340779684077565875299103*Pi*Log[3]^2)/
          (59649118104787200*Sqrt[3]) - (55418472375202542554222395411*
           PolyGamma[2, 1])/4611961358920137600 + 
         (390454200806653737462357549133*Zeta[3])/25365787474060756800) + 
       CF*Log[x]*((2558881038132429330428264407*NM*NC)/1451581499768400 - 
         (13905215857*lm*NM*NC)/1188 - 2186184*lm^2*NM*NC - 
         (66909152064637*NC*NL)/1663200 - (13905215857*lm*NC*NL)/1188 - 
         2186184*lm^2*NC*NL - (5959968300807645755019922481033007493*NC*NH)/
          9371092728414647093896632600 - (13905215857*lm*NC*NH)/1188 - 
         2186184*lm^2*NC*NH + (595935594737*NM*NC*Pi^2)/3 - 
         (31607303*NC*NL*Pi^2)/9 + (913778877890600602732*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(24873582091635609034881422379441303265921/
            62355853315726952307213888000 - (11163741121*lm)/44 - 
           59026968*lm^2 + (28119857075773913*Pi^2)/712800 + 
           (340779684077565875299103*Im[PolyLog[2, (-1)^(1/3)]])/
            (1864034940774600*Sqrt[3]) - 17489472*Zeta[3]) + 
         CA*NC*(-124335708285984084026874182670825362260553/
            623558533157269523072138880000 + (17210726065*lm)/216 + 
           12024012*lm^2 - (9371921822657203*Pi^2)/475200 - 
           (340779684077565875299103*Im[PolyLog[2, (-1)^(1/3)]])/
            (3728069881549200*Sqrt[3]) + 8744736*Zeta[3])), 
      (3474428503803212258527097657193949665422092499938171*CF^2*NC)/
        3919314255575192681920441412869785600000 - 
       (84803549022091*CF^2*lm*NC)/2509056 - (2427040161*CF^2*lm^2*NC)/80 - 
       (43801989867389836687925303234260452661*CF*NM*NC)/
        170310356183381522524416000 - (825760848880463*CF*lm*NM*NC)/
        338722560 - (269671129*CF*lm^2*NM*NC)/240 + 
       (125424393291345753361*CF*NC*NL)/6535228392000 - 
       (825760848880463*CF*lm*NC*NL)/338722560 - (269671129*CF*lm^2*NC*NL)/
        240 + (18585217730788357462594104553252951004846224987633*CF*NC*NH)/
        21675589339810622436784550304721218816000 - 
       (825760848880463*CF*lm*NC*NH)/338722560 - (269671129*CF*lm^2*NC*NH)/
        240 - (731261333240450860498927*CF^2*NC*Pi^2)/1310009500800 + 
       (1946035*CF^2*lm*NC*Pi^2)/24 + (719040184108819403*CF*NM*NC*Pi^2)/
        8981280 + (1946035*CF*lm*NM*NC*Pi^2)/648 - 
       (257381570173*CF*NC*NL*Pi^2)/128304 + (1946035*CF*lm*NC*NL*Pi^2)/
        648 + (1946035*CF*lm*NC*NH*Pi^2)/648 - 
       (1962243130614208713784037*CF^2*NC*Pi^3)/(90592098121645560*Sqrt[3]) - 
       (411127938127705678607315*CF*NC*NH*Pi^3)/(3294258113514384*Sqrt[3]) - 
       (2441819107*CF^2*NC*Pi^4)/4050 + (5436592474828323399237156509*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(34877957776833540600*Sqrt[3]) + 
       (40870569871486294142661929*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (57649516986501720*Sqrt[3]) - (366142504*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (560640894461202489652582*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(699013102790475*Sqrt[3]) - 
       (11746512517934447960209*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (280320447230601244826291*CF^2*NC*Pi*Log[3]^2)/(16776314466971400*
         Sqrt[3]) - (11746512517934447960209*CF*NC*NH*Pi*Log[3]^2)/
        (122009559759792*Sqrt[3]) - 
       (CF*NC*(-46*CA*(8684787295702147884498119 + 350076671623755326250*
             lm) + 5*(46*CF*(3474166176123548568286171 + 
              343711641230596138500*lm) + 165*(69*(-2012702791745283695983 + 
                51434589035629800*lm)*NM + 1740124386*(2560470271 + 
                2039501700*lm)*NL + (688805669995659871 + 
                3548986643458456200*lm)*NH)))*Log[x]^2)/119265448302000 + 
       (CF*NC*(469945941129579267*CA + 40*(-23519657584421932*CF + 
            3969716755982010*NM + 218736557325*NL))*Log[x]^3)/534600 - 
       (101737533819664613266370277997*CF^2*NC*PolyGamma[2, 1])/
        324278533049072175 + (7358715960048737*CF*NM*NC*PolyGamma[2, 1])/
        75600 - (155057852465187778672869643*CF*NC*NH*PolyGamma[2, 1])/
        2594228264392577400 + CA*CF*NC*
        (-3474601539767254733147743794029168326478332374961033/
          7838628511150385363840882825739571200000 + (2966382419*lm^2)/480 + 
         (351569758661165697313*Pi^2)/1259624520 + 
         (1962243130614208713784037*Pi^3)/(181184196243291120*Sqrt[3]) + 
         (2461279457*Pi^4)/8100 + lm*(1310159232373487/61585920 - 
           (21406385*Pi^2)/1296) - (5436592474828323399237156509*
           Im[PolyLog[2, (-1)^(1/3)]])/(69755915553667081200*Sqrt[3]) + 
         (183071252*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (280320447230601244826291*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (699013102790475*Sqrt[3]) + (280320447230601244826291*Pi*Log[3]^2)/
          (33552628933942800*Sqrt[3]) + (101737533819664613266370277997*
           PolyGamma[2, 1])/648557066098144350 - 
         (7184479458194990928318902615971*Zeta[3])/57073021816636702800) + 
       (898261720293909475693092565892*CF^2*NC*Zeta[3])/3567063863539793925 + 
       (1751024327892137*CF*NM*NC*Zeta[3])/37800 - 
       (831054146*CF*NC*NL*Zeta[3])/27 + (147608438091871576433519657*CF*NC*
         NH*Zeta[3])/1297114132196288700 + CF*Log[x]*
        ((5278995844132953812414708879*NM*NC)/18289926897081840 - 
         (3547560142399*lm*NM*NC)/213840 - 3097094*lm^2*NM*NC - 
         (219980628007161419*NC*NL)/3772137600 - (3547560142399*lm*NC*NL)/
          213840 - 3097094*lm^2*NC*NL - 
         (613037793695177984465629794200325386543*NC*NH)/
          674718676445854590760557547200 - (3547560142399*lm*NC*NH)/213840 - 
         3097094*lm^2*NC*NH + (24057477862777*NM*NC*Pi^2)/324 - 
         (61487491*NC*NL*Pi^2)/12 + (11746512517934447960209*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(-1161939693575920296695379990009373156697959/
            280601339920771285382462496000 - (2848484084719*lm)/7920 - 
           83621538*lm^2 - (156665336839406963*Pi^2)/356400 + 
           (560640894461202489652582*Im[PolyLog[2, (-1)^(1/3)]])/
            (2097039308371425*Sqrt[3]) - 24776752*Zeta[3]) + 
         CA*NC*(1659973849701202367434065061179379107243457/
            801718114059346529664178560000 + (4390465245439*lm)/38880 + 
           17034017*lm^2 + (156668319656926139*Pi^2)/712800 - 
           (280320447230601244826291*Im[PolyLog[2, (-1)^(1/3)]])/
            (2097039308371425*Sqrt[3]) + 12388376*Zeta[3])), 
      (-142095358528222776680562288390264508626236288639857*CF^2*NC)/
        139975509127685452925730050459635200000 - (37371239587423*CF^2*lm*NC)/
        784080 - (212001426*CF^2*lm^2*NC)/5 - 
       (322364872427036435391851142971831101*CF*NM*NC)/
        60479529894666733851000 - (72463411630351*CF*lm*NM*NC)/21170160 - 
       (23555714*CF*lm^2*NM*NC)/15 + (4918414799135762497*CF*NC*NL)/
        164314313856 - (72463411630351*CF*lm*NC*NL)/21170160 - 
       (23555714*CF*lm^2*NC*NL)/15 + 
       (24460484380879058727321874886537810576056842251*CF*NC*NH)/
        18724075820131632882284309957500500000 - 
       (72463411630351*CF*lm*NC*NH)/21170160 - (23555714*CF*lm^2*NC*NH)/
        15 + (2345647062749228997823699*CF^2*NC*Pi^2)/3555740073600 + 
       (331240*CF^2*lm*NC*Pi^2)/3 + (1684363797697963021*CF*NM*NC*Pi^2)/
        561330 + (331240*CF*lm*NM*NC*Pi^2)/81 - (23390529227*CF*NC*NL*Pi^2)/
        8019 + (331240*CF*lm*NC*NL*Pi^2)/81 + (331240*CF*lm*NC*NH*Pi^2)/
        81 - (734907776697226333940557*CF^2*NC*Pi^3)/(22648024530411390*
         Sqrt[3]) - (39162760928649905985340*CF*NC*NH*Pi^3)/
        (205891132094649*Sqrt[3]) - (1793432914*CF^2*NC*Pi^4)/2025 + 
       (32724463765417225069176663151*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (139511831107334162400*Sqrt[3]) + (12003821478050345195151514*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(11324012265205695*Sqrt[3]) - 
       (1582174048*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (839894601939687238789208*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(699013102790475*Sqrt[3]) - 
       (17902976424525671307584*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (104986825242460904848651*CF^2*NC*Pi*Log[3]^2)/(4194078616742850*
         Sqrt[3]) - (1118936026532854456724*CF*NC*NH*Pi*Log[3]^2)/
        (7625597484987*Sqrt[3]) + CF*((2931322895326799828747*CF*NC)/
          370389591 - 1012133304*CF*lm*NC + 
         CA*(-20521200200065358229588583/5185454274000 + (618525908*lm)/3)*
          NC + (1571694395423077786853*NM*NC)/43648605 - 
         (112459256*lm*NM*NC)/3 - (1270779770*NC*NL)/27 - 
         (112459256*lm*NC*NL)/3 - (151037784647297*NC*NH)/19980675 - 
         (112459256*lm*NC*NH)/3)*Log[x]^2 + 
       (2*CF*NC*(-34497553158658087*CA + 68906167572399285*CF + 
          322142784435021000*NM + 835009975800*NL)*Log[x]^3)/66825 + 
       (1702361938567042869722506703143*CF^2*NC*PolyGamma[2, 1])/
        5188456528785154800 + (973461276005228*CF*NM*NC*PolyGamma[2, 1])/
        525 - (28869578366495299753515142*CF*NC*NH*PolyGamma[2, 1])/
        324278533049072175 - (429100769825831709821082359431*CF^2*NC*Zeta[3])/
        1141460436332734056 - (1751432450827832*CF*NM*NC*Zeta[3])/1575 - 
       (1256720920*CF*NC*NL*Zeta[3])/27 + (60976282674280941274116916*CF*NC*
         NH*Zeta[3])/324278533049072175 + 
       CA*CF*NC*(497301273931932215035547507043489228694768233392351/
          979828563893798170480110353217446400000 + (129556427*lm^2)/15 - 
         (66475404727602415057489*Pi^2)/201539923200 + 
         (734907776697226333940557*Pi^3)/(45296049060822780*Sqrt[3]) + 
         (903341257*Pi^4)/2025 + lm*(22955100847427/769824 - 
           (1821820*Pi^2)/81) - (32724463765417225069176663151*
           Im[PolyLog[2, (-1)^(1/3)]])/(279023662214668324800*Sqrt[3]) + 
         (791087024*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (419947300969843619394604*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (699013102790475*Sqrt[3]) + (104986825242460904848651*Pi*Log[3]^2)/
          (8388157233485700*Sqrt[3]) - (1702361938567042869722506703143*
           PolyGamma[2, 1])/10376913057570309600 + 
         (2145985534245351048786664483127*Zeta[3])/11414604363327340560) + 
       CF*Log[x]*((1915899718339996643093195313851*NM*NC)/
          91449634485409200 - (324724874552*lm*NM*NC)/13365 - 
         4504864*lm^2*NM*NC - (2604712829364607*NC*NL)/29638224 - 
         (324724874552*lm*NC*NL)/13365 - 4504864*lm^2*NC*NL - 
         (2582625833919602942918307840455336411*NC*NH)/
          1865100277658819633902470000 - (324724874552*lm*NC*NH)/13365 - 
         4504864*lm^2*NC*NH + (195237579691184*NM*NC*Pi^2)/81 - 
         (69744220*NC*NL*Pi^2)/9 + (17902976424525671307584*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(99762902409726185868735080633290304924111/
            20042952851483663241604464000 - (261172505672*lm)/495 - 
           121631328*lm^2 + (68985498866522533*Pi^2)/133650 + 
           (839894601939687238789208*Im[PolyLog[2, (-1)^(1/3)]])/
            (2097039308371425*Sqrt[3]) - 36038912*Zeta[3]) + 
         CA*NC*(-39676663238096660615686388481454567203997/
            15943257950043823033094460000 + (200676305596*lm)/1215 + 
           24776752*lm^2 - (34491906712514657*Pi^2)/133650 - 
           (419947300969843619394604*Im[PolyLog[2, (-1)^(1/3)]])/
            (2097039308371425*Sqrt[3]) + 18019456*Zeta[3])), 
      (2696448056769930244644905160113529576228908634960055108237*CF^2*NC)/
        232470695669468925634514302018135071801600000 - 
       (8411710670438599*CF^2*lm*NC)/132509520 - (284544036*CF^2*lm^2*NC)/5 - 
       (1679456487373492507641759139474180978619*CF*NM*NC)/
        711595502638462563377256000 - (16371611547718951*CF*lm*NM*NC)/
        3577757040 - (10538668*CF*lm^2*NM*NC)/5 + 
       (30304113744450721420573*CF*NC*NL)/694227976041600 - 
       (16371611547718951*CF*lm*NC*NL)/3577757040 - 
       (10538668*CF*lm^2*NC*NL)/5 + 
       (3012418664364313184006287418478069374113502889439*CF*NC*NH)/
        1649420860882504751175772395347089500000 - 
       (16371611547718951*CF*lm*NC*NH)/3577757040 - 
       (10538668*CF*lm^2*NC*NH)/5 - (2248761887876259342670449871*CF^2*NC*
         Pi^2)/323572346697600 + (425320*CF^2*lm*NC*Pi^2)/3 + 
       (660782060621611531*CF*NM*NC*Pi^2)/1042470 + 
       (425320*CF*lm*NM*NC*Pi^2)/81 - (420417646535*CF*NC*NL*Pi^2)/104247 + 
       (425320*CF*lm*NC*NL*Pi^2)/81 + (425320*CF*lm*NC*NH*Pi^2)/81 - 
       (29702467004317524624787727*CF^2*NC*Pi^3)/(642380332135304880*
         Sqrt[3]) - (164248177388294240929940*CF*NC*NH*Pi^3)/
        (617673396283947*Sqrt[3]) - (5009748919*CF^2*NC*Pi^4)/4050 + 
       (2092568024183927226327883793221*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6430227124674401848800*Sqrt[3]) + (50642364042151287521507738*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(33972036795617085*Sqrt[3]) - 
       (729050168*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (4243209572045360660683961*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2478319182620775*Sqrt[3]) - 
       (75084881091791652996544*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (4243209572045360660683961*CF^2*NC*Pi*Log[3]^2)/(118959320765797200*
         Sqrt[3]) - (4692805068236978312284*CF*NC*NH*Pi*Log[3]^2)/
        (22876792454961*Sqrt[3]) - 
       (CF*NC*(-243*CA*(266062887151521760879238733 + 1885538914336669592000*
             lm) + 10*(CF*(12930821379196836934334077871 + 
              224927651217507076238400*lm) + 24024*
             (45*(-1090858454464091441171 + 7705862423499240*lm)*NM + 
              6214729950*(69784405 + 55797084*lm)*NL + (72147840170420101 + 
                346763809057465800*lm)*NH)))*Log[x]^2)/1550450827926000 + 
       (CF*NC*(9584044132262274479*CA + 130*(-147473086887160751*CF + 
            9240*(1779790844911*NM + 25905789*NL)))*Log[x]^3)/868725 - 
       (322529811671834210227540160291*CF^2*NC*PolyGamma[2, 1])/
        82356452837859600 + (4037064787802138*CF*NM*NC*PolyGamma[2, 1])/
        4725 - (26998188649622288163709099*CF*NC*NH*PolyGamma[2, 1])/
        216185688699381450 + CA*CF*NC*
        (-2696470172088780441309052745603203700956706091431328409291/
          464941391338937851269028604036270143603200000 + (57962674*lm^2)/5 + 
         (118355988401669817114749437*Pi^2)/34060247020800 + 
         (29702467004317524624787727*Pi^3)/(1284760664270609760*Sqrt[3]) + 
         (560419391*Pi^4)/900 + lm*(25969195380612007/650501280 - 
           (2339260*Pi^2)/81) - (2092568024183927226327883793221*
           Im[PolyLog[2, (-1)^(1/3)]])/(12860454249348803697600*Sqrt[3]) + 
         (364525084*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (4243209572045360660683961*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4956638365241550*Sqrt[3]) + (4243209572045360660683961*Pi*
           Log[3]^2)/(237918641531594400*Sqrt[3]) + 
         (322529811671834210227540160291*PolyGamma[2, 1])/
          164712905675719200 - (18844106508899904136096610451383*Zeta[3])/
          11776972755813922800) + (18844810144627562570996413600343*CF^2*NC*
         Zeta[3])/5888486377906961400 + (2261815301068276*CF*NM*NC*Zeta[3])/
        4725 - (1789250680*CF*NC*NL*Zeta[3])/27 + 
       (27858080018558681906583701*CF*NC*NH*Zeta[3])/108092844349690725 + 
       CF*Log[x]*((10550756671153125514087941257789*NM*NC)/
          6910979520397352400 - (5847994329896*lm*NM*NC)/173745 - 
         6237504*lm^2*NM*NC - (239725882887539927*NC*NL)/1926484560 - 
         (5847994329896*lm*NC*NL)/173745 - 6237504*lm^2*NC*NL - 
         (3499124187078269970178057946373020158169*NC*NH)/
          1807282169051396225251493430000 - (5847994329896*lm*NC*NH)/
          173745 - 6237504*lm^2*NC*NH + (49833456816080*NM*NC*Pi^2)/81 - 
         (99308300*NC*NL*Pi^2)/9 + (75084881091791652996544*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-9101796728551554466752005878625916649695547427/
            180908945122044762147674492343000 - (4704051690056*lm)/6435 - 
           168412608*lm^2 - (6389482797575654357*Pi^2)/1158300 + 
           (4243209572045360660683961*Im[PolyLog[2, (-1)^(1/3)]])/
            (7434957547862325*Sqrt[3]) - 49900032*Zeta[3]) + 
         CA*NC*(52010590528297794390900978373995641067344847473/
            2067530801394797281687708483920000 + (3613646794708*lm)/15795 + 
           34306272*lm^2 + (709944842986764529*Pi^2)/257400 - 
           (4243209572045360660683961*Im[PolyLog[2, (-1)^(1/3)]])/
            (14869915095724650*Sqrt[3]) + 24950016*Zeta[3])), 
      (-113808301792508032036652907438980315999982561290496866453681*CF^2*NC)/
        8368945044100881322842514872652862584857600000 - 
       (11573664452855047*CF^2*lm*NC)/132509520 - (388484901*CF^2*lm^2*NC)/
        5 - (4238658379086509914085356408177686023501849*CF*NM*NC)/
        64755190740100093267330296000 - (22441231201926079*CF*lm*NM*NC)/
        3577757040 - (43164989*CF*lm^2*NM*NC)/15 + 
       (45677406165494387864263*CF*NC*NL)/694227976041600 - 
       (22441231201926079*CF*lm*NC*NL)/3577757040 - 
       (43164989*CF*lm^2*NC*NL)/15 + 
       (16969618109746560378843072083003183105913740279599*CF*NC*NH)/
        6280487124129537321784671813052379250000 - 
       (22441231201926079*CF*lm*NC*NH)/3577757040 - 
       (43164989*CF*lm^2*NC*NH)/15 + (537134692447436985867974339*CF^2*NC*
         Pi^2)/64714469339520 + (566440*CF^2*lm*NC*Pi^2)/3 + 
       (52219729636261692347*CF*NM*NC*Pi^2)/1459458 + 
       (566440*CF*lm*NM*NC*Pi^2)/81 - (595472776562*CF*NC*NL*Pi^2)/104247 + 
       (566440*CF*lm*NC*NL*Pi^2)/81 + (566440*CF*lm*NC*NH*Pi^2)/81 - 
       (8562228355164832321029052577*CF^2*NC*Pi^3)/(127191305762790366240*
         Sqrt[3]) - (2187230130678346248131840*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (14311912111*CF^2*NC*Pi^4)/8100 + 
       (18946103808291691319483770589387*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (39787030333922861439450*Sqrt[3]) + (60368753871135327780356614*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(27795302832777615*Sqrt[3]) - 
       (3072467188*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (1223175479309261760147007511*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(490707198158913450*
         Sqrt[3]) - (999876631167243999145984*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (1223175479309261760147007511*CF^2*NC*Pi*Log[3]^2)/
        (23553945511627845600*Sqrt[3]) - (62492289447952749946624*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) - 
       (CF*NC*(CA*(154422168734448475571359506139 - 1357264435636036719792000*
             lm) + 40*(25*CF*(-308839399915542220322899141 + 
              6662934502213271169888*lm) + 
            1716*(15*(-1293133968938189993482331 + 239680800246527640*lm)*
               NM + 91*(8126954550*(6081275 + 4861332*lm)*NL + 
                7*(1213694942925709 + 5643974888065800*lm)*NH))))*Log[x]^2)/
        3100901655852000 + (CF*NC*(-22801177930027884619*CA + 
          300*(151972845983169925*CF + 1144*(584956733180611*NM + 
              268588593*NL)))*Log[x]^3)/1737450 + 
       (601094308049977037255944074620591*CF^2*NC*PolyGamma[2, 1])/
        140088326277199179600 + (102926307513315646*CF*NM*NC*
         PolyGamma[2, 1])/4725 - (226520324746785576163933334*CF*NC*NH*
         PolyGamma[2, 1])/1250788627474992675 - 
       (9096788598638316111323695632071323*CF^2*NC*Zeta[3])/
        2003263065763948268280 - (67124689089657508*CF*NM*NC*Zeta[3])/4725 - 
       (2628143560*CF*NC*NL*Zeta[3])/27 + (507375998465185993746981332*CF*NC*
         NH*Zeta[3])/1250788627474992675 + 
       CA*CF*NC*(4064540616656101039581985754220418333230802754155691344061/
          597781788864348665917322490903775898918400000 + 
         (474814879*lm^2)/30 - (2821082745200439330330301*Pi^2)/
          679773837600 + (8562228355164832321029052577*Pi^3)/
          (254382611525580732480*Sqrt[3]) + (14402542511*Pi^4)/16200 + 
         lm*(7108941762649235/130100256 - (3115420*Pi^2)/81) - 
         (18946103808291691319483770589387*Im[PolyLog[2, (-1)^(1/3)]])/
          (79574060667845722878900*Sqrt[3]) + 
         (1536233594*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (1223175479309261760147007511*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (981414396317826900*Sqrt[3]) + (1223175479309261760147007511*Pi*
           Log[3]^2)/(47107891023255691200*Sqrt[3]) - 
         (601094308049977037255944074620591*PolyGamma[2, 1])/
          280176652554398359200 + (9097136295516672118975756946722249*
           Zeta[3])/4006526131527896536560) + 
       CF*Log[x]*((11883177530034261503193139366252421*NM*NC)/
          48376856642781466800 - (8334305396336*lm*NM*NC)/173745 - 
         8836464*lm^2*NM*NC - (351024368522435807*NC*NL)/1926484560 - 
         (8334305396336*lm*NC*NL)/173745 - 8836464*lm^2*NC*NL - 
         (3584111990853023981167998381171330986153*NC*NH)/
          1251195347804812771327956990000 - (8334305396336*lm*NC*NH)/
          173745 - 8836464*lm^2*NC*NH + (2339826042832352*NM*NC*Pi^2)/81 - 
         (145882100*NC*NL*Pi^2)/9 + (999876631167243999145984*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(3165753600906083518733668366275047637857476676153/
            52101776195148891498530253794784000 - (6713719989896*lm)/6435 - 
           238584528*lm^2 + (45601284643614997411*Pi^2)/6949800 + 
           (1223175479309261760147007511*Im[PolyLog[2, (-1)^(1/3)]])/
            (1472121594476740350*Sqrt[3]) - 70691712*Zeta[3]) + 
         CA*NC*(-989290666912558350529521197363309337100221843223/
            32563610121968057186581408621740000 + (5144156340328*lm)/15795 + 
           48600552*lm^2 - (45601101997698869593*Pi^2)/13899600 - 
           (1223175479309261760147007511*Im[PolyLog[2, (-1)^(1/3)]])/
            (2944243188953480700*Sqrt[3]) + 35345856*Zeta[3])), 
      (7877616170160578005075757937006679250657560256487737329973057*CF^2*NC)/
        53256923007914699327179640098700034630912000000 - 
       (74238966241273025*CF^2*lm*NC)/649296648 - (1024027317*CF^2*lm^2*NC)/
        10 - (1311940633159923428656955583410665203577173733*CF*NM*NC)/
        64755190740100093267330296000000 - (722112958522535539*CF*lm*NM*NC)/
        87655047480 - (113780813*CF*lm^2*NM*NC)/30 + 
       (129928694189985190873297*CF*NC*NL)/1388455952083200 - 
       (722112958522535539*CF*lm*NC*NL)/87655047480 - 
       (113780813*CF*lm^2*NC*NL)/30 + 
       (22593360051327959445310416951571724184320155496851001*CF*NC*NH)/
        6096259501821737560345654773202842792000000 - 
       (722112958522535539*CF*lm*NC*NH)/87655047480 - 
       (113780813*CF*lm^2*NC*NH)/30 - (48096234681109624675674952123*CF^2*NC*
         Pi^2)/566251606720800 + (716720*CF^2*lm*NC*Pi^2)/3 + 
       (30129480196736630921*CF*NM*NC*Pi^2)/7297290 + 
       (716720*CF*lm*NM*NC*Pi^2)/81 - (807138579235*CF*NC*NL*Pi^2)/104247 + 
       (716720*CF*lm*NC*NL*Pi^2)/81 + (716720*CF*lm*NC*NH*Pi^2)/81 - 
       (23857321249919921623052432521*CF^2*NC*Pi^3)/(254382611525580732480*
         Sqrt[3]) - (1000050785251275132795560*CF*NC*NH*Pi^3)/
        (1853020188851841*Sqrt[3]) - (39145939423*CF^2*NC*Pi^4)/16200 + 
       (5784481715847120730156779189636091*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8912294794798720962436800*Sqrt[3]) + 
       (305247628727485097858395022*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (101916110386851255*Sqrt[3]) - (1387848414*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (23857321249919921623052432521*
         CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6869900774224788300*Sqrt[3]) - (457166073257725774992256*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (23857321249919921623052432521*CF^2*NC*Pi*Log[3]^2)/
        (329755237162789838400*Sqrt[3]) - (28572879578607860937016*CF*NC*NH*
         Pi*Log[3]^2)/(68630377364883*Sqrt[3]) - 
       (CF*NC*(-(CA*(3160621084383377222111870550083 + 
             3805400121321215328912000*lm)) + 
          80*(CF*(79015699060189006765417978123 + 233513189262892758819600*
               lm) + 429*(9*(-994802952473291790682673 + 2239999129595026800*
                 lm)*NM + 11*(3841833060*(594741853 + 477044820*lm)*NL + 
                (405178992552097117 + 1832726560577749200*lm)*NH))))*
         Log[x]^2)/6201803311704000 + (CF*NC*(3303704974059314831331*CA - 
          440*(15017322426086851333*CF - 5460*(179639076790120*NM + 
              753049323*NL)))*Log[x]^3)/24324300 - 
       (3368465799872211385820042590821587*CF^2*NC*PolyGamma[2, 1])/
        70044163138599589800 + (44404404818383549*CF*NM*NC*PolyGamma[2, 1])/
        6300 - (2907616427143951775532029779*CF*NC*NH*PolyGamma[2, 1])/
        11674027189766598300 + CA*CF*NC*
        (-10831736537058467278299651026318976757539077923675631709694649/
          146456538271765423149744010271425095235008000000 + 
         (1251588943*lm^2)/60 + (22633525222815416585561970379*Pi^2)/
          532942688678400 + (23857321249919921623052432521*Pi^3)/
          (508765223051161464960*Sqrt[3]) + (39375289823*Pi^4)/32400 + 
         lm*(1145229552224329531/15937281360 - (3941960*Pi^2)/81) - 
         (5784481715847120730156779189636091*Im[PolyLog[2, (-1)^(1/3)]])/
          (17824589589597441924873600*Sqrt[3]) + 
         (693924207*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (23857321249919921623052432521*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(13739801548449576600*Sqrt[3]) + 
         (23857321249919921623052432521*Pi*Log[3]^2)/(659510474325579676800*
           Sqrt[3]) + (3368465799872211385820042590821587*PolyGamma[2, 1])/
          140088326277199179600 - (397033926682453076041265966702450311*
           Zeta[3])/20032630657639482682800) + 
       (49629542283889432801778666957967332*CF^2*NC*Zeta[3])/
        1252039416102467667675 + (16462874484147149*CF*NM*NC*Zeta[3])/3150 - 
       (3662650748*CF*NC*NL*Zeta[3])/27 + (3195533510453256015903833021*CF*
         NC*NH*Zeta[3])/5837013594883299150 + 
       CF*Log[x]*((-4106629637065991701898532317896717*NM*NC)/
          2418842832139073340000 - (15843145724381*lm*NM*NC)/243243 - 
         11992344*lm^2*NM*NC - (34078742448418080799*NC*NL)/134853919200 - 
         (15843145724381*lm*NC*NL)/243243 - 11992344*lm^2*NC*NL - 
         (298286979729838146319716361155445416197617*NC*NH)/
          75905851100158641460562724060000 - (15843145724381*lm*NC*NH)/
          243243 - 11992344*lm^2*NC*NH + (359276887731136*NM*NC*Pi^2)/81 - 
         (203321326*NC*NL*Pi^2)/9 + (457166073257725774992256*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-2192093028224752003192181135179563671916156811209727/
            3647124333660422404897117765634880000 - (12764033452145*lm)/
            9009 - 323793288*lm^2 - (104879858375914601873*Pi^2)/1544400 + 
           (23857321249919921623052432521*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) - 95938752*Zeta[3]) + 
         CA*NC*(137005956407904836797647480981501312943461687727549/
            455890541707552800612139720704360000 + (19555759564589*lm)/
            44226 + 65957892*lm^2 + (2202478213476826892219*Pi^2)/64864800 - 
           (23857321249919921623052432521*Im[PolyLog[2, (-1)^(1/3)]])/
            (41219404645348729800*Sqrt[3]) + 47969376*Zeta[3])), 
      (-10304389925020425978809426348714747939644843565643431424257239*CF^2*
         NC)/58582615308706169259897604108570038094003200000 - 
       (12344828045540247*CF^2*lm*NC)/80160080 - (684992781*CF^2*lm^2*NC)/5 - 
       (79139538505515269954904552572319537759612397*CF*NM*NC)/
        99930849907561872326127000000 - (531927647027627*CF*lm*NM*NC)/
        48096048 - (25370103*CF*lm^2*NM*NC)/5 + 
       (320551435292856188475823*CF*NC*NL)/2339805400732800 - 
       (531927647027627*CF*lm*NC*NL)/48096048 - (25370103*CF*lm^2*NC*NL)/
        5 + (21284373174618964704892985944365981293301798713132214431*CF*NC*
         NH)/3982544812230277429266165382061896415734500000 - 
       (531927647027627*CF*lm*NC*NH)/48096048 - (25370103*CF*lm^2*NC*NH)/
        5 + (77102208217391303661263290039*CF^2*NC*Pi^2)/755002142294400 + 
       312120*CF^2*lm*NC*Pi^2 + (37957589111489443157*CF*NM*NC*Pi^2)/90090 + 
       11560*CF*lm*NM*NC*Pi^2 - (289710942397*CF*NC*NL*Pi^2)/27027 + 
       11560*CF*lm*NC*NL*Pi^2 + 11560*CF*lm*NC*NH*Pi^2 - 
       (16941890821179182468458530841*CF^2*NC*Pi^3)/(127191305762790366240*
         Sqrt[3]) - (4326413392448645395985500*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (9097286381*CF^2*NC*Pi^4)/2700 + 
       (1032556431661423252210137368540533*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1114036849349840120304600*Sqrt[3]) + 
       (23734748658578296954636798394*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5564619627122078523*Sqrt[3]) - (1907584348*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (16941890821179182468458530841*
         CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3434950387112394150*Sqrt[3]) - (1977788979405095038164800*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (16941890821179182468458530841*CF^2*NC*Pi*Log[3]^2)/
        (164877618581394919200*Sqrt[3]) - (123611811212818439885300*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((55416828134618724665552588381*CF*NC)/45221482481175 - 
         4345382376*CF*lm*NC + CA*(-4433357926361965239913365671683/
            7235437196988000 + 885170484*lm)*NC + 
         (8459607220275359992505093*NM*NC)/1673196525 - 
         160940088*lm*NM*NC - (7024715146*NC*NL)/35 - 160940088*lm*NC*NL - 
         (592312376470053787*NC*NH)/16174233075 - 160940088*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-660317812247372007193*CA + 
          2080*(634895594744306878*CF + 31185*(85467127247335*NM + 
              6705837*NL)))*Log[x]^3)/4054050 + 
       (22834027656910282924966465306190941*CF^2*NC*PolyGamma[2, 1])/
        420264978831597538800 + (171559330117014746*CF*NM*NC*
         PolyGamma[2, 1])/675 - (1853528954647497684619471454*CF*NC*NH*
         PolyGamma[2, 1])/5253312235394969235 - 
       (1629018867827981340834784216865429749*CF^2*NC*Zeta[3])/
        30048945986459224024200 - (118403099662805708*CF*NM*NC*Zeta[3])/
        675 - 194288376*CF*NC*NL*Zeta[3] + (4353675152704488281927744132*CF*
         NC*NH*Zeta[3])/5253312235394969235 + 
       CA*CF*NC*(52573334562736241255195976200940483747209002007136757757221/
          597781788864348665917322490903775898918400000 + 
         (279071133*lm^2)/10 - (1133855828502287267015526619*Pi^2)/
          22205945361600 + (16941890821179182468458530841*Pi^3)/
          (254382611525580732480*Sqrt[3]) + (9147225581*Pi^4)/5400 + 
         lm*(4212622206332791/43723680 - 63580*Pi^2) - 
         (1032556431661423252210137368540533*Im[PolyLog[2, (-1)^(1/3)]])/
          (2228073698699680240609200*Sqrt[3]) + 
         (953792174*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (16941890821179182468458530841*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(6869900774224788300*Sqrt[3]) + 
         (16941890821179182468458530841*Pi*Log[3]^2)/(329755237162789838400*
           Sqrt[3]) - (22834027656910282924966465306190941*PolyGamma[2, 1])/
          840529957663195077600 + (1629029132969067414179318942874695239*
           Zeta[3])/60097891972918448048400) + 
       CF*Log[x]*((4719127654825462083909056367780707*NM*NC)/
          1659014288161230000 - (4083734764442*lm*NM*NC)/45045 - 
         16604784*lm^2*NM*NC - (3905691030011207999*NC*NL)/10821610800 - 
         (4083734764442*lm*NC*NL)/45045 - 16604784*lm^2*NC*NL - 
         (542591770055837650841652047081158416443736553*NC*NH)/
          95755231162850126202499876401690000 - (4083734764442*lm*NC*NH)/
          45045 - 16604784*lm^2*NC*NH + 341868489296880*NM*NC*Pi^2 - 
         32358276*NC*NL*Pi^2 + (1977788979405095038164800*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(265493488761880470834282084709601440064730847855687/
            364712433366042240489711776563488000 - (9882656391606*lm)/5005 - 
           448329168*lm^2 + (1320630527546682955487*Pi^2)/16216200 + 
           (16941890821179182468458530841*Im[PolyLog[2, (-1)^(1/3)]])/
            (10304851161337182450*Sqrt[3]) - 132838272*Zeta[3]) + 
         CA*NC*(-75527187342647903273106018722719285330158931813/
            207505936143628948844851943880000 + (2517843515581*lm)/4095 + 
           91326312*lm^2 - (440209893144563225407*Pi^2)/10810800 - 
           (16941890821179182468458530841*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) + 66419136*Zeta[3])), 
      (45687670895458463435802351310039278243766341957828266623445447*CF^2*
         NC)/24776482038456556547889024294038080020960000000 - 
       (3580905053506506871*CF^2*lm*NC)/18036018000 - 
       (888416532*CF^2*lm^2*NC)/5 - 
       (33990307716724725648043869528010508217512837207*CF*NM*NC)/
        218548768747837814777239749000000 - (6963643216732528471*CF*lm*NM*
         NC)/486972486000 - (32904316*CF*lm^2*NM*NC)/5 + 
       (301099317411548037595946791*CF*NC*NL)/1579368645494640000 - 
       (6963643216732528471*CF*lm*NC*NL)/486972486000 - 
       (32904316*CF*lm^2*NC*NL)/5 + 
       (1808229317506121495542124843995630790527273011810981925553*CF*NC*NH)/
        250900323170507478043768419069899474191273500000 - 
       (6963643216732528471*CF*lm*NC*NH)/486972486000 - 
       (32904316*CF*lm^2*NC*NH)/5 - (1284531673518517539623625655949*CF^2*NC*
         Pi^2)/1258336903824000 + (1949016*CF^2*lm*NC*Pi^2)/5 + 
       (54412209317181846701*CF*NM*NC*Pi^2)/4054050 + 
       (649672*CF*lm*NM*NC*Pi^2)/45 - (9646691813812*CF*NC*NL*Pi^2)/
        675675 + (649672*CF*lm*NC*NL*Pi^2)/45 + (649672*CF*lm*NC*NH*Pi^2)/
        45 - (9466463714010419155852874863*CF^2*NC*Pi^3)/
        (52032806902959695280*Sqrt[3]) - (52511195989179206974491160*CF*NC*
         NH*Pi^3)/(50031545098999707*Sqrt[3]) - (6106428917*CF^2*NC*Pi^4)/
        1350 + (22666022330781088565817307472162167*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(18229693898451929241348000*Sqrt[3]) + 
       (7237258000777296189079822598798*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1252039416102467667675*Sqrt[3]) - 
       (2539940216*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (9466463714010419155852874863*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1405206976545979425*
         Sqrt[3]) - (24005118166481923188338816*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (9466463714010419155852874863*CF^2*NC*Pi*Log[3]^2)/
        (67449934874207012400*Sqrt[3]) - (1500319885405120199271176*CF*NC*NH*
         Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) - 
       (CF*NC*(-14877*CA*(129580026115255271333529281633 + 
            25742622115954691147200*lm) + 
          2*(1653*CF*(1166220655065038739590793207997 + 
              568677924925180904433600*lm) + 40040*
             (203*(-3118322229946144224707009 + 4283367653607676920*lm)*NM + 
              11*(2571072894*(38227690873 + 30744987140*lm)*NL + 
                (18436375233102301079 + 79047603062032583160*lm)*NH))))*
         Log[x]^2)/314741518068978000 + 
       (4*CF*NC*(832705925568936081790*CA - 1665421164016703802201*CF + 
          20020*(2260165890086001*NM + 3733319867*NL))*Log[x]^3)/2027025 - 
       (732968721591380239179310906488760727*CF^2*NC*PolyGamma[2, 1])/
        1260794936494792616400 + (296083913157628291*CF*NM*NC*
         PolyGamma[2, 1])/5670 - (37570791969395444584892262094*CF*NC*NH*
         PolyGamma[2, 1])/78799683530924538525 + 
       CA*CF*NC*
        (-319813762906710150998108194734810813526093198325903921666092679/
          346870748538391791670446340116533120293440000000 + 
         (180973738*lm^2)/5 + (226682064710348870915341852783*Pi^2)/
          444118907232000 + (9466463714010419155852874863*Pi^3)/
          (104065613805919390560*Sqrt[3]) + (6137613173*Pi^4)/2700 + 
         lm*(11042351432679693271/88540452000 - (3573196*Pi^2)/45) - 
         (22666022330781088565817307472162167*Im[PolyLog[2, (-1)^(1/3)]])/
          (36459387796903858482696000*Sqrt[3]) + 
         (1269970108*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (9466463714010419155852874863*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2810413953091958850*Sqrt[3]) + (9466463714010419155852874863*Pi*
           Log[3]^2)/(134899869748414024800*Sqrt[3]) + 
         (732968721591380239179310906488760727*PolyGamma[2, 1])/
          2521589872989585232800 - (8663124500382035251169726316812200159*
           Zeta[3])/36058735183751068829040) + 
       (43315664450826014924799121369123103099*CF^2*NC*Zeta[3])/
        90146837959377672072600 + (169518796928066659*CF*NM*NC*Zeta[3])/
        2835 - (35867669368*CF*NC*NL*Zeta[3])/135 + 
       (86877342761944591912165180132*CF*NC*NH*Zeta[3])/
        78799683530924538525 + CF*Log[x]*
        ((-2392619696699186254582777459670642249*NM*NC)/
          10884792744625830030000 - (81714868421218*lm*NM*NC)/675675 - 
         22139712*lm^2*NM*NC - (2153877864923604863831*NC*NL)/
          4382752374000 - (81714868421218*lm*NC*NL)/675675 - 
         22139712*lm^2*NC*NL - 
         (6586263102718859931526112404053178214069968627*NC*NH)/
          861797080465651135822498887615210000 - (81714868421218*lm*NC*NH)/
          675675 - 22139712*lm^2*NC*NH + (602710163393984*NM*NC*Pi^2)/27 - 
         (17922140588*NC*NL*Pi^2)/405 + (24005118166481923188338816*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*(-3818095945312270322188393834982306572514457031758127/
            539870378337891474409112827149900000 - (65924549076418*lm)/
            25025 - 597772224*lm^2 - (740183435897292091403*Pi^2)/900900 + 
           (9466463714010419155852874863*Im[PolyLog[2, (-1)^(1/3)]])/
            (4215620929637938275*Sqrt[3]) - 177117696*Zeta[3]) + 
         CA*NC*(1090884739589028365773274679726439802203902997138247/
            308497359050223699662350186942800000 + (50376956877809*lm)/
            61425 + 121768416*lm^2 + (6661651502892059465791*Pi^2)/16216200 - 
           (9466463714010419155852874863*Im[PolyLog[2, (-1)^(1/3)]])/
            (8431241859275876550*Sqrt[3]) + 88558848*Zeta[3])), 
      (-2915744153771720190349800238120364221927077474608129430242405989*CF^2*
         NC)/1318108844445888808347696092442825857115072000000 - 
       (4734206433606036071*CF^2*lm*NC)/18036018000 - 
       (1167584922*CF^2*lm^2*NC)/5 - 
       (2064090520354875336770766670524703567705146413377*CF*NM*NC)/
        218548768747837814777239749000000 - (9179907219435939671*CF*lm*NM*
         NC)/486972486000 - (43243886*CF*lm^2*NM*NC)/5 + 
       (429849858871276366991913371*CF*NC*NL)/1579368645494640000 - 
       (9179907219435939671*CF*lm*NC*NL)/486972486000 - 
       (43243886*CF*lm^2*NC*NL)/5 + 
       (151913669892268282068721134216497216781476296776038552438494621*CF*NC*
         NH)/14949143055145176556803809945022750471264457677000000 - 
       (9179907219435939671*CF*lm*NC*NH)/486972486000 - 
       (43243886*CF*lm^2*NC*NH)/5 + (4652869481388833203135356134917*CF^2*NC*
         Pi^2)/3775010711472000 + (2503896*CF^2*lm*NC*Pi^2)/5 + 
       (19874424552666942588791*CF*NM*NC*Pi^2)/4054050 + 
       (834632*CF*lm*NM*NC*Pi^2)/45 - (13091375777972*CF*NC*NL*Pi^2)/
        675675 + (834632*CF*lm*NC*NL*Pi^2)/45 + (834632*CF*lm*NC*NH*Pi^2)/
        45 - (36180323617856924060802232157*CF^2*NC*Pi^3)/
        (143090218983139162020*Sqrt[3]) - (74037350235004472368926160*CF*NC*
         NH*Pi^3)/(50031545098999707*Sqrt[3]) - (1389579592*CF^2*NC*Pi^4)/
        225 + (348500433646266623248514722453939907*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(200526632882971221654828000*Sqrt[3]) + 
       (1442868834359154173085901772474*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (178862773728923952525*Sqrt[3]) - 
       (3424895616*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (144721294471427696243208928628*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(15457276742005773675*
         Sqrt[3]) - (33845645821716330225794816*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (36180323617856924060802232157*CF^2*NC*Pi*Log[3]^2)/
        (185487320904069284100*Sqrt[3]) - (2115352863857270639112176*CF*NC*
         NH*Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) - 
       (CF*NC*(-13485*CA*(-5350796228038470462905591776951 + 
            1241147001934506360133440*lm) + 
          52*(8091*CF*(-342999612869356491929285469853 + 
              195285367437247504216800*lm) + 
            1540*(899*(-7972943297706871021252729513 + 42269560051352273640*
                 lm)*NM + 16657981280226*(2837375707 + 2281208860*lm)*NL + 
              (9090853229087223381629 + 38000334486165694002360*lm)*NH)))*
         Log[x]^2)/9756987060138318000 + 
       (CF*NC*(-803020467055477068529*CA + 1606030077695590982276*CF + 
          16016*(404699233175397621*NM + 5263074727*NL))*Log[x]^3)/405405 + 
       (845431662549960594506516430289967957*CF^2*NC*PolyGamma[2, 1])/
        1260794936494792616400 + (41702923619348994794*CF*NM*NC*
         PolyGamma[2, 1])/14175 - (52135501333795537678886730884*CF*NC*NH*
         PolyGamma[2, 1])/78799683530924538525 - 
       (11532918385301571481552470189697734373*CF^2*NC*Zeta[3])/
        18029367591875534414520 - (29909908337964522572*CF*NM*NC*Zeta[3])/
        14175 - (50247267608*CF*NC*NL*Zeta[3])/135 + 
       (127356689851907934929995850552*CF*NC*NH*Zeta[3])/
        78799683530924538525 + CA*CF*NC*
        (29752484132375566375644433545538288002266757408284103240074693/
          26900180498895689966279512090669915451328000000 + 
         (237841373*lm^2)/5 - (14405168338170805837638019253*Pi^2)/
          23374679328000 + (36180323617856924060802232157*Pi^3)/
          (286180437966278324040*Sqrt[3]) + (698128324*Pi^4)/225 + 
         lm*(14540273717183000471/88540452000 - (4590476*Pi^2)/45) - 
         (348500433646266623248514722453939907*Im[PolyLog[2, (-1)^(1/3)]])/
          (401053265765942443309656000*Sqrt[3]) + 
         (1712447808*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (72360647235713848121604464314*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(15457276742005773675*Sqrt[3]) + 
         (36180323617856924060802232157*Pi*Log[3]^2)/(370974641808138568200*
           Sqrt[3]) - (845431662549960594506516430289967957*PolyGamma[2, 1])/
          2521589872989585232800 + (57664650227809358935927246454366155733*
           Zeta[3])/180293675918755344145200) + 
       CF*Log[x]*((354471950655954223019390978983828153361*NM*NC)/
          10884792744625830030000 - (111415862729978*lm*NM*NC)/675675 - 
         30046752*lm^2*NM*NC - (3009627449816817901111*NC*NL)/
          4382752374000 - (111415862729978*lm*NC*NL)/675675 - 
         30046752*lm^2*NC*NL - 
         (8923294817129104297922630005043240812048073114347*NC*NH)/
          828186994327490741525421430998216810000 - 
         (111415862729978*lm*NC*NH)/675675 - 30046752*lm^2*NC*NH + 
         (107919794603905216*NM*NC*Pi^2)/27 - (25108610428*NC*NL*Pi^2)/
          405 + (33845645821716330225794816*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*(6400398636201179268245206083718129390015737412292387/
            746002704612359128274410452061680000 - (89986143619178*lm)/
            25025 - 811262304*lm^2 + (803019969719932007807*Pi^2)/810810 + 
           (144721294471427696243208928628*Im[PolyLog[2, (-1)^(1/3)]])/
            (46371830226017321025*Sqrt[3]) - 240374016*Zeta[3]) + 
         CA*NC*(-17601092881639361565578109739405180128210027759161413/
            4103014875367975205509257486339240000 + (68627283556189*lm)/
            61425 + 165257136*lm^2 - (1003774860863025080498*Pi^2)/2027025 - 
           (72360647235713848121604464314*Im[PolyLog[2, (-1)^(1/3)]])/
            (46371830226017321025*Sqrt[3]) + 120187008*Zeta[3])), 
      (3160748337767625865266931207068073332348831462158915945619911676534645\
1*CF^2*NC)/1402793742859234130041830981756570756182377789440000000 - 
       (385326677908196502539*CF^2*lm*NC)/1154305152000 - 
       (23885484687*CF^2*lm^2*NC)/80 - 
       (67369873430481818352343199798839227053560264233808397*CF*NM*NC)/
        71817241882826327102007245316864000000 - 
       (749112526944448544939*CF*lm*NM*NC)/31166239104000 - 
       (884647581*CF*lm^2*NM*NC)/80 + (4694514913511468628555760573*CF*NC*
         NL)/12634949163957120000 - (749112526944448544939*CF*lm*NC*NL)/
        31166239104000 - (884647581*CF*lm^2*NC*NL)/80 + 
       (154945799600352818508090436586866678286008152601372235954611950893*CF*
         NC*NH)/11480941866351495595625326037777472361931103495936000000 - 
       (749112526944448544939*CF*lm*NC*NH)/31166239104000 - 
       (884647581*CF*lm^2*NC*NH)/80 - (243285449617658582320516671553481*
         CF^2*NC*Pi^2)/20133390461184000 + (24725973*CF^2*lm*NC*Pi^2)/40 - 
       (3305088902894912468431*CF*NM*NC*Pi^2)/16216200 + 
       (8241991*CF*lm*NM*NC*Pi^2)/360 - (3295952443585289*CF*NC*NL*Pi^2)/
        129729600 + (8241991*CF*lm*NC*NL*Pi^2)/360 + 
       (8241991*CF*lm*NC*NH*Pi^2)/360 - (9323225945689617939509072170489*
         CF^2*NC*Pi^3)/(27473322044762719107840*Sqrt[3]) - 
       (1180045851259100948672643695*CF*NC*NH*Pi^3)/(600378541187996484*
         Sqrt[3]) - (176161405727*CF^2*NC*Pi^4)/21600 + 
       (22119601888404549166295593326197189491*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(9625278378382618639431744000*Sqrt[3]) + 
       (323423826297210824782502443369547*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(30048945986459224024200*Sqrt[3]) - 
       (8978908717*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (9323225945689617939509072170489*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(741949283616277136400*
         Sqrt[3]) - (134862383001040108419730708*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (9323225945689617939509072170489*CF^2*NC*Pi*Log[3]^2)/
        (35613565613581302547200*Sqrt[3]) - (33715595750260027104932677*CF*NC*
         NH*Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) - 
       (CF*NC*(-31*CA*(730221346173217765484265876539561519 + 
            23338239027018490317155212800*lm) + 
          26*(31*CF*(56170876046097868997146197668813381 + 
              4406520655451043626316019200*lm) + 
            3080*(4123*(2312830395553836671169887537 + 398409502783929848640*
                 lm)*NM + 133263850241808*(15291048253 + 12326241340*lm)*
               NL + (401781047876548075965373 + 1642642379978142765942720*
                 lm)*NH)))*Log[x]^2)/312223585924426176000 + 
       (CF*NC*(634678558987212910428895*CA - 1672*(759185598703746756349*CF + 
            1820*(2047165481784753*NM - 2993515754*NL)))*Log[x]^3)/
        32432400 - (654858745594983251870614135033896877*CF^2*NC*
         PolyGamma[2, 1])/94559620237109446230 + 
       (34572771185049248287*CF*NM*NC*PolyGamma[2, 1])/113400 - 
       (665788210869029578962107798647*CF*NC*NH*PolyGamma[2, 1])/
        756476961896875569840 + CA*CF*NC*
        (-2674479449082894556645026730306334323035541446361020258797854383648\
1397/2373958641761780835455406276818812048924023951360000000 + 
         (9731123391*lm^2)/160 + (2259617186167848686979463801897*Pi^2)/
          373994869248000 + (9323225945689617939509072170489*Pi^3)/
          (54946644089525438215680*Sqrt[3]) + (176952636863*Pi^4)/43200 + 
         lm*(1187744268366149572139/5666588928000 - (90661901*Pi^2)/720) - 
         (22119601888404549166295593326197189491*Im[PolyLog[2, (-1)^(1/3)]])/
          (19250556756765237278863488000*Sqrt[3]) + 
         (8978908717*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (9323225945689617939509072170489*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1483898567232554272800*Sqrt[3]) + 
         (9323225945689617939509072170489*Pi*Log[3]^2)/
          (71227131227162605094400*Sqrt[3]) + 
         (654858745594983251870614135033896877*PolyGamma[2, 1])/
          189119240474218892460 - (883733500903418813984835928591273984051*
           Zeta[3])/309074873003580589963200) + 
       (6186135443936117321594710527120719212249*CF^2*NC*Zeta[3])/
        1081762055512532064871200 + (40018391009675153197*CF*NM*NC*Zeta[3])/
        56700 - (135123412051*CF*NC*NL*Zeta[3])/270 + 
       (802499781532065208970732507969*CF*NC*NH*Zeta[3])/
        378238480948437784920 + CF*Log[x]*
        ((-6375812688287236903597964201859606158377*NM*NC)/
          1401586327001771951040000 - (4681689142256471*lm*NM*NC)/21621600 - 
         39436362*lm^2*NM*NC - (16125437467139419352509*NC*NL)/
          17531009496000 - (4681689142256471*lm*NC*NL)/21621600 - 
         39436362*lm^2*NC*NL - 
         (1137877537204776972145470928814865934848270610283797*NC*NH)/
          79505951455439111186440457375828813760000 - 
         (4681689142256471*lm*NC*NH)/21621600 - 39436362*lm^2*NC*NH - 
         (2593078764115339*NM*NC*Pi^2)/54 - (33762308533*NC*NL*Pi^2)/405 + 
         (134862383001040108419730708*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CF*NC*(-4855642159172446938303542690395214715511594503427178193449/
            59153751603162293962856323645908014400000 - (3781640939602871*lm)/
            800800 - 1064781774*lm^2 - (60445582184612327585809*Pi^2)/
            6177600 + (9323225945689617939509072170489*
             Im[PolyLog[2, (-1)^(1/3)]])/(2225847850848831409200*Sqrt[3]) - 
           315490896*Zeta[3]) + CA*NC*
          (38845138311520295849900257790995968156222159526303774763557/
            946460025650596703405701178334528230400000 + 
           (5766914726317271*lm)/3931200 + 216899991*lm^2 + 
           (1269357243308089082383541*Pi^2)/259459200 - 
           (9323225945689617939509072170489*Im[PolyLog[2, (-1)^(1/3)]])/
            (4451695701697662818400*Sqrt[3]) + 157745448*Zeta[3])), 
      (-943561317561359511726989047520782991372911104660429220456864490187720\
9959*CF^2*NC)/347191451357660447185353167984751262155138502886400000000 - 
       (5011367267592510509*CF^2*lm*NC)/11543051520 - 
       (7725210057*CF^2*lm^2*NC)/20 - 
       (3445895777426351846260420198701412710936553550589169447*CF*NM*NC)/
        31011990813038641248594037750464000000 - 
       (1943538706921107433*CF*lm*NM*NC)/62332478208 - 
       (286118891*CF*lm^2*NM*NC)/20 + (7492626320739277499497277*CF*NC*NL)/
        14439941901665280 - (1943538706921107433*CF*lm*NC*NL)/62332478208 - 
       (286118891*CF*lm^2*NC*NL)/20 + 
       (96380617057346145472957899997313469725053657406754864034278332231*CF*
         NC*NH)/5166423839858173018031396716999862562868996573171200000 - 
       (1943538706921107433*CF*lm*NC*NH)/62332478208 - 
       (286118891*CF*lm^2*NC*NH)/20 + (4064280582019128844097222412530731*
         CF^2*NC*Pi^2)/277840788364339200 + (1564935*CF^2*lm*NC*Pi^2)/2 + 
       (2903607612678422268689*CF*NM*NC*Pi^2)/51480 + 
       (521645*CF*lm*NM*NC*Pi^2)/18 - (43946128286821*CF*NC*NL*Pi^2)/
        1297296 + (521645*CF*lm*NC*NL*Pi^2)/18 + (521645*CF*lm*NC*NH*Pi^2)/
        18 - (8800402395041112109382806412963*CF^2*NC*Pi^3)/
        (19019992184835728613120*Sqrt[3]) - (3669721822404560083056691180*CF*
         NC*NH*Pi^3)/(1350851717672992089*Sqrt[3]) - 
       (78705901283*CF^2*NC*Pi^4)/7200 + 
       (21002278447981500192519571813864477217*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(6663654261957197519606592000*Sqrt[3]) + 
       (99737263339418722558650711591082*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(6761012846953325405445*Sqrt[3]) - 
       (11903648523*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (8800402395041112109382806412963*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(513657196349730325200*
         Sqrt[3]) - (1677587118813513180825915968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (8800402395041112109382806412963*CF^2*NC*Pi*Log[3]^2)/
        (24655545424787055609600*Sqrt[3]) - (104849194925844573801619748*CF*
         NC*NH*Pi*Log[3]^2)/(50031545098999707*Sqrt[3]) + 
       CF*((4419904362301440749400341471502297473*CF*NC)/
          25179321445518240000 - 15714391864*CF*lm*NC + 
         CA*(-4419904657339228041609326525965296713/50358642891036480000 + 
           (86429155252*lm)/27)*NC + (21281419420332499680358561984693*NM*
           NC)/31442709097800 - (15714391864*lm*NM*NC)/27 - 
         (75838474274*NC*NL)/105 - (15714391864*lm*NC*NL)/27 - 
         (28385516484510448517123*NC*NH)/194944796406360 - 
         (15714391864*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-191885607874714240471829*CA + 4*(95942696788023324586117*CF + 
            200200*(1870973043126380937*NM + 3928597966*NL)))*Log[x]^3)/
        8108100 + (1103229405492437219774373468188296301837*CF^2*NC*
         PolyGamma[2, 1])/136165853141437602571200 + 
       (38292491349371491819*CF*NM*NC*PolyGamma[2, 1])/1134 - 
       (364457561886377118764237565896*CF*NC*NH*PolyGamma[2, 1])/
        303941636476423220025 - (2270192058669090387471340205376470694631*
         CF^2*NC*Zeta[3])/304245578112899643245025 - 
       (14094751633352222939*CF*NM*NC*Zeta[3])/567 - 
       (18563199538*CF*NC*NL*Zeta[3])/27 + (920078178454600824932699363108*
         CF*NC*NH*Zeta[3])/303941636476423220025 + 
       CA*CF*NC*(943561282862362384344692637588382289231506669447321706387657\
0261781420959/694382902715320894370706335969502524310277005772800000000 + 
         (3147307801*lm^2)/40 - (2735415646798964192162441155691*Pi^2)/
          373994869248000 + (8800402395041112109382806412963*Pi^3)/
          (38039984369671457226240*Sqrt[3]) + (79039754083*Pi^4)/14400 + 
         lm*(15392307024018373133/56665889280 - (5738095*Pi^2)/36) - 
         (21002278447981500192519571813864477217*Im[PolyLog[2, (-1)^(1/3)]])/
          (13327308523914395039213184000*Sqrt[3]) + 
         (11903648523*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (8800402395041112109382806412963*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1027314392699460650400*Sqrt[3]) + 
         (8800402395041112109382806412963*Pi*Log[3]^2)/
          (49311090849574111219200*Sqrt[3]) - 
         (1103229405492437219774373468188296301837*PolyGamma[2, 1])/
          272331706282875205142400 + (454038483698079119656392537992467375703*
           Zeta[3])/121698231245159857298010) + 
       CF*Log[x]*((2078208433566028722755262301917348145458241*NM*NC)/
          5633298891218660341680000 - (20894030846323*lm*NM*NC)/72072 - 
         52581816*lm^2*NM*NC - (2210112487215688117627*NC*NL)/
          1753100949600 - (20894030846323*lm*NC*NL)/72072 - 
         52581816*lm^2*NC*NL - 
         (707655096026027315446654615562815361427179403823399*NC*NH)/
          35777678154947600033898205819122966192000 - 
         (20894030846323*lm*NC*NH)/72072 - 52581816*lm^2*NC*NH + 
         (1247315360593938418*NM*NC*Pi^2)/27 - (9276904964*NC*NL*Pi^2)/81 + 
         (1677587118813513180825915968*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CF*NC*(1350590042969474621519276048966601958280880225379732705965337/
            13551586730906270980581630507971654208000000 - 
           (50681449836921*lm)/8008 - 1419709032*lm^2 + 
           (1535084713618255571269763*Pi^2)/129729600 + 
           (8800402395041112109382806412963*Im[PolyLog[2, (-1)^(1/3)]])/
            (1540971589049190975600*Sqrt[3]) - 420654528*Zeta[3]) + 
         CA*NC*
          (-14856490030147205844010673212814548672963402027682615901583007/
            298134908079937961572795871175376392576000000 + 
           (25717255664371*lm)/13104 + 289199988*lm^2 - 
           (1535084689723015408638211*Pi^2)/259459200 - 
           (8800402395041112109382806412963*Im[PolyLog[2, (-1)^(1/3)]])/
            (3081943178098381951200*Sqrt[3]) + 210327264*Zeta[3])), 
      (1585246149867650867214868859029875858914814900743595173083467620793755\
7122536807*CF^2*NC)/
        58611356321911020165226851955457774154894476457102873600000000 - 
       (363888755366343839945*CF^2*lm*NC)/667188377856 - 
       (4875853131*CF^2*lm^2*NC)/10 - 
       (17173670047758595319185581036951105599479447790754462123067*CF*NM*
         NC)/10162660401423575775805514764864803264000000 - 
       (3536364284653490996269*CF*lm*NM*NC)/90070431010560 - 
       (180587153*CF*lm^2*NM*NC)/10 + (101718171802225950344926193189*CF*NC*
         NL)/146060012335344307200 - (3536364284653490996269*CF*lm*NC*NL)/
        90070431010560 - (180587153*CF*lm^2*NC*NL)/10 + 
       (631242874203156435504546149731965742681659850819414159797800120873*CF*
         NC*NH)/25832119199290865090156983584999312814344982865856000000 - 
       (3536364284653490996269*CF*lm*NC*NH)/90070431010560 - 
       (180587153*CF*lm^2*NC*NH)/10 - (74040846552747461679553627425527029*
         CF^2*NC*Pi^2)/524810378021529600 + (1911495*CF^2*lm*NC*Pi^2)/2 - 
       (331510751395670163923327*CF*NM*NC*Pi^2)/55135080 + 
       (637165*CF*lm*NM*NC*Pi^2)/18 - (138003488360407*CF*NC*NL*Pi^2)/
        3150576 + (637165*CF*lm*NC*NL*Pi^2)/18 + (637165*CF*lm*NC*NH*Pi^2)/
        18 - (856595110964188578036665323675613*CF^2*NC*Pi^3)/
        (1401139424282898674499840*Sqrt[3]) - 
       (4807596558372070253851571210*CF*NC*NH*Pi^3)/(1350851717672992089*
         Sqrt[3]) - (307252227017*CF^2*NC*Pi^4)/21600 + 
       (4903943702240123077092520308572675197897*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1192159479151104337198188864000*
         Sqrt[3]) + (10093675860770601708048062878733*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(520077911304101954265*Sqrt[3]) - 
       (15386586859*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (122370730137741225433809331953659*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5405630494918590565200*
         Sqrt[3]) - (2197758426684374973189289696*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (122370730137741225433809331953659*CF^2*NC*Pi*Log[3]^2)/
        (259470263756092347129600*Sqrt[3]) - (137359901667773435824330606*CF*
         NC*NH*Pi*Log[3]^2)/(50031545098999707*Sqrt[3]) - 
       (CF*NC*(-219*CA*(102579537388802671353119554087191531883 + 
            515883283491883599671258880000*lm) + 
          14*(CF*(3209274127719042341177830400611242627831 + 
              39615816302435165257872126720000*lm) + 
            1944800*((70328688258281160230814415812037 + 
                754449020796866958763200*lm)*NM + 666319251209040*(
                1401821419 + 1132263580*lm)*NL + (192566082102544861090613 + 
                754449020796866958763200*lm)*NH)))*Log[x]^2)/
        26539004803576224960000 + (CF*NC*(31667533335085942785702971*CA - 
          68*(931398185217443945329299*CF + 200200*(150206522635560807*NM - 
              5224587662*NL)))*Log[x]^3)/137837700 - 
       (3693757475680812646000593424812392807593*CF^2*NC*PolyGamma[2, 1])/
        45388617713812534190400 + (29573477129528956837*CF*NM*NC*
         PolyGamma[2, 1])/56700 - (26768298507452947517670097518629*CF*NC*NH*
         PolyGamma[2, 1])/17020731642679700321400 + 
       CA*CF*NC*(-15852461576703172355611415595988080491125638772131023787380\
108413522272646669807/
          117222712643822040330453703910915548309788952914205747200000000 + 
         (1986458683*lm^2)/20 + (7624343470065857405874549904663213*Pi^2)/
          108084517212672000 + (856595110964188578036665323675613*Pi^3)/
          (2802278848565797348999680*Sqrt[3]) + (308475583817*Pi^4)/43200 + 
         lm*(5606526810830938329901/16376442001920 - (7008815*Pi^2)/36) - 
         (4903943702240123077092520308572675197897*
           Im[PolyLog[2, (-1)^(1/3)]])/(2384318958302208674396377728000*
           Sqrt[3]) + (15386586859*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (122370730137741225433809331953659*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(10811260989837181130400*Sqrt[3]) + 
         (122370730137741225433809331953659*Pi*Log[3]^2)/
          (518940527512184694259200*Sqrt[3]) + 
         (3693757475680812646000593424812392807593*PolyGamma[2, 1])/
          90777235427625068380800 - (9238702163443112300609730402282399673763*
           Zeta[3])/275849324155695676542156) + 
       (230967559471764415687535782030894028133431*CF^2*NC*Zeta[3])/
        3448116551946195956776950 + (239862755971188117337*CF*NM*NC*Zeta[3])/
        28350 - (24584360642*CF*NC*NL*Zeta[3])/27 + 
       (33406970059912789899785346546571*CF*NC*NH*Zeta[3])/
        8510365821339850160700 + CF*Log[x]*
        ((-5072311947476436923826393180199049095025950507*NM*NC)/
          70376803047994723648608240000 - (2299389643609391*lm*NM*NC)/
          6126120 - 68047056*lm^2*NM*NC - (49589973150057383270641*NC*NL)/
          29802716143200 - (2299389643609391*lm*NC*NL)/6126120 - 
         68047056*lm^2*NC*NL - 
         (4635651803243708544094484039043691226215106077916617*NC*NH)/
          178888390774738000169491029095614830960000 - 
         (2299389643609391*lm*NC*NH)/6126120 - 68047056*lm^2*NC*NH - 
         (100137683761187062*NM*NC*Pi^2)/27 - (12286445836*NC*NL*Pi^2)/81 + 
         (2197758426684374973189289696*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CF*NC*
          (-76388632604221577939567114418089634683067849638530017161876651733\
1/811771665550324413035794357898687354252352000000 - (5578098233602893*lm)/
            680680 - 1837270512*lm^2 - (84446756689741908574417559*Pi^2)/
            735134400 + (122370730137741225433809331953659*
             Im[PolyLog[2, (-1)^(1/3)]])/(16216891484755771695600*Sqrt[3]) - 
           544376448*Zeta[3]) + CA*NC*
          (763886329214667051859670775684515794989964344975534129508794625231/
            1623543331100648826071588715797374708504704000000 + 
           (2829944373594671*lm)/1113840 + 374258808*lm^2 + 
           (253340270607207213311171909*Pi^2)/4410806400 - 
           (122370730137741225433809331953659*Im[PolyLog[2, (-1)^(1/3)]])/
            (32433782969511543391200*Sqrt[3]) + 272188224*Zeta[3])), 
      (-850549161646274049066889132456331922742395698127297591509563146280475\
929769261*CF^2*NC)/
        2598533038902459022103653534971034322138178759181900800000000 - 
       (5288048286763752909*CF^2*lm*NC)/7564494080 - 
       (3110068143*CF^2*lm^2*NC)/5 - 
       (69410125188156618187728500452110240694245487398978674647813*CF*NM*
         NC)/53770689954622094051881030501930176000000 - 
       (1139407524537061157*CF*lm*NM*NC)/22693482240 - 
       (115187709*CF*lm^2*NM*NC)/5 + (1474326695190842760570657859*CF*NC*
         NL)/1545608596141209600 - (1139407524537061157*CF*lm*NC*NL)/
        22693482240 - (115187709*CF*lm^2*NC*NL)/5 + 
       (514345237895932670074527665710535451017326253964161713881438161171*CF*
         NC*NH)/15499271519574519054094190150999587688606989719513600000 - 
       (1139407524537061157*CF*lm*NC*NH)/22693482240 - 
       (115187709*CF*lm^2*NC*NH)/5 + (16487910998435756074777781700633169*
         CF^2*NC*Pi^2)/96393742901913600 + (2388015*CF^2*lm*NC*Pi^2)/2 + 
       (210737758177714346110567*CF*NM*NC*Pi^2)/328185 + 
       (88445*CF*lm*NM*NC*Pi^2)/2 - (60378576615397*CF*NC*NL*Pi^2)/
        1050192 + (88445*CF*lm*NC*NL*Pi^2)/2 + (88445*CF*lm*NC*NH*Pi^2)/2 - 
       (10333792468592826112182295518158143*CF^2*NC*Pi^3)/
        (12610254818546088070498560*Sqrt[3]) - 
       (78336428389344930496716733345*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) - (405128963323*CF^2*NC*Pi^4)/21600 + 
       (8501976384792115309269941987500548013421*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1532776473194277004969099968000*
         Sqrt[3]) + (1061688438449189535368956112943029*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40566077081719952432670*Sqrt[3]) - 
       (20092181921*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (1476256066941832301740327931165449*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(48650674454267315086800*
         Sqrt[3]) - (8952734673067992056767626668*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (1476256066941832301740327931165449*CF^2*NC*Pi*Log[3]^2)/
        (2335232373804831124166400*Sqrt[3]) - 
       (2238183668266998014191906667*CF*NC*NH*Pi*Log[3]^2)/
        (600378541187996484*Sqrt[3]) + 
       CF*((134170372144956290021131507509881461399*CF*NC)/
          65367006905360160000 - 28354377996*CF*lm*NC + 
         CA*(-134170373529412837858968865971822078919/130734013810720320000 + 
           5775891814*lm)*NC + (39739712575069940231565090252947*NM*NC)/
          5157269746200 - 1050162148*lm*NM*NC - (11706030986*NC*NL)/9 - 
         1050162148*lm*NC*NL - (658282865835457911067*NC*NH)/
          2406725881560 - 1050162148*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-5481609756159014279062723*CA + 
          4*(2740804382884364660072659*CF + 1562160600*
             (6657959795650815*NM + 2206223*NL)))*Log[x]^3)/19691100 + 
       (4364030453986155017946679683307354639877*CF^2*NC*PolyGamma[2, 1])/
        45388617713812534190400 + (259375210930579157303*CF*NM*NC*
         PolyGamma[2, 1])/675 - (498287208681972686782621078979*CF*NC*NH*
         PolyGamma[2, 1])/236399050592773615575 - 
       (593654019678469527145736941177906579727279*CF^2*NC*Zeta[3])/
        6896233103892391913553900 - (194317067462125326794*CF*NM*NC*Zeta[3])/
        675 - 1229316340*CF*NC*NL*Zeta[3] + (1293633386090462520582185358242*
         CF*NC*NH*Zeta[3])/236399050592773615575 + 
       CA*CF*NC*(850549156973114686808945676236617614732669762260790430005000\
765087483750765761/
          5197066077804918044207307069942068644276357518363801600000000 + 
         (1267064799*lm^2)/10 - (30372467613425466965501374146843457*Pi^2)/
          355134842270208000 + (10333792468592826112182295518158143*Pi^3)/
          (25220509637092176140997120*Sqrt[3]) + (406657292923*Pi^4)/43200 + 
         lm*(360958389265263265/825217536 - (972895*Pi^2)/4) - 
         (8501976384792115309269941987500548013421*
           Im[PolyLog[2, (-1)^(1/3)]])/(3065552946388554009938199936000*
           Sqrt[3]) + (20092181921*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (1476256066941832301740327931165449*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(97301348908534630173600*
           Sqrt[3]) + (1476256066941832301740327931165449*Pi*Log[3]^2)/
          (4670464747609662248332800*Sqrt[3]) - 
         (4364030453986155017946679683307354639877*PolyGamma[2, 1])/
          90777235427625068380800 + 
         (148413508534011147057403380007611511625783*Zeta[3])/
          3448116551946195956776950) + CF*Log[x]*
        ((70048443119365654439954602246702991446995491*NM*NC)/
          16925638058680789718280000 - (432744275567089*lm*NM*NC)/875160 - 
         89311761*lm^2*NM*NC - (8079601436271940847*NC*NL)/3604258944 - 
         (432744275567089*lm*NC*NL)/875160 - 89311761*lm^2*NC*NL - 
         (472049262187877511013425003996743686872173938321073*NC*NH)/
          13416629308105350012711827182171112322000 - 
         (432744275567089*lm*NC*NH)/875160 - 89311761*lm^2*NC*NH + 
         528198143701441675*NM*NC*Pi^2 - (614392835*NC*NL*Pi^2)/3 + 
         (8952734673067992056767626668*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*
          (3739098664814116369729862904496460496034205651995813957788038383/
            3271806981617966734134415235597038149696000000 - 
           (1050719570971527*lm)/97240 - 2411417547*lm^2 + 
           (43852877391342490726998071*Pi^2)/315057600 + 
           (1476256066941832301740327931165449*Im[PolyLog[2, (-1)^(1/3)]])/
            (145952023362801945260400*Sqrt[3]) - 714494088*Zeta[3]) + 
         CA*NC*
          (-41130085125663221141718240307001145117323699498692483129684735913/
            71979753595595268150957135183134839293312000000 + 
           (532223287439329*lm)/159120 + (982429371*lm^2)/2 - 
           (14617625762593577500789789*Pi^2)/210038400 - 
           (1476256066941832301740327931165449*Im[PolyLog[2, (-1)^(1/3)]])/
            (291904046725603890520800*Sqrt[3]) + 357247044*Zeta[3])), 
      (6501969528836853366954191817282506337174165477173664006915456488378277\
086939812801*CF^2*NC)/
        2034651369460625414307160717882319874234193968439428326400000000 - 
       (266093876035480573469*CF^2*lm*NC)/306362010240 - 
       (31047543009*CF^2*lm^2*NC)/40 + 
       (72907621786991283222949386654465885728380037293138006017983*CF*NM*
         NC)/967872419183197692933858549034743168000000 - 
       (517099384501802614901*CF*lm*NM*NC)/8271774276480 - 
       (3449727001*CF*lm^2*NM*NC)/120 + (105240867828298676709361095689*CF*
         NC*NL)/83462864191625318400 - (517099384501802614901*CF*lm*NC*NL)/
        8271774276480 - (3449727001*CF*lm^2*NC*NL)/120 + 
       (97071288389323731340541022227745994951891213923872281138221469*CF*NC*
         NH)/2261206363169036575235482529952201024979203609600000 - 
       (517099384501802614901*CF*lm*NC*NH)/8271774276480 - 
       (3449727001*CF*lm^2*NC*NH)/120 - 
       (126646817725827029933420461119619949*CF^2*NC*Pi^2)/
        77856484651545600 + (4333805*CF^2*lm*NC*Pi^2)/3 - 
       (499426070667222048299291*CF*NM*NC*Pi^2)/4725864 + 
       (4333805*CF*lm*NM*NC*Pi^2)/81 - (86731505447705*CF*NC*NL*Pi^2)/
        1181466 + (4333805*CF*lm*NC*NL*Pi^2)/81 + 
       (4333805*CF*lm*NC*NH*Pi^2)/81 - (16523700685013942848110622116781289*
         CF^2*NC*Pi^3)/(15476221822761108086520960*Sqrt[3]) - 
       (2736551615851261636270048465595*CF*NC*NH*Pi^3)/
        (437675956526049436836*Sqrt[3]) - (780379490611*CF^2*NC*Pi^4)/32400 + 
       (94197258111833430375308335530911396942311*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(13167943337896288815416358816000*
         Sqrt[3]) + (5319505195452477923960787855436927*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(156469154458062673668870*Sqrt[3]) - 
       (38468003497*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (2360528669287706121158660302397327*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59707645921146250333800*
         Sqrt[3]) - (312748756097287044145148396068*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (2360528669287706121158660302397327*CF^2*NC*Pi*Log[3]^2)/
        (2865967004215020016022400*Sqrt[3]) - 
       (78187189024321761036287099017*CF*NC*NH*Pi*Log[3]^2)/
        (16210220612075905068*Sqrt[3]) + 
       CF*((-55504551158927204660426989776534347742313*CF*NC)/
          2843464800383166960000 - 37180575866*CF*lm*NC + 
         CA*(55504551080260770578415296585121907932703/
            5686929600766333920000 + (204493167263*lm)/27)*NC - 
         (117723614933088065436670341834547*NM*NC)/92830855431600 - 
         (37180575866*lm*NM*NC)/27 - (45952654117*NC*NL)/27 - 
         (37180575866*lm*NC*NL)/27 - (44209543328101973*NC*NH)/121041360 - 
         (37180575866*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-13106411461269267556250439*CA + 26212823586911331192164623*
           CF + 1701700*(861742945283344449*NM - 2655755419*NL))*Log[x]^3)/
        4922775 - (743971065203597667084940389718320322529119*CF^2*NC*
         PolyGamma[2, 1])/787816721746888986304800 - 
       (1782631489012659209431*CF*NM*NC*PolyGamma[2, 1])/75600 - 
       (7525787561882678203955571773283913*CF*NC*NH*PolyGamma[2, 1])/
        2757358526114111452066800 + CA*CF*NC*
        (-6501969533642802993305508000153895612723601768824744488775949557707\
808324935403051/
          4069302738921250828614321435764639748468387936878856652800000000 + 
         (37946997011*lm^2)/240 + (33328109930106614752854750549863947*Pi^2)/
          40977097185024000 + (16523700685013942848110622116781289*Pi^3)/
          (30952443645522216173041920*Sqrt[3]) + (87017013979*Pi^4)/7200 + 
         lm*(819747174614305746197/1503958959360 - (47671855*Pi^2)/162) - 
         (94197258111833430375308335530911396942311*
           Im[PolyLog[2, (-1)^(1/3)]])/(26335886675792577630832717632000*
           Sqrt[3]) + (38468003497*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (2360528669287706121158660302397327*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(119415291842292500667600*
           Sqrt[3]) + (2360528669287706121158660302397327*Pi*Log[3]^2)/
          (5731934008430040032044800*Sqrt[3]) + 
         (743971065203597667084940389718320322529119*PolyGamma[2, 1])/
          1575633443493777972609600 - 
         (185225051188868653003756672186487974041486827*Zeta[3])/
          478795612641671781426742200) + 
       (370450103685914902164327644841899182486821961*CF^2*NC*Zeta[3])/
        478795612641671781426742200 + (3847422770217202003769*CF*NM*NC*
         Zeta[3])/37800 - (43360422595*CF*NC*NL*Zeta[3])/27 + 
       (9673244948952005264997681186819287*CF*NC*NH*Zeta[3])/
        1378679263057055726033400 + CF*Log[x]*
        ((-6804959102861394915629648800368712240221825457*NM*NC)/
          6702552671237592728438880000 - (622339928863957*lm*NM*NC)/984555 - 
         (228241167*lm^2*NM*NC)/2 - (3977598002900413855585*NC*NL)/
          1362409880832 - (622339928863957*lm*NC*NL)/984555 - 
         (228241167*lm^2*NC*NL)/2 - 
         (86255225826197505563599028555353387938653175470111*NC*NH)/
          1894731566231288396695491775971860256000 - 
         (622339928863957*lm*NC*NH)/984555 - (228241167*lm^2*NC*NH)/2 - 
         (2010733542101518493*NM*NC*Pi^2)/27 - (43343087375*NC*NL*Pi^2)/
          162 + (312748756097287044145148396068*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CF*NC*
          (-44466810150719845506290030849950583805681776795209825007728262338\
3/41686499308691638285650471041711966839248000000 - (2014959308640493*lm)/
            145860 - (6162511509*lm^2)/2 - (209702583812958397895830201*Pi^2)/
            157528800 + (2360528669287706121158660302397327*
             Im[PolyLog[2, (-1)^(1/3)]])/(179122937763438751001400*Sqrt[3]) - 
           912964668*Zeta[3]) + CA*NC*(37574454601168863846373695726819828815\
000979084911501269113824687201/
            7045018383168886870274929606049322395832912000000 + 
           (382670504215151*lm)/89505 + (2510652837*lm^2)/4 + 
           (209702583880606336896493937*Pi^2)/315057600 - 
           (2360528669287706121158660302397327*Im[PolyLog[2, (-1)^(1/3)]])/
            (358245875526877502002800*Sqrt[3]) + 456482334*Zeta[3])), 
      (-487576352070289756158656763262307282822785358478595049632153892443061\
8051292359*CF^2*NC)/
        1258287798058519118309932416748497139291400104167859200000000 - 
       (5564316477637076909*CF^2*lm*NC)/5063834880 - 
       (9778248711*CF^2*lm^2*NC)/10 - 
       (7172838729471411127695725645335124434349564718671692926881761*CF*NM*
         NC)/483936209591598846466929274517371584000000 - 
       (10790945926934076653*CF*lm*NM*NC)/136723541760 - 
       (1086472079*CF*lm^2*NM*NC)/30 + (46320261732906938767012396601*CF*NC*
         NL)/27285936370339046400 - (10790945926934076653*CF*lm*NC*NL)/
        136723541760 - (1086472079*CF*lm^2*NC*NL)/30 + 
       (202717473144441896062364038228228544668804030337374787225127940828064\
8547*CF*NC*NH)/
        35328807012645365114116485617336195183595443261813507136000000 - 
       (10790945926934076653*CF*lm*NC*NH)/136723541760 - 
       (1086472079*CF*lm^2*NC*NH)/30 + (51887051294866436486573435269175869*
         CF^2*NC*Pi^2)/26289202609612800 + (10701845*CF^2*lm*NC*Pi^2)/6 + 
       (171057576939410179802550139*CF*NM*NC*Pi^2)/23629320 + 
       (10701845*CF*lm*NM*NC*Pi^2)/162 - (81634243292635*CF*NC*NL*Pi^2)/
        859248 + (10701845*CF*lm*NC*NL*Pi^2)/162 + 
       (10701845*CF*lm*NC*NH*Pi^2)/162 - 
       (14542408058563354031201496321279217*CF^2*NC*Pi^3)/
        (10317481215174072057680640*Sqrt[3]) - 
       (609551918745517080644168422075*CF*NC*NH*Pi^3)/(72945992754341572806*
         Sqrt[3]) - (2028041151829*CF^2*NC*Pi^4)/64800 + 
       (83399902145924815088539390375013599308413*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8778628891930859210277572544000*
         Sqrt[3]) + (2156948208835532200048523131807289*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(47743152257716559401527*Sqrt[3]) - 
       (33036510661*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (2077486865509050575885928045897031*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(39805097280764166889200*
         Sqrt[3]) - (139326152856118189861524210760*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) - (2077486865509050575885928045897031*CF^2*NC*Pi*Log[3]^2)/
        (1910644669476680010681600*Sqrt[3]) - 
       (17415769107014773732690526345*CF*NC*NH*Pi*Log[3]^2)/
        (2701703435345984178*Sqrt[3]) + 
       CF*((12244695467596041626851438732759114442023*CF*NC)/
          516993600069666720000 - 49639760506*CF*lm*NC + 
         CA*(-1749242212399583832327645963329005597009/
            147712457162761920000 + (273018682783*lm)/27)*NC + 
         (237184210044378902282315997431497*NM*NC)/2730319277400 - 
         (49639760506*lm*NM*NC)/27 - (61375000933*NC*NL)/27 - 
         (49639760506*lm*NC*NL)/27 - (663327355258412645458187*NC*NH)/
          1335732864265800 - (49639760506*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-5781023650289460666934093*CA + 
          52*(222347057095790652440603*CF + 11900*(69181763278937221968*NM + 
              3545697179*NL)))*Log[x]^3)/1790100 + 
       (4129946193015475286364098729312043924841297*CF^2*NC*PolyGamma[2, 1])/
        3676478034818815269422400 + (20486340305129583387668*CF*NM*NC*
         PolyGamma[2, 1])/4725 - (207058399119821760465464088404734*CF*NC*NH*
         PolyGamma[2, 1])/57444969294043988584725 - 
       (49905655849964902431294786075985299645672239*CF^2*NC*Zeta[3])/
        50781352855934885908896900 - (15525759342044040543614*CF*NM*NC*
         Zeta[3])/4725 - (57636179090*CF*NC*NL*Zeta[3])/27 + 
       (550658113696770670282544195321932*CF*NC*NH*Zeta[3])/
        57444969294043988584725 + CA*CF*NC*(238912412320660101445712048752970\
518048295341108165999016182312435282316194347091/
          123312204209734873594373376841352719650557210208450201600000000 + 
         (11951192869*lm^2)/60 - (95581410273102942544168562760739181*Pi^2)/
          96854956982784000 + (14542408058563354031201496321279217*Pi^3)/
          (20634962430348144115361280*Sqrt[3]) + (678296777543*Pi^4)/43200 + 
         lm*(37604403367916483747/54689416704 - (117720295*Pi^2)/324) - 
         (83399902145924815088539390375013599308413*
           Im[PolyLog[2, (-1)^(1/3)]])/(17557257783861718420555145088000*
           Sqrt[3]) + (33036510661*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (2077486865509050575885928045897031*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(79610194561528333778400*
           Sqrt[3]) + (2077486865509050575885928045897031*Pi*Log[3]^2)/
          (3821289338953360021363200*Sqrt[3]) - 
         (4129946193015475286364098729312043924841297*PolyGamma[2, 1])/
          7352956069637630538844800 + 
         (24952828016727508107501782686854776767053601*Zeta[3])/
          50781352855934885908896900) + CF*Log[x]*
        ((154195123095511571272718080946058704062791075419*NM*NC)/
          3351276335618796364219440000 - (587703821805551*lm*NM*NC)/716040 - 
         147685461*lm^2*NM*NC - (123220894377654559865*NC*NL)/31814516448 - 
         (587703821805551*lm*NC*NL)/716040 - 147685461*lm^2*NC*NL - 
         (402258910379682713591273842495590004762530267195882408349*NC*NH)/
          6612251588206640700264896908461210996774480000 - 
         (587703821805551*lm*NC*NH)/716040 - 147685461*lm^2*NC*NH + 
         (161424114313970874506*NM*NC*Pi^2)/27 - (28807387700*NC*NL*Pi^2)/
          81 + (139326152856118189861524210760*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1350851717672992089*Sqrt[3]) + 
         CF*NC*
          (158016011852964385397601537529191456653561794485972601744516722772\
9/121991660314612759658440339498689565295808000000 - (476080196672531*lm)/
            26520 - 3987507447*lm^2 + (46248189097141360969427761*Pi^2)/
            28641600 + (2077486865509050575885928045897031*
             Im[PolyLog[2, (-1)^(1/3)]])/(119415291842292500667600*Sqrt[3]) - 
           1181483688*Zeta[3]) + CA*NC*(-110611208221312314125581036634868499\
44683757313561883579669646386803/
            1707883244404578635218164752981653914141312000000 + 
           (7945223804783221*lm)/1432080 + (1624540071*lm^2)/2 - 
           (46248189080820561881979217*Pi^2)/57283200 - 
           (2077486865509050575885928045897031*Im[PolyLog[2, (-1)^(1/3)]])/
            (238830583684585001335200*Sqrt[3]) + 590741844*Zeta[3])), 
      (6229632269465434747406704423623172200265296221881529479360396276343858\
529215940067*CF^2*NC)/
        167352277141783042735221011427550119525756213854325273600000000 - 
       (494172288150140172601*CF^2*lm*NC)/365608878336 - 
       (12075328881*CF^2*lm^2*NC)/10 + 
       (6186705876554578098139433809544121859580704726201345432664249*CF*NM*
         NC)/3387553467141191925268504921621601088000000 - 
       (4800919815936634319069*CF*lm*NM*NC)/49357198575360 - 
       (447234403*CF*lm^2*NM*NC)/10 + (3968321613169108991879166355930387*CF*
         NC*NL)/1792740591404016026572800 - (4800919815936634319069*CF*lm*NC*
         NL)/49357198575360 - (447234403*CF*lm^2*NC*NL)/10 + 
       (707096346047518453711561710098690786160263038972815498877194620981581\
061*CF*NC*NH)/
        9635129185266917758395405168364416868253302707767320128000000 - 
       (4800919815936634319069*CF*lm*NC*NH)/49357198575360 - 
       (447234403*CF*lm^2*NC*NH)/10 - 
       (64833332529611756874410591204795385401*CF^2*NC*Pi^2)/
        3496463947078502400 + (12836285*CF^2*lm*NC*Pi^2)/6 - 
       (123176570634703628751301430*CF*NM*NC*Pi^2)/78567489 + 
       (12836285*CF*lm*NM*NC*Pi^2)/162 - (1957963156018177*CF*NC*NL*Pi^2)/
        16325712 + (12836285*CF*lm*NC*NL*Pi^2)/162 + 
       (12836285*CF*lm*NC*NH*Pi^2)/162 - 
       (355462075217490831252266991178183357*CF^2*NC*Pi^3)/
        (196032143088307369095932160*Sqrt[3]) - 
       (4678415786085669363042694217215*CF*NC*NH*Pi^3)/
        (437675956526049436836*Sqrt[3]) - (2573381920571*CF^2*NC*Pi^4)/
        64800 + (38406882488653181748539542390442637673581187*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3169085029987040174910203688384000*
         Sqrt[3]) + (98194787477214328435842108863435351*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1692711761864496196963230*Sqrt[3]) - 
       (125064171617*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
       (50780296459641547321752427311169051*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(756296848334519170894800*
         Sqrt[3]) - (534676089838362212919165053396*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (50780296459641547321752427311169051*CF^2*NC*Pi*Log[3]^2)/
        (36302248720056920202950400*Sqrt[3]) - 
       (133669022459590553229791263349*CF*NC*NH*Pi*Log[3]^2)/
        (16210220612075905068*Sqrt[3]) + 
       CF*((-312241960589914742033947604094959298043651*CF*NC)/
          1403268343046238240000 - 64266491746*CF*lm*NC + 
         CA*(2185693723658718984238987377001023558433117/
            19645756802647335360000 + (353465704603*lm)/27)*NC - 
         (6112612684169076790272310400788531*NM*NC)/324907994010600 - 
         (64266491746*lm*NM*NC)/27 - (396542615753*NC*NL)/135 - 
         (64266491746*lm*NC*NL)/27 - (8819780591904567337153*NC*NH)/
          13492251154200 - (64266491746*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(1037025255667527645692844737*CA - 
          76*(27290138416744173278196949*CF + 22100*(94586450588397374592*
               NM - 32133245873*NL)))*Log[x]^3)/34011900 - 
       (358402576677539503147992188412500813176615237*CF^2*NC*
         PolyGamma[2, 1])/33088302313369337424801600 - 
       (7031061643332912327701*CF*NM*NC*PolyGamma[2, 1])/12600 - 
       (9540327267307821504035921582894159*CF*NC*NH*PolyGamma[2, 1])/
        2068018894585583589050100 + CA*CF*NC*
        (-4360742589103262221407467390399244563719080273889392861579470337061\
7330242852911469/
          2342931879984962598293094159985701673360586993960553830400000000 + 
         (4919578433*lm^2)/20 + (324166662651218661874633720886657850781*
           Pi^2)/34964639470785024000 + (355462075217490831252266991178183357*
           Pi^3)/(392064286176614738191864320*Sqrt[3]) + 
         (2581597142971*Pi^4)/129600 + lm*(83714050109347989663871/
            98714397150720 - (141199135*Pi^2)/324) - 
         (38406882488653181748539542390442637673581187*
           Im[PolyLog[2, (-1)^(1/3)]])/(6338170059974080349820407376768000*
           Sqrt[3]) + (125064171617*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (50780296459641547321752427311169051*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1512593696669038341789600*
           Sqrt[3]) + (50780296459641547321752427311169051*Pi*Log[3]^2)/
          (72604497440113840405900800*Sqrt[3]) + 
         (358402576677539503147992188412500813176615237*PolyGamma[2, 1])/
          66176604626738674849603200 - 
         (471676162883604948106719032223235073905987471*Zeta[3])/
          106875216472182959882109168) + 
       (11791904078305777425463020656785039880343095983*CF^2*NC*Zeta[3])/
        1335940205902286998526364600 + (7682386327045482991499*CF*NM*NC*
         Zeta[3])/6300 - (74365867340*CF*NC*NL*Zeta[3])/27 + 
       (12576719366479883632248084652158841*CF*NC*NH*Zeta[3])/
        1034009447292791794525050 + CF*Log[x]*
        ((-6027171427364364499172621252233150843991189623*NM*NC)/
          451133352871761049029540000 - (2822142463753921*lm*NM*NC)/
          2720952 - 186550056*lm^2*NM*NC - (191891955469205423414113223*NC*
           NL)/38505109257014400 - (2822142463753921*lm*NC*NL)/2720952 - 
         186550056*lm^2*NC*NL - 
         (70170309108320265986372707063249003643282545398830329931*NC*NH)/
          901670671119087368217940487517437863196520000 - 
         (2822142463753921*lm*NC*NH)/2720952 - 186550056*lm^2*NC*NH - 
         (31528816867438878865*NM*NC*Pi^2)/27 - (37170097385*NC*NL*Pi^2)/
          81 + (534676089838362212919165053396*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CF*NC*(-194183687139726250810924337504109278452164829761831406752851\
6902987877/16224890821843497034572565153325712184342464000000 - 
           (2286349063115425*lm)/100776 - 5036851512*lm^2 - 
           (638169388302631538234386943*Pi^2)/41860800 + 
           (50780296459641547321752427311169051*Im[PolyLog[2, (-1)^(1/3)]])/
            (2268890545003557512684400*Sqrt[3]) - 1492400448*Zeta[3]) + 
         CA*NC*
          (213388667206810960718486777044957483832623469630846265600962515299\
47/356591007073483451309287146226938729326208000000 + (38149879572919499*lm)/
            5441904 + 1026025308*lm^2 + (638169388333411121484617951*Pi^2)/
            83721600 - (50780296459641547321752427311169051*
             Im[PolyLog[2, (-1)^(1/3)]])/(4537781090007115025368800*
             Sqrt[3]) + 746200224*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["s", 2, 4, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-1601525942907030*NM + 123832156815360*lm*NM + 
         84276412416000*lm^2*NM + 376663249780736*NL + 
         123832156815360*lm*NL + 84276412416000*lm^2*NL - 
         1601525942907030*NH + 123832156815360*lm*NH + 
         84276412416000*lm^2*NH + 36*CF*(294232533634027642 + 
           26155291115520*lm + 63207309312000*lm^2 - 244741896826385175*
            Zeta[3]) + 1301908056458625*NM*Zeta[3] + 1301908056458625*NH*
          Zeta[3] - 10*CA*(-71548384747112638 + 127101174939648*lm + 
           46352026828800*lm^2 + 59616002432440125*Zeta[3])))/
       3114856202895360000, -(CF*NC*(-3771482548799070*NM + 
          663881452093440*lm*NM + 337105649664000*lm^2*NM + 
          1630485155938304*NL + 663881452093440*lm*NL + 
          337105649664000*lm^2*NL - 8793060680826450*NH + 
          663881452093440*lm*NH + 337105649664000*lm^2*NH + 
          144*CF*(294239072456806522 + 57758945771520*lm + 
            63207309312000*lm^2 - 244741896826385175*Zeta[3]) + 
          3316577868190125*NM*Zeta[3] + 7098686583478875*NH*Zeta[3] - 
          40*CA*(-71516609453377726 + 150277188354048*lm + 
            46352026828800*lm^2 + 59616002432440125*Zeta[3])))/
       3114856202895360000, 
      (CF*NC*(22*CF*(1592081067287276434159558 + 75869725055149670400*lm + 
           58069819211120640000*lm^2 - 1324420722263510313143625*Zeta[3]) - 
         121*CA*(-13255738823222550575854 + 7817506961699635200*lm + 
           2150734044856320000*lm^2 + 11034391685840756533125*Zeta[3]) + 
         5*(2097152*(23915518533359 + 10658702840940*lm + 4512419604000*lm^2)*
            NL + 3465*NH*(-96670925991103310 + 6451059157368832*lm + 
             2731090850611200*lm^2 + 78211011658504725*Zeta[3]) + 
           3465*NM*(6451059157368832*lm + 2731090850611200*lm^2 + 
             583*(-25049728898258 + 28131302274075*Zeta[3])))))/
       195986752286176051200000, 
      -(CF*NC*(22*CF*(1410308575610258249414278 + 30443508594848563200*lm + 
            19022871810539520000*lm^2 - 1173228968080042607435625*Zeta[3]) - 
          121*CA*(-11024965308000481461934 + 2767930902813081600*lm + 
            704550807797760000*lm^2 + 9174372409948624633125*Zeta[3]) + 
          5*(16777216*(1072368545977 + 490749564690*lm + 184775802750*lm^2)*
             NL + 231*NM*(-18631611594999598 + 35642473803939840*lm + 
              13420015386624000*lm^2 + 51197156975089125*Zeta[3]) + 
            693*NH*(11880824601313280*lm + 4473338462208000*lm^2 + 
              693*(-305815384023034 + 248629322316375*Zeta[3])))))/
       39197350457235210240000, 
      (CF*NC*(34944*CF*(400098070858026311512753846 + 3119231460982652928000*
            lm + 1733973701233213440000*lm^2 - 332842757046901840842728625*
            Zeta[3]) - 704*CA*(-727603719220038909355984894 + 
           72359283504163848192000*lm + 17532400756913602560000*lm^2 + 
           605372314872009614512708125*Zeta[3]) + 
         25*(134217728*(4214755785816263 + 1909077411821580*lm + 
             668808012272400*lm^2)*NL + 45045*NH*(5688356816312860672*lm + 
             1992804792438620160*lm^2 + 1573*(-79580925907109026 + 
               65036051610750675*Zeta[3])) + 3003*NM*
            (85325352244692910080*lm + 29892071886579302400*lm^2 + 
             1001*(15125275131685946 + 100755918646007625*Zeta[3])))))/
       4239585425454560339558400000, 
      -(CF*NC*(93184*CF*(1028573936790838064079126422 + 
            2857945078648170086400*lm + 1503307474922373120000*lm^2 - 
            855676606381133969049242625*Zeta[3]) - 
          5632*CA*(-550585799103227181178173386 + 21429050936691209011200*
             lm + 5066702971034664960000*lm^2 + 458059385866774961573679375*
             Zeta[3]) + 5*(1073741824*(6524729743152347 + 2857307411698740*
               lm + 966396898467000*lm^2)*NL + 3003*NM*
             (-123062281177213968686 + 1021648508813228113920*lm + 
              345541381441191936000*lm^2 + 1802755199542629457125*Zeta[3]) + 
            9009*NH*(-9537835748309540339382 + 340549502937742704640*lm + 
              115180460480397312000*lm^2 + 7830600067745206376625*Zeta[3]))))/
       8479170850909120679116800000, 
      (CF*NC*(-385*CA*(-5888422136321254915504691316194 + 
           87883262852229564695838720*lm + 20781451036527182217216000*lm^2 + 
           4898720134085458858746563869875*Zeta[3]) + 
         2*(7*CF*(5645091931905497743822996634352754 + 
             5332252579706197368845107200*lm + 2805495889931169599324160000*
              lm^2 - 4696190622512684002351905959572875*Zeta[3]) + 
           5*(4294967296*(240684877697071237 + 100126257971479740*lm + 
               33869910346272000*lm^2)*NL + 3003*NM*
              (-280871349800789732545054 + 143203131354766827847680*lm + 
               48441610807755669504000*lm^2 + 523991598226912845154125*
                Zeta[3]) + 3003*NH*(-5279829140384996324787374 + 
               143203131354766827847680*lm + 48441610807755669504000*lm^2 + 
               4351227858891923669785125*Zeta[3])))))/
       2306334471447280824719769600000, 
      -(CF*NC*(-11*CA*(-504065208940492649536920832667978 + 
            2803490658955645727381913600*lm + 681797243245484184698880000*
             lm^2 + 419338771103215052630036400279375*Zeta[3]) + 
          2*(3*CF*(36081701643234359901982562878622534 + 
              10944664606229529312519782400*lm + 6136175189209357662289920000*
               lm^2 - 30016627986833371092118375800959625*Zeta[3]) + 
            10*(2147483648*(232006193398891451 + 90140323760306820*lm + 
                31748658197256000*lm^2)*NL + 858*NM*(
                -1620745462008954161358326 + 225611738112686209105920*lm + 
                79463548163809345536000*lm^2 + 1901575582700172718964625*
                 Zeta[3]) + 429*NH*(-22870896878535615816417082 + 
                451223476225372418211840*lm + 158927096327618691072000*lm^2 + 
                18904925523070112151000375*Zeta[3])))))/
       2306334471447280824719769600000, 
      (CF*NC*(68*CF*(616915142701093845636412047825967667474 + 
           54681100641693619222644523008000*lm + 
           35884770112013755996333670400000*lm^2 - 
           513216233020539878537787553792341898875*Zeta[3]) - 
         22*CA*(-43870800663418071994824883551899794474 + 
           87034329990234292563914784768000*lm + 
           22594114514971624145839718400000*lm^2 + 
           36496541096706116490828415628651049375*Zeta[3]) + 
         175*(4294967296*(874571830172277678941 + 310147363394002674540*lm + 
             120242336578516152000*lm^2)*NL + 7293*NM*
            (-3961240934309775065961349042 + 182650868328242019701882880*lm + 
             70812683833724312223744000*lm^2 + 3844914075859194854658016875*
              Zeta[3]) + 7293*NH*(182650868328242019701882880*lm + 
             70812683833724312223744000*lm^2 + 75361*
              (-180151972202308739825546 + 149254703873993442099375*
                Zeta[3])))))/177297156158038266119507568230400000, 
      CA*CF*NC*((174900603707*lm)/23029371565200 + (7879*lm^2)/3527160 + 
         (-23287061599691169663317971933199977946 + 
           19372694221448356795139012124844974375*Zeta[3])/
          2014740410886798478630767820800000) - 
       (CF*NC*(5984*CF*(32958778605479638460997190712140813766 + 
            696334286682020400435560448000*lm + 
            649811203531461103630417920000*lm^2 - 
            27418650821297993661939438459514583625*Zeta[3]) + 
          175*(68719476736*(82270419575532999929 + 25473892123272312720*lm + 
              11975595625105912800*lm^2)*NL + 21879*NH*
             (-9772853756244495097104442662 + 80010628325818608627220480*lm + 
              37613998124192566031155200*lm^2 + 8110687341381422252095265625*
               Zeta[3]) + 2431*NM*(-48886289074433312686744634218 + 
              720095654932367477644984320*lm + 338525983117733094280396800*lm^
                2 + 43472660677995248771766069375*Zeta[3]))))/
        354594312316076532239015136460800000, 
      (CF*NC*(1216*CF*(1037434566922876488106920635502123406438814 + 
           2219096946715778416321950960844800*lm + 
           6782460147922956339325949706240000*lm^2 - 
           863049468972850645823681506126171668586125*Zeta[3]) - 
         11616*CA*(-2048579822077304426768049250277337356114 + 
           384064047598328588796830102323200*lm + 
           144631585645944074575974236160000*lm^2 + 
           1704228943514064923775340375304536870875*Zeta[3]) + 
         35*(1099511627776*(46418855036785558100959 + 10975614877975133876490*
              lm + 7937599649247305037000*lm^2)*NL + 
           46189*NM*(-71614297320251970523553494623958 + 
             261270349657384291917795164160*lm + 
             188951549307802962056183808000*lm^2 + 
             61152552359936364914860342694625*Zeta[3]) + 
           138567*NH*(87090116552461430639265054720*lm + 
             62983849769267654018727936000*lm^2 + 
             4199*(-5439625387878574267376667214 + 
               4520142784467194585294719125*Zeta[3])))))/
       1024068373968829025106275714098790400000, 
      CA*CF*NC*((506209932376961*lm)/332544125401488000 + 
         (2207*lm^2)/2015520 + (-129671702667792056730954217533983647000754 + 
           107874842227472461127311795240472171344875*Zeta[3])/
          2909285153320537003142828733235200000) - 
       (CF*NC*(1216*CF*(62354614311966011370616626259426460267882 - 
            121339248417944149105732516577280*lm + 
            129343208731236193216040534016000*lm^2 - 
            51873263596249887637155740001938120930175*Zeta[3]) + 
          11*(274877906944*(7051308973116381171469 + 226248818081370133140*
               lm + 1926552822497845542000*lm^2)*NL + 37791*NH*
             (1645651122297923952191733760*lm + 14013040339373484071190528000*
               lm^2 + 46189*(-161673690348138848320854422 + 
                134465821160133909880058625*Zeta[3])) + 
            4199*NM*(14810860100681315569725603840*lm + 
              126117363054361356640714752000*lm^2 + 
              17*(-7870701261487181414094866563886 + 
                6603588139401690931808190001125*Zeta[3])))))/
        29259096399109400717322163259965440000, 
      (CF*NC*(52*CF*(311603138959649674585023464961054653791412064862 - 
           632774510242916548265163285415015219200*lm + 
           187291908439049949709458547031408640000*lm^2 - 
           259224949363626792001579568164093091700631774125*Zeta[3]) + 
         CA*(255155485926566241723404649799346767586815451764 + 
           2083626263745024060188251951847807385600*lm - 
           1983906881984010578403894238925291520000*lm^2 - 
           212265715442694665667875028595827294060894576750*Zeta[3]) + 
         1155*(274877906944*(-1400076596576713194431741 - 
             2639273396587773864478560*lm + 1136152883416171673052000*lm^2)*
            NL + 4199*NH*(-64234530850914825198038091674777122 - 
             172773981211485808870743720591360*lm + 
             74375643382192835906148237312000*lm^2 + 
             53457481761160323743685787653529875*Zeta[3]) + 
           37791*NM*(-19197109023498423207860413399040*lm + 
             8263960375799203989572026368000*lm^2 + 
             323*(-85598202708875638155941465393126 + 
               71331180851123497899123397493625*Zeta[3])))))/
       3109071583369364920222653068003927654400000, 
      -(CF*NC*(16*CF*(3914767991596901364769125881644313474292798309278 - 
            5383493706612120922728897211124416512000*lm + 
            543731468832297638858634706708070400000*lm^2 - 
            3256724359187667735780256025653427547647253322125*Zeta[3]) - 
          8*CA*(-113304382399951661203477160918967644643971972194 - 
            1677513470735618788449570057634185216000*lm + 
            221520228042787926942406732362547200000*lm^2 + 
            94258745520855859984323996217612171387069621875*Zeta[3]) + 
          5775*(3298534883328*(-264128359297042659527239 - 
              149619444572921666222880*lm + 16914829226536236996000*lm^2)*
             NL + 46189*NM*(-16440376237441809018730405385251906 - 
              10684902404207545759435598069760*lm + 
              1207953284315870683088289792000*lm^2 + 
              13670928161002004020367082408439875*Zeta[3]) + 
            4199*NH*(-117533926446283003353791578767360*lm + 
              13287486127474577513971187712000*lm^2 + 
              4199*(-5594073260539742133882208402838 + 
                4657386125637883335849929402625*Zeta[3])))))/
       6218143166738729840445306136007855308800000, 
      CF*((-5637273023262630715880908828373382913*NM*NC)/
         4444725479823430119287742447747072000 - (235324215047263*lm*NM*NC)/
         425291047409067840 + (58*lm^2*NM*NC)/9784775 - 
        (649948939551677805275294297*NC*NL)/518041525920800746138642368000 - 
        (235324215047263*lm*NC*NL)/425291047409067840 + 
        (58*lm^2*NC*NL)/9784775 - (197741618838553443608152052340361*NC*NH)/
         2428369411668237180452235902976000 - (235324215047263*lm*NC*NH)/
         425291047409067840 + (58*lm^2*NC*NH)/9784775 + 
        CF*NC*((-1189926063349787*lm)/78757601372049600 + 
          (1566*lm^2)/9784775 + 
          (977408675141370842927371495070864118483974612742674 - 
            813113483487120377562967962533964765179682497530875*Zeta[3])/
           52006288303633013210997105864792971673600000) + 
        CA*NC*((1160578697223899*lm)/386628224917334400 - (29*lm^2)/889525 + 
          (54545538253916052213974050574761460958850157163622 - 
            45376833555359574923786446767614436742870030253625*Zeta[3])/
           217480841997010782518715169980043336089600000) + 
        (128194028978139299*NM*NC*Zeta[3])/121597189939003392 + 
        (916183516742291*NC*NH*Zeta[3])/13510798882111488), 
      (CF*NC*(-5*CA*(40134428319872985839827335132144488488196013401318 + 
           318378221357259084973330085401087954649088*lm + 
           12702346745944790241786922825756610396160*lm^2 - 
           33388125948526619482048581240033016369441201676025*Zeta[3]) + 
         14*(115*CF*(-10096177682348288077088457956176169925251332477658 + 
             4402990553271655756115362570202372898816*lm + 
             193655201660366649648925418574493777920*lm^2 + 
             8399084651658329186969269972153776618111566952615*Zeta[3]) + 
           3*(2199023255552*(7757394415536313185039369269 + 
               2974673673170209722442250520*lm + 125029405470988987566998400*
                lm^2)*NL + 37145*NM*
              (692159305708463566390258794868913920906 + 
               176103825144153469389354154120445952*lm + 
               7401872937368292995792738545827840*lm^2 - 
               575426278368216547581797015129217190575*Zeta[3]) + 
             4680270*NH*(1397649405905979915788525032701952*lm + 
               58745023312446769807878877347840*lm^2 - 7429*
                (-23150939568965651119009479647042 + 
                 19281421287376878191699580718275*Zeta[3]))))))/
       478457852393423721541173373956095339397120000}, 0, 16, 1]

CbarTable["s", 2, -1] = {{0., 0.000925925925925926*CF*NC*
       (CF*(-6538.21369593866 - 4967.885821649447*lm - 2430.*lm^2 - 
          2160.*lm^3) - 1.*CA*(8942.848749338787 + 8518.557089175276*lm + 
          4560.*lm^2 + 660.*lm^3) + 
        30.*((83.46582090110702 + 45.*lm + 20.*lm^2 + 4.*lm^3)*NM + 
          (83.46582090110702 + 45.*lm + 20.*lm^2 + 4.*lm^3)*NL + 
          (-9.63037315387456 + 117.*lm + 20.*lm^2 + 4.*lm^3)*NH))}, 
     {0.005, CF*NC*(CF*(-6.0839855969489225 - 4.622918117799469*lm - 
          2.2612982625868847*lm^2 - 2.01005*lm^3) + 
        CA*(-8.321863184601451 - 7.927150709796014*lm - 4.243436448290437*
           lm^2 - 0.6141819444444444*lm^3) + 2.3300890798915157*NM + 
        1.2563250686439094*lm*NM + 0.5583467784770492*lm^2*NM + 
        0.11166944444444445*lm^3*NM + 2.3301193522931856*NL + 
        1.2562750686439095*lm*NL + 0.5583467784770492*lm^2*NL + 
        0.11166944444444445*lm^3*NL - 0.27332010249206223*NH + 
        3.2562750686439093*lm*NH + 0.5583467784770492*lm^2*NH + 
        0.11166944444444445*lm^3*NH)}, 
     {0.01, CF*NC*(CF*(-6.11323196800925 - 4.645797222889379*lm - 
          2.2726691797553213*lm^2 - 2.0202*lm^3) + 
        CA*(-8.36313023966629 - 7.966981489133796*lm - 4.264849610480793*
           lm^2 - 0.6172833333333333*lm^3) + 2.341636449493132*NM + 
        1.262786100503589*lm*NM + 0.5611635655419623*lm^2*NM + 
        0.11223333333333334*lm^3*NM + 2.341764901690692*NL + 
        1.262586100503589*lm*NL + 0.5611635655419623*lm^2*NL + 
        0.11223333333333334*lm^3*NL - 0.27918175247532956*NH + 
        3.2625861005035888*lm*NH + 0.5611635655419623*lm^2*NH + 
        0.11223333333333334*lm^3*NH)}, 
     {0.015, CF*NC*(CF*(-6.141335118305258 - 4.668347765764544*lm - 
          2.2840835717709096*lm^2 - 2.03045*lm^3) + 
        CA*(-8.403996378201832 - 8.006954647694712*lm - 4.286452792763334*
           lm^2 - 0.6204152777777778*lm^3) + 2.35309474624465*NM + 
        1.2693686950351073*lm*NM + 0.5640042956539394*lm^2*NM + 
        0.11280277777777778*lm^3*NM + 2.353398240097904*NL + 
        1.2689186950351072*lm*NL + 0.5640042956539394*lm^2*NL + 
        0.11280277777777778*lm^3*NL - 0.28509086934768946*NH + 
        3.2689186950351075*lm*NH + 0.5640042956539394*lm^2*NH + 
        0.11280277777777778*lm^3*NH)}, 
     {0.02, CF*NC*(CF*(-6.168163334231159 - 4.690446388864673*lm - 
          2.2955167814198765*lm^2 - 2.0408*lm^3) + 
        CA*(-8.444332938351037 - 8.047003440757075*lm - 4.308238460989407*
           lm^2 - 0.6235777777777778*lm^3) + 2.3644374775479555*NM + 
        1.2760624602738788*lm*NM + 0.566867598967771*lm^2*NM + 
        0.11337777777777777*lm^3*NM + 2.3650004383536625*NL + 
        1.275262460273879*lm*NL + 0.566867598967771*lm^2*NL + 
        0.11337777777777777*lm^3*NL - 0.2910436260425849*NH + 
        3.2752624602738787*lm*NH + 0.566867598967771*lm^2*NH + 
        0.11337777777777777*lm^3*NH)}, 
     {0.025, CF*NC*(CF*(-6.193655076839717 - 4.712000738895975*lm - 
          2.306946850104978*lm^2 - 2.05125*lm^3) + 
        CA*(-8.484052688819842 - 8.08707377674501*lm - 4.330199905587632*
           lm^2 - 0.6267708333333334*lm^3) + 2.375645387555514*NM + 
        1.2828591140160148*lm*NM + 0.5697522555613876*lm^2*NM + 
        0.11395833333333333*lm^3*NM + 2.376558992767449*NL + 
        1.2816091140160148*lm*NL + 0.5697522555613876*lm^2*NL + 
        0.11395833333333333*lm^3*NL - 0.29703656538882717*NH + 
        3.281609114016015*lm*NH + 0.5697522555613876*lm^2*NH + 
        0.11395833333333333*lm^3*NH)}, 
     {0.03, CF*NC*(CF*(-6.21778647649417 - 4.732938365051867*lm - 
          2.3183537373621323*lm^2 - 2.0618*lm^3) + 
        CA*(-8.523092858066079 - 8.127119905420818*lm - 4.352331003082874*
           lm^2 - 0.6299944444444444*lm^3) + 2.386703523776452*NM + 
        1.2897517550389892*lm*NM + 0.572657152075674*lm^2*NM + 
        0.11454444444444445*lm^3*NM + 2.3880651352577824*NL + 
        1.2879517550389892*lm*NL + 0.572657152075674*lm^2*NL + 
        0.11454444444444445*lm^3*NL - 0.30306649403071256*NH + 
        3.287951755038989*lm*NH + 0.572657152075674*lm^2*NH + 
        0.11454444444444445*lm^3*NH)}, 
     {0.035, CF*NC*(CF*(-6.240556384060507 - 4.753200926591156*lm - 
          2.3297188784835234*lm^2 - 2.07245*lm^3) + 
        CA*(-8.561406871717773 - 8.167102126751823*lm - 4.374626080925521*
           lm^2 - 0.6332486111111111*lm^3) + 2.397599805336912*NM + 
        1.2967344778111514*lm*NM + 0.5755812571379735*lm^2*NM + 
        0.1151361111111111*lm^3*NM + 2.3995125376911757*NL + 
        1.2942844778111513*lm*NL + 0.5755812571379735*lm^2*NL + 
        0.1151361111111111*lm^3*NL - 0.3091304225581574*NH + 
        3.2942844778111513*lm*NH + 0.5755812571379735*lm^2*NH + 
        0.1151361111111111*lm^3*NH)}, 
     {0.04, CF*NC*(CF*(-6.261978268212148 - 4.772740697307739*lm - 
          2.3410248993401055*lm^2 - 2.0832*lm^3) + 
        CA*(-8.598959635376222 - 8.206985386823927*lm - 4.397079830353921*
           lm^2 - 0.6365333333333333*lm^3) + 2.4083242034225*NM + 
        1.3038021373673452*lm*NM + 0.5785236055188947*lm^2*NM + 
        0.11573333333333333*lm^3*NM + 2.4108965789780132*NL + 
        1.300602137367345*lm*NL + 0.5785236055188947*lm^2*NL + 
        0.11573333333333333*lm^3*NL - 0.31522552706835794*NH + 
        3.300602137367345*lm*NH + 0.5785236055188947*lm^2*NH + 
        0.11573333333333333*lm^3*NH)}, 
     {0.045, CF*NC*(CF*(-6.282075371390578 - 4.791518261819227*lm - 
          2.352255417575913*lm^2 - 2.09405*lm^3) + 
        CA*(-8.635724570392513 - 8.246738339688841*lm - 4.419687245648196*
           lm^2 - 0.6398486111111111*lm^3) + 2.4188682248473294*NM + 
        1.3109501927926466*lm*NM + 0.5814832870875507*lm^2*NM + 
        0.11633611111111111*lm^3*NM + 2.422213888395848*NL + 
        1.3069001927926465*lm*NL + 0.5814832870875507*lm^2*NL + 
        0.11633611111111111*lm^3*NL - 0.3213491224716783*NH + 
        3.3069001927926465*lm*NH + 0.5814832870875507*lm^2*NH + 
        0.11633611111111111*lm^3*NH)}, 
     {0.05, CF*NC*(CF*(-6.300877616720527 - 4.809500903313625*lm - 
          2.363394896410178*lm^2 - 2.105*lm^3) + 
        CA*(-8.671681625599955 - 8.286332682474816*lm - 4.442443579458666*
           lm^2 - 0.6431944444444444*lm^3) + 2.42922456464675*NM + 
        1.318174596670631*lm*NM + 0.5844594386894544*lm^2*NM + 
        0.11694444444444445*lm^3*NM + 2.433462041694452*NL + 
        1.313174596670631*lm*NL + 0.5844594386894544*lm^2*NL + 
        0.11694444444444445*lm^3*NL - 0.3274986429309233*NH + 
        3.313174596670631*lm*NH + 0.5844594386894544*lm^2*NH + 
        0.11694444444444445*lm^3*NH)}, 
     {0.055, CF*NC*(CF*(-6.31841953724038 - 4.8266614245632855*lm - 
          2.37442853284638*lm^2 - 2.11605*lm^3) + 
        CA*(-8.70681587863592 - 8.325742663424265*lm - 4.465344308647505*
           lm^2 - 0.6465708333333333*lm^3) + 2.439386860944214*NM + 
        1.3254717135400766*lm*NM + 0.58745123793591*lm^2*NM + 
        0.11755833333333333*lm^3*NM + 2.4446393489379967*NL + 
        1.3194217135400768*lm*NL + 0.58745123793591*lm^2*NL + 
        0.11755833333333333*lm^3*NL - 0.3336716269526137*NH + 
        3.3194217135400765*lm*NH + 0.58745123793591*lm^2*NH + 
        0.11755833333333333*lm^3*NH)}, 
     {0.06, CF*NC*(CF*(-6.334738839514682 - 4.842977256284015*lm - 
          2.3853421695980406*lm^2 - 2.1272*lm^3) + 
        CA*(-8.741116515526661 - 8.364944705675311*lm - 4.488385107377179*
           lm^2 - 0.6499777777777778*lm^3) + 2.449349515543842*NM + 
        1.33283825771908*lm*NM + 0.5904578983110023*lm^2*NM + 
        0.11817777777777778*lm^3*NM + 2.4557447008647957*NL + 
        1.3256382577190802*lm*NL + 0.5904578983110023*lm^2*NL + 
        0.11817777777777778*lm^3*NL - 0.3398657056754294*NH + 
        3.32563825771908*lm*NH + 0.5904578983110023*lm^2*NH + 
        0.11817777777777778*lm^3*NH)}, 
     {0.065, CF*NC*(CF*(-6.34987537972903 - 4.85842976459545*lm - 
          2.396122224038562*lm^2 - 2.13845*lm^3) + 
        CA*(-8.774576064472821 - 8.403917111938263*lm - 4.511561825400672*
           lm^2 - 0.6534152777777777*lm^3) + 2.459107558768383*NM + 
        1.3402712446336185*lm*NM + 0.5934786652243645*lm^2*NM + 
        0.11880277777777777*lm^3*NM + 2.4667774543554573*NL + 
        1.3318212446336184*lm*NL + 0.5934786652243645*lm^2*NL + 
        0.11880277777777777*lm^3*NL - 0.3460785934467116*NH + 
        3.3318212446336184*lm*NH + 0.5934786652243645*lm^2*NH + 
        0.11880277777777777*lm^3*NH)}, 
     {0.07, CF*NC*(CF*(-6.36387041808918 - 4.873003701339779*lm - 
          2.4067556297720265*lm^2 - 2.1498*lm^3) + 
        CA*(-8.807189806891582 - 8.442639827693785*lm - 4.534870470208119*
           lm^2 - 0.6568833333333334*lm^3) + 2.468656545204936*NM + 
        1.347767951894029*lm*NM + 0.5965128127651126*lm^2*NM + 
        0.11943333333333334*lm^3*NM + 2.4777373450263656*NL + 
        1.337967951894029*lm*NL + 0.5965128127651126*lm^2*NL + 
        0.11943333333333334*lm^3*NL - 0.35230808009010595*NH + 
        3.337967951894029*lm*NH + 0.5965128127651126*lm^2*NH + 
        0.11943333333333334*lm^3*NH)}, 
     {0.075, CF*NC*(CF*(-6.376766066706513 - 4.886686759869994*lm - 
          2.4172297878107356*lm^2 - 2.16125*lm^3) + 
        CA*(-8.838955315847766 - 8.481094247936914*lm - 4.558307192108836*
           lm^2 - 0.6603819444444444*lm^3) + 2.477992471703963*NM + 
        1.3553258876096508*lm*NM + 0.5995596409894853*lm^2*NM + 
        0.12006944444444445*lm^3*NM + 2.4886244192160225*NL + 
        1.3440758876096508*lm*NL + 0.5995596409894853*lm^2*NL + 
        0.12006944444444445*lm^3*NL - 0.35855202445654333*NH + 
        3.344075887609651*lm*NH + 0.5995596409894853*lm^2*NH + 
        0.12006944444444445*lm^3*NH)}, 
     {0.08, CF*NC*(CF*(-6.388604875370049 - 4.8994692105779665*lm - 
          2.4275325252275763*lm^2 - 2.1728*lm^3) + 
        CA*(-8.869872088365952 - 8.519263057093175*lm - 4.581868271597315*
           lm^2 - 0.6639111111111111*lm^3) + 2.4871117118091886*NM + 
        1.3629427642062337*lm*NM + 0.6026184736237542*lm^2*NM + 
        0.12071111111111112*lm^3*NM + 2.4994389801904253*NL + 
        1.3501427642062336*lm*NL + 0.6026184736237542*lm^2*NL + 
        0.12071111111111112*lm^3*NL - 0.36480834897073855*NH + 
        3.350142764206234*lm*NH + 0.6026184736237542*lm^2*NH + 
        0.12071111111111112*lm^3*NH)}, 
     {0.085, CF*NC*(CF*(-6.399429517636898 - 4.911343597936126*lm - 
          2.437652059733603*lm^2 - 2.18445*lm^3) + 
        CA*(-8.899941248417615 - 8.557130094711846*lm - 4.605550108529712*
           lm^2 - 0.6674708333333333*lm^3) + 2.4960109625810083*NM + 
        1.370616476511147*lm*NM + 0.6056886560963113*lm^2*NM + 
        0.12135833333333333*lm^3*NM + 2.5101815449990252*NL + 
        1.3561664765111472*lm*NL + 0.6056886560963113*lm^2*NL + 
        0.12135833333333333*lm^3*NL - 0.3710750349644526*NH + 
        3.356166476511147*lm*NH + 0.6056886560963113*lm^2*NH + 
        0.12135833333333333*lm^3*NH)}, 
     {0.09, CF*NC*(CF*(-6.409282551197349 - 4.922304485820143*lm - 
          2.4475769690280367*lm^2 - 2.1962*lm^3) + 
        CA*(-8.929165304093786 - 8.594680241534803*lm - 4.629349212758567*
           lm^2 - 0.6710611111111111*lm^3) + 2.5046872009408596*NM + 
        1.3783450832057984*lm*NM + 0.608769553834891*lm^2*NM + 
        0.12201111111111111*lm^3*NM + 2.5208528094558034*NL + 
        1.3621450832057984*lm*NL + 0.608769553834891*lm^2*NL + 
        0.12201111111111111*lm^3*NL - 0.37735011864156787*NH + 
        3.362145083205798*lm*NH + 0.608769553834891*lm^2*NH + 
        0.12201111111111111*lm^3*NH)}, 
     {0.095, CF*NC*(CF*(-6.418206234058559 - 4.932348241299823*lm - 
          2.457296164045773*lm^2 - 2.20805*lm^3) + 
        CA*(-8.957547946984349 - 8.631899321911764*lm - 4.653262195958431*
           lm^2 - 0.6746819444444444*lm^3) + 2.513137647447037*NM + 
        1.3861267909745363*lm*NM + 0.6118605507803208*lm^2*NM + 
        0.12266944444444444*lm^3*NM + 2.531453619418048*NL + 
        1.3680767909745362*lm*NL + 0.6118605507803208*lm^2*NL + 
        0.12266944444444444*lm^3*NL - 0.38363168755764326*NH + 
        3.3680767909745364*lm*NH + 0.6118605507803208*lm^2*NH + 
        0.12266944444444444*lm^3*NH)}, 
     {0.1, CF*NC*(CF*(-6.426242383216699 - 4.941472849485901*lm - 
          2.466798865426746*lm^2 - 2.22*lm^3) + 
        CA*(-8.985093884892756 - 8.668774019500926*lm - 4.6772857644359505*
           lm^2 - 0.6783333333333333*lm^3) + 2.5213597359524287*NM + 
        1.3939599408412813*lm*NM + 0.6149610480792637*lm^2*NM + 
        0.12333333333333334*lm^3*NM + 2.5419849470147478*NL + 
        1.3739599408412813*lm*NL + 0.6149610480792637*lm^2*NL + 
        0.12333333333333334*lm^3*NL - 0.38991787752355*NH + 
        3.3739599408412815*lm*NH + 0.6149610480792637*lm^2*NH + 
        0.12333333333333334*lm^3*NH)}, 
     {0.105, CF*NC*(CF*(-6.433432266028284 - 4.949677753742215*lm - 
          2.4760745826773554*lm^2 - 2.23205*lm^3) + 
        CA*(-9.011808701204268 - 8.705291803892072*lm - 4.7014167127625255*
           lm^2 - 0.6820152777777778*lm^3) + 2.529351087975452*NM + 
        1.401842996301702*lm*NM + 0.6180704629265197*lm^2*NM + 
        0.12400277777777778*lm^3*NM + 2.5524478708131104*NL + 
        1.3797929963017022*lm*NL + 0.6180704629265197*lm^2*NL + 
        0.12400277777777778*lm^3*NL - 0.39620686986246745*NH + 
        3.379792996301702*lm*NH + 0.6180704629265197*lm^2*NH + 
        0.12400277777777778*lm^3*NH)}, 
     {0.11, CF*NC*(CF*(-6.4398165169859345 - 4.956963716831313*lm - 
          2.485113095602847*lm^2 - 2.2442*lm^3) + 
        CA*(-9.037698735799001 - 8.741440866301696*lm - 4.72565191810087*
           lm^2 - 0.6857277777777778*lm^3) + 2.5371094908893674*NM + 
        1.409774532944286*lm*NM + 0.6211882275334915*lm^2*NM + 
        0.12467777777777778*lm^3*NM + 2.562843559152774*NL + 
        1.385574532944286*lm*NL + 0.6211882275334915*lm^2*NL + 
        0.12467777777777778*lm^3*NL - 0.40249688896416225*NH + 
        3.3855745329442857*lm*NH + 0.6211882275334915*lm^2*NH + 
        0.12467777777777778*lm^3*NH)}, 
     {0.115, CF*NC*(CF*(-6.445435074391967 - 4.963332699497302*lm - 
          2.4939044376718984*lm^2 - 2.25645*lm^3) + 
        CA*(-9.062770983551175 - 8.777210062872804*lm - 4.7499883351219685*
           lm^2 - 0.6894708333333334*lm^3) + 2.544632879235623*NM + 
        1.4177532293174504*lm*NM + 0.6243137882039943*lm^2*NM + 
        0.12535833333333332*lm^3*NM + 2.573173256052994*NL + 
        1.3913032293174503*lm*NL + 0.6243137882039943*lm^2*NL + 
        0.12535833333333332*lm^3*NL - 0.40878620009154726*NH + 
        3.3913032293174505*lm*NH + 0.6243137882039943*lm^2*NH + 
        0.12535833333333332*lm^3*NH)}, 
     {0.12, CF*NC*(CF*(-6.450327132725012 - 4.968787753695892*lm - 
          2.5024388810379032*lm^2 - 2.2688*lm^3) + 
        CA*(-9.087033007310259 - 8.81258886440223*lm - 4.774422991428248*
           lm^2 - 0.6932444444444444*lm^3) + 2.551919318615894*NM + 
        1.4257778588481573*lm*NM + 0.6274466045021058*lm^2*NM + 
        0.12604444444444443*lm^3*NM + 2.5834382692281626*NL + 
        1.3969778588481574*lm*NL + 0.6274466045021058*lm^2*NL + 
        0.12604444444444443*lm^3*NL - 0.415073107403009*NH + 
        3.3969778588481576*lm*NH + 0.6274466045021058*lm^2*NH + 
        0.12604444444444443*lm^3*NH)}, 
     {0.125, CF*NC*(CF*(-6.454531107455804 - 4.973332928221936*lm - 
          2.510706922990719*lm^2 - 2.28125*lm^3) + 
        CA*(-9.110492862902948 - 8.847567311541495*lm - 4.798952983413831*
           lm^2 - 0.6970486111111112*lm^3) + 2.558966991729881*NM + 
        1.4338472826545727*lm*NM + 0.6305861484994844*lm^2*NM + 
        0.1267361111111111*lm^3*NM + 2.5936399598446775*NL + 
        1.4025972826545727*lm*NL + 0.6305861484994844*lm^2*NL + 
        0.1267361111111111*lm^3*NL - 0.42135595216059174*NH + 
        3.4025972826545727*lm*NH + 0.6305861484994844*lm^2*NH + 
        0.1267361111111111*lm^3*NH)}, 
     {0.13, CF*NC*(CF*(-6.458084609786558 - 4.976973184903155*lm - 
          2.518699273651409*lm^2 - 2.2938*lm^3) + 
        CA*(-9.133159034185784 - 8.882135974690787*lm - 4.823575472504597*
           lm^2 - 0.7008833333333333*lm^3) + 2.56577418621171*NM + 
        1.44196044312413*lm*NM + 0.633731904091745*lm^2*NM + 
        0.12743333333333334*lm^3*NM + 2.6037797337264688*NL + 
        1.4081604431241301*lm*NL + 0.633731904091745*lm^2*NL + 
        0.12743333333333334*lm^3*NL - 0.42763311109931473*NH + 
        3.40816044312413*lm*NH + 0.633731904091745*lm^2*NH + 
        0.12743333333333334*lm^3*NH)}, 
     {0.135, CF*NC*(CF*(-6.461024429331354 - 4.979714323856491*lm - 
          2.5264068447534074*lm^2 - 2.30645*lm^3) + 
        CA*(-9.15504037655684 - 8.916285917942126*lm - 4.848287681730207*
           lm^2 - 0.7047486111111111*lm^3) + 2.5723392839840766*NM + 
        1.4501163581509946*lm*NM + 0.6368833663751893*lm^2*NM + 
        0.12813611111111112*lm^3*NM + 2.6138590337736085*NL + 
        1.4136663581509945*lm*NL + 0.6368833663751893*lm^2*NL + 
        0.12813611111111112*lm^3*NL - 0.43390299493702045*NH + 
        3.4136663581509943*lm*NH + 0.6368833663751893*lm^2*NH + 
        0.12813611111111112*lm^3*NH)}, 
     {0.14, CF*NC*(CF*(-6.463386523169598 - 4.981562916562817*lm - 
          2.5338207393783203*lm^2 - 2.3192*lm^3) + 
        CA*(-9.17614606763022 - 8.950008666536288*lm - 4.87308689258782*
           lm^2 - 0.7086444444444444*lm^3) + 2.578660751901028*NM + 
        1.4583141159448898*lm*NM + 0.6400400410765733*lm^2*NM + 
        0.12884444444444446*lm^3*NM + 2.6238793334028703*NL + 
        1.4191141159448897*lm*NL + 0.6400400410765733*lm^2*NL + 
        0.12884444444444446*lm^3*NL - 0.4401640470074593*NH + 
        3.4191141159448897*lm*NH + 0.6400400410765733*lm^2*NH + 
        0.12884444444444446*lm^3*NH)}, 
     {0.145, CF*NC*(CF*(-6.465206010024379 - 4.982526245722823*lm - 
          2.540932242534737*lm^2 - 2.33205*lm^3) + 
        CA*(-9.196485564009699 - 8.983296177384988*lm - 4.897970442163392*
           lm^2 - 0.7125708333333334*lm^3) + 2.5847371334910587*NM + 
        1.4665528703376425*lm*NM + 0.6432014440297076*lm^2*NM + 
        0.12955833333333333*lm^3*NM + 2.6338421308539655*NL + 
        1.4245028703376423*lm*NL + 0.6432014440297076*lm^2*NL + 
        0.12955833333333333*lm^3*NL - 0.4464147420019918*NH + 
        3.4245028703376423*lm*NH + 0.6432014440297076*lm^2*NH + 
        0.12955833333333333*lm^3*NH)}, 
     {0.15, CF*NC*(CF*(-6.466517168566049 - 4.982612251023712*lm - 
          2.547732812484849*lm^2 - 2.345*lm^3) + 
        CA*(-9.216068563282475 - 9.01614081228028*lm - 4.922935720481481*
           lm^2 - 0.7165277777777778*lm^3) + 2.5905670416446593*NM + 
        1.47483183652543*lm*NM + 0.6463671006936027*lm^2*NM + 
        0.13027777777777777*lm^3*NM + 2.643748944232812*NL + 
        1.42983183652543*lm*NL + 0.6463671006936027*lm^2*NL + 
        0.13027777777777777*lm^3*NL - 0.4526535848074749*NH + 
        3.42983183652543*lm*NH + 0.6463671006936027*lm^2*NH + 
        0.13027777777777777*lm^3*NH)}, 
     {0.155, CF*NC*(CF*(-6.4673534390361915 - 4.981829480081777*lm - 
          2.5542140727372504*lm^2 - 2.35805*lm^3) + 
        CA*(-9.234904970502095 - 9.04853531347037*lm - 4.947980168058605*
           lm^2 - 0.7205152777777778*lm^3) + 2.5961491521164564*NM + 
        1.4831502871941877*lm*NM + 0.649536545707625*lm^2*NM + 
        0.13100277777777777*lm^3*NM + 2.6536013071852467*NL + 
        1.4351002871941876*lm*NL + 0.649536545707625*lm^2*NL + 
        0.13100277777777777*lm^3*NL - 0.45887910942969345*NH + 
        3.435100287194188*lm*NH + 0.649536545707625*lm^2*NH + 
        0.13100277777777777*lm^3*NH)}, 
     {0.16, CF*NC*(CF*(-6.4677474275408215 - 4.980187043936766*lm - 
          2.5603678046355274*lm^2 - 2.3712*lm^3) + 
        CA*(-9.253004868548905 - 9.080472781328249*lm - 4.973101273638633*
           lm^2 - 0.7245333333333334*lm^3) + 2.6014821977331275*NM + 
        1.4915075489833973*lm*NM + 0.6527093224797516*lm^2*NM + 
        0.13173333333333334*lm^3*NM + 2.6634007651123417*NL + 
        1.4403075489833974*lm*NL + 0.6527093224797516*lm^2*NL + 
        0.13173333333333334*lm^3*NL - 0.4650898779931869*NH + 
        3.440307548983397*lm*NH + 0.6527093224797516*lm^2*NH + 
        0.13173333333333334*lm^3*NH)}, 
     {0.165, CF*NC*(CF*(-6.467730912483847 - 4.977694576565116*lm - 
          2.566185940481648*lm^2 - 2.38445*lm^3) + 
        CA*(-9.27037849185355 - 9.111946653878434*lm - 4.998296572091615*
           lm^2 - 0.7285819444444445*lm^3) + 2.6065649632153685*NM + 
        1.499902999249903*lm*NM + 0.655884982804536*lm^2*NM + 
        0.13246944444444445*lm^3*NM + 2.673148871852875*NL + 
        1.4454529992499028*lm*NL + 0.655884982804536*lm^2*NL + 
        0.13246944444444445*lm^3*NL - 0.4712844798095586*NH + 
        3.445452999249903*lm*NH + 0.655884982804536*lm^2*NH + 
        0.13246944444444445*lm^3*NH)}, 
     {0.17, CF*NC*(CF*(-6.467334852709403 - 4.974362197954847*lm - 
          2.5716605571410414*lm^2 - 2.3978*lm^3) + 
        CA*(-9.287036203048444 - 9.14295068797954*lm - 5.023563642459763*
           lm^2 - 0.7326611111111111*lm^3) + 2.6113962805362227*NM + 
        1.5083360630987253*lm*NM + 0.6590630865078356*lm^2*NM + 
        0.1332111111111111*lm^3*NM + 2.6828471867702275*NL + 
        1.4505360630987252*lm*NL + 0.6590630865078356*lm^2*NL + 
        0.1332111111111111*lm^3*NL - 0.4774615305073959*NH + 
        3.4505360630987254*lm*NH + 0.6590630865078356*lm^2*NH + 
        0.1332111111111111*lm^3*NH)}, 
     {0.175, CF*NC*(CF*(-6.466589397000164 - 4.970200480347907*lm - 
          2.57678387008293*lm^2 - 2.41125*lm^3) + 
        CA*(-9.302988472177459 - 9.173478941987522*lm - 5.0489001061364505*
           lm^2 - 0.7367708333333334*lm^3) + 2.6159750247496207*NM + 
        1.5168062106523148*lm*NM + 0.6622432011157183*lm^2*NM + 
        0.13395833333333335*lm^3*NM + 2.692497272190625*NL + 
        1.4555562106523148*lm*NL + 0.6622432011157183*lm^2*NL + 
        0.13395833333333335*lm^3*NL - 0.4836196712178042*NH + 
        3.4555562106523148*lm*NH + 0.6622432011157183*lm^2*NH + 
        0.13395833333333335*lm^3*NH)}, 
     {0.18, CF*NC*(CF*(-6.4655238946421365 - 4.965220417308657*lm - 
          2.58154822781514*lm^2 - 2.4248*lm^3) + 
        CA*(-9.318245858148316 - 9.203525759747235*lm - 5.074303625165737*
           lm^2 - 0.7409111111111111*lm^3) + 2.6203001102325656*NM + 
        1.5253129545334259*lm*NM + 0.6654249015452856*lm^2*NM + 
        0.13471111111111111*lm^3*NM + 2.70210069114758*NL + 
        1.4605129545334259*lm*NL + 0.6654249015452856*lm^2*NL + 
        0.13471111111111111*lm^3*NL - 0.4897575678103019*NH + 
        3.460512954533426*lm*NH + 0.6654249015452856*lm^2*NH + 
        0.13471111111111111*lm^3*NH)}, 
     {0.185, CF*NC*(CF*(-6.464166906817873 - 4.959433395321744*lm - 
          2.5859461066774423*lm^2 - 2.43845*lm^3) + 
        CA*(-9.332818992157138 - 9.233085755779323*lm - 5.099771900651441*
           lm^2 - 0.7450819444444444*lm^3) + 2.624370487292387*NM + 
        1.533855847539969*lm*NM + 0.6686077698154135*lm^2*NM + 
        0.13546944444444445*lm^3*NM + 2.7116590053939884*NL + 
        1.4654058475399692*lm*NL + 0.6686077698154135*lm^2*NL + 
        0.13546944444444445*lm^3*NL - 0.49587391017445537*NH + 
        3.465405847539969*lm*NH + 0.6686077698154135*lm^2*NH + 
        0.13546944444444445*lm^3*NH)}, 
     {0.19, CF*NC*(CF*(-6.462546218632033 - 4.952851167660349*lm - 
          2.5899701059616342*lm^2 - 2.4522*lm^3) + 
        CA*(-9.346718562852349 - 9.262153801545786*lm - 5.125302671266055*
           lm^2 - 0.7492833333333333*lm^3) + 2.6281851390971602*NM + 
        1.5424344804928882*lm*NM + 0.6717913947756463*lm^2*NM + 
        0.13623333333333335*lm^3*NM + 2.721173773648854*NL + 
        1.4702344804928884*lm*NL + 0.6717913947756463*lm^2*NL + 
        0.13623333333333335*lm^3*NL - 0.5019674115431749*NH + 
        3.470234480492888*lm*NH + 0.6717913947756463*lm^2*NH + 
        0.13623333333333335*lm^3*NH)}, 
     {0.195, CF*NC*(CF*(-6.4606888516075465 - 4.945485830297918*lm - 
          2.593612943330127*lm^2 - 2.46605*lm^3) + 
        CA*(-9.359955303036841 - 9.290725012691677*lm - 5.150893711850872*
           lm^2 - 0.7535152777777778*lm^3) + 2.631743078893032*NM + 
        1.551048480240406*lm*NM + 0.6749753718516738*lm^2*NM + 
        0.13700277777777778*lm^3*NM + 2.730646550050198*NL + 
        1.4749984802404061*lm*NL + 0.6749753718516738*lm^2*NL + 
        0.13700277777777778*lm^3*NL - 0.5080368078540572*NH + 
        3.4749984802404064*lm*NH + 0.6749753718516738*lm^2*NH + 
        0.13700277777777778*lm^3*NH)}, 
     {0.2, NC*(CF^2*(-6.4586210765188605 - 4.937349799663929*lm - 
          2.596867450507908*lm^2 - 2.48*lm^3) + 
        CA*CF*(-9.372539977734037 - 9.318794737172341*lm - 
          5.1765428320996385*lm^2 - 0.7577777777777778*lm^3) + 
        CF*((2.635043347476949 + 1.5596975078039501*lm + 0.6781593028059949*
             lm^2 + 0.13777777777777778*lm^3)*NM + 
          (2.7400788827896227 + 1.4796975078039503*lm + 0.6781593028059949*
             lm^2 + 0.13777777777777778*lm^3)*NL + 
          (-0.5140808571455638 + 3.4796975078039503*lm + 0.6781593028059949*
             lm^2 + 0.13777777777777778*lm^3)*NH))}, 
     {0.205, NC*(CF^2*(-6.456368426452 - 4.928455792067798*lm - 
          2.5997265692254157*lm^2 - 2.49405*lm^3) + 
        CA*CF*(-9.38448337346621 - 9.34635854418601*lm - 5.202247875318877*
           lm^2 - 0.7620708333333334*lm^3) + 
        CF*((2.6380850108973255 + 1.5683812566527637*lm + 0.6813427955125231*
             lm^2 + 0.13855833333333334*lm^3)*NM + 
          (2.749472312907263 + 1.4843312566527638*lm + 0.6813427955125231*
             lm^2 + 0.13855833333333334*lm^3)*NL + 
          (-0.5200983389851715 + 3.484331256652764*lm + 0.6813427955125231*
             lm^2 + 0.13855833333333334*lm^3)*NH))}, 
     {0.21, NC*(CF^2*(-6.4539557100004235 - 4.918816804635334*lm - 
          2.6021833473922165*lm^2 - 2.5082*lm^3) + 
        CA*CF*(-9.395796288612713 - 9.3734122138405*lm - 5.228006717258733*
           lm^2 - 0.7663944444444445*lm^3) + 
        CF*((2.6408671583586387 + 1.5770994510956724*lm + 0.684525463744012*
             lm^2 + 0.13934444444444444*lm^3)*NM + 
          (2.7588283732286536 + 1.4888994510956726*lm + 0.684525463744012*
             lm^2 + 0.13934444444444444*lm^3)*NL + 
          (-0.5260880539269343 + 3.4888994510956723*lm + 0.684525463744012*
             lm^2 + 0.13934444444444444*lm^3)*NH))}, 
     {0.215, NC*(CF^2*(-6.45140702452159 - 4.908446097619693*lm - 
          2.6042309354834012*lm^2 - 2.52245*lm^3) + 
        CA*CF*(-9.406489524732354 - 9.399951727490526*lm - 
          5.253817265008817*lm^2 - 0.7707486111111111*lm^3) + 
        CF*((2.643388900308888 + 1.5858518447797394*lm + 0.6877069269713001*
             lm^2 + 0.1401361111111111*lm^3)*NM + 
          (2.768148587427407 + 1.4934018447797395*lm + 0.6877069269713001*
             lm^2 + 0.1401361111111111*lm^3)*NL + 
          (-0.5320488229961602 + 3.4934018447797395*lm + 0.6877069269713001*
             lm^2 + 0.1401361111111111*lm^3)*NH))}, 
     {0.22, NC*(CF^2*(-6.448745769392416 - 4.897357177963989*lm - 
          2.605862583122433*lm^2 - 2.5368*lm^3) + 
        CA*CF*(-9.416573878748226 - 9.425973258688947*lm - 
          5.279677455954077*lm^2 - 0.7751333333333333*lm^3) + 
        CF*((2.6456493666913885 + 1.594638219286653*lm + 0.6908868101734685*
             lm^2 + 0.14093333333333333*lm^3)*NM + 
          (2.777434469199641 + 1.497838219286653*lm + 0.6908868101734685*
             lm^2 + 0.14093333333333333*lm^3)*NL + 
          (-0.5379794871991402 + 3.497838219286653*lm + 0.6908868101734685*
             lm^2 + 0.14093333333333333*lm^3)*NH))}, 
     {0.225, NC*(CF^2*(-6.445994659212849 - 4.885563784006017*lm - 
          2.6070716358457364*lm^2 - 2.55125*lm^3) + 
        CA*CF*(-9.426060135905564 - 9.451473164701104*lm - 
          5.305585256786197*lm^2 - 0.7795486111111111*lm^3) + 
        CF*((2.647647705344554 + 1.6034583828186486*lm + 0.6940647436580965*
             lm^2 + 0.14173611111111112*lm^3)*NM + 
          (2.7866875215378135 + 1.5022083828186485*lm + 0.6940647436580965*
             lm^2 + 0.14173611111111112*lm^3)*NL + 
          (-0.5438789070560671 + 3.5022083828186483*lm + 0.6940647436580965*
             lm^2 + 0.14173611111111112*lm^3)*NH))}, 
     {0.23, NC*(CF^2*(-6.443175736915987 - 4.873079871227093*lm - 
          2.607851532035733*lm^2 - 2.5658*lm^3) + 
        CA*CF*(-9.434959063423722 - 9.476447978536692*lm - 
          5.331538662566474*lm^2 - 0.7839944444444444*lm^3) + 
        CF*((2.6493830805352183 + 1.612312168966609*lm + 0.6972403628908741*
             lm^2 + 0.14254444444444445*lm^3)*NM + 
          (2.7959092360931534 + 1.506512168966609*lm + 0.6972403628908741*
             lm^2 + 0.14254444444444445*lm^3)*NL + 
          (-0.5497459621554622 + 3.506512168966609*lm + 0.6972403628908741*
             lm^2 + 0.14254444444444445*lm^3)*NH))}, 
     {0.235, NC*(CF^2*(-6.440310386750901 - 4.859919598957162*lm - 
          2.608195800010248*lm^2 - 2.58045*lm^3) + 
        CA*CF*(-9.443281404772444 - 9.500894401458037*lm - 
          5.357535695836464*lm^2 - 0.7884708333333333*lm^3) + 
        CF*((2.6508546716126715 + 1.621199435553738*lm + 0.7004133083339027*
             lm^2 + 0.14335833333333334*lm^3)*NM + 
          (2.8051010926171327 + 1.510749435553738*lm + 0.7004133083339027*
             lm^2 + 0.14335833333333334*lm^3)*NL + 
          (-0.555579550728589 + 3.510749435553738*lm + 0.7004133083339027*
             lm^2 + 0.14335833333333334*lm^3)*NH))}, 
     {0.24, NC*(CF^2*(-6.437419347110759 - 4.846097317957252*lm - 
          2.608098055257326*lm^2 - 2.5952*lm^3) + 
        CA*CF*(-9.451037874510575 - 9.5248092959278*lm - 5.3835744057730714*
           lm^2 - 0.7929777777777778*lm^3) + 
        CF*((2.6520616717720276 + 1.63012006354884*lm + 0.7035832252920736*
             lm^2 + 0.14417777777777777*lm^3)*NM + 
          (2.814264558473582 + 1.51492006354884*lm + 0.7035832252920736*
             lm^2 + 0.14417777777777777*lm^3)*NL + 
          (-0.5613785892424696 + 3.51492006354884*lm + 0.7035832252920736*
             lm^2 + 0.14417777777777777*lm^3)*NH))}, 
     {0.245, NC*(CF^2*(-6.434522723184261 - 4.831627558808198*lm - 
          2.6075519978054444*lm^2 - 2.61005*lm^3) + 
        CA*CF*(-9.458239153632228 - 9.548189678962572*lm - 
          5.409652867384997*lm^2 - 0.7975152777777778*lm^3) + 
        CF*((2.653003286916776 + 1.6390739560438259*lm + 0.7067497637669692*
             lm^2 + 0.14500277777777779*lm^3)*NM + 
          (2.823401088214001 + 1.519023956043826*lm + 0.7067497637669692*
             lm^2 + 0.14500277777777779*lm^3)*NL + 
          (-0.567142012010247 + 3.5190239560438257*lm + 0.7067497637669692*
             lm^2 + 0.14500277777777779*lm^3)*NH))}, 
     {0.25, NC*(CF^2*(-6.431639999412927 - 4.816525021041488*lm - 
          2.6065514097200273*lm^2 - 2.625*lm^3) + 
        CA*CF*(-9.464895885371455 - 9.571032715862017*lm - 
          5.435769180747786*lm^2 - 0.8020833333333334*lm^3) + 
        CF*((2.6536787346114576 + 1.6480610372905753*lm + 0.7099125783177793*
             lm^2 + 0.14583333333333334*lm^3)*NM + 
          (2.8325121232094683 + 1.5230610372905753*lm + 0.7099125783177793*
             lm^2 + 0.14583333333333334*lm^3)*NL + 
          (-0.5728687708177459 + 3.5230610372905753*lm + 0.7099125783177793*
             lm^2 + 0.14583333333333334*lm^3)*NH))}, 
     {0.255, NC*(CF^2*(-6.428790051740598 - 4.800804562954243*lm - 
          2.605090152717888*lm^2 - 2.64005*lm^3) + 
        CA*CF*(-9.47101867142179 - 9.593335714286042*lm - 
          5.46192147027491*lm^2 - 0.8066819444444444*lm^3) + 
        CF*((2.6540872431163685 + 1.6570812517927302*lm + 0.7130713279287716*
             lm^2 + 0.14666944444444444*lm^3)*NM + 
          (2.8415990913333067 + 1.5270312517927302*lm + 0.7130713279287716*
             lm^2 + 0.14666944444444444*lm^3)*NL + 
          (-0.5785578345651867 + 3.5270312517927302*lm + 0.7130713279287716*
             lm^2 + 0.14666944444444444*lm^3)*NH))}, 
     {0.26, NC*(CF^2*(-6.425991159644696 - 4.784481192055789*lm - 
          2.6031621658919817*lm^2 - 2.6552*lm^3) + 
        CA*CF*(-9.4766180685316 - 9.615096118654888*lm - 
          5.48810788402255*lm^2 - 0.8113111111111111*lm^3) + 
        CF*((2.654228050497023 + 1.6661345634484093*lm + 0.7162256758828879*
             lm^2 + 0.14751111111111112*lm^3)*NM + 
          (2.850663406689285 + 1.5309345634484093*lm + 0.7162256758828879*
             lm^2 + 0.14751111111111112*lm^3)*NL + 
          (-0.5842081889230938 + 3.530934563448409*lm + 0.7162256758828879*
             lm^2 + 0.14751111111111112*lm^3)*NH))}, 
     {0.265, NC*(CF^2*(-6.423261017941485 - 4.767570056098118*lm - 
          2.600761463539443*lm^2 - 2.67045*lm^3) + 
        CA*CF*(-9.481704585440308 - 9.636311504849354*lm - 
          5.514326593025941*lm^2 - 0.8159708333333333*lm^3) + 
        CF*((2.654100403801862 + 1.6752209547401815*lm + 0.7193752896410802*
             lm^2 + 0.14835833333333334*lm^3)*NM + 
          (2.8597064693807313 + 1.5347709547401815*lm + 0.7193752896410802*
             lm^2 + 0.14835833333333334*lm^3)*NL + 
          (-0.589818836001518 + 3.5347709547401815*lm + 0.7193752896410802*
             lm^2 + 0.14835833333333334*lm^3)*NH))}, 
     {0.27, NC*(CF^2*(-6.420616748359796 - 4.750086434646897*lm - 
          2.5978821330864594*lm^2 - 2.6858*lm^3) + 
        CA*CF*(-9.48628868012417 - 9.656979575190267*lm - 
          5.540575790665307*lm^2 - 0.8206611111111111*lm^3) + 
        CF*((2.6537035583023356 + 1.6843404259689727*lm + 0.7225198407270255*
             lm^2 + 0.1492111111111111*lm^3)*NM + 
          (2.8687296653164025 + 1.5385404259689726*lm + 0.7225198407270255*
             lm^2 + 0.1492111111111111*lm^3)*NL + 
          (-0.5953887940317706 + 3.538540425968973*lm + 0.7225198407270255*
             lm^2 + 0.1492111111111111*lm^3)*NH))}, 
     {0.275, NC*(CF^2*(-6.4180749108796205 - 4.732045731153507*lm - 
          2.594518333104047*lm^2 - 2.70125*lm^3) + 
        CA*CF*(-9.49038075732339 - 9.677098153678159*lm - 
          5.56685369205957*lm^2 - 0.8253819444444445*lm^3) + 
        CF*((2.653036776790072 + 1.6934929945288475*lm + 0.7256590046168915*
             lm^2 + 0.15006944444444445*lm^3)*NM + 
          (2.877734366049427 + 1.5422429945288474*lm + 0.7256590046168915*
             lm^2 + 0.15006944444444445*lm^3)*NL + 
          (-0.6009170970599222 + 3.5422429945288476*lm + 0.7256590046168915*
             lm^2 + 0.15006944444444445*lm^3)*NH))}, 
     {0.28, NC*(CF^2*(-6.415651514833476 - 4.7134634654921*lm - 
          2.5906642914092584*lm^2 - 2.7168*lm^3) + 
        CA*CF*(-9.493991166325252 - 9.696665181475684*lm - 
          5.593158533486163*lm^2 - 0.8301333333333333*lm^3) + 
        CF*((2.652099328926361 + 1.7026786942198915*lm + 0.7287924606338477*
             lm^2 + 0.15093333333333334*lm^3)*NM + 
          (2.8867219286459913 + 1.5458786942198914*lm + 0.7287924606338477*
             lm^2 + 0.15093333333333334*lm^3)*NL + 
          (-0.606402794651387 + 3.5458786942198914*lm + 0.7287924606338477*
             lm^2 + 0.15093333333333334*lm^3)*NH))}, 
     {0.285, NC*(CF^2*(-6.413362029769839 - 4.694355266928738*lm - 
          2.586314303246755*lm^2 - 2.73245*lm^3) + 
        CA*CF*(-9.497130198980429 - 9.715678712616764*lm - 
          5.619488571825397*lm^2 - 0.8349152777777777*lm^3) + 
        CF*((2.6508904906396347 + 1.711897574596629*lm + 0.731919891847042*
             lm^2 + 0.1518027777777778*lm^3)*NM + 
          (2.895693695580813 + 1.549447574596629*lm + 0.731919891847042*
             lm^2 + 0.1518027777777778*lm^3)*NL + 
          (-0.6118449516059584 + 3.549447574596629*lm + 0.731919891847042*
             lm^2 + 0.1518027777777778*lm^3)*NH))}, 
     {0.29, NC*(CF^2*(-6.411221396078995 - 4.6747368674924905*lm - 
          2.581462729546083*lm^2 - 2.7482*lm^3) + 
        CA*CF*(-9.499808087931816 - 9.73413690992773*lm - 
          5.6458420840279695*lm^2 - 0.8397277777777777*lm^3) + 
        CF*((2.649409543567037 + 1.7211497003496377*lm + 0.7350409849747823*
             lm^2 + 0.15267777777777777*lm^3)*NM + 
          (2.9046509946567327 + 1.5529497003496375*lm + 0.7350409849747823*
             lm^2 + 0.15267777777777777*lm^3)*NL + 
          (-0.6172426476827143 + 3.5529497003496378*lm + 0.7350409849747823*
             lm^2 + 0.15267777777777777*lm^3)*NH))}, 
     {0.295, NC*(CF^2*(-6.40924403538256 - 4.654624095720878*lm - 
          2.5761039952503055*lm^2 - 2.76405*lm^3) + 
        CA*CF*(-9.502035005037255 - 9.752038041146946*lm - 
          5.67221736660426*lm^2 - 0.8445708333333334*lm^3) + 
        CF*((2.647655774536535 + 1.7304351507182008*lm + 0.7381554302916836*
             lm^2 + 0.15355833333333332*lm^3)*NM + 
          (2.9135951389460226 + 1.5563851507182007*lm + 0.7381554302916836*
             lm^2 + 0.15355833333333332*lm^3)*NL + 
          (-0.6225949773342525 + 3.5563851507182007*lm + 0.7381554302916836*
             lm^2 + 0.15355833333333332*lm^3)*NH))}, 
     {0.3, NC*(CF^2*(-6.407443860688723 - 4.634032870754314*lm - 
          2.5702325877119954*lm^2 - 2.78*lm^3) + 
        CA*CF*(-9.503821059969285 - 9.769380475230415*lm - 
          5.698612735134221*lm^2 - 0.8494444444444444*lm^3) + 
        CF*((2.645628475086353 + 1.7397540189320162*lm + 0.7412629215395553*
             lm^2 + 0.15444444444444444*lm^3)*NM + 
          (2.922527426751263 + 1.5597540189320163*lm + 0.7412629215395553*
             lm^2 + 0.15444444444444444*lm^3)*NL + 
          (-0.6279010494497551 + 3.5597540189320163*lm + 0.7412629215395553*
             lm^2 + 0.15444444444444444*lm^3)*NH))}, 
     {0.305, NC*(CF^2*(-6.40583428631581 - 4.612979196756258*lm - 
          2.56384305515284*lm^2 - 2.79605*lm^3) + 
        CA*CF*(-9.505176298976604 - 9.786162678831877*lm - 
          5.725026523796701*lm^2 - 0.8543486111111112*lm^3) + 
        CF*((2.6433269410188 + 1.7491064116801294*lm + 0.7443631558418244*
             lm^2 + 0.15533611111111112*lm^3)*NM + 
          (2.9314491415838435 + 1.5630564116801293*lm + 0.7443631558418244*
             lm^2 + 0.15533611111111112*lm^3)*NL + 
          (-0.6331599871064183 + 3.563056411680129*lm + 0.7443631558418244*
             lm^2 + 0.15533611111111112*lm^3)*NH))}, 
     {0.31, NC*(CF^2*(-6.404428237587338 - 4.591479157637647*lm - 
          2.5569300051834047*lm^2 - 2.8122*lm^3) + 
        CA*CF*(-9.50611070379337 - 9.80238321294675*lm - 5.751457084917152*
           lm^2 - 0.8592833333333333*lm^3) + 
        CF*((2.6407504719858204 + 1.7584924486054048*lm + 0.7474558336213003*
             lm^2 + 0.15623333333333334*lm^3)*NM + 
          (2.9403615521583335 + 1.5662924486054048*lm + 0.7474558336213003*
             lm^2 + 0.15623333333333334*lm^3)*NL + 
          (-0.6383709273288145 + 3.5662924486054046*lm + 0.7474558336213003*
             lm^2 + 0.15623333333333334*lm^3)*NH))}, 
     {0.315, NC*(CF^2*(-6.403238160302081 - 4.569548912065859*lm - 
          2.549488103379825*lm^2 - 2.82845*lm^3) + 
        CA*CF*(-9.506634190683734 - 9.8180407297101*lm - 5.7779027885327245*
           lm^2 - 0.8642486111111111*lm^3) + 
        CF*((2.637898371103836 + 1.7679122618229757*lm + 0.7505406585211014*
             lm^2 + 0.15713611111111112*lm^3)*NM + 
          (2.949265912401144 + 1.5694622618229759*lm + 0.7505406585211014*
             lm^2 + 0.15713611111111112*lm^3)*NL + 
          (-0.643533020855788 + 3.569462261822976*lm + 0.7505406585211014*
             lm^2 + 0.15713611111111112*lm^3)*NH))}, 
     {0.32, NC*(CF^2*(-6.402276029983021 - 4.547204688739982*lm - 
          2.5415120719144175*lm^2 - 2.8448*lm^3) + 
        CA*CF*(-9.506756609610127 - 9.83313396933949*lm - 
          5.80436202197385*lm^2 - 0.8692444444444445*lm^3) + 
        CF*((2.63476994459566 + 1.777365995461226*lm + 0.7536173373285787*
             lm^2 + 0.15804444444444443*lm^3)*NM + 
          (2.9581634614720507 + 1.5725659954612259*lm + 0.7536173373285787*
             lm^2 + 0.15804444444444443*lm^3)*NL + 
          (-0.6486454319145063 + 3.572565995461226*lm + 0.7536173373285787*
             lm^2 + 0.15804444444444443*lm^3)*NH))}, 
     {0.325, NC*(CF^2*(-6.401553360909305 - 4.524462781915572*lm - 
          2.5329966882374104*lm^2 - 2.86125*lm^3) + 
        CA*CF*(-9.50648774351484 - 9.84766175721432*lm - 5.830833189461431*
           lm^2 - 0.8742708333333333*lm^3) + 
        CF*((2.6313645014574445 + 1.7868538052239689*lm + 0.7566855799020784*
             lm^2 + 0.15895833333333334*lm^3)*NM + 
          (2.967055423797284 + 1.5756038052239687*lm + 0.7566855799020784*
             lm^2 + 0.15895833333333334*lm^3)*NL + 
          (-0.6537073380013205 + 3.575603805223969*lm + 0.7566855799020784*
             lm^2 + 0.15895833333333334*lm^3)*NH))}, 
     {0.33, NC*(CF^2*(-6.401081214935516 - 4.501339547163322*lm - 
          2.5239367838071676*lm^2 - 2.8778*lm^3) + 
        CA*CF*(-9.505837307705416 - 9.861623001083753*lm - 
          5.857314711718857*lm^2 - 0.8793277777777778*lm^3) + 
        CF*((2.627681353148813 + 1.7963758579725821*lm + 0.7597450991003982*
             lm^2 + 0.15987777777777779*lm^3)*NM + 
          (2.9759430091130192 + 1.5785758579725822*lm + 0.7597450991003982*
             lm^2 + 0.15987777777777779*lm^3)*NL + 
          (-0.6587179296691086 + 3.578575857972582*lm + 0.7597450991003982*
             lm^2 + 0.15987777777777779*lm^3)*NH))}, 
     {0.335, NC*(CF^2*(-6.4008702101027115 - 4.477851397347264*lm - 
          2.5143272428664614*lm^2 - 2.89445*lm^3) + 
        CA*CF*(-9.504814949335115 - 9.87501668839599*lm - 
          5.883805025598085*lm^2 - 0.8844152777777777*lm^3) + 
        CF*((2.6237198133044615 + 1.805932331326947*lm + 0.7627956107148034*
             lm^2 + 0.16080277777777777*lm^3)*NM + 
          (2.9848274125182037 + 1.581482331326947*lm + 0.7627956107148034*
             lm^2 + 0.16080277777777777*lm^3)*NL + 
          (-0.6636764103207945 + 3.581482331326947*lm + 0.7627956107148034*
             lm^2 + 0.16080277777777777*lm^3)*NH))}, 
     {0.34, NC*(CF^2*(-6.400930529045788 - 4.4540147988091165*lm - 
          2.504163001262503*lm^2 - 2.9112*lm^3) + 
        CA*CF*(-9.503430246970558 - 9.88784188374209*lm - 
          5.910302583719099*lm^2 - 0.8895333333333333*lm^3) + 
        CF*((2.619479197465676 + 1.81552341328412*lm + 0.7658368334034724*
             lm^2 + 0.16173333333333334*lm^3)*NM + 
          (2.993709814535758 + 1.58432341328412*lm + 0.7658368334034724*
             lm^2 + 0.16173333333333334*lm^3)*NL + 
          (-0.6685819960087599 + 3.58432341328412*lm + 0.7658368334034724*
             lm^2 + 0.16173333333333334*lm^3)*NH))}, 
     {0.345, NC*(CF^2*(-6.401271927201791 - 4.429846267746438*lm - 
          2.4934390453085773*lm^2 - 2.92805*lm^3) + 
        CA*CF*(-9.50169271023926 - 9.900097726408024*lm - 
          5.936805854122065*lm^2 - 0.8946819444444445*lm^3) + 
        CF*((2.614958822830326 + 1.8251493018537424*lm + 0.7688684886282543*
             lm^2 + 0.16266944444444445*lm^3)*NM + 
          (3.002591381181285 + 1.5870993018537425*lm + 0.7688684886282543*
             lm^2 + 0.16266944444444445*lm^3)*NL + 
          (-0.67343391523988 + 3.5870993018537423*lm + 0.7688684886282543*
             lm^2 + 0.16266944444444445*lm^3)*NH))}, 
     {0.35, NC*(CF^2*(-6.401903740823829 - 4.405362366773039*lm - 
          2.4821504106852776*lm^2 - 2.945*lm^3) + 
        CA*CF*(-9.499611779550442 - 9.911783428029082*lm - 
          5.963313319931612*lm^2 - 0.8998611111111111*lm^3) + 
        CF*((2.6101580080200146 + 1.834810204709259*lm + 0.7718903005936265*
             lm^2 + 0.16361111111111112*lm^3)*NM + 
          (3.011473264038489 + 1.589810204709259*lm + 0.7718903005936265*
             lm^2 + 0.16361111111111112*lm^3)*NL + 
          (-0.6782314087859324 + 3.589810204709259*lm + 0.7718903005936265*
             lm^2 + 0.16361111111111112*lm^3)*NH))}, 
     {0.355, NC*(CF^2*(-6.402834894805245 - 4.380579701650994*lm - 
          2.4702921813794414*lm^2 - 2.96205*lm^3) + 
        CA*CF*(-9.49719682588303 - 9.922898270341133*lm - 
          5.989823479032607*lm^2 - 0.9050708333333334*lm^3) + 
        CF*((2.605076072863173 + 1.8445063388540814*lm + 0.7749019961877468*
             lm^2 + 0.16455833333333333*lm^3)*NM + 
          (3.020356600340586 + 1.5924563388540816*lm + 0.7749019961877468*
             lm^2 + 0.16455833333333333*lm^3)*NL + 
          (-0.6829737294991435 + 3.5924563388540816*lm + 0.7749019961877468*
             lm^2 + 0.16455833333333333*lm^3)*NH))}, 
     {0.36, NC*(CF^2*(-6.404073910318714 - 4.3555149181843*lm - 
          2.4578594886590226*lm^2 - 2.9792*lm^3) + 
        CA*CF*(-9.494457150635263 - 9.933441603023606*lm - 
          6.0163348437569235*lm^2 - 0.9103111111111111*lm^3) + 
        CF*((2.599712338192982 + 1.8542379303018879*lm + 0.7779033049255013*
             lm^2 + 0.1655111111111111*lm^3)*NM + 
          (3.029242513057054 + 1.5950379303018878*lm + 0.7779033049255013*
             lm^2 + 0.1655111111111111*lm^3)*NL + 
          (-0.6876601421326509 + 3.595037930301888*lm + 0.7779033049255013*
             lm^2 + 0.1655111111111111*lm^3)*NH))}, 
     {0.365, NC*(CF^2*(-6.405628912274867 - 4.330184699264895*lm - 
          2.444847510082219*lm^2 - 2.99645*lm^3) + 
        CA*CF*(-9.491401985530802 - 9.94341284162942*lm - 
          6.042845940580678*lm^2 - 0.9155819444444444*lm^3) + 
        CF*((2.5940661256590833 + 1.8640052137703051*lm + 0.7808939588934566*
             lm^2 + 0.16646944444444445*lm^3)*NM + 
          (3.0381321109851274 + 1.5975552137703053*lm + 0.7808939588934566*
             lm^2 + 0.16646944444444445*lm^3)*NL + 
          (-0.6922899231656736 + 3.5975552137703053*lm + 0.7808939588934566*
             lm^2 + 0.16646944444444445*lm^3)*NH))}, 
     {0.37, NC*(CF^2*(-6.407507636605039 - 4.304605762062438*lm - 
          2.431251468539297*lm^2 - 3.0138*lm^3) + 
        CA*CF*(-9.488040492576658 - 9.952811465597323*lm - 
          6.069355309831452*lm^2 - 0.9208833333333334*lm^3) + 
        CF*((2.5881367575521423 + 1.8738084323872695*lm + 0.7838736926966277*
             lm^2 + 0.16743333333333332*lm^3)*NM + 
          (3.047026488845489 + 1.6000084323872694*lm + 0.7838736926966277*
             lm^2 + 0.16743333333333332*lm^3)*NL + 
          (-0.6968623606331925 + 3.6000084323872694*lm + 0.7838736926966277*
             lm^2 + 0.16743333333333332*lm^3)*NH))}, 
     {0.375, NC*(CF^2*(-6.409717437372648 - 4.278794855349757*lm - 
          2.417066631325627*lm^2 - 3.03125*lm^3) + 
        CA*CF*(-9.484381764068626 - 9.961637016342495*lm - 
          6.095861505405053*lm^2 - 0.9262152777777778*lm^3) + 
        CF*((2.5819235566403695 + 1.883647837409403*lm + 0.7868422434069793*
             lm^2 + 0.1684027777777778*lm^3)*NM + 
          (3.055926727381681 + 1.602397837409403*lm + 0.7868422434069793*
             lm^2 + 0.1684027777777778*lm^3)*NL + 
          (-0.7013767539599578 + 3.602397837409403*lm + 0.7868422434069793*
             lm^2 + 0.1684027777777778*lm^3)*NH))}, 
     {0.38, NC*(CF^2*(-6.412265293717661 - 4.25276875695647*lm - 
          2.4022883092445357*lm^2 - 3.0488*lm^3) + 
        CA*CF*(-9.480434822640238 - 9.969889095421424*lm - 
          6.122363094491386*lm^2 - 0.9315777777777777*lm^3) + 
        CF*((2.5754258460171973 + 1.8935236879517914*lm + 0.7897993505135853*
             lm^2 + 0.16937777777777777*lm^3)*NM + 
          (3.0648338934627652 + 1.6047236879517914*lm + 0.7897993505135853*
             lm^2 + 0.16937777777777777*lm^3)*NL + 
          (-0.7058324137986473 + 3.6047236879517914*lm + 0.7897993505135853*
             lm^2 + 0.16937777777777777*lm^3)*NH))}, 
     {0.385, NC*(CF^2*(-6.415157816638528 - 4.2265442713437205*lm - 
          2.3869118557386657*lm^2 - 3.06645*lm^3) + 
        CA*CF*(-9.476208621351638 - 9.977567362767385*lm - 
          6.148858657309037*lm^2 - 0.9369708333333333*lm^3) + 
        CF*((2.568642948959362 + 1.9034362507285814*lm + 0.7927447558743703*
             lm^2 + 0.17035833333333333*lm^3)*NM + 
          (3.0737490401888468 + 1.6069862507285815*lm + 0.7927447558743703*
             lm^2 + 0.17035833333333333*lm^3)*NL + 
          (-0.7102286618720115 + 3.6069862507285815*lm + 0.7927447558743703*
             lm^2 + 0.17035833333333333*lm^3)*NH))}, 
     {0.39, NC*(CF^2*(-6.41840125561587 - 4.2001382272934835*lm - 
          2.3709326660485948*lm^2 - 3.0842*lm^3) + 
        CA*CF*(-9.471712043814982 - 9.984671534993055*lm - 
          6.1753467868481815*lm^2 - 0.9423944444444444*lm^3) + 
        CF*((2.5615741887946872 + 1.9133857998038544*lm + 0.7956782036693664*
             lm^2 + 0.17134444444444444*lm^3)*NM + 
          (3.08267320699907 + 1.6091857998038543*lm + 0.7956782036693664*
             lm^2 + 0.17134444444444444*lm^3)*NL + 
          (-0.7145648308188487 + 3.6091857998038543*lm + 0.7956782036693664*
             lm^2 + 0.17134444444444444*lm^3)*NH))}, 
     {0.395, NC*(CF^2*(-6.422001505082149 - 4.173567475706256*lm - 
          2.3543461763975464*lm^2 - 3.10205*lm^3) + 
        CA*CF*(-9.466953904353298 - 9.991201383756962*lm - 
          6.201826088621472*lm^2 - 0.9478486111111111*lm^3) + 
        CF*((2.5542188887789368 + 1.9233726163522673*lm + 0.7985994403554192*
             lm^2 + 0.1723361111111111*lm^3)*NM + 
          (3.0916074197817633 + 1.6113226163522674*lm + 0.7985994403554192*
             lm^2 + 0.1723361111111111*lm^3)*NL + 
          (-0.7188402640436641 + 3.6113226163522674*lm + 0.7985994403554192*
             lm^2 + 0.1723361111111111*lm^3)*NH))}, 
     {0.4, NC*(CF^2*(-6.425964110741419 - 4.146848887501384*lm - 
          2.3371478632010816*lm^2 - 3.12*lm^3) + 
        CA*CF*(-9.461942948189952 - 9.997156734190765*lm - 
          6.228295180422553*lm^2 - 0.9533333333333334*lm^3) + 
        CF*((2.5465763719811276 + 1.9333969884289801*lm + 0.8015082146222823*
             lm^2 + 0.17333333333333334*lm^3)*NM + 
          (3.1005526909864085 + 1.6133969884289803*lm + 0.8015082146222823*
             lm^2 + 0.17333333333333334*lm^3)*NL + 
          (-0.7230543155698713 + 3.6133969884289803*lm + 0.8015082146222823*
             lm^2 + 0.17333333333333334*lm^3)*NH))}, 
     {0.405, NC*(CF^2*(-6.430294275743202 - 4.11999935161462*lm - 
          2.319333242300724*lm^2 - 3.13805*lm^3) + 
        CA*CF*(-9.456687851666093 - 10.002537463384405*lm - 
          6.254752692091888*lm^2 - 0.9588486111111111*lm^3) + 
        CF*((2.538645961176758 + 1.9434592107484199*lm + 0.8044042773500402*
             lm^2 + 0.1743361111111111*lm^3)*NM + 
          (3.1095100197371686 + 1.61540921074842*lm + 0.8044042773500402*
             lm^2 + 0.1743361111111111*lm^3)*NL + 
          (-0.7272063498964061 + 3.61540921074842*lm + 0.8044042773500402*
             lm^2 + 0.1743361111111111*lm^3)*NH))}, 
     {0.41, NC*(CF^2*(-6.434996866714408 - 4.093035773087826*lm - 
          2.3008978682205226*lm^2 - 3.1562*lm^3) + 
        CA*CF*(-9.451197222483675 - 10.007343498926458*lm - 
          6.281197265289604*lm^2 - 0.9643944444444444*lm^3) + 
        CF*((2.5304269787484293 + 1.9535595844714566*lm + 0.8072873815678068*
             lm^2 + 0.17534444444444444*lm^3)*NM + 
          (3.1184803919477044 + 1.6173595844714566*lm + 0.8072873815678068*
             lm^2 + 0.17534444444444444*lm^3)*NL + 
          (-0.7312957418576251 + 3.6173595844714566*lm + 0.8072873815678068*
             lm^2 + 0.17534444444444444*lm^3)*NH))}, 
     {0.415, NC*(CF^2*(-6.440076419653141 - 4.065975071246083*lm - 
          2.281837333445618*lm^2 - 3.17445*lm^3) + 
        CA*CF*(-9.445479599971796 - 10.01157481749713*lm - 
          6.30762755327505*lm^2 - 0.9699708333333333*lm^3) + 
        CF*((2.521918746593389 + 1.9636984170005916*lm + 0.8101572824136455*
             lm^2 + 0.17635833333333334*lm^3)*NM + 
          (3.127464780437054 + 1.6192484170005916*lm + 0.8101572824136455*
             lm^2 + 0.17635833333333334*lm^3)*NL + 
          (-0.7353218764863726 + 3.6192484170005916*lm + 0.8101572824136455*
             lm^2 + 0.17635833333333334*lm^3)*NH))}, 
     {0.42, NC*(CF^2*(-6.445537145688126 - 4.038834177957713*lm - 
          2.262147267721913*lm^2 - 3.1928*lm^3) + 
        CA*CF*(-9.439543455374313 - 10.015231443511428*lm - 
          6.334042220692806*lm^2 - 0.9755777777777778*lm^3) + 
        CF*((2.5131205860375463 + 1.9738760217827824*lm + 0.8130137370956618*
             lm^2 + 0.17737777777777777*lm^3)*NM + 
          (3.1364641450463604 + 1.6210760217827824*lm + 0.8130137370956618*
             lm^2 + 0.17737777777777777*lm^3)*NL + 
          (-0.7392841488800987 + 3.6210760217827827*lm + 0.8130137370956618*
             lm^2 + 0.17737777777777777*lm^3)*NH))}, 
     {0.425, NC*(CF^2*(-6.451382936707399 - 4.011630035973032*lm - 
          2.241823337376007*lm^2 - 3.21125*lm^3) + 
        CA*CF*(-9.43339719215682 - 10.018313447810277*lm - 
          6.360439943364891*lm^2 - 0.9812152777777777*lm^3) + 
        CF*((2.5040318177555476 + 1.9840927181195493*lm + 0.8158565048542226*
             lm^2 + 0.17840277777777777*lm^3)*NM + 
          (3.1454794327562516 + 1.6228427181195493*lm + 0.8158565048542226*
             lm^2 + 0.17840277777777777*lm^3)*NL + 
          (-0.7431819640699271 + 3.6228427181195495*lm + 0.8158565048542226*
             lm^2 + 0.17840277777777777*lm^3)*NH))}, 
     {0.43, NC*(CF^2*(-6.457617370859807 - 3.9843795973378526*lm - 
          2.220861244654587*lm^2 - 3.2298*lm^3) + 
        CA*CF*(-9.427049146331232 - 10.020820946397409*lm - 
          6.386819408088901*lm^2 - 0.9868833333333333*lm^3) + 
        CF*((2.4946517616965287 + 1.9943488309840272*lm + 0.8186853469252549*
             lm^2 + 0.17943333333333333*lm^3)*NM + 
          (3.1545115778046955 + 1.624548830984027*lm + 0.8186853469252549*
             lm^2 + 0.17943333333333333*lm^3)*NL + 
          (-0.7470147368925639 + 3.6245488309840272*lm + 0.8186853469252549*
             lm^2 + 0.17943333333333333*lm^3)*NH))}, 
     {0.435, NC*(CF^2*(-6.464243717932755 - 3.957099821878044*lm - 
          2.1992567270825245*lm^2 - 3.24845*lm^3) + 
        CA*CF*(-9.420507586796347 - 10.022754099219984*lm - 
          6.4131793124418826*lm^2 - 0.9925819444444445*lm^3) + 
        CF*((2.4849797370151814 + 2.004644690844648*lm + 0.8215000265045846*
             lm^2 + 0.18046944444444443*lm^3)*NM + 
          (3.1635615018051753 + 1.626194690844648*lm + 0.8215000265045846*
             lm^2 + 0.18046944444444443*lm^3)*NL + 
          (-0.7507818918649557 + 3.626194690844648*lm + 0.8215000265045846*
             lm^2 + 0.18046944444444443*lm^3)*NH))}, 
     {0.44, NC*(CF^2*(-6.471264944609575 - 3.9298076757516163*lm - 
          2.177005556838934*lm^2 - 3.2672*lm^3) + 
        CA*CF*(-9.413780715692896 - 10.02411310899103*lm - 
          6.4395183645896745*lm^2 - 0.9983111111111111*lm^3) + 
        CF*((2.475015062007804 + 2.014980633495156*lm + 0.8243003087132741*
             lm^2 + 0.18151111111111112*lm^3)*NM + 
          (3.17263011386503 + 1.6277806334951561*lm + 0.8243003087132741*
             lm^2 + 0.18151111111111112*lm^3)*NL + 
          (-0.7544828630616008 + 3.627780633495156*lm + 0.8243003087132741*
             lm^2 + 0.18151111111111112*lm^3)*NH))}, 
     {0.445, NC*(CF^2*(-6.478683719609753 - 3.9025201300650454*lm - 
          2.1541035401505244*lm^2 - 3.28605*lm^3) + 
        CA*CF*(-9.406876668771655 - 10.024898220051861*lm - 
          6.4658352831015495*lm^2 - 1.0040708333333332*lm^3) + 
        CF*((2.4647570540530235 + 2.02535699989067*lm + 0.827085960563918*
             lm^2 + 0.18255833333333332*lm^3)*NM + 
          (3.1817183107038356 + 1.6293069998906702*lm + 0.827085960563918*
             lm^2 + 0.18255833333333332*lm^3)*NL + 
          (-0.7581170939944277 + 3.6293069998906704*lm + 0.827085960563918*
             lm^2 + 0.18255833333333332*lm^3)*NH))}, 
     {0.45, NC*(CF^2*(-6.486502418715198 - 3.8752541595507095*lm - 
          2.130546516701576*lm^2 - 3.305*lm^3) + 
        CA*CF*(-9.399803515773385 - 10.025109717272787*lm - 
          6.492128796769926*lm^2 - 1.009861111111111*lm^3) + 
        CF*((2.4542050295568902 + 2.0357741359895294*lm + 0.8298567509278654*
             lm^2 + 0.1836111111111111*lm^3)*NM + 
          (3.1908269767716955 + 1.6307741359895294*lm + 0.8298567509278654*
             lm^2 + 0.1836111111111111*lm^3)*NL + 
          (-0.7616840374951543 + 3.6307741359895296*lm + 0.8298567509278654*
             lm^2 + 0.1836111111111111*lm^3)*NH))}, 
     {0.455, NC*(CF^2*(-6.49472312968562 - 3.848026741302505*lm - 
          2.106330359059923*lm^2 - 3.32405*lm^3) + 
        CA*CF*(-9.392569260819368 - 10.024747924990434*lm - 
          6.518397644434977*lm^2 - 1.0156819444444445*lm^3) + 
        CF*((2.443358303902089 + 2.046232392600667*lm + 0.8326124505033291*
             lm^2 + 0.18466944444444444*lm^3)*NM + 
          (3.1999569843673443 + 1.632182392600667*lm + 0.8326124505033291*
             lm^2 + 0.18466944444444444*lm^3)*NL + 
          (-0.7651831556000509 + 3.632182392600667*lm + 0.8326124505033291*
             lm^2 + 0.18466944444444444*lm^3)*NH))}, 
     {0.46, NC*(CF^2*(-6.503347657066015 - 3.820854853566863*lm - 
          2.0814509721183487*lm^2 - 3.3432*lm^3) + 
        CA*CF*(-9.385181842811447 - 10.02381320598016*lm - 
          6.54464057481394*lm^2 - 1.0215333333333334*lm^3) + 
        CF*((2.4322161914009985 + 2.0567321252362754*lm + 0.8353528317843527*
             lm^2 + 0.18573333333333333*lm^3)*NM + 
          (3.2091091937559524 + 1.6335321252362751*lm + 0.8353528317843527*
             lm^2 + 0.18573333333333333*lm^3)*NL + 
          (-0.7686139194370263 + 3.6335321252362753*lm + 0.8353528317843527*
             lm^2 + 0.18573333333333333*lm^3)*NH))}, 
     {0.465, NC*(CF^2*(-6.5123775268891455 - 3.7937554745865483*lm - 
          2.0559042925508253*lm^2 - 3.36245*lm^3) + 
        CA*CF*(-9.377649135840576 - 10.022305960462097*lm - 
          6.570856346334974*lm^2 - 1.0274152777777779*lm^3) + 
        CF*((2.4207780052523673 + 2.067273693969531*lm + 0.8380776690306014*
             lm^2 + 0.1868027777777778*lm^3)*NM + 
          (3.218284453286548 + 1.634823693969531*lm + 0.8380776690306014*
             lm^2 + 0.1868027777777778*lm^3)*NL + 
          (-0.7719758091149678 + 3.634823693969531*lm + 0.8380776690306014*
             lm^2 + 0.1868027777777778*lm^3)*NH))}, 
     {0.47, NC*(CF^2*(-6.5218139912758515 - 3.766745581494756*lm - 
          2.0296862882830595*lm^2 - 3.3818*lm^3) + 
        CA*CF*(-9.369978949602897 - 10.020226625139408*lm - 
          6.59704372697538*lm^2 - 1.0333277777777778*lm^3) + 
        CF*((2.409043057501387 + 2.077857463297172*lm + 0.8407867382379478*
             lm^2 + 0.18787777777777778*lm^3)*NM + 
          (3.227483599508974 + 1.6360574632971718*lm + 0.8407867382379478*
             lm^2 + 0.18787777777777778*lm^3)*NL + 
          (-0.7752683136152623 + 3.636057463297172*lm + 0.8407867382379478*
             lm^2 + 0.18787777777777778*lm^3)*NH))}, 
     {0.475, NC*(CF^2*(-6.5316580329358995 - 3.739842149257174*lm - 
          2.0027929579768307*lm^2 - 3.40125*lm^3) + 
        CA*CF*(-9.362179029822498 - 10.017575672267457*lm - 
          6.623201494104031*lm^2 - 1.0392708333333334*lm^3) + 
        CF*((2.39701065900295 + 2.0884838020067136*lm + 0.8434798171098239*
             lm^2 + 0.18895833333333334*lm^3)*NM + 
          (3.2367074572903034 + 1.6372338020067136*lm + 0.8434798171098239*
             lm^2 + 0.18895833333333334*lm^3)*NL + 
          (-0.7784909306854327 + 3.6372338020067136*lm + 0.8434798171098239*
             lm^2 + 0.18895833333333334*lm^3)*NH))}, 
     {0.48, NC*(CF^2*(-6.5419103695720535 - 3.7130621496597853*lm - 
          1.9752203305276264*lm^2 - 3.4208*lm^3) + 
        CA*CF*(-9.354257058680039 - 10.014353608752613*lm - 
          6.649328434327886*lm^2 - 1.0452444444444444*lm^3) + 
        CF*((2.3846801193879035 + 2.099153083048119*lm + 0.8461566850293126*
             lm^2 + 0.19004444444444443*lm^3)*NM + 
          (3.245956839930651 + 1.6383530830481188*lm + 0.8461566850293126*
             lm^2 + 0.19004444444444443*lm^3)*NL + 
          (-0.7816431667348264 + 3.638353083048119*lm + 0.8461566850293126*
             lm^2 + 0.19004444444444443*lm^3)*NH))}, 
     {0.485, NC*(CF^2*(-6.552571458189912 - 3.6864225503403163*lm - 
          1.9469644645751116*lm^2 - 3.44045*lm^3) + 
        CA*CF*(-9.34622065524649 - 10.01056097527953*lm - 
          6.675423343342395*lm^2 - 1.051248611111111*lm^3) + 
        CF*((2.37205074703211 + 2.1098656834097316*lm + 0.8488171230319507*
             lm^2 + 0.19113611111111112*lm^3)*NM + 
          (3.2552325492783143 + 1.6394156834097315*lm + 0.8488171230319507*
             lm^2 + 0.19113611111111112*lm^3)*NL + 
          (-0.7847245367322915 + 3.6394156834097315*lm + 0.8488171230319507*
             lm^2 + 0.19113611111111112*lm^3)*NH))}, 
     {0.49, NC*(CF^2*(-6.563641499316029 - 3.659940313861344*lm - 
          1.91802144802598*lm^2 - 3.4602*lm^3) + 
        CA*CF*(-9.338077375921287 - 10.006198345465725*lm - 
          6.701485025785716*lm^2 - 1.0572833333333334*lm^3) + 
        CF*((2.3591218490281523 + 2.120621983998304*lm + 0.8514609137792211*
             lm^2 + 0.19223333333333334*lm^3)*NM + 
          (3.2645353758442 + 1.6404219839983039*lm + 0.8514609137792211*
             lm^2 + 0.19223333333333334*lm^3)*NL + 
          (-0.7877345641057868 + 3.6404219839983036*lm + 0.8514609137792211*
             lm^2 + 0.19223333333333334*lm^3)*NH))}, 
     {0.495, NC*(CF^2*(-6.57512044112674 - 3.633632396823179*lm - 
          1.8883873975887595*lm^2 - 3.48005*lm^3) + 
        CA*CF*(-9.329834714874277 - 10.001266325042403*lm - 
          6.727512295096566*lm^2 - 1.063348611111111*lm^3) + 
        CF*((2.3458927311595166 + 2.131422369522947*lm + 0.8540878415327089*
             lm^2 + 0.1933361111111111*lm^3)*NM + 
          (3.273866098915477 + 1.6413723695229472*lm + 0.8540878415327089*
             lm^2 + 0.1933361111111111*lm^3)*NL + 
          (-0.7906727806438645 + 3.641372369522947*lm + 0.8540878415327089*
             lm^2 + 0.1933361111111111*lm^3)*NH))}, 
     {0.5, CF*NC*(CF*(-6.587007983486852 - 3.607515749011501*lm - 
          1.8580584583198019*lm^2 - 3.5*lm^3) + 
        CA*(-9.321500104487727 - 9.995765551059087*lm - 6.753503973375495*
           lm^2 - 1.0694444444444444*lm^3) + 2.332362697876557*NM + 
        2.1422672283826203*lm*NM + 0.8566976921288779*lm^2*NM + 
        0.19444444444444445*lm^3*NM + 3.2832254866679684*NL + 
        1.64226722838262*lm*NL + 0.8566976921288779*lm^2*NL + 
        0.19444444444444445*lm^3*NL - 0.7935387263989276*NH + 
        3.6422672283826203*lm*NH + 0.8566976921288779*lm^2*NH + 
        0.19444444444444445*lm^3*NH)}, 
     {0.505, CF*NC*(CF*(-6.5993035819203785 - 3.581607312598329*lm - 
          1.8270308031823306*lm^2 - 3.52005*lm^3) + 
        CA*(-9.313080915817343 - 9.989696691119914*lm - 6.779458891250156*
           lm^2 - 1.0755708333333334*lm^3) + 2.318531052277554*NM + 
        2.153156952558453*lm*NM + 0.859290252954574*lm^2*NM + 
        0.19555833333333333*lm^3*NM + 3.29261429628006*NL + 
        1.6431069525584532*lm*NL + 0.859290252954574*lm^2*NL + 
        0.19555833333333333*lm^3*NL - 0.7963319495925054*NH + 
        3.643106952558453*lm*NH + 0.859290252954574*lm^2*NH + 
        0.19555833333333333*lm^3*NH)}, 
     {0.51, CF*NC*(CF*(-6.612006451463553 - 3.555924021341723*lm - 
          1.795300632612248*lm^2 - 3.5402*lm^3) + 
        CA*(-9.30458445902086 - 9.983060442627517*lm - 6.805375887742631*
           lm^2 - 1.0817277777777778*lm^3) + 2.3043970960856988*NM + 
        2.1640919375069725*lm*NM + 0.8618653129229027*lm^2*NM + 
        0.19667777777777778*lm^3*NM + 3.3020332740407294*NL + 
        1.6438919375069725*lm*NL + 0.8618653129229027*lm^2*NL + 
        0.19667777777777778*lm^3*NL - 0.799052006521721*NH + 
        3.6438919375069725*lm*NH + 0.8618653129229027*lm^2*NH + 
        0.19667777777777778*lm^3*NH)}, 
     {0.515, CF*NC*(CF*(-6.625115570474904 - 3.5304827998567707*lm - 
          1.762864174098623*lm^2 - 3.56045*lm^3) + 
        CA*(-9.296017983824914 - 9.975857532065989*lm - 6.831253810141246*
           lm^2 - 1.0879152777777779*lm^3) + 2.2899601296345145*NM + 
        2.1750725820593924*lm*NM + 0.8644226624499235*lm^2*NM + 
        0.19780277777777777*lm^3*NM + 3.311483155461953*NL + 
        1.644622582059392*lm*NL + 0.8644226624499235*lm^2*NL + 
        0.19780277777777777*lm^3*NL - 0.8016984614679896*NH + 
        3.6446225820593923*lm*NH + 0.8644226624499235*lm^2*NH + 
        0.19780277777777777*lm^3*NH)}, 
     {0.52, CF*NC*(CF*(-6.638629684347199 - 3.50530056289799*lm - 
          1.7297176817719873*lm^2 - 3.5808*lm^3) + 
        CA*(-9.287388679973615 - 9.968088714296526*lm - 6.8570915138747734*
           lm^2 - 1.0941333333333334*lm^3) + 2.2752194518516315*NM + 
        2.1860992883226595*lm*NM + 0.8669620934317771*lm^2*NM + 
        0.19893333333333332*lm^3*NM + 3.3209646653873497*NL + 
        1.6452992883226596*lm*NL + 0.8669620934317771*lm^2*NL + 
        0.19893333333333332*lm^3*NL - 0.8042708866070444*NH + 
        3.6452992883226596*lm*NH + 0.8669620934317771*lm^2*NH + 
        0.19893333333333332*lm^3*NH)}, 
     {0.525, CF*NC*(CF*(-6.652547309147442 - 3.4803942146764366*lm - 
          1.6958574360028644*lm^2 - 3.60125*lm^3) + 
        CA*(-9.278703677682124 - 9.959754771875739*lm - 6.882887862389764*
           lm^2 - 1.1003819444444445*lm^3) + 2.2601743602450166*NM + 
        2.1971724615838997*lm*NM + 0.8694833992223814*lm^2*NM + 
        0.20006944444444444*lm^3*NM + 3.3304785181004677*NL + 
        1.6459224615838997*lm*NL + 0.8694833992223814*lm^2*NL + 
        0.20006944444444444*lm^3*NL - 0.8067688619206081*NH + 
        3.6459224615838997*lm*NH + 0.8694833992223814*lm^2*NH + 
        0.20006944444444444*lm^3*NH)}, 
     {0.53, CF*NC*(CF*(-6.666866735182626 - 3.4557806482058515*lm - 
          1.661279743009734*lm^2 - 3.6218*lm^3) + 
        CA*(-9.269970048090677 - 9.950856514393953*lm - 6.908641727030752*
           lm^2 - 1.106661111111111*lm^3) + 2.2448241508908113*NM + 
        2.2082925102178237*lm*NM + 0.8719863746116518*lm^2*NM + 
        0.20121111111111112*lm^3*NM + 3.3400254174320825*NL + 
        1.6464925102178236*lm*NL + 0.8719863746116518*lm^2*NL + 
        0.20121111111111112*lm^3*NL - 0.8091919751096038*NH + 
        3.646492510217824*lm*NH + 0.8719863746116518*lm^2*NH + 
        0.20121111111111112*lm^3*NH)}, 
     {0.535, CF*NC*(CF*(-6.681586030493131 - 3.431476744676602*lm - 
          1.625980934476121*lm^2 - 3.64245*lm^3) + 
        CA*(-9.261194803718706 - 9.941394777832746*lm - 6.934351986923259*
           lm^2 - 1.1129708333333332*lm^3) + 2.229168118422675*NM + 
        2.2194598455969956*lm*NM + 0.8744708158042289*lm^2*NM + 
        0.20235833333333333*lm^3*NM + 3.349606056866495*NL + 
        1.6470098455969955*lm*NL + 0.8744708158042289*lm^2*NL + 
        0.20235833333333333*lm^3*NL - 0.8115398215088627*NH + 
        3.6470098455969957*lm*NH + 0.8744708158042289*lm^2*NH + 
        0.20235833333333333*lm^3*NH)}, 
     {0.54, CF*NC*(CF*(-6.696703044275627 - 3.4074993728562415*lm - 
          1.5899573671765284*lm^2 - 3.6632*lm^3) + 
        CA*(-9.252384898918734 - 9.931370423941054*lm - 6.9600175288594945*
           lm^2 - 1.1193111111111111*lm^3) + 2.2132055560225545*NM + 
        2.230674882004842*lm*NM + 0.876936520398696*lm^2*NM + 
        0.20351111111111111*lm^3*NM + 3.3592211196468087*NL + 
        1.647474882004842*lm*NL + 0.876936520398696*lm^2*NL + 
        0.20351111111111111*lm^3*NL - 0.8138120040032928*NH + 
        3.647474882004842*lm*NH + 0.876936520398696*lm^2*NH + 
        0.20351111111111111*lm^3*NH)}, 
     {0.545, CF*NC*(CF*(-6.712215410237243 - 3.383865388515554*lm - 
          1.5532054226109286*lm^2 - 3.68405*lm^3) + 
        CA*(-9.24354723032976 - 9.92078433962913*lm - 6.985637247186673*
           lm^2 - 1.1256819444444444*lm^3) + 2.1969357554127837*NM + 
        2.24193803655131*lm*NM + 0.8793832873672738*lm^2*NM + 
        0.20466944444444443*lm^3*NM + 3.3688712788791784*NL + 
        1.64788803655131*lm*NL + 0.8793832873672738*lm^2*NL + 
        0.20466944444444443*lm^3*NL - 0.816008132945467*NH + 
        3.64788803655131*lm*NH + 0.8793832873672738*lm^2*NH + 
        0.20466944444444443*lm^3*NH)}, 
     {0.55, CF*NC*(CF*(-6.728120549882767 - 3.3605916338790243*lm - 
          1.515721506647548*lm^2 - 3.705*lm^3) + 
        CA*(-9.23468863732986 - 9.909637436379747*lm - 7.0112100436978615*
           lm^2 - 1.1320833333333333*lm^3) + 2.1803580068494397*NM + 
        2.25324972909107*lm*NM + 0.8818109170359749*lm^2*NM + 
        0.20583333333333334*lm^3*NM + 3.378557197636018*NL + 
        1.6482497290910703*lm*NL + 0.8818109170359749*lm^2*NL + 
        0.20583333333333334*lm^3*NL - 0.8181278260745968*NH + 
        3.64824972909107*lm*NH + 0.8818109170359749*lm^2*NH + 
        0.20583333333333334*lm^3*NH)}, 
     {0.555, CF*NC*(CF*(-6.744415675736549 - 3.3376949370986995*lm - 
          1.4775020491736883*lm^2 - 3.72605*lm^3) + 
        CA*(-9.225815902487746 - 9.897930649676024*lm - 7.036734827525294*
           lm^2 - 1.1385152777777778*lm^3) + 2.1634715991168783*NM + 
        2.264610382144173*lm*NM + 0.884219211065205*lm^2*NM + 
        0.20700277777777779*lm^3*NM + 3.3882795290581584*NL + 
        1.648560382144173*lm*NL + 0.884219211065205*lm^2*NL + 
        0.20700277777777779*lm^3*NL - 0.8201707084368546*NH + 
        3.648560382144173*lm*NH + 0.884219211065205*lm^2*NH + 
        0.20700277777777779*lm^3*NH)}, 
     {0.56, CF*NC*(CF*(-6.761097794500733 - 3.3151921117504894*lm - 
          1.4385435037543368*lm^2 - 3.7472*lm^3) + 
        CA*(-9.216935752013068 - 9.885664938445274*lm - 7.062210515036047*
           lm^2 - 1.1449777777777779*lm^3) + 2.1462758195233724*NM + 
        2.27602042081907*lm*NM + 0.8866079724307965*lm^2*NM + 
        0.20817777777777777*lm^3*NM + 3.398038916455952*NL + 
        1.6488204208190702*lm*NL + 0.8866079724307965*lm^2*NL + 
        0.20817777777777777*lm^3*NL - 0.8221364123070124*NH + 
        3.64882042081907*lm*NH + 0.8866079724307965*lm^2*NH + 
        0.20817777777777777*lm^3*NH)}, 
     {0.565, CF*NC*(CF*(-6.778163710151422 - 3.293099956351958*lm - 
          1.3988423472983307*lm^2 - 3.76845*lm^3) + 
        CA*(-9.20805485620523 - 9.872841284518321*lm - 7.087636029730046*
           lm^2 - 1.1514708333333334*lm^3) + 2.128769953897799*NM + 
        2.287480272737913*lm*NM + 0.8889770054054629*lm^2*NM + 
        0.20935833333333334*lm^3*NM + 3.407835993409314*NL + 
        1.649030272737913*lm*NL + 0.8889770054054629*lm^2*NL + 
        0.20935833333333334*lm^3*NL - 0.8240245771113623*NH + 
        3.649030272737913*lm*NH + 0.8889770054054629*lm^2*NH + 
        0.20935833333333334*lm^3*NH)}, 
     {0.57, CF*NC*(CF*(-6.795610026974306 - 3.271435253900744*lm - 
          1.3583950797318445*lm^2 - 3.7898*lm^3) + 
        CA*(-9.199179829900542 - 9.859460692103756*lm - 7.113010302140286*
           lm^2 - 1.1579944444444445*lm^3) + 2.1109532865872964*NM + 
        2.298990367964049*lm*NM + 0.891326115540658*lm^2*NM + 
        0.21054444444444445*lm^3*NM + 3.4176713838667023*NL + 
        1.649190367964049*lm*NL + 0.891326115540658*lm^2*NL + 
        0.21054444444444445*lm^3*NL - 0.8258348493518896*NH + 
        3.649190367964049*lm*NH + 0.891326115540658*lm^2*NH + 
        0.21054444444444445*lm^3*NH)}, 
     {0.575, CF*NC*(CF*(-6.813433152541243 - 3.2502147714327565*lm - 
          1.317198223678983*lm^2 - 3.81125*lm^3) + 
        CA*(-9.190317232917511 - 9.8455241872766*lm - 7.138332269735245*
           lm^2 - 1.1645486111111112*lm^3) + 2.0928251004558427*NM + 
        2.310551138931636*lm*NM + 0.8936551096488324*lm^2*NM + 
        0.21173611111111112*lm^3*NM + 3.4275457022430302*NL + 
        1.6493011389316363*lm*NL + 0.8936551096488324*lm^2*NL + 
        0.21173611111111112*lm^3*NL - 0.827566882531665*NH + 
        3.6493011389316363*lm*NH + 0.8936551096488324*lm^2*NH + 
        0.21173611111111112*lm^3*NH)}, 
     {0.58, CF*NC*(CF*(-6.831629300629256 - 3.229455259599346*lm - 
          1.275248324149269*lm^2 - 3.8328*lm^3) + 
        CA*(-9.181473570500122 - 9.831032817480896*lm - 7.163600876823388*
           lm^2 - 1.1711333333333334*lm^3) + 2.0743846768836973*NM + 
        2.3221630203773023*lm*NM + 0.8959637957860705*lm^2*NM + 
        0.21293333333333334*lm^3*NM + 3.4374595535165153*NL + 
        1.6493630203773022*lm*NL + 0.8959637957860705*lm^2*NL + 
        0.21293333333333334*lm^3*NL - 0.8292203370814297*NH + 
        3.649363020377302*lm*NH + 0.8959637957860705*lm^2*NH + 
        0.21293333333333334*lm^3*NH)}, 
     {0.585, CF*NC*(CF*(-6.850194494083346 - 3.2091734522626862*lm - 
          1.2325419482318223*lm^2 - 3.85445*lm^3) + 
        CA*(-9.172655293758956 - 9.815987651045734*lm - 7.188815074459724*
           lm^2 - 1.177748611111111*lm^3) + 2.055631295767648*NM + 
        2.333826449273772*lm*NM + 0.8982519832351012*lm^2*NM + 
        0.2141361111111111*lm^3*NM + 3.4474135333244598*NL + 
        1.6493764492737721*lm*NL + 0.8982519832351012*lm^2*NL + 
        0.2141361111111111*lm^3*NL - 0.8307948802873424*NH + 
        3.649376449273772*lm*NH + 0.8982519832351012*lm^2*NH + 
        0.2141361111111111*lm^3*NH)}, 
     {0.59, CF*NC*(CF*(-6.869124567624485 - 3.1893860661086326*lm - 
          1.1890756847960342*lm^2 - 3.8762*lm^3) + 
        CA*(-9.163868800109988 - 9.800389776714297*lm - 7.213973820354344*
           lm^2 - 1.1843944444444445*lm^3) + 2.036564235522022*NM + 
        2.3455418647654045*lm*NM + 0.9005194824886685*lm^2*NM + 
        0.21534444444444445*lm^3*NM + 3.457408228057969*NL + 
        1.6493418647654046*lm*NL + 0.9005194824886685*lm^2*NL + 
        0.21534444444444445*lm^3*NL - 0.8322901862198621*NH + 
        3.649341864765405*lm*NH + 0.9005194824886685*lm^2*NH + 
        0.21534444444444445*lm^3*NH)}, 
     {0.595, CF*NC*(CF*(-6.888415170604136 - 3.170109800276363*lm - 
          1.1448461441985505*lm^2 - 3.89805*lm^3) + 
        CA*(-9.155120433710975 - 9.784240303185435*lm - 7.23907607878289*
           lm^2 - 1.1910708333333333*lm^3) + 2.0171827730804055*NM + 
        2.3573097081055616*lm*NM + 0.9027661052332528*lm^2*NM + 
        0.21655833333333332*lm^3*NM + 3.4674442149556075*NL + 
        1.6492597081055613*lm*NL + 0.9027661052332528*lm^2*NL + 
        0.21655833333333332*lm^3*NL - 0.8337059356637395*NH + 
        3.6492597081055616*lm*NH + 0.9027661052332528*lm^2*NH + 
        0.21655833333333332*lm^3*NH)}, 
     {0.6, CF*NC*(CF*(-6.908061769706561 - 3.151361336004128*lm - 
          1.0998499579963799*lm^2 - 3.92*lm^3) + 
        CA*(-9.146416485895285 - 9.767540358667404*lm - 7.264120820498894*
           lm^2 - 1.1977777777777778*lm^3) + 1.9974861838980313*NM + 
        2.3691304225957532*lm*NM + 0.9049916643331322*lm^2*NM + 
        0.21777777777777776*lm^3*NM + 3.4775220621959977*NL + 
        1.6491304225957533*lm*NL + 0.9049916643331322*lm^2*NL + 
        0.21777777777777776*lm^3*NL - 0.8350418160490924*NH + 
        3.649130422595753*lm*NH + 0.9049916643331322*lm^2*NH + 
        0.21777777777777776*lm^3*NH)}, 
     {0.605, CF*NC*(CF*(-6.92805965160019 - 3.133157336290479*lm - 
          1.054083778665956*lm^2 - 3.94205*lm^3) + 
        CA*(-9.13776319560308 - 9.750291090443335*lm - 7.289107022647931*
           lm^2 - 1.2045152777777777*lm^3) + 1.9774737419547972*NM + 
        2.3810044535264985*lm*NM + 0.9071959738147753*lm^2*NM + 
        0.21900277777777777*lm^3*NM + 3.4876423289893657*NL + 
        1.6489544535264986*lm*NL + 0.9071959738147753*lm^2*NL + 
        0.21900277777777777*lm^3*NL - 0.8362975213835381*NH + 
        3.6489544535264984*lm*NH + 0.9071959738147753*lm^2*NH + 
        0.21900277777777777*lm^3*NH)}, 
     {0.61, CF*NC*(CF*(-6.948403925539272 - 3.11551444557036*lm - 
          1.0075442793279812*lm^2 - 3.9642*lm^3) + 
        CA*(-9.129166749809759 - 9.73249366444807*lm - 7.31403366868355*
           lm^2 - 1.2112833333333333*lm^3) + 1.9571447197588647*NM + 
        2.39293224811984*lm*NM + 0.9093788488515545*lm^2*NM + 
        0.22023333333333334*lm^3*NM + 3.4978055656680356*NL + 
        1.6487322481198399*lm*NL + 0.9093788488515545*lm^2*NL + 
        0.22023333333333334*lm^3*NL - 0.8374727521853604*NH + 
        3.6487322481198396*lm*NH + 0.9093788488515545*lm^2*NH + 
        0.22023333333333334*lm^3*NH)}, 
     {0.615, CF*NC*(CF*(-6.969089525916965 - 3.0984492894054827*lm - 
          0.9602281534778923*lm^2 - 3.98645*lm^3) + 
        CA*(-9.120633283951562 - 9.714149264855967*lm - 7.338899748284912*
           lm^2 - 1.2180819444444444*lm^3) + 1.9364983883508118*NM + 
        2.4049142554734577*lm*NM + 0.9115401057487718*lm^2*NM + 
        0.22146944444444444*lm^3*NM + 3.508012313775885*NL + 
        1.6484642554734579*lm*NL + 0.9115401057487718*lm^2*NL + 
        0.22146944444444444*lm^3*NL - 0.8385672154176887*NH + 
        3.648464255473458*lm*NH + 0.9115401057487718*lm^2*NH + 
        0.22146944444444444*lm^3*NH)}, 
     {0.62, CF*NC*(CF*(-6.990111214771039 - 3.081978474188431*lm - 
          0.9121321147217917*lm^2 - 4.0088*lm^3) + 
        CA*(-9.112168882348282 - 9.695259093679358*lm - 7.363704257276103*
           lm^2 - 1.224911111111111*lm^3) + 1.9155340173082975*NM + 
        2.416950926506335*lm*NM + 0.9136795619289885*lm^2*NM + 
        0.2227111111111111*lm^3*NM + 3.518263106156761*NL + 
        1.648150926506335*lm*NL + 0.9136795619289885*lm^2*NL + 
        0.2227111111111111*lm^3*NL - 0.8395806244236639*NH + 
        3.648150926506335*lm*NH + 0.9136795619289885*lm^2*NH + 
        0.2227111111111111*lm^3*NH)}, 
     {0.625, CF*NC*(CF*(-7.011463584243289 - 3.066118586859952*lm - 
          0.8632528965176909*lm^2 - 4.03125*lm^3) + 
        CA*(-9.103779578622984 - 9.675824370377285*lm - 7.388446197547072*
           lm^2 - 1.2317708333333333*lm^3) + 1.8942508747512092*NM + 
        2.4290427139059125*lm*NM + 0.9157970359176495*lm^2*NM + 
        0.22395833333333334*lm^3*NM + 3.528558467041866*NL + 
        1.6477927139059125*lm*NL + 0.9157970359176495*lm^2*NL + 
        0.22395833333333334*lm^3*NL - 0.8405126988625712*NH + 
        3.6477927139059125*lm*NH + 0.9157970359176495*lm^2*NH + 
        0.22395833333333334*lm^3*NH)}, 
     {0.63, CF*NC*(CF*(-7.0331410589937615 - 3.050886194638937*lm - 
          0.8135872519219229*lm^2 - 4.0538*lm^3) + 
        CA*(-9.09547135611869 - 9.655846331474207*lm - 7.413124576976143*
           lm^2 - 1.2386611111111112*lm^3) + 1.8726482273472589*NM + 
        2.441190072076695*lm*NM + 0.9178923473289957*lm^2*NM + 
        0.2252111111111111*lm^3*NM + 3.5388989121361254*NL + 
        1.6473900720766952*lm*NL + 0.9178923473289957*lm^2*NL + 
        0.2252111111111111*lm^3*NL - 0.841363164646919*NH + 
        3.647390072076695*lm*NH + 0.9178923473289957*lm^2*NH + 
        0.2252111111111111*lm^3*NH)}, 
     {0.635, CF*NC*(CF*(-7.055137898570825 - 3.0362978447645923*lm - 
          0.7631319533405817*lm^2 - 4.07645*lm^3) + 
        CA*(-9.087250148311984 - 9.635326230188362*lm - 7.437738409354067*
           lm^2 - 1.2455819444444445*lm^3) + 1.8507253403179986*NM + 
        2.453393457090254*lm*NM + 0.9199653168522546*lm^2*NM + 
        0.22646944444444445*lm^3*NM + 3.5492849487035336*NL + 
        1.646943457090254*lm*NL + 0.9199653168522546*lm^2*NL + 
        0.22646944444444445*lm^3*NL - 0.8421317538804413*NH + 
        3.646943457090254*lm*NH + 0.9199653168522546*lm^2*NH + 
        0.22646944444444445*lm^3*NH)}, 
     {0.64, CF*NC*(CF*(-7.077448199738128 - 3.022370064250339*lm - 
          0.7118837922858532*lm^2 - 4.0992*lm^3) + 
        CA*(-9.079121839223447 - 9.614265336069456*lm - 7.462286714309566*
           lm^2 - 1.2525333333333333*lm^3) + 1.8284814774452294*NM + 
        2.4656533266365837*lm*NM + 0.922015766238103*lm^2*NM + 
        0.22773333333333334*lm^3*NM + 3.559717075651501*NL + 
        1.6464533266365837*lm*NL + 0.922015766238103*lm^2*NL + 
        0.22773333333333334*lm^3*NL - 0.8428182047970062*NH + 
        3.6464533266365837*lm*NH + 0.922015766238103*lm^2*NH + 
        0.22773333333333334*lm^3*NH)}, 
     {0.645, CF*NC*(CF*(-7.1000658987594285 - 3.009119359648991*lm - 
          0.6598395791371067*lm^2 - 4.12205*lm^3) + 
        CA*(-9.071092263824928 - 9.59266493464543*lm - 7.486768517236338*
           lm^2 - 1.2595152777777778*lm^3) + 1.8059159010777754*NM + 
        2.477970139976769*lm*NM + 0.9240435182853948*lm^2*NM + 
        0.22900277777777778*lm^3*NM + 3.5701957836141966*NL + 
        1.645920139976769*lm*NL + 0.9240435182853948*lm^2*NL + 
        0.22900277777777778*lm^3*NL - 0.8434222617004089*NH + 
        3.6459201399767687*lm*NH + 0.9240435182853948*lm^2*NH + 
        0.22900277777777778*lm^3*NH)}, 
     {0.65, CF*NC*(CF*(-7.122984773642274 - 2.996562216828788*lm - 
          0.60699614290662*lm^2 - 4.145*lm^3) + 
        CA*(-9.063167208443586 - 9.570526327077992*lm - 7.511182849221467*
           lm^2 - 1.2665277777777777*lm^3) + 1.7830278721385995*NM + 
        2.4903443578969178*lm*NM + 0.9260483968281455*lm^2*NM + 
        0.23027777777777778*lm^3*NM + 3.5807215550349056*NL + 
        1.6453443578969178*lm*NL + 0.9260483968281455*lm^2*NL + 
        0.23027777777777778*lm^3*NL - 0.8439436749050322*NH + 
        3.6453443578969176*lm*NH + 0.9260483968281455*lm^2*NH + 
        0.23027777777777778*lm^3*NH)}, 
     {0.655, CF*NC*(CF*(-7.1461984463414545 - 2.9847151007598636*lm - 
          0.5533503310098159*lm^2 - 4.16805*lm^3) + 
        CA*(-9.055352411162653 - 9.54785082982665*lm - 7.5355287469752215*
           lm^2 - 1.2735708333333333*lm^3) + 1.759816650132233*NM + 
        2.5027764426633254*lm*NM + 0.9280302267227676*lm^2*NM + 
        0.23155833333333334*lm^3*NM + 3.5912948642474047*NL + 
        1.6447264426633257*lm*NL + 0.9280302267227676*lm^2*NL + 
        0.23155833333333334*lm^3*NL - 0.8443822006773551*NH + 
        3.6447264426633255*lm*NH + 0.9280302267227676*lm^2*NH + 
        0.23155833333333334*lm^3*NH)}, 
     {0.66, CF*NC*(CF*(-7.1697003849231695 - 2.9735944553107583*lm - 
          0.4988990090398914*lm^2 - 4.1912*lm^3) + 
        CA*(-9.047653562218954 - 9.524639774320997*lm - 7.559805252762189*
           lm^2 - 1.2806444444444445*lm^3) + 1.7362814931525052*NM + 
        2.515266857978824*lm*NM + 0.9299888338355495*lm^2*NM + 
        0.23284444444444444*lm^3*NM + 3.6019161775563684*NL + 
        1.6440668579788238*lm*NL + 0.9299888338355495*lm^2*NL + 
        0.23284444444444444*lm^3*NL - 0.8447376011782929*NH + 
        3.6440668579788236*lm*NH + 0.9299888338355495*lm^2*NH + 
        0.23284444444444444*lm^3*NH)}, 
     {0.665, CF*NC*(CF*(-7.193483905690772 - 2.963216703054608*lm - 
          0.44363906054672575*lm^2 - 4.21445*lm^3) + 
        CA*(-9.040076304397074 - 9.500894506640993*lm - 7.584011414333721*
           lm^2 - 1.2877486111111112*lm^3) + 1.7124216578905427*NM + 
        2.527816068940282*lm*NM + 0.9319240450303736*lm^2*NM + 
        0.2341361111111111*lm^3*NM + 3.6125859533168114*NL + 
        1.6433660689402823*lm*NL + 0.9319240450303736*lm^2*NL + 
        0.2341361111111111*lm^3*NL - 0.8450096444063502*NH + 
        3.6433660689402823*lm*NH + 0.9319240450303736*lm^2*NH + 
        0.2341361111111111*lm^3*NH)}, 
     {0.67, CF*NC*(CF*(-7.217542175272974 - 2.9535982450846308*lm - 
          0.3875673868199564*lm^2 - 4.2378*lm^3) + 
        CA*(-9.032626233420224 - 9.476616387204995*lm - 7.608146284861653*
           lm^2 - 1.2948833333333334*lm^3) + 1.6882363996430232*NM + 
        2.5404245419972256*lm*NM + 0.9338356881566643*lm^2*NM + 
        0.23543333333333333*lm^3*NM + 3.6233046420125814*NL + 
        1.6426245419972256*lm*NL + 0.9338356881566643*lm^2*NL + 
        0.23543333333333333*lm^3*NL - 0.8451981041415723*NH + 
        3.6426245419972254*lm*NH + 0.9338356881566643*lm^2*NH + 
        0.23543333333333333*lm^3*NH)}, 
     {0.675, CF*NC*(CF*(-7.241868212675355 - 2.9447554608385764*lm - 
          0.33068090667611594*lm^2 - 4.26125*lm^3) + 
        CA*(-9.02530889833776 - 9.451806790465314*lm - 7.632208922873257*
           lm^2 - 1.3020486111111111*lm^3) + 1.6637249723206666*NM + 
        2.5530927449115315*lm*NM + 0.935723592037562*lm^2*NM + 
        0.23673611111111112*lm^3*NM + 3.6340726863339117*NL + 
        1.6418427449115316*lm*NL + 0.935723592037562*lm^2*NL + 
        0.23673611111111112*lm^3*NL - 0.8453027598902759*NH + 
        3.6418427449115316*lm*NH + 0.935723592037562*lm^2*NH + 
        0.23673611111111112*lm^3*NH)}, 
     {0.68, CF*NC*(CF*(-7.266454891295976 - 2.9367047079318023*lm - 
          0.2729765562497264*lm^2 - 4.2848*lm^3) + 
        CA*(-9.018129801909332 - 9.426467104611067*lm - 7.656198392187417*
           lm^2 - 1.3092444444444444*lm^3) + 1.6388866284569406*NM + 
        2.565821146718174*lm*NM + 0.9375875864583181*lm^2*NM + 
        0.23804444444444445*lm^3*NM + 3.6448905212540383*NL + 
        1.6410211467181743*lm*NL + 0.9375875864583181*lm^2*NL + 
        0.23804444444444445*lm^3*NL - 0.8453233968305471*NH + 
        3.6410211467181743*lm*NH + 0.9375875864583181*lm^2*NH + 
        0.23804444444444445*lm^3*NH)}, 
     {0.685, CF*NC*(CF*(-7.2912949409059165 - 2.929462321998652*lm - 
          0.2144512887882511*lm^2 - 4.30845*lm^3) + 
        CA*(-9.011094400985689 - 9.400598731278116*lm - 7.680113761851966*
           lm^2 - 1.3164708333333333*lm^3) + 1.6137206192169686*NM + 
        2.5786102176869847*lm*NM + 0.9394275021549029*lm^2*NM + 
        0.23935833333333334*lm^3*NM + 3.655758574104899*NL + 
        1.6401602176869847*lm*NL + 0.9394275021549029*lm^2*NL + 
        0.23935833333333334*lm^3*NL - 0.8452598057584871*NH + 
        3.6401602176869847*lm*NH + 0.9394275021549029*lm^2*NH + 
        0.23935833333333334*lm^3*NH)}, 
     {0.69, CF*NC*(CF*(-7.3163809495955 - 2.9230446165418376*lm - 
          0.1551020744508068*lm^2 - 4.3322*lm^3) + 
        CA*(-9.004208106886095 - 9.374203085265878*lm - 7.703954106082191*
           lm^2 - 1.3237277777777778*lm^3) + 1.5882261944066218*NM + 
        2.5914604292853944*lm*NM + 0.9412431708028226*lm^2*NM + 
        0.24067777777777777*lm^3*NM + 3.6666772646519186*NL + 
        1.6392604292853945*lm*NL + 0.9412431708028226*lm^2*NL + 
        0.24067777777777777*lm^3*NL - 0.8451117830351947*NH + 
        3.6392604292853945*lm*NH + 0.9412431708028226*lm^2*NH + 
        0.24067777777777777*lm^3*NH)}, 
     {0.695, CF*NC*(CF*(-7.341705365686961 - 2.917467882789521*lm - 
          0.09492590011054206*lm^2 - 4.35605*lm^3) + 
        CA*(-8.997476285772386 - 9.347281594260812*lm - 7.7277185042004435*
           lm^2 - 1.3310152777777777*lm^3) + 1.5624026024817803*NM + 
        2.6043722541421324*lm*NM + 0.9430344250061412*lm^2*NM + 
        0.2420027777777778*lm^3*NM + 3.6776470051678967*NL + 
        1.6383222541421325*lm*NL + 0.9430344250061412*lm^2*NL + 
        0.2420027777777778*lm^3*NL - 0.8448791305344687*NH + 
        3.6383222541421327*lm*NH + 0.9430344250061412*lm^2*NH + 
        0.2420027777777778*lm^3*NH)}, 
     {0.7, CF*NC*(CF*(-7.367260499614298 - 2.9127483895598196*lm - 
          0.033919769160591765*lm^2 - 4.38*lm^3) + 
        CA*(-8.990904259019644 - 9.319835698566383*lm - 7.751406040576848*
           lm^2 - 1.3383333333333334*lm^3) + 1.53624909055775*NM + 
        2.61734616601185*lm*NM + 0.9448010982866996*lm^2*NM + 
        0.24333333333333335*lm^3*NM + 3.688668200506001*NL + 
        1.6373461660118502*lm*NL + 0.9448010982866996*lm^2*NL + 
        0.24333333333333335*lm^3*NL - 0.8445616555912165*NH + 
        3.63734616601185*lm*NH + 0.9448010982866996*lm^2*NH + 
        0.24333333333333335*lm^3*NH)}, 
     {0.705, CF*NC*(CF*(-7.393038525771018 - 2.908902383132466*lm + 
          0.027919298676481342*lm^2 - 4.40405*lm^3) + 
        CA*(-8.984497303583504 - 9.291866850839325*lm - 7.775015804571075*
           lm^2 - 1.3456819444444443*lm^3) + 1.5097649044188208*NM + 
        2.630382639740641*lm*NM + 0.9465430250735288*lm^2*NM + 
        0.24466944444444444*lm^3*NM + 3.699741248171883*NL + 
        1.6363326397406408*lm*NL + 0.9465430250735288*lm^2*NL + 
        0.24466944444444444*lm^3*NL - 0.8441591709505565*NH + 
        3.636332639740641*lm*NH + 0.9465430250735288*lm^2*NH + 
        0.24466944444444444*lm^3*NH)}, 
     {0.71, CF*NC*(CF*(-7.419031484326467 - 2.905946087127346*lm + 
          0.09059426753584245*lm^2 - 4.4282*lm^3) + 
        CA*(-8.978260652364106 - 9.263376515832014*lm - 7.798546890475159*
           lm^2 - 1.353061111111111*lm^3) + 1.482949288527957*NM + 
        2.643482151232433*lm*NM + 0.9482600406924532*lm^2*NM + 
        0.24601111111111112*lm^3*NM + 3.710866538394922*NL + 
        1.6352821512324327*lm*NL + 0.9482600406924532*lm^2*NL + 
        0.24601111111111112*lm^3*NL - 0.8436714947175987*NH + 
        3.6352821512324325*lm*NH + 0.9482600406924532*lm^2*NH + 
        0.24601111111111112*lm^3*NH)}, 
     {0.715, CF*NC*(CF*(-7.445231283011448 - 2.903895702389684*lm + 
          0.15410808559422107*lm^2 - 4.45245*lm^3) + 
        CA*(-8.972199494566658 - 9.23436617014078*lm - 7.821998397457321*
           lm^2 - 1.3604708333333333*lm^3) + 1.4558014860365998*NM + 
        2.6566451774162263*lm*NM + 0.9499519813558767*lm^2*NM + 
        0.24735833333333335*lm^3*NM + 3.7220444541986137*NL + 
        1.6341951774162264*lm*NL + 0.9499519813558767*lm^2*NL + 
        0.24735833333333335*lm^3*NL - 0.843098450307894*NH + 
        3.634195177416226*lm*NH + 0.9499519813558767*lm^2*NH + 
        0.24735833333333335*lm^3*NH)}, 
     {0.72, CF*NC*(CF*(-7.471629698873751 - 2.9027674068816234*lm + 
          0.21846368525050774*lm^2 - 4.4768*lm^3) + 
        CA*(-8.96631897605868 - 9.204837301959989*lm - 7.845369429506789*
           lm^2 - 1.367911111111111*lm^3) + 1.4283207387945807*NM + 
        2.669872196214152*lm*NM + 0.9516186841527495*lm^2*NM + 
        0.2487111111111111*lm^3*NM + 3.733275371470103*NL + 
        1.633072196214152*lm*NL + 0.9516186841527495*lm^2*NL + 
        0.2487111111111111*lm^3*NL - 0.8424398663985343*NH + 
        3.633072196214152*lm*NH + 0.9516186841527495*lm^2*NH + 
        0.2487111111111111*lm^3*NH)}, 
     {0.725, CF*NC*(CF*(-7.498218380004266 - 2.9025773555799654*lm + 
          0.28366398330318915*lm^2 - 4.50125*lm^3) + 
        CA*(-8.96062419972389 - 9.174791410841745*lm - 7.868659095379581*
           lm^2 - 1.3753819444444444*lm^3) + 1.4005062873601275*NM + 
        2.6831636865103228*lm*NM + 0.9532599870387117*lm^2*NM + 
        0.25006944444444446*lm^3*NM + 3.744559659028885*NL + 
        1.631913686510323*lm*NL + 0.9532599870387117*lm^2*NL + 
        0.25006944444444446*lm^3*NL - 0.8416955768798977*NH + 
        3.6319136865103228*lm*NH + 0.9532599870387117*lm^2*NH + 
        0.25006944444444446*lm^3*NH)}, 
     {0.73, CF*NC*(CF*(-7.524988847234295 - 2.90334168037986*lm + 
          0.34971188112469637*lm^2 - 4.5258*lm^3) + 
        CA*(-8.955120225812765 - 9.144230007461031*lm - 7.891866508545232*
           lm^2 - 1.3828833333333332*lm^3) + 1.372357371009956*NM + 
        2.6965201281204636*lm*NM + 0.9548757288264058*lm^2*NM + 
        0.25143333333333334*lm^3*NM + 3.7558976786946747*NL + 
        1.6307201281204635*lm*NL + 0.9548757288264058*lm^2*NL + 
        0.25143333333333334*lm^3*NL - 0.8408654208080205*NH + 
        3.6307201281204637*lm*NH + 0.9548757288264058*lm^2*NH + 
        0.25143333333333334*lm^3*NH)}, 
     {0.735, CF*NC*(CF*(-7.551932495804673 - 2.9050764900042187*lm + 
          0.41661026483273966*lm^2 - 4.55045*lm^3) + 
        CA*(-8.949812072289786 - 9.113154613386156*lm - 7.914990787134441*
           lm^2 - 1.3904152777777778*lm^3) + 1.3438732277494374*NM + 
        2.7099420017622866*lm*NM + 0.956465749175959*lm^2*NM + 
        0.25280277777777777*lm^3*NM + 3.76728978535446*NL + 
        1.6294920017622865*lm*NL + 0.956465749175959*lm^2*NL + 
        0.25280277777777777*lm^3*NL - 0.8399492423575892*NH + 
        3.6294920017622863*lm*NH + 0.956465749175959*lm^2*NH + 
        0.25280277777777777*lm^3*NH)}, 
     {0.74, CF*NC*(CF*(-7.579040597007298 - 2.9077978699186495*lm + 
          0.4843620054587009*lm^2 - 4.5752*lm^3) + 
        CA*(-8.944704715177393 - 9.08156676085436*lm - 7.938031053887619*
           lm^2 - 1.3979777777777778*lm^3) + 1.3150530943228338*NM + 
        2.7234297890265995*lm*NM + 0.9580298885856278*lm^2*NM + 
        0.2541777777777778*lm^3*NM + 3.7787363270287453*NL + 
        1.6282297890265993*lm*NL + 0.9580298885856278*lm^2*NL + 
        0.2541777777777778*lm^3*NL - 0.8389468907755376*NH + 
        3.6282297890265993*lm*NH + 0.9580298885856278*lm^2*NH + 
        0.2541777777777778*lm^3*NH)}, 
     {0.745, CF*NC*(CF*(-7.606304299799637 - 2.9115218822517197*lm + 
          0.5529699591131515*lm^2 - 4.60005*lm^3) + 
        CA*(-8.939803088896634 - 9.04946799255242*lm - 7.960986436104315*
           lm^2 - 1.4055708333333334*lm^3) + 1.285896206223588*NM + 
        2.7369839723491203*lm*NM + 0.9595679883826027*lm^2*NM + 
        0.25555833333333333*lm^3*NM + 3.790237644937*NL + 
        1.62693397234912*lm*NL + 0.9595679883826027*lm^2*NL + 
        0.25555833333333333*lm^3*NL - 0.8378582203352408*NH + 
        3.62693397234912*lm*NH + 0.9595679883826027*lm^2*NH + 
        0.25555833333333333*lm^3*NH)}, 
     {0.75, CF*NC*(CF*(-7.6337146323927945 - 2.916264565720346*lm + 
          0.6224369671485638*lm^2 - 4.625*lm^3) + 
        CA*(-8.935112086604576 - 9.016859861402159*lm - 7.9838560655934945*
           lm^2 - 1.4131944444444444*lm^3) + 1.256401797704667*NM + 
        2.7506050349829803*lm*NM + 0.9610798907139687*lm^2*NM + 
        0.2569444444444444*lm^3*NM + 3.8017940735623195*NL + 
        1.62560503498298*lm*NL + 0.9610798907139687*lm^2*NL + 
        0.2569444444444444*lm^3*NL - 0.8366830902912926*NH + 
        3.6256050349829803*lm*NH + 0.9610798907139687*lm^2*NH + 
        0.2569444444444444*lm^3*NH)}, 
     {0.755, CF*NC*(CF*(-7.6612625038136635 - 2.9220419355601384*lm + 
          0.6927658563192789*lm^2 - 4.65005*lm^3) + 
        CA*(-8.930636560528452 - 8.98374393035066*lm - 8.006639078624664*
           lm^2 - 1.4208486111111112*lm^3) + 1.2265691017889464*NM + 
        2.7642934609718957*lm*NM + 0.9625654385378178*lm^2*NM + 
        0.2583361111111111*lm^3*NM + 3.81340594071531*NL + 
        1.6242434609718959*lm*NL + 0.9625654385378178*lm^2*NL + 
        0.2583361111111111*lm^3*NL - 0.8354213648348581*NH + 
        3.6242434609718956*lm*NH + 0.9625654385378178*lm^2*NH + 
        0.2583361111111111*lm^3*NH)}, 
     {0.76, CF*NC*(CF*(-7.688938705441727 - 2.9288699834605167*lm + 
          0.7639594389387963*lm^2 - 4.6752*lm^3) + 
        CA*(-8.92638132229658 - 8.950121772165124*lm - 8.029334615879812*
           lm^2 - 1.4285333333333334*lm^3) + 1.1963973502796301*NM + 
        2.7780497351239903*lm*NM + 0.9640244756145113*lm^2*NM + 
        0.2597333333333333*lm^3*NM + 3.8250735675972036*NL + 
        1.6228497351239901*lm*NL + 0.9640244756145113*lm^2*NL + 
        0.2597333333333333*lm^3*NL - 0.8340729130495897*NH + 
        3.62284973512399*lm*NH + 0.9640244756145113*lm^2*NH + 
        0.2597333333333333*lm^3*NH)}, 
     {0.765, CF*NC*(CF*(-7.7167339125210095 - 2.936764677504426*lm + 
          0.8360205130344429*lm^2 - 4.70045*lm^3) + 
        CA*(-8.922351143266079 - 8.91599496923222*lm - 8.051941822406143*
           lm^2 - 1.436248611111111*lm^3) + 1.1658857737706982*NM + 
        2.7918743429862456*lm*NM + 0.9654568464980865*lm^2*NM + 
        0.2611361111111111*lm^3*NM + 3.836797268862222*NL + 
        1.6214243429862454*lm*NL + 0.9654568464980865*lm^2*NL + 
        0.2611361111111111*lm^3*NL - 0.832637608868097*NH + 
        3.6214243429862454*lm*NH + 0.9654568464980865*lm^2*NH + 
        0.2611361111111111*lm^3*NH)}, 
     {0.77, CF*NC*(CF*(-7.7446386856477 - 2.9457419621124954*lm + 
          0.9089518624994852*lm^2 - 4.7258*lm^3) + 
        CA*(-8.918550754847404 - 8.881365113361783*lm - 8.074459847569601*
           lm^2 - 1.4439944444444444*lm^3) + 1.1350336016573777*NM + 
        2.8057677708195707*lm*NM + 0.9668623965278064*lm^2*NM + 
        0.26254444444444447*lm^3*NM + 3.848577352679187*NL + 
        1.6199677708195706*lm*NL + 0.9668623965278064*lm^2*NL + 
        0.26254444444444447*lm^3*NL - 0.8311153310289608*NH + 
        3.6199677708195708*lm*NH + 0.9668623965278064*lm^2*NH + 
        0.26254444444444447*lm^3*NH)}, 
     {0.775, CF*NC*(CF*(-7.772643472233939 - 2.9558177579914746*lm + 
          0.9827562572427372*lm^2 - 4.75125*lm^3) + 
        CA*(-8.914984848825712 - 8.846233805594801*lm - 8.096887845009164*
           lm^2 - 1.4517708333333332*lm^3) + 1.1038400621466282*NM + 
        2.8197305055744644*lm*NM + 0.9682409718198479*lm^2*NM + 
        0.26395833333333335*lm^3*NM + 3.8604141207924*NL + 
        1.6184805055744644*lm*NL + 0.9682409718198479*lm^2*NL + 
        0.26395833333333335*lm^3*NL - 0.8295059630342817*NH + 
        3.6184805055744644*lm*NH + 0.9682409718198479*lm^2*NH + 
        0.26395833333333335*lm^3*NH)}, 
     {0.78, CF*NC*(CF*(-7.800738607948252 - 2.967007962086803*lm + 
          1.0574364533357234*lm^2 - 4.7768*lm^3) + 
        CA*(-8.911658077679085 - 8.810602656015512*lm - 8.119224972591862*
           lm^2 - 1.4595777777777779*lm^3) + 1.0723043822676395*NM + 
        2.8337630348672604*lm*NM + 0.9695924192591264*lm^2*NM + 
        0.26537777777777777*lm^3*NM + 3.8723078685817907*NL + 
        1.6169630348672601*lm*NL + 0.9695924192591264*lm^2*NL + 
        0.26537777777777777*lm^3*NL - 0.8278093931077539*NH + 
        3.6169630348672603*lm*NH + 0.9695924192591264*lm^2*NH + 
        0.26537777777777777*lm^3*NH)}, 
     {0.785, CF*NC*(CF*(-7.828914318133113 - 2.979328447539158*lm + 
          1.1329951931574516*lm^2 - 4.80245*lm^3) + 
        CA*(-8.908575054893644 - 8.77447328356756*lm - 8.141470392368557*
           lm^2 - 1.4674152777777778*lm^3) + 1.040425787882332*NM + 
        2.8478658469569345*lm*NM + 0.9709165864912527*lm^2*NM + 
        0.2668027777777778*lm^3*NM + 3.8842588851223487*NL + 
        1.6154158469569344*lm*NL + 0.9709165864912527*lm^2*NL + 
        0.2668027777777778*lm^3*NL - 0.8260255141532548*NH + 
        3.6154158469569344*lm*NH + 0.9709165864912527*lm^2*NH + 
        0.2668027777777778*lm^3*NH)}, 
     {0.79, CF*NC*(CF*(-7.857160719200085 - 2.9927950636448477*lm + 
          1.209435205536844*lm^2 - 4.8282*lm^3) + 
        CA*(-8.905740355275558 - 8.737847315874074*lm - 8.163623270530408*
           lm^2 - 1.4752833333333333*lm^3) + 1.008203503695859*NM + 
        2.8620394307224646*lm*NM + 0.9722133219146197*lm^2*NM + 
        0.2682333333333333*lm^3*NM + 3.896267453242849*NL + 
        1.6138394307224646*lm*NL + 0.9722133219146197*lm^2*NL + 
        0.2682333333333333*lm^3*NL - 0.8241542237139418*NH + 
        3.6138394307224644*lm*NH + 0.9722133219146197*lm^2*NH + 
        0.2682333333333333*lm^3*NH)}, 
     {0.795, CF*NC*(CF*(-7.885467820002993 - 3.0074236358199093*lm + 
          1.286759205892884*lm^2 - 4.85405*lm^3) + 
        CA*(-8.903158515260005 - 8.700726389061568*lm - 8.185682777366063*
           lm^2 - 1.4831819444444445*lm^3) + 0.9756367532671039*NM + 
        2.8762842756407205*lm*NM + 0.9734824746726175*lm^2*NM + 
        0.26966944444444446*lm^3*NM + 3.908333849583877*NL + 
        1.6122342756407204*lm*NL + 0.9734824746726175*lm^2*NL + 
        0.26966944444444446*lm^3*NL - 0.8221954239318487*NH + 
        3.6122342756407204*lm*NH + 0.9734824746726175*lm^2*NH + 
        0.26966944444444446*lm^3*NH)}, 
     {0.8, CF*NC*(CF*(-7.913825523189577 - 3.0232299655677832*lm + 
          1.3649698963725236*lm^2 - 4.88*lm^3) + 
        CA*(-8.900834033217063 - 8.66311214758758*lm - 8.207648087219507*
           lm^2 - 1.491111111111111*lm^3) + 0.9427247590191659*NM + 
        2.8906008717648772*lm*NM + 0.9747238946459709*lm^2*NM + 
        0.27111111111111114*lm^3*NM + 3.920458344655165*NL + 
        1.6106008717648772*lm*NL + 0.9747238946459709*lm^2*NL + 
        0.27111111111111114*lm^3*NL - 0.8201490215079706*NH + 
        3.6106008717648774*lm*NH + 0.9747238946459709*lm^2*NH + 
        0.27111111111111114*lm^3*NH)}, 
     {0.805, CF*NC*(CF*(-7.942223626532032 - 3.0402298304504325*lm + 
          1.4440699659864027*lm^2 - 4.90605*lm^3) + 
        CA*(-8.898771369754604 - 8.62500624407193*lm - 8.2295183784486*lm^2 - 
          1.4990708333333334*lm^3) + 0.9094667422498356*NM + 
        2.9049897097033317*lm*NM + 0.9759374324451998*lm^2*NM + 
        0.27255833333333335*lm^3*NM + 3.9326412028922504*NL + 
        1.6089397097033318*lm*NL + 0.9759374324451998*lm^2*NL + 
        0.27255833333333335*lm^3*NL - 0.8180149276628311*NH + 
        3.6089397097033316*lm*NH + 0.9759374324451998*lm^2*NH + 
        0.27255833333333335*lm^3*NH)}, 
     {0.81, CF*NC*(CF*(-7.970651824236874 - 3.0584389840627932*lm + 
          1.5240620907424254*lm^2 - 4.9322*lm^3) + 
        CA*(-8.896974948018194 - 8.586410339131536*lm - 8.251292833384259*
           lm^2 - 1.5070611111111112*lm^3) + 0.8758619231420504*NM + 
        2.9194512805991124*lm*NM + 0.9771229394031986*lm^2*NM + 
        0.2740111111111111*lm^3*NM + 3.9448826827124606*NL + 
        1.6072512805991126*lm*NL + 0.9771229394031986*lm^2*NL + 
        0.2740111111111111*lm^3*NL - 0.8157930580975237*NH + 
        3.6072512805991126*lm*NH + 0.9771229394031986*lm^2*NH + 
        0.2740111111111111*lm^3*NH)}, 
     {0.815, CF*NC*(CF*(-7.9990997082345325 - 3.077873156010434*lm + 
          1.6049489337772431*lm^2 - 4.95845*lm^3) + 
        CA*(-8.895449153988006 - 8.547326101218667*lm - 8.272970638290287*
           lm^2 - 1.5150819444444446*lm^3) + 0.8419095207743292*NM + 
        2.933986076109769*lm*NM + 0.978280267567931*lm^2*NM + 
        0.27546944444444443*lm^3*NM + 3.9571830365702394*NL + 
        1.605536076109769*lm*NL + 0.978280267567931*lm^2*NL + 
        0.27546944444444443*lm^3*NL - 0.8134833329552184*NH + 
        3.605536076109769*lm*NH + 0.978280267567931*lm^2*NH + 
        0.27546944444444443*lm^3*NH)}, 
     {0.82, CF*NC*(CF*(-8.027556769449058 - 3.098548051890311*lm + 
          1.6867331454856833*lm^2 - 4.9848*lm^3) + 
        CA*(-8.89419833677283 - 8.50775520646256*lm - 8.29455098332382*lm^2 - 
          1.5231333333333332*lm^3) + 0.8076087531311842*NM + 
        2.948594588387726*lm*NM + 0.9794092696952398*lm^2*NM + 
        0.2769333333333333*lm^3*NM + 3.9695425110118183*NL + 
        1.6037945883877263*lm*NL + 0.9794092696952398*lm^2*NL + 
        0.2769333333333333*lm^3*NL - 0.8110856767831267*NH + 
        3.6037945883877263*lm*NH + 0.9794092696952398*lm^2*NH + 
        0.2769333333333333*lm^3*NH)}, 
     {0.825, CF*NC*(CF*(-8.056012399048347 - 3.1204793532745083*lm + 
          1.7694173636481736*lm^2 - 5.01125*lm^3) + 
        CA*(-8.893226808901126 - 8.467699338514322*lm - 8.316033062496391*
           lm^2 - 1.5312152777777779*lm^3) + 0.772958837113501*NM + 
        2.963277310061094*lm*NM + 0.9805097992417682*lm^2*NM + 
        0.2784027777777778*lm^3*NM + 3.9819613467292467*NL + 
        1.602027310061094*lm*NL + 0.9805097992417682*lm^2*NL + 
        0.2784027777777778*lm^3*NL - 0.8086000184949165*NH + 
        3.6020273100610942*lm*NH + 0.9805097992417682*lm^2*NH + 
        0.2784027777777778*lm^3*NH)}, 
     {0.83, CF*NC*(CF*(-8.084455889675253 - 3.1436827176968665*lm + 
          1.8530042135561973*lm^2 - 5.0378*lm^3) + 
        CA*(-8.892538846609236 - 8.42716018839502*lm - 8.337416073635607*
           lm^2 - 1.5393277777777779*lm^3) + 0.7379589885488915*NM + 
        2.978034734214919*lm*NM + 0.981581710357989*lm^2*NM + 
        0.2798777777777778*lm^3*NM + 3.9944397786137835*NL + 
        1.6002347342149195*lm*NL + 0.981581710357989*lm^2*NL + 
        0.2798777777777778*lm^3*NL - 0.8060262913335704*NH + 
        3.6002347342149195*lm*NH + 0.981581710357989*lm^2*NH + 
        0.2798777777777778*lm^3*NH)}, 
     {0.835, CF*NC*(CF*(-8.112876436659961 - 3.168173778642385*lm + 
          1.9374963081358278*lm^2 - 5.06445*lm^3) + 
        CA*(-8.892138690126698 - 8.386139454346898*lm - 8.358699218347386*
           lm^2 - 1.5474708333333334*lm^3) + 0.7026084222020098*NM + 
        2.9928673543728674*lm*NM + 0.9826248578813429*lm^2*NM + 
        0.2813583333333333*lm^3*NM + 4.006978035808666*NL + 
        1.5984173543728675*lm*NL + 0.9826248578813429*lm^2*NL + 
        0.2813583333333333*lm^3*NL - 0.8033644328346806*NH + 
        3.5984173543728675*lm*NH + 0.9826248578813429*lm^2*NH + 
        0.2813583333333333*lm^3*NH)}, 
     {0.84, CF*NC*(CF*(-8.141263139213983 - 3.193968145539312*lm + 
          2.0228962480693764*lm^2 - 5.0912*lm^3) + 
        CA*(-8.89203054395875 - 8.344638841687622*lm - 8.379881701978801*
           lm^2 - 1.5556444444444444*lm^3) + 0.6669063517848327*NM + 
        3.007775664479324*lm*NM + 0.9836390973294791*lm^2*NM + 
        0.28284444444444445*lm^3*NM + 4.0195763417612635*NL + 
        1.5965756644793243*lm*NL + 0.9836390973294791*lm^2*NL + 
        0.28284444444444445*lm^3*NL - 0.8006143847901709*NH + 
        3.596575664479324*lm*NH + 0.9836390973294791*lm^2*NH + 
        0.28284444444444445*lm^3*NH)}, 
     {0.845, CF*NC*(CF*(-8.169605001606122 - 3.2210814037538182*lm + 
          2.109206621915197*lm^2 - 5.11805*lm^3) + 
        CA*(-8.892218577166021 - 8.3026600626675*lm - 8.400962733581467*
           lm^2 - 1.5638486111111112*lm^3) + 0.6308519899669004*NM + 
        3.0227601588819057*lm*NM + 0.9846242848936002*lm^2*NM + 
        0.2843361111111111*lm^3*NM + 4.032234914274609*NL + 
        1.5947101588819057*lm*NL + 0.9846242848936002*lm^2*NL + 
        0.2843361111111111*lm^3*NL - 0.797776093212442*NH + 
        3.594710158881906*lm*NH + 0.9846242848936002*lm^2*NH + 
        0.2843361111111111*lm^3*NH)}, 
     {0.85, CF*NC*(CF*(-8.197890934320764 - 3.2495291145871694*lm + 
          2.1964300062256816*lm^2 - 5.145*lm^3) + 
        CA*(-8.89270692364145 - 8.260204836329583*lm - 8.421941525875486*
           lm^2 - 1.5720833333333333*lm^3) + 0.5944445483855159*NM + 
        3.037821332314367*lm*NM + 0.9855802774319066*lm^2*NM + 
        0.28583333333333333*lm^3*NM + 4.044953965558349*NL + 
        1.5928213323143667*lm*NL + 0.9855802774319066*lm^2*NL + 
        0.28583333333333333*lm^3*NL - 0.7948495082989316*NH + 
        3.5928213323143665*lm*NH + 0.9855802774319066*lm^2*NH + 
        0.28583333333333333*lm^3*NH)}, 
     {0.855, CF*NC*(CF*(-8.226109755198816 - 3.2793268152753083*lm + 
          2.284568965663487*lm^2 - 5.17205*lm^3) + 
        CA*(-8.89349968238444 - 8.217274888372607*lm - 8.442817295213935*
           lm^2 - 1.5803486111111111*lm^3) + 0.5576832376558996*NM + 
        3.052959679879897*lm*NM + 0.9865069324631396*lm^2*NM + 
        0.2873361111111111*lm^3*NM + 4.057733702279085*NL + 
        1.5909096798798967*lm*NL + 0.9865069324631396*lm^2*NL + 
        0.2873361111111111*lm^3*NL - 0.7918345843970823*NH + 
        3.5909096798798967*lm*NH + 0.9865069324631396*lm^2*NH + 
        0.2873361111111111*lm^3*NH)}, 
     {0.86, CF*NC*(CF*(-8.25425019056164 - 3.310490018990757*lm + 
          2.3736260531160283*lm^2 - 5.1992*lm^3) + 
        CA*(-8.894600917772316 - 8.173871951016661*lm - 8.463589261547881*
           lm^2 - 1.5886444444444445*lm^3) + 0.5205672673812987*NM + 
        3.068175697034794*lm*NM + 0.9874041081602206*lm^2*NM + 
        0.28884444444444446*lm^3*NM + 4.070574325610139*NL + 
        1.5889756970347941*lm*NL + 0.9874041081602206*lm^2*NL + 
        0.28884444444444446*lm^3*NL - 0.7887312799697127*NH + 
        3.588975697034794*lm*NH + 0.9874041081602206*lm^2*NH + 
        0.28884444444444446*lm^3*NH)}, 
     {0.865, CF*NC*(CF*(-8.282300876318278 - 3.343034214846763*lm + 
          2.46360380980827*lm^2 - 5.22645*lm^3) + 
        CA*(-8.896014659829046 - 8.129997762871561*lm - 8.484256648391918*
           lm^2 - 1.5969708333333332*lm^3) + 0.4830958461630479*NM + 
        3.0834698795725077*lm*NM + 0.988271663343985*lm^2*NM + 
        0.29035833333333333*lm^3*NM + 4.083476031280738*NL + 
        1.587019879572508*lm*NL + 0.988271663343985*lm^2*NL + 
        0.29035833333333333*lm^3*NL - 0.7855395575607828*NH + 
        3.587019879572508*lm*NH + 0.988271663343985*lm^2*NH + 
        0.29035833333333333*lm^3*NH)}, 
     {0.87, CF*NC*(CF*(-8.310250359056305 - 3.3769748679036047*lm + 
          2.5545047654138573*lm^2 - 5.2538*lm^3) + 
        CA*(-8.897744904491336 - 8.085654068807843*lm - 8.50481868279021*
           lm^2 - 1.6053277777777777*lm^3) + 0.4452681816105812*NM + 
        3.09884272360804*lm*NM + 0.989109457477008*lm^2*NM + 
        0.2918777777777778*lm^3*NM + 4.09643900962463*NL + 
        1.58504272360804*lm*NL + 0.989109457477008*lm^2*NL + 
        0.2918777777777778*lm^3*NL - 0.7822593837615499*NH + 
        3.58504272360804*lm*NH + 0.989109457477008*lm^2*NH + 
        0.2918777777777778*lm^3*NH)}, 
     {0.875, CF*NC*(CF*(-8.338087097116608 - 3.412327419176985*lm + 
          2.6463314381646112*lm^2 - 5.28125*lm^3) + 
        CA*(-8.899795613872058 - 8.040842619830315*lm - 8.525274595283035*
           lm^2 - 1.6137152777777777*lm^3) + 0.4070834803513908*NM + 
        3.114294725562696*lm*NM + 0.9899173506575216*lm^2*NM + 
        0.2934027777777778*lm^3*NM + 4.109463445628148*NL + 
        1.5830447255626958*lm*NL + 0.9899173506575216*lm^2*NL + 
        0.2934027777777778*lm^3*NL - 0.7788907291771079*NH + 
        3.583044725562696*lm*NH + 0.9899173506575216*lm^2*NH + 
        0.2934027777777778*lm^3*NH)}, 
     {0.88, CF*NC*(CF*(-8.365799461652383 - 3.449107285648435*lm + 
          2.739086334958428*lm^2 - 5.3088*lm^3) + 
        CA*(-8.902170716521068 - 7.995565172954098*lm - 8.545623619873814*
           lm^2 - 1.6221333333333334*lm^3) + 0.3685409480409341*NM + 
        3.129826382149177*lm*NM + 0.9906952036134207*lm^2*NM + 
        0.2949333333333333*lm^3*NM + 4.122549518977703*NL + 
        1.581026382149177*lm*NL + 0.9906952036134207*lm^2*NL + 
        0.2949333333333333*lm^3*NL - 0.775433568393303*NH + 
        3.5810263821491772*lm*NH + 0.9906952036134207*lm^2*NH + 
        0.2949333333333333*lm^3*NH)}, 
     {0.885, CF*NC*(CF*(-8.393375737672661 - 3.487329860277654*lm + 
          2.83277195146561*lm^2 - 5.33645*lm^3) + 
        CA*(-8.904874107683437 - 7.9498234910831185*lm - 
          8.56586499399662*lm^2 - 1.6305819444444445*lm^3) + 
        0.329639789372486*NM + 3.145438190357007*lm*NM + 
        0.991442877696355*lm^2*NM + 0.29646944444444445*lm^3*NM + 
        4.135697404106752*NL + 1.578988190357007*lm*NL + 
        0.991442877696355*lm^2*NL + 0.29646944444444445*lm^3*NL - 
        0.7718878799440223*NH + 3.578988190357007*lm*NH + 
        0.991442877696355*lm^2*NH + 0.29646944444444445*lm^3*NH)}, 
     {0.89, CF*NC*(CF*(-8.420804125070624 - 3.527010512016727*lm + 
          2.927390772233661*lm^2 - 5.3642*lm^3) + 
        CA*(-8.907909649555126 - 7.903619342890978*lm - 8.585997958484159*
           lm^2 - 1.639061111111111*lm^3) + 0.29037920808693435*NM + 
        3.1611306474382803*lm*NM + 0.9921602348759078*lm^2*NM + 
        0.2980111111111111*lm^3*NM + 4.148907270242213*NL + 
        1.5769306474382803*lm*NL + 0.9921602348759078*lm^2*NL + 
        0.2980111111111111*lm^3*NL - 0.7682536462788471*NH + 
        3.5769306474382803*lm*NH + 0.9921602348759078*lm^2*NH + 
        0.2980111111111111*lm^3*NH)}, 
     {0.895, CF*NC*(CF*(-8.448072739637015 - 3.5681645858261395*lm + 
          3.0229452707905744*lm^2 - 5.39205*lm^3) + 
        CA*(-8.911281171536126 - 7.856954502704147*lm - 8.606021757536213*
           lm^2 - 1.6475708333333334*lm^3) + 0.25075840698251967*NM + 
        3.1769042508937284*lm*NM + 0.992847137733857*lm^2*NM + 
        0.2995583333333333*lm^3*NM + 4.1621792814503555*NL + 
        1.5748542508937282*lm*NL + 0.992847137733857*lm^2*NL + 
        0.2995583333333333*lm^3*NL - 0.7645308537310678*NH + 
        3.574854250893728*lm*NH + 0.992847137733857*lm^2*NH + 
        0.2995583333333333*lm^3*NH)}, 
     {0.9, CF*NC*(CF*(-8.475169614058899 - 3.6108074026925365*lm + 
          3.1194379097466447*lm^2 - 5.42*lm^3) + 
        CA*(-8.91499247048109 - 7.809830750387435*lm - 8.625935638688524*
           lm^2 - 1.656111111111111*lm^3) + 0.21077658792451556*NM + 
        3.1927594984590946*lm*NM + 0.9935034494585198*lm^2*NM + 
        0.3011111111111111*lm^3*NM + 4.175513596682166*NL + 
        1.5727594984590945*lm*NL + 0.9935034494585198*lm^2*NL + 
        0.3011111111111111*lm^3*NL - 0.7607194924860525*NH + 
        3.5727594984590945*lm*NH + 0.9935034494585198*lm^2*NH + 
        0.3011111111111111*lm^3*NH)}, 
     {0.905, CF*NC*(CF*(-8.502082698904056 - 3.6549542596481555*lm + 
          3.2168711408948325*lm^2 - 5.44805*lm^3) + 
        CA*(-8.919047310947478 - 7.762249871231671*lm - 8.645738852782134*
           lm^2 - 1.6646819444444445*lm^3) + 0.17043295185485005*NM + 
        3.20869688809181*lm*NM + 0.994129033839176*lm^2*NM + 
        0.30266944444444444*lm^3*NM + 4.1889103698182*NL + 
        1.57064688809181*lm*NL + 0.994129033839176*lm^2*NL + 
        0.30266944444444444*lm^3*NL - 0.756819556549966*NH + 
        3.5706468880918103*lm*NH + 0.994129033839176*lm^2*NH + 
        0.30266944444444444*lm^3*NH)}, 
     {0.91, CF*NC*(CF*(-8.528799863591253 - 3.700620429791878*lm + 
          3.3152474053097065*lm^2 - 5.4762*lm^3) + 
        CA*(-8.923449425441268 - 7.714213655843561*lm - 8.665430653933145*
           lm^2 - 1.6732833333333332*lm^3) + 0.12972669880166682*NM + 
        3.224716917957963*lm*NM + 0.9947237552605719*lm^2*NM + 
        0.30423333333333336*lm^3*NM + 4.20236974971292*NL + 
        1.5685169179579628*lm*NL + 0.9947237552605719*lm^2*NL + 
        0.30423333333333336*lm^3*NL - 0.752831043718832*NH + 
        3.5685169179579628*lm*NH + 0.9947237552605719*lm^2*NH + 
        0.30423333333333336*lm^3*NH)}, 
     {0.915, CF*NC*(CF*(-8.555308897346654 - 3.747821162311839*lm + 
          3.414569133444995*lm^2 - 5.50445*lm^3) + 
        CA*(-8.928202514660216 - 7.665723900037657*lm - 8.685010299502919*
           lm^2 - 1.6819152777777777*lm^3) + 0.08865702788882493*NM + 
        3.2408200864195527*lm*NM + 0.9952874786975003*lm^2*NM + 
        0.30580277777777776*lm^3*NM + 4.215891880238536*NL + 
        1.5663700864195524*lm*NL + 0.9952874786975003*lm^2*NL + 
        0.30580277777777776*lm^3*NL - 0.7487539555479356*NH + 
        3.5663700864195524*lm*NH + 0.9952874786975003*lm^2*NH + 
        0.30580277777777776*lm^3*NH)}, 
     {0.92, CF*NC*(CF*(-8.58159751014663 - 3.796571682509541*lm + 
          3.5148387452297687*lm^2 - 5.5328*lm^3) + 
        CA*(-8.933310247734736 - 7.616782404730395*lm - 8.704477050068682*
           lm^2 - 1.6905777777777777*lm^3) + 0.04722313734533667*NM + 
        3.257006892022028*lm*NM + 0.9958200697094574*lm^2*NM + 
        0.3073777777777778*lm^3*NM + 4.229476900328347*NL + 
        1.5642068920220278*lm*NL + 0.9958200697094574*lm^2*NL + 
        0.3073777777777778*lm^3*NL - 0.7445882973215586*NH + 
        3.564206892022028*lm*NH + 0.9958200697094574*lm^2*NH + 
        0.3073777777777778*lm^3*NH)}, 
     {0.925, CF*NC*(CF*(-8.607653333647196 - 3.8468871918254126*lm + 
          3.616058650163287*lm^2 - 5.56125*lm^3) + 
        CA*(-8.938776262466394 - 7.56739097583616*lm - 8.723830169394551*
           lm^2 - 1.6992708333333333*lm^3) + 0.005424224514742676*NM + 
        3.2732778334820924*lm*NM + 0.9963213944353729*lm^2*NM + 
        0.30895833333333333*lm^3*NM + 4.243124944019598*NL + 
        1.5620278334820927*lm*NL + 0.9963213944353729*lm^2*NL + 
        0.30895833333333333*lm^3*NL - 0.740334078023045*NH + 
        3.5620278334820927*lm*NH + 0.9963213944353729*lm^2*NH + 
        0.30895833333333333*lm^3*NH)}, 
     {0.93, CF*NC*(CF*(-8.633463922100331 - 3.8987828678657652*lm + 
          3.7182312474085237*lm^2 - 5.5898*lm^3) + 
        CA*(-8.944604165564051 - 7.51755142416532*lm - 8.743068924402952*
           lm^2 - 1.7079944444444444*lm^3) - 0.03674051413557646*NM + 
        3.289633409675782*lm*NM + 0.9967913195884154*lm^2*NM + 
        0.31054444444444446*lm^3*NM + 4.256836140495852*NL + 
        1.5598334096757822*lm*NL + 0.9967913195884154*lm^2*NL + 
        0.31054444444444446*lm^3*NL - 0.7359913103051896*NH + 
        3.559833409675782*lm*NH + 0.9967913195884154*lm^2*NH + 
        0.31054444444444446*lm^3*NH)}, 
     {0.935, CF*NC*(CF*(-8.659016753257399 - 3.9522738644310933*lm + 
          3.821358925884408*lm^2 - 5.61845*lm^3) + 
        CA*(-8.950797532877694 - 7.467265565324197*lm - 8.762192585146432*
           lm^2 - 1.7167486111111112*lm^3) - 0.07927188300515257*NM + 
        3.306074119626796*lm*NM + 0.9972297124508662*lm^2*NM + 
        0.3121361111111111*lm^3*NM + 4.270610614128884*NL + 
        1.557624119626796*lm*NL + 0.9972297124508662*lm^2*NL + 
        0.3121361111111111*lm^3*NL - 0.7315600104609473*NH + 
        3.557624119626796*lm*NH + 0.9972297124508662*lm^2*NH + 
        0.3121361111111111*lm^3*NH)}, 
     {0.94, CF*NC*(CF*(-8.68429922925991 - 4.007375311545671*lm + 
          3.925444064356793*lm^2 - 5.6472*lm^3) + 
        CA*(-8.957359909629957 - 7.416535219616921*lm - 8.781200424779868*
           lm^2 - 1.7255333333333334*lm^3) - 0.12217068735124688*NM + 
        3.322600462495087*lm*NM + 0.9976364408690671*lm^2*NM + 
        0.3137333333333333*lm^3*NM + 4.284448484520117*NL + 
        1.555400462495087*lm*NL + 0.9976364408690671*lm^2*NL + 
        0.3137333333333333*lm^3*NL - 0.727040198394456*NH + 
        3.5554004624950872*lm*NH + 0.9976364408690671*lm^2*NH + 
        0.3137333333333333*lm^3*NH)}, 
     {0.945, CF*NC*(CF*(-8.709298677517834 - 4.064102315488394*lm + 
          4.030489031528189*lm^2 - 5.67605*lm^3) + 
        CA*(-8.964294810645384 - 7.365362211949131*lm - 8.800091719533054*
           lm^2 - 1.734348611111111*lm^3) - 0.16543773327973196*NM + 
        3.3392129375656965*lm*NM + 0.9980113732484339*lm^2*NM + 
        0.3153361111111111*lm^3*NM + 4.298349866541578*NL + 
        1.5531629375656966*lm*NL + 0.9980113732484339*lm^2*NL + 
        0.3153361111111111*lm^3*NL - 0.7224318975923704*NH + 
        3.5531629375656966*lm*NH + 0.9980113732484339*lm^2*NH + 
        0.3153361111111111*lm^3*NH)}, 
     {0.95, CF*NC*(CF*(-8.734002351575715 - 4.122469958824827*lm + 
          4.136496186126274*lm^2 - 5.705*lm^3) + 
        CA*(-8.971605720577426 - 7.313748371733487*lm - 8.818865748683638*
           lm^2 - 1.7431944444444445*lm^3) - 0.20907382773603922*NM + 
        3.3559120442378325*lm*NM + 0.9983543785485404*lm^2*NM + 
        0.3169444444444444*lm^3*NM + 4.31231487037642*NL + 
        1.5509120442378324*lm*NL + 0.9983543785485404*lm^2*NL + 
        0.3169444444444444*lm^3*NL - 0.7177351350955015*NH + 
        3.5509120442378324*lm*NH + 0.9983543785485404*lm^2*NH + 
        0.3169444444444444*lm^3*NH)}, 
     {0.955, CF*NC*(CF*(-8.758397431966754 - 4.182493300440408*lm + 
          4.243467876991198*lm^2 - 5.73405*lm^3) + 
        CA*(-8.97929609413323 - 7.261695532796929*lm - 8.837521794530467*
           lm^2 - 1.7520708333333332*lm^3) - 0.25307977849617214*NM + 
        3.3726982820141815*lm*NM + 0.9986653262782668*lm^2*NM + 
        0.31855833333333333*lm^3*NM + 4.326343601558972*NL + 
        1.5486482820141816*lm*NL + 0.9986653262782668*lm^2*NL + 
        0.31855833333333333*lm^3*NL - 0.7129499414707574*NH + 
        3.548648282014182*lm*NH + 0.9986653262782668*lm^2*NH + 
        0.31855833333333333*lm^3*NH)}, 
     {0.96, CF*NC*(CF*(-8.782471027055113 - 4.24418737557476*lm + 
          4.351406443161733*lm^2 - 5.7632*lm^3) + 
        CA*(-8.987369356296231 - 7.209205533289681*lm - 8.856059142367249*
           lm^2 - 1.7609777777777778*lm^3) - 0.29745639415778585*NM + 
        3.389572150490456*lm*NM + 0.9989440864910148*lm^2*NM + 
        0.3201777777777778*lm^3*NM + 4.340436161014361*NL + 
        1.5463721504904557*lm*NL + 0.9989440864910148*lm^2*NL + 
        0.3201777777777778*lm^3*NL - 0.7080763507833807*NH + 
        3.5463721504904555*lm*NH + 0.9989440864910148*lm^2*NH + 
        0.3201777777777778*lm^3*NH)}, 
     {0.965, CF*NC*(CF*(-8.806210173866623 - 4.3075671958570885*lm + 
          4.460314213960247*lm^2 - 5.79245*lm^3) + 
        CA*(-8.995828902546556 - 7.156280215595932*lm - 8.874477080456591*
           lm^2 - 1.7699152777777778*lm^3) - 0.3422044841313328*NM + 
        3.406534149345159*lm*NM + 0.9991905297799862*lm^2*NM + 
        0.32180277777777777*lm^3*NM + 4.354592645097688*NL + 
        1.5440841493451591*lm*NL + 0.9991905297799862*lm^2*NL + 
        0.32180277777777777*lm^3*NL - 0.7031144005694795*NH + 
        3.544084149345159*lm*NH + 0.9991905297799862*lm^2*NH + 
        0.32180277777777777*lm^3*NH)}, 
     {0.97, CF*NC*(CF*(-8.829601838908092 - 4.3726477493425975*lm + 
          4.570193509076561*lm^2 - 5.8218*lm^3) + 
        CA*(-9.004678099079301 - 7.102921426246165*lm - 8.892774900004385*
           lm^2 - 1.7788833333333334*lm^3) - 0.38732485863127536*NM + 
        3.4235847783295794*lm*NM + 0.9994045272735244*lm^2*NM + 
        0.32343333333333335*lm^3*NM + 4.368813145632775*NL + 
        1.5417847783295795*lm*NL + 0.9994045272735244*lm^2*NL + 
        0.32343333333333335*lm^3*NL - 0.6980641318088459*NH + 
        3.5417847783295793*lm*NH + 0.9994045272735244*lm^2*NH + 
        0.32343333333333335*lm^3*NH)}, 
     {0.975, CF*NC*(CF*(-8.852632918975441 - 4.439444000549908*lm + 
          4.681046638650684*lm^2 - 5.85125*lm^3) + 
        CA*(-9.013920283020664 - 7.0491310158311045*lm - 8.910951895134513*
           lm^2 - 1.7878819444444445*lm^3) - 0.43281832866736497*NM + 
        3.44072453725799*lm*NM + 0.9995859506305176*lm^2*NM + 
        0.32506944444444447*lm^3*NM + 4.383097749950484*NL + 
        1.53947453725799*lm*NL + 0.9995859506305176*lm^2*NL + 
        0.32506944444444447*lm^3*NL - 0.6929255888980603*NH + 
        3.5394745372579903*lm*NH + 0.9995859506305176*lm^2*NH + 
        0.32506944444444447*lm^3*NH)}, 
     {0.98, CF*NC*(CF*(-8.875290241950816 - 4.507970890499429*lm + 
          4.792875903354459*lm^2 - 5.8808*lm^3) + 
        CA*(-9.023558762641981 - 6.994910838917244*lm - 8.929007362863915*
           lm^2 - 1.7969111111111111*lm^3) - 0.47868570603598876*NM + 
        3.4579539259980665*lm*NM + 0.9997346720358634*lm^2*NM + 
        0.3267111111111111*lm^3*NM + 4.397446540926621*NL + 
        1.5371539259980662*lm*NL + 0.9997346720358634*lm^2*NL + 
        0.3267111111111111*lm^3*NL - 0.6876988196238752*NH + 
        3.537153925998066*lm*NH + 0.9997346720358634*lm^2*NH + 
        0.3267111111111111*lm^3*NH)}, 
     {0.985, CF*NC*(CF*(-8.8975605675889 - 4.578243336752649*lm + 
          4.9056835944721415*lm^2 - 5.91045*lm^3) + 
        CA*(-9.033596817571699 - 6.940262753963916*lm - 8.946940603077957*
           lm^2 - 1.8059708333333333*lm^3) - 0.5249278033115824*NM + 
        3.475273444461502*lm*NM + 0.9998505641959922*lm^2*NM + 
        0.3283583333333333*lm^3*NM + 4.411859597019418*NL + 
        1.534823444461502*lm*NL + 0.9998505641959922*lm^2*NL + 
        0.3283583333333333*lm^3*NL - 0.6823838751368763*NH + 
        3.534823444461502*lm*NH + 0.9998505641959922*lm^2*NH + 
        0.3283583333333333*lm^3*NH)}, 
     {0.99, CF*NC*(CF*(-8.919430588292593 - 4.650276233452309*lm + 
          5.019471993979914*lm^2 - 5.9402*lm^3) + 
        CA*(-9.04403769900527 - 6.88518862324187*lm - 8.964750918506137*
           lm^2 - 1.815061111111111*lm^3) - 0.5715454338381109*NM + 
        3.492683592594831*lm*NM + 0.9999335003344493*lm^2*NM + 
        0.3300111111111111*lm^3*NM + 4.426336992306607*NL + 
        1.5324835925948308*lm*NL + 0.9999335003344493*lm^2*NL + 
        0.3300111111111111*lm^3*NL - 0.6769808099254156*NH + 
        3.5324835925948306*lm*NH + 0.9999335003344493*lm^2*NH + 
        0.3300111111111111*lm^3*NH)}, 
     {0.995, CF*NC*(CF*(-8.940886929878252 - 4.724084451363425*lm + 
          5.134243374624374*lm^2 - 5.97005*lm^3) + 
        CA*(-9.054884629913044 - 6.829690312753339*lm - 8.982437614698108*
           lm^2 - 1.8241819444444445*lm^3) - 0.618539411720616*NM + 
        3.51018487037044*lm*NM + 0.9999833541875348*lm^2*NM + 
        0.33166944444444446*lm^3*NM + 4.440878796522098*NL + 
        1.53013487037044*lm*NL + 0.9999833541875348*lm^2*NL + 
        0.33166944444444446*lm^3*NL - 0.6714896817898145*NH + 
        3.53013487037044*lm*NH + 0.9999833541875348*lm^2*NH + 
        0.33166944444444446*lm^3*NH)}, 
     {1., -6.014728109467526*(CA - 2.*CF)*CF*NC + 0.002777777777777778*CF*NC*
        (CF*(-7556.8940536556465 - 1727.8858216494473*lm + 1890.*lm^2 - 
           2160.*lm^3) - 1.*CA*(1098.508570480295 + 2438.5570891752764*lm + 
           3240.*lm^2 + 660.*lm^3) + 10.*((-23.97277986540592 + 127.*lm + 
             36.*lm^2 + 12.*lm^3)*NM + (160.39746270332105 + 55.*lm + 
             36.*lm^2 + 12.*lm^3)*NL + (-23.97277986540592 + 127.*lm + 
             36.*lm^2 + 12.*lm^3)*NH))}}
 
CbarTable["s", 2, 0] = {{0., -0.000038580246913580246*CF*NC*
       (-3.*CA*(5160.430157209292 + 198.04533104651125*lm + 7140.*lm^2 + 
          1320.*lm^3) + 2.*(CF*(-135.93938964079425 + 116.1865557539944*lm + 
            5670.*lm^2 - 3240.*lm^3) - 
          15.*((-288.8434648794611 - 83.04316479128514*lm - 84.*lm^2 - 
              24.*lm^3)*NM + (-288.8434648794611 - 83.04316479128514*lm - 
              84.*lm^2 - 24.*lm^3)*NL - 1.*(-114.9438057198067 + 
              83.04316479128514*lm + 84.*lm^2 + 24.*lm^3)*NH)))}, 
     {0.005, CF*NC*(CA*(0.5721849650298131 + 0.003389912136761509*lm + 
          0.8240753559234069*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.015742162055531205 - 0.02285796723312334*lm - 
          0.44128578121624334*lm^2 + 0.25*lm^3) - 0.3306313025613586*NM - 
        0.093098864122663*lm*NM - 0.09680157986486185*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3306508116377671*NL - 
        0.093098864122663*lm*NL - 0.09680157986486185*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13102939970085378*NH - 
        0.093098864122663*lm*NH - 0.09680157986486185*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.01, CF*NC*(CA*(0.5472191432292776 - 0.016337174885636373*lm + 
          0.821721067344922*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.041276846210040435 - 0.03675185585929372*lm - 
          0.4451382534355821*lm^2 + 0.25*lm^3) - 0.32694293707000543*NM - 
        0.09005691507890119*lm*NM - 0.09637352739604643*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.32701612921167955*NL - 
        0.09005691507890119*lm*NL - 0.09637352739604643*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12899427971671942*NH - 
        0.09005691507890119*lm*NH - 0.09637352739604643*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.015, CF*NC*(CA*(0.5225644037880556 - 0.03619470775921618*lm + 
          0.8193294919313148*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.06586267444437607 - 0.05056799423210315*lm - 
          0.44905174047603036*lm^2 + 0.25*lm^3) - 0.32327784135435556*NM - 
        0.08699987696619249*lm*NM - 0.09593869550266329*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3234337222136378*NL - 
        0.08699987696619249*lm*NL - 0.09593869550266329*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12693389579055975*NH - 
        0.08699987696619249*lm*NH - 0.09593869550266329*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.02, CF*NC*(CA*(0.49832486389371694 - 0.056138209771308976*lm + 
          0.8169034230803651*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.08939780619864532 - 0.06425541848207832*lm - 
          0.45302167132303883*lm^2 + 0.25*lm^3) - 0.31965459171711763*NM - 
        0.08393519005346975*lm*NM - 0.09549759207521791*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3199183841598915*NL - 
        0.08393519005346975*lm*NL - 0.09549759207521791*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12485024913409827*NH - 
        0.08393519005346975*lm*NH - 0.09549759207521791*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.025, CF*NC*(CA*(0.47456689681565584 - 0.07613360290759158*lm + 
          0.8144452539797441*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.11183876482330349 - 0.07777705518370694*lm - 
          0.4570441298513278*lm^2 + 0.25*lm^3) - 0.3160852162805232*NM - 
        0.08086849654784307*lm*NM - 0.09505065223874136*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3164791525588288*NL - 
        0.08086849654784307*lm*NL - 0.09505065223874136*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12274507776946549*NH - 
        0.08086849654784307*lm*NH - 0.09505065223874136*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.03, CF*NC*(CA*(0.45133512687868754 - 0.09615350194153624*lm + 
          0.8119570948716573*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.13317230447171127 - 0.091104572965352*lm - 
          0.46111566293728795*lm^2 + 0.25*lm^3) - 0.31257795114815856*NM - 
        0.077804287260898*lm*NM - 0.09459825967363467*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3131218127875409*NL - 
        0.077804287260898*lm*NL - 0.09459825967363467*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12061993264644418*NH - 
        0.077804287260898*lm*NH - 0.09459825967363467*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.035, CF*NC*(CA*(0.4286601270625781 - 0.1161752711202678*lm + 
          0.8094408393541201*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.15340273233126134 - 0.10421572034813059*lm - 
          0.4652331719659852*lm^2 + 0.25*lm^3) - 0.30913857118804*NM - 
        0.0747462395960959*lm*NM - 0.09414075867044609*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30985008685731913*NL - 
        0.0747462395960959*lm*NL - 0.09414075867044609*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11847622058119808*NH - 
        0.0747462395960959*lm*NH - 0.09414075867044609*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.04, CF*NC*(CA*(0.40656276535167546 - 0.13617984657624793*lm + 
          0.8068982070548071*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.17254517119456902 - 0.11709273206245492*lm - 
          0.4693938430012247*lm^2 + 0.25*lm^3) - 0.3057711440103076*NM - 
        0.07169742178080006*lm*NM - 0.09367846188875281*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.306666296616814*NL - 
        0.07169742178080006*lm*NL - 0.09367846188875281*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11631523184937359*NH - 
        0.07169742178080006*lm*NH - 0.09367846188875281*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.045, CF*NC*(CA*(0.3850569059263286 - 0.1561509574804605*lm + 
          0.8043307733521055*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.1906216126132315 - 0.129721286690397*lm - 0.4735950981511002*
           lm^2 + 0.25*lm^3) - 0.3024785001519763*NM - 
        0.06866042759718824*lm*NM - 0.09321165576098887*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3035717713124776*NL - 
        0.06866042759718824*lm*NL - 0.09321165576098887*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11413815938642723*NH - 
        0.06866042759718824*lm*NH - 0.09321165576098887*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.05, CF*NC*(CA*(0.3641512006042113 - 0.17607457928467704*lm + 
          0.8017399912207542*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.2076584505513653 - 0.14208978258385158*lm - 
          0.4778345598205839*lm^2 + 0.25*lm^3) - 0.29926254594548557*NM - 
        0.06563747073756072*lm*NM - 0.09274060446437957*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30056711497147337*NL - 
        0.06563747073756072*lm*NL - 0.09274060446437957*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1119461128968264*NH - 
        0.06563747073756072*lm*NH - 0.09274060446437957*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.055, CF*NC*(CA*(0.3438503342953334 - 0.195938532833154*lm + 
          0.7991272079337889*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.22368486852430863 - 0.15418881230629902*lm - 
          0.4821100233810728*lm^2 + 0.25*lm^3) - 0.29612448173192313*NM - 
        0.0626304538282098*lm*NM - 0.09226555295765858*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2976523903273216*NL - 
        0.0626304538282098*lm*NL - 0.09226555295765858*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10974012964537717*NH - 
        0.0626304538282098*lm*NH - 0.09226555295765858*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.06, CF*NC*(CA*(0.3241559224486177 - 0.21573218049581028*lm + 
          0.7964936782225247*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.23873174951132642 - 0.16601076817457422*lm - 
          0.4864194356358687*lm^2 + 0.25*lm^3) - 0.2930649595823947*NM - 
        0.05964102063264747*lm*NM - 0.09178672937379237*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2948272499589714*NL - 
        0.05964102063264747*lm*NL - 0.09178672937379237*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.107521182968546*NH - 
        0.05964102063264747*lm*NH - 0.09178672937379237*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.065, CF*NC*(CA*(0.3050671761611047 - 0.23544618971402473*lm + 
          0.7938405748958781*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.2528309212142887 - 0.17754953826982584*lm - 
          0.49076087744310853*lm^2 + 0.25*lm^3) - 0.2900842005259838*NM - 
        0.056670596585915126*lm*NM - 0.09130434695076571*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2920910324527146*NL - 
        0.056670596585915126*lm*NL - 0.09130434695076571*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10529018915338216*NH - 
        0.056670596585915126*lm*NH - 0.09130434695076571*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.07, CF*NC*(CA*(0.2865814063557244 - 0.25507234504495746*lm + 
          0.7911689975769253*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.2660146243719645 - 0.18880026710548095*lm - 
          0.4951325494195768*lm^2 + 0.25*lm^3) - 0.28718208365453274*NM - 
        0.05372042094666024*lm*NM - 0.09081860562004702*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2894428345156521*NL - 
        0.05372042094666024*lm*NL - 0.09081860562004702*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10304801310875368*NH - 
        0.05372042094666024*lm*NH - 0.09081860562004702*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.075, CF*NC*(CA*(0.26869441309386244 - 0.2746033961029706*lm + 
          0.7884799800065887*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.27831513381003536 - 0.1997591638453031*lm - 
          0.4995327599892186*lm^2 + 0.25*lm^3) - 0.2843582151013668*NM - 
        0.05079157275404154*lm*NM - 0.09032969333453127*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2868815660502941*NL - 
        0.05079157275404154*lm*NL - 0.09032969333453127*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10079547311878233*NH - 
        0.05079157275404154*lm*NH - 0.09032969333453127*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.08, CF*NC*(CA*(0.25140079083537564 - 0.2940329327073893*lm + 
          0.7857744962323605*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.2897644865707516 - 0.21042334633314824*lm - 
          0.5039599152561374*lm^2 + 0.25*lm^3) - 0.2816119822545744*NM - 
        0.047884992096034744*lm*NM - 0.08983778719376251*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2844059928521607*NL - 
        0.047884992096034744*lm*NL - 0.08983778719376251*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09853334488294047*NH - 
        0.047884992096034744*lm*NH - 0.08983778719376251*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.085, CF*NC*(CA*(0.23469417088818276 - 0.31335528106703986*lm + 
          0.7830534659129703*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.30039428657707806 - 0.22079071264213246*lm - 
          0.5084125103242304*lm^2 + 0.25*lm^3) - 0.278942596908548*NM - 
        0.04500149775744477*lm*NM - 0.08934305440841885*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2820147701262001*NL - 
        0.04500149775744477*lm*NL - 0.08934305440841885*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09626236499104586*NH - 
        0.04500149775744477*lm*NH - 0.08934305440841885*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.09, CF*NC*(CA*(0.21856741607213606 - 0.3325654165128041*lm + 
          0.7803177589106758*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.31023556487330783 - 0.2308598341387689*lm - 
          0.5128891217825305*lm^2 + 0.25*lm^3) - 0.2763491299792669*NM - 
        0.04214180202403512*lm*NM - 0.08884565313527439*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2797064690698512*NL - 
        0.04214180202403512*lm*NL - 0.08884565313527439*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.0939832339431722*NH - 
        0.04214180202403512*lm*NH - 0.08884565313527439*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.095, CF*NC*(CA*(0.20301277846117619 - 0.35165888944245494*lm + 
          0.7775681993014181*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.3193186807498495 - 0.24062986562077157*lm - 
          0.5173884011431341*lm^2 + 0.25*lm^3) - 0.2738305396859887*NM - 
        0.039306523219133443*lm*NM - 0.08834573320631843*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2774795981390872*NL - 
        0.039306523219133443*lm*NL - 0.08834573320631843*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09169661879779478*NH - 
        0.039306523219133443*lm*NH - 0.08834573320631843*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.1, CF*NC*(CA*(0.18802202821122568 - 0.3706317619527949*lm + 
          0.7748055689033936*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.32767325326070174 - 0.25010046918204565*lm - 
          0.5219090690671742*lm^2 + 0.25*lm^3) - 0.2713856946048655*NM - 
        0.03649619640853185*lm*NM - 0.08784343677031398*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27533262018217747*NL - 
        0.03649619640853185*lm*NL - 0.08784343677031398*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08940315551239328*NH - 
        0.03649619640853185*lm*NH - 0.08784343677031398*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.105, CF*NC*(CA*(0.17358655947580526 - 0.38948055321662434*lm + 
          0.7720306104028802*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.3353281155215955 - 0.2592717492419889*lm - 
          0.5264499102498323*lm^2 + 0.25*lm^3) - 0.2690133926503274*NM - 
        0.03371128260861553*lm*NM - 0.08733889886112974*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2732639663242601*NL - 
        0.03371128260861553*lm*NL - 0.08733889886112974*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08710345102678685*NH - 
        0.03371128260861553*lm*NH - 0.08733889886112974*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.11, CF*NC*(CA*(0.15969747797543704 - 0.4082021920886097*lm + 
          0.769244030139981*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.3423112861891705 - 0.26814419674788414*lm - 
          0.5310097688618493*lm^2 + 0.25*lm^3) - 0.26671237678923443*NM - 
        0.030952176758842813*lm*NM - 0.08683224790423898*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27127204727079685*NL - 
        0.030952176758842813*lm*NL - 0.08683224790423898*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08479808512910542*NH - 
        0.030952176758842813*lm*NH - 0.08683224790423898*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.115, CF*NC*(CA*(0.14634567374069343 - 0.4267939757417722*lm + 
          0.766446500604703*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.34864995395219384 - 0.2767186409833261*lm - 
          0.5355875444650314*lm^2 + 0.25*lm^3) - 0.26448134810969104*NM - 
        0.02821921466477842*lm*NM - 0.08632360617055206*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26935526254201936*NL - 
        0.02821921466477842*lm*NL - 0.08632360617055206*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08248761213646126*NH - 
        0.02821921466477842*lm*NH - 0.08632360617055206*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.12, CF*NC*(CA*(0.13352188177451743 - 0.44525353337647144*lm + 
          0.7636386626843862*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.35437047189841847 - 0.2849962077351533*lm - 
          0.5401821883346407*lm^2 + 0.25*lm^3) - 0.26231897673064597*NM - 
        0.02551267907639401*lm*NM - 0.08581309018503992*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2675120080355664*NL - 
        0.02551267907639401*lm*NL - 0.08581309018503992*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08017256241637354*NH - 
        0.02551267907639401*lm*NH - 0.08581309018503992*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.125, CF*NC*(CA*(0.12121673279840289 - 0.46357879422780085*lm + 
          0.7608211276961768*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.35949835937608315 - 0.2929782828153624*lm - 
          0.5447927001335289*lm^2 + 0.25*lm^3) - 0.26022391093631514*NM - 
        0.02283280503458093*lm*NM - 0.08530081109627456*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26574068222866115*NL - 
        0.02283280503458093*lm*NL - 0.08530081109627456*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07785344377032717*NH - 
        0.02283280503458093*lm*NH - 0.08530081109627456*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.13, CF*NC*(CA*(0.10942079580542259 - 0.4817679592400988*lm + 
          0.7579944792324781*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.3640583095283859 - 0.30066648012312863*lm - 
          0.5494181248923086*lm^2 + 0.25*lm^3) - 0.2581947848417245*NM - 
        0.020179784594192573*lm*NM - 0.0847868750119657*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26403969126621896*NL - 
        0.020179784594192573*lm*NL - 0.0847868750119657*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07553074269717568*NH - 
        0.020179784594192573*lm*NH - 0.0847868750119657*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.135, CF*NC*(CA*(0.09812461380359223 - 0.4998194758892996*lm + 
          0.7551592748427262*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.36807420109790573 - 0.30806261357954356*lm - 
          0.5540575502573571*lm^2 + 0.25*lm^3) - 0.2562302248357912*NM - 
        0.01755377101262758*lm*NM - 0.08427138330473809*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2624074531315606*NL - 
        0.01755377101262758*lm*NL - 0.08427138330473809*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07320492555117844*NH - 
        0.01755377101262758*lm*NH - 0.08427138330473809*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.14, CF*NC*(CA*(0.08731873386930762 - 0.5177320157226322*lm + 
          0.7523160475711508*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.37156911341434434 - 0.3151686723841807*lm - 
          0.5587101039744806*lm^2 + 0.25*lm^3) - 0.25432885500175095*NM - 
        0.014954882477675463*lm*NM - 0.08375443289172438*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26084240105795653*NL - 
        0.014954882477675463*lm*NL - 0.08375443289172438*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07087643960712173*NH - 
        0.014954882477675463*lm*NH - 0.08375443289172438*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.145, CF*NC*(CA*(0.07699373242371867 - 0.5355044542562039*lm + 
          0.749465307367193*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.37456534372017386 - 0.3219867991354786*lm - 
          0.5633749515809571*lm^2 + 0.25*lm^3) - 0.25248930167811307*NM - 
        0.012383205436123746*lm*NM - 0.08323611649100478*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.25934298630920627*NL - 
        0.012383205436123746*lm*NL - 0.08323611649100478*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06854571404307476*NH - 
        0.012383205436123746*lm*NH - 0.08323611649100478*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.15, CF*NC*(CA*(0.06714023648120915 - 0.5531358529283195*lm + 
          0.7466075423828069*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.37708442617412147 - 0.3285192704316284*lm - 
          0.5680512942826795*lm^2 + 0.25*lm^3) - 0.2507101972942869*NM - 
        0.009838797574770564*lm*NM - 0.08271652285748005*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2579076804338114*NL - 
        0.009838797574770564*lm*NL - 0.08271652285748005*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06621316084978383*NH - 
        0.009838797574770564*lm*NH - 0.08271652285748005*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.155, CF*NC*(CA*(0.057748941488570356 - 0.5706254428530038*lm + 
          0.7437432201688591*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.37914715201583715 - 0.3347684796292053*lm - 
          0.5727383669964123*lm^2 + 0.25*lm^3) - 0.24899018359181946*NM - 
        0.007321690497477042*lm*NM - 0.08219573700039863*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.25653497707852446*NL - 
        0.007321690497477042*lm*NL - 0.08219573700039863*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06387917567443242*NH - 
        0.007321690497477042*lm*NH - 0.08219573700039863*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.16, CF*NC*(CA*(0.04881062626850953 - 0.58797261015639*lm + 
          0.7408727887811652*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.380773590486766 - 0.3407369214862282*lm - 0.5774354365399114*
           lm^2 + 0.25*lm^3) - 0.24732791432349782*NM - 
        0.004831892135335982*lm*NM - 0.08167384038445429*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.25522339343203665*NL - 
        0.004831892135335982*lm*NL - 0.08167384038445429*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06154413860543817*NH - 
        0.004831892135335982*lm*NH - 0.08167384038445429*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.165, CF*NC*(CA*(0.04031616549620201 - 0.6051768827101456*lm + 
          0.7379966778053116*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.38198311018969283 - 0.34642717845698756*lm - 
          0.5821417999549446*lm^2 + 0.25*lm^3) - 0.2457220575074246*NM - 
        0.0023693889216275608*lm*NM - 0.08115091111611726*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2539714713574705*NL - 
        0.0023693889216275608*lm*NL - 0.08115091111611726*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.059208414904076426*NH - 
        0.0023693889216275608*lm*NH - 0.08115091111611726*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.17, CF*NC*(CA*(0.0322565400684193 - 0.6222379181022678*lm + 
          0.735115299308231*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.38279440063823994 - 0.35184190843962493*lm - 
          0.5868567829501673*lm^2 + 0.25*lm^3) - 0.24417129730081524*NM + 
        0.00006585224125207677*lm*NM - 0.08062702411664807*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2527777782625366*NL + 
        0.00006585224125207677*lm*NL - 0.08062702411664807*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.05687235568797902*NH + 
        0.00006585224125207677*lm*NH - 0.08062702411664807*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.175, CF*NC*(CA*(0.02462284566808324 - 0.6391554927074288*lm + 
          0.7322290487235144*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.3832254938019865 - 0.3569838338054478*lm - 
          0.5915797384524311*lm^2 + 0.25*lm^3) - 0.24267433554812276*NM + 
        0.002473882199446067*lm*NM - 0.08010225128306321*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.25164090774821934*NL + 
        0.002473882199446067*lm*NL - 0.08010225128306321*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.054536298570932305*NH + 
        0.002473882199446067*lm*NH - 0.08010225128306321*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.18, CF*NC*(CA*(0.017406299780392657 - 0.6559294917373947*lm + 
          0.7293383056765919*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.3832937854960245 - 0.3618557315624019*lm - 
          0.5963100452564861*lm^2 + 0.25*lm^3) - 0.2412298930497243*NM + 
        0.0048547679295734905*lm*NM - 0.0795766616381682*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2505594800702993*NL + 
        0.0048547679295734905*lm*NL - 0.0795766616381682*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.052200568262866905*NH + 
        0.0048547679295734905*lm*NH - 0.0795766616381682*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.185, CF*NC*(CA*(0.010598247377986827 - 0.6725599001675366*lm + 
          0.7264434347552029*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.38301605649810083 - 0.366460424524845*lm - 
          0.6010471067642134*lm^2 + 0.25*lm^3) - 0.23983671059045986*NM + 
        0.007208591067294443*lm*NM - 0.07905032147064296*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.24953214244261965*NL + 
        0.007208591067294443*lm*NL - 0.07905032147064296*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.04986547713347886*NH + 
        0.007208591067294443*lm*NH - 0.07905032147064296*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.19, CF*NC*(CA*(0.0041901654604150655 - 0.6890467944485864*lm + 
          0.7235447862299509*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.38240849330389237 - 0.370800773378437*lm - 
          0.605790349805535*lm^2 + 0.25*lm^3) - 0.23849354976152523*NM + 
        0.009535446567096394*lm*NM - 0.07852329446605166*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.24855756920652922*NL + 
        0.009535446567096394*lm*NL - 0.07852329446605166*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.04753132574253276*NH + 
        0.009535446567096394*lm*NH - 0.07852329446605166*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.195, CF*NC*(CA*(-0.001826333393735682 - 0.7053903349239877*lm + 
          0.7206426967292076*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.38148670845285915 - 0.37487966954312335*lm - 
          0.610539223534024*lm^2 + 0.25*lm^3) - 0.23719919360437489*NM + 
        0.011835441479807272*lm*NM - 0.07799564182955289*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.24763446188721544*NL + 
        0.011835441479807272*lm*NL - 0.07799564182955289*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.045198403339562876*NH + 
        0.011835441479807272*lm*NH - 0.07799564182955289*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.2, NC*(CA*CF*(-0.00745949832630699 - 0.7215907588827798*lm + 
          0.7177374898721736*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3802657603746484 - 0.37870002874926995*lm - 
          0.6152931983909886*lm^2 + 0.25*lm^3) + 
        CF*((-0.23595244710122176 + 0.014108693835976483*lm - 
            0.07746742240100125*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24676154915453327 + 0.014108693835976483*lm - 
            0.07746742240100125*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.042866988335398024 + 0.014108693835976483*lm - 
            0.07746742240100125*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.205, NC*(CA*CF*(-0.01271743823392195 - 0.7376483741861836*lm + 
          0.7148294768634952*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3787601727200886 - 0.3822647852523516*lm - 
          0.6200517651324624*lm^2 + 0.25*lm^3) + 
        CF*((-0.23475213753324553 + 0.01635533162466978*lm - 
            0.07693869276305973*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2459375867033303 + 0.01635533162466978*lm - 0.07693869276305973*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.04053734874768446 + 0.01635533162466978*lm - 0.07693869276305973*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.21, NC*(CA*CF*(-0.017608120436674382 - 0.7535635534131687*lm + 
          0.7119189570524922*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.37698395315199296 - 0.38557688662049416*lm - 
          0.6248144339141036*lm^2 + 0.25*lm^3) + 
        CF*((-0.23359711472480738 + 0.01857549185843499*lm - 
            0.07640950734287738*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24516135706607747 + 0.01857549185843499*lm - 
            0.07640950734287738*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.038209742622361015 + 0.01857549185843499*lm - 
            0.07640950734287738*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.215, NC*(CA*CF*(-0.0221393698942429 - 0.7693367284764314*lm + 
          0.7090062184597438*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.37495061158009796 - 0.3886392890368471*lm - 
          0.6295807334295102*lm^2 + 0.25*lm^3) + 
        CF*((-0.23248625118931746 + 0.020769319716243427*lm - 
            0.0758799185078322*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2444316693687625 + 0.020769319716243427*lm - 0.0758799185078322*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.03588441843284875 + 0.020769319716243427*lm - 0.0758799185078322*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.22, NC*(CA*CF*(-0.026318868894239067 - 0.7849683856655588*lm + 
          0.7060915382735095*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3726731778315401 - 0.39145495306540734*lm - 
          0.6343502100978936*lm^2 + 0.25*lm^3) + 
        CF*((-0.23141844219049718 + 0.02293696775712147*lm - 
            0.07534997665578959*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24374735903943692 + 0.02293696775712147*lm - 
            0.07534997665578959*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.033561615458547946 + 0.02293696775712147*lm - 
            0.07534997665578959*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.225, NC*(CA*CF*(-0.030154157147530586 - 0.8004590610788193*lm + 
          0.7031751833182271*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3701642187540784 - 0.39402683983469483*lm - 
          0.6391224272974465*lm^2 + 0.25*lm^3) + 
        CF*((-0.2303926057307942 + 0.025078595197979527*lm - 
            0.07481973030028372*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24310728747747407 + 0.025078595197979527*lm - 
            0.07481973030028372*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.031241564144086673 + 0.025078595197979527*lm - 
            0.07481973030028372*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.23, NC*(CA*CF*(-0.03365263223384002 - 0.8158093364090879*lm + 
          0.7002574104971183*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.36743585475378393 - 0.39635790759870576*lm - 
          0.6438969646410792*lm^2 + 0.25*lm^3) + 
        CF*((-0.22940768247722712 + 0.027194367249837884*lm - 
            0.0742892261509912*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2425103416904626 + 0.027194367249837884*lm - 0.0742892261509912*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.028924486440633185 + 0.027194367249837884*lm - 
            0.0742892261509912*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.235, NC*(CA*CF*(-0.036821550348286276 - 0.8310198350529975*lm + 
          0.697338467210746*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3644997757724562 - 0.39845110863897304*lm - 
          0.6486734172915065*lm^2 + 0.25*lm^3) + 
        CF*((-0.22846263563371008 + 0.029284454507255978*lm - 
            0.07375850918983261*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24195543390468952 + 0.029284454507255978*lm - 
            0.07375850918983261*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.026610596130467564 + 0.029284454507255978*lm - 
            0.07375850918983261*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.24, NC*(CA*CF*(-0.039668027305813126 - 0.846091218515545*lm + 
          0.6944185917532063*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.361367256712934 - 0.40030938647541403*lm - 
          0.6534513953129352*lm^2 + 0.25*lm^3) + 
        CF*((-0.2275564507674543 + 0.03134903238630501*lm - 
            0.0732276227430072*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24144150115433752 + 0.03134903238630501*lm - 0.0732276227430072*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.024300099135904106 + 0.03134903238630501*lm - 0.0732276227430072*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.245, NC*(CA*CF*(-0.04219903976598701 - 0.8610241830851573*lm + 
          0.6914980136874843*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.35804917232249517 - 0.4019356733570331*lm - 
          0.6582305230568439*lm^2 + 0.25*lm^3) + 
        CF*((-0.22668813559644274 + 0.033388280606893875*lm - 
            0.07269660854923957*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24096750485380994 + 0.033388280606893875*lm - 
            0.07269660854923957*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.021993193813563156 + 0.033388280606893875*lm - 
            0.07269660854923957*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.25, NC*(CA*CF*(-0.044421426645324474 - 0.8758194567566739*lm + 
          0.6885769542013775*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.35455601154630473 - 0.4033328880065323*lm - 
          0.6630104385795641*lm^2 + 0.25*lm^3) + 
        CF*((-0.22585671974379323 + 0.03540238271567384*lm - 
            0.07216550682449288*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24053243035698366 + 0.03540238271567384*lm - 
            0.07216550682449288*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.019690071234908044 + 0.03540238271567384*lm - 
            0.07216550682449288*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.255, NC*(CA*CF*(-0.046341890688442404 - 0.8904777963818746*lm + 
          0.6856556264452687*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3508978913640531 - 0.4045039335955144*lm - 
          0.6677907930895605*lm^2 + 0.25*lm^3) + 
        CF*((-0.2250612544642371 + 0.03739152564611489*lm - 
            0.07163435632338218*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24013528650666308 + 0.03739152564611489*lm - 
            0.07163435632338218*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.017390915453888513 + 0.03739152564611489*lm - 
            0.07163435632338218*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.26, NC*(CA*CF*(-0.04796700017288317 - 0.9049999850291134*lm + 
          0.6827342358529245*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3470845701238458 - 0.40545169592930014*lm - 
          0.6725712504224872*lm^2 + 0.25*lm^3) + 
        CF*((-0.224300812347246 + 0.03935589931267371*lm - 
            0.07110319439750142*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2397751051770533 + 0.03935589931267371*lm - 0.07110319439750142*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.01509590376246497 + 0.03935589931267371*lm - 0.07110319439750142*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.265, NC*(CA*CF*(-0.049303190725566305 - 0.9193868295353375*lm + 
          0.6798129804464039*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3431254603880422 - 0.4061790418224443*lm - 
          0.6773514865422481*lm^2 + 0.25*lm^3) + 
        CF*((-0.2235744870007752 + 0.04129569623626341*lm - 
            0.07057205705086132*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23945094081167648 + 0.04129569623626341*lm - 
            0.07057205705086132*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.012805206934727722 + 0.04129569623626341*lm - 
            0.07057205705086132*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.27, NC*(CA*CF*(-0.05035676723151463 - 0.9336391582353057*lm + 
          0.6768920511260695*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.33902964130617363 - 0.4066888176478799*lm - 
          0.6821311890664317*lm^2 + 0.25*lm^3) + 
        CF*((-0.22288139271909127 + 0.043211111198494315*lm - 
            0.0700409789926187*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2391618699588153 + 0.043211111198494315*lm - 0.0700409789926187*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.010518989460270824 + 0.043211111198494315*lm - 
            0.0700409789926187*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.275, NC*(CA*CF*(-0.05113390581785223 - 0.9477578188541935*lm + 
          0.6739716319466214*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3348058705303271 - 0.40698384804425375*lm - 
          0.6869100568146196*lm^2 + 0.25*lm^3) + 
        CF*((-0.2222206641377332 + 0.04510234092238672*lm - 
            0.06950999368726449*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2389069908062713 + 0.04510234092238672*lm - 0.06950999368726449*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.008237409767430981 + 0.04510234092238672*lm - 
            0.06950999368726449*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.28, NC*(CA*CF*(-0.051640655898111315 - 0.9617436765509967*lm + 
          0.6710519003800007*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3304625956885236 - 0.4070669347674814*lm - 
          0.6916877993781806*lm^2 + 0.25*lm^3) + 
        CF*((-0.2215914558782595 + 0.046969583777463526*lm - 
            0.06897913340242437*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23868542271696996 + 0.046969583777463526*lm - 
            0.06897913340242437*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.005960620436957132 + 0.046969583777463526*lm - 
            0.06897913340242437*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.285, NC*(CA*CF*(-0.05188294226367312 - 0.975597612101257*lm + 
          0.6681330275659474*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.32600796543163457 - 0.40694085567385424*lm - 
          0.696464136710268*lm^2 + 0.25*lm^3) + 
        CF*((-0.22099294218511423 + 0.04881303950731668*lm - 
            0.06844842925441467*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23849630576672115 + 0.04881303950731668*lm - 
            0.06844842925441467*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.0036887684066358277 + 0.04881303950731668*lm - 
            0.06844842925441467*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.29, NC*(CA*CF*(-0.05186656721074053 - 0.9893205202086159*lm + 
          0.665215178550936*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.32144984006929095 - 0.4066083638232042*lm - 
          0.701238798734832*lm^2 + 0.25*lm^3) + 
        CF*((-0.2204243165566442 + 0.05063290897790825*lm - 
            0.06791791125168534*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23833880028525017 + 0.05063290897790825*lm - 
            0.06791791125168534*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.0014219951673604297 + 0.05063290897790825*lm - 
            0.06791791125168534*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.295, NC*(CA*CF*(-0.0515972126926674 - 1.0029133079356074*lm + 
          0.6622985125161649*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.31679580180997685 - 0.4060721866916803*lm - 
          0.7060115249735484*lm^2 + 0.25*lm^3) + 
        CF*((-0.21988479137205083 + 0.05242939394501751*lm - 
            0.0673876083362724*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23821208640144548 + 0.05242939394501751*lm - 0.0673876083362724*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.000839563048901518 + 0.05242939394501751*lm - 
            0.0673876083362724*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.3, NC*(CA*CF*(-0.05108041712396821 - 1.0163768932448953*lm + 
          0.6593831829952216*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.3120532153497032 - 0.40533502548463574*lm - 
          0.7107820641896374*lm^2 + 0.25*lm^3) + 
        CF*((-0.21937359751582347 + 0.05420269683938052*lm - 
            0.06685754842337363*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2381153635936222 + 0.05420269683938052*lm - 0.06685754842337363*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.0030957750888192916 + 0.05420269683938052*lm - 
            0.06685754842337363*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.305, NC*(CA*CF*(-0.05032168375926183 - 1.0297122036429027*lm + 
          0.6564693380820061*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.30722902496165866 - 0.40439955454097287*lm - 
          0.7155501740476264*lm^2 + 0.25*lm^3) + 
        CF*((-0.21888998400101492 + 0.05595302056819148*lm - 
            0.06632775843915262*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23804785024547326 + 0.05595302056819148*lm - 
            0.06632775843915262*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.005346514704693119 + 0.05595302056819148*lm - 
            0.06632775843915262*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.31, NC*(CA*CF*(-0.04932631605001242 - 1.0429201749184291*lm + 
          0.653557120629452*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.30233009728158616 - 0.4032684208210604*lm - 
          0.7203156207881695*lm^2 + 0.25*lm^3) + 
        CF*((-0.21843321759253237 + 0.057680568331745743*lm - 
            0.06579826435687006*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23800878320826696 + 0.057680568331745743*lm - 
            0.06579826435687006*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.007591660388362104 + 0.057680568331745743*lm - 
            0.06579826435687006*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.315, NC*(CA*CF*(-0.04809953655070995 - 1.0560017499694596*lm + 
          0.6506466684395492*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2973629966473962 - 0.4019442434710266*lm - 
          0.7250781789171014*lm^2 + 0.25*lm^3) + 
        CF*((-0.2180025824314712 + 0.05938554345410437*lm - 
            0.06526909123143318*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23799741736975383 + 0.05938554345410437*lm - 
            0.06526909123143318*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.009831095211680397 + 0.05938554345410437*lm - 
            0.06526909123143318*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.32, NC*(CA*CF*(-0.046646458371697584 - 1.0689578777119062*lm + 
          0.6477381144451376*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2923340550015049 - 0.400429613456857*lm - 
          0.7298376309079566*lm^2 + 0.25*lm^3) + 
        CF*((-0.2175973796613763 + 0.06106814922675149*lm - 
            0.06474026323244926*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23801302523015982 + 0.06106814922675149*lm - 
            0.06474026323244926*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.012064706673237939 + 0.06106814922675149*lm - 
            0.06474026323244926*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.325, NC*(CA*CF*(-0.04497208734563291 - 1.081789512064519*lm + 
          0.6448315868839105*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2872493800257477 - 0.39872709326229205*lm - 
          0.7345937669172374*lm^2 + 0.25*lm^3) + 
        CF*((-0.21721692705719892 + 0.0627285887642979*lm - 
            0.0642118036758625*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23805489648556902 + 0.0627285887642979*lm - 0.0642118036758625*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.014292386551022268 + 0.0627285887642979*lm - 0.0642118036758625*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.33, NC*(CA*CF*(-0.043081324177816 - 1.0944976110046536*lm + 
          0.641927209465037*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2821148629729887 - 0.3968392166450296*lm - 
          0.7393463845117576*lm^2 + 0.25*lm^3) + 
        CF*((-0.21686055865760798 + 0.06436706487135994*lm - 
            0.06368373505424915*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2381223376189353 + 0.06436706487135994*lm - 0.06368373505424915*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.016514030760736507 + 0.06436706487135994*lm - 
            0.06368373505424915*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.335, NC*(CA*CF*(-0.04097896657712612 - 1.1070831356899944*lm + 
          0.6390251015287879*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.27693618620715577 - 0.39476848844620405*lm - 
          0.744095288407438*lm^2 + 0.25*lm^3) + 
        CF*((-0.2165276244012218 + 0.06598377991981057*lm - 
            0.06315607906584023*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23821467149890496 + 0.06598377991981057*lm - 
            0.06315607906584023*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.018729539219505785 + 0.06598377991981057*lm - 
            0.06315607906584023*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.34, NC*(CA*CF*(-0.03866971136476765 - 1.1195470496416995*lm + 
          0.6361253781995229*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2717188304630208 - 0.3925173844485356*lm - 
          0.7488402902189626*lm^2 + 0.25*lm^3) + 
        CF*((-0.21621748976724228 + 0.06757893573566255*lm - 
            0.06262885664233749*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23833123698658443 + 0.06757893573566255*lm - 
            0.06262885664233749*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.020938815714720317 + 0.06757893573566255*lm - 
            0.06262885664233749*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.345, NC*(CA*CF*(-0.03615815655843169 - 1.131890317984783*lm + 
          0.6332281505323764*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2664680818366403 - 0.3900883512789252*lm - 
          0.7535812082197477*lm^2 + 0.25*lm^3) + 
        CF*((-0.21592953542089938 + 0.06915273349490005*lm - 
            0.062102087975583586*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2384713885503445 + 0.06915273349490005*lm - 
            0.062102087975583586*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.02314176777777804 + 0.06915273349490005*lm - 
            0.062102087975583586*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.35, NC*(CA*CF*(-0.03344880342984031 - 1.1441139067418613*lm + 
          0.6303335256539584*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.26118903851697034 - 0.38748380635162305*lm - 
          0.7583178671117046*lm^2 + 0.25*lm^3) + 
        CF*((-0.21566315686405035 + 0.07070537362762744*lm - 
            0.061575792543143944*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2386344958887152 + 0.07070537362762744*lm - 
            0.061575792543143944*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.02533830656250341 + 0.07070537362762744*lm - 
            0.061575792543143944*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.355, NC*(CA*CF*(-0.030546058533958306 - 1.1562187821766718*lm + 
          0.627441606897365*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2558866172687784 - 0.3847061378484141*lm - 
          0.763050097804312*lm^2 + 0.25*lm^3) + 
        CF*((-0.21541776409121816 + 0.07223705572995157*lm - 
            0.06104998913285423*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23881994356139388 + 0.07223705572995157*lm - 
            0.06104998913285423*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.027528346728031606 + 0.07223705572995157*lm - 
            0.06104998913285423*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.36, NC*(CA*CF*(-0.027454235708441077 - 1.1682059101840432*lm + 
          0.6245524939317795*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2505655596765894 - 0.3817577047325564*lm - 
          0.7677777372025427*lm^2 + 0.25*lm^3) + 
        CF*((-0.21519278125130448 + 0.07374797848305711*lm - 
            0.06052469586638414*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2390271306283615 + 0.07374797848305711*lm - 0.06052469586638414*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.029711806325959333 + 0.07374797848305711*lm - 
            0.06052469586638414*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.365, NC*(CA*CF*(-0.024177558042136494 - 1.1800762557232272*lm + 
          0.6216662828869247*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.24523043815902837 - 0.3786408367934715*lm - 
          0.7725006280032141*lm^2 + 0.25*lm^3) + 
        CF*((-0.21498764631516623 + 0.07523833957897542*lm - 
            0.0599999302218651*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2392554702970776 + 0.07523833957897542*lm - 0.0599999302218651*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.03188860669157411 + 0.07523833957897542*lm - 0.0599999302218651*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.37, NC*(CA*CF*(-0.020720159811681602 - 1.1918307822917356*lm + 
          0.618783066472614*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.23988566176255763 - 0.37535783471943124*lm - 
          0.7772186184993588*lm^2 + 0.25*lm^3) + 
        CF*((-0.21480181074920734 + 0.07670833565258278*lm - 
            0.0594757090556268*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23950438957770476 + 0.07670833565258278*lm - 0.0594757090556268*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.03405867233898459 + 0.07670833565258278*lm - 0.0594757090556268*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.375, NC*(CA*CF*(-0.017086088385429275 - 1.203470451437019*lm + 
          0.6159029340936328*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.23453548174325403 - 0.37191097019570235*lm - 
          0.7819315623922372*lm^2 + 0.25*lm^3) + 
        CF*((-0.2146347391950978 + 0.07815816221939896*lm - 
            0.05895204862308476*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.23977332894629536 + 0.07815816221939896*lm - 
            0.05895204862308476*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.03622193085998354 + 0.07815816221939896*lm - 
            0.05895204862308476*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.38, NC*(CA*CF*(-0.013279306094116055 - 1.2149962223035156*lm + 
          0.6130259719601701*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.22918399694492558 - 0.36830248602581833*lm - 
          0.7866393186106307*lm^2 + 0.25*lm^3) + 
        CF*((-0.21448590915570676 + 0.07958801361878713*lm - 
            0.0584289645988188*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24006174201585812 + 0.07958801361878713*lm - 0.0584289645988188*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.03837831282648448 + 0.07958801361878713*lm - 0.0584289645988188*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.385, NC*(CA*CF*(-0.009303692067833857 - 1.226409051212775*lm + 
          0.6101522631940072*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.22383515898153855 - 0.3645345962738298*lm - 
          0.7913417511370793*lm^2 + 0.25*lm^3) + 
        CF*((-0.21435481068730491 + 0.08099808296218501*lm - 
            0.05790647209588009*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24036909521521016 + 0.08099808296218501*lm - 
            0.05790647209588009*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.04052775169638093 + 0.08099808296218501*lm - 
            0.05790647209588009*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.39, NC*(CA*CF*(-0.005163044039004989 - 1.2377098912745135*lm + 
          0.6072818879306577*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.21849277723160396 - 0.36060948642555696*lm - 
          0.796038728840742*lm^2 + 0.25*lm^3) + 
        CF*((-0.21424094609806973 + 0.08238856208602355*lm - 
            0.057384585684362006*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24069486747550825 + 0.08238856208602355*lm - 
            0.057384585684362006*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.04267018372268534 + 0.08238856208602355*lm - 
            0.057384585684362006*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.395, NC*(CA*CF*(-0.0008610801111788994 - 1.2488996920266107*lm + 
          0.6044149234176442*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2131605236518644 - 0.35652931356702444*lm - 
          0.800730125316582*lm^2 + 0.25*lm^3) + 
        CF*((-0.21414382965290474 + 0.08375964150901331*lm - 
            0.056863319409268656*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24103854992434537 + 0.08375964150901331*lm - 
            0.056863319409268656*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.04480554786581186 + 0.08375964150901331*lm - 
            0.056863319409268656*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.4, NC*(CA*CF*(0.003598559506425209 - 1.2599793991021904*lm + 
          0.6015514441090851*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.2078419374173241 - 0.3522962065784*lm - 0.8054158187305879*
           lm^2 + 0.25*lm^3) + CF*((-0.2140629872845674 + 0.08511151039350175*
             lm - 0.056342686807712455*lm^2 - 0.027777777777777776*lm^3)*
           NM + (-0.24139964558728982 + 0.08511151039350175*lm - 
            0.056342686807712455*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.046933785708874076 + 0.08511151039350175*lm - 
            0.056342686807712455*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.405, NC*(CA*CF*(0.008212310798613133 - 1.2709499539220552*lm + 
          0.5986915217567567*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.20254042939437875 - 0.3479122663418938*lm - 
          0.8100956916707619*lm^2 + 0.25*lm^3) + 
        CF*((-0.2139979563110821 + 0.08644435651062428*lm - 
            0.055822700925470904*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24177766909673978 + 0.08644435651062428*lm - 
            0.055822700925470904*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.04905484137587521 + 0.08644435651062428*lm - 
            0.055822700925470904*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.41, NC*(CA*CF*(0.012976684278050411 - 1.2818122934108587*lm + 
          0.5958352254977864*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.19725928645352706 - 0.34337956596219366*lm - 
          0.8147696310036222*lm^2 + 0.25*lm^3) + 
        CF*((-0.21394828515940212 + 0.08775836620899215*lm - 
            0.05530337433293087*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2421721464079593 + 0.08775836620899215*lm - 0.05530337433293087*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.05116866145267445 + 0.08775836620899215*lm - 
            0.05530337433293087*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.415, NC*(CA*CF*(0.017888263353067087 - 1.2925673497355104*lm + 
          0.5929826219391267*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.19200167562787915 - 0.3387001509981239*lm - 
          0.8194375277359746*lm^2 + 0.25*lm^3) + 
        CF*((-0.21391353309527228 + 0.08905372438667698*lm - 
            0.054784719140447274*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24258261452215993 + 0.08905372438667698*lm - 
            0.054784719140447274*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.05327519491061851 + 0.08905372438667698*lm - 
            0.054784719140447274*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.42, NC*(CA*CF*(0.022943702729202455 - 1.3032160500644048*lm + 
          0.5901337752389453*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.18677064812342617 - 0.3338760397043194*lm - 
          0.8240992768817259*lm^2 + 0.25*lm^3) + 
        CF*((-0.21389326995923139 + 0.09033061446626868*lm - 
            0.05426674701314157*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24300862121648764 + 0.09033061446626868*lm - 
            0.05426674701314157*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.05537439303273311 + 0.09033061446626868*lm - 
            0.05426674701314157*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.425, NC*(CA*CF*(0.028139726844203437 - 1.3137593163461583*lm + 
          0.58728874718507*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.18156914318678707 - 0.32890922328179917*lm - 
          0.8287547773335219*lm^2 + 0.25*lm^3) + 
        CF*((-0.21388707590868977 + 0.0915892183727982*lm - 
            0.05374946918516424*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24344972478077367 + 0.0915892183727982*lm - 0.05374946918516424*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.05746620934237399 + 0.0915892183727982*lm - 0.05374946918516424*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.43, NC*(CA*CF*(0.033473128336144714 - 1.324198065106629*lm + 
          0.5844475972706096*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.17639999183591676 - 0.32380166613641176*lm - 
          0.8334039317390025*lm^2 + 0.25*lm^3) + 
        CF*((-0.21389454116600082 + 0.09282971651433095*lm - 
            0.05323289647344417*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24390549376090598 + 0.09282971651433095*lm - 
            0.05323289647344417*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.05955059953424176 + 0.09282971651433095*lm - 
            0.05323289647344417*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.435, NC*(CA*CF*(0.03894076654429926 - 1.3345332072630642*lm + 
          0.581610382766873*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.1712659204590378 - 0.3185553061442062*lm - 
          0.8380466463814805*lm^2 + 0.25*lm^3) + 
        CF*((-0.21391526577244863 + 0.09405228776504956*lm - 
            0.05271703929094661*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24437550670867747 + 0.09405228776504956*lm - 
            0.05271703929094661*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.06162752140766932 + 0.09405228776504956*lm - 
            0.05271703929094661*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.44, NC*(CA*CF*(0.04453956604235094 - 1.3447656479543066*lm + 
          0.5787771587936988*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.16616955428683655 - 0.31317205492285427*lm - 
          0.8426828310648564*lm^2 + 0.25*lm^3) + 
        CF*((-0.21394885934806063 + 0.09525710945065664*lm - 
            0.0522019076594604*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24485935193796673 + 0.09525710945065664*lm - 0.0522019076594604*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.06369693480209535 + 0.09525710945065664*lm - 0.0522019076594604*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.445, NC*(CA*CF*(0.050266515203512406 - 1.3548962863860468*lm + 
          0.575947978387304*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.1611134207427617 - 0.3076537981083208*lm - 
          0.8473123990025934*lm^2 + 0.25*lm^3) + 
        CF*((-0.21399494085715384 + 0.09644435733593952*lm - 
            0.05168751122193407*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2453566272871074 + 0.09644435733593952*lm - 0.05168751122193407*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.06575880153463995 + 0.09644435733593952*lm - 
            0.05168751122193407*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.45, NC*(CA*CF*(0.05611866479708735 - 1.3649260156901832*lm + 
          0.5731228925657537*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.15609995267606558 - 0.30200239563603887*lm - 
          0.851935266710585*lm^2 + 0.25*lm^3) + 
        CF*((-0.21405313837951673 + 0.09761420561434937*lm - 
            0.05117385925437945*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24586693988730263 + 0.09761420561434937*lm - 
            0.05117385925437945*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.06781308533970437 + 0.09761420561434937*lm - 
            0.05117385925437945*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.455, NC*(CA*CF*(0.062093126615996024 - 1.374855722797407*lm + 
          0.5703019503921495*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.1511314914820421 - 0.29621968202590915*lm - 
          0.8565513539037555*lm^2 + 0.25*lm^3) + 
        CF*((-0.21412308888712925 + 0.09876682689945682*lm - 
            0.050660960677360506*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24638990593694285 + 0.09876682689945682*lm - 
            0.050660960677360506*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.06985975181051815 + 0.09876682689945682*lm - 
            0.050660960677360506*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.46, NC*(CA*CF*(0.06818707213476069 - 1.3846862883221798*lm + 
          0.5674851990356304*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.1462102901137217 - 0.2903074666704921*lm - 
          0.8611605833962411*lm^2 + 0.25*lm^3) + 
        CF*((-0.21420443802631525 + 0.0999023922181549*lm - 
            0.05014882406708432*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24692515048168487 + 0.0999023922181549*lm - 0.05014882406708432*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.07189876834256195 + 0.0999023922181549*lm - 0.05014882406708432*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.465, NC*(CA*CF*(0.07439773119744143 - 1.3944185864593364*lm + 
          0.5646726838302728*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.14133851598912675 - 0.2842675341258156*lm - 
          0.8657628810050081*lm^2 + 0.25*lm^3) + 
        CF*((-0.21429683990522694 + 0.1010210710054891*lm - 
            0.04963745766611022*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24747230720015367 + 0.1010210710054891*lm - 0.04963745766611022*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.07393010407879677 + 0.1010210710054891*lm - 0.04963745766611022*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.47, NC*(CA*CF*(0.08072239073499615 - 1.404053484891578*lm + 
          0.5618644483319749*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.1365182537980127 - 0.278101644404264*lm - 
          0.8703581754567684*lm^2 + 0.25*lm^3) + 
        CF*((-0.21439995688655325 + 0.10212303110100127*lm - 
            0.0491268693936924*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24803101819512854 + 0.10212303110100127*lm - 0.0491268693936924*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.07595372985663357 + 0.10212303110100127*lm - 0.0491268693936924*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.475, NC*(CA*CF*(0.08715839351153055 - 1.413591844707177*lm + 
          0.5590605343734052*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.13175150821186166 - 0.2718115332690587*lm - 
          0.8749463982980643*lm^2 + 0.25*lm^3) + 
        CF*((-0.21451345938534666 + 0.10320843874648243*lm - 
            0.048617066855770635*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2486009337900777 + 0.10320843874648243*lm - 
            0.048617066855770635*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.07796961815657943 + 0.10320843874648243*lm - 
            0.048617066855770635*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.48, NC*(CA*CF*(0.09370313689890164 - 1.4230345203272527*lm + 
          0.5562609821170923*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.12704020650075032 - 0.26539891252987985*lm - 
          0.8795274838083945*lm^2 + 0.25*lm^3) + 
        CF*((-0.21463702567186146 + 0.1042774585850354*lm - 
            0.04810805735462284*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.24918171233090794 + 0.1042774585850354*lm - 0.04810805735462284*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.07997774305250105 + 0.1042774585850354*lm - 0.04810805735462284*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.485, NC*(CA*CF*(0.1003540716791287 - 1.432382359442019*lm + 
          0.5534658301067279*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.12238620106055752 - 0.25886547033921337*lm - 
          0.8841013689162636*lm^2 + 0.25*lm^3) + 
        CF*((-0.21477034167929618 + 0.10533025366135486*lm - 
            0.047599847898192944*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.2497730199927975 + 0.10533025366135486*lm - 
            0.047599847898192944*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.08197808016344595 + 0.10533025366135486*lm - 
            0.047599847898192944*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.49, NC*(CA*CF*(0.10710870087406793 - 1.4416362029554342*lm + 
          0.5506751153167526*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.11779127185384553 - 0.25221287148904503*lm - 
          0.8886679931180411*lm^2 + 0.25*lm^3) + 
        CF*((-0.21491310081633314 + 0.10636698542313856*lm - 
            0.04709244520910654*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.25037453059198306 + 0.10636698542313856*lm - 
            0.04709244520910654*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.08397060660696727 + 0.10636698542313856*lm - 
            0.04709244520910654*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.495, NC*(CA*CF*(0.11396457860180324 - 1.4507968849377286*lm + 
          0.5478888732002922*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(-0.11325712876760964 - 0.24544275770755092*lm - 
          0.8932272983995218*lm^2 + 0.25*lm^3) + 
        CF*((-0.21506500378436819 + 0.10738781372354837*lm - 
            0.046585855733386465*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.25098592540237363 + 0.10738781372354837*lm - 
            0.046585855733386465*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (-0.08595530095389815 + 0.10738781372354837*lm - 
            0.046585855733386465*lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.5, CF*NC*(CA*(0.12091930909610314 - 1.4598652325141395*lm + 
          0.5451071377391519*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.10878541382305405 - 0.23855674786748227*lm - 
          0.8977792291541151*lm^2 + 0.25*lm^3) - 0.21522575842592714*NM + 
        0.10839289681254924*lm*NM - 0.04608008564954277*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2516068929953809*NL + 
        0.10839289681254924*lm*NL - 0.04608008564954277*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.08793214318229221*NH + 
        0.10839289681254924*lm*NH - 0.04608008564954277*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.505, CF*NC*(CA*(0.127970545036828 - 1.4688420661320867*lm + 
          0.5423299414732499*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.10437770366296036 - 0.23155643865323577*lm - 
          0.902323732134682*lm^2 + 0.25*lm^3) - 0.2153950794386814*NM + 
        0.10938239139229786*lm*NM - 0.045575140873924225*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2522371289876767*NL + 
        0.10938239139229786*lm*NL - 0.045575140873924225*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.08990111464436885*NH + 
        0.10938239139229786*lm*NH - 0.045575140873924225*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.51, CF*NC*(CA*(0.13511598740164452 - 1.4777281990570457*lm + 
          0.5395573155684287*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.10003551122176327 - 0.2244434042655155*lm - 
          0.9068607563425712*lm^2 + 0.25*lm^3) - 0.21557268838459498*NM + 
        0.11035645254117475*lm*NM - 0.045071027073047644*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.25287633599577247*NL + 
        0.11035645254117475*lm*NL - 0.045071027073047644*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.09186219801036405*NH + 
        0.11035645254117475*lm*NH - 0.045071027073047644*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.515, CF*NC*(CA*(0.1423533837713926 - 1.486524437691004*lm + 
          0.5367892898410221*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.0957602881046146 - 0.2172191971343138*lm - 
          0.9113902529874183*lm^2 + 0.25*lm^3) - 0.21575831339807217*NM + 
        0.11131523377737065*lm*NM - 0.044567749668064635*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.25352422338247255*NL + 
        0.11131523377737065*lm*NL - 0.044567749668064635*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.09381537723925125*NH + 
        0.11131523377737065*lm*NH - 0.044567749668064635*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.52, CF*NC*(CA*(0.14968052748709987 - 1.4952315814664374*lm + 
          0.5340258928030973*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.09155342648595191 - 0.20988534809874998*lm - 
          0.9159121754131135*lm^2 + 0.25*lm^3) - 0.21595168905911*NM + 
        0.11225888705007837*lm*NM - 0.04406531384298738*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.25418050711950635*NL + 
        0.11225888705007837*lm*NL - 0.04406531384298738*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.0957606375371852*NH + 
        0.11225888705007837*lm*NH - 0.04406531384298738*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.525, CF*NC*(CA*(0.1570952566552608 - 1.503850422836646*lm + 
          0.5312671517017213*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.08741626102881 - 0.20244336669793192*lm - 0.9204264790335469*
           lm^2 + 0.25*lm^3) - 0.21615255623646815*NM + 
        0.1131875627468227*lm*NM - 0.043563724551828116*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2548449096305769*NL + 
        0.1131875627468227*lm*NL - 0.043563724551828116*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.09769796531997507*NH + 
        0.1131875627468227*lm*NH - 0.043563724551828116*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.53, CF*NC*(CA*(0.16459545317609584 - 1.5123817472710468*lm + 
          0.5285130925569671*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.08335007074007265 - 0.1948947414600693*lm - 
          0.9249331212704175*lm^2 + 0.25*lm^3) - 0.2163606619348116*NM + 
        0.11410140970139872*lm*NM - 0.043062986525509175*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2555171596384215*NL + 
        0.11410140970139872*lm*NL - 0.043062986525509175*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.09962734817669099*NH + 
        0.11410140970139872*lm*NH - 0.043062986525509175*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.535, CF*NC*(CA*(0.17217904179427465 - 1.5208263332550922*lm + 
          0.5257637401987034*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.0793560807639772 - 0.18724094018967152*lm - 
          0.9294320614930307*lm^2 + 0.25*lm^3) - 0.2165757591457284*NM + 
        0.11500057520237078*lm*NM - 0.042563104278552144*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2561969920157777*NL + 
        0.11500057520237078*lm*NL - 0.042563104278552144*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.10154877483436556*NH + 
        0.11500057520237078*lm*NH - 0.042563104278552144*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.54, CF*NC*(CA*(0.17984398917159575 - 1.529184952294519*lm + 
          0.5230191183022139*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.0754354641160934 - 0.17948341025267872*lm - 
          0.9339232609600135*lm^2 + 0.25*lm^3) - 0.21679760670252693*NM + 
        0.11588520500208713*lm*NM - 0.04206408211555405*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.25688414764015133*NL + 
        0.11588520500208713*lm*NL - 0.04206408211555405*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.10346223512375394*NH + 
        0.11588520500208713*lm*NH - 0.04206408211555405*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.545, CF*NC*(CA*(0.1875883029811219 - 1.537458368923632*lm + 
          0.5202792494226874*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.07158934335991124 - 0.1716235788593888*lm - 
          0.9384066827628751*lm^2 + 0.25*lm^3) - 0.21702596913871794*NM + 
        0.11675544332616773*lm*NM - 0.04156592413745833*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.257578373252284*NL + 
        0.11675544332616773*lm*NL - 0.04156592413745833*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1053677199461167*NH + 
        0.11675544332616773*lm*NH - 0.04156592413745833*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.55, CF*NC*(CA*(0.19541003102227902 - 1.545647340717365*lm + 
          0.5175441550286206*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.06781879222808876 - 0.16366285334505726*lm - 
          0.9428822917713481*lm^2 + 0.25*lm^3) - 0.21726061655008955*NM + 
        0.11761143288342597*lm*NM - 0.04106863424762799*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2582794213182228*NL + 
        0.11761143288342597*lm*NL - 0.04106863424762799*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.10726522124099193*NH + 
        0.11761143288342597*lm*NH - 0.04106863424762799*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.555, CF*NC*(CA*(0.20330726035643504 - 1.5537526183068504*lm + 
          0.5148138555341708*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.06412483719033191 - 0.15560262144805814*lm - 
          0.9473500545804477*lm^2 + 0.25*lm^3) - 0.21750132446028447*NM + 
        0.11845331487618704*lm*NM - 0.040572216157728026*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2589870498948953*NL + 
        0.11845331487618704*lm*NL - 0.040572216157728026*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.10915473195492356*NH + 
        0.11845331487618704*lm*NH - 0.040572216157728026*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.56, CF*NC*(CA*(0.21127811646248268 - 1.5617749453982746*lm + 
          0.5120883703304983*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.06050845896980119 - 0.14744425158550764*lm - 
          0.9518099394591847*lm^2 + 0.25*lm^3) - 0.21774787368979065*NM + 
        0.119281229010968*lm*NM - 0.040076673393423926*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.25970102249909527*NL + 
        0.119281229010968*lm*NL - 0.040076673393423926*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.11103624601111477*NH + 
        0.119281229010968*lm*NH - 0.040076673393423926*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.565, CF*NC*(CA*(0.21932076241195986 - 1.5697150587947795*lm + 
          0.5093677178161312*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.05697059400986732 - 0.13918909312626052*lm - 
          0.9562619163008763*lm^2 + 0.25*lm^3) - 0.21800005022825852*NM + 
        0.12009531350948728*lm*NM - 0.03958200929990264*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2604211079797892*NL + 
        0.12009531350948728*lm*NL - 0.03958200929990264*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.11290975827997587*NH + 
        0.12009531350948728*lm*NH - 0.03958200929990264*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.57, CF*NC*(CA*(0.22743339806324944 - 1.57757368842121*lm + 
          0.5066519154263901*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.05351213589296757 - 0.13083847666120174*lm - 
          0.960705956574998*lm^2 + 0.25*lm^3) - 0.21825764511006007*NM + 
        0.12089570511997254*lm*NM - 0.039088227047222444*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26114708039365336*NL + 
        0.12089570511997254*lm*NL - 0.039088227047222444*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.11477526455053798*NH + 
        0.12089570511997254*lm*NH - 0.039088227047222444*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.575, CF*NC*(CA*(0.23561425927440915 - 1.5853515573514974*lm + 
          0.5039409796619033*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.050133936713247534 - 0.12239371427076311*lm - 
          0.9651420332805218*lm^2 + 0.25*lm^3) - 0.2185204542930063*NM + 
        0.12168253912873862*lm*NM - 0.038595329635497576*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26187871888375597*NL + 
        0.12168253912873862*lm*NL - 0.038595329635497576*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.11663276150270396*NH + 
        0.12168253912873862*lm*NH - 0.038595329635497576*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.58, CF*NC*(CA*(0.24386161713419124 - 1.5930493818385005*lm + 
          0.5012349261162453*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.04683680840460839 - 0.11385609978960434*lm - 
          0.9695701209006895*lm^2 + 0.25*lm^3) - 0.21878827854014182*NM + 
        0.1224559493720084*lm*NM - 0.03810331989992339*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26261580756129854*NL + 
        0.1224559493720084*lm*NL - 0.03810331989992339*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.11848224668031009*NH + 
        0.1224559493720084*lm*NH - 0.03810331989992339*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.585, CF*NC*(CA*(0.25217377721082074 - 1.6006678713461182*lm + 
          0.49853376950272854*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.04362152402571813 - 0.10522690906840565*lm - 
          0.9739901953591715*lm^2 + 0.25*lm^3) - 0.2190609233045376*NM + 
        0.12321606824795156*lm*NM - 0.03761220051564761*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2633581353903359*NL + 
        0.12321606824795156*lm*NL - 0.03761220051564761*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.12032371846497208*NH + 
        0.12321606824795156*lm*NH - 0.03761220051564761*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.59, CF*NC*(CA*(0.2605490788181095 - 1.608207728583513*lm + 
          0.49583752368037787*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.04048881900348595 - 0.09650740023272611*lm - 
          0.9784022339775635*lm^2 + 0.25*lm^3) - 0.21933819861700338*NM + 
        0.12396302672891739*lm*NM - 0.037121974002492945*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26410549607539435*NL + 
        0.12396302672891739*lm*NL - 0.037121974002492945*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.12215717605069068*NH + 
        0.12396302672891739*lm*NH - 0.037121974002492945*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.595, CF*NC*(CA*(0.26898589429849257 - 1.615669649541284*lm + 
          0.4931462016791155*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.03743939233644222 - 0.08769881393888923*lm - 
          0.9828062154341747*lm^2 + 0.25*lm^3) - 0.21961991897664482*NM + 
        0.12469695437383983*lm*NM - 0.036632642729536154*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2648576879519095*NL + 
        0.12469695437383983*lm*NL - 0.036632642729536154*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.12398261941919239*NH + 
        0.12469695437383983*lm*NH - 0.036632642729536154*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.6, CF*NC*(CA*(0.2774826283225821 - 1.6230543235294441*lm + 
          0.49045981572418335*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.03447390775941203 - 0.07880237362686313*lm - 
          0.9872021197240636*lm^2 + 0.25*lm^3) - 0.2199059032441909*NM + 
        0.12541797934079377*lm*NM - 0.03614420891954849*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26561451387940976*NL + 
        0.12541797934079377*lm*NL - 0.03614420891954849*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1258000493159824*NH + 
        0.12541797934079377*lm*NH - 0.03614420891954849*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.605, CF*NC*(CA*(0.28603771720484256 - 1.6303624332170599*lm + 
          0.4877783772598287*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.03159299487081809 - 0.06981928577010874*lm - 
          0.9915899281202804*lm^2 + 0.25*lm^3) - 0.22019597453801965*NM + 
        0.12612622839968313*lm*NM - 0.03565667465330218*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2663757811373701*NL + 
        0.12612622839968313*lm*NL - 0.03565667465330218*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.12760946722708694*NH + 
        0.12612622839968313*lm*NH - 0.03565667465330218*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.61, CF*NC*(CA*(0.2946496282350008 - 1.6375946546734215*lm + 
          0.48510189697227796*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.02879725022389862 - 0.060750740122374726*lm - 
          0.9959696231362725*lm^2 + 0.25*lm^3) - 0.22048996013281125*NM + 
        0.12682182694504293*lm*NM - 0.03517004187374751*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2671413013236659*NL + 
        0.12682182694504293*lm*NL - 0.03517004187374751*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1294108753564637*NH + 
        0.12682182694504293*lm*NH - 0.03517004187374751*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.615, CF*NC*(CA*(0.30331685902481104 - 1.6447516574106231*lm + 
          0.4824303848120229*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.026087238383077964 - 0.05159790996142311*lm - 
          1.000341188489417*lm^2 + 0.25*lm^3) - 0.22078769136076062*NM + 
        0.1275048990089379*lm*NM - 0.03468431239006476*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26791089025555664*NL + 
        0.1275048990089379*lm*NL - 0.03468431239006476*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1312042766040592*NH + 
        0.1275048990089379*lm*NH - 0.03468431239006476*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.62, CF*NC*(CA*(0.31203793686980597 - 1.6518341044274314*lm + 
          0.47976385001544114*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.02346349294668132 - 0.042361952329673505*lm - 
          1.0047046090656417*lm^2 + 0.25*lm^3) - 0.22108900351528157*NM + 
        0.128175567273942*lm*NM - 0.03419948788159536*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2686843678731317*NL + 
        0.128175567273942*lm*NL - 0.03419948788159536*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.13298967454449329*NH + 
        0.128175567273942*lm*NH - 0.03419948788159536*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.625, CF*NC*(CA*(0.3208114181256717 - 1.6588426522543358*lm + 
          0.47710230112577473*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.020926517537140938 - 0.033044008271758955*lm - 
          1.009059870885096*lm^2 + 0.25*lm^3) - 0.22139373575713775*NM + 
        0.12883395308618362*lm*NM - 0.033715569901656015*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26946155814515255*NL + 
        0.12883395308618362*lm*NL - 0.033715569901656015*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1347670734063508*NH + 
        0.12883395308618362*lm*NH - 0.033715569901656015*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.63, CF*NC*(CA*(0.32963588759889334 - 1.6657779509996757*lm + 
          0.4744457460134865*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.018476786759798632 - 0.02364520306898967*lm - 
          1.0134069610688403*lm^2 + 0.25*lm^3) - 0.22170173102293672*NM + 
        0.12948017646844318*lm*NM - 0.03323255988123997*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27024228897722774*NL + 
        0.12948017646844318*lm*NL - 0.03323255988123997*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.13653647805206243*NH + 
        0.12948017646844318*lm*NH - 0.03323255988123997*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.635, CF*NC*(CA*(0.3385099579513264 - 1.6726406443967472*lm + 
          0.4717941918960154*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.016114747131368592 - 0.014166646470724735*lm - 
          1.0177458678065203*lm^2 + 0.25*lm^3) - 0.22201283593592455*NM + 
        0.1301143561332893*lm*NM - 0.03275045913260886*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27102639212225726*NL + 
        0.1301143561332893*lm*NL - 0.03275045913260886*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.13829789395835593*NH + 
        0.1301143561332893*lm*NH - 0.03275045913260886*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.64, CF*NC*(CA*(0.34743226911835634 - 1.6794313698517966*lm + 
          0.46914764535695064*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.013840817979085516 - 0.004609432922655292*lm - 
          1.0220765803249898*lm^2 + 0.25*lm^3) - 0.22232690071902123*NM + 
        0.130736609496242*lm*NM - 0.03226926885277891*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27181370309308744*NL + 
        0.130736609496242*lm*NL - 0.03226926885277891*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.14005132719726063*NH + 
        0.130736609496242*lm*NH - 0.03226926885277891*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.645, CF*NC*(CA*(0.3564014877403184 - 1.6861507584928157*lm + 
          0.46650611236464334*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.01165539231152537 + 0.005025358207994417*lm - 
          1.0263990888578565*lm^2 + 0.25*lm^3) - 0.22264377911003722*NM + 
        0.13134705268895122*lm*NM - 0.03178899012690485*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27260406107731555*NL + 
        0.13134705268895122*lm*NL - 0.03178899012690485*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.14179678441764829*NH + 
        0.13134705268895122*lm*NH - 0.03178899012690485*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.65, CF*NC*(CA*(0.36541630660685537 - 1.6927994352190556*lm + 
          0.4638695982902738*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.009558837662050117 + 0.01473666241033887*lm - 
          1.0307133846159156*lm^2 + 0.25*lm^3) - 0.22296332827901433*NM + 
        0.13194580057238042*lm*NM - 0.03130962393156494*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2733973088541891*NL + 
        0.13194580057238042*lm*NL - 0.03130962393156494*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.14353427282729403*NH + 
        0.13194580057238042*lm*NH - 0.03130962393156494*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.655, CF*NC*(CA*(0.37447544411390055 - 1.6993780187511838*lm + 
          0.4612381079253925*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.007551496905793054 + 0.02452342981076413*lm - 
          1.0350194597584486*lm^2 + 0.25*lm^3) - 0.22328540874763475*NM + 
        0.1325329667499849*lm*NM - 0.030831171137950156*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27419329271354204*NL + 
        0.1325329667499849*lm*NL - 0.030831171137950156*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.14526380017544135*NH + 
        0.1325329667499849*lm*NH - 0.030831171137950156*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.66, CF*NC*(CA*(0.3835776437329794 - 1.7058871216820108*lm + 
          0.4586116454989511*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.005633689051068153 + 0.0343846249569076*lm - 
          1.0393173073653528*lm^2 + 0.25*lm^3) - 0.2236098843106437*NM + 
        0.13310866358087609*lm*NM - 0.030353632514960812*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2749918623767154*NL + 
        0.13310866358087609*lm*NL - 0.030353632514960812*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.14698537473585663*NH + 
        0.13310866358087609*lm*NH - 0.030353632514960812*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.665, CF*NC*(CA*(0.39272167349253184 - 1.7123273505277201*lm + 
          0.45599021469384055*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.0038057100060548163 + 0.04431922660466833*lm - 
          1.0436069214100792*lm^2 + 0.25*lm^3) - 0.22393662195923303*NM + 
        0.13367300219296294*lm*NM - 0.029877008732213436*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2757928709194094*NL + 
        0.13367300219296294*lm*NL - 0.029877008732213436*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.14869900529035762*NH + 
        0.13367300219296294*lm*NH - 0.029877008732213436*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.67, CF*NC*(CA*(0.4019063254709633 - 1.7186993057795361*lm + 
          0.4533738186629512*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.002067833321578774 + 0.054326227508229664*lm - 
          1.0478882967333527*lm^2 + 0.25*lm^3) - 0.22426549180633396*NM + 
        0.13422609249606252*lm*NM - 0.02940130036296082*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2765961746964151*NL + 
        0.13422609249606252*lm*NL - 0.02940130036296082*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.15040470111280244*NH + 
        0.13422609249606252*lm*NH - 0.02940130036296082*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.675, CF*NC*(CA*(0.4111304153011413 - 1.72500358195577*lm + 
          0.4507624600447707*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.00042031091078031154 + 0.06440463421307406*lm - 
          1.052161429017648*lm^2 + 0.25*lm^3) - 0.22459636701376867*NM + 
        0.1347680431949724*lm*NM - 0.028926507886928014*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2774016332681772*NL + 
        0.1347680431949724*lm*NL - 0.028926507886928014*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.15210247195352497*NH + 
        0.1347680431949724*lm*NH - 0.028926507886928014*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.68, CF*NC*(CA*(0.4203927816860589 - 1.7312407676541888*lm + 
          0.4481561409785346*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.0011366262535673062 + 0.0745534668519685*lm - 
          1.0564263147623978*lm^2 + 0.25*lm^3) - 0.22492912372121182*NM + 
        0.13529896180249804*lm*NM - 0.0284526316930669*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2782091093291388*NL + 
        0.13529896180249804*lm*NL - 0.0284526316930669*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.15379232802420337*NH + 
        0.13529896180249804*lm*NH - 0.0284526316930669*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.685, CF*NC*(CA*(0.42969228592539627 - 1.7374114456046508*lm + 
          0.4455548631189422*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.002602767463353635 + 0.08477175894389728*lm - 
          1.0606829512599127*lm^2 + 0.25*lm^3) - 0.22526364097691484*NM + 
        0.13581895465242838*lm*NM - 0.027979672082231916*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2790184686378217*NL + 
        0.13581895465242838*lm*NL - 0.027979672082231916*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1554742799831491*NH + 
        0.13581895465242838*lm*NH - 0.027979672082231916*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.69, CF*NC*(CA*(0.43902781145271513 - 1.7435161927219616*lm + 
          0.4429586276504533*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.003977921620331668 + 0.0950585571959178*lm - 
          1.0649313365719855*lm^2 + 0.25*lm^3) - 0.2255998006701459*NM + 
        0.1363281269124544*lm*NM - 0.02750762926977938*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27982957994859625*NL + 
        0.1363281269124544*lm*NL - 0.02750762926977938*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.157148338921004*NH + 
        0.1363281269124544*lm*NH - 0.02750762926977938*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.695, CF*NC*(CA*(0.4483982633830302 - 1.7495555801589013*lm + 
          0.44036743530117756*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.00526191660153906 + 0.10541292130791342*lm - 
          1.0691714695071641*lm^2 + 0.25*lm^3) - 0.2259374874653013*NM + 
        0.13682658259702432*lm*NM - 0.027036503388092884*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28064231494509645*NL + 
        0.13682658259702432*lm*NL - 0.027036503388092884*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.15881451634683313*NH + 
        0.13682658259702432*lm*NH - 0.027036503388092884*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.7, CF*NC*(CA*(0.45780256807050573 - 1.7555301733593793*lm + 
          0.43778128635636976*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.006454598644279974 + 0.11583392378021697*lm - 
          1.0734033495986677*lm^2 + 0.25*lm^3) - 0.22627658873764372*NM + 
        0.1373144245801309*lm*NM - 0.026566294489036923*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2814565481752376*NL + 
        0.1373144245801309*lm*NL - 0.026566294489036923*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.16047282417460224*NH + 
        0.1373144245801309*lm*NH - 0.026566294489036923*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.705, CF*NC*(CA*(0.4672396726760337 - 1.7614405321116746*lm + 
          0.43520018067154276*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.007555831750030824 + 0.1263206497240768*lm - 
          1.07762697708293*lm^2 + 0.25*lm^3) - 0.22661699451062514*NM + 
        0.13779175460802626*lm*NM - 0.026097002546341112*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28227215698779407*NL + 
        0.13779175460802626*lm*NL - 0.026097002546341112*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.16212327471002813*NH + 
        0.13779175460802626*lm*NH - 0.026097002546341112*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.71, CF*NC*(CA*(0.4767085447444541 - 1.7672872106017243*lm + 
          0.43262411768521053*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.00856549710665562 + 0.13687219667493733*lm - 
          1.0818423528787464*lm^2 + 0.25*lm^3) - 0.22695859739475255*NM + 
        0.13825867331185926*lm*NM - 0.025628627457917063*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28308902147049675*NL + 
        0.13825867331185926*lm*NL - 0.025628627457917063*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.16376588063779163*NH + 
        0.13825867331185926*lm*NH - 0.025628627457917063*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.715, CF*NC*(CA*(0.48620817179118536 - 1.7730707574664246*lm + 
          0.43005309643127165*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.009483492528338137 + 0.14748767440850394*lm - 
          1.08604947856701*lm^2 + 0.25*lm^3) - 0.22730129252795633*NM + 
        0.13871528022023213*lm*NM - 0.02516116904811*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2839070243896103*NL + 
        0.13871528022023213*lm*NL - 0.02516116904811*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.16540065500910203*NH + 
        0.13871528022023213*lm*NH - 0.02516116904811*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.72, CF*NC*(CA*(0.4957375608980387 - 1.7787917158469058*lm + 
          0.4274871155510458*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.010309731912658856 + 0.15816620475956308*lm - 
          1.090248356371016*lm^2 + 0.25*lm^3) - 0.22764497751742166*NM + 
        0.13916167377167232*lm*NM - 0.024694627069887117*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2847260511309521*NL + 
        0.13916167377167232*lm*NL - 0.024694627069887117*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.16702761122960338*NH + 
        0.13916167377167232*lm*NH - 0.024694627069887117*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.725, CF*NC*(CA*(0.5052957383179946 - 1.7844506234417545*lm + 
          0.4249261733049722*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.011044144714264579 + 0.16890692144352645*lm - 
          1.0944389891373183*lm^2 + 0.25*lm^3) - 0.22798955238284502*NM + 
        0.1395979513270162*lm*NM - 0.024229001206964633*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28554598964231537*NL + 
        0.1395979513270162*lm*NL - 0.024229001206964633*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.16864676304761234*NH + 
        0.1395979513270162*lm*NH - 0.024229001206964633*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.73, CF*NC*(CA*(0.5148817490887262 - 1.7900480125601506*lm + 
          0.4223702675839811*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.011686675434597778 + 0.17970896988066815*lm - 
          1.0986213803171219*lm^2 + 0.25*lm^3) - 0.22833491950107832*NM + 
        0.14002420918170183*lm*NM - 0.02376429107587535*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28636673037725935*NL + 
        0.14002420918170183*lm*NL - 0.02376429107587535*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.17025812454267825*NH + 
        0.14002420918170183*lm*NH - 0.02376429107587535*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.735, CF*NC*(CA*(0.52449465665466 - 1.7955844101748903*lm + 
          0.41981939592054884*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.012237283127171232 + 0.19057150702302364*lm - 
          1.1027955339481927*lm^2 + 0.25*lm^3) - 0.22868098355212454*NM + 
        0.1404405425779677*lm*NM - 0.023300496227978577*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28718816624023247*NL + 
        0.1404405425779677*lm*NL - 0.023300496227978577*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.17186171011445633*NH + 
        0.1404405425779677*lm*NH - 0.023300496227978577*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.74, CF*NC*(CA*(0.5341335424973691 - 1.8010603379752723*lm + 
          0.4172735554994442*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.012695940917891226 + 0.20149370118391807*lm - 
          1.106961454637273*lm^2 + 0.25*lm^3) - 0.22902765146644982*NM + 
        0.1408470457169551*lm*NM - 0.022837616151414098*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28801019253299304*NL + 
        0.1408470457169551*lm*NL - 0.022837616151414098*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.17345753447188483*NH + 
        0.1408470457169551*lm*NH - 0.022837616151414098*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.745, CF*NC*(CA*(0.5437975057740984 - 1.8064763124198182*lm + 
          0.4147327431681774*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.01306263553994977 + 0.21247473187009241*lm - 
          1.1111191475429825*lm^2 + 0.25*lm^3) - 0.2293748323735773*NM + 
        0.1412438117707116*lm*NM - 0.02237565027300194*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28883270690229434*NL + 
        0.1412438117707116*lm*NL - 0.02237565027300194*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1750456126226574*NH + 
        0.1412438117707116*lm*NH - 0.02237565027300194*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.75, CF*NC*(CA*(0.5534856629642283 - 1.811832844788808*lm + 
          0.41219695544715884*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.013337366882822664 + 0.22351378961639423*lm - 
          1.1152686183591947*lm^2 + 0.25*lm^3) - 0.22972243755192984*NM + 
        0.1416309328940939*lm*NM - 0.021914597960089488*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28965560928880174*NL + 
        0.1416309328940939*lm*NL - 0.021914597960089488*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1766259598629826*NH + 
        0.1416309328940939*lm*NH - 0.021914597960089488*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.755, CF*NC*(CA*(0.5631971475234879 - 1.8171304412366074*lm + 
          0.4096661885395782*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.013520147554926159 + 0.2346100758230011*lm - 
          1.119409873298872*lm^2 + 0.25*lm^3) - 0.23007038037988894*NM + 
        0.1420085002365677*lm*NM - 0.02145445852234755*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29047880187721026*NL + 
        0.1420085002365677*lm*NL - 0.02145445852234755*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.17819859176762226*NH + 
        0.1420085002365677*lm*NH - 0.02145445852234755*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.76, CF*NC*(CA*(0.5729311095457306 - 1.8223696028437688*lm + 
          0.4071404383410097*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.013611002459500223 + 0.24576280259514358*lm - 
          1.1235429190783477*lm^2 + 0.25*lm^3) - 0.23041857628803838*NM + 
        0.14237660395390353*lm*NM - 0.020995231213516916*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29130218904753113*NL + 
        0.14237660395390353*lm*NL - 0.020995231213516916*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.17976352418020072*NH + 
        0.14237660395390353*lm*NH - 0.020995231213516916*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.765, CF*NC*(CA*(0.582686715432093 - 1.827550825668886*lm + 
          0.40461970044875417*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.013609968383301078 + 0.2569711925852946*lm - 
          1.1276677629020386*lm^2 + 0.25*lm^3) - 0.23076694271256176*NM + 
        0.1427353332197665*lm*NM - 0.020536915233106825*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2921256773275188*NL + 
        0.1427353332197665*lm*NL - 0.020536915233106825*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.18132077320377743*NH + 
        0.1427353332197665*lm*NH - 0.020536915233106825*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.77, CF*NC*(CA*(0.5924631475673642 - 1.8326746008001844*lm + 
          0.40210397017092414*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.013517093597699884 + 0.2682344788377931*lm - 
          1.1317844124475787*lm^2 + 0.25*lm^3) - 0.23111539904976444*NM + 
        0.14308477623719895*lm*NM - 0.02007950972804681*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2929491753462078*NL + 
        0.14308477623719895*lm*NL - 0.02007950972804681*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1828703551916755*NH + 
        0.14308477623719895*lm*NH - 0.02007950972804681*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.775, CF*NC*(CA*(0.602259604003388 - 1.8377414144068362*lm + 
          0.3995932425352795*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.013332437471798065 + 0.2795519046358681*lm - 
          1.135892875851361*lm^2 + 0.25*lm^3) - 0.23146386661169024*NM + 
        0.14342502024999476*lm*NM - 0.019623013794293247*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29377259378853243*NL + 
        0.14342502024999476*lm*NL - 0.019623013794293247*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.18441228673855897*NH + 
        0.14342502024999476*lm*NH - 0.019623013794293247*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.78, CF*NC*(CA*(0.6120752981493379 - 1.8427517477899784*lm + 
          0.3970875122978225*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.013056070097182909 + 0.29092272335103103*lm - 
          1.1399931616944723*lm^2 + 0.25*lm^3) - 0.23181226858280543*NM + 
        0.14375615155396443*lm*NM - 0.019167426478391977*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29459584535100086*NL + 
        0.14375615155396443*lm*NL - 0.019167426478391977*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.18594658467175207*NH + 
        0.14375615155396443*lm*NH - 0.019167426478391977*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.785, CF*NC*(CA*(0.6219094584686985 - 1.8477060774334253*lm + 
          0.39458677395115704*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.012688071923959742 + 0.30234619829480286*lm - 
          1.1440852789890157*lm^2 + 0.25*lm^3) - 0.23216052997772169*NM + 
        0.14407825550809003*lm*NM - 0.01871274677899825*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2954188446983977*NL + 
        0.14407825550809003*lm*NL - 0.01871274677899825*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.18747326604279324*NH + 
        0.14407825550809003*lm*NH - 0.01871274677899825*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.79, CF*NC*(CA*(0.631761328182794 - 1.852604875054062*lm + 
          0.39209102173262067*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.01222853340770918 + 0.3138216025727437*lm - 
          1.1481692371648025*lm^2 + 0.25*lm^3) - 0.23250857759993193*NM + 
        0.14439141654556925*lm*NM - 0.01825897364835527*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2962415084214881*NL + 
        0.14439141654556925*lm*NL - 0.01825897364835527*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.18899234811921806*NH + 
        0.14439141654556925*lm*NH - 0.01825897364835527*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.795, CF*NC*(CA*(0.6416301649807123 - 1.8574486076519046*lm + 
          0.3896002496321954*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.011677554667029697 + 0.3253482189407521*lm - 
          1.1522450460564075*lm^2 + 0.25*lm^3) - 0.23285634000153277*NM + 
        0.14469571818474802*lm*NM - 0.0178061059937325*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2970637549956993*NL + 
        0.14469571818474802*lm*NL - 0.0178061059937325*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.19050384837656403*NH + 
        0.14469571818474802*lm*NH - 0.0178061059937325*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.8, CF*NC*(CA*(0.6515152407354726 - 1.8622377375598205*lm + 
          0.3871144514002038*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.011035245151337124 + 0.3369253396636013*lm - 
          1.1563127158905757*lm^2 + 0.25*lm^3) - 0.2332037474439082*NM + 
        0.1449912430399413*lm*NM - 0.01735414267882493*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29788550474075354*NL + 
        0.1449912430399413*lm*NL - 0.01735414267882493*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.19200778449059183*NH + 
        0.1449912430399413*lm*NH - 0.01735414267882493*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.805, CF*NC*(CA*(0.661415841226287 - 1.8669727224928956*lm + 
          0.3846336205547959*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.010301723318603568 + 0.3485522663756804*lm - 
          1.1603722572739703*lm^2 + 0.25*lm^3) - 0.23355073185934996*NM + 
        0.14527807283214153*lm*NM - 0.01690308252511441*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2987066797812297*NL + 
        0.14527807283214153*lm*NL - 0.01690308252511441*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1935041743297162*NH + 
        0.14527807283214153*lm*NH - 0.01690308252511441*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.81, CF*NC*(CA*(0.6713312658667787 - 1.8716540155974408*lm + 
          0.3821577503892345*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.009477116322728804 + 0.36022830994390825*lm - 
          1.1644236811812527*lm^2 + 0.25*lm^3) - 0.2338972268135908*NM + 
        0.1455562883996149*lm*NM - 0.016452924313194152*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2995272040080299*NL + 
        0.1455562883996149*lm*NL - 0.016452924313194152*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.19499303594764153*NH + 
        0.1455562883996149*lm*NH - 0.016452924313194152*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.815, CF*NC*(CA*(0.681260827439011 - 1.8762820654996304*lm + 
          0.3796868339789826*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.008561559710247343 + 0.37195279033278805*lm - 
          1.168466998943483*lm^2 + 0.25*lm^3) - 0.234243167469227*NM + 
        0.1458259697083845*lm*NM - 0.01600366678405745*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30034700304072787*NL + 
        0.1458259697083845*lm*NL - 0.01600366678405745*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.19647438757619615*NH + 
        0.1458259697083845*lm*NH - 0.01600366678405745*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.82, CF*NC*(CA*(0.6912038518331952 - 1.880857316353763*lm + 
          0.3772208641886007*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.007555197126084135 + 0.38372503647157086*lm - 
          1.1725022222368353*lm^2 + 0.25*lm^3) - 0.23458849055000788*NM + 
        0.1460871958626012*lm*NM - 0.01555530864035164*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30116600419077816*NL + 
        0.1460871958626012*lm*NL - 0.01555530864035164*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.1979482476183595*NH + 
        0.1460871958626012*lm*NH - 0.01555530864035164*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.825, CF*NC*(CA*(0.7011596777929436 - 1.8853802078901394*lm + 
          0.3747598336784573*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.006458180028081378 + 0.3955443861234964*lm - 
          1.1765293630716154*lm^2 + 0.25*lm^3) - 0.23493313430596988*NM + 
        0.14634004511480173*lm*NM - 0.015107848547598293*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30198413642556365*NL + 
        0.14634004511480173*lm*NL - 0.015107848547598293*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.19941463464147788*NH + 
        0.14634004511480173*lm*NH - 0.015107848547598293*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.83, CF*NC*(CA*(0.7111276566659376 - 1.8898511754625524*lm + 
          0.3723037349112599*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.005270667410027927 + 0.40741018575708077*lm - 
          1.1805484337815746*lm^2 + 0.25*lm^3) - 0.23527703847939388*NM + 
        0.1465845948760543*lm*NM - 0.01466128513538059*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30280133033326123*NL + 
        0.1465845948760543*lm*NL - 0.01466128513538059*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.20087356737066261*NH + 
        0.1465845948760543*lm*NH - 0.01466128513538059*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.835, CF*NC*(CA*(0.7211071521598847 - 1.8942706500953808*lm + 
          0.3698525601584103*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.00399282553293165 + 0.41932179041941897*lm - 
          1.1845594470135106*lm^2 + 0.25*lm^3) - 0.23562014427156494*NM + 
        0.14682092172599176*lm*NM - 0.014215616998498836*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30361751808850496*NL + 
        0.14682092172599176*lm*NL - 0.014215616998498836*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.20232506468236636*NH + 
        0.14682092172599176*lm*NH - 0.014215616998498836*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.84, CF*NC*(CA*(0.7310975401036439 - 1.8986390585302828*lm + 
          0.367406301506189*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.002624827664283506 + 0.4312785636114723*lm - 
          1.1885624157171453*lm^2 + 0.25*lm^3) - 0.23596239431031427*NM + 
        0.14704910142273267*lm*NM - 0.013770842698094973*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30443263341882737*NL + 
        0.14704910142273267*lm*NL - 0.013770842698094973*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.2037691455981324*NH + 
        0.14704910142273267*lm*NH - 0.013770842698094973*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.845, CF*NC*(CA*(0.7410982082133961 - 1.9029568232724885*lm + 
          0.36496495086177516*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.0011668538250703196 + 0.44327987716531037*lm - 
          1.192557353135277*lm^2 + 0.25*lm^3) - 0.2363037326183231*NM + 
        0.14726920891269082*lm*NM - 0.013326960762746996*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3052466115718589*NL + 
        0.14726920891269082*lm*NL - 0.013326960762746996*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.20520582927851236*NH + 
        0.14726920891269082*lm*NH - 0.013326960762746996*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.85, CF*NC*(CA*(0.7511085558637451 - 1.907224362636681*lm + 
          0.36252849995910424*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.00038090945569888913 + 0.45532511112327667*lm - 
          1.196544272794193*lm^2 + 0.25*lm^3) - 0.23664410458217006*NM + 
        0.14748131834027303*lm*NM - 0.012883969689534104*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3060593892832677*NL + 
        0.14748131834027303*lm*NL - 0.012883969689534104*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.20663513501714778*NH + 
        0.14748131834027303*lm*NH - 0.012883969689534104*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.855, CF*NC*(CA*(0.7611279938636346 - 1.9114420907924687*lm + 
          0.36009694036457035*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.002018269379180565 + 0.4674136536190495*lm - 
          1.2005231884943395*lm^2 + 0.25*lm^3) - 0.23698345692210238*NM + 
        0.14768550305746628*lm*NM - 0.012441867945073399*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3068709047454211*NL + 
        0.14768550305746628*lm*NL - 0.012441867945073399*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.20805708223501113*NH + 
        0.14768550305746628*lm*NH - 0.012441867945073399*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.86, CF*NC*(CA*(0.7711559442369698 - 1.9156104178094437*lm + 
          0.35767026348257586*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.0037450271078184427 + 0.47954490076056777*lm - 
          1.2044941143012395*lm^2 + 0.25*lm^3) - 0.2373217376625138*NM + 
        0.14788183563331428*lm*NM - 0.012000653966528949*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30768109757675094*NL + 
        0.14788183563331428*lm*NL - 0.012000653966528949*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.2094716904748019*NH + 
        0.14788183563331428*lm*NH - 0.012000653966528949*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.865, CF*NC*(CA*(0.7811918400078359 - 1.9197297497018226*lm + 
          0.35524846056093334*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.005560977989612637 + 0.4917182565147922*lm - 
          1.2084570645366546*lm^2 + 0.25*lm^3) - 0.23765889610311022*NM + 
        0.14807038786328408*lm*NM - 0.011560326162593946*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3084899087918056*NL + 
        0.14807038786328408*lm*NL - 0.011560326162593946*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.21087897939549385*NH + 
        0.14807038786328408*lm*NH - 0.011560326162593946*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.87, CF*NC*(CA*(0.7912351249902072 - 1.9238004884726694*lm + 
          0.35283152269612383*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.007465911775742256 + 0.5039331325942746*lm - 
          1.2124120537699792*lm^2 + 0.25*lm^3) - 0.23799488279074707*NM + 
        0.1482512307785234*lm*NM - 0.011120882914446755*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30929728077197227*NL + 
        0.1482512307785234*lm*NL - 0.011120882914446755*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.2122789687670289*NH + 
        0.1482512307785234*lm*NH - 0.011120882914446755*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.875, CF*NC*(CA*(0.8012852535820443 - 1.9278230321576986*lm + 
          0.3504194408384151*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.009459612831741166 + 0.5161889483455059*lm - 
          1.2163590968098663*lm^2 + 0.25*lm^3) - 0.23832964949192056*NM + 
        0.14842443465500935*lm*NM - 0.01068232257668153*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3101031572368526*NL + 
        0.14842443465500935*lm*NL - 0.01068232257668153*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.21367167846515436*NH + 
        0.14842443465500935*lm*NH - 0.01068232257668153*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.88, CF*NC*(CA*(0.8113416905636783 - 1.9317977748686574*lm + 
          0.34801220579684433*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.011541860342420199 + 0.5284851306390139*lm - 
          1.220298208696073*lm^2 + 0.25*lm^3) - 0.23866314916589712*NM + 
        0.1485900690225888*lm*NM - 0.010244643478214126*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.31090748321627615*NL + 
        0.1485900690225888*lm*NL - 0.010244643478214126*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.21505712846639916*NH + 
        0.1485900690225888*lm*NH - 0.010244643478214126*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.885, CF*NC*(CA*(0.8214039109003856 - 1.9357251068362853*lm + 
          0.34560980824406856*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.01371242851072288 + 0.5408211137611857*lm - 
          1.224229404691524*lm^2 + 0.25*lm^3) - 0.238995335938465*NM + 
        0.14874820267391187*lm*NM - 0.009807843923163983*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.31171020502293617*NL + 
        0.14874820267391187*lm*NL - 0.009807843923163983*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.21643533884318567*NH + 
        0.14874820267391187*lm*NH - 0.009807843923163983*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.89, CF*NC*(CA*(0.8314713995490551 - 1.9396054144528507*lm + 
          0.34321223872108614*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.015971086750695845 + 0.5531963393077846*lm - 
          1.2281527002745862*lm^2 + 0.25*lm^3) - 0.2393261650762924*NM + 
        0.1488989036732584*lm*NM - 0.009371922191712633*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.31251127022563224*NL + 
        0.1488989036732584*lm*NL - 0.009371922191712633*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.21780632975907335*NH + 
        0.1488989036732584*lm*NH - 0.009371922191712633*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.895, CF*NC*(CA*(0.8415436512688574 - 1.943439080314265*lm + 
          0.3408194876418338*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.01831759987474937 + 0.5656102560791354*lm - 
          1.2320681111315446*lm^2 + 0.25*lm^3) - 0.2396555929618769*NM + 
        0.1490422393652588*lm*NM - 0.008936876540939479*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3133106276231057*NL + 
        0.1490422393652588*lm*NL - 0.008936876540939479*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.2191701214641309*NH + 
        0.1490422393652588*lm*NH - 0.008936876540939479*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.9, CF*NC*(CA*(0.8516201704358237 - 1.9472264832617734*lm + 
          0.33843154529766173*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.020751728275377856 + 0.578062319976953*lm - 
          1.235975653149281*lm^2 + 0.25*lm^3) - 0.2399835770690723*NM + 
        0.14917827638350978*lm*NM - 0.008502705205635465*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.314108227218453*NL + 
        0.14917827638350978*lm*NL - 0.008502705205635465*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.22052673429043324*NH + 
        0.14917827638350978*lm*NH - 0.008502705205635465*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.905, CF*NC*(CA*(0.8617004708612453 - 1.950967998423224*lm + 
          0.3360484018616904*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.02327322810150478 + 0.5905519939027853*lm - 
          1.239875342408143*lm^2 + 0.25*lm^3) - 0.24031007593917744*NM + 
        0.14930708065908593*lm*NM - 0.008069406399095222*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3149040201941036*NL + 
        0.14930708065908593*lm*NL - 0.008069406399095222*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.22187618864768044*NH + 
        0.14930708065908593*lm*NH - 0.008069406399095222*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.91, CF*NC*(CA*(0.8717840756138086 - 1.9546639972539122*lm + 
          0.33367004739305245*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.02588185142961146 + 0.6030787476580465*lm - 
          1.2437671951750051*lm^2 + 0.25*lm^3) - 0.24063504915757408*NM + 
        0.14942871742894773*lm*NM - 0.007636978313888321*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.315697958887348*NL + 
        0.14942871742894773*lm*NL - 0.007636978313888321*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.22321850501893498*NH + 
        0.14942871742894773*lm*NH - 0.007636978313888321*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.915, CF*NC*(CA*(0.8818705168453803 - 1.958314847577007*lm + 
          0.3312964718410224*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.02857734642980388 + 0.6156420578456138*lm - 
          1.2476512278965088*lm^2 + 0.25*lm^3) - 0.24095845733089985*NM + 
        0.14954325124424725*lm*NM - 0.007205419122610132*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.316489996766404*NL + 
        0.14954325124424725*lm*NL - 0.007205419122610132*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.2245537039564743*NH + 
        0.14954325124424725*lm*NH - 0.007205419122610132*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.92, CF*NC*(CA*(0.891959335620361 - 1.9619209136235534*lm + 
          0.32892766504903764*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.031359457526967206 + 0.6282414077729639*lm - 
          1.251527457192484*lm^2 + 0.25*lm^3) - 0.2412802620647431*NM + 
        0.14965074597853195*lm*NM - 0.006774726978612909*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.317280088407007*NL + 
        0.14965074597853195*lm*NL - 0.006774726978612909*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.22588180607775604*NH + 
        0.14965074597853195*lm*NH - 0.006774726978612909*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.925, CF*NC*(CA*(0.9020500817485265 - 1.9654825560720588*lm + 
          0.32656361675861334*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.03422792555715263 + 0.6408762873568226*lm - 
          1.2553958998495418*lm^2 + 0.25*lm^3) - 0.24160042594184697*NM + 
        0.149751264835848*lm*NM - 0.006344900016717574*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.31806818946951276*NL + 
        0.149751264835848*lm*NL - 0.006344900016717574*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.2272028320614923*NH + 
        0.149751264835848*lm*NH - 0.006344900016717574*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.93, CF*NC*(CA*(0.9121423136212785 - 1.9690001320876593*lm + 
          0.3242043166131539*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.037182487919337 + 0.6535461930293041*lm - 1.259256572814839*
           lm^2 + 0.25*lm^3) - 0.24191891250081002*NM + 
        0.14984487035874341*lm*NM - 0.005915936353906769*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3188542566764998*NL + 
        0.14984487035874341*lm*NL - 0.005915936353906769*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.22851680264383062*NH + 
        0.14984487035874341*lm*NH - 0.005915936353906769*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.935, CF*NC*(CA*(0.9222355980512297 - 1.97247399536087*lm + 
          0.3218497541616647*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.040222878722691105 + 0.6662506276455153*lm - 
          1.263109493190003*lm^2 + 0.25*lm^3) - 0.24223568621527153*NM + 
        0.14993162443617267*lm*NM - 0.005487834089999646*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.31963824779086*NL + 
        0.14993162443617267*lm*NL - 0.005487834089999646*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.22982373861463873*NH + 
        0.14993162443617267*lm*NH - 0.005487834089999646*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.94, CF*NC*(CA*(0.9323295101150458 - 1.9759044961459211*lm + 
          0.31949991886236556*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.043348828929488305 + 0.6789891003926024*lm - 
          1.26695467822522*lm^2 + 0.25*lm^3) - 0.24255071247356919*NM + 
        0.15001158831130282*lm*NM - 0.005060591308308895*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.32042012159436567*NL + 
        0.15001158831130282*lm*NL - 0.005060591308308895*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.23112366081389038*NH + 
        0.15001158831130282*lm*NH - 0.005060591308308895*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.945, CF*NC*(CA*(0.9424236329994762 - 1.9792919812986822*lm + 
          0.31715480008620933*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.04656006649378122 + 0.6917611267002138*lm - 
          1.2707921453134756*lm^2 + 0.25*lm^3) - 0.2428639575588581*NM + 
        0.1500848225892232*lm*NM - 0.00463420607628049*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3211998378667018*NL + 
        0.1500848225892232*lm*NL - 0.00463420607628049*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.2324165901281494*NH + 
        0.1500848225892232*lm*NH - 0.00463420607628049*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.95, CF*NC*(CA*(0.9525175578504963 - 1.9826367943141732*lm + 
          0.31481438712030796*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.04985631649597017 + 0.7045662281523591*lm - 
          1.2746219119849507*lm^2 + 0.25*lm^3) - 0.2431753886296797*NM + 
        0.15015138724455845*lm*NM - 0.004208676446116599*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.32197735736495253*NL + 
        0.15015138724455845*lm*NL - 0.004208676446116599*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.23370254748714972*NH + 
        0.15015138724455845*lm*NH - 0.004208676446116599*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.955, CF*NC*(CA*(0.9626108836254995 - 1.9859392753636704*lm + 
          0.3124786691712684*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.05323730127338322 + 0.71740393240064*lm - 1.2784439959015608*
           lm^2 + 0.25*lm^3) - 0.24348497370096941*NM + 
        0.15021134162898678*lm*NM - 0.003784000455382127*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.32275264180353086*NL + 
        0.15021134162898678*lm*NL - 0.003784000455382127*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.23498155386046898*NH + 
        0.15021134162898678*lm*NH - 0.003784000455382127*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.96, CF*NC*(CA*(0.9727032169484644 - 1.9891997613314027*lm + 
          0.3101476353684408*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.056702740546984015 + 0.7302737730788303*lm - 
          1.2822584148516423*lm^2 + 0.25*lm^3) - 0.24379268162549284*NM + 
        0.15026474447866398*lm*NM - 0.0033601761275953005*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.32352565383454174*NL + 
        0.15026474447866398*lm*NL - 0.0033601761275953005*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.23625363025429263*NH + 
        0.15026474447866398*lm*NH - 0.0033601761275953005*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.965, CF*NC*(CA*(0.9827941719680361 - 1.9924185858508472*lm + 
          0.3078212747670817*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.060252351544320175 + 0.7431752897187835*lm - 
          1.2860651867447754*lm^2 + 0.25*lm^3) - 0.24409848207569976*NM + 
        0.15031165392155424*lm*NM - 0.0029372014728027396*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3242963570285681*NL + 
        0.15031165392155424*lm*NL - 0.0029372014728027396*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.23751879770826706*NH + 
        0.15031165392155424*lm*NH - 0.0029372014728027396*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.97, CF*NC*(CA*(0.9928833702184556 - 1.995596079340621*lm + 
          0.30549957635143343*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.0638858491188213 + 0.7561080276676465*lm - 
          1.2898643296067454*lm^2 + 0.25*lm^3) - 0.2444023455259859*NM + 
        0.1503521274846689*lm*NM - 0.0025150744881394112*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3250647158558696*NL + 
        0.1503521274846689*lm*NL - 0.0025150744881394112*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.23877707729243872*NH + 
        0.1503521274846689*lm*NH - 0.0025150744881394112*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.975, CF*NC*(CA*(1.0029704404832733 - 1.9987325690399764*lm + 
          0.30318252903772297*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.0676029458655525 + 0.7690715380063574*lm - 
          1.2936558615746352*lm^2 + 0.25*lm^3) - 0.2447042432353529*NM + 
        0.15038622210121375*lm*NM - 0.0020937931583738722*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3258306956679849*NL + 
        0.15038622210121375*lm*NL - 0.0020937931583738722*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.24002849010427757*NH + 
        0.15038622210121375*lm*NH - 0.0020937931583738722*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.98, CF*NC*(CA*(1.0130550186617884 - 2.0018283790438987*lm + 
          0.30087012167708216*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.07140335223352617 + 0.7820653774694067*lm - 
          1.2974398008920474*lm^2 + 0.25*lm^3) - 0.24500414723045644*NM + 
        0.15041399411764636*lm*NM - 0.0016733554564391812*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3265942626797281*NL + 
        0.15041399411764636*lm*NL - 0.0016733554564391812*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.24127305726578224*NH + 
        0.15041399411764636*lm*NH - 0.0016733554564391812*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.985, CF*NC*(CA*(1.0231367476381499 - 2.0048838303378114*lm + 
          0.2985623430583909*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.07528677663467138 + 0.7950891083658408*lm - 
          1.3012161659044512*lm^2 + 0.25*lm^3) - 0.24530203028903355*NM + 
        0.15043549930064407*lm*NM - 0.0012537593439498629*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.32735538395156943*NL + 
        0.15043549930064407*lm*NL - 0.0012537593439498629*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.24251079992066507*NH + 
        0.15043549930064407*lm*NH - 0.0012537593439498629*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.99, CF*NC*(CA*(1.0332152771530674 - 2.0078992408318914*lm + 
          0.2962591819110457*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.07925292554955747 + 0.8081422985014879*lm - 
          1.3049849750546525*lm^2 + 0.25*lm^3) - 0.2455978659236999*NM + 
        0.15045079284398374*lm*NM - 0.0008350027717052831*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3281140273723926*NL + 
        0.15045079284398374*lm*NL - 0.0008350027717052831*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.2437417392316149*NH + 
        0.15045079284398374*lm*NH - 0.0008350027717052831*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.995, CF*NC*(CA*(1.043290263678066 - 2.0108749253949982*lm + 
          0.29396062690765556*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(-0.08330150362996543 + 0.8212245211023856*lm - 
          1.308746246878382*lm^2 + 0.25*lm^3) - 0.24589162836610814*NM + 
        0.1504599293753343*lm*NM - 0.0004170836801797949*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.32887016164261834*NL + 
        0.1504599293753343*lm*NL - 0.0004170836801797949*lm^2*NL - 
        0.027777777777777776*lm^3*NL - 0.2449658963776357*NH + 
        0.1504599293753343*lm*NH - 0.0004170836801797949*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {1., 0.7518410136834407*(CA - 2.*CF)*CF*NC - 0.00011574074074074075*CF*
        NC*(3.*CF*(-4078.7994630772328 - 2402.8858216494473*lm + 3780.*lm^2 - 
           720.*lm^3) + 2.*CA*(-1302.5679405500098 + 8699.664366237086*lm - 
           1260.*lm^2 - 660.*lm^3) + 10.*((212.70236476446036 - 130.*lm + 
             24.*lm^3)*NM + 2.*(142.39746270332105 - 65.*lm + 12.*lm^3)*
            NL + (212.70236476446036 - 130.*lm + 24.*lm^3)*NH))}}
 
CbarTable["s", 2, 1] = {{0., -6.430041152263374*^-6*CF*NC*
       (2.*CA*(-2388.1522153911205 - 28035.755618875908*lm) + 
        15.*(-3103.0124357078876*CF + 
          4.*((-67.3596725935698 + 169.91367041742973*lm)*NM + 
            (-67.3596725935698 + 169.91367041742973*lm)*NL + 
            (-206.3135567749981 + 169.91367041742973*lm)*NH)))}, 
     {0.005, CF*NC*(0.28213167692761754*CF + CA*(0.01523570807559985 + 
          0.3544921274717939*lm) + 0.028064564661836613*NM - 
        0.06445311408578071*lm*NM + 0.028061373314394525*NL - 
        0.06445311408578071*lm*NL + 0.07920937501989908*NH - 
        0.06445311408578071*lm*NH)}, 
     {0.01, CF*NC*(0.2655102740513045*CF + CA*(-0.00010584725951057361 + 
          0.34839877513719564*lm) + 0.03011188794655863*NM - 
        0.06334523184312647*lm*NM + 0.03010274601289116*NL - 
        0.06334523184312647*lm*NL + 0.0788148387906109*NH - 
        0.06334523184312647*lm*NH)}, 
     {0.015, CF*NC*(0.24959392888332618*CF + CA*(-0.015156157540557354 + 
          0.34230517176025627*lm) + 0.03210392446101721*NM - 
        0.062237303956410236*lm*NM + 0.032089453177243626*NL - 
        0.062237303956410236*lm*NL + 0.07841395157861986*NH - 
        0.062237303956410236*lm*NH)}, 
     {0.02, CF*NC*(0.23443477372283683*CF + CA*(-0.02983748030250488 + 
          0.3362381657095184*lm) + 0.034028474414121684*NM - 
        0.061134211947185164*lm*NM + 0.0340113601985505*NL - 
        0.061134211947185164*lm*NL + 0.0780077150207475*NH - 
        0.061134211947185164*lm*NH)}, 
     {0.025, CF*NC*(0.22004256038159634*CF + CA*(-0.04410560010026053 + 
          0.33021658543714016*lm) + 0.035878990148072575*NM - 
        0.06003937917038912*lm*NM + 0.035863270294085904*NL - 
        0.06003937917038912*lm*NL + 0.07759696598282394*NH - 
        0.06003937917038912*lm*NH)}, 
     {0.03, CF*NC*(0.20640687971247296*CF + CA*(-0.05793496986525157 + 
          0.3242542859513163*lm) + 0.037652048930027646*NM - 
        0.05895532471842114*lm*NM + 0.03764265212520737*NL - 
        0.05895532471842114*lm*NL + 0.07718242501999277*NH - 
        0.05895532471842114*lm*NH)}, 
     {0.035, CF*NC*(0.19350677382764772*CF + CA*(-0.07131166985052045 + 
          0.31836171595425883*lm) + 0.03934615490366842*NM - 
        0.05788394835531979*lm*NM + 0.03934858369955933*NL - 
        0.05788394835531979*lm*NL + 0.0767647237324203*NH - 
        0.05788394835531979*lm*NH)}, 
     {0.04, CF*NC*(0.18131563082801452*CF + CA*(-0.08422949315627934 + 
          0.31254685122327097*lm) + 0.040961073193891875*NM - 
        0.0568267002224129*lm*NM + 0.04098117571504449*NL - 
        0.0568267002224129*lm*NL + 0.07634442237688759*NH - 
        0.0568267002224129*lm*NH)}, 
     {0.045, CF*NC*(0.1698039197672235*CF + CA*(-0.09668755225806322 + 
          0.3068158018283332*lm) + 0.042497423240388466*NM - 
        0.055784691241515125*lm*NM + 0.042541225129219574*NL - 
        0.055784691241515125*lm*NL + 0.0759220221524152*NH - 
        0.055784691241515125*lm*NH)}, 
     {0.05, CF*NC*(0.15894080955968382*CF + CA*(-0.10868871918210889 + 
          0.3011732314964476*lm) + 0.0439564144011887*NM - 
        0.05475876936299048*lm*NM + 0.04402999336823992*NL - 
        0.05475876936299048*lm*NL + 0.07549797425395588*NH - 
        0.05475876936299048*lm*NH)}, 
     {0.055, CF*NC*(0.14869516217036893*CF + CA*(-0.12023856150337771 + 
          0.29562266006268345*lm) + 0.04533966626753616*NM - 
        0.05374957455685153*lm*NM + 0.04544905778132338*NL - 
        0.05374957455685153*lm*NL + 0.07507268681729538*NH - 
        0.05374957455685153*lm*NH)}, 
     {0.06, CF*NC*(0.13903615392711322*CF + CA*(-0.1313445914378964 + 
          0.2901666888859507*lm) + 0.046649082511343934*NM - 
        0.05275757979744558*lm*NM + 0.04680020879832838*NL - 
        0.05275757979744558*lm*NL + 0.0746465304119656*NH - 
        0.05275757979744558*lm*NH)}, 
     {0.065, CF*NC*(0.1299336660828502*CF + CA*(-0.1420157219164373 + 
          0.28480717322744864*lm) + 0.047886760131980066*NM - 
        0.05178312240499066*lm*NM + 0.04808537694009804*NL - 
        0.05178312240499066*lm*NL + 0.07421984249185799*NH - 
        0.05178312240499066*lm*NH)}, 
     {0.07, CF*NC*(0.12135852749803376*CF + CA*(-0.15226186453309404 + 
          0.27954535681824044*lm) + 0.0490549229602225*NM - 
        0.05082642851240736*lm*NM + 0.04930658004288171*NL - 
        0.05082642851240736*lm*NL + 0.07379293107225611*NH - 
        0.05082642851240736*lm*NH)}, 
     {0.075, CF*NC*(0.11328266024547244*CF + CA*(-0.16209362762690124 + 
          0.2743819786954612*lm) + 0.05015587226608779*NM - 
        0.04988763249008386*lm*NM + 0.05046588457188632*NL - 
        0.04988763249008386*lm*NL + 0.07336607781681542*NH - 
        0.04988763249008386*lm*NH)}, 
     {0.08, CF*NC*(0.10567916037595664*CF + CA*(-0.17152208675448405 + 
          0.26931735921575345*lm) + 0.051191949710792724*NM - 
        0.04896679258468245*lm*NM + 0.0515653769894566*NL - 
        0.04896679258468245*lm*NL + 0.0729395406640803*NH - 
        0.04896679258468245*lm*NH)}, 
     {0.085, CF*NC*(0.09852233488487551*CF + CA*(-0.18055860855534178 + 
          0.2643514701208994*lm) + 0.05216550938021511*NM - 
        0.048063903658345335*lm*NM + 0.05260714243977808*NL - 
        0.048063903658345335*lm*NL + 0.07251355608763897*NH - 
        0.048063903658345335*lm*NH)}, 
     {0.09, CF*NC*(0.09178770892980867*CF + CA*(-0.1892147146654399 + 
          0.2594839921815749*lm) + 0.05307889660674327*NM - 
        0.04717890766937726*lm*NM + 0.05359324884442148*NL - 
        0.04717890766937726*lm*NL + 0.07208834105989824*NH - 
        0.04717890766937726*lm*NH)}, 
     {0.095, CF*NC*(0.0854520128580938*CF + CA*(-0.19750197610084408 + 
          0.25471436302410044*lm) + 0.0539344319330948*NM - 
        0.046311702368018265*lm*NM + 0.05452573505360431*NL - 
        0.046311702368018265*lm*NL + 0.0716640947726077*NH - 
        0.046311702368018265*lm*NH)}, 
     {0.1, CF*NC*(0.07949315564662314*CF + CA*(-0.2054319311064344 + 
          0.2500418171003734*lm) + 0.05473439901414617*NM - 
        0.04546214856370425*lm*NM + 0.05540660207156879*NL - 
        0.04546214856370425*lm*NL + 0.07124100015520328*NH - 
        0.04546214856370425*lm*NH)}, 
     {0.105, CF*NC*(0.07389018936835831*CF + CA*(-0.2130160212625275 + 
          0.24546541930003207*lm) + 0.05548103556230233*NM - 
        0.04463007623636946*lm*NM + 0.056237806633563425*NL - 
        0.04463007623636946*lm*NL + 0.07081922522322602*NH - 
        0.04463007623636946*lm*NH)}, 
     {0.11, CF*NC*(0.06862326793955566*CF + CA*(-0.22026554192295317 + 
          0.2409840933676825*lm) + 0.05617652666263915*NM - 
        0.043815289703215*lm*NM + 0.05702125659514725*NL - 
        0.043815289703215*lm*NL + 0.07039892428251096*NH - 
        0.043815289703215*lm*NH)}, 
     {0.115, CF*NC*(0.06367360245609269*CF + CA*(-0.22719160398636362 + 
          0.2365966460386998*lm) + 0.05682299994414844*NM - 
        0.04301757200703633*lm*NM + 0.05775880772635984*NL - 
        0.04301757200703633*lm*NL + 0.06998023900987409*NH - 
        0.04301757200703633*lm*NH)}, 
     {0.12, CF*NC*(0.059023414761356384*CF + CA*(-0.2338051046857194 + 
          0.23230178761941064*lm) + 0.05742252221131787*NM - 
        0.04223668865807466*lm*NM + 0.05845226159959113*NL - 
        0.04223668865807466*lm*NL + 0.06956329942721107*NH - 
        0.04223668865807466*lm*NH)}, 
     {0.125, CF*NC*(0.05465589041391721*CF + CA*(-0.24011670559064538 + 
          0.2280981495942117*lm) + 0.0579770972282862*NM - 
        0.04147239083531122*lm*NM + 0.05910336433128311*NL - 
        0.04147239083531122*lm*NL + 0.069148224782951*NH - 
        0.04147239083531122*lm*NH)}, 
     {0.13, CF*NC*(0.05055513188232132*CF + CA*(-0.24613681640243268 + 
          0.22398429973150302*lm) + 0.058488664414304344*NM - 
        0.04072441813300055*lm*NM + 0.05971380599103205*NL - 
        0.04072441813300055*lm*NL + 0.06873512435246841*NH - 
        0.04072441813300055*lm*NH)}, 
     {0.135, CF*NC*(0.04670611254742042*CF + CA*(-0.25187558341562194 + 
          0.2199587550738501*lm) + 0.05895909826001359*NM - 
        0.0399925009225182*lm*NM + 0.06028522053215016*NL - 
        0.0399925009225182*lm*NL + 0.06832409816719211*NH - 
        0.0399925009225182*lm*NH)}, 
     {0.14, CF*NC*(0.04309463191275024*CF + CA*(-0.2573428817470931 + 
          0.21601999312954745*lm) + 0.059390208313215447*NM - 
        0.03927636238719044*lm*NM + 0.06081918612873*NL - 
        0.03927636238719044*lm*NL + 0.06791523768064854*NH - 
        0.03927636238719044*lm*NH)}, 
     {0.145, CF*NC*(0.039707272291823*CF + CA*(-0.2625483106103507 + 
          0.21216646152839885*lm) + 0.059783739613277924*NM - 
        0.038575720277890704*lm*NM + 0.0613172258281764*NL - 
        0.038575720277890704*lm*NL + 0.067508626378458*NH - 
        0.038575720277890704*lm*NH)}, 
     {0.15, CF*NC*(0.03653135714463084*CF + CA*(-0.26750119105150794 + 
          0.20839658636085856*lm) + 0.0601413734772191*NM - 
        0.03789028842924701*lm*NM + 0.061780808446788564*NL - 
        0.03789028842924701*lm*NL + 0.06710434033830268*NH - 
        0.03789028842924701*lm*NH)}, 
     {0.155, CF*NC*(0.03355491116478208*CF + CA*(-0.27221056567330487 + 
          0.2047087793843186*lm) + 0.06046472855938466*NM - 
        0.03721977806987611*lm*NM + 0.06221134965057137*NL - 
        0.03721977806987611*lm*NL + 0.06670244874506044*NH - 
        0.03721977806987611*lm*NH)}, 
     {0.16, CF*NC*(0.03076662216676451*CF + CA*(-0.27668519996102037 + 
          0.20110144425149049*lm) + 0.060755362121643036*NM - 
        0.03656389895481645*lm*NM + 0.0626102131749729*NL - 
        0.03656389895481645*lm*NL + 0.06630301436561131*NH - 
        0.03656389895481645*lm*NH)}, 
     {0.165, CF*NC*(0.028155804784953224*CF + CA*(-0.28093358489431214 + 
          0.19757298189215255*lm) + 0.061014771463023525*NM - 
        0.03592236034402774*lm*NM + 0.06297871214638928*NL - 
        0.03592236034402774*lm*NL + 0.06590609398724784*NH - 
        0.03592236034402774*lm*NH)}, 
     {0.17, CF*NC*(0.02571236596857189*CF + CA*(-0.28496394058562646 + 
          0.1941217951599762*lm) + 0.06124439546737174*NM - 
        0.03529487184726841*lm*NM + 0.0633181104755757*NL - 
        0.03529487184726841*lm*NL + 0.06551173882313559*NH - 
        0.03529487184726841*lm*NH)}, 
     {0.175, CF*NC*(0.023426772237234637*CF + CA*(-0.2887842207317152 + 
          0.1907462928398926*lm) + 0.061445616235391576*NM - 
        0.034681144152707746*lm*NM + 0.06362962429895441*NL - 
        0.034681144152707746*lm*NL + 0.06511999488785783*NH - 
        0.034681144152707746*lm*NH)}, 
     {0.18, CF*NC*(0.02129001864797869*CF + CA*(-0.2924021177021992 + 
          0.18744489309788687*lm) + 0.06161976077376635*NM - 
        0.03408088965416125*lm*NM + 0.06391442344852477*NL - 
        0.03408088965416125*lm*NL + 0.06473090334572768*NH - 
        0.03408088965416125*lm*NH)}, 
     {0.185, CF*NC*(0.019293599415381262*CF + 
        CA*(-0.295825068119724 + 0.18421602644371107*lm) + 
        0.061768102719201995*NM - 0.03349382298976565*lm*NM + 
        0.06417363293488974*NL - 0.03349382298976565*lm*NL + 
        0.06434450083424874*NH - 0.03349382298976565*lm*NH)}, 
     {0.19, CF*NC*(0.017429480120338053*CF + CA*(-0.29906025881140913 + 
          0.18105813826739586*lm) + 0.061891864079444*NM - 
        0.03291966150316288*lm*NM + 0.06440833443100538*NL - 
        0.03291966150316288*lm*NL + 0.06396081976484665*NH - 
        0.03291966150316288*lm*NH)}, 
     {0.195, CF*NC*(0.015690071439534617*CF + CA*(-0.3021146330320378 + 
          0.1779696910022987*lm) + 0.06199221697677054*NM - 
        0.03235812563678158*lm*NM + 0.06461956774677292*NL - 
        0.03235812563678158*lm*NL + 0.06357988860276778*NH - 
        0.03235812563678158*lm*NH)}, 
     {0.2, NC*(0.014068204326364941*CF^2 + CA*CF*(-0.30499489687681425 + 
          0.17494916596050322*lm) + 
        CF*((0.062070285381568696 - 0.03180893926554604*lm)*NM + 
          (0.06480833228664407 - 0.03180893926554604*lm)*NL + 
          (0.06320173212784665 - 0.03180893926554604*lm)*NH))}, 
     {0.205, NC*(0.012557106571306782*CF^2 + CA*CF*(-0.3077075258145638 + 
          0.1719950648804713*lm) + 
        CF*((0.062127146830093495 - 0.03127182997826751*lm)*NM + 
          (0.06497558848408437 - 0.03127182997826751*lm)*NL + 
          (0.06282637167767183 - 0.03127182997826751*lm)*NH))}, 
     {0.21, NC*(0.011150380676613178*CF^2 + CA*CF*(-0.3102587712871998 + 
          0.16910591122178484*lm) + 
        CF*((0.06216383411175097 - 0.030746529313051787*lm)*NM + 
          (0.06512225920811046 - 0.030746529313051787*lm)*NL + 
          (0.062453825374531056 - 0.030746529313051787*lm)*NH))}, 
     {0.215, NC*(0.009841982972529539*CF^2 + CA*CF*(-0.3126546673266535 + 
          0.16628025123745893*lm) + 
        CF*((0.06218133692844967 - 0.03023277295226526*lm)*NM + 
          (0.06524923113823862 - 0.03023277295226526*lm)*NL + 
          (0.062084108337383356 - 0.03023277295226526*lm)*NH))}, 
     {0.22, NC*(0.008626203912263245*CF^2 + CA*CF*(-0.31490103715278817 + 
          0.1635166548505538*lm) + 
        CF*((0.06218060351595616 - 0.029730300881918872*lm)*NM + 
          (0.06535735610510247 - 0.029730300881918872*lm)*NL + 
          (0.06171723287999035 - 0.029730300881918872*lm)*NH))}, 
     {0.225, NC*(0.0074976494807645604*CF^2 + CA*CF*(-0.31700349972052666 + 
          0.16081371635856287*lm) + 
        CF*((0.06216254222579478 - 0.029238857519738704*lm)*NM + 
          (0.06544745239475039 - 0.029238857519738704*lm)*NL + 
          (0.061353208696235104 - 0.029238857519738704*lm)*NH))}, 
     {0.23, NC*(0.006451223656225482*CF^2 + CA*CF*(-0.3189674761909057 + 
          0.15817005498623896*lm) + 
        CF*((0.06212802306482655 - 0.02875819181567981*lm)*NM + 
          (0.06552030601525027 - 0.02875819181567981*lm)*NL + 
          (0.06099204303356499 - 0.02875819181567981*lm)*NH))}, 
     {0.235, NC*(0.005482111865767536*CF^2 + CA*CF*(-0.320798196305611 + 
          0.15558431530506867*lm) + 
        CF*((0.062077879190828564 - 0.028288057328194303*lm)*NM + 
          (0.06557667192473386 - 0.028288057328194303*lm)*NL + 
          (0.06063374085541375 - 0.028288057328194303*lm)*NH))}, 
     {0.24, NC*(0.004585765379236013*CF^2 + CA*CF*(-0.32250070464851505 + 
          0.1530551675354706*lm) + 
        CF*((0.0620129083626674 - 0.027828212279176475*lm)*NM + 
          (0.06561727522042358 - 0.027828212279176475*lm)*NL + 
          (0.060278304993384095 - 0.027828212279176475*lm)*NH))}, 
     {0.245, NC*(0.003757886588064143*CF^2 + CA*CF*(-0.3240798667813465 + 
          0.1505813077459253*lm) + 
        CF*((0.061933874344593916 - 0.027378419590168235*lm)*NM + 
          (0.06564281228852023 - 0.027378419590168235*lm)*NL + 
          (0.05992573628990673 - 0.027378419590168235*lm)*NH))}, 
     {0.25, NC*(0.002994415118592026*CF^2 + CA*CF*(-0.32554037524337925 + 
          0.1481614579616116*lm) + 
        CF*((0.06184150826424984 - 0.0269384469021112*lm)*NM + 
          (0.06565395191509993 - 0.0269384469021112*lm)*NL + 
          (0.05957603373203314 - 0.0269384469021112*lm)*NH))}, 
     {0.255, NC*(0.002291514731985049*CF^2 + CA*CF*(-0.32688675540752016 + 
          0.1457943661936892*lm) + 
        CF*((0.06173650992448858 - 0.026508066580670765*lm)*NM + 
          (0.06565133635838752 - 0.026508066580670765*lm)*NL + 
          (0.05922919457696557 - 0.026508066580670765*lm)*NH))}, 
     {0.26, NC*(0.001645560965405306*CF^2 + CA*CF*(-0.3281233711871871 + 
          0.14347880639910654*lm) + 
        CF*((0.06161954906933746 - 0.026087055708928462*lm)*NM + 
          (0.06563558238294755 - 0.026087055708928462*lm)*NL + 
          (0.05888521446988028 - 0.026087055708928462*lm)*NH))}, 
     {0.265, NC*(0.001053129471526284*CF^2 + CA*CF*(-0.3292544305900623 + 
          0.1412135783797022*lm) + 
        CF*((0.061491266604656696 - 0.02567519606903676*lm)*NM + 
          (0.06560728225647178 - 0.02567519606903676*lm)*NL + 
          (0.05854408755455638 - 0.02567519606903676*lm)*NH))}, 
     {0.27, NC*(0.0005109850157848933*CF^2 + CA*CF*(-0.33028399111619916 + 
          0.13899750762838858*lm) + 
        CF*((0.06135227577421606 - 0.02527227411425247*lm)*NM + 
          (0.0655670047099503 - 0.02527227411425247*lm)*NL + 
          (0.058205806577283276 - 0.02527227411425247*lm)*NH))}, 
     {0.275, NC*(0.000016071092958718765*CF^2 + 
        CA*CF*(-0.3312159649991163 + 0.13682944512934034*lm) + 
        CF*((0.06120316329207417 - 0.024878080932607335*lm)*NM + 
          (0.06551529586209538 - 0.024878080932607335*lm)*NL + 
          (0.057870362984483815 - 0.024878080932607335*lm)*NH))}, 
     {0.28, NC*(-0.0004344998733438606*CF^2 + CA*CF*(-0.33205412428942543 + 
          0.13470826711834316*lm) + 
        CF*((0.06104449043222786 - 0.024492412203335118*lm)*NM + 
          (0.06545268010894917 - 0.024492412203335118*lm)*NL + 
          (0.05753774701445791 - 0.024492412203335118*lm)*NH))}, 
     {0.285, NC*(-0.0008434557827877508*CF^2 + 
        CA*CF*(-0.3328021057812829 + 0.13263287480878005*lm) + 
        CF*((0.06087679407660371 - 0.02411506814705092*lm)*NM + 
          (0.06537966097965088 - 0.02411506814705092*lm)*NL + 
          (0.057207947783621364 - 0.02411506814705092*lm)*NH))}, 
     {0.29, NC*(-0.0012133735947550924*CF^2 + CA*CF*(-0.3334634157825422 + 
          0.1306021940881288*lm) + 
        CF*((0.06070058772251237 - 0.023745853470568873*lm)*NM + 
          (0.06529672195936902 - 0.023745853470568873*lm)*NL + 
          (0.05688095336758769 - 0.023745853470568873*lm)*NH))}, 
     {0.295, NC*(-0.001546687580094542*CF^2 + CA*CF*(-0.33404143473000397 + 
          0.1286151751893082*lm) + 
        CF*((0.06051636245074054 - 0.023384577307146943*lm)*NM + 
          (0.06520432728042284 - 0.023384577307146943*lm)*NL + 
          (0.05655675087741583 - 0.023384577307146943*lm)*NH))}, 
     {0.3, NC*(-0.001845774732245511*CF^2 + CA*CF*(-0.3345393828441878 + 
          0.1266707923407351*lm) + 
        CF*((0.06032458785547424 - 0.02303105315286093*lm)*NM + 
          (0.06510292268262555 - 0.02303105315286093*lm)*NL + 
          (0.056235326531323813 - 0.02303105315286093*lm)*NH))}, 
     {0.305, NC*(-0.0021126386268656774*CF^2 + 
        CA*CF*(-0.334960486195058 + 0.12476804339852876*lm) + 
        CF*((0.06012571293727498 - 0.0226850987997325*lm)*NM + 
          (0.06499293614388268 - 0.0226850987997325*lm)*NL + 
          (0.055916665722147575 - 0.0226850987997325*lm)*NH))}, 
     {0.31, NC*(-0.0023494220006175116*CF^2 + CA*CF*(-0.33530772805888304 + 
          0.12290594946392099*lm) + 
        CF*((0.05992016696032719 - 0.022346536266167453*lm)*NM + 
          (0.06487477858207308 - 0.022346536266167453*lm)*NL + 
          (0.05560075308080499 - 0.022346536266167453*lm)*NH))}, 
     {0.315, NC*(-0.0025580615120023606*CF^2 + 
        CA*CF*(-0.3355840288497821 + 0.12108355448859344*lm) + 
        CF*((0.0597083602751795 - 0.022015191725198807*lm)*NM + 
          (0.06474884452922891 - 0.022015191725198807*lm)*NL + 
          (0.05528757253600731 - 0.022015191725198807*lm)*NH))}, 
     {0.32, NC*(-0.002740385932254359*CF^2 + CA*CF*(-0.33579220401643023 + 
          0.11929992487036084*lm) + 
        CF*((0.059490685108189854 - 0.0216908954309747*lm)*NM + 
          (0.06461551277901563 - 0.0216908954309747*lm)*NL + 
          (0.054977107370444145 - 0.0216908954309747*lm)*NH))}, 
     {0.325, NC*(-0.002898121988775882*CF^2 + CA*CF*(-0.3359349678066321 + 
          0.11755414904135032*lm) + 
        CF*((0.0592675163188725 - 0.021373481643881878*lm)*NM + 
          (0.06447514700849422 - 0.021373481643881878*lm)*NL + 
          (0.05466934027365292 - 0.021373481643881878*lm)*NH))}, 
     {0.33, NC*(-0.0030328998865524325*CF^2 + CA*CF*(-0.33601493690047274 + 
          0.11584533705058554*lm) + 
        CF*((0.05903921212632405 - 0.021062788554651917*lm)*NM + 
          (0.06432809637512654 - 0.021062788554651917*lm)*NL + 
          (0.05436425339176986 - 0.021062788554651917*lm)*NH))}, 
     {0.335, NC*(-0.0031462585259095827*CF^2 + 
        CA*CF*(-0.33603463391576505 + 0.11417262014266868*lm) + 
        CF*((0.0588061148058825 - 0.020758658207757942*lm)*NM + 
          (0.06417469608996158 - 0.020758658207757942*lm)*NL + 
          (0.054061828374347025 - 0.020758658207757942*lm)*NH))}, 
     {0.34, NC*(-0.00323965043389278*CF^2 + CA*CF*(-0.33599649078954397 + 
          0.11253515033406036*lm) + 
        CF*((0.05856855135714579 - 0.020460936424374614*lm)*NM + 
          (0.06401526796791458 - 0.020460936424374614*lm)*NL + 
          (0.05376204641840709 - 0.020460936424374614*lm)*NH))}, 
     {0.345, NC*(-0.003314446425541577*CF^2 + CA*CF*(-0.3359028520393516 + 
          0.11093209998828413*lm) + 
        CF*((0.05832683414445733 - 0.02016947272514257*lm)*NM + 
          (0.06385012095602638 - 0.02016947272514257*lm)*NL + 
          (0.05346488830989833 - 0.02016947272514257*lm)*NH))}, 
     {0.35, NC*(-0.0033719400103591687*CF^2 + CA*CF*(-0.33575597790805084 + 
          0.10936266139122734*lm) + 
        CF*((0.05808126151092893 - 0.019884120252950426*lm)*NM + 
          (0.06367955164056195 - 0.019884120252950426*lm)*NL + 
          (0.05317033446269973 - 0.019884120252950426*lm)*NH))}, 
     {0.355, NC*(-0.003413351558381108*CF^2 + CA*CF*(-0.33555804739587086 + 
          0.10782604632757144*lm) + 
        CF*((0.0578321183670318 - 0.01960473569592208*lm)*NM + 
          (0.06350384473378146 - 0.01960473569592208*lm)*NL + 
          (0.05287836495531894 - 0.01960473569592208*lm)*NH))}, 
     {0.36, NC*(-0.00343983223940589*CF^2 + CA*CF*(-0.3353111611833406 + 
          0.10632148565925904*lm) + 
        CF*((0.05757967675476945 - 0.01933117921077437*lm)*NM + 
          (0.06332327354118844 - 0.01933117921077437*lm)*NL + 
          (0.05258895956541489 - 0.01933117921077437*lm)*NH))}, 
     {0.365, NC*(-0.0034524677481720827*CF^2 + 
        CA*CF*(-0.3350173444487011 + 0.10484822890679449*lm) + 
        CF*((0.05732419638843427 - 0.019063314346689907*lm)*NM + 
          (0.06313810041003314 - 0.019063314346689907*lm)*NL + 
          (0.05230209780227087 - 0.019063314346689907*lm)*NH))}, 
     {0.37, NC*(-0.0034522818274508624*CF^2 + CA*CF*(-0.33467854958336035 + 
          0.10340554383407326*lm) + 
        CF*((0.057065925172822655 - 0.0188010079698315*lm)*NM + 
          (0.06294857715982158 - 0.0188010079698315*lm)*NL + 
          (0.05201775893733378 - 0.0188010079698315*lm)*NH))}, 
     {0.375, NC*(-0.0034402396004443994*CF^2 + 
        CA*CF*(-0.3342966588088157 + 0.10199271603734618*lm) + 
        CF*((0.05680509969992416 - 0.018544130188608395*lm)*NM + 
          (0.0627549454955538 - 0.018544130188608395*lm)*NL + 
          (0.051735922032930516 - 0.018544130188608395*lm)*NH))}, 
     {0.38, NC*(-0.0034172507230790894*CF^2 + CA*CF*(-0.3338734866984693 + 
          0.10060904853884309*lm) + 
        CF*((0.05654194572486811 - 0.018292554279789652*lm)*NM + 
          (0.06255743740438845 - 0.018292554279789652*lm)*NL + 
          (0.05145656596926424 - 0.018292554279789652*lm)*NH))}, 
     {0.385, NC*(-0.003384172366270903*CF^2 + CA*CF*(-0.33341078260762036 + 
          0.09925386138550871*lm) + 
        CF*((0.05627667862203242 - 0.018046156615547038*lm)*NM + 
          (0.06235627553640483 - 0.018046156615547038*lm)*NL + 
          (0.05117966946978747 - 0.018046156615547038*lm)*NH))}, 
     {0.39, NC*(-0.0033418120376036142*CF^2 + CA*CF*(-0.33291023301486466 + 
          0.0979264912532379*lm) + 
        CF*((0.05600950382211118 - 0.0178048165914978*lm)*NM + 
          (0.062151673570108 - 0.0178048165914978*lm)*NL + 
          (0.05090521112504382 - 0.0178048165914978*lm)*NH))}, 
     {0.395, NC*(-0.0032909302513333375*CF^2 + 
        CA*CF*(-0.3323734637780327 + 0.09662629105693978*lm) + 
        CF*((0.05574061723093707 - 0.01756841655580723*lm)*NM + 
          (0.06194383656329765 - 0.01756841655580723*lm)*NL + 
          (0.05063316941506366 - 0.01756841655580723*lm)*NH))}, 
     {0.4, NC*(-0.0032322430551072505*CF^2 + CA*CF*(-0.3318020423077159 + 
          0.09535262956670736*lm) + 
        CF*((0.05547020563080544 - 0.017336841739401337*lm)*NM + 
          (0.06173296128989757 - 0.017336841739401337*lm)*NL + 
          (0.05036352273039481 - 0.017336841739401337*lm)*NH))}, 
     {0.405, NC*(-0.003166424421310491*CF^2 + CA*CF*(-0.3311974796613363 + 
          0.09410489103032323*lm) + 
        CF*((0.05519844706503641 - 0.017109980187331494*lm)*NM + 
          (0.061519236563318785 - 0.017109980187331494*lm)*NL + 
          (0.05009624939184511 - 0.017109980187331494*lm)*NH))}, 
     {0.41, NC*(-0.0030941085104942596*CF^2 + CA*CF*(-0.330561232560628 + 
          0.09288247480228921*lm) + 
        CF*((0.054925511206468415 - 0.016887722691325314*lm)*NM + 
          (0.06130284354690686 - 0.016887722691325314*lm)*NL + 
          (0.04983132766900654 - 0.016887722691325314*lm)*NH))}, 
     {0.415, NC*(-0.0030158918139115334*CF^2 + 
        CA*CF*(-0.3298947053353112 + 0.0916847949795313*lm) + 
        CF*((0.0546515597105544 - 0.016669962723551146*lm)*NM + 
          (0.06108395605200175 - 0.016669962723551146*lm)*NL + 
          (0.04956873579763148 - 0.016669962723551146*lm)*NH))}, 
     {0.42, NC*(-0.002932335181794348*CF^2 + CA*CF*(-0.32919925179564297 + 
          0.0905112800438968*lm) + 
        CF*((0.054376746553717464 - 0.016456596371617598*lm)*NM + 
          (0.06086274082411728 - 0.016456596371617598*lm)*NL + 
          (0.0493084519959218 - 0.016456596371617598*lm)*NH))}, 
     {0.425, NC*(-0.0028439657436022934*CF^2 + 
        CA*CF*(-0.32847617703645954 + 0.08936137251153146*lm) + 
        CF*((0.054101218357548136 - 0.016247522274823904*lm)*NM + 
          (0.06063935781772699 - 0.016247522274823904*lm)*NL + 
          (0.04905045447979279 - 0.016247522274823904*lm)*NH))}, 
     {0.43, NC*(-0.0027512787261592345*CF^2 + CA*CF*(-0.327726739175211 + 
          0.08823452858919739*lm) + 
        CF*((0.05382511469949912 - 0.016042641561672254*lm)*NM + 
          (0.06041396046012284 - 0.016042641561672254*lm)*NL + 
          (0.04879472147716779 - 0.016042641561672254*lm)*NH))}, 
     {0.435, NC*(-0.002654739175218362*CF^2 + CA*CF*(-0.32695215102643166 + 
          0.08713021783756869*lm) + 
        CF*((0.053548568410576834 - 0.015841857788648852*lm)*NM + 
          (0.06018669590479452 - 0.015841857788648852*lm)*NL + 
          (0.04854123124135834 - 0.015841857788648852*lm)*NH))}, 
     {0.44, NC*(-0.0025547835857069106*CF^2 + CA*CF*(-0.3261535817149892 + 
          0.086047922841521*lm) + 
        CF*((0.05327170586062691 - 0.015645076880276547*lm)*NM + 
          (0.059957705274758605 - 0.015645076880276547*lm)*NL + 
          (0.0482899620635756 - 0.015645076880276547*lm)*NH))}, 
     {0.445, NC*(-0.0024518214455960564*CF^2 + 
        CA*CF*(-0.3253321582303811 + 0.08498713888741215*lm) + 
        CF*((0.052994647231708464 - 0.015452207070438572*lm)*NM + 
          (0.05972712389624879 - 0.015452207070438572*lm)*NL + 
          (0.04804089228462927 - 0.015452207070438572*lm)*NH))}, 
     {0.45, NC*(-0.002346236698067791*CF^2 + CA*CF*(-0.32448896692426393 + 
          0.08394737364733461*lm) + 
        CF*((0.05271750678008289 - 0.015263158844969928*lm)*NM + 
          (0.059495081523162005 - 0.015263158844969928*lm)*NL + 
          (0.047794000305849745 - 0.015263158844969928*lm)*NH))}, 
     {0.455, NC*(-0.0022383891263869056*CF^2 + 
        CA*CF*(-0.3236250549533255 + 0.08292814687030589*lm) + 
        CF*((0.052440393087251014 - 0.015077844885510162*lm)*NM + 
          (0.059261702552638205 - 0.015077844885510162*lm)*NL + 
          (0.04754926459928194 - 0.015077844885510162*lm)*NH))}, 
     {0.46, NC*(-0.002128615665634555*CF^2 + CA*CF*(-0.32274143166953556 + 
          0.08192899008035001*lm) + 
        CF*((0.052163409300571485 - 0.014896180014609094*lm)*NM + 
          (0.059027106232136264 - 0.014896180014609094*lm)*NL + 
          (0.047306663717188786 - 0.014896180014609094*lm)*NH))}, 
     {0.465, NC*(-0.0020172316452357177*CF^2 + 
        CA*CF*(-0.3218390699597342 + 0.08094944628141186*lm) + 
        CF*((0.05188665336382896 - 0.014718081142074882*lm)*NM + 
          (0.058791406858353275 - 0.014718081142074882*lm)*NL + 
          (0.04706617630090279 - 0.014718081142074882*lm)*NH))}, 
     {0.47, NC*(-0.0019045319659911377*CF^2 + CA*CF*(-0.32091890753644675 + 
          0.07998906966903647*lm) + 
        CF*((0.051610218238217216 - 0.014543467212552086*lm)*NM + 
          (0.058554713968319974 - 0.014543467212552086*lm)*NL + 
          (0.04682778108905949 - 0.014543467212552086*lm)*NH))}, 
     {0.475, NC*(-0.0017907922151125237*CF^2 + 
        CA*CF*(-0.3199818481817478 + 0.07904742534873667*lm) + 
        CF*((0.051334192114129644 - 0.014372259154315758*lm)*NM + 
          (0.058317132522991054 - 0.014372259154315758*lm)*NL + 
          (0.04659145692525339 - 0.014372259154315758*lm)*NH))}, 
     {0.48, NC*(-0.0016762697225775013*CF^2 + CA*CF*(-0.31902876294592475 + 
          0.07812408906096473*lm) + 
        CF*((0.05105865861414313 - 0.014204379829266315*lm)*NM + 
          (0.05807876308363607 - 0.014204379829266315*lm)*NL + 
          (0.04635718276513678 - 0.014204379829266315*lm)*NH))}, 
     {0.485, NC*(-0.0015612045619242591*CF^2 + 
        CA*CF*(-0.31806049130263214 + 0.07721864691259778*lm) + 
        CF*((0.0507836969875669 - 0.014039753984108685*lm)*NM + 
          (0.057839701981323474 - 0.014039753984108685*lm)*NL + 
          (0.04612493768300416 - 0.014039753984108685*lm)*NH))}, 
     {0.49, NC*(-0.0014458204984462728*CF^2 + CA*CF*(-0.31707784226215974 + 
          0.07633069511484084*lm) + 
        CF*((0.05050938229691355 - 0.013878308202698334*lm)*NM + 
          (0.05760004147977838 - 0.013878308202698334*lm)*NL + 
          (0.04589470087788166 - 0.013878308202698334*lm)*NH))}, 
     {0.495, NC*(-0.001330325887575559*CF^2 + CA*CF*(-0.316081595444381 + 
          0.07545983972744694*lm) + 
        CF*((0.050235785596630424 - 0.013719970859535807*lm)*NM + 
          (0.05735986993188277 - 0.013719970859535807*lm)*NL + 
          (0.04566645167915405 - 0.013719970859535807*lm)*NH))}, 
     {0.5, CF*NC*(-0.001214915150357372*CF + CA*(-0.31507250169552525 + 
          0.07460569668599738*lm) + 0.049962974042399896*NM - 
        0.013564672124726796*lm*NM + 0.05711927189407148*NL - 
        0.013564672124726796*lm*NL + 0.04544016956068295*NH - 
        0.013564672124726796*lm*NH)}, 
     {0.505, CF*NC*(-0.001099766956757123*CF + 
        CA*(-0.3140512858402893 + 0.07376789039443735*lm) + 
        0.04969101131622739*NM - 0.013412343708079517*lm*NM + 
        0.056878328422354275*NL - 0.013412343708079517*lm*NL + 
        0.0452158341080384*NH - 0.013412343708079517*lm*NH)}, 
     {0.51, CF*NC*(-0.0009850491386159802*CF + 
        CA*(-0.3130186448636814 + 0.07294605532972195*lm) + 
        0.04941995737076144*NM - 0.013262919150858537*lm*NM + 
        0.056637116971347115*NL - 0.013262919150858537*lm*NL + 
        0.04499342508228315*NH - 0.013262919150858537*lm*NH)}, 
     {0.515, CF*NC*(-0.0008709164843087995*CF + 
        CA*(-0.311975250801834 + 0.07213983450848145*lm) + 
        0.04914986887230409*NM - 0.013116333546996628*lm*NM + 
        0.056395711697488644*NL - 0.013116333546996628*lm*NL + 
        0.04477292238201577*NH - 0.013116333546996628*lm*NH)}, 
     {0.52, CF*NC*(-0.0007575122054359619*CF + 
        CA*(-0.31092175111057213 + 0.07134887960838755*lm) + 
        0.048880799267478535*NM - 0.012972523565161372*lm*NM + 
        0.056154183542100986*NL - 0.012972523565161372*lm*NL + 
        0.044554306058224635*NH - 0.012972523565161372*lm*NH)}, 
     {0.525, CF*NC*(-0.0006449685868464348*CF + 
        CA*(-0.30985876952627023 + 0.07057285074792069*lm) + 
        0.04861279892190853*NM - 0.012831427408712853*lm*NM + 
        0.05591260035479959*NL - 0.012831427408712853*lm*NL + 
        0.04433755631761931*NH - 0.012831427408712853*lm*NH)}, 
     {0.53, CF*NC*(-0.0005334076025889747*CF + 
        CA*(-0.3087869068957934 + 0.06981141627168728*lm) + 
        0.048345915253161634*NM - 0.012692984776670415*lm*NM + 
        0.05567102701213506*NL - 0.012692984776670415*lm*NL + 
        0.044122653525651284*NH - 0.012692984776670415*lm*NH)}, 
     {0.535, CF*NC*(-0.0004229414995731061*CF + 
        CA*(-0.307706741976675 + 0.06906425254116914*lm) + 
        0.048080192858196764*NM - 0.012557136825667116*lm*NM + 
        0.05542952553165811*NL - 0.012557136825667116*lm*NL + 
        0.04390957820924135*NH - 0.012557136825667116*lm*NH)}, 
     {0.54, CF*NC*(-0.00031367335062607363*CF + 
        CA*(-0.3066188322086403 + 0.06833104373078755*lm) + 
        0.047815673635545716*NM - 0.012423826132870464*lm*NM + 
        0.05518815518159103*NL - 0.012423826132870464*lm*NL + 
        0.04369831105923018*NH - 0.012423826132870464*lm*NH)}, 
     {0.545, CF*NC*(-0.00020569757854181823*CF + 
        CA*(-0.30552371445754134 + 0.06761148162916497*lm) + 
        0.047552396902448946*NM - 0.012292996659848177*lm*NM + 
        0.054946972586281166*NL - 0.012292996659848177*lm*NL + 
        0.04348883293256779*NH - 0.012292996659848177*lm*NH)}, 
     {0.55, CF*NC*(-0.00009910045263287*CF + CA*(-0.3044219057327294 + 
          0.06690526544546796*lm) + 0.04729039950715616*NM - 
        0.01216459371735781*lm*NM + 0.054706031827604584*NL - 
        0.01216459371735781*lm*NL + 0.043281124854256614*NH - 
        0.01216459371735781*lm*NH)}, 
     {0.555, CF*NC*(6.039440784415429*^-6*CF + 
        CA*(-0.30331390387884993 + 0.06621210162071603*lm) + 
        0.047029715936593344*NM - 0.012038563931039279*lm*NM + 
        0.054465384542481385*NL - 0.012038563931039279*lm*NL + 
        0.043075168019062325*NH - 0.012038563931039279*lm*NH)}, 
     {0.56, CF*NC*(0.00010965075261687793*CF + 
        CA*(-0.3022001882430084 + 0.06553170364394208*lm) + 
        0.04677037841958913*NM - 0.01191485520798947*lm*NM + 
        0.05422508001665698*NL - 0.01191485520798947*lm*NL + 
        0.04287094379300573*NH - 0.01191485520798947*lm*NH)}, 
     {0.565, CF*NC*(0.00021166894865128766*CF + 
        CA*(-0.30108122031821954 + 0.06486379187309115*lm) + 
        0.04651241702584545*NM - 0.011793416704198392*lm*NM + 
        0.05398516527489767*NL - 0.011793416704198392*lm*NL + 
        0.04266843371464829*NH - 0.011793416704198392*lm*NH)}, 
     {0.57, CF*NC*(0.0003120359094261604*CF + CA*(-0.29995744436401456 + 
          0.064208093360546*lm) + 0.04625585976082913*NM - 
        0.011674198792826546*lm*NM + 0.053745685167742266*NL - 
        0.011674198792826546*lm*NL + 0.042467619496183225*NH - 
        0.011674198792826546*lm*NH)}, 
     {0.575, CF*NC*(0.0004106995511682166*CF + 
        CA*(-0.29882928800505265 + 0.06356434168316898*lm) + 
        0.04600073265675385*NM - 0.01155715303330345*lm*NM + 
        0.05350668245494622*NL - 0.01155715303330345*lm*NL + 
        0.042268483024343675*NH - 0.01155715303330345*lm*NH)}, 
     {0.58, CF*NC*(0.0005076134667037358*CF + CA*(-0.2976971628085447 + 
          0.06293227677675149*lm) + 0.045747059859814476*NM - 
        0.011442232141227544*lm*NM + 0.05326819788574838*NL - 
        0.011442232141227544*lm*NL + 0.042071006361138495*NH - 
        0.011442232141227544*lm*NH)}, 
     {0.585, CF*NC*(0.0006027365853124412*CF + 
        CA*(-0.29656146484127077 + 0.06231164477476406*lm) + 
        0.04549486371382916*NM - 0.011329389959048012*lm*NM + 
        0.053030270276085804*NL - 0.011329389959048012*lm*NL + 
        0.04187517174442593*NH - 0.011329389959048012*lm*NH)}, 
     {0.59, CF*NC*(0.0006960328505458078*CF + CA*(-0.29542257520694154 + 
          0.061702197851301425*lm) + 0.04524416484043759*NM - 
        0.01121858142750935*lm*NM + 0.0527929365828764*NL - 
        0.01121858142750935*lm*NL + 0.0416809615883349*NH - 
        0.01121858142750935*lm*NH)}, 
     {0.595, CF*NC*(0.0007874709150830073*CF + 
        CA*(-0.2942808605646238 + 0.061103694068119094*lm) + 
        0.044994982215997834*NM - 0.011109762557839836*lm*NM + 
        0.052556231975484556*NL - 0.011109762557839836*lm*NL + 
        0.04148835848354289*NH - 0.011109762557839836*lm*NH)}, 
     {0.6, CF*NC*(0.0008770238517462359*CF + CA*(-0.2931366736289257 + 
          0.06051589722565959*lm) + 0.04474733324531803*NM - 
        0.01100289040466538*lm*NM + 0.052320189904480015*NL - 
        0.01100289040466538*lm*NL + 0.04129734519741931*NH - 
        0.01100289040466538*lm*NH)}, 
     {0.605, CF*NC*(0.0009646688798430912*CF + 
        CA*(-0.2919903536526072 + 0.05993857671796829*lm) + 
        0.044501233832353417*NM - 0.010897923039630598*lm*NM + 
        0.05208484216779589*NL - 0.010897923039630598*lm*NL + 
        0.04110790467404236*NH - 0.010897923039630598*lm*NH)}, 
     {0.61, CF*NC*(0.0010503871060470952*CF + CA*(-0.29084222689226036 + 
          0.05937150739140093*lm) + 0.04425669844799364*NM - 
        0.01079481952570926*lm*NM + 0.05185021897438717*NL - 
        0.01079481952570926*lm*NL + 0.0409200200340973*NH - 
        0.01079481952570926*lm*NH)}, 
     {0.615, CF*NC*(0.0011341632790685696*CF + 
        CA*(-0.28969260705767413 + 0.0588144694070265*lm) + 
        0.04401374019506016*NM - 0.010693539892186636*lm*NM + 
        0.05161634900548728*NL - 0.010693539892186636*lm*NL + 
        0.040733674574663536*NH - 0.010693539892186636*lm*NH)}, 
     {0.62, CF*NC*(0.0012159855574069576*CF + CA*(-0.2885417957454805 + 
          0.05826724810663128*lm) + 0.04377237087062828*NM - 
        0.010594045110296596*lm*NM + 0.05138325947355587*NL - 
        0.010594045110296596*lm*NL + 0.040548851768897366*NH - 
        0.010594045110296596*lm*NH)}, 
     {0.625, CF*NC*(0.0012958452895124998*CF + 
        CA*(-0.2873900828576519 + 0.05772963388223185*lm) + 
        0.04353260102578374*NM - 0.0104962970694967*lm*NM + 
        0.05115097617900755*NL - 0.0104962970694967*lm*NL + 
        0.04036553526561724*NH - 0.0104962970694967*lm*NH)}, 
     {0.63, CF*NC*(0.0013737368057200124*CF + CA*(-0.2862377470054006 + 
          0.05720142204900655*lm) + 0.04329444002291899*NM - 
        0.010400258554364827*lm*NM + 0.05091952356480762*NL - 
        0.010400258554364827*lm*NL + 0.04018370888879761*NH - 
        0.010400258554364827*lm*NH)}, 
     {0.635, CF*NC*(0.0014496572213504985*CF + 
        CA*(-0.285085055899009 + 0.05668241272155707*lm) + 
        0.04305789609067003*NM - 0.010305893222101285*lm*NM + 
        0.05068892476901701*NL - 0.010305893222101285*lm*NL + 
        0.040003356636977516*NH - 0.010305893222101285*lm*NH)}, 
     {0.64, CF*NC*(0.001523606250407553*CF + CA*(-0.28393226672410016 + 
          0.0561724106934137*lm) + 0.04282297637659027*NM - 
        0.010213165580620673*lm*NM + 0.05045920167536596*NL - 
        0.010213165580620673*lm*NL + 0.039824462682589344*NH - 
        0.010213165580620673*lm*NH)}, 
     {0.645, CF*NC*(0.0015955860293250849*CF + 
        CA*(-0.2827796265048381 + 0.055671225319699695*lm) + 
        0.04258968699765401*NM - 0.010122040967218126*lm*NM + 
        0.050230374961932035*NL - 0.010122040967218126*lm*NL + 
        0.03964701137121334*NH - 0.010122040967218126*lm*NH)}, 
     {0.65, CF*NC*(0.0016656009502508846*CF + CA*(-0.28162737245452996 + 
          0.0551786704028721*lm) + 0.04235803308867815*NM - 
        0.010032485527794928*lm*NM + 0.05000246414799568*NL - 
        0.010032485527794928*lm*NL + 0.039470987220762734*NH - 
        0.010032485527794928*lm*NH)}, 
     {0.655, CF*NC*(0.0017336575033770824*CF + 
        CA*(-0.28047573231408296 + 0.05469456408145841*lm) + 
        0.042128018848747055*NM - 0.009944466196628803*lm*NM + 
        0.04977548763914315*NL - 0.009944466196628803*lm*NL + 
        0.03929637492060443*NH - 0.009944466196628803*lm*NH)}, 
     {0.66, CF*NC*(0.001799764127853658*CF + CA*(-0.27932492467875353 + 
          0.0542187287217101*lm) + 0.041899647585722025*NM - 
        0.009857950676674564*lm*NM + 0.04954946277068399*NL - 
        0.009857950676674564*lm*NL + 0.03912315933061969*NH - 
        0.009857950676674564*lm*NH)}, 
     {0.665, CF*NC*(0.0018639310708449626*CF + 
        CA*(-0.27817515931360826 + 0.05375099081209625*lm) + 
        0.04167292175891328*NM - 0.009772907420381137*lm*NM + 
        0.04932440584944767*NL - 0.009772907420381137*lm*NL + 
        0.03895132548020924*NH - 0.009772907420381137*lm*NH)}, 
     {0.67, CF*NC*(0.0019261702543117546*CF + CA*(-0.2770266374581015 + 
          0.053291180860562025*lm) + 0.04144784301998931*NM - 
        0.009689305611011277*lm*NM + 0.04910033219402111*NL - 
        0.009689305611011277*lm*NL + 0.03878085856724678*NH - 
        0.009689305611011277*lm*NH)}, 
     {0.675, CF*NC*(0.001986495149122609*CF + CA*(-0.2758795521201591 + 
          0.05283913329447872*lm) + 0.04122441225219519*NM - 
        0.009607115144450677*lm*NM + 0.048877256173486774*NL - 
        0.009607115144450677*lm*NL + 0.03861174395698474*NH - 
        0.009607115144450677*lm*NH)}, 
     {0.68, CF*NC*(0.002044920656118805*CF + CA*(-0.2747340883601423 + 
          0.05239468636321402*lm) + 0.04100262960794861*NM - 
        0.009526306611493457*lm*NM + 0.048655191244718204*NL - 
        0.009526306611493457*lm*NL + 0.03844396718091612*NH - 
        0.009526306611493457*lm*NH)}, 
     {0.685, CF*NC*(0.002101462993775982*CF + CA*(-0.2735904235650539 + 
          0.0519576820432525*lm) + 0.040782494544879234*NM - 
        0.009446851280591364*lm*NM + 0.04843414998828797*NL - 
        0.009446851280591364*lm*NL + 0.03827751393559561*NH - 
        0.009446851280591364*lm*NH)}, 
     {0.69, CF*NC*(0.002156139592124027*CF + CA*(-0.2724487277133328 + 
          0.0515279659457987*lm) + 0.04056400586037486*NM - 
        0.009368721081054309*lm*NM + 0.04821414414304056*NL - 
        0.009368721081054309*lm*NL + 0.038112370081423486*NH - 
        0.009368721081054309*lm*NH)}, 
     {0.695, CF*NC*(0.002208968992603905*CF + CA*(-0.2713091636305719 + 
          0.051105387226796146*lm) + 0.0403471617246945*NM - 
        0.009291888586690208*lm*NM + 0.04799518463938093*NL - 
        0.009291888586690208*lm*NL + 0.03794852164139527*NH - 
        0.009291888586690208*lm*NH)}, 
     {0.7, CF*NC*(0.002259970753556476*CF + CA*(-0.2701718872364817 + 
          0.05068979849929805*lm) + 0.04013195971270664*NM - 
        0.009216326999872371*lm*NM + 0.04777728163132716*NL - 
        0.009216326999872371*lm*NL + 0.037785954799820116*NH - 
        0.009216326999872371*lm*NH)}, 
     {0.705, CF*NC*(0.0023091653610538346*CF + 
        CA*(-0.2690370477834091 + 0.05028105574812646*lm) + 
        0.039918396834308166*NM - 0.009142010136022994*lm*NM + 
        0.047560444527373874*NL - 0.009142010136022994*lm*NL + 
        0.0376246559010107*NH - 0.009142010136022994*lm*NH)}, 
     {0.71, CF*NC*(0.002356574144798402*CF + CA*(-0.2679047880867101 + 
          0.049879018246758784*lm) + 0.03970646956357736*NM - 
        0.009068912408501597*lm*NM + 0.047344682020211394*NL - 
        0.009068912408501597*lm*NL + 0.03746461144794724*NH - 
        0.009068912408501597*lm*NH)}, 
     {0.715, CF*NC*(0.002402219198828928*CF + CA*(-0.26677524474726433 + 
          0.049483548476381686*lm) + 0.03949617386671196*NM - 
        0.00899700881388758*lm*NM + 0.047130002115343496*NL - 
        0.00899700881388758*lm*NL + 0.037305808100918075*NH - 
        0.00899700881388758*lm*NH)}, 
     {0.72, CF*NC*(0.002446123306785776*CF + CA*(-0.26564854836640833 + 
          0.049094512047054374*lm) + 0.03928750522880151*NM - 
        0.008926274917646249*lm*NM + 0.046916412158645344*NL - 
        0.008926274917646249*lm*NL + 0.03714823267613927*NH - 
        0.008926274917646249*lm*NH)}, 
     {0.725, CF*NC*(0.002488309871500392*CF + CA*(-0.2645248237535535 + 
          0.04871177762092448*lm) + 0.039080458679480824*NM - 
        0.008856686840168087*lm*NM + 0.04670391886290119*NL - 
        0.008856686840168087*lm*NL + 0.03699187214435532*NH - 
        0.008856686840168087*lm*NH)}, 
     {0.73, CF*NC*(0.0025288028486857472*CF + CA*(-0.26340419012674676 + 
          0.04833521683744142*lm) + 0.03887502881750979*NM - 
        0.008788221243171168*lm*NM + 0.04649252833336021*NL - 
        0.008788221243171168*lm*NL + 0.036836713629423125*NH - 
        0.008788221243171168*lm*NH)}, 
     {0.735, CF*NC*(0.002567626684515824*CF + 
        CA*(-0.262286761306421 + 0.04796470424051341*lm) + 
        0.038671209834322734*NM - 0.008720855316456983*lm*NM + 
        0.04628224609234707*NL - 0.008720855316456983*lm*NL + 
        0.0366827444068812*NH - 0.008720855316456983*lm*NH)}, 
     {0.74, CF*NC*(0.00260480625689291*CF + CA*(-0.2611726459025733 + 
          0.04760011720755593*lm) + 0.03846899553658881*NM - 
        0.008654566765010169*lm*NM + 0.046073077102962615*NL - 
        0.008654566765010169*lm*NL + 0.03652995190250601*NH - 
        0.008654566765010169*lm*NH)}, 
     {0.745, CF*NC*(0.002640366820211623*CF + CA*(-0.26006194749560146 + 
          0.04724133588038065*lm) + 0.03826837936782318*NM - 
        0.008589333796432846*lm*NM + 0.045865025791908584*NL - 
        0.008589333796432846*lm*NL + 0.03637832369085711*NH - 
        0.008589333796432846*lm*NH)}, 
     {0.75, CF*NC*(0.0026743339534382148*CF + CA*(-0.25895476481101937 + 
          0.04688824309787532*lm) + 0.038069354429087265*NM - 
        0.008525135108704604*lm*NM + 0.045658096071468965*NL - 
        0.008525135108704604*lm*NL + 0.03622784749381288*NH - 
        0.008525135108704604*lm*NH)}, 
     {0.755, CF*NC*(0.0027067335113328548*CF + 
        CA*(-0.25785119188826516 + 0.046540724330426296*lm) + 
        0.03787191349881457*NM - 0.008461949878259326*lm*NM + 
        0.04545229136067927*NL - 0.008461949878259326*lm*NL + 
        0.036078511179098244*NH - 0.008461949878259326*lm*NH)}, 
     {0.76, CF*NC*(0.0027375915786512646*CF + 
        CA*(-0.256751318243807 + 0.04619866761603686*lm) + 
        0.0376760490517973*NM - 0.008399757748370337*lm*NM + 
        0.045247614605714095*NL - 0.008399757748370337*lm*NL + 
        0.035930302758806085*NH - 0.008399757748370337*lm*NH)}, 
     {0.765, CF*NC*(0.0027669344271703117*CF + 
        CA*(-0.25565522902874477 + 0.04586196349809562*lm) + 
        0.037481753277367365*NM - 0.008338538817835566*lm*NM + 
        0.04504406829952165*NL - 0.008338538817835566*lm*NL + 
        0.035783210387913496*NH - 0.008338538817835566*lm*NH)}, 
     {0.77, CF*NC*(0.00279478847538999*CF + CA*(-0.2545630051810991 + 
          0.04553050496475052*lm) + 0.03728901809680432*NM - 
        0.008278273629954641*lm*NM + 0.04484165450073342*NL - 
        0.008278273629954641*lm*NL + 0.03563722236279436*NH - 
        0.008278273629954641*lm*NH)}, 
     {0.775, CF*NC*(0.0028211802507716387*CF + 
        CA*(-0.2534747235729702 + 0.04520418738984532*lm) + 
        0.03709783518000102*NM - 0.008218943161790058*lm*NM + 
        0.04464037485187559*NL - 0.008218943161790058*lm*NL + 
        0.035492327119729425*NH - 0.008218943161790058*lm*NH)}, 
     {0.78, CF*NC*(0.0028461363543792937*CF + CA*(-0.25239045715274566 + 
          0.04488290847537631*lm) + 0.036908195961416944*NM - 
        0.008160528813704783*lm*NM + 0.044440230596908*NL - 
        0.008160528813704783*lm*NL + 0.035348513233415015*NH - 
        0.008160528813704783*lm*NH)}, 
     {0.785, CF*NC*(0.002869683427797757*CF + CA*(-0.25131027508252624 + 
          0.04456656819542852*lm) + 0.03672009165534773*NM - 
        0.008103012399168823*lm*NM + 0.04424122259811559*NL - 
        0.008103012399168823*lm*NL + 0.03520576941547152*NH - 
        0.008103012399168823*lm*NH)}, 
     {0.79, CF*NC*(0.0028918481222073205*CF + CA*(-0.25023424287093576 + 
          0.04425506874155154*lm) + 0.03653351327053828*NM - 
        0.008046376134827553*lm*NM + 0.04404335135237601*NL - 
        0.008046376134827553*lm*NL + 0.03506408451295264*NH - 
        0.008046376134827553*lm*NH)}, 
     {0.795, CF*NC*(0.002912657069501126*CF + CA*(-0.24916242250147325 + 
          0.043948314469536155*lm) + 0.03634845162416583*NM - 
        0.007990602630824755*lm*NM + 0.04384661700682641*NL - 
        0.007990602630824755*lm*NL + 0.03492344750685636*NH - 
        0.007990602630824755*lm*NH)}, 
     {0.8, CF*NC*(0.002932136855336845*CF + CA*(-0.24809487255656054 + 
          0.04364621184755428*lm) + 0.03616489735521823*NM - 
        0.007935674881373506*lm*NM + 0.04365101937395147*NL - 
        0.007935674881373506*lm*NL + 0.03478384751063859*NH - 
        0.007935674881373506*lm*NH)}, 
     {0.805, CF*NC*(0.0029503139940198343*CF + 
        CA*(-0.24703164833743296 + 0.043348669405625456*lm) + 
        0.035982840937291635*NM - 0.007881576255568264*lm*NM + 
        0.043456557946113916*NL - 0.007881576255568264*lm*NL + 
        0.034645273768730264*NH - 0.007881576255568264*lm*NH)}, 
     {0.81, CF*NC*(0.0029672149051200684*CF + CA*(-0.2459728019800156 + 
          0.04305559768637428*lm) + 0.03580227269083094*NM - 
        0.007828290488431687*lm*NM + 0.04326323190954796*NL - 
        0.007828290488431687*lm*NL + 0.034507715655058745*NH - 
        0.007828290488431687*lm*NH)}, 
     {0.815, CF*NC*(0.0029828658917300686*CF + 
        CA*(-0.24491838256692192 + 0.0427669091970442*lm) + 
        0.03562318279483524*NM - 0.007775801672189854*lm*NM + 
        0.043071040157835215*NL - 0.007775801672189854*lm*NL + 
        0.03437116267157421*NH - 0.007775801672189854*lm*NH)}, 
     {0.82, CF*NC*(0.0029972931202757055*CF + CA*(-0.24386843623570797 + 
          0.04248251836273387*lm) + 0.035445561298049856*NM - 
        0.007724094247769793*lm*NM + 0.042879981304882214*NL - 
        0.007724094247769793*lm*NL + 0.03423560444678178*NH - 
        0.007724094247769793*lm*NH)}, 
     {0.825, CF*NC*(0.0030105226017961926*CF + 
        CA*(-0.2428230062835087 + 0.04220234148082335*lm) + 
        0.03526939812966533*NM - 0.007673152996513337*lm*NM + 
        0.04269005369741748*NL - 0.007673152996513337*lm*NL + 
        0.03410103073428002*NH - 0.007673152996513337*lm*NH)}, 
     {0.83, CF*NC*(0.0030225801746137796*CF + CA*(-0.24178213326818054 + 
          0.04192629667655833*lm) + 0.03509468310954341*NM - 
        0.007622963032101515*lm*NM + 0.042501255427025854*NL - 
        0.007622963032101515*lm*NL + 0.03396743141130634*NH - 
        0.007622963032101515*lm*NH)}, 
     {0.835, CF*NC*(0.0030334914883176655*CF + 
        CA*(-0.24074585510606836 + 0.041654303859761196*lm) + 
        0.03492140595798878*NM - 0.007573509792683854*lm*NM + 
        0.04231358434173689*NL - 0.007573509792683854*lm*NL + 
        0.03383479647729002*NH - 0.007573509792683854*lm*NH)}, 
     {0.84, CF*NC*(0.003043281988990449*CF + CA*(-0.2397142071665115 + 
          0.04138628468263904*lm) + 0.03474955630508486*NM - 
        0.007524779033207098*lm*NM + 0.042127038057183486*NL - 
        0.007524779033207098*lm*NL + 0.0337031160524132*NH - 
        0.007524779033207098*lm*NH)}, 
     {0.845, CF*NC*(0.0030519769056090314*CF + 
        CA*(-0.2386872223631997 + 0.04112216249865912*lm) + 
        0.034579123699611115*NM - 0.007476756817938021*lm*NM + 
        0.041941613967346456*NL - 0.007476756817938021*lm*NL + 
        0.033572380376180454*NH - 0.007476756817938021*lm*NH)}, 
     {0.85, CF*NC*(0.003059601237555333*CF + CA*(-0.23766493124248478 + 
          0.04086186232246333*lm) + 0.034410097617558776*NM - 
        0.007429429513175152*lm*NM + 0.04175730925490004*NL - 
        0.007429429513175152*lm*NL + 0.033442579805997366*NH - 
        0.007429429513175152*lm*NH)}, 
     {0.855, CF*NC*(0.0030661797431754344*CF + 
        CA*(-0.23664736206875198 + 0.04060531079079405*lm) + 
        0.03424246747026094*NM - 0.007382783780144371*lm*NM + 
        0.041574120901172816*NL - 0.007382783780144371*lm*NL + 
        0.03331370481575844*NH - 0.007382783780144371*lm*NH)}, 
     {0.86, CF*NC*(0.0030717369293288455*CF + CA*(-0.23563454090694916 + 
          0.04035243612440414*lm) + 0.03407622261215271*NM - 
        0.007336806568073479*lm*NM + 0.04139204569573803*NL - 
        0.007336806568073479*lm*NL + 0.03318574599444493*NH - 
        0.007336806568073479*lm*NH)}, 
     {0.865, CF*NC*(0.003076297041872564*CF + CA*(-0.23462649170237027 + 
          0.04010316809092532*lm) + 0.033911352348176056*NM - 
        0.007291485107440967*lm*NM + 0.04121108024564664*NL - 
        0.007291485107440967*lm*NL + 0.03305869404473268*NH - 
        0.007291485107440967*lm*NH)}, 
     {0.87, CF*NC*(0.0030798840570273674*CF + CA*(-0.23362323635778529 + 
          0.03985743796866898*lm) + 0.033747845940843915*NM - 
        0.007246806903394361*lm*NM + 0.04103122098431609*NL - 
        0.007246806903394361*lm*NL + 0.03293253978161058*NH - 
        0.007246806903394361*lm*NH)}, 
     {0.875, CF*NC*(0.003082521673576449*CF + CA*(-0.2326247948080057 + 
          0.03961517851133499*lm) + 0.03358569261697702*NM - 
        0.007202759729333635*lm*NM + 0.04085246418008726*NL - 
        0.007202759729333635*lm*NL + 0.03280727413100965*NH - 
        0.007202759729333635*lm*NH)}, 
     {0.88, CF*NC*(0.0030842333058490315*CF + CA*(-0.23163118509197198 + 
          0.03937632391360417*lm) + 0.033424881574126764*NM - 
        0.007159331620655304*lm*NM + 0.04067480594446156*NL - 
        0.007159331620655304*lm*NL + 0.032682888128443374*NH - 
        0.007159331620655304*lm*NH)}, 
     {0.885, CF*NC*(0.0030850420774440022*CF + 
        CA*(-0.23064242342244523 + 0.03914080977759118*lm) + 
        0.03326540198669676*NM - 0.007116510868652942*lm*NM + 
        0.04049824224002963*NL - 0.007116510868652942*lm*NL + 
        0.03255937291765916*NH - 0.007116510868652942*lm*NH)}, 
     {0.89, CF*NC*(0.003084970815650878*CF + CA*(-0.22965852425338446 + 
          0.0389085730801349*lm) + 0.03310724301177516*NM - 
        0.0070742860145699814*lm*NM + 0.040322768888102906*NL - 
        0.0070742860145699814*lm*NL + 0.03243671974930143*NH - 
        0.0070742860145699814*lm*NH)}, 
     {0.895, CF*NC*(0.0030840420465275986*CF + 
        CA*(-0.22867950034508566 + 0.03867955214090418*lm) + 
        0.03295039379468948*NM - 0.007032645843800761*lm*NM + 
        0.04014838157605869*NL - 0.007032645843800761*lm*NL + 
        0.032314919979586465*NH - 0.007032645843800761*lm*NH)}, 
     {0.9, CF*NC*(0.0030822779905967028*CF + CA*(-0.22770536282715814 + 
          0.0384536865912975*lm) + 0.03279484347429515*NM - 
        0.006991579380235908*lm*NM + 0.03997507586440897*NL - 
        0.006991579380235908*lm*NL + 0.03219396506898913*NH - 
        0.006991579380235908*lm*NH)}, 
     {0.905, CF*NC*(0.0030797005591233903*CF + 
        CA*(-0.2267361212594099 + 0.03823091734411535*lm) + 
        0.03264058118800848*NM - 0.006951075880748245*lm*NM + 
        0.03980284719360308*NL - 0.006951075880748245*lm*NL + 
        0.03207384658094173*NH - 0.006951075880748245*lm*NH)}, 
     {0.91, CF*NC*(0.0030763313509408574*CF + CA*(-0.22577178369071174 + 
          0.038011186563985326*lm) + 0.0324875960765945*NM - 
        0.0069111248298155134*lm*NM + 0.03963169089057364*NL - 
        0.0069111248298155134*lm*NL + 0.03195455618054511*NH - 
        0.0069111248298155134*lm*NH)}, 
     {0.915, CF*NC*(0.0030721916497900483*CF + 
        CA*(-0.22481235671590746 + 0.03779443763851972*lm) + 
        0.03233587728871951*NM - 0.006871715934276313*lm*NM + 
        0.03946160217503504*NL - 0.006871715934276313*lm*NL + 
        0.03183608563329213*NH - 0.006871715934276313*lm*NH)}, 
     {0.92, CF*NC*(0.00306730242214266*CF + CA*(-0.22385784553083482 + 
          0.037580615150186625*lm) + 0.032185413985277994*NM - 
        0.00683283911821575*lm*NM + 0.039292576165543366*NL - 
        0.00683283911821575*lm*NL + 0.03171842680380364*NH - 
        0.00683283911821575*lm*NH)}, 
     {0.925, CF*NC*(0.003061684315477833*CF + CA*(-0.22290825398552008 + 
          0.03736966484887566*lm) + 0.03203619534350291*NM - 
        0.0067944845179773936*lm*NM + 0.03912460788532634*NL - 
        0.0067944845179773936*lm*NL + 0.031601571654577054*NH - 
        0.0067944845179773936*lm*NH)}, 
     {0.93, CF*NC*(0.0030553576569844836*CF + CA*(-0.22196358463560675 + 
          0.037161533625140214*lm) + 0.03188821056086838*NM - 
        0.006756642477298221*lm*NM + 0.038957692267891454*NL - 
        0.006756642477298221*lm*NL + 0.03148551224474755*NH - 
        0.006756642477298221*lm*NH)}, 
     {0.935, CF*NC*(0.0030483424526626867*CF + 
        CA*(-0.22102383879207663 + 0.03695616948409831*lm) + 
        0.03174144885879307*NM - 0.006719303542563328*lm*NM + 
        0.03879182416242037*NL - 0.006719303542563328*lm*NL + 
        0.03137024072886214*NH - 0.006719303542563328*lm*NH)}, 
     {0.94, CF*NC*(0.0030406583867988836*CF + CA*(-0.22008901656932012 + 
          0.036753521519975005*lm) + 0.03159589948615246*NM - 
        0.0066824584581772735*lm*NM + 0.038626998338957115*NL - 
        0.0066824584581772735*lm*NL + 0.0312557493556664*NH - 
        0.0066824584581772735*lm*NH)}, 
     {0.945, CF*NC*(0.0030323248217910045*CF + 
        CA*(-0.21915911693160975 + 0.03655353989126956*lm) + 
        0.03145155172260786*NM - 0.006646098162049011*lm*NM + 
        0.03846320949339751*NL - 0.006646098162049011*lm*NL + 
        0.031142030466904193*NH - 0.006646098162049011*lm*NH)}, 
     {0.95, CF*NC*(0.003023360798300839*CF + CA*(-0.2182341377380302 + 
          0.036356175796530915*lm) + 0.031308394881759544*NM - 
        0.006610213781187439*lm*NM + 0.038300452252286996*NL - 
        0.006610213781187439*lm*NL + 0.031029076496130185*NH - 
        0.006610213781187439*lm*NH)}, 
     {0.955, CF*NC*(0.0030137850357121643*CF + 
        CA*(-0.2173140757859149 + 0.036161381450725776*lm) + 
        0.03116641831413144*NM - 0.006574796627404686*lm*NM + 
        0.03813872117743364*NL - 0.006574796627404686*lm*NL + 
        0.03091687996753532*NH - 0.006574796627404686*lm*NH)}, 
     {0.96, CF*NC*(0.0030036159328742694*CF + CA*(-0.21639892685283948 + 
          0.035969110062183854*lm) + 0.03102561140999403*NM - 
        0.006539838193124337*lm*NM + 0.037978010770342976*NL - 
        0.006539838193124337*lm*NL + 0.030805433494785206*NH - 
        0.006539838193124337*lm*NH)}, 
     {0.965, CF*NC*(0.0029928715691115815*CF + 
        CA*(-0.21548868573721808 + 0.03577931581010516*lm) + 
        0.03088596360203237*NM - 0.006505330147291847*lm*NM + 
        0.03781831547648101*NL - 0.006505330147291847*lm*NL + 
        0.030694729779871453*NH - 0.006505330147291847*lm*NH)}, 
     {0.97, CF*NC*(0.002981569705481114*CF + CA*(-0.21458334629754977 + 
          0.03559195382261491*lm) + 0.030747464367865466*NM - 
        0.006471264331384528*lm*NM + 0.03765962968937161*NL - 
        0.006471264331384528*lm*NL + 0.0305847616119759*NH - 
        0.006471264331384528*lm*NH)}, 
     {0.975, CF*NC*(0.002969727786260423*CF + CA*(-0.21368290149035857 + 
          0.03540698015535169*lm) + 0.03061010323242323*NM - 
        0.006437632755518489*lm*NM + 0.03750194775453409*NL - 
        0.006437632755518489*lm*NL + 0.030475521866347787*NH - 
        0.006437632755518489*lm*NH)}, 
     {0.98, CF*NC*(0.0029573629406496734*CF + CA*(-0.21278734340687014 + 
          0.03522435177057524*lm) + 0.030473869770186866*NM - 
        0.0064044275946500435*lm*NM + 0.03734526397326683*NL - 
        0.0064044275946500435*lm*NL + 0.030367003503193813*NH - 
        0.0064044275946500435*lm*NH)}, 
     {0.985, CF*NC*(0.002944491984672299*CF + CA*(-0.21189666330846643 + 
          0.03504402651678024*lm) + 0.030338753607298454*NM - 
        0.0063716411848691356*lm*NM + 0.03718957260628231*NL - 
        0.0063716411848691356*lm*NL + 0.030259199566581022*NH - 
        0.0063716411848691356*lm*NH)}, 
     {0.99, CF*NC*(0.0029311314232595477*CF + CA*(-0.2110108516609584 + 
          0.03486596310880325*lm) + 0.030204744423545066*NM - 
        0.00633926601978241*lm*NM + 0.037034867877198965*NL - 
        0.00633926601978241*lm*NL + 0.03015210318335255*NH - 
        0.00633926601978241*lm*NH)}, 
     {0.995, CF*NC*(0.0029172974525050214*CF + 
        CA*(-0.2101298981677153 + 0.03469012110840984*lm) + 
        0.030071831954222753*NM - 0.0063072947469836075*lm*NM + 
        0.036881143975894884*NL - 0.0063072947469836075*lm*NL + 
        0.030045707562056146*NH - 0.0063072947469836075*lm*NH)}, 
     {1., -2.679183813443073*^-7*CF*NC*(-10835.411693329585*CF - 
        24.*CA*(-32543.149700998507 + 5368.*lm) - 111750.47356459241*NM + 
        23424.*lm*NM - 137088.*NL + 23424.*lm*NL - 111750.47356459241*
         NH + 23424.*lm*NH)}}
 
CbarTable["s", 2, 2] = {{0., -1.6075102880658437*^-7*CF*NC*
       (15.*CA*(-29093.002395114298 + 3898.992508165458*lm + 15840.*lm^2) + 
        2.*(CF*(-609746.3369659903 + 167166.91012706028*lm - 194400.*lm^2) + 
          60.*((-625.7551981765639 + 369.5683520871487*lm - 360.*lm^2)*NM + 
            (-625.7551981765639 + 369.5683520871487*lm - 360.*lm^2)*NL + 
            (-294.90179009708874 + 369.5683520871487*lm - 360.*lm^2)*NH)))}, 
     {0.005, CF*NC*(CA*(0.06104574445209462 - 0.011221302258290166*lm - 
          0.03780575278975277*lm^2) + CF*(0.18698012493535815 - 
          0.05006315713896201*lm + 0.06186395911050453*lm^2) + 
        0.013178391062891634*NM - 0.006708201887856974*lm*NM + 
        0.006873773234500504*lm^2*NM + 0.013178791921067296*NL - 
        0.006708201887856974*lm*NL + 0.006873773234500504*lm^2*NL + 
        0.005620216030284914*NH - 0.006708201887856974*lm*NH + 
        0.006873773234500504*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(0.052119636767134346 - 0.013016124832801833*lm - 
          0.03740592717895398*lm^2) + CF*(0.1783706150720464 - 
          0.04640252343219966*lm + 0.06120969902010651*lm^2) + 
        0.01424175696494796*NM - 0.00628934888172786*lm*NM + 
        0.006801077668900724*lm^2*NM + 0.014246208161793443*NL - 
        0.00628934888172786*lm*NL + 0.006801077668900724*lm^2*NL + 
        0.005550317046814811*NH - 0.00628934888172786*lm*NH + 
        0.006801077668900724*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(0.04349896214263795 - 0.014760190097314751*lm - 
          0.036997541166744585*lm^2) + CF*(0.17030471715332565 - 
          0.04280945352271688*lm + 0.060541431000127495*lm^2) + 
        0.01524216279288379*NM - 0.005877743558082014*lm*NM + 
        0.0067268256666808334*lm^2*NM + 0.015256593087824729*NL - 
        0.005877743558082014*lm*NL + 0.0067268256666808334*lm^2*NL + 
        0.005479477563935692*NH - 0.005877743558082014*lm*NH + 
        0.0067268256666808334*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(0.035238143140889897 - 0.016440121016693933*lm - 
          0.03658252359159277*lm^2) + CF*(0.16279312213227257 - 
          0.03930932814259022*lm + 0.059862311331697254*lm^2) + 
        0.016172632041988568*NM - 0.0054762644479118255*lm*NM + 
        0.006651367925744139*lm^2*NM + 0.016204026020964483*NL - 
        0.0054762644479118255*lm*NL + 0.006651367925744139*lm^2*NL + 
        0.005408055333191111*NH - 0.0054762644479118255*lm*NH + 
        0.006651367925744139*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(0.027362387047372785 - 0.01804825073895666*lm - 
          0.03616242840495083*lm^2) + CF*(0.15581913302143788 - 
          0.035917505573312504*lm + 0.059174882844464996*lm^2) + 
        0.01703089114688277*NM - 0.005086665116376667*lm*NM + 
        0.006574986982718333*lm^2*NM + 0.017086668784661942*NL - 
        0.005086665116376667*lm*NL + 0.006574986982718333*lm^2*NL + 
        0.005336335087250667*NH - 0.005086665116376667*lm*NH + 
        0.006574986982718333*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(0.019881360151768272 - 0.01958023681718895*lm - 
          0.03573854913074057*lm^2) + CF*(0.14935511119769768 - 
          0.03264343280850226*lm + 0.058481262213939116*lm^2) + 
        0.017817092926730595*NM - 0.0047100344271287535*lm*NM + 
        0.006497918023771013*lm^2*NM + 0.017904741155337415*NL - 
        0.0047100344271287535*lm*NL + 0.006497918023771013*lm^2*NL + 
        0.005264550512074061*NH - 0.0047100344271287535*lm*NH + 
        0.006497918023771013*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(0.012795542089579219 - 0.021033870567391064*lm - 
          0.035311983434707095*lm^2) + CF*(0.1433691216180044 - 
          0.029492710742623322*lm + 0.05778324562042979*lm^2) + 
        0.01853276563200746*NM - 0.004347027964373513*lm*NM + 
        0.006420360624492198*lm^2*NM + 0.018659606978588632*NL - 
        0.004347027964373513*lm*NL + 0.006420360624492198*lm^2*NL + 
        0.005192896683453731*NH - 0.004347027964373513*lm*NH + 
        0.006420360624492198*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(0.006099686060637124 - 0.022408388334083658*lm - 
          0.03488367462312507*lm^2) + CF*(0.137828057290981 - 
          0.026468296300130794*lm + 0.057082376656022844*lm^2) + 
        0.019180245834009065*NM - 0.003998002860311252*lm*NM + 
        0.006342486295113649*lm^2*NM + 0.019353290550402493*NL - 
        0.003998002860311252*lm*NL + 0.006342486295113649*lm^2*NL + 
        0.0051215381043947395*NH - 0.003998002860311252*lm*NH + 
        0.006342486295113649*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.00021511335761567496 - 0.023704036557962122*lm - 
          0.03445444050819253*lm^2) + CF*(0.13269921862641706 - 
          0.023571266386922845*lm + 0.05637999355886051*lm^2) + 
        0.019762343702587563*NM - 0.0036631035533406958*lm*NM + 
        0.006264443728762279*lm^2*NM + 0.019988196107854503*NL - 
        0.0036631035533406958*lm*NL + 0.006264443728762279*lm^2*NL + 
        0.005050614334956599*NH - 0.0036631035533406958*lm*NH + 
        0.006264443728762279*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.006160106911776348 - 0.024921780605169586*lm - 
          0.03402499459289468*lm^2) + CF*(0.1279511308304592 - 
          0.02080133269438312*lm + 0.05567726387928221*lm^2) + 
        0.02028213389598964*NM - 0.003342319630473721*lm*NM + 
        0.006186362653253579*lm^2*NM + 0.0205669353385359*NL - 
        0.003342319630473721*lm*NL + 0.006186362653253579*lm^2*NL + 
        0.004980244156843896*NH - 0.003342319630473721*lm*NH + 
        0.006186362653253579*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.01174802071754125 - 0.026063101610526843*lm - 
          0.03359596223594349*lm^2) + CF*(0.12355395649453446 - 
          0.018157203394936445*lm + 0.054975210931543894*lm^2) + 
        0.020742819985970634*NM - 0.0030355265055770843*lm*NM + 
        0.006108356770171543*lm^2*NM + 0.021092217165034833*NL - 
        0.0030355265055770843*lm*NL + 0.006108356770171543*lm^2*NL + 
        0.004910528777817281*NH - 0.0030355265055770843*lm*NH + 
        0.006108356770171543*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.016992462589911633 - 0.02712985035566501*lm - 
          0.03316789335557952*lm^2) + CF*(0.11947968249095617 - 
          0.015636845243390443*lm + 0.0542747345818574*lm^2) + 
        0.021147644469400297*NM - 0.0027425149267074084*lm*NM + 
        0.0060305260646508225*lm^2*NM + 0.021566775581132482*NL - 
        0.0027425149267074084*lm*NL + 0.0060305260646508225*lm^2*NL + 
        0.004841554371418659*NH - 0.0027425149267074084*lm*NH + 
        0.0060305260646508225*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.02190750838546668 - 0.028124139743836894*lm - 
          0.03274127264653702*lm^2) + CF*(0.11570217735177164 - 
          0.013237678019106637*lm + 0.053576627967060586*lm^2) + 
        0.02149982827158952*NM - 0.0024630128904018595*lm*NM + 
        0.0059529586630067315*lm^2*NM + 0.0219933217711167*NL - 
        0.0024630128904018595*lm*NL + 0.0059529586630067315*lm^2*NL + 
        0.004773394136606667*NH - 0.0024630128904018595*lm*NH + 
        0.0059529586630067315*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.026507409758674456 - 0.029048264298086848*lm - 
          0.03231652795061384*lm^2) + CF*(0.11219717344866062 - 
          0.01095672140630774*lm + 0.05288159119191357*lm^2) + 
        0.021802529957771554*NM - 0.002196702215365926*lm*NM + 
        0.005875732354657063*lm^2*NM + 0.02237451224824309*NL - 
        0.002196702215365926*lm*NL + 0.005875732354657063*lm^2*NL + 
        0.004706109998690074*NH - 0.002196702215365926*lm*NH + 
        0.005875732354657063*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.030806386081279568 - 0.029904639103457177*lm - 
          0.03189403721921553*lm^2) + CF*(0.10894220582552173 - 
          0.008790707508460168*lm + 0.05219024272235268*lm^2) + 
        0.022058818446078148*NM - 0.001943231255057661*lm*NM + 
        0.005798915858039187*lm^2*NM + 0.0227129278339225*NL - 
        0.001943231255057661*lm*NL + 0.005798915858039187*lm^2*NL + 
        0.004639754034756652*NH - 0.001943231255057661*lm*NH + 
        0.005798915858039187*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.034818475992692915 - 0.030695753054478924*lm - 
          0.03147413437808193*lm^2) + CF*(0.10591652688004086 - 
          0.006736167967050532*lm + 0.05150312898231588*lm^2) + 
        0.02227165514670317*NM - 0.0017022247552707236*lm*NM + 
        0.005722569886923987*lm^2*NM + 0.02301106011780578*NL - 
        0.0017022247552707236*lm*NL + 0.005722569886923987*lm^2*NL + 
        0.004574369682605455*NH - 0.0017022247552707236*lm*NH + 
        0.005722569886923987*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.038557431946919275 - 0.0314241328220534*lm - 
          0.03105711431991925*lm^2) + CF*(0.10310100868115987 - 
          0.004789501961121844*lm + 0.05082073252350423*lm^2) + 
        0.022443882775122867*NM - 0.0014732915609302834*lm*NM + 
        0.005646748058167137*lm^2*NM + 0.023271303155820853*NL - 
        0.0014732915609302834*lm*NL + 0.005646748058167137*lm^2*NL + 
        0.004509992776257365*NH - 0.0014732915609302834*lm*NH + 
        0.005646748058167137*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.04203664619781132 - 0.032092314975946445*lm - 
          0.030643237193125745*lm^2) + CF*(0.1004780402348802 - 
          0.0029470295872491077*lm + 0.050143479043296676*lm^2) + 
        0.022578218937235883*NM - 0.0012560306771628022*lm*NM + 
        0.005571497671477408*lm^2*NM + 0.023495948873095023*NL - 
        0.0012560306771628022*lm*NL + 0.005571497671477408*lm^2*NL + 
        0.004446652440271145*NH - 0.0012560306771628022*lm*NH + 
        0.005571497671477408*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.04526910002424281 - 0.03270282439158695*lm - 
          0.030232732114513945*lm^2) + CF*(0.09803142424100555 - 
          0.0012050339135895737*lm + 0.04947174346011373*lm^2) + 
        0.02267725314627666*NM - 0.0010500360544750216*lm*NM + 
        0.005496860384457081*lm^2*NM + 0.023687185103158044*NL - 
        0.0010500360544750216*lm*NL + 0.005496860384457081*lm^2*NL + 
        0.004384371867494446*NH - 0.0010500360544750216*lm*NH + 
        0.005496860384457081*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.048267330277124286 - 0.03325815755080174*lm - 
          0.02982580040503955*lm^2) + CF*(0.09574627613523432 + 
          0.0004402058376453146*lm + 0.04880585520824654*lm^2) + 
        0.0227434463121629*NM - 0.0008549003737476787*lm*NM + 
        0.005422872800916282*lm^2*NM + 0.02384709550633032*NL - 
        0.0008549003737476787*lm*NL + 0.005422872800916282*lm^2*NL + 
        0.0043231689994247405*NH - 0.0008549003737476787*lm*NH + 
        0.005422872800916282*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.051043408911897896 - 0.03376076968744071*lm - 
          0.029422618426384117*lm^2) + CF*(0.09360892709145659 + 
          0.0019923881217780064*lm + 0.04814610287953765*lm^2) + 
        0.022779132007470775*NM - 0.0006702180397938816*lm*NM + 
        0.005349566986615294*lm^2*NM + 0.023977660823622546*NL - 
        0.0006702180397938816*lm*NL + 0.005349566986615294*lm^2*NL + 
        0.004263057124353696*NH - 0.0006702180397938816*lm*NH + 
        0.005349566986615294*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.053608932288283374 - 0.03421306497570959*lm - 
          0.029023340080448396*lm^2) + CF*(0.09160683193503957 + 
          0.0034551684923330526*lm + 0.047492738313461014*lm^2) + 
        0.022786518999955492*NM - 0.0004955875436937537*lm*NM + 
        0.00527697092371789*lm^2*NM + 0.02408076107141437*NL - 
        0.0004955875436937537*lm*NL + 0.00527697092371789*lm^2*NL + 
        0.00420404540547607*NH - 0.0004955875436937537*lm*NH + 
        0.00527697092371789*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.0559750178227308 - 0.03461738914058238*lm - 
          0.028628099021835655*lm^2) + CF*(0.08972848244727026 + 
          0.004832143504572744*lm + 0.04684598021754925*lm^2) + 
        0.022767694674503063*NM - 0.000330613318335422*lm*NM + 
        0.005205108913061029*lm^2*NM + 0.024158178387799448*NL - 
        0.000330613318335422*lm*NL + 0.005205108913061029*lm^2*NL + 
        0.004146139348867705*NH - 0.000330613318335422*lm*NH + 
        0.005205108913061029*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.058152306165228825 - 0.03497602400518217*lm - 
          0.02823701062418387*lm^2) + CF*(0.08796332623544674 + 
          0.006126838234130598*lm + 0.04620601738502815*lm^2) + 
        0.022724629063908278*NM - 0.00017490718481934383*lm*NM + 
        0.005134001931669794*lm^2*NM + 0.024211600317433968*NL - 
        0.00017490718481934383*lm*NL + 0.005134001931669794*lm^2*NL + 
        0.004089341219478463*NH - 0.00017490718481934383*lm*NH + 
        0.005134001931669794*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.06015096750525197 - 0.035291183592518954*lm - 
          0.027850173734013297*lm^2) + CF*(0.08630169114608723 + 
          0.007342696723717692*lm + 0.04557301156474903*lm^2) + 
        0.02265917927875758*NM - 0.00002808946708227555*lm*NM + 
        0.005063667951638782*lm^2*NM + 0.02424262337700649*NL - 
        0.00002808946708227555*lm*NL + 0.005063667951638782*lm^2*NL + 
        0.004033650411908178*NH - 0.00002808946708227555*lm*NH + 
        0.005063667951638782*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.06198071093536649 - 0.03556501147742259*lm - 
          0.02746767224007739*lm^2) + CF*(0.08473471507395776 + 
          0.00848307480952665*lm + 0.04494710002921755*lm^2) + 
        0.02257309417929481*NM + 0.00011021016348041408*lm*NM + 
        0.004994122225468616*lm^2*NM + 0.024252756784108254*NL + 
        0.00011021016348041408*lm*NL + 0.004994122225468616*lm^2*NL + 
        0.003979063781640692*NH + 0.00011021016348041408*lm*NH + 
        0.004994122225468616*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.0636507960454575 - 0.035799579145193716*lm - 
          0.027089576481672876*lm^2) + CF*(0.08325428094320154 + 
          0.009551234886462773*lm + 0.04432839787910107*lm^2) + 
        0.022468019171525397*NM + 0.00024035206369769574*lm*NM + 
        0.004925377542122341*lm^2*NM + 0.02424342626246381*NL + 
        0.00024035206369769574*lm*NL + 0.004925377542122341*lm^2*NL + 
        0.003925575941533903*NH + 0.00024035206369769574*lm*NH + 
        0.004925377542122341*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.06517004610678563 - 0.035996885160889044*lm - 
          0.026715944515711274*lm^2) + CF*(0.08185295659289432 + 
          0.010550342255498031*lm + 0.04371700011661845*lm^2) + 
        0.02234550103951601*NM + 0.00036268617437721745*lm*NM + 
        0.00485744445740205*lm^2*NM + 0.024215977859056565*NL + 
        0.00036268617437721745*lm*NL + 0.00485744445740205*lm^2*NL + 
        0.0038731795276524157*NH + 0.00036268617437721745*lm*NH + 
        0.00485744445740205*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.06654686234812102 - 0.0361588549904931*lm - 
          0.026346823259381976*lm^2) + CF*(0.08052393927716696 + 
          0.011483462762917203*lm + 0.043112983515352324*lm^2) + 
        0.02220699274839073*NM + 0.0004775517233731648*lm*NM + 
        0.004790331501705813*lm^2*NM + 0.02417168172567904*NL + 
        0.0004775517233731648*lm*NL + 0.004790331501705813*lm^2*NL + 
        0.0038218654379469524*NH + 0.0004775517233731648*lm*NH + 
        0.004790331501705813*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.06778923893683618 - 0.036287341344870425*lm - 
          0.02598224952279887*lm^2) + CF*(0.0792610044823863 + 
          0.012353561494143737*lm + 0.04251640831003451*lm^2) + 
        0.022053858169723908*NM + 0.0005852770491634799*lm*NM + 
        0.004724045367781612*lm^2*NM + 0.024111735830299626*NL + 
        0.0005852770491634799*lm*NL + 0.004724045367781612*lm^2*NL + 
        0.003771623046803547*NH + 0.0005852770491634799*lm*NH + 
        0.004724045367781612*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.06890477836393646 - 0.036384124941093804*lm - 
          0.025622250944006938*lm^2) + CF*(0.07805845876582387 + 
          0.013163502327264907*lm + 0.04192731972655681*lm^2) + 
        0.02188737669420312*NM + 0.0006861795229080117*lm*NM + 
        0.004658591080728534*lm^2*NM + 0.02403726957341096*NL + 
        0.0006861795229080117*lm*NL + 0.004658591080728534*lm^2*NL + 
        0.0037224403980848746*NH + 0.0006861795229080117*lm*NH + 
        0.004658591080728534*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.0699007069993686 - 0.03645091559481656*lm - 
          0.025266846837047094*lm^2) + CF*(0.07691109632837656 + 
          0.013916048185622842*lm + 0.04134574936971343*lm^2) + 
        0.02170874770655401*NM + 0.0007805655508152522*lm*NM + 
        0.004593972152190381*lm^2*NM + 0.023949347291972872*NL + 
        0.0007805655508152522*lm*NL + 0.004593972152190381*lm^2*NL + 
        0.0036743043789498786*NH + 0.0007805655508152522*lm*NH + 
        0.004593972152190381*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.070783890636892 - 0.0364893535727939*lm - 
          0.024916048962371037*lm^2) + CF*(0.07581415904590386 + 
          0.014613861856644084*lm + 0.04077171648387988*lm^2) + 
        0.021519094905503466*NM + 0.0008687306417774931*lm*NM + 
        0.0045301907204310975*lm^2*NM + 0.023848971639246697*NL + 
        0.0008687306417774931*lm*NL + 0.0045301907204310975*lm^2*NL + 
        0.003627200876453852*NH + 0.0008687306417774931*lm*NH + 
        0.0045301907204310975*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.0715608498895696 - 0.036501011147218446*lm - 
          0.024569862227712066*lm^2) + CF*(0.07476329969800681 + 
          0.015259507266779427*lm + 0.04020522909989247*lm^2) + 
        0.02131947045754985*NM + 0.0009509595277922981*lm*NM + 
        0.00446724767776583*lm^2*NM + 0.02373708683315662*NL + 
        0.0009509595277922981*lm*NL + 0.00446724767776583*lm^2*NL + 
        0.0035811149186896376*NH + 0.0009509595277922981*lm*NH + 
        0.00446724767776583*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.07223777532999189 - 0.03648739430380219*lm - 
          0.024228285326511945*lm^2) + CF*(0.07375454814849626 + 
          0.01585545112104726*lm + 0.03964628507974682*lm^2) + 
        0.021110858977919252*NM + 0.0010275263267877173*lm*NM + 
        0.0044051427866385355*lm^2*NM + 0.023614581769120672*NL + 
        0.0010275263267877173*lm*NL + 0.0044051427866385355*lm^2*NL + 
        0.0035360308020241094*NH + 0.0010275263267877173*lm*NH + 
        0.0044051427866385355*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.0728205422955692 - 0.03644994456396628*lm - 
          0.023891311320146522*lm^2) + CF*(0.07278428024763214 + 
          0.016404064831018465*lm + 0.039094873069330675*lm^2) + 
        0.020894181335629928*NM + 0.001098694739199632*lm*NM + 
        0.004343874785481186*lm^2*NM + 0.023482292995806193*NL + 
        0.001098694739199632*lm*NL + 0.004343874785481186*lm^2*NL + 
        0.0034919322058065104*NH + 0.001098694739199632*lm*NH + 
        0.004343874785481186*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.07331472530005499 - 0.036390040888446246*lm - 
          0.023558928169458194*lm^2) + CF*(0.07184918924195523 + 
          0.01690762666777696*lm + 0.038550973368204317*lm^2) + 
        0.020670298282310613*NM + 0.0011647182710825454*lm*NM + 
        0.0042834414853560356*lm^2*NM + 0.02334100755416249*NL + 
        0.0011647182710825454*lm*NL + 0.0042834414853560356*lm^2*NL + 
        0.003448802295771759*NH + 0.0011647182710825454*lm*NH + 
        0.0042834414853560356*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.07372561200901322 - 0.03630900163536369*lm - 
          0.02323111922047095*lm^2) + CF*(0.07094625949283823 + 
          0.017368324086932844*lm + 0.038014558724407004*lm^2) + 
        0.020440013906524515*NM + 0.0012258404777257417*lm*NM + 
        0.004223839858267445*lm^2*NM + 0.02319146568150434*NL + 
        0.0012258404777257417*lm*NL + 0.004223839858267445*lm^2*NL + 
        0.0034066238172285996*NH + 0.0012258404777257417*lm*NH + 
        0.004223839858267445*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.07405821675007916 - 0.036208086550578854*lm - 
          0.022907863648617237*lm^2) + CF*(0.07007274231952715 + 
          0.01778825618154907*lm + 0.03748559506137366*lm^2) + 
        0.020204078917016907*NM + 0.0012822952227392733*lm*NM + 
        0.004165066117930407*lm^2*NM + 0.023034363383470993*NL + 
        0.0012822952227392733*lm*NL + 0.004165066117930407*lm^2*NL + 
        0.003365379179006272*NH + 0.0012822952227392733*lm*NH + 
        0.004165066117930407*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.07431729354664135 - 0.03608849877209924*lm - 
          0.0225891368653314*lm^2) + CF^2*(0.06922613381104191 + 
          0.01816943622618242*lm + 0.036964042143269565*lm^2) + 
        CF*((0.019963193724820357 + 0.0013343069484041661*lm + 
            0.004107115793696619*lm^2)*NM + (0.022870354877447714 + 
            0.0013343069484041661*lm + 0.004107115793696619*lm^2)*NL + 
          (0.0033250505290316917 + 0.0013343069484041661*lm + 
            0.004107115793696619*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.07450734863017983 - 0.03595138683362039*lm - 
          0.022274910890451048*lm^2) + CF^2*(0.06840415438108721 + 
          0.018513794281388902*lm + 0.03644985418437444*lm^2) + 
        CF*((0.019718011493585094 + 0.0013820909537770177*lm + 
            0.0040499837982638275*lm^2)*NM + (0.022700054911575025 + 
            0.0013820909537770177*lm + 0.0040499837982638275*lm^2)*NL + 
          (0.0032856198223197206 + 0.0013820909537770177*lm + 
            0.0040499837982638275*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.07463265249980784 - 0.03579784665503046*lm - 
          0.0219651546935065*lm^2) + CF^2*(0.06760473006595923 + 
          0.018823179833207505*lm + 0.03594298040755609*lm^2) + 
        CF*((0.01946914081696607 + 0.0014258536776238693*lm + 
            0.003993664489728455*lm^2)*NM + (0.022524040963834254 + 
            0.0014258536776238693*lm + 0.003993664489728455*lm^2)*NL + 
          (0.0032470688820803355 + 0.0014258536776238693*lm + 
            0.003993664489728455*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.0746972514466965 - 0.03562892351001525*lm - 
          0.021659834506661174*lm^2) + CF^2*(0.06682597526487365 + 
          0.019099364446481176*lm + 0.03544336555635465*lm^2) + 
        CF*((0.01921714843144103 + 0.0014657929837506001*lm + 
            0.00393815172848385*lm^2)*NM + (0.02234285532592568 + 
            0.0014657929837506001*lm + 0.00393815172848385*lm^2)*NL + 
          (0.0032093794545767964 + 0.0014657929837506001*lm + 
            0.00393815172848385*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.07470497860431087 - 0.03544561396282906*lm - 
          0.021358914111786923*lm^2) + CF^2*(0.06606617691125558 + 
          0.01934404441453568*lm + 0.03495095036474224*lm^2) + 
        CF*((0.018962561702985124 + 0.0015020984467124417*lm + 
            0.003883438929415804*lm^2)*NM + (0.022157007076778343 + 
            0.0015020984467124417*lm + 0.003883438929415804*lm^2)*NL + 
          (0.0031725332583070133 + 0.0015020984467124417*lm + 
            0.003883438929415804*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.07465946451292425 - 0.035248867767913625*lm - 
          0.02106235510391193*lm^2) + CF^2*(0.06532377992226092 + 
          0.019558843390827977*lm + 0.034465671988219516*lm^2) + 
        CF*((0.018705870990363804 + 0.0015349516362360802*lm + 
            0.003829519109802169*lm^2)*NM + (0.021966973950572146 + 
            0.0015349516362360802*lm + 0.003829519109802169*lm^2)*NL + 
          (0.0031365120280256536 + 0.0015349516362360802*lm + 
            0.003829519109802169*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.07456414721224426 - 0.035039589727401746*lm - 
          0.020770117133060793*lm^2) + CF^2*(0.06459737382891144 + 
          0.019745314990787046*lm + 0.033987464399554024*lm^2) + 
        CF*((0.018447531876760796 + 0.0015645263989845972*lm + 
            0.0037763849332837804*lm^2)*NM + (0.021773204104132672 + 
            0.0015645263989845972*lm + 0.0037763849332837804*lm^2)*NL + 
          (0.0031012975540743435 + 0.0015645263989845972*lm + 
            0.0037763849332837804*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.07442228187476672 - 0.034818641502678056*lm - 
          0.02048215812631299*lm^2) + CF^2*(0.0638856804916535 + 
          0.01990494535427859*lm + 0.03351625875214853*lm^2) + 
        CF*((0.01818796727603541 + 0.0015909891365467224*lm + 
            0.0037240287502387256*lm^2)*NM + (0.021576117788491802 + 
            0.0015909891365467224*lm + 0.0037240287502387256*lm^2)*NL + 
          (0.003066871717445744 + 0.0015909891365467224*lm + 
            0.0037240287502387256*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.07423694999362726 - 0.03458684337712043*lm - 
          0.020198434491733676*lm^2) + CF^2*(0.0631875428136217 + 
          0.020039155660993145*lm + 0.033051983713746014*lm^2) + 
        CF*((0.01792756941976139 + 0.0016144990787446826*lm + 
            0.003672442634860668*lm^2)*NM + (0.02137610892930474 + 
            0.0016144990787446826*lm + 0.003672442634860668*lm^2)*NL + 
          (0.0030332165209651036 + 0.0016144990787446826*lm + 
            0.003672442634860668*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.07401106813976943 - 0.03434497596794217*lm - 
          0.019918901305677302*lm^2) + CF^2*(0.06250191437130918 + 
          0.02014930459263818*lm + 0.03259456577292649*lm^2) + 
        CF*((0.017666701731089716 + 0.0016352085515352333*lm + 
            0.003621618419214055*lm^2)*NM + (0.021173546620685893 + 
            0.0016352085515352333*lm + 0.003621618419214055*lm^2)*NL + 
          (0.0030003141169399304 + 0.0016352085515352333*lm + 
            0.003621618419214055*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.07374739630368793 - 0.03409378188572017*lm - 
          0.019643512484827364*lm^2) + CF^2*(0.06182784988860045 + 
          0.02023669073715207*lm + 0.0321439295206266*lm^2) + 
        CF*((0.01740570059126517 + 0.0016532632389312189*lm + 
            0.0035715477245140664*lm^2)*NM + (0.0209687765368794 + 
            0.0016532632389312189*lm + 0.0035715477245140664*lm^2)*NL + 
          (0.0029681468315955768 + 0.0016532632389312189*lm + 
            0.0035715477245140664*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.073448545837381 - 0.033833967340749886*lm - 
          0.01937222094421253*lm^2) + CF^2*(0.06116449648622018 + 
          0.020302554931288706*lm + 0.03169999790871141*lm^2) + 
        CF*((0.01714487700444309 + 0.0016688024385003856*lm + 
            0.003522221989856824*lm^2)*NM + (0.020762122266020935 + 
            0.0016688024385003856*lm + 0.003522221989856824*lm^2)*NL + 
          (0.002936697186586265 + 0.0016688024385003856*lm + 
            0.003522221989856824*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.07311698701223071 - 0.0335662036958293*lm - 
          0.01910497874232924*lm^2) + CF^2*(0.060511085644077645 + 
          0.02034808253887684*lm + 0.031262692487447855*lm^2) + 
        CF*((0.016884518166236095 + 0.0016819593101076514*lm + 
            0.0034736324986053167*lm^2)*NM + (0.020553886570080362 + 
            0.0016819593101076514*lm + 0.0034736324986053167*lm^2)*NL + 
          (0.002905947917845156 + 0.0016819593101076514*lm + 
            0.0034736324986053167*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.07275505620844645 - 0.03329112896545696*lm - 
          0.018841737214401588*lm^2) + CF^2*(0.0598669258189446 + 
          0.020374405662863884*lm + 0.030831933623566236*lm^2) + 
        CF*((0.016624888941193725 + 0.0016928611176595752*lm + 
            0.0034257704026184705*lm^2)*NM + (0.020344352574903204 + 
            0.0016928611176595752*lm + 0.0034257704026184705*lm^2)*NL + 
          (0.002875881992013911 + 0.0016928611176595752*lm + 
            0.0034257704026184705*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.07236496275146882 - 0.033009349261744904*lm - 
          0.01858244709471991*lm^2) + CF^2*(0.059231395664388974 + 
          0.02038260528993248*lm + 0.030407640700450763*lm^2) + 
        CF*((0.01636623325420616 + 0.001701629463687854*lm + 
            0.0033786267444945294*lm^2)*NM + (0.02013378489409593 + 
            0.001701629463687854*lm + 0.0033786267444945294*lm^2)*NL + 
          (0.0028464826206709318 + 0.001701629463687854*lm + 
            0.0033786267444945294*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.0719487954103632 - 0.0327214401876062*lm - 
          0.018327058628918966*lm^2) + CF^2*(0.05860393780392639 + 
          0.020373713367047717*lm + 0.0299897323018674*lm^2) + 
        CF*((0.016108775400574964 + 0.0017083805166744242*lm + 
            0.0033321924779852667*lm^2)*NM + (0.01992243069032751 + 
            0.0017083805166744242*lm + 0.0033321924779852667*lm^2)*NL + 
          (0.0028177332725583923 + 0.0017083805166744242*lm + 
            0.0033321924779852667*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.07150852857271331 - 0.03242794817798765*lm - 
          0.018075521676983567*lm^2) + CF^2*(0.05798405311188957 + 
          0.02034871480976987*lm + 0.029578126380518564*lm^2) + 
        CF*((0.01585272127929382 + 0.0017132252310759378*lm + 
            0.003286458486724285*lm^2)*NM + (0.019710520677449456 + 
            0.0017132252310759378*lm + 0.003286458486724285*lm^2)*NL + 
          (0.002789617683990802 + 0.0017132252310759378*lm + 
            0.003286458486724285*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.07104602810991492 - 0.03212939179008827*lm - 
          0.01782778580770366*lm^2) + CF^2*(0.05737129545966496 + 
          0.020308549442565098*lm + 0.029172740412605987*lm^2) + 
        CF*((0.015598259553838109 + 0.0017162695600515666*lm + 
            0.003241415601400665*lm^2)*NM + (0.019498270066669952 + 
            0.0017162695600515666*lm + 0.003241415601400665*lm^2)*NL + 
          (0.0027621198676121717 + 0.0017162695600515666*lm + 
            0.003241415601400665*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.07056305694606374 - 0.031826262943639445*lm - 
          0.017583800385240936*lm^2) + CF^2*(0.05676526688769112 + 
          0.020254113871676405*lm + 0.02877349153948517*lm^2) + 
        CF*((0.015345562744566705 + 0.001717614660936542*lm + 
            0.0031970546154983523*lm^2)*NM + (0.019285879459855177 + 
            0.001717614660936542*lm + 0.0031970546154983523*lm^2)*NL + 
          (0.0027352241196540368 + 0.001717614660936542*lm + 
            0.0031970546154983523*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.07006128034295783 - 0.03151902811242883*lm - 
          0.017343514648414843*lm^2) + CF^2*(0.05616561316621518 + 
          0.020186263291388895*lm + 0.028380296697406108*lm^2) + 
        CF*((0.015094788256605126 + 0.0017173570935356901*lm + 
            0.00315336629971179*lm^2)*NM + (0.019073535692874004 + 
            0.0017173570935356901*lm + 0.00315336629971179*lm^2)*NL + 
          (0.0027089150258345048 + 0.0017173570935356901*lm + 
            0.00315336629971179*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.06954220220584144 - 0.031208129468331142*lm - 
          0.017106877783266344*lm^2) + CF^2*(0.05557188229575498 + 
          0.02010581322474576*lm + 0.027993072736254017*lm^2) + 
        CF*((0.014846079346912715 + 0.0017155890113374178*lm + 
            0.003110341415139335*lm^2)*NM + (0.018861412631750445 + 
            0.0017155890113374178*lm + 0.003110341415139335*lm^2)*NL + 
          (0.002683177466025271 + 0.0017155890113374178*lm + 
            0.003110341415139335*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.06900745500119142 - 0.030893985979169425*lm - 
          0.016873838989413*lm^2) + CF^2*(0.05498409107510174 + 
          0.02001354119995123*lm + 0.027611736528130367*lm^2) + 
        CF*((0.014599566033987045 + 0.0017123983457699443*lm + 
            0.0030679707253478184*lm^2)*NM + (0.018649671924242637 + 
            0.0017123983457699443*lm + 0.0030679707253478184*lm^2)*NL + 
          (0.0026579966178039037 + 0.0017123983457699443*lm + 
            0.0030679707253478184*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.06845836078744189 - 0.030576994461772523*lm - 
          0.016644347540667886*lm^2) + CF^2*(0.05440183468722386 + 
          0.019910188363840436*lm + 0.027236205066547448*lm^2) + 
        CF*((0.014355365953543383 + 0.0017078689836387995*lm + 
            0.003026245007394161*lm^2)*NM + (0.018438463709327384 + 
            0.0017078689836387995*lm + 0.003026245007394161*lm^2)*NL + 
          (0.002633357958997983 + 0.0017078689836387995*lm + 
            0.003026245007394161*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.0678962423491963 - 0.030257530591622554*lm - 
          0.016418352840357437*lm^2) + CF^2*(0.05382489723589041 + 
          0.019796461033908985*lm + 0.02686639555694853*lm^2) + 
        CF*((0.01411358516323908 + 0.0017020809378982477*lm + 
            0.00298515506188317*lm^2)*NM + (0.01822792728693584 + 
            0.0017020809378982477*lm + 0.00298515506188317*lm^2)*NL + 
          (0.002609247269318862 + 0.0017020809378982477*lm + 
            0.00298515506188317*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.06732234756834618 - 0.029935949870500748*lm - 
          0.016195804471739354*lm^2) + CF^2*(0.05325308945453702 + 
          0.01967303219048124*lm + 0.026502225499209848*lm^2) + 
        CF*((0.013874318899428365 + 0.0016951105119199553*lm + 
            0.0029446917221344275*lm^2)*NM + (0.01801819175015844 + 
            0.0016951105119199553*lm + 0.0029446917221344275*lm^2)*NL + 
          (0.0025856506311748386 + 0.0016951105119199553*lm + 
            0.0029446917221344275*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.06673785330595113 - 0.02961258855354492*lm - 
          0.01597665224389027*lm^2) + CF^2*(0.05268624609256072 + 
          0.019540542910660538*lm + 0.026143612762729532*lm^2) + 
        CF*((0.013637652288710013 + 0.0016870304574302538*lm + 
            0.002904845862525504*lm^2)*NM + (0.01780937658201586 + 
            0.0016870304574302538*lm + 0.002904845862525504*lm^2)*NL + 
          (0.002562554429745285 + 0.0016870304574302538*lm + 
            0.002904845862525504*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.06614386908676902 - 0.029287764537127448*lm - 
          0.01576084623340448*lm^2) + CF^2*(0.05212422352292102 + 
          0.019399603745749203*lm + 0.025790475654661874*lm^2) + 
        CF*((0.013403661016900562 + 0.0016779101262932102*lm + 
            0.0028656084060735415*lm^2)*NM + (0.01760159221877734 + 
            0.0016779101262932102*lm + 0.0028656084060735415*lm^2)*NL + 
          (0.0025399453523911337 + 0.0016779101262932102*lm + 
            0.0028656084060735415*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.06554144059629143 - 0.02896177820895129*lm - 
          0.015548336822218718*lm^2) + CF^2*(0.05156689755332583 + 
          0.01925079604385501*lm + 0.025442732981812446*lm^2) + 
        CF*((0.013172411957904296 + 0.0016678156163206967*lm + 
            0.002826970331312494*lm^2)*NM + (0.017394940581698135 + 
            0.0016678156163206967*lm + 0.002826970331312494*lm^2)*NL + 
          (0.002517810387470425 + 0.0016678156163206967*lm + 
            0.002826970331312494*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.0649315529996882 - 0.028634913261744208*lm - 
          0.015339074731854101*lm^2) + CF^2*(0.051014161424692284 + 
          0.019094673219415745*lm + 0.025100304106670347*lm^2) + 
        CF*((0.012943963764800689 + 0.0016568099112930393*lm + 
            0.0027889226785189273*lm^2)*NM + (0.017189515578943798 + 
            0.0016568099112930393*lm + 0.0027889226785189273*lm^2)*NL + 
          (0.0024961368226202514 + 0.0016568099112930393*lm + 
            0.0027889226785189273*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.06431513409160527 - 0.028307437471908965*lm - 
          0.015133011054344172*lm^2) + CF^2*(0.05046592398182982 + 
          0.01893176197137687*lm + 0.024763108998017737*lm^2) + 
        CF*((0.012718367425408165 + 0.0016449530153748793*lm + 
            0.002751456555335304*lm^2)*NM + (0.016985403579370454 + 
            0.0016449530153748793*lm + 0.002751456555335304*lm^2)*NL + 
          (0.002474912242565993 + 0.0016449530153748793*lm + 
            0.002751456555335304*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.06369305728536188 - 0.02797960344446123*lm - 
          0.01493009728009784*lm^2) + CF^2*(0.04992210800253459 + 
          0.01876256345175121*lm + 0.024431068276523738*lm^2) + 
        CF*((0.01249566678437173 + 0.001632302082110806*lm + 
            0.002714563141835971*lm^2)*NM + (0.01678268385973686 + 
            0.001632302082110806*lm + 0.002714563141835971*lm^2)*NL + 
          (0.0024541245265061475 + 0.001632302082110806*lm + 
            0.002714563141835971*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.0630661444496667 - 0.027651649325557512*lm - 
          0.014730285322927372*lm^2) + CF^2*(0.04938264867234807 + 
          0.01858755438627515*lm + 0.024104103255699335*lm^2) + 
        CF*((0.012275899033692864 + 0.0016189115381842882*lm + 
            0.0026782336950777036*lm^2)*NM + (0.01658142902683564 + 
            0.0016189115381842882*lm + 0.0026782336950777036*lm^2)*NL + 
          (0.002433761845124884 + 0.0016189115381842882*lm + 
            0.0026782336950777036*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.062435168600586274 - 0.027323799483883627*lm - 
          0.01453352754245442*lm^2) + CF^2*(0.04884749219325246 + 
          0.018407188148854878*lm + 0.023782135978561776*lm^2) + 
        CF*((0.012059095173573333 + 0.00160483320212162*lm + 
            0.0026424595531735306*lm^2)*NM + (0.01638170541594759 + 
            0.00160483320212162*lm + 0.0026424595531735306*lm^2)*NL + 
          (0.002413812657272556 + 0.00160483320212162*lm + 
            0.0026424595531735306*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.061800856456086795 - 0.02699626516214064*lm - 
          0.014339776764091393*lm^2) + CF^2*(0.04831659451543602 + 
          0.01822189579146968*lm + 0.02346508925033137*lm^2) + 
        CF*((0.011845280445448088 + 0.0015901163981201245*lm + 
            0.002607232138925708*lm^2)*NM + (0.016183573466943883 + 
            0.0015901163981201245*lm + 0.002607232138925708*lm^2)*NL + 
          (0.002394265706358585 + 0.0015901163981201245*lm + 
            0.002607232138925708*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.061163890860207556 - 0.026669245099830142*lm - 
          0.01414898629678084*lm^2) + CF^2*(0.047789920182312005 + 
          0.0180320870311683*lm + 0.023152886667459557*lm^2) + 
        CF*((0.011634474738465274 + 0.0015748080651768563*lm + 
            0.002572542963051062*lm^2)*NM + (0.015987088079286386 + 
            0.0015748080651768563*lm + 0.002572542963051062*lm^2)*NL + 
          (0.002375110016489035 + 0.0015748080651768563*lm + 
            0.002572542963051062*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.06052491308340537 - 0.026342926128504744*lm - 
          0.013961109948662204*lm^2) + CF^2*(0.04726744127941677 + 
          0.017838151195759645*lm + 0.022845452643265422*lm^2) + 
        CF*((0.011426692971517546 + 0.0015589528616906006*lm + 
            0.0025383836270294917*lm^2)*NM + (0.015792298947105755 + 
            0.0015589528616906006*lm + 0.0025383836270294917*lm^2)*NL + 
          (0.0023563348883857585 + 0.0015589528616906006*lm + 
            0.0025383836270294917*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.05988452500547481 - 0.0260174837406131*lm - 
          0.0137761020408229*lm^2) + CF^2*(0.046749136478928324 + 
          0.017640458129761807*lm + 0.022542712430437473*lm^2) + 
        CF*((0.011221945451754332 + 0.0015425932657061737*lm + 
            0.0025047458256041637*lm^2)*NM + (0.015599250875470504 + 
            0.0015425932657061737*lm + 0.0025047458256041637*lm^2)*NL + 
          (0.0023379298951166617 + 0.0015425932657061737*lm + 
            0.0025047458256041637*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.05924329118698185 - 0.0256930826330319*lm - 
          0.013593917419279265*lm^2) + CF^2*(0.046234990171912 + 
          0.01743935906213353*lm + 0.022244592140638796*lm^2) + 
        CF*((0.01102023821124835 + 0.00152576967096597*lm + 
            0.0024716213489598664*lm^2)*NM + (0.015407984078897256 + 
            0.00152576967096597*lm + 0.0024716213489598664*lm^2)*NL + 
          (0.002319884877664068 + 0.00152576967096597*lm + 
            0.0024716213489598664*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.05860174083492227 - 0.025369877226340317*lm - 
          0.013414511465322375*lm^2) + CF^2*(0.0457249916811633 + 
          0.017235187437270934*lm + 0.021951018761436614*lm^2) + 
        CF*((0.010821573322994993 + 0.0015085204789294256*lm + 
            0.002439002084604068*lm^2)*NM + (0.015218534463093236 + 
            0.0015085204789294256*lm + 0.002439002084604068*lm^2)*NL + 
          (0.0023021899403587102 + 0.0015085204789294256*lm + 
            0.002439002084604068*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.057960369667999195 - 0.025048012160855684*lm - 
          0.013237840104354014*lm^2) + CF^2*(0.04521913454802519 + 
          0.017028259710709884*lm + 0.021661920170761115*lm^2) + 
        CF*((0.010625949197506902 + 0.001490882186916633*lm + 
            0.002406880018973457*lm^2)*NM + (0.015030933890865992 + 
            0.001490882186916633*lm + 0.002406880018973457*lm^2)*NL + 
          (0.002284835446200078 + 0.001490882186916633*lm + 
            0.002406880018973457*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.057319641686656986 - 0.024727622770412634*lm - 
          0.013063859813329002*lm^2) + CF^2*(0.044717415887111145 + 
          0.016818876110930994*lm + 0.02137722514908382*lm^2) + 
        CF*((0.010433360861097524 + 0.0014728894725278172*lm + 
            0.0023752472387870913*lm^2)*NM + (0.01484521043308262 + 
            0.0014728894725278172*lm + 0.0023752472387870913*lm^2)*NL + 
          (0.0022678120120854448 + 0.0014728894725278172*lm + 
            0.0023752472387870913*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.056679990852732315 - 0.02440883553483219*lm - 
          0.012892527626911813*lm^2) + CF^2*(0.044219835803313824 + 
          0.01660732136862055*lm + 0.021096863389492057*lm^2) + 
        CF*((0.01024380021697504 + 0.0014545752744857636*lm + 
            0.0023440959321657843*lm^2)*NM + (0.014661388605510979 + 
            0.0014545752744857636*lm + 0.0023440959321657843*lm^2)*NL + 
          (0.0022511105039698634 + 0.0014545752744857636*lm + 
            0.0023440959321657843*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.05604182268334517 - 0.024091768511991733*lm - 
          0.01272380114244767*lm^2) + CF^2*(0.043726396865941354 + 
          0.016393865414696885*lm + 0.02082076550582346*lm^2) + 
        CF*((0.01005725629013291 + 0.0014359708700436638*lm + 
            0.00231341838953594*lm^2)*NM + (0.0144794895923284 + 
            0.0014359708700436638*lm + 0.00231341838953594*lm^2)*NL + 
          (0.002234722031964985 + 0.0014359708700436638*lm + 
            0.00231341838953594*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.05540551576341501 - 0.023776531750372303*lm - 
          0.01255763852384112*lm^2) + CF^2*(0.04323710363522794 + 
          0.016178764048367857*lm + 0.02054886303901274*lm^2) + 
        CF*((0.009873715456990801 + 0.0014171059490961928*lm + 
            0.002283207004334749*lm^2)*NM + (0.014299531457039143 + 
            0.0014171059490961928*lm + 0.002283207004334749*lm^2)*NL + 
          (0.0022186379454067454 + 0.0014171059490961928*lm + 
            0.002283207004334749*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.054771423180947534 - 0.02346322768292575*lm - 
          0.012393998504428504*lm^2) + CF^2*(0.04275196223680982 + 
          0.015962259576441786*lm + 0.020281088461792097*lm^2) + 
        CF*((0.009693161660747041 + 0.0013980086851270116*lm + 
            0.002253454273532455*lm^2)*NM + (0.014121529341500093 + 
            0.0013980086851270116*lm + 0.002253454273532455*lm^2)*NL + 
          (0.0022028498278923326 + 0.0013980086851270116*lm + 
            0.002253454273532455*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.05413987388906873 - 0.023151951503071228*lm - 
          0.0122328403889246*lm^2) + CF^2*(0.04227097998019257 + 
          0.015744581425071204*lm + 0.020017375181876615*lm^2) + 
        CF*((0.009515576613103842 + 0.0013787058031213078*lm + 
            0.0022241527979862904*lm^2)*NM + (0.013945495653714833 + 
            0.0013787058031213078*lm + 0.0022241527979862904*lm^2)*NL + 
          (0.0021873494923078593 + 0.0013787058031213078*lm + 
            0.0022241527979862904*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.053511173998504497 - 0.022842791523598402*lm - 
          0.012074124054517958*lm^2) + CF^2*(0.04179416501740327 + 
          0.015525946725066537*lm + 0.01975765754375666*lm^2) + 
        CF*((0.009340939983482432 + 0.001359222644567455*lm + 
            0.0021952952826396286*lm^2)*NM + (0.013771440245019098 + 
            0.001359222644567455*lm + 0.0021952952826396286*lm^2)*NL + 
          (0.0021721289758553095 + 0.001359222644567455*lm + 
            0.0021952952826396286*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.05288560800409448 - 0.0225358295192235*lm - 
          0.011917809951184242*lm^2) + CF^2*(0.041321526038480196 + 
          0.01530656087187524*lm + 0.01950187082921058*lm^2) + 
        CF*((0.00916922957611873 + 0.0013395832296674234*lm + 
            0.002166874536578953*lm^2)*NM + (0.013599370577245617 + 
            0.0013395832296674234*lm + 0.002166874536578953*lm^2)*NL + 
          (0.0021571805350956577 + 0.0013395832296674234*lm + 
            0.002166874536578953*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.05226343994868666 - 0.02223114105351401*lm - 
          0.011763859101281903*lm^2) + CF^2*(0.040853072000605214 + 
          0.015086618061281299*lm + 0.019249951256643114*lm^2) + 
        CF*((0.009000421496012925 + 0.001319810316871198*lm + 
            0.0021388834729603456*lm^2)*NM + (0.013429291880423364 + 
            0.001319810316871198*lm + 0.0021388834729603456*lm^2)*NL + 
          (0.002142496640994671 + 0.001319810316871198*lm + 
            0.0021388834729603456*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.051644914527617325 - 0.021928795790868552*lm - 
          0.01161223309849001*lm^2) + CF^2*(0.040388811887996576 + 
          0.014866301801840178*lm + 0.01900183597934729*lm^2) + 
        CF*((0.008834490304250186 + 0.001299925459846181*lm + 
            0.0021113151088163655*lm^2)*NM + (0.013261207301535124 + 
            0.001299925459846181*lm + 0.0021113151088163655*lm^2)*NL + 
          (0.0021280699740219666 + 0.001299925459846181*lm + 
            0.0021113151088163655*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.05103025813679719 - 0.021628857794210046*lm - 
          0.011462894106143826*lm^2) + CF^2*(0.03992875449987169 + 
          0.01464578540502555*lm + 0.018757463082780805*lm^2) + 
        CF*((0.008671409163450324 + 0.0012799490619883796*lm + 
            0.002084162564753423*lm^2)*NM + (0.013095118044827917 + 
            0.0012799490619883796*lm + 0.002084162564753423*lm^2)*NL + 
          (0.0021138934192656477 + 0.0012799490619883796*lm + 
            0.002084162564753423*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.05041967986728648 - 0.021331385809022805*lm - 
          0.011315804855019733*lm^2) + CF^2*(0.0394729082640385 + 
          0.014425232454026396*lm + 0.01851677158094138*lm^2) + 
        CF*((0.008511149973682292 + 0.0012599004285780925*lm + 
            0.0020574190645490423*lm^2)*NM + (0.012931023504143206 + 
            0.0012599004285780925*lm + 0.0020574190645490423*lm^2)*NL + 
          (0.002099960061599007 + 0.0012599004285780925*lm + 
            0.0020574190645490423*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.049813372449075626 - 0.021036433534337873*lm - 
          0.011170928640617524*lm^2) + CF^2*(0.03902128107383334 + 
          0.014204797252096371*lm + 0.018279701411919584*lm^2) + 
        CF*((0.008353683499795341 + 0.0012397978166788638*lm + 
            0.002031077934657732*lm^2)*NM + (0.0127689213877077 + 
            0.0012397978166788638*lm + 0.002031077934657732*lm^2)*NL + 
          (0.0020862631808937823 + 0.0012397978166788638*lm + 
            0.002031077934657732*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.04921151314666636 - 0.020744049881245265*lm - 
          0.011028229319984633*lm^2) + CF^2*(0.03857388014634186 + 
          0.01398462525132172*lm + 0.018046193432702126*lm^2) + 
        CF*((0.008198979490295143 + 0.001219658482874596*lm + 
            0.0020051326036335695*lm^2)*NM + (0.012608807835800965 + 
            0.001219658482874596*lm + 0.0020051326036335695*lm^2)*NL + 
          (0.002072796247288961 + 0.001219658482874596*lm + 
            0.0020051326036335695*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.04861426460889523 - 0.020454279219487264*lm - 
          0.010887671308123724*lm^2) + CF^2*(0.038130711899966245 + 
          0.013764853462639524*lm + 0.017816189413293368*lm^2) + 
        CF*((0.008047006788490414 + 0.001199498728935996*lm + 
            0.0019795766014770407*lm^2)*NM + (0.01245067753169289 + 
            0.001199498728935996*lm + 0.0019795766014770407*lm^2)*NL + 
          (0.002059552916508086 + 0.001199498728935996*lm + 
            0.0019795766014770407*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.04802177567533544 - 0.02016716161266323*lm - 
          0.010749219574022143*lm^2) + CF^2*(0.03769178184959708 + 
          0.013545610847904711*lm + 0.017589632030218055*lm^2) + 
        CF*((0.007897733436309009 + 0.001179333945503893*lm + 
            0.001954403558913117*lm^2)*NM + (0.012294523806222143 + 
            0.001179333945503893*lm + 0.001954403558913117*lm^2)*NL + 
          (0.002046527025265756 + 0.001179333945503893*lm + 
            0.001954403558913117*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.047434182141472575 - 0.019882733042553665*lm - 
          0.01061283963633896*lm^2) + CF^2*(0.03725709451774811 + 
          0.013327018694771849*lm + 0.017366464859463752*lm^2) + 
        CF*((0.007751126771213046 + 0.0011591786538734691*lm + 
            0.0019296072066070837*lm^2)*NM + (0.012140338736366144 + 
            0.0011591786538734691*lm + 0.0019296072066070837*lm^2)*NL + 
          (0.0020337125867039025 + 0.0011591786538734691*lm + 
            0.0019296072066070837*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.046851607484757835 - 0.01960102562304931*lm - 
          0.010478497558782813*lm^2) + CF^2*(0.03682665336018672 + 
          0.013109190975126674*lm + 0.017146632368917333*lm^2) + 
        CF*((0.007607153516626725 + 0.0011390465459600503*lm + 
            0.001905181374324148*lm^2)*NM + (0.011988113238133624 + 
            0.0011390465459600503*lm + 0.001905181374324148*lm^2)*NL + 
          (0.0020211037859284263 + 0.0011390465459600503*lm + 
            0.001905181374324148*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.04627416355351396 - 0.01932206780415011*lm - 
          0.010346159945211398*lm^2) + CF^2*(0.03640046070467159 + 
          0.01289223468777211*lm + 0.016930079910345924*lm^2) + 
        CF*((0.007465779866278077 + 0.0011189505225238285*lm + 
            0.0018811199900384359*lm^2)*NM + (0.01183783715409245 + 
            0.0011189505225238285*lm + 0.0018811199900384359*lm^2)*NL + 
          (0.0020086949755978435 + 0.0011189505225238285*lm + 
            0.0018811199900384359*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.045701951220583105 - 0.019045884566478623*lm - 
          0.010215793934481195*lm^2) + CF^2*(0.03597851770155312 + 
          0.01267625018604451*lm + 0.01671675371096923*lm^2) + 
        CF*((0.007326971562807516 + 0.0010989027297277376*lm + 
            0.0018574170789965809*lm^2)*NM + (0.01168949933582813 + 
            0.0010989027297277376*lm + 0.0018574170789965809*lm^2)*NL + 
          (0.001996480671597063 + 0.0010989027297277376*lm + 
            0.0018574170789965809*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.04513506258989378 - 0.018772497203347772*lm - 
          0.010087367338729567*lm^2) + CF*(0.03556081383381524 + 
          0.012461330570918049*lm + 0.01650660109973929*lm^2) + 
        0.007190694678619835*NM + 0.0010789144875142408*lm*NM + 
        0.001834066788859921*lm^2*NM + 0.011543088213280072*NL + 
        0.0010789144875142408*lm*NL + 0.001834066788859921*lm^2*NL + 
        0.0019844555886362257*NH + 0.0010789144875142408*lm*NH + 
        0.001834066788859921*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.04457357494885853 - 0.01850192518851134*lm - 
          0.009960848036226572*lm^2) + CF*(0.03514737065073918 + 
          0.012247565846211787*lm + 0.016299569513825298*lm^2) + 
        0.007056912722217203*NM + 0.0010589967696934338*lm*NM + 
        0.0018110632793139222*lm^2*NM + 0.01139858980997307*NL + 
        0.0010589967696934338*lm*NL + 0.0018110632793139222*lm^2*NL + 
        0.00197261446921011*NH + 0.0010589967696934338*lm*NH + 
        0.0018110632793139222*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.04401756176716543 - 0.018234183677818473*lm - 
          0.0098362049132917*lm^2) + CF*(0.034738172814026434 + 
          0.012035037125596487*lm + 0.016095608039931875*lm^2) + 
        0.006925591364589676*NM + 0.0010391595317342046*lm*NM + 
        0.0017884008933257637*lm^2*NM + 0.011255991051871693*NL + 
        0.0010391595317342046*lm*NL + 0.0017884008933257637*lm^2*NL + 
        0.00196095234232738*NH + 0.0010391595317342046*lm*NH + 
        0.0017884008933257637*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.04346708589911603 - 0.01796928554686452*lm - 
          0.00971340719232482*lm^2) + CF*(0.034333216530227 + 
          0.011823821183140822*lm + 0.01589466631471334*lm^2) + 
        0.00679669522303935*NM + 0.0010194122367431777*lm*NM + 
        0.0017660740349681491*lm^2*NM + 0.01111527755649878*NL + 
        0.0010194122367431777*lm*NL + 0.0017660740349681491*lm^2*NL + 
        0.0019494643347918556*NH + 0.0010194122367431777*lm*NH + 
        0.0017660740349681491*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.0429222020236384 - 0.0177072410459598*lm - 
          0.009592424602233465*lm^2) + CF*(0.033932496711976255 + 
          0.011613989580255469*lm + 0.01569669480365476*lm^2) + 
        0.006670188782819852*NM + 0.000999763753294038*lm*NM + 
        0.0017440772004060846*lm^2*NM + 0.010976434296346932*NL + 
        0.000999763753294038*lm*NL + 0.0017440772004060846*lm^2*NL + 
        0.0019381457161903694*NH + 0.000999763753294038*lm*NH + 
        0.0017440772004060846*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.04238295712063695 - 0.01744805794610802*lm - 
          0.009473227372257089*lm^2) + CF*(0.03353600698018675 + 
          0.011405608915744509*lm + 0.015501644790966145*lm^2) + 
        0.0065460364477976625*NM + 0.000980222383398165*lm*NM + 
        0.0017224049767740161*lm^2*NM + 0.010839445656200191*NL + 
        0.000980222383398165*lm*NL + 0.0017224049767740161*lm^2*NL + 
        0.0019269918950300838*NH + 0.000980222383398165*lm*NH + 
        0.0017224049767740161*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.041849390922848964 - 0.017191741678099712*lm - 
          0.009355786225695028*lm^2) + CF*(0.033143739671524806 + 
          0.011198741064764723*lm + 0.015309468369319137*lm^2) + 
        0.0064242025874177745*NM + 0.000960795889245726*lm*NM + 
        0.0017010520410354595*lm^2*NM + 0.010704295487055248*NL + 
        0.000960795889245726*lm*NL + 0.0017010520410354595*lm^2*NL + 
        0.0019159984149576994*NH + 0.000960795889245726*lm*NH + 
        0.0017010520410354595*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.0413215363444408 - 0.016938295465032664*lm - 
          0.009240072373553333*lm^2) + CF*(0.03275568585057997 + 
          0.010993443407175934*lm + 0.015120118429450907*lm^2) + 
        0.006304651580197073*NM + 0.0009414915187704574*lm*NM + 
        0.0016800131588278785*lm^2*NM + 0.01057096715682848*NL + 
        0.0009414915187704574*lm*NL + 0.0016800131588278785*lm^2*NL + 
        0.0019051609510604603*NH + 0.0009414915187704574*lm*NH + 
        0.0016800131588278785*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.04079941988751385 - 0.016687720448557403*lm - 
          0.009126057508124468*lm^2) + CF*(0.03237183532618427 + 
          0.010789769045744687*lm + 0.014933548649658221*lm^2) + 
        0.006187347853955973*NM + 0.0009223160300890722*lm*NM + 
        0.0016592831832953577*lm^2*NM + 0.01043944359802503*NL + 
        0.0009223160300890722*lm*NL + 0.0016592831832953577*lm^2*NL + 
        0.0018944753062487014*NH + 0.0009223160300890722*lm*NH + 
        0.0016592831832953577*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.04028306202763119 - 0.016440015809132204*lm - 
          0.0090137137965129*lm^2) + CF*(0.031992176671383425 + 
          0.0105877670146434*lm + 0.014749713485202928*lm^2) + 
        0.006072255922986719*NM + 0.0009032757148640274*lm*NM + 
        0.0016388570539114364*lm^2*NM + 0.010309707352536557*NL + 
        0.0009032757148640274*lm*NL + 0.0016388570539114364*lm^2*NL + 
        0.0018839374077195426*NH + 0.0009032757148640274*lm*NH + 
        0.0016388570539114364*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.03977247757941946 - 0.016195178880559567*lm - 
          0.00890301387411857*lm^2) + CF*(0.031616697246604146 + 
          0.010387482478667996*lm + 0.014568568157648568*lm^2) + 
        0.005959340422345352*NM + 0.0008843764206362853*lm*NM + 
        0.0016187297952942855*lm^2*NM + 0.010181740613725305*NL + 
        0.0008843764206362853*lm*NL + 0.0016187297952942855*lm^2*NL + 
        0.0018735433035012216*NH + 0.0008843764206362853*lm*NH + 
        0.0016187297952942855*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.039267676043247074 - 0.015953205259063588*lm - 
          0.008793930838089407*lm^2) + CF*(0.031245383225600578 + 
          0.010188956923578596*lm + 0.014390068644146303*lm^2) + 
        0.005848566139443526*NM + 0.0008656235721726903*lm*NM + 
        0.0015988965160162558*lm^2*NM + 0.010055525265943607*NL + 
        0.0008656235721726903*lm*NL + 0.0015988965160162558*lm^2*NL + 
        0.0018632891590774285*NH + 0.0008656235721726903*lm*NH + 
        0.0015988965160162558*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.03876866193392926 - 0.015714088907156223*lm - 
          0.008686438240753151*lm^2) + CF*(0.030878219623798792 + 
          0.009992228337950347*lm + 0.014214171666686976*lm^2) + 
        0.005739898043106218*NM + 0.00084702219187065*lm*NM + 
        0.001579352407409664*lm^2*NM + 0.009931042921629855*NL + 
        0.00084702219187065*lm*NL + 0.001579352407409664*lm^2*NL + 
        0.0018531712540909202*NH + 0.00084702219187065*lm*NH + 
        0.001579352407409664*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.038275435092362295 - 0.015477822252529127*lm - 
          0.008580510083037982*lm^2) + CF*(0.030515190328691478 + 
          0.009797331386904536*lm + 0.014040834681334881*lm^2) + 
        0.00563330131025177*NM + 0.0008285769192609691*lm*NM + 
        0.0015600927423705423*lm^2*NM + 0.009808274956114367*NL + 
        0.0008285769192609691*lm*NL + 0.0015600927423705423*lm^2*NL + 
        0.001843185979125592*NH + 0.0008285769192609691*lm*NH + 
        0.0015600927423705423*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.037787990980943785 - 0.015244396282197172*lm - 
          0.008476120807890704*lm^2) + CF*(0.03015627813196591 + 
          0.009604297578074182*lm + 0.013870015867457517*lm^2) + 
        0.005528741350341668*NM + 0.000810292029647918*lm*NM + 
        0.0015411128741619463*lm^2*NM + 0.00968720254026134*NL + 
        0.000810292029647918*lm*NL + 0.0015411128741619463*lm^2*NL + 
        0.0018333298325661103*NH + 0.000810292029647918*lm*NH + 
        0.0015411128741619463*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.03730632096359259 - 0.015013800632109574*lm - 
          0.008373245293700551*lm^2) + CF*(0.029801464763076435 + 
          0.009413155420142766*lm + 0.01370167411696454*lm^2) + 
        0.005426183827738914*NM + 0.000792171451923927*lm*NM + 
        0.0015224082352182822*lm^2*NM + 0.009567806671066303*NL + 
        0.000792171451923927*lm*NL + 0.0015224082352182822*lm^2*NL + 
        0.0018235994175341357*NH + 0.000792171451923927*lm*NH + 
        0.0015224082352182822*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.036830412571140884 - 0.014786023672434796*lm - 
          0.008271858847736043*lm^2) + CF*(0.02945073092399923 + 
          0.009223930574280136*lm + 0.01353576902356807*lm^2) + 
        0.00532559468210582*NM + 0.0007742187855946804*lm*NM + 
        0.001503974335952008*lm^2*NM + 0.009450068200322004*NL + 
        0.0007742187855946804*lm*NL + 0.001503974335952008*lm^2*NL + 
        0.001813991438900107*NH + 0.0007742187855946804*lm*NH + 
        0.001503974335952008*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.03636024975283201 - 0.014561052588716195*lm - 
          0.008171937199601676*lm^2) + CF*(0.029104056324931096 + 
          0.00903664599878545*lm + 0.013372260872075471*lm^2) + 
        0.005226940146964454*NM + 0.0007564373170488376*lm*NM + 
        0.0014858067635639411*lm^2*NM + 0.00933396786145957*NL + 
        0.0007564373170488376*lm*NL + 0.0014858067635639411*lm^2*NL + 
        0.0018045027003695*NH + 0.0007564373170488376*lm*NH + 
        0.0014858067635639411*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.03589581311462085 - 0.014338873459086418*lm - 
          0.00807345649472074*lm^2) + CF*(0.02876141972071661 + 
          0.008851322087233628*lm + 0.013211110627724846*lm^2) + 
        0.005130186766535825*NM + 0.0007388300351051282*lm*NM + 
        0.0014679011808583164*lm^2*NM + 0.009219486294666037*NL + 
        0.0007388300351051282*lm*NL + 0.0014679011808583164*lm^2*NL + 
        0.0017951301016424282*NH + 0.0007388300351051282*lm*NH + 
        0.0014679011808583164*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.03543708014493833 - 0.014119471327720198*lm - 
          0.00797639328784994*lm^2) + CF*(0.02842279894780846 + 
          0.008667976800408782*lm + 0.013052279925572629*lm^2) + 
        0.0050353014109671265*NM + 0.0007213996458681492*lm*NM + 
        0.0014502533250636254*lm^2*NM + 0.009106604070373864*NL + 
        0.0007213996458681492*lm*NL + 0.0014502533250636254*lm^2*NL + 
        0.0017858706356454121*NH + 0.0007213996458681492*lm*NH + 
        0.0014502533250636254*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.03498402542854845 - 0.01390283027469701*lm - 
          0.0078807245366311*lm^2) + CF*(0.02808817096158481 + 
          0.008486625792295845*lm + 0.012895731059941799*lm^2) + 
        0.004942251290050014*NM + 0.0007041485869228384*lm*NM + 
        0.0014328590066601998*lm^2*NM + 0.008995301711212919*NL + 
        0.0007041485869228384*lm*NL + 0.0014328590066601998*lm^2*NL + 
        0.0017767213858341114*NH + 0.0007041485869228384*lm*NH + 
        0.0014328590066601998*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.034536620849094854 - 0.013688933482437422*lm - 
          0.007786427595184676*lm^2) + CF*(0.027757511873865184 + 
          0.008307282530389799*lm + 0.01274142697393856*lm^2) + 
        0.004851003965526887*NM + 0.0006870790408963006*lm*NM + 
        0.0014157141082153956*lm^2*NM + 0.008885559712510522*NL + 
        0.0006870790408963006*lm*NL + 0.0014157141082153956*lm^2*NL + 
        0.0017676795235657802*NH + 0.0006870790408963006*lm*NH + 
        0.0014157141082153956*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.034094835780903644 - 0.013477763298869553*lm - 
          0.007693480207749472*lm^2) + CF*(0.027430796990482224 + 
          0.008129958410570555*lm + 0.012589331249044591*lm^2) + 
        0.0047615273620764675*NM + 0.000670192948414421*lm*NM + 
        0.0013988145832271768*lm^2*NM + 0.008777358561420517*NL + 
        0.000670192948414421*lm*NL + 0.0013988145832271768*lm^2*NL + 
        0.0017587423055401917*NH + 0.000670192948414421*lm*NH + 
        0.0013988145832271768*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.0336586372705812 - 0.013269301297474997*lm - 
          0.007601860502372451*lm^2) + CF*(0.027108000848781844 + 
          0.007954662866780848*lm + 0.012439408094791283*lm^2) + 
        0.0046737897770646715*NM + 0.000653492020479515*lm*NM + 
        0.0013821564549768093*lm^2*NM + 0.008670678754758009*NL + 
        0.000653492020479515*lm*NL + 0.0013821564549768093*lm^2*NL + 
        0.0017499070713077442*NH + 0.000653492020479515*lm*NH + 
        0.0013821564549768093*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.033227990208918354 - 0.013063528334356917*lm - 
          0.007511546984652257*lm^2) + CF*(0.02678909725493754 + 
          0.007781403475734093*lm + 0.012291622338521876*lm^2) + 
        0.0045877598891416885*NM + 0.0006369777502941238*lm*NM + 
        0.0013657358153913194*lm^2*NM + 0.008565500815612255*NL + 
        0.0006369777502941238*lm*NL + 0.0013657358153913194*lm^2*NL + 
        0.0017411712408434662*NH + 0.0006369777502941238*lm*NH + 
        0.0013657358153913194*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.0328028574935871 - 0.012860424602466506*lm - 
          0.007422518531539648*lm^2) + CF*(0.02647405932097755 + 
          0.0076101860568693*lm + 0.012145939415246696*lm^2) + 
        0.004503406765761483*NM + 0.0006206514245549834*lm*NM + 
        0.0013495488239162994*lm^2*NM + 0.008461805308806278*NL + 
        0.0006206514245549834*lm*NL + 0.0013495488239162994*lm^2*NL + 
        0.0017325323121856059*NH + 0.0006206514245549834*lm*NH + 
        0.0013495488239162994*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.03238320018309132 - 0.01265996968311796*lm - 
          0.007334754385197748*lm^2) + CF*(0.026162859501434668 + 
          0.00744101476776074*lm + 0.012002325357596315*lm^2) + 
        0.004420699869695419*NM + 0.0006045141342401504*lm*NM + 
        0.0013335917063995904*lm^2*NM + 0.008359572855268112*NL + 
        0.0006045141342401504*lm*NL + 0.0013335917063995904*lm^2*NL + 
        0.001723987859137503*NH + 0.0006045141342401504*lm*NH + 
        0.0013335917063995904*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.03196897764241037 - 0.012462142594916197*lm - 
          0.007248234146924718*lm^2) + CF*(0.025855469629539347 + 
          0.0072738921951809405*lm + 0.011860746785876812*lm^2) + 
        0.0043396090646075376*NM + 0.0005885667849112748*lm*NM + 
        0.0013178607539863123*lm^2*NM + 0.008258784145375066*NL + 
        0.0005885667849112748*lm*NL + 0.0013178607539863123*lm^2*NL + 
        0.0017155355290314213*NH + 0.0005885667849112748*lm*NH + 
        0.0013178607539863123*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.03156014768075208 - 0.012266921840215987*lm - 
          0.007162937771141161*lm^2) + CF*(0.02555186095288622 + 
          0.007108819442007035*lm + 0.01172117089823099*lm^2) + 
        0.004260104619754967*NM + 0.0005728101065520596*lm*NM + 
        0.0013023523220256656*lm^2*NM + 0.008159419951329116*NL + 
        0.0005728101065520596*lm*NL + 0.0013023523220256656*lm^2*NL + 
        0.0017071730405530305*NH + 0.0005728101065520596*lm*NH + 
        0.0013023523220256656*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.031156666681811298 - 0.012074285449225827*lm - 
          0.007078845559444314*lm^2) + CF*(0.02525200416851307 + 
          0.00694579621015214*lm + 0.011583565460908878*lm^2) + 
        0.004182157213873279*NM + 0.0005572446629630364*lm*NM + 
        0.0012870628289898753*lm^2*NM + 0.008061461138618366*NL + 
        0.0005572446629630364*lm*NL + 0.0012870628289898753*lm^2*NL + 
        0.0016988981816252215*NH + 0.0005572446629630364*lm*NH + 
        0.0012870628289898753*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.030758489726910122 - 0.011884211021864783*lm - 
          0.006995938154730854*lm^2) + CF*(0.02495586945733931 + 
          0.00678482087969562*lm + 0.01144789879865049*lm^2) + 
        0.004105737938302995*NM + 0.0005418708607319116*lm*NM + 
        0.00127198875540561*lm^2*NM + 0.007964888676616605*NL + 
        0.0005418708607319116*lm*NL + 0.00127198875540561*lm^2*NL + 
        0.001690708807349948*NH + 0.0005418708607319116*lm*NH + 
        0.00127198875540561*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.030365570711377445 - 0.011696675767475647*lm - 
          0.006914196535389888*lm^2) + CF*(0.024663426517918544 + 
          0.0066258905843784525*lm + 0.011314139785183452*lm^2) + 
        0.004030818299410154*NM + 0.0005266889577979124*lm*NM + 
        0.0012571266427981614*lm^2*NM + 0.007869683648370146*NL + 
        0.0005266889577979124*lm*NL + 0.0012571266427981614*lm^2*NL + 
        0.0016826028380067886*NH + 0.0005266889577979124*lm*NH + 
        0.0012571266427981614*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.02997786245450747 - 0.011511656542493127*lm - 
          0.00683360200956751*lm^2) + CF*(0.024374644599466318 + 
          0.006469001283622762*lm + 0.011182257833837745*lm^2) + 
        0.003957370220350687*NM + 0.000511699071627756*lm*NM + 
        0.0012424730926486383*lm^2*NM + 0.007775827259618525*NL + 
        0.000511699071627756*lm*NL + 0.0012424730926486383*lm^2*NL + 
        0.001674578257106938*NH + 0.000511699071627756*lm*NH + 
        0.0012424730926486383*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.02959531680342013 - 0.011329129886161322*lm - 
          0.006754136209504124*lm^2) + CF*(0.024089492534130556 + 
          0.006314147831227592*lm + 0.011052222888279475*lm^2) + 
        0.0038853660422253906*NM + 0.0004969011870201125*lm*NM + 
        0.001228024765364386*lm^2*NM + 0.0076833008470930724*NL + 
        0.0004969011870201125*lm*NL + 0.001228024765364386*lm^2*NL + 
        0.0016666331095013425*NH + 0.0004969011870201125*lm*NH + 
        0.001228024765364386*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.029217884731130205 - 0.011149072054390526*lm - 
          0.0066757810859454925*lm^2) + CF*(0.023807938768477525 + 
          0.006161324040886456*lm + 0.010924005413365351*lm^2) + 
        0.0038147785246694862*NM + 0.0004822951635546923*lm*NM + 
        0.0012137783792628169*lm^2*NM + 0.007592085886135078*NL + 
        0.0004822951635546923*lm*NL + 0.0012137783792628169*lm^2*NL + 
        0.0016587654995417066*NH + 0.0004822951635546923*lm*NH + 
        0.0012137783792628169*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.0288455164291168 - 0.010971459051839308*lm - 
          0.006598518902628394*lm^2) + CF*(0.02352995139417145 + 
          0.0060105227486658246*lm + 0.01079757638611919*lm^2) + 
        0.003745580845918123*NM + 0.0004678807427014029*lm*NM + 
        0.0011997307095687989*lm^2*NM + 0.007502163997672937*NL + 
        0.0004678807427014029*lm*NL + 0.0011997307095687989*lm^2*NL + 
        0.0016509735892931156*NH + 0.0004678807427014029*lm*NH + 
        0.0011997307095687989*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.02847816139467026 - 0.010796266662304006*lm - 
          0.0065223322308415235*lm^2) + CF*(0.023255498177830382 + 
          0.005861735872577681*lm + 0.010672907286831583*lm^2) + 
        0.003677746602386693*NM + 0.0004536575546043426*lm*NM + 
        0.0011858785874257316*lm^2*NM + 0.00741351695459561*NL + 
        0.0004536575546043426*lm*NL + 0.0011858785874257316*lm^2*NL + 
        0.0016432555967970269*NH + 0.0004536575546043426*lm*NH + 
        0.0011858785874257316*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.028115768513280043 - 0.010623470477494007*lm - 
          0.006447203944062191*lm^2) + CF*(0.022984546590045198 + 
          0.0057149544693735005*lm + 0.010549970090283585*lm^2) + 
        0.003611249807802483*NM + 0.00043962512455476697*lm*NM + 
        0.0011722188989203982*lm^2*NM + 0.007326126687557663*NL + 
        0.00043962512455476697*lm*NL + 0.0011722188989203982*lm^2*NL + 
        0.0016356097943834031*NH + 0.00043962512455476697*lm*NH + 
        0.0011722188989203982*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.02775828613631383 - 0.010453045924267757*lm - 
          0.006373117212669215*lm^2) + CF*(0.022717063833552282 + 
          0.005570168788681469*lm + 0.010428737257095078*lm^2) + 
        0.0035460648919219814*NM + 0.0004257828791665507*lm*NM + 
        0.0011587485841216753*lm^2*NM + 0.007239975290249303*NL + 
        0.0004257828791665507*lm*NL + 0.0011587485841216753*lm^2*NL + 
        0.0016280345070307782*NH + 0.0004257828791665507*lm*NH + 
        0.0011587485841216753*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.027405662154225928 - 0.01028496829040095*lm - 
          0.006300055498732277*lm^2) + CF*(0.022453016870553986 + 
          0.005427368324603465*lm + 0.010309181725198272*lm^2) + 
        0.003482166698866076*NM + 0.0004121301522670837*lm*NM + 
        0.0011454646361331413*lm^2*NM + 0.0071550450241629725*NL + 
        0.0004121301522670837*lm*NL + 0.0011454646361331413*lm^2*NL + 
        0.0016205281107730578*NH + 0.0004121301522670837*lm*NH + 
        0.0011454646361331413*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.02705784406552118 - 0.010119212748955247*lm - 
          0.006228002550877911*lm^2) + CF*(0.022192372449183893 + 
          0.005286541864883276*lm + 0.010191276901436582*lm^2) + 
        0.0034195304851034098*NM + 0.00039866619051598287*lm*NM + 
        0.0011323641001596203*lm^2*NM + 0.0070713183228863965*NL + 
        0.00039866619051598287*lm*NL + 0.0011323641001596203*lm^2*NL + 
        0.0016130890311518832*NH + 0.00039866619051598287*lm*NH + 
        0.0011323641001596203*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.026714779041689382 - 0.009955754381312725*lm - 
          0.0061569423992321685*lm^2) + CF*(0.021935097129116794 + 
          0.005147677537752683*lm + 0.010074996653289004*lm^2) + 
        0.003358131917110313*NM + 0.00038539015876346477*lm*NM + 
        0.001119444072587667*lm^2*NM + 0.006988777795950335*NL + 
        0.00038539015876346477*lm*NL + 0.001119444072587667*lm^2*NL + 
        0.0016057157417134003*NH + 0.00038539015876346477*lm*NH + 
        0.001119444072587667*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.026376413988314636 - 0.009794568198938357*lm - 
          0.006086859350439939*lm^2) + CF*(0.021681157306325704 + 
          0.0050107628565574215*lm + 0.009960315300719901*lm^2) + 
        0.003297947068733999*NM + 0.00037230114515971537*lm*NM + 
        0.001106701700079989*lm^2*NM + 0.006907406232257783*NL + 
        0.00037230114515971537*lm*NL + 0.001106701700079989*lm^2*NL + 
        0.0015984067625482979*NH + 0.00037230114515971537*lm*NH + 
        0.001106701700079989*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.026042695602554018 - 0.009635629163930003*lm - 
          0.006017737982760776*lm^2) + CF*(0.02143051923699041 + 
          0.004875784762260582*lm + 0.009847207608153998*lm^2) + 
        0.003238952418284034*NM + 0.0003593981660261018*lm*NM + 
        0.0010941341786837775*lm^2*NM + 0.0068271866031199115*NL + 
        0.0003593981660261018*lm*NL + 0.0010941341786837775*lm^2*NL + 
        0.001591160658873996*NH + 0.0003593981660261018*lm*NH + 
        0.0010941341786837775*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.0257135704271702 - 0.009478912208412729*lm - 
          0.005949563141241027*lm^2) + CF*(0.02118314906056415 + 
          0.004742729663916823*lm + 0.009735648776576226*lm^2) + 
        0.0031811248453755803*NM + 0.0003466801704986057*lm*NM + 
        0.001081738752952914*lm^2*NM + 0.006748102064922651*NL + 
        0.0003466801704986057*lm*NL + 0.001081738752952914*lm^2*NL + 
        0.0015839760396578913*NH + 0.0003466801704986057*lm*NH + 
        0.001081738752952914*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.02538898490129371 - 0.009324392252831718*lm - 
          0.005882319932961978*lm^2) + CF*(0.020939012822006612 + 
          0.00461158347720667*lm + 0.009625614435755965*lm^2) + 
        0.00312444162754642*NM + 0.00033414604495340846*lm*NM + 
        0.001069512715083996*lm^2*NM + 0.006670135961446554*NL + 
        0.00033414604495340846*lm*NL + 0.001069512715083996*lm^2*NL + 
        0.00157685155628058*NH + 0.00033414604495340846*lm*NH + 
        0.001069512715083996*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.02506888540808178 - 0.00917204422319556*lm - 
          0.00581599372236366*lm^2) + CF*(0.020698076493193086 + 
          0.004482331661116357*lm + 0.009517080636595081*lm^2) + 
        0.003068880436668405*NM + 0.0003217946172241307*lm*NM + 
        0.00105745340406612*lm^2*NM + 0.006593271825861312*NL + 
        0.0003217946172241307*lm*NL + 0.00105745340406612*lm^2*NL + 
        0.0015697859012380063*NH + 0.0003217946172241307*lm*NH + 
        0.00105745340406612*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.024753218319432477 - 0.009021843067319417*lm - 
          0.0057505701266438855*lm^2) + CF*(0.020460305993510924 + 
          0.004354959252844907*lm + 0.009410023843599085*lm^2) + 
        0.0030144193351726786*NM + 0.00030962466061982137*lm*NM + 
        0.0010455582048443427*lm^2*NM + 0.0065174933824151725*NL + 
        0.00030962466061982137*lm*NL + 0.0010455582048443427*lm^2*NL + 
        0.0015627778068815006*NH + 0.00030962466061982137*lm*NH + 
        0.0010455582048443427*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.02444193003790509 - 0.008873763770115329*lm - 
          0.005686035011232049*lm^2) + CF*(0.02022566720965567 + 
          0.004229450901016663*lm + 0.009304420927470625*lm^2) + 
        0.002961036772106791*NM + 0.00029763489775239544*lm*NM + 
        0.0010338245474967361*lm^2*NM + 0.006442784547838365*NL + 
        0.00029763489775239544*lm*NL + 0.0010338245474967361*lm^2*NL + 
        0.0015558260441946934*NH + 0.00029763489775239544*lm*NH + 
        0.0010338245474967361*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.024134967035990152 - 0.008727781367974745*lm - 
          0.005622374485337164*lm^2) + CF*(0.019994126014640217 + 
          0.004105790897274054*lm + 0.00920024915782445*lm^2) + 
        0.0029087115790406718*NM + 0.0002858240041818496*lm*NM + 
        0.0010222499064249388*lm^2*NM + 0.006369129432478633*NL + 
        0.0002858240041818496*lm*NL + 0.0010222499064249388*lm^2*NL + 
        0.0015489294216063164*NH + 0.0002858240041818496*lm*NH + 
        0.0010222499064249388*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0238322758928656 - 0.008583870962286414*lm - 
          0.00555957489756954*lm^2) + CF*(0.019765648286031254 + 
          0.003983963206322155*lm + 0.009097486196022882*lm^2) + 
        0.0028574229658373507*NM + 0.0002741906118872231*lm*NM + 
        0.0010108317995580981*lm^2*NM + 0.006296512341185958*NL + 
        0.0002741906118872231*lm*NL + 0.0010108317995580981*lm^2*NL + 
        0.0015420867838379156*NH + 0.0002741906118872231*lm*NH + 
        0.0010108317995580981*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.023533803328768716 - 0.008442007732130751*lm - 
          0.005497622831635502*lm^2) + CF*(0.01954019992342806 + 
          0.003863951494493503*lm + 0.008996110088130822*lm^2) + 
        0.002807150516303281*NM + 0.00026273331257092955*lm*NM + 
        0.0009995677875700912*lm^2*NM + 0.00622491777396264*NL + 
        0.00026273331257092955*lm*NL + 0.0009995677875700912*lm^2*NL + 
        0.001535297010785532*NH + 0.00026273331257092955*lm*NH + 
        0.0009995677875700912*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.02323949623710711 - 0.00830216694619*lm - 
          0.005436505102104477*lm^2) + CF*(0.019317746865199256 + 
          0.003745739156898672*lm + 0.008896099257989145*lm^2) + 
        0.002757874183732163*NM + 0.00025145066080375716*lm*NM + 
        0.0009884554731099048*lm^2*NM + 0.006154330426394017*NL + 
        0.00025145066080375716*lm*NL + 0.0009884554731099048*lm^2*NL + 
        0.0015285590164344145*NH + 0.00025145066080375716*lm*NH + 
        0.0009884554731099048*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.02294930171442609 - 0.008164323973911682*lm - 
          0.005376208750247751*lm^2) + CF*(0.019098255104493738 + 
          0.0036293093432252523*lm + 0.008797432500405409*lm^2) + 
        0.002709574286355262*NM + 0.00024034117701752047*lm*NM + 
        0.0009774925000450455*lm^2*NM + 0.006084735189874239*NL + 
        0.00024034117701752047*lm*NL + 0.0009774925000450455*lm^2*NL + 
        0.0015218717478058669*NH + 0.00024034117701752047*lm*NH + 
        0.0009774925000450455*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.022663167088343754 - 0.008028454295961211*lm - 
          0.005316721039948177*lm^2) + CF*(0.0188816907045424 + 
          0.0035146449822451996*lm + 0.008700088974460653*lm^2) + 
        0.0026622315027103427*NM + 0.0002294033503520471*lm*NM + 
        0.0009666765527178504*lm^2*NM + 0.006016117151640756*NL + 
        0.0002294033503520471*lm*NL + 0.0009666765527178504*lm^2*NL + 
        0.0015152341839353295*NH + 0.0002294033503520471*lm*NH + 
        0.0009666765527178504*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.022381039943559868 - 0.007894533513997843*lm - 
          0.0052580294536800805*lm^2) + CF*(0.018668019813267617 + 
          0.0034017288050878962*lm + 0.00860404819693104*lm^2) + 
        0.0026158268669405583*NM + 0.00021863564136289515*lm*NM + 
        0.00095600535521456*lm^2*NM + 0.0059484615946304095*NL + 
        0.00021863564136289515*lm*NL + 0.00095600535521456*lm^2*NL + 
        0.0015086453348808419*NH + 0.00021863564136289515*lm*NH + 
        0.00095600535521456*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.022102868146039244 - 0.007762537359806645*lm - 
          0.00520012168855856*lm^2) + CF*(0.018457208677217705 + 
          0.00329054336733381*lm + 0.008509290035823099*lm^2) + 
        0.0025703417640338647*NM + 0.00020803648459592148*lm*NM + 
        0.000945476670647011*lm^2*NM + 0.005881753997169286*NL + 
        0.00020803648459592148*lm*NL + 0.000945476670647011*lm^2*NL + 
        0.0015021042407610315*NH + 0.00020803648459592148*lm*NH + 
        0.000945476670647011*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.021828599865465426 - 0.007632441703817694*lm - 
          0.005142985652457414*lm^2) + CF*(0.018249223654843775 + 
          0.0031810710699812375*lm + 0.008415794704021222*lm^2) + 
        0.0025257579250128038*NM + 0.0001976042910345593*lm*NM + 
        0.0009350883004468025*lm^2*NM + 0.005815980032507856*NL + 
        0.0001976042910345593*lm*NL + 0.0009350883004468025*lm^2*NL + 
        0.0014956099708218066*NH + 0.0001976042910345593*lm*NH + 
        0.0009350883004468025*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.02155818359605575 - 0.0075042225630422696*lm - 
          0.005086609460194831*lm^2) + CF*(0.01804403122913652 + 
          0.0030732941793363755*lm + 0.008323542753046087*lm^2) + 
        0.002482057422083855*NM + 0.00018733745042541047*lm*NM + 
        0.0009248380836717874*lm^2*NM + 0.005751125568212245*NL + 
        0.00018733745042541047*lm*NL + 0.0009248380836717874*lm^2*NL + 
        0.0014891616225309464*NH + 0.00018733745042541047*lm*NH + 
        0.0009248380836717874*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.021291568175824397 - 0.007377856108454495*lm - 
          0.005030981429786043*lm^2) + CF*(0.017841598019640522 + 
          0.002967194845874765*lm + 0.008232515066922616*lm^2) + 
        0.0024392226637548935*NM + 0.00017723433348751805*lm*NM + 
        0.0009147238963247351*lm^2*NM + 0.005687176665421904*NL + 
        0.00017723433348751805*lm*NL + 0.0009147238963247351*lm^2*NL + 
        0.001482758320699804*NH + 0.00017723433348751805*lm*NH + 
        0.0009147238963247351*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0210287028043757 - 0.007253318671845568*lm - 
          0.004976090078762058*lm^2) + CF*(0.017641890793863697 + 
          0.0028627551221200955*lm + 0.008142692856156096*lm^2) + 
        0.0023972363899287157*NM + 0.00016729329401045327*lm*NM + 
        0.0009047436506840106*lm^2*NM + 0.00562411957798336*NL + 
        0.00016729329401045327*lm*NL + 0.0009047436506840106*lm^2*NL + 
        0.0014763992166313509*NH + 0.00016729329401045327*lm*NH + 
        0.0009047436506840106*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.020769537059306075 - 0.007130586752176512*lm - 
          0.004921924120553618*lm^2) + CF*(0.017444876478099437 + 
          0.002759956979584354*lm + 0.008054057651815012*lm^2) + 
        0.0023560816669800275*NM + 0.00015751267084613172*lm*NM + 
        0.0008948952946461123*lm^2*NM + 0.00556194075146919*NL + 
        0.00015751267084613172*lm*NL + 0.0008948952946461123*lm^2*NL + 
        0.0014700834872938223*NH + 0.00015751267084613172*lm*NH + 
        0.0008948952946461123*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.020514020911288854 - 0.007009637021454195*lm - 
          0.004868472460939497*lm^2) + CF*(0.01725052216767891 + 
          0.0026587823248114123*lm + 0.007966591299719177*lm^2) + 
        0.0023157418828227585*NM + 0.00014789078979906108*lm*NM + 
        0.0008851768110799085*lm^2*NM + 0.005500626822090833*NL + 
        0.00014789078979906108*lm*NL + 0.0008851768110799085*lm^2*NL + 
        0.0014638103345192277*NH + 0.00014789078979906108*lm*NH + 
        0.0008851768110799085*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.020262104737912876 - 0.006890446330154258*lm - 
          0.004815724194558267*lm^2) + CF*(0.017058795136670926 + 
          0.002559213014564319*lm + 0.00788027595473171*lm^2) + 
        0.0022762007419740767*NM + 0.0001384259654195223*lm*NM + 
        0.0008755862171924122*lm^2*NM + 0.005440164615513407*NL + 
        0.0001384259654195223*lm*NL + 0.0008755862171924122*lm^2*NL + 
        0.0014575789842260194*NH + 0.0001384259654195223*lm*NH + 
        0.0008755862171924122*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.02001373933634199 - 0.006772991712213476*lm - 
          0.0047636686014826245*lm^2) + CF*(0.01686966284704654 + 
          0.002461230870194822*lm + 0.007795094075153385*lm^2) + 
        0.002237442260621005*NM + 0.00012911650270399164*lm*NM + 
        0.0008661215639059317*lm^2*NM + 0.005380541145580181*NL + 
        0.00012911650270399164*lm*NL + 0.0008661215639059317*lm^2*NL + 
        0.0014513886856652282*NH + 0.00012911650270399164*lm*NH + 
        0.0008661215639059317*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.01976887593485946 - 0.00665725038961313*lm - 
          0.004712295143855383*lm^2) + CF*(0.016683092957325413 + 
          0.0023648176912319904*lm + 0.007711028417217899*lm^2) + 
        0.002199450761695108*NM + 0.0001199606987069267*lm*NM + 
        0.0008567809352464333*lm^2*NM + 0.0053217436129539665*NL + 
        0.0001199606987069267*lm*NL + 0.0008567809352464333*lm^2*NL + 
        0.0014452387106893881*NH + 0.0001199606987069267*lm*NH + 
        0.0008567809352464333*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.01952746620335797 - 0.006543199776573909*lm - 
          0.004661593462586236*lm^2) + CF*(0.016499053330720725 + 
          0.002269955268225192*lm + 0.007628062029686568*lm^2) + 
        0.0021622108699603016*NM + 0.00011095684406786267*lm*NM + 
        0.000847562447742952*lm^2*NM + 0.005263759403682242*NL + 
        0.00011095684406786267*lm*NL + 0.000847562447742952*lm^2*NL + 
        0.0014391283530435985*NH + 0.00011095684406786267*lm*NH + 
        0.000847562447742952*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.019289462262833058 - 0.00643081748338198*lm - 
          0.004611553374108378*lm^2) + CF*(0.01631751204279927 + 
          0.0021766253948751852*lm + 0.007546178248540982*lm^2) + 
        0.0021257075071184467*NM + 0.00010210322445759499*lm*NM + 
        0.0008384642498378868*lm^2*NM + 0.005206576087692456*NL + 
        0.00010210322445759499*lm*NL + 0.0008384642498378868*lm^2*NL + 
        0.0014330569276780776*NH + 0.00010210322445759499*lm*NH + 
        0.0008384642498378868*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.019054816693934818 - 0.006320081319864952*lm - 
          0.004562164867194082*lm^2) + CF*(0.01613843738867297 + 
          0.0020848098794855924*lm + 0.007465360691772133*lm^2) + 
        0.0020899258869370315*NM + 0.00009339812194706336*lm*NM + 
        0.0008294845213080148*lm^2*NM + 0.00515018141722357*NL + 
        0.00009339812194706336*lm*NL + 0.0008294845213080148*lm^2*NL + 
        0.0014270237700815913*NH + 0.00009339812194706336*lm*NH + 
        0.0008294845213080148*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.018823482544630087 - 0.006210969298535598*lm - 
          0.00451341809982833*lm^2) + CF*(0.01596179788973789 + 
          0.0019944905557656555*lm + 0.007385593254264539*lm^2) + 
        0.0020548515104029013*NM + 0.0000848398163023962*lm*NM + 
        0.0008206214726960599*lm^2*NM + 0.005094563325199569*NL + 
        0.0000848398163023962*lm*NL + 0.0008206214726960599*lm^2*NL + 
        0.0014210282356351474*NH + 0.0000848398163023962*lm*NH + 
        0.0008206214726960599*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.01859541333702468 - 0.006103459637420414*lm - 
          0.0044653033961395885*lm^2) + CF*(0.0157875622999765 + 
          0.0019056492930138182*lm + 0.007306860102773873*lm^2) + 
        0.002020470160905668*NM + 0.00007642658620942661*lm*NM + 
        0.0008118733447526525*lm^2*NM + 0.005039709923550295*NL + 
        0.00007642658620942661*lm*NL + 0.0008118733447526525*lm^2*NL + 
        0.0014150696989853643*NH + 0.00007642658620942661*lm*NH + 
        0.0008118733447526525*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.018370563073392836 - 0.005997530762589275*lm - 
          0.004417811243386835*lm^2) + CF*(0.015615699611838623 + 
          0.0018182680057104096*lm + 0.007229145670996639*lm^2) + 
        0.0019867678994541383*NM + 0.0000681567104308485*lm*NM + 
        0.0008032384078885153*lm^2*NM + 0.004985609501484701*NL + 
        0.0000681567104308485*lm*NL + 0.0008032384078885153*lm^2*NL + 
        0.0014091475534369448*NH + 0.0000681567104308485*lm*NH + 
        0.0008032384078885153*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.018148886241458634 - 0.005893161310401736*lm - 
          0.004370932289001916*lm^2) + CF*(0.01544617906171622 + 
          0.0017323286625464784*lm + 0.007152434654730409*lm^2) + 
        0.0019537310599288056*NM + 0.000060028468899045584*lm*NM + 
        0.0007947149616367121*lm^2*NM + 0.004932250523721279*NL + 
        0.000060028468899045584*lm*NL + 0.0007947149616367121*lm^2*NL + 
        0.001403261210363691*NH + 0.000060028468899045584*lm*NH + 
        0.0007947149616367121*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.017930337818971933 - 0.005790330129484802*lm - 
          0.00432465733768638*lm^2) + CF*(0.015278970135026803 + 
          0.0016478132949146577*lm + 0.007076712007123167*lm^2) + 
        0.0019213462443732014*NM + 0.00005204014374749591*lm*NM + 
        0.0007863013341247964*lm^2*NM + 0.004879621628680144*NL + 
        0.00005204014374749591*lm*NL + 0.0007863013341247964*lm^2*NL + 
        0.0013974100986375206*NH + 0.00005204014374749591*lm*NH + 
        0.0007863013341247964*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.017714873277619312 - 0.0056890162824563125*lm - 
          0.004278977348561849*lm^2) + CF*(0.01511404257091998 + 
          0.0015647040048868165*lm + 0.007001962934010299*lm^2) + 
        0.0018896003183266259*NM + 0.00004419002028352964*lm*NM + 
        0.0007779958815566999*lm^2*NM + 0.0048277116266410135*NL + 
        0.00004419002028352964*lm*NL + 0.0007779958815566999*lm^2*NL + 
        0.0013915936640749552*NH + 0.00004419002028352964*lm*NH + 
        0.0007779958815566999*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.017502448586308384 - 0.005589199047407426*lm - 
          0.004233883432373086*lm^2) + CF*(0.014951366366621277 + 
          0.001482982972702185*lm + 0.006928172889337778*lm^2) + 
        0.0018584804062005739*NM + 0.000036476387905098736*lm*NM + 
        0.0007697969877041975*lm^2*NM + 0.004776509497871024*NL + 
        0.000036476387905098736*lm*NL + 0.0007697969877041975*lm^2*NL + 
        0.0013858113689005644*NH + 0.000036476387905098736*lm*NH + 
        0.0007697969877041975*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.01729302021386202 - 0.005490857919157103*lm - 
          0.00418936684874285*lm^2) + CF*(0.014790911781427045 + 
          0.001402632463788613*lm + 0.006855327570670118*lm^2) + 
        0.0018279738867009276*NM + 0.00002889754096410295*lm*NM + 
        0.0007617030634077909*lm^2*NM + 0.0047260043907261335*NL + 
        0.00002889754096410295*lm*NL + 0.0007617030634077909*lm^2*NL + 
        0.0013800626912268703*NH + 0.00002889754096410295*lm*NH + 
        0.0007617030634077909*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.017086545131157118 - 0.005393972610290851*lm - 
          0.004145419003477684*lm^2) + CF*(0.014632649340363934 + 
          0.0013236348353386418*lm + 0.006783412914781665*lm^2) + 
        0.0017980683882977964*NM + 0.000021451779578707122*lm*NM + 
        0.0007537125460868518*lm^2*NM + 0.004676185619729602*NL + 
        0.000021451779578707122*lm*NL + 0.0007537125460868518*lm^2*NL + 
        0.0013743471245502206*NH + 0.000021451779578707122*lm*NH + 
        0.0007537125460868518*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.016882980812740887 - 0.005298523051995457*lm - 
          0.004102031445923767*lm^2) + CF*(0.01447654983752606 + 
          0.0012459725424611217*lm + 0.006712415093329799*lm^2) + 
        0.0017687517847446855*NM + 0.000014137410396980204*lm*NM + 
        0.0007458238992588665*lm^2*NM + 0.004627042663630827*NL + 
        0.000014137410396980204*lm*NL + 0.0007458238992588665*lm^2*NL + 
        0.0013686641772621643*NH + 0.000014137410396980204*lm*NH + 
        0.0007458238992588665*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.01668228523795592 - 0.005204489394700881*lm - 
          0.004059195866371963*lm^2) + CF*(0.01432258433910263 + 
          0.0011696281439282207*lm + 0.006642320508608666*lm^2) + 
        0.0017400121906484985*NM + 6.952747314086261*^-6*lm*NM + 
        0.0007380356120676296*lm^2*NM + 0.004578565163447636*NL + 
        6.952747314086261*^-6*lm*NL + 0.0007380356120676296*lm^2*NL + 
        0.001363013372175864*NH + 6.952747314086261*^-6*lm*NH + 
        0.0007380356120676296*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.016484416891603737 - 0.0051118520085399735*lm - 
          0.004016904093511245*lm^2) + CF*(0.014170724186108504 + 
          0.0010945843075367949*lm + 0.006573115789382036*lm^2) + 
        0.0017118379570917044*NM - 1.0388785483829105*^-7*lm*NM + 
        0.0007303461988202262*lm^2*NM + 0.004530742920494911*NL - 
        1.0388785483829105*^-7*lm*NL + 0.0007303461988202262*lm^2*NL + 
        0.0013573942460671042*NH - 1.0388785483829105*^-7*lm*NH + 
        0.0007303461988202262*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.01628933476417502 - 0.0050205914836361715*lm - 
          0.003975148091929618*lm^2) + CF*(0.014020940996829769 + 
          0.0010208238151022786*lm + 0.00650478778679392*lm^2) + 
        0.0016842176673078474*NM - 7.034164744078689*^-6*lm*NM + 
        0.0007227541985326578*lm^2*NM + 0.00448356589440226*NL - 
        7.034164744078689*^-6*lm*NL + 0.0007227541985326578*lm^2*NL + 
        0.0013518063492294573*NH - 7.034164744078689*^-6*lm*NH + 
        0.0007227541985326578*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.016096998351673362 - 0.004930688630228883*lm - 
          0.003933919959661742*lm^2) + CF*(0.013873206668996088 + 
          0.0009483295671024572*lm + 0.006437323570355578*lm^2) + 
        0.001657140132411429*NM - 0.000013839743847052498*lm*NM + 
        0.0007152581744839531*lm^2*NM + 0.004437024201123274*NL - 
        0.000013839743847052498*lm*NL + 0.0007152581744839531*lm^2*NL + 
        0.0013462492450431879*NH - 0.000013839743847052498*lm*NH + 
        0.0007152581744839531*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.015907367655057857 - 0.0048421244786457755*lm - 
          0.0038932119257824114*lm^2) + CF*(0.013727493381691259 + 
          0.0008770845869877315*lm + 0.006370710424007582*lm^2) + 
        0.0016305943871830493*NM - 0.00002052227596446653*lm*NM + 
        0.0007078567137786203*lm^2*NM + 0.0043911081109387394*NL - 
        0.00002052227596446653*lm*NL + 0.0007078567137786203*lm^2*NL + 
        0.0013407225095574866*NH - 0.00002052227596446653*lm*NH + 
        0.0007078567137786203*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.01572040317932879 - 0.004754880279130809*lm - 
          0.003853016348045091*lm^2) + CF*(0.013583773597013068 + 
          0.0008070720251737623*lm + 0.006304935842255603*lm^2) + 
        0.0016045696859105728*NM - 0.000027083401689130178*lm*NM + 
        0.0007005484269172892*lm^2*NM + 0.004345808046456033*NL - 
        0.000027083401689130178*lm*NL + 0.0007005484269172892*lm^2*NL + 
        0.001335225731085632*NH - 0.000027083401689130178*lm*NH + 
        0.0007005484269172892*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.01553606593227922 - 0.004668937501536382*lm - 
          0.0038133257105646997*lm^2) + CF*(0.01344202006149319 + 
          0.0007382751627316882*lm + 0.006239987526378599*lm^2) + 
        0.0015790554982869584*NM - 0.00003352475092571241*lm*NM + 
        0.0006933319473754*lm^2*NM + 0.004301114580606767*NL - 
        0.00003352475092571241*lm*NL + 0.0006933319473754*lm^2*NL + 
        0.001329758509812697*NH - 0.00003352475092571241*lm*NH + 
        0.0006933319473754*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.015354317422934303 - 0.004584277834887617*lm - 
          0.0037741326215438506*lm^2) + CF*(0.01330220580728758 + 
          0.0006706774147904532*lm + 0.006175853380708119*lm^2) + 
        0.001554041505365283*NM - 0.0000398479424438037*lm*NM + 
        0.000686205931189791*lm^2*NM + 0.004257018434644622*NL - 
        0.0000398479424438037*lm*NL + 0.000686205931189791*lm^2*NL + 
        0.0013243204574154223*NH - 0.0000398479424438037*lm*NH + 
        0.000686205931189791*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.015175119659698854 - 0.004500883186826407*lm - 
          0.003735429811041765*lm^2) + CF*(0.01316430415314747 + 
          0.0006042623336651408*lm + 0.006112521508977434*lm^2) + 
        0.0015295175955713836*NM - 0.000046054583462714615*lm*NM + 
        0.0006791690565530482*lm^2*NM + 0.004213510476145186*NL - 
        0.000046054583462714615*lm*NL + 0.0006791690565530482*lm^2*NL + 
        0.0013189111966938943*NH - 0.000046054583462714615*lm*NH + 
        0.0006791690565530482*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.014998435148232842 - 0.004418735682942485*lm - 
          0.003697210128785088*lm^2) + CF*(0.013028288705180753 + 
          0.0005390136117246082*lm + 0.006049980210739235*lm^2) + 
        0.0015054738607744472*NM - 0.00005214626926651084*lm*NM + 
        0.0006722200234154706*lm^2*NM + 0.004170581717009465*NL - 
        0.00005214626926651084*lm*NL + 0.0006722200234154706*lm^2*NL + 
        0.0013135303612146685*NH - 0.00005214626926651084*lm*NH + 
        0.0006722200234154706*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.014824226889073288 - 0.00433781766599845*lm - 
          0.0036594665420198436*lm^2) + CF*(0.012894133357413256 + 
          0.000474915084011135*lm + 0.005988217977850653*lm^2) + 
        0.0014819005924157818*NM - 0.00005812458284784896*lm*NM + 
        0.000665357553094517*lm^2*NM + 0.004128223311472652*NL - 
        0.00005812458284784896*lm*NL + 0.000665357553094517*lm^2*NL + 
        0.0013081775949649996*NH - 0.00005812458284784896*lm*NH + 
        0.000665357553094517*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.01465245837502021 - 0.004258111695055355*lm - 
          0.0036221921334037782*lm^2) + CF*(0.012761812292159072 + 
          0.00041195073062423826*lm + 0.005927223491024364*lm^2) + 
        0.0014587882776959252*NM - 0.00006399109457923953*lm*NM + 
        0.000658580387891596*lm^2*NM + 0.004086426554119594*NL - 
        0.00006399109457923953*lm*NL + 0.000658580387891596*lm^2*NL + 
        0.001302852552017841*NH - 0.00006399109457923953*lm*NH + 
        0.000658580387891596*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.014483093588303287 - 0.004179600544505115*lm - 
          0.0035853800989383493*lm^2) + CF*(0.012631299980208838 + 
          0.00035010467888028365*lm + 0.0058669856164445715*lm^2) + 
        0.0014361275958201653*NM - 0.00006974736191042351*lm*NM + 
        0.0006518872907160635*lm^2*NM + 0.004045182877908328*NL - 
        0.00006974736191042351*lm*NL + 0.0006518872907160635*lm^2*NL + 
        0.001297554896207288*NH - 0.00006974736191042351*lm*NH + 
        0.0006518872907160635*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.014316096997545066 - 0.004102267203015754*lm - 
          0.003549023745939635*lm^2) + CF*(0.012502571180844538 + 
          0.0002893612052590028*lm + 0.005807493402446675*lm^2) + 
        0.0014139094143024718*NM - 0.00007539492909060479*lm*NM + 
        0.0006452770447162973*lm^2*NM + 0.004004483852202933*NL - 
        0.00007539492909060479*lm*NL + 0.0006452770447162973*lm^2*NL + 
        0.0012922843008141543*NH - 0.00007539492909060479*lm*NH + 
        0.0006452770447162973*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.01415143355453572 - 0.004026094872395161*lm - 
          0.0035131164910474372*lm^2) + CF*(0.012375600941689139 + 
          0.00022970473714754652*lm + 0.005748736076259443*lm^2) + 
        0.0013921247853277787*NM - 0.00008093532691433636*lm*NM + 
        0.0006387484529177159*lm^2*NM + 0.003964321180816855*NL - 
        0.00008093532691433636*lm*NL + 0.0006387484529177159*lm^2*NL + 
        0.0012870404482613687*NH - 0.00008093532691433636*lm*NH + 
        0.0006387484529177159*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.013989068690833535 - 0.003951066966378797*lm - 
          0.003477651858271879*lm^2) + CF*(0.012250364598399075 + 
          0.00017111985439223406*lm + 0.0056907030408085285*lm^2) + 
        0.001370764942172487*NM - 0.00008637007248990972*lm*NM + 
        0.0006323003378676143*lm^2*NM + 0.003924686700067797*NL - 
        0.00008637007248990972*lm*NL + 0.0006323003378676143*lm^2*NL + 
        0.0012818230298189028*NH - 0.00008637007248990972*lm*NH + 
        0.0006323003378676143*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.013828968314204635 - 0.003877167109346511*lm - 
          0.003442623477076786*lm^2) + CF*(0.012126837774207316 + 
          0.00011359129066771087*lm + 0.005633383871580196*lm^2) + 
        0.001349821295683005*NM - 0.00009170066902914685*lm*NM + 
        0.0006259315412866884*lm^2*NM + 0.003885572376845155*NL - 
        0.00009170066902914685*lm*NL + 0.0006259315412866884*lm^2*NL + 
        0.001276631745317935*NH - 0.00009170066902914685*lm*NH + 
        0.0006259315412866884*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.013671098804914636 - 0.003804379134973383*lm - 
          0.003408025080499182*lm^2) + CF*(0.012004996379324511 + 
          0.00005710393467280164*lm + 0.005576768313544116*lm^2) + 
        0.0013292854308120875*NM - 0.0000969286056575427*lm*NM + 
        0.000619640923727124*lm^2*NM + 0.0038469703066909113*NL - 
        0.0000969286056575427*lm*NL + 0.000619640923727124*lm^2*NL + 
        0.001271466302873974*NH - 0.0000969286056575427*lm*NH + 
        0.000619640923727124*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.01351542701188436 - 0.0037326870848192646*lm - 
          0.003373850503304203*lm^2) + CF*(0.011884816610205394 + 
          1.642831161933867*^-6*lm + 0.00552084627813415*lm^2) + 
        0.0013091491032126887*NM - 0.00010205535724375087*lm*NM + 
        0.0006134273642371278*lm^2*NM + 0.0038088727118948465*NL - 
        0.00010205535724375087*lm*NL + 0.0006134273642371278*lm^2*NL + 
        0.0012663264186186685*NH - 0.00010205535724375087*lm*NH + 
        0.0006134273642371278*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.013361920248721001 - 0.0036620752068614736*lm - 
          0.0033400936801747817*lm^2) + CF*(0.01176627494868745 - 
          0.0000528068181793835*lm + 0.005465607840286006*lm^2) + 
        0.0012894042358889972*NM - 0.00010708238424745013*lm*NM + 
        0.0006072897600317784*lm^2*NM + 0.003771271939604819*NL - 
        0.00010708238424745013*lm*NL + 0.0006072897600317784*lm^2*NL + 
        0.0012612118164400427*NH - 0.00010708238424745013*lm*NH + 
        0.0006072897600317784*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.01321054628963557 - 0.0035925279539748656*lm - 
          0.0033067486439354358*lm^2) + CF*(0.011649348161008495 - 
          0.000106259654006918*lm + 0.005411043235530713*lm^2) + 
        0.0012700429159042785*NM - 0.00011201113258467076*lm*NM + 
        0.0006012270261700792*lm^2*NM + 0.003734160459952832*NL - 
        0.00011201113258467076*lm*NL + 0.0006012270261700792*lm^2*NL + 
        0.001256122227730895*NH - 0.00011201113258467076*lm*NH + 
        0.0006012270261700792*lm^2*NH)}, 
     {1., 1.1960642024299431*^-11*CF*NC*
       (80.*CF*(1.2054132705916837*^7 - 165888.*lm + 5.59872*^6*lm^2) - 
        8.*CA*(1.365026365089909*^8 + 3.682944*^7*lm + 3.42144*^7*lm^2) + 
        1.0459784588514988*^8*NM - 9.76896*^6*lm*NM + 4.97664*^7*lm^2*NM + 
        3.09141504*^8*NL - 9.76896*^6*lm*NL + 4.97664*^7*lm^2*NL + 
        1.0459784588514988*^8*NH - 9.76896*^6*lm*NH + 4.97664*^7*lm^2*NH)}}
 
CbarTable["s", 2, 3] = {{0., -1.286008230452675*^-7*CF*NC*
       (CF*(-769577.7091909414 - 97666.17974587942*lm - 777600.*lm^2) + 
        4.*CA*(-6575.71205023619 + 127610.61095281024*lm + 59400.*lm^2) + 
        20.*((-5945.359133912704 - 1891.294943738554*lm - 2160.*lm^2)*NM + 
          (-5945.359133912704 - 1891.294943738554*lm - 2160.*lm^2)*NL + 
          (987.1190910339575 - 1891.294943738554*lm - 2160.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.0021883657414318433 - 0.06580246115456644*lm - 
          0.030087447482851633*lm^2) + CF*(0.09435751293412262 + 
          0.016179580028464074*lm + 0.09846800994387807*lm^2) + 
        0.015867939975662503*NM + 0.005001699304798479*lm*NM + 
        0.005470444996882115*lm^2*NM + 0.015869498280214986*NL + 
        0.005001699304798479*lm*NL + 0.005470444996882115*lm^2*NL - 
        0.0025147396288183062*NH + 0.005001699304798479*lm*NH + 
        0.005470444996882115*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.0075496065503110185 - 0.06590359346522018*lm - 
          0.02960412835415843*lm^2) + CF*(0.09011427647920252 + 
          0.019710051244184214*lm + 0.09688623824997304*lm^2) + 
        0.0163933852502104*NM + 0.005131929440647999*lm*NM + 
        0.005382568791665169*lm^2*NM + 0.016401912182702923*NL + 
        0.005131929440647999*lm*NL + 0.005382568791665169*lm^2*NL - 
        0.0024895632491222152*NH + 0.005131929440647999*lm*NH + 
        0.005382568791665169*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.012601768335543054 - 0.06593517016853363*lm - 
          0.029110198410936698*lm^2) + CF*(0.08628069189947135 + 
          0.023083127765115882*lm + 0.09526974025397464*lm^2) + 
        0.016854900241031878*NM + 0.005251968497533159*lm*NM + 
        0.005292763347443036*lm^2*NM + 0.016877326334879077*NL + 
        0.005251968497533159*lm*NL + 0.005292763347443036*lm^2*NL - 
        0.0024634798920292727*NH + 0.005251968497533159*lm*NH + 
        0.005292763347443036*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.017310362818128724 - 0.06589431697634342*lm - 
          0.028608996908409415*lm^2) + CF*(0.08283850944477536 + 
          0.02626729751236408*lm + 0.09362944442752172*lm^2) + 
        0.017249796944853596*NM + 0.005360521157389188*lm*NM + 
        0.005201635801528984*lm^2*NM + 0.017293450054446984*NL + 
        0.005360521157389188*lm*NL + 0.005201635801528984*lm^2*NL - 
        0.0024365898297860436*NH + 0.005360521157389188*lm*NH + 
        0.005201635801528984*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.02166584945795037 - 0.06578166396684164*lm - 
          0.028103137518317608*lm^2) + CF*(0.07975501259300505 + 
          0.029247320485098215*lm + 0.09197390460540308*lm^2) + 
        0.017579138851820962*NM + 0.005457097163286141*lm*NM + 
        0.005109661366966838*lm^2*NM + 0.017651221040336437*NL + 
        0.005457097163286141*lm*NL + 0.005109661366966838*lm^2*NL - 
        0.0024089803944942283*NH + 0.005457097163286141*lm*NH + 
        0.005109661366966838*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.02567116407398516 - 0.06559961487169563*lm - 
          0.027594735108560964*lm^2) + CF*(0.07699418410510712 + 
          0.032017063365571405*lm + 0.09031004217347224*lm^2) + 
        0.017845726785088903*NM + 0.005541644166426421*lm*NM + 
        0.005017224565192903*lm^2*NM + 0.017953035803002913*NL + 
        0.005541644166426421*lm*NL + 0.005017224565192903*lm^2*NL - 
        0.0023807298561299662*NH + 0.005541644166426421*lm*NH + 
        0.005017224565192903*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.029336065463341648 - 0.06535152988921601*lm - 
          0.027085533555212236*lm^2) + CF*(0.0745206741753215 + 
          0.034575978995078846*lm + 0.08864356436251278*lm^2) + 
        0.018053203273863144*NM + 0.005614369570386857*lm*NM + 
        0.004924642464584043*lm^2*NM + 0.018201982444339238*NL + 
        0.005614369570386857*lm*NL + 0.004924642464584043*lm^2*NL - 
        0.002351909548020944*NH + 0.005614369570386857*lm*NH + 
        0.004924642464584043*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.03267414136640044 - 0.06504127989820759*lm - 
          0.02657698779322569*lm^2) + CF*(0.07230134928950117 + 
          0.03692710427534234*lm + 0.08697923277782953*lm^2) + 
        0.018205590406098943*NM + 0.005675640492150805*lm*NM + 
        0.004832179598768307*lm^2*NM + 0.018401453228537038*NL + 
        0.005675640492150805*lm*NL + 0.004832179598768307*lm^2*NL - 
        0.0023225851845286812*NH + 0.005675640492150805*lm*NH + 
        0.004832179598768307*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.03570107634163724 - 0.06467298276792467*lm - 
          0.026070320794710816*lm^2) + CF*(0.07030585849036199 + 
          0.03907581999615544*lm + 0.08532104987359904*lm^2) + 
        0.018307031760663287*NM + 0.005725922633408595*lm*NM + 
        0.004740058326311057*lm^2*NM + 0.01855493233557912*NL + 
        0.005725922633408595*lm*NL + 0.004740058326311057*lm^2*NL - 
        0.0022928177429231253*NH + 0.005725922633408595*lm*NH + 
        0.004740058326311057*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.03843359328346099 - 0.06425083961383028*lm - 
          0.025566565290132497*lm^2) + CF*(0.06850676029932994 + 
          0.041029038757691406*lm + 0.08367239549497908*lm^2) + 
        0.018361642150849875*NM + 0.005765740854384762*lm*NM + 
        0.004648466416387727*lm^2*NM + 0.018665874427285643*NL + 
        0.005765740854384762*lm*NL + 0.004648466416387727*lm^2*NL - 
        0.0022626640868161356*NH + 0.005765740854384762*lm*NH + 
        0.004648466416387727*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.04088878418901504 - 0.06377903023123735*lm - 
          0.025066595506770088*lm^2) + CF*(0.06687944524456253 + 
          0.04279465264997645*lm + 0.08203613074942938*lm^2) + 
        0.0183734188037561*NM + 0.005795652817336027*lm*NM + 
        0.004557562819412743*lm^2*NM + 0.018737634061706993*NL + 
        0.005795652817336027*lm*NL + 0.004557562819412743*lm^2*NL - 
        0.0022321774262648248*NH + 0.005795652817336027*lm*NH + 
        0.004557562819412743*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.04308367891593674 - 0.06326164550860787*lm - 
          0.02457115201676865*lm^2) + CF*(0.06540196470622271 + 
          0.04438114757005805*lm + 0.0804146793276065*lm^2) + 
        0.01834618942149221*NM + 0.00581623094809794*lm*NM + 
        0.004467482184867028*lm^2*NM + 0.018773425137672297*NL + 
        0.00581623094809794*lm*NL + 0.004467482184867028*lm^2*NL - 
        0.0022014076698040454*NH + 0.00581623094809794*lm*NH + 
        0.004467482184867028*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.04503496563519312 - 0.06270264387896787*lm - 
          0.024080861629667386*lm^2) + CF*(0.06405482116367087 + 
          0.04579732901411325*lm + 0.07881009260618417*lm^2) + 
        0.018283583198829126*NM + 0.005828049914930632*lm*NM + 
        0.004378338478121343*lm^2*NM + 0.018776298746252054*NL + 
        0.005828049914930632*lm*NL + 0.004378338478121343*lm^2*NL - 
        0.002170401702433048*NH + 0.005828049914930632*lm*NH + 
        0.004378338478121343*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.04675881102843964 - 0.06210582385912883*lm - 
          0.02359625360297265*lm^2) + CF*(0.06282074807717215 + 
          0.047052124894495256*lm + 0.07722410270063776*lm^2) + 
        0.018189016479459703*NM + 0.005831677884442977*lm*NM + 
        0.004290227927813209*lm^2*NM + 0.018749132590024867*NL + 
        0.005831677884442977*lm*NL + 0.004290227927813209*lm^2*NL - 
        0.002139203611442647*NH + 0.005831677884442977*lm*NH + 
        0.004290227927813209*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.04827074760570016 - 0.06147480758735623*lm - 
          0.02311777304384658*lm^2) + CF*(0.061684493946855865 + 
          0.04815444294604923*lm + 0.07565816632531608*lm^2) + 
        0.01806568788003082*NM + 0.005827670427224239*lm*NM + 
        0.00420323146251756*lm^2*NM + 0.0186946277793655*NL + 
        0.005827670427224239*lm*NL + 0.00420323146251756*lm^2*NL - 
        0.0021078548746448424*NH + 0.005827670427224239*lm*NH + 
        0.00420323146251756*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.04958560695051802 - 0.06081303199237604*lm - 
          0.022645792120762516*lm^2) + CF*(0.06063261783520857 + 
          0.04911306760537302*lm + 0.07411350148613187*lm^2) + 
        0.01791657956600781*NM + 0.005816566317776218*lm*NM + 
        0.004117416749229549*lm^2*NM + 0.018615310355105563*NL + 
        0.005816566317776218*lm*NL + 0.004117416749229549*lm^2*NL - 
        0.0020763945209550435*NH + 0.005816566317776218*lm*NH + 
        0.004117416749229549*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.05071748474275624 - 0.060123745305827335*lm - 
          0.022180619536211733*lm^2) + CF*(0.05965329969370215 + 
          0.04993658588927294*lm + 0.0725911184821475*lm^2) + 
        0.01774446250106169*NM + 0.00579888470838242*lm*NM + 
        0.0040328399156748605*lm^2*NM + 0.018513535819157118*NL + 
        0.00579888470838242*lm*NL + 0.0040328399156748605*lm^2*NL - 
        0.0020448592702720985*NH + 0.00579888470838242*lm*NH + 
        0.0040328399156748605*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.05167972789811628 - 0.05941000732950444*lm - 
          0.021722508597148176*lm^2) + CF*(0.058736166662139065 + 
          0.050633334844364185*lm + 0.0710918463179395*lm^2) + 
        0.017551904212495528*NM + 0.0057751233101566*lm*NM + 
        0.003949547017663305*lm^2*NM + 0.018391495537856184*NL + 
        0.0057751233101566*lm*NL + 0.003949547017663305*lm^2*NL - 
        0.0020132836575880637*NH + 0.0057751233101566*lm*NH + 
        0.003949547017663305*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.052484937107161476 - 0.058674692334687195*lm - 
          0.021271664139638068*lm^2) + CF*(0.05787213531727035 + 
          0.05121136519575236*lm + 0.06961635536608822*lm^2) + 
        0.01734127808442903*NM + 0.005745757317795474*lm*NM + 
        0.0038675752981160126*lm^2*NM + 0.018251224257682865*NL + 
        0.005745757317795474*lm*NL + 0.0038675752981160126*lm^2*NL - 
        0.00198170014487957*NH + 0.005745757317795474*lm*NH + 
        0.0038675752981160126*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.053144980034300036 - 0.05792049378886411*lm - 
          0.020828248506551256*lm^2) + CF*(0.05705326920909195 + 
          0.051678417244980436*lm + 0.06816517693053138*lm^2) + 
        0.017114773502778156*NM + 0.005711238885715499*lm*NM + 
        0.00378695427391841*lm^2*NM + 0.018094608219564465*NL + 
        0.005711238885715499*lm*NL + 0.00378695427391841*lm^2*NL - 
        0.0019501392233685587*NH + 0.005711238885715499*lm*NH + 
        0.00378695427391841*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.05367101179354057 - 0.05714993032665769*lm - 
          0.020392386734844795*lm^2) + CF*(0.05627265070275211 + 
          0.05204190607227904*lm + 0.06673872022312842*lm^2) + 
        0.01687440638783823*NM + 0.00567199701331252*lm*NM + 
        0.00370770667906269*lm^2*NM + 0.01792339352319782*NL + 
        0.00567199701331252*lm*NL + 0.00370770667906269*lm^2*NL - 
        0.00191862950805603*NH + 0.00567199701331252*lm*NH + 
        0.00370770667906269*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.05407350026466373 - 0.05636535253877084*lm - 
          0.01996417107737838*lm^2) + CF*(0.05552426600685529 + 
          0.05230891382126586*lm + 0.06533728716232926*lm^2) + 
        0.01662202979607181*NM + 0.005628437732945155*lm*NM + 
        0.0036298492867960696*lm^2*NM + 0.017739194505292086*NL + 
        0.005628437732945155*lm*NL + 0.0036298492867960696*lm^2*NL - 
        0.0018871978259407125*NH + 0.005628437732945155*lm*NH + 
        0.0036298492867960696*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.054362254484495706 - 0.05556895026574813*lm - 
          0.019543664960176704*lm^2) + CF*(0.05480290223713593 + 
          0.05248618737301421*lm + 0.06396108532421467*lm^2) + 
        0.0163593443743084*NM + 0.005580944520343067*lm*NM + 
        0.0035533936291230373*lm^2*NM + 0.01754350197314916*NL + 
        0.005580944520343067*lm*NL + 0.0035533936291230373*lm^2*NL - 
        0.0018558692989772655*NH + 0.005580944520343067*lm*NH + 
        0.0035533936291230373*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.05454645482975571 - 0.05476276016568625*lm - 
          0.019130906457523456*lm^2) + CF*(0.054104055392031974 + 
          0.05258014010855756*lm + 0.06261023931553131*lm^2) + 
        0.016087908521051443*NM + 0.005529878866400336*lm*NM + 
        0.0034783466286406285*lm^2*NM + 0.01733769118894977*NL + 
        0.005529878866400336*lm*NL + 0.0034783466286406285*lm^2*NL - 
        0.0018246674225668343*NH + 0.005529878866400336*lm*NH + 
        0.0034783466286406285*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.05463468405768413 - 0.053948673385700974*lm - 
          0.01872591135278853*lm^2) + CF*(0.05342384817626219 + 
          0.05259685675333862*lm + 0.06128480079094428*lm^2) + 
        0.015809148160234668*NM + 0.005475580963697046*lm*NM + 
        0.00340471115505246*lm^2*NM + 0.017123029537928144*NL + 
        0.005475580963697046*lm*NL + 0.00340471115505246*lm^2*NL - 
        0.0017936141401795787*NH + 0.005475580963697046*lm*NH + 
        0.00340471115505246*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.054634958526892305 - 0.053128443212077645*lm - 
          0.018328675841433568*lm^2) + CF*(0.052758956683761356 + 
          0.05254210052061536*lm + 0.059984757299237135*lm^2) + 
        0.015524366068804262*NM + 0.005418370471946845*lm*NM + 
        0.003332486516624285*lm^2*NM + 0.016900683840235964*NL + 
        0.005418370471946845*lm*NL + 0.003332486516624285*lm^2*NL - 
        0.0017627299145654973*NH + 0.005418370471946845*lm*NH + 
        0.003332486516624285*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.05455475911003752 - 0.05230369260784184*lm - 
          0.017939178923480584*lm^2) + CF*(0.05210654503253226 + 
          0.05242132194212744*lm + 0.05871004011320918*lm^2) + 
        0.015234750725178383*NM + 0.00535854733483524*lm*NM + 
        0.003261668895178288*lm^2*NM + 0.016671727285055744*NL + 
        0.00535854733483524*lm*NL + 0.003261668895178288*lm^2*NL - 
        0.0017320337959031563*NH + 0.00535854733483524*lm*NH + 
        0.003261668895178288*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.05440106145042103 - 0.05147592157197651*lm - 
          0.017557384525331034*lm^2) + CF*(0.051464207125426376 + 
          0.052239668906715206*lm + 0.057460531173810656*lm^2) + 
        0.014941384663897614*NM + 0.005296392627059623*lm*NM + 
        0.0031922517318783697*lm^2*NM + 0.01643714597871511*NL + 
        0.005296392627059623*lm*NL + 0.0031922517318783697*lm^2*NL - 
        0.001701543487156266*NH + 0.005296392627059623*lm*NH + 
        0.0031922517318783697*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.05418036531942341 - 0.05064651427381741*lm - 
          0.017183243384795484*lm^2) + CF*(0.05082991478932055 + 
          0.052001997530665395*lm + 0.056236069259330675*lm^2) + 
        0.014645252334696717*NM + 0.005232169415286855*lm*NM + 
        0.003124226069962815*lm^2*NM + 0.016197845107768196*NL + 
        0.005232169415286855*lm*NL + 0.003124226069962815*lm^2*NL - 
        0.0016712754068485193*NH + 0.005232169415286855*lm*NH + 
        0.003124226069962815*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.05389872291012105 - 0.04981674593082637*lm - 
          0.016816694728242543*lm^2) + CF*(0.05020197161887402 + 
          0.051712883564338556*lm + 0.05503645547424832*lm^2) + 
        0.014347247473267412*NM + 0.005166123620556933*lm*NM + 
        0.003057580859680462*lm^2*NM + 0.01595465472436798*NL + 
        0.005166123620556933*lm*NL + 0.003057580859680462*lm^2*NL - 
        0.0016412447494226054*NH + 0.005166123620556933*lm*NH + 
        0.003057580859680462*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.05356176596118519 - 0.048987789409103775*lm - 
          0.016457667764677414*lm^2) + CF*(0.04957897191921195 + 
          0.05137663410329328*lm + 0.05386145813894426*lm^2) + 
        0.014048179997198457*NM + 0.005098484872638971*lm*NM + 
        0.0029923032299413476*lm^2*NM + 0.015708335165548475*NL + 
        0.005098484872638971*lm*NL + 0.0029923032299413476*lm^2*NL - 
        0.0016114655433161211*NH + 0.005098484872638971*lm*NH + 
        0.0029923032299413476*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.053174731649160284 - 0.0481607215344945*lm - 
          0.016106083018144677*lm^2) + CF*(0.04895976420422747 + 
          0.05099729942252839*lm + 0.05271081715029167*lm^2) + 
        0.013748782444738558*NM + 0.0050294673491803965*lm*NM + 
        0.0029283787305717595*lm^2*NM + 0.015459582120838842*NL + 
        0.0050294673491803965*lm*NL + 0.0029283787305717595*lm^2*NL - 
        0.0015819507068623993*NH + 0.0050294673491803965*lm*NH + 
        0.0029283787305717595*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.052742487220066935 - 0.04733652910859033*lm - 
          0.015761853516984885*lm^2) + CF*(0.04834341876379272 + 
          0.050578684792536195*lm + 0.05158424787376871*lm^2) + 
        0.013449715976696171*NM + 0.004959270594325708*lm*NM + 
        0.0028657915485427064*lm^2*NM + 0.015209031364353634*NL + 
        0.004959270594325708*lm*NL + 0.0028657915485427064*lm^2*NL - 
        0.00155271210210597*NH + 0.004959270594325708*lm*NH + 
        0.0028657915485427064*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.05226955335566587 - 0.046516114628808294*lm - 
          0.015424885856057396*lm^2) + CF*(0.047729198864273445 + 
          0.05012436216781909*lm + 0.050481444619824206*lm^2) + 
        0.013151575963400509*NM + 0.004888080312927069*lm*NM + 
        0.002804524701101345*lm^2*NM + 0.014957263168444703*NL + 
        0.004888080312927069*lm*NL + 0.002804524701101345*lm^2*NL - 
        0.0015237605866088944*NH + 0.004888080312927069*lm*NH + 
        0.002804524701101345*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.05176012628765976 - 0.045700301715384396*lm - 
          0.015095081145991394*lm^2) + CF*(0.047116535192691426 + 
          0.04963768166407533*lm + 0.04940208375051729*lm^2) + 
        0.012854897179556153*NM + 0.004816069137609073*lm*NM + 
        0.0027445602083620716*lm^2*NM + 0.014704806416379466*NL + 
        0.004816069137609073*lm*NL + 0.0027445602083620716*lm^2*NL - 
        0.0014951060633143583*NH + 0.004816069137609073*lm*NH + 
        0.0027445602083620716*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.05121809868610007 - 0.04488984025084047*lm - 
          0.014772335861778885*lm^2) + CF*(0.046505003196036954 + 
          0.049121782760726755*lm + 0.0483458264567309*lm^2) + 
        0.012560158630367791*NM + 0.004743397366848607*lm*NM + 
        0.002685879247596161*lm^2*NM + 0.01445214243148813*NL + 
        0.004743397366848607*lm*NL + 0.002685879247596161*lm^2*NL - 
        0.0014667575285267872*NH + 0.004743397366848607*lm*NH + 
        0.002685879247596161*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.0506470793574169 - 0.04408541123946712*lm - 
          0.014456542601526233*lm^2) + CF*(0.045894303003924095 + 
          0.04857960518187162*lm + 0.04731232124135858*lm^2) + 
        0.012267788032889611*NM + 0.004670213672938364*lm*NM + 
        0.0026284622911865877*lm^2*NM + 0.014199708539917935*NL + 
        0.004670213672938364*lm*NL + 0.0026284622911865877*lm^2*NL - 
        0.0014387231180626328*NH + 0.004670213672938364*lm*NH + 
        0.0026284622911865877*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.05005041179359122 - 0.043287631395781734*lm - 
          0.014147590764892675*lm^2) + CF*(0.045284241655228125 + 
          0.048013899421905246*lm + 0.046301206139648755*lm^2) + 
        0.011978165977737425*NM + 0.0045966557792578785*lm*NM + 
        0.002572289229980486*lm^2*NM + 0.013947901383632869*NL + 
        0.0045966557792578785*lm*NL + 0.002572289229980486*lm^2*NL - 
        0.001411010151622401*NH + 0.0045966557792578785*lm*NH + 
        0.002572289229980486*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.04943119161754076 - 0.042497057471892453*lm - 
          0.013845367159631888*lm^2) + CF*(0.04467471737757796 + 
          0.047427236892597265*lm + 0.04531211070424982*lm^2) + 
        0.01169162979901396*NM + 0.0045228511067102566*lm*NM + 
        0.0025173394835694344*lm^2*NM + 0.013697079999667433*NL + 
        0.0045228511067102566*lm*NL + 0.0025173394835694344*lm^2*NL - 
        0.0013836251754319904*NH + 0.0045228511067102566*lm*NH + 
        0.0025173394835694344*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.04879228312006094 - 0.041714190334326565*lm - 
          0.013549756543688254*lm^2) + CF^2*(0.04406570599044979 + 
          0.04682201967685148*lm + 0.04434465777934338*lm^2) + 
        CF*((0.011408476248597234 + 0.004448917389519945*lm + 
            0.00246359209885241*lm^2)*NM + (0.01344756868093078 + 
            0.004448917389519945*lm + 0.00246359209885241*lm^2)*NL + 
          (-0.0013565740031997228 + 0.004448917389519945*lm + 
            0.00246359209885241*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.04813633424354478 - 0.04093947880124176*lm - 
          0.0132606421094605*lm^2) + CF^2*(0.04345724784343228 + 
          0.04620048988110642*lm + 0.043398465085507085*lm^2) + 
        CF*((0.01112896743382378 + 0.004374963260846486*lm + 
            0.0024110258380837272*lm^2)*NM + (0.01319965963309785 + 
            0.004374963260846486*lm + 0.0024110258380837272*lm^2)*NL + 
          (-0.0013298617554343226 + 0.004374963260846486*lm + 
            0.0024110258380837272*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.047465791523037454 - 0.04017332325109172*lm - 
          0.012977905916113225*lm^2) + CF^2*(0.042849438032359195 + 
          0.04556473858368287*lm + 0.04247314663455237*lm^2) + 
        CF*((0.010853330642521104 + 0.004301088808866508*lm + 
            0.002359619257475132*lm^2)*NM + (0.012953615441343016 + 
            0.004301088808866508*lm + 0.002359619257475132*lm^2)*NL + 
          (-0.0013034928971683677 + 0.004301088808866508*lm + 
            0.002359619257475132*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.0467829133464468 - 0.03941607901381225*lm - 
          0.01270142927517581*lm^2) + CF^2*(0.042242416358185104 + 
          0.04491671438061015*lm + 0.04156831399148447*lm^2) + 
        CF*((0.010581762988757083 + 0.004227386104123528*lm + 
            0.0023093507773046923*lm^2)*NM + (0.012709671359887788 + 
            0.004227386104123528*lm + 0.0023093507773046923*lm^2)*NL + 
          (-0.0012774712741312406 + 0.004227386104123528*lm + 
            0.0023093507773046923*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.04608978270394006 - 0.03866805955546773*lm - 
          0.012431093094105514*lm^2) + CF^2*(0.04163635912860212 + 
          0.044258231533774436*lm + 0.04068357739889077*lm^2) + 
        CF*((0.01031443362129294 + 0.004153939699052362*lm + 
            0.0022601987443828207*lm^2)*NM + (0.012468037436560617 + 
            0.004153939699052362*lm + 0.0022601987443828207*lm^2)*NL + 
          (-0.0012518001474154466 + 0.004153939699052362*lm + 
            0.0022601987443828207*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.04538831907151371 - 0.03792953946708041*lm - 
          0.012166778181996293*lm^2) + CF^2*(0.041031471869991364 + 
          0.0435909777288001*lm + 0.03981854677744241*lm^2) + 
        CF*((0.010051486131726668 + 0.004080827100660106*lm + 
            0.0022121414876356896*lm^2)*NM + (0.012228900483813593 + 
            0.004080827100660106*lm + 0.0022121414876356896*lm^2)*NL + 
          (-0.0012264822266790708 + 0.004080827100660106*lm + 
            0.0022121414876356896*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.04468028953595905 - 0.03720075726808061*lm - 
          0.011908365521177773*lm^2) + CF^2*(0.040427982958404225 + 
          0.042916521452037386*lm + 0.03897283261476362*lm^2) + 
        CF*((0.009793040778581463 + 0.004008119217395006*lm + 
            0.0021651573674868678*lm^2)*NM + (0.011992425906913896 + 
            0.004008119217395006*lm + 0.0021651573674868678*lm^2)*NL + 
          (-0.0012015197019298856 + 0.004008119217395006*lm + 
            0.0021651573674868678*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.04396731920571126 - 0.03648191803448306*lm - 
          0.011655736508062342*lm^2) + CF^2*(0.03982613806837096 + 
          0.0422363189974988*lm + 0.038146046753658576*lm^2) + 
        CF*((0.009539196540574247 + 0.0039358807812634854*lm + 
            0.0021192248196476985*lm^2)*NM + (0.011758759399331709 + 
            0.0039358807812634854*lm + 0.0021192248196476985*lm^2)*NL + 
          (-0.001176914273930453 + 0.0039358807812634854*lm + 
            0.0021192248196476985*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.04325090094999987 - 0.03577319586152791*lm - 
          0.011408773166255633*lm^2) + CF^2*(0.03922619534872961 + 
          0.04155172111565529*lm + 0.03733780308956389*lm^2) + 
        CF*((0.009290033011599802 + 0.0038641707462682335*lm + 
            0.0020743223938646605*lm^2)*NM + (0.011528028514683517 + 
            0.0038641707462682335*lm + 0.0020743223938646605*lm^2)*NL + 
          (-0.0011526671832709113 + 0.0038641707462682335*lm + 
            0.0020743223938646605*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.04253240450694932 - 0.03507473617013639*lm - 
          0.011167358334641395*lm^2) + CF^2*(0.03862842124465677 + 
          0.04086397931674591*lm + 0.03654771818609911*lm^2) + 
        CF*((0.009045612148890365 + 0.0037930426642400136*lm + 
            0.002030428788116617*lm^2)*NM + (0.011300344123961439 + 
            0.0037930426642400136*lm + 0.002030428788116617*lm^2)*NL + 
          (-0.001128779238149789 + 0.0037930426642400136*lm + 
            0.002030428788116617*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.04181308499909699 - 0.03438665786613005*lm - 
          0.01093137583288096*lm^2) + CF^2*(0.03803308689328398 + 
          0.040174251841734294*lm + 0.035775411816701325*lm^2) + 
        CF*((0.008805979885202722 + 0.0037225450391255716*lm + 
            0.0019875228787056293*lm^2)*NM + (0.011075801766186083 + 
            0.0037225450391255716*lm + 0.0019875228787056293*lm^2)*NL + 
          (-0.001105250840905813 + 0.0037225450391255716*lm + 
            0.0019875228787056293*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.041094090892857205 - 0.033709055360755254*lm - 
          0.01070071060652606*lm^2) + CF^2*(0.03744046502805213 + 
          0.03948360931431161*lm + 0.035020507439539834*lm^2) + 
        CF*((0.008571167615039421 + 0.0036527216607759156*lm + 
            0.001945583746641102*lm^2)*NM + (0.010854482900062015 + 
            0.0036527216607759156*lm + 0.001945583746641102*lm^2)*NL + 
          (-0.0010820820133424088 + 0.0036527216607759156*lm + 
            0.001945583746641102*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.04037647143642378 - 0.033042000460648195*lm - 
          0.010475248853728173*lm^2) + CF^2*(0.036850827333666826 + 
          0.03879304008744148*lm + 0.03428263261220129*lm^2) + 
        CF*((0.008341193564232645 + 0.003583611919255136*lm + 
            0.0019045907006778496*lm^2)*NM + (0.010636456063690555 + 
            0.003583611919255136*lm + 0.0019045907006778496*lm^2)*NL + 
          (-0.0010592724208864676 + 0.003583611919255136*lm + 
            0.0019045907006778496*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.039661183608584616 - 0.03238554413497276*lm - 
          0.010254878135334745*lm^2) + CF^2*(0.03626444219944728 + 
          0.03810345529790148*lm + 0.03356141935200462*lm^2) + 
        CF*((0.00811606405153841 + 0.003515251100661386*lm + 
            0.0018645232973335901*lm^2)*NM + (0.010421777948903244 + 
            0.003515251100661386*lm + 0.0018645232973335901*lm^2)*NL + 
          (-0.0010368213956219664 + 0.003515251100661386*lm + 
            0.0018645232973335901*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.038949098608894964 - 0.03173971816706886*lm - 
          0.01003948746998994*lm^2) + CF^2*(0.03568157282401598 + 
          0.03741569364212664*lm + 0.03285650444723981*lm^2) + 
        CF*((0.00789577465032147 + 0.0034476706654198055*lm + 
            0.0018253613581799893*lm^2)*NM + (0.01021049439631966 + 
            0.0034476706654198055*lm + 0.0018253613581799893*lm^2)*NL + 
          (-0.001014727958238807 + 0.0034476706654198055*lm + 
            0.0018253613581799893*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.03824100791761662 - 0.031104536697564085*lm - 
          0.009828967415702534*lm^2) + CF^2*(0.03510247562869457 + 
          0.03673052588642685*lm + 0.032167529724117384*lm^2) + 
        CF*((0.0076803112577423765 + 0.0033808985099730493*lm + 
            0.001787084984673188*lm^2)*NM + (0.010002641316803798 + 
            0.0033808985099730493*lm + 0.001787084984673188*lm^2)*NL + 
          (-0.0009929908389364704 + 0.0033808985099730493*lm + 
            0.001787084984673188*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.03753762895169471 - 0.030479997665528266*lm - 
          0.009623210139204478*lm^2) + CF^2*(0.03452739894053842 + 
          0.036048659124350464*lm + 0.03149414227376011*lm^2) + 
        CF*((0.007469651078423183 + 0.0033149592127594747*lm + 
            0.0017496745707644506*lm^2)*NM + (0.009798245544592549 + 
            0.0033149592127594747*lm + 0.0017496745707644506*lm^2)*NL + 
          (-0.0009716084973212996 + 0.0033149592127594747*lm + 
            0.0017496745707644506*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.03683961034086542 - 0.029866084153890863*lm - 
          0.009422109474298451*lm^2) + CF^2*(0.033956581908810964 + 
          0.03537074079361754*lm + 0.03083599464315857*lm^2) + 
        CF*((0.007263763528970613 + 0.0032498742653325812*lm + 
            0.0017131108135088095*lm^2)*NM + (0.009597325626996299 + 
            0.0032498742653325812*lm + 0.0017131108135088095*lm^2)*NL + 
          (-0.0009505791413352067 + 0.0032498742653325812*lm + 
            0.0017131108135088095*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.03614753684571662 - 0.02926276564499526*lm - 
          0.009225560970280001*lm^2) + CF^2*(0.03339025362081287 + 
          0.03469736246465987*lm + 0.030192744993643637*lm^2) + 
        CF*((0.007062611069350671 + 0.0031856622894384777*lm + 
            0.001677374721869091*lm^2)*NM + (0.009399892555223732 + 
            0.0031856622894384777*lm + 0.001677374721869091*lm^2)*NL + 
          (-0.0009299007452540976 + 0.0031856622894384777*lm + 
            0.001677374721869091*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.035461933937363195 - 0.028669999191832475*lm - 
          0.00903346193141828*lm^2) + CF^2*(0.03282863238479383 + 
          0.034029063412393534*lm + 0.029564057230096193*lm^2) + 
        CF*((0.006866149966573449 + 0.0031223392408314264*lm + 
            0.001642447623894233*lm^2)*NM + (0.009205950440559154 + 
            0.0031223392408314264*lm + 0.001642447623894233*lm^2)*NL + 
          (-0.0009095710667906361 + 0.0031223392408314264*lm + 
            0.001642447623894233*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.0347831393775409 - 0.0280877305101803*lm - 
          0.008845711448387762*lm^2) + CF^2*(0.03227165979160579 + 
          0.033366333982419845*lm + 0.028949601103814494*lm^2) + 
        CF*((0.006674330995892766 + 0.003059918600571151*lm + 
            0.0016083111724341384*lm^2)*NM + (0.009015497139819351 + 
            0.003059918600571151*lm + 0.0016083111724341384*lm^2)*NL + 
          (-0.0008895876633388677 + 0.003059918600571151*lm + 
            0.0016083111724341384*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.03411185594223177 - 0.027515894996572046*lm - 
          0.008662210422460404*lm^2) + CF^2*(0.03172009778057423 + 
          0.03270961876241113*lm + 0.028349052291688593*lm^2) + 
        CF*((0.006487100084134046 + 0.0029984115545098654*lm + 
            0.0015749473495382553*lm^2)*NM + (0.008828524833736981 + 
            0.0029984115545098654*lm + 0.0015749473495382553*lm^2)*NL + 
          (-0.0008699479073938319 + 0.0029984115545098654*lm + 
            0.0015749473495382553*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.033448305062824465 - 0.02695441867673185*lm - 
          0.008482861583192997*lm^2) + CF^2*(0.031173828201631556 + 
          0.032059319568993556*lm + 0.027762092454086174*lm^2) + 
        CF*((0.00630439889968922 + 0.0029378271616421216*lm + 
            0.0015423384696714542*lm^2)*NM + (0.008645020561657092 + 
            0.0029378271616421216*lm + 0.0015423384696714542*lm^2)*NL + 
          (-0.00085064900118062 + 0.0029378271616421216*lm + 
            0.0015423384696714542*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.03279281585519818 - 0.02640321908884075*lm - 
          0.008307569500276583*lm^2) + CF^2*(0.030633023762932775 + 
          0.03141579825999499*lm + 0.027188409273632454*lm^2) + 
        CF*((0.006126165393068287 + 0.0028781725119566295*lm + 
            0.0015104671818684696*lm^2)*NM + (0.008464966715691543 + 
            0.0028781725119566295*lm + 0.0015104671818684696*lm^2)*NL + 
          (-0.0008316879905257603 + 0.0028781725119566295*lm + 
            0.0015104671818684696*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.03214567700523791 - 0.025862206105739236*lm - 
          0.00813624059015354*lm^2) + CF^2*(0.03009784525346763 + 
          0.03077937938148555*lm + 0.02662769647686613*lm^2) + 
        CF*((0.0059523342919275725 + 0.002819452874396397*lm + 
            0.0014793164709370073*lm^2)*NM + (0.00828834149725133 + 
            0.002819452874396397*lm + 0.0014793164709370073*lm^2)*NL + 
          (-0.0008130617780019137 + 0.002819452874396397*lm + 
            0.0014793164709370073*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.03150713980673407 - 0.025331282699926797*lm - 
          0.007968783117952325*lm^2) + CF^2*(0.029568441588805946 + 
          0.030150352658604954*lm + 0.026079653840571246*lm^2) + 
        CF*((0.005782837553965731 + 0.002761671835501855*lm + 
            0.0014488696578095137*lm^2)*NM + (0.008115119338668209 + 
            0.002761671835501855*lm + 0.0014488696578095137*lm^2)*NL + 
          (-0.0007947671353779084 + 0.002761671835501855*lm + 
            0.0014488696578095137*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.03087742099416558 - 0.024810345654987544*lm - 
          0.007805107195239422*lm^2) + CF^2*(0.02904494992464102 + 
          0.029528975338746204*lm + 0.025543987184419928*lm^2) + 
        CF*((0.0056176047807080945 + 0.002704831429281175*lm + 
            0.0014191103991344405*lm^2)*NM + (0.007945271292423206 + 
            0.002704831429281175*lm + 0.0014191103991344405*lm^2)*NL + 
          (-0.0007768007154027977 + 0.002704831429281175*lm + 
            0.0014191103991344405*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.030256705382994752 - 0.02429928622685172*lm - 
          0.007645124774042291*lm^2) + CF^2*(0.028527495826216068 + 
          0.02891547439525129*lm + 0.025020408351411134*lm^2) + 
        CF*((0.0054565635969064455 + 0.002648932258822758*lm + 
            0.0013900226861895074*lm^2)*NM + (0.007778765390319651 + 
            0.002648932258822758*lm + 0.0013900226861895074*lm^2)*NL + 
          (-0.0007591590629526862 + 0.002648932258822758*lm + 
            0.0013900226861895074*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.029645148332589497 - 0.02379799075809635*lm - 
          0.007488749637555551*lm^2) + CF^2*(0.02801619348960406 + 
          0.02831004859937321*lm + 0.02450863517745453*lm^2) + 
        CF*((0.005299639992829606 + 0.002593973610136895*lm + 
            0.0013615908431919184*lm^2)*NM + (0.007615566974771442 + 
            0.002593973610136895*lm + 0.0013615908431919184*lm^2)*NL + 
          (-0.0007418386255730452 + 0.002593973610136895*lm + 
            0.0013615908431919184*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.02904287803903478 - 0.0233063412482931*lm - 
          0.007335897387904881*lm^2) + CF^2*(0.027511145997783388 + 
          0.027712870467869903*lm + 0.024008391451325065*lm^2) + 
        CF*((0.005146758641688838 + 0.002539953558686872*lm + 
            0.0013337995250736147*lm^2)*NM + (0.007455639004222081 + 
            0.002539953558686872*lm + 0.0013337995250736147*lm^2)*NL + 
          (-0.000724835763432794 + 0.002539953558686872*lm + 
            0.0013337995250736147*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.02844999767395773 - 0.02282421588322744*lm - 
          0.007186485431308741*lm^2) + CF^2*(0.027012445614643218 + 
          0.027124088093221203*lm + 0.023519406866101333*lm^2) + 
        CF*((0.004997843183883732 + 0.002486869069044289*lm + 
            0.0013066337147834073*lm^2)*NM + (0.0072989423345661865 + 
            0.002486869069044289*lm + 0.0013066337147834073*lm^2)*NL + 
          (-0.0007081467587299066 + 0.002486869069044289*lm + 
            0.0013066337147834073*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.02786658737561285 - 0.022351489525640058*lm - 
          0.00704043296094686*lm^2) + CF^2*(0.026520174102567743 + 
          0.0265438268630994*lm + 0.023041416963098815*lm^2) + 
        CF*((0.004852816488153146 + 0.002434716088079084*lm + 
            0.0012800787201721563*lm^2)*NM + (0.007145435978311517 + 
            0.002434716088079084*lm + 0.0012800787201721563*lm^2)*NL + 
          (-0.0006917678245608564 + 0.002434716088079084*lm + 
            0.0012800787201721563*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.027292706104207247 - 0.021888034169978057*lm - 
          0.006897660937815947*lm^2) + CF^2*(0.02603440306280649 + 
          0.025972191075377987*lm + 0.022574163069215825*lm^2) + 
        CF*((0.0047116008873368765 + 0.002383489632071659*lm + 
            0.0012541201705119904*lm^2)*NM + (0.00699507734309557 + 
            0.002383489632071659*lm + 0.0012541201705119904*lm^2)*NL + 
          (-0.0006756951132903932 + 0.002383489632071659*lm + 
            0.0012541201705119904*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.02672839336936175 - 0.02143371936349005*lm - 
          0.006758092069827243*lm^2) + CF^2*(0.025555194291595373 + 
          0.025409265454631718*lm + 0.022117392228525525*lm^2) + 
        CF*((0.004574118392905984 + 0.002333183868112548*lm + 
            0.0012287440126958625*lm^2)*NM + (0.006847822451055644 + 
            0.002333183868112548*lm + 0.0012287440126958625*lm^2)*NL + 
          (-0.0006599247244311719 + 0.002333183868112548*lm + 
            0.0012287440126958625*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.026173670838595352 - 0.020988412595854565*lm - 
          0.006621650789376966*lm^2) + CF^2*(0.025082600148750057 + 
          0.024855116575764113*lm + 0.021670857128870073*lm^2) + 
        CF*((0.004440290888155722 + 0.0022837921901342592*lm + 
            0.0012039365071594484*lm^2)*NM + (0.006703626140444453 + 
            0.0022837921901342592*lm + 0.0012039365071594484*lm^2)*NL + 
          (-0.0006444527120704368 + 0.0022837921901342592*lm + 
            0.0012039365071594484*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.025628543834377945 - 0.02055197965939535*lm - 
          0.006488263229599213*lm^2) + CF^2*(0.024616663934401893 + 
          0.024309794200095772*lm + 0.02123431602414288*lm^2) + 
        CF*((0.004310040303710166 + 0.0022353072899001626*lm + 
            0.0011796842235634933*lm^2)*NM + (0.006562442250784091 + 
            0.0022353072899001626*lm + 0.0011796842235634933*lm^2)*NL + 
          (-0.000629275091854277 + 0.0022353072899001626*lm + 
            0.0011796842235634933*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.025093002727350718 - 0.0201242849818093*lm - 
          0.006357857199491324*lm^2) + CF^2*(0.024157420271160274 + 
          0.023773332528958118*lm + 0.020807532652880698*lm^2) + 
        CF*((0.004183288774979752 + 0.0021877212232565913*lm + 
            0.0011559740362711499*lm^2)*NM + (0.0064242237927591315 + 
            0.0021877212232565913*lm + 0.0011559740362711499*lm^2)*NL + 
          (-0.0006143878475537724 + 0.0021877212232565913*lm + 
            0.0011559740362711499*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.024567024232431983 - 0.019705191933212685*lm - 
          0.0062303621580838825*lm^2) + CF^2*(0.023704895488609143 + 
          0.023245751379562255*lm + 0.02039027615372907*lm^2) + 
        CF*((0.004059958784018297 + 0.0021410254719366143*lm + 
            0.001132793119651615*lm^2)*NM + (0.0062889231039640605 + 
            0.0021410254719366143*lm + 0.001132793119651615*lm^2)*NL + 
          (-0.0005997869372363542 + 0.0021410254719366143*lm + 
            0.001132793119651615*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.024050572614279633 - 0.01929456310919837*lm - 
          0.006105709187811238*lm^2) + CF^2*(0.023259108007829474 + 
          0.022727057287650856*lm + 0.019982320978291324*lm^2) + 
        CF*((0.003939973286658856 + 0.002095211001187186*lm + 
            0.0011101289432384068*lm^2)*NM + (0.006156491991540912 + 
            0.002095211001187186*lm + 0.0011101289432384068*lm^2)*NL + 
          (-0.0005854682990542816 + 0.002095211001187186*lm + 
            0.0011101289432384068*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.02354360080808475 - 0.01889226059149088*lm - 
          0.005983830967223621*lm^2) + CF^2*(0.022820068723824364 + 
          0.022217244541192293*lm + 0.019583446801822762*lm^2) + 
        CF*((0.0038232558262803356 + 0.0020502683134755203*lm + 
            0.0010879692667679311*lm^2)*NM + (0.006026881862669205 + 
            0.0020502683134755203*lm + 0.0010879692667679311*lm^2)*NL + 
          (-0.00057142785667729 + 0.0020502683134755203*lm + 
            0.0010879692667679311*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.023046051461325337 - 0.018498146187686373*lm - 
          0.0058646617431683794*lm^2) + CF^2*(0.022387781384117324 + 
          0.02171629614913993*lm + 0.019193438432187425*lm^2) + 
        CF*((0.0037097306351099577 + 0.0020061874985155834*lm + 
            0.0010663021351215237*lm^2)*NM + (0.005900043843801871 + 
            0.0020061874985155834*lm + 0.0010663021351215237*lm^2)*NL + 
          (-0.0005576615243828749 + 0.0020061874985155834*lm + 
            0.0010663021351215237*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.022557857901700257 - 0.018112081651471316*lm - 
          0.005748137302555501*lm^2) + CF^2*(0.02196224296197738 + 
          0.02122418474905525*lm + 0.018812085717454366*lm^2) + 
        CF*((0.003599322724233856 + 0.001962958279841446*lm + 
            0.0010451158731919093*lm^2)*NM + (0.005775928889477262 + 
            0.001962958279841446*lm + 0.0010451158731919093*lm^2)*NL + 
          (-0.0005441652118092674 + 0.001962958279841446*lm + 
            0.0010451158731919093*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.022078945036150422 - 0.0177339288846257*lm - 
          0.005634194943811359*lm^2) + CF^2*(0.02154344402302135 + 
          0.02074087345718081*lm + 0.01843918345247354*lm^2) + 
        CF*((0.003491957963144164 + 0.0019205700581408868*lm + 
            0.0010243990806929743*lm^2)*NM + (0.005654487881478295 + 
            0.0019205700581408868*lm + 0.0010243990806929743*lm^2)*NL + 
          (-0.0005309348284230074 + 0.0019205700581408868*lm + 
            0.0010243990806929743*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.02160923018554898 - 0.017363550122034343*lm - 
          0.0055227734481143*lm^2) + CF^2*(0.021131369084143377 + 
          0.020266316664347483*lm + 0.018074531284737707*lm^2) + 
        CF*((0.0033875631496774017 + 0.0018790119515500424*lm + 
            0.0010041406269298728*lm^2)*NM + (0.00553567171905495 + 
            0.0018790119515500424*lm + 0.0010041406269298728*lm^2)*NL + 
          (-0.0005179662876632334 + 0.0018790119515500424*lm + 
            0.0010041406269298728*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.02114862385930181 - 0.01700080810085251*lm - 
          0.005413813050496324*lm^2) + CF^2*(0.020725996963826057 + 
          0.019800460780909405*lm + 0.017717933619806153*lm^2) + 
        CF*((0.0032860660713887957 + 0.001838272833098001*lm + 
            0.0009843296455447862*lm^2)*NM + (0.0054194314008754255 + 
            0.001838272833098001*lm + 0.0009843296455447862*lm^2)*NL + 
          (-0.0005052555108296495 + 0.001838272833098001*lm + 
            0.0009843296455447862*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.02069703047394642 - 0.01664556621489944*lm - 
          0.005307255410886562*lm^2) + CF^2*(0.02032730112330461 + 
          0.019343244933719354*lm + 0.01736919952653784*lm^2) + 
        CF*((0.003187395558358634 + 0.0017983413654790407*lm + 
            0.0009649555292521022*lm^2)*NM + (0.005305718099323881 + 
            0.0017983413654790407*lm + 0.0009649555292521022*lm^2)*NL + 
          (-0.0004927984306964936 + 0.0017983413654790407*lm + 
            0.0009649555292521022*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.0202543490193539 - 0.016297688655285407*lm - 
          0.00520304358516442*lm^2) + CF^2*(0.01993524999775614 + 
          0.018894601617986118*lm + 0.017028142642356282*lm^2) + 
        CF*((0.0030914815293949936 + 0.0017592060333196295*lm + 
            0.0009460079245753491*lm^2)*NM + (0.005194483227718803 + 
            0.0017592060333196295*lm + 0.0009460079245753491*lm^2)*NL + 
          (-0.00048059099487776305 + 0.0017592060333196295*lm + 
            0.0009460079245753491*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.019820473676146103 - 0.015957040538213965*lm - 
          0.005101121996283156*lm^2) + CF^2*(0.019549807317317636 + 
          0.018454457306693574*lm + 0.016694581078744875*lm^2) + 
        CF*((0.00299825503081377 + 0.0017208551730973462*lm + 
            0.0009274767265969376*lm^2)*NM + (0.00508567850098514 + 
            0.0017208551730973462*lm + 0.0009274767265969376*lm^2)*NL + 
          (-0.0004686291689304181 + 0.0017208551730973462*lm + 
            0.0009274767265969376*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.019395294387522244 - 0.015623488020841216*lm - 
          0.005001436405518137*lm^2) + CF^2*(0.019170932417468166 + 
          0.01802273302010821*lm + 0.01636833732715027*lm^2) + 
        CF*((0.002907648269455858 + 0.0016832770008594952*lm + 
            0.0009093520737305704*lm^2)*NM + (0.0049792559902754234 + 
            0.0016832770008594952*lm + 0.0009093520737305704*lm^2)*NL + 
          (-0.0004569089393021518 + 0.0016832770008594952*lm + 
            0.0009093520737305704*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.018978697388580178 - 0.015296898406017615*lm - 
          0.004903933883888104*lm^2) + CF^2*(0.018798580538618184 + 
          0.017599344857757052*lm + 0.01604923816545198*lm^2) + 
        CF*((0.0028195946398716335 + 0.0016464596378803354*lm + 
            0.0008916243425251099*lm^2)*NM + (0.004875168171999819 + 
            0.0016464596378803354*lm + 0.0008916243425251099*lm^2)*NL + 
          (-0.00044542631596290126 + 0.0016464596378803354*lm + 
            0.0008916243425251099*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.018570565695954236 - 0.014977140236685284*lm - 
          0.004808562783792369*lm^2) + CF^2*(0.01843270311470575 + 
          0.01718420449512136*lm + 0.015737114565138665*lm^2) + 
        CF*((0.0027340287467307626 + 0.0016103911343875199*lm + 
            0.0008742841425077036*lm^2)*NM + (0.004773367971692289 + 
            0.0016103911343875199*lm + 0.0008742841425077036*lm^2)*NL + 
          (-0.00043417733491700147 + 0.0016103911343875199*lm + 
            0.0008742841425077036*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.01817077956047182 - 0.014664083380654218*lm - 
          0.004715272710901924*lm^2) + CF^2*(0.01807324805080747 + 
          0.016777219647162226*lm + 0.015431801599315386*lm^2) + 
        CF*((0.0026508864218058124 + 0.001575059491480487*lm + 
            0.000857322311073077*lm^2)*NM + (0.004673808803109585 + 
            0.001575059491480487*lm + 0.000857322311073077*lm^2)*NL + 
          (-0.0004231580604846622 + 0.001575059491480487*lm + 
            0.000857322311073077*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.017779216885273175 - 0.014357599106434497*lm - 
          0.004624014496337966*lm^2) + CF^2*(0.01772015998966902 + 
          0.016378294500672318*lm + 0.015133138351651523*lm^2) + 
        CF*((0.002570104737689839 + 0.0015404526813561643*lm + 
            0.0008407299084250846*lm^2)*NM + (0.004576444602931475 + 
            0.0015404526813561643*lm + 0.0008407299084250846*lm^2)*NL + 
          (-0.0004123645874103855 + 0.0015404526813561643*lm + 
            0.0008407299084250846*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.017395753611770825 - 0.014057560150758158*lm - 
          0.004534740169167248*lm^2) + CF^2*(0.017373380567305197 + 
          0.015987330117332766*lm + 0.014840967826365539*lm^2) + 
        CF*((0.0024916220169074604 + 0.0015065586659503845*lm + 
            0.0008244982125758633*lm^2)*NM + (0.004481229861404319 + 
            0.0015065586659503845*lm + 0.0008244982125758633*lm^2)*NL + 
          (-0.00040179304279227987 + 0.0015065586659503845*lm + 
            0.0008244982125758633*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.017020264075582842 - 0.013763840778383567*lm - 
          0.004447402929239926*lm^2) + CF^2*(0.017032848657686877 + 
          0.015604224809245556*lm + 0.014555136859330665*lm^2) + 
        CF*((0.0024153778377989793 + 0.0014733654140968641*lm + 
            0.0008086187144072593*lm^2)*NM + (0.00438811964924562 + 
            0.0014733654140968641*lm + 0.0008086187144072593*lm^2)*NL + 
          (-0.00039143958789519465 + 0.0014733654140968641*lm + 
            0.0008086187144072593*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.016652621334504746 - 0.013476316834736985*lm - 
          0.004361957120392191*lm^2) + CF^2*(0.016698500606718354 + 
          0.015228874488609098*lm + 0.014275496030374443*lm^2) + 
        CF*((0.0023413130372309824 + 0.0014408609172994406*lm + 
            0.0007930831127985801*lm^2)*NM + (0.004297069641104466 + 
            0.0014408609172994406*lm + 0.0007930831127985801*lm^2)*NL + 
          (-0.0003813004196892264 + 0.0014408609172994406*lm + 
            0.0007930831127985801*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.0162926974703925 - 0.013194865791910135*lm - 
          0.0042783582040329*lm^2) + CF^2*(0.01637027045562412 + 
          0.014861172993107937*lm + 0.014001899576834946*lm^2) + 
        CF*((0.0022693697104037543 + 0.0014090332042074527*lm + 
            0.0007778833098241637*lm^2)*NM + (0.004208036135851634 + 
            0.0014090332042074527*lm + 0.0007778833098241637*lm^2)*NL + 
          (-0.00037137177241005357 + 0.0014090332042074527*lm + 
            0.0007778833098241637*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.015940363866761845 - 0.012919366788499068*lm - 
          0.004196562733130591*lm^2) + CF^2*(0.016048090154007082 + 
          0.0145010123884961*lm + 0.013734205308427387*lm^2) + 
        CF*((0.0021994912080470393 + 0.0013778703538787024*lm + 
            0.0007630114060237438*lm^2)*NM + (0.004120976073953462 + 
            0.0013778703538787024*lm + 0.0007630114060237438*lm^2)*NL + 
          (-0.00036164991883965174 + 0.0013778703538787024*lm + 
            0.0007630114060237438*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.015595491463736202 - 0.012649700663738057*lm - 
          0.004116528326614738*lm^2) + CF^2*(0.015731889762750112 + 
          0.014148283249767484*lm + 0.013472274523466417*lm^2) + 
        CF*((0.0021316221313314294 + 0.0013473605079092942*lm + 
            0.0007484596957481343*lm^2)*NM + (0.00403584705216535 + 
            0.0013473605079092942*lm + 0.0007484596957481343*lm^2)*NL + 
          (-0.0003521311715508956 + 0.0013473605079092942*lm + 
            0.0007484596957481343*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.015257950991912322 - 0.012385749986352803*lm - 
          0.004038213644202795*lm^2) + CF^2*(0.015421597647043664 + 
          0.013802874922225379*lm + 0.013215971926481876*lm^2) + 
        CF*((0.0020657083246805783 + 0.0013174918815048215*lm + 
            0.0007342206625823264*lm^2)*NM + (0.003952607335763736 + 
            0.0013174918815048215*lm + 0.0007342206625823264*lm^2)*NL + 
          (-0.0003428118839787084 + 0.0013174918815048215*lm + 
            0.0007342206625823264*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.014927655842652458 - 0.012127408963642079*lm - 
          0.003961580103343299*lm^2) + CF*(0.015117090829434713 + 
          0.013464696585324629*lm + 0.012965171247305344*lm^2) + 
        0.00200170781674659*NM + 0.0012882541678224243*lm*NM + 
        0.0007202872915169636*lm^2*NM + 0.0038712237447950672*NL + 
        0.0012882541678224243*lm*NL + 0.0007202872915169636*lm^2*NL - 
        0.0003336884384712828*NH + 0.0012882541678224243*lm*NH + 
        0.0007202872915169636*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.014604384380147115 - 0.011874542243258903*lm - 
          0.0038865845895903472*lm^2) + CF*(0.014818403106735751 + 
          0.013133590678253367*lm + 0.012719731384113864*lm^2) + 
        0.0019395451395394026*NM + 0.0012596327342410424*lm*NM + 
        0.0007066517435618813*lm^2*NM + 0.0037916388129731115*NL + 
        0.0012596327342410424*lm*NL + 0.0007066517435618813*lm^2*NL - 
        0.0003247573011966068*NH + 0.0012596327342410424*lm*NH + 
        0.0007066517435618813*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.014288059017906364 - 0.011627049543047345*lm - 
          0.0038131908277238983*lm^2) + CF*(0.014525398937200241 + 
          0.01280946914082567*lm + 0.012479533618005485*lm^2) + 
        0.0018791829317531107*NM + 0.00123161774190721*lm*NM + 
        0.0006933074232225269*lm^2*NM + 0.003713822302602431*NL + 
        0.00123161774190721*lm*NL + 0.0006933074232225269*lm^2*NL - 
        0.00031601493785609323*NH + 0.00123161774190721*lm*NH + 
        0.0006933074232225269*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.01397855143032539 - 0.011384820503824302*lm - 
          0.0037413613899837292*lm^2) + CF*(0.01423800187286335 + 
          0.012492218563119478*lm + 0.012244455458128568*lm^2) + 
        0.0018205718563966793*NM + 0.001204197786484217*lm*NM + 
        0.0006802475254515871*lm^2*NM + 0.0036377351986812724*NL + 
        0.001204197786484217*lm*NL + 0.0006802475254515871*lm^2*NL - 
        0.0003074578740693318*NH + 0.001204197786484217*lm*NH + 
        0.0006802475254515871*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.013675734010012536 - 0.011147746580165763*lm - 
          0.0036710597713423255*lm^2) + CF*(0.01395613456186676 + 
          0.012181725362813547*lm + 0.012014377433483974*lm^2) + 
        0.001763663766488226*NM + 0.001177361579884807*lm*NM + 
        0.0006674654129713319*lm^2*NM + 0.003563339190672811*NL + 
        0.001177361579884807*lm*NL + 0.0006674654129713319*lm^2*NL - 
        0.0002990826801449797*NH + 0.001177361579884807*lm*NH + 
        0.0006674654129713319*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.013379479998636696 - 0.010915721044185698*lm - 
          0.003602250366859578*lm^2) + CF*(0.01367971889303061 + 
          0.011877875947462934*lm + 0.011789183018813165*lm^2) + 
        0.0017084116883197963*NM + 0.0011510979561984893*lm*NM + 
        0.0006549546121562868*lm^2*NM + 0.003490596673033698*NL + 
        0.0011510979561984893*lm*NL + 0.0006549546121562868*lm^2*NL - 
        0.00029088597157346085*NH + 0.0011510979561984893*lm*NH + 
        0.0006549546121562868*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.013089663605549556 - 0.010688638986433787*lm - 
          0.0035348984495176036*lm^2) + CF*(0.013408676131845886 + 
          0.011580556864166772*lm + 0.011568758562057612*lm^2) + 
        0.001654769803971324*NM + 0.0011253958769838878*lm*NM + 
        0.0006427088090032007*lm^2*NM + 0.0034194707445239663*NL + 
        0.0011253958769838878*lm*NL + 0.0006427088090032007*lm^2*NL - 
        0.0002828644094398273*NH + 0.0011253958769838878*lm*NH + 
        0.0006427088090032007*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.012806160115020645 - 0.010466397314143729*lm - 
          0.0034689701485322655*lm^2) + CF*(0.013142927048275065 + 
          0.011289654937409683*lm + 0.011352993213378324*lm^2) + 
        0.0016026934331773047*NM + 0.0011002444359690792*lm*NM + 
        0.0006307218451876847*lm^2*NM + 0.0033499252064056345*NL + 
        0.0011002444359690792*lm*NL + 0.0006307218451876847*lm^2*NL - 
        0.00027501470076173105*NH + 0.0011002444359690792*lm*NH + 
        0.0006307218451876847*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.012528845982871222 - 0.010248894747049165*lm - 
          0.003404432428137397*lm^2) + CF*(0.012882392036735175 + 
          0.011005057395813346*lm + 0.01114177885572239*lm^2) + 
        0.0015521390146415641*NM + 0.0010756328632002855*lm*NM + 
        0.0006189877142067995*lm^2*NM + 0.0032819245596300032*NL + 
        0.0010756328632002855*lm*NL + 0.0006189877142067995*lm^2*NL - 
        0.00026733359875720156*NH + 0.0010756328632002855*lm*NH + 
        0.0006189877142067995*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.012257598923244236 - 0.010036031810970252*lm - 
          0.00334125306683723*lm^2) + CF*(0.012626991228624165 + 
          0.010726651988492552*lm + 0.010935010036921843*lm^2) + 
        0.0015030640868879026*NM + 0.0010515505286768853*lm*NM + 
        0.0006075005576067691*lm^2*NM + 0.0032154340011066856*NL + 
        0.0010515505286768853*lm*NL + 0.0006075005576067691*lm^2*NL - 
        0.00025981790304668324*NH + 0.0010515505286768853*lm*NH + 
        0.0006075005576067691*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.011992297986201536 - 0.009827710829360776*lm - 
          0.003279400637122072*lm^2) + CF*(0.012376644597738448 + 
          0.010454327091670147*lm + 0.0107325839033086*lm^2) + 
        0.0014554272687273067*NM + 0.001027986945508422*lm*NM + 
        0.0005962546612949222*lm^2*NM + 0.0031504194191409375*NL + 
        0.001027986945508422*lm*NL + 0.0005962546612949222*lm^2*NL - 
        0.0002524644597935562*NH + 0.001027986945508422*lm*NH + 
        0.0005962546612949222*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.011732823626796271 - 0.009623835912993423*lm - 
          0.0032188444856418677*lm^2) + CF*(0.012131272058916627 + 
          0.010187971806167435*lm + 0.010534400134827931*lm^2) + 
        0.0014091882394158023*NM + 0.0010049317726271323*lm*NM + 
        0.0005852444519348851*lm^2*NM + 0.003086847388119754*NL + 
        0.0010049317726271323*lm*NL + 0.0005852444519348851*lm^2*NL - 
        0.0002452701617871455*NH + 0.0010049317726271323*lm*NH + 
        0.0005852444519348851*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.011479057766227646 - 0.009424312947949078*lm - 
          0.0031595547138319117*lm^2) + CF*(0.011890793560232031 + 
          0.009927476046351018*lm + 0.010340360881631712*lm^2) + 
        0.001364307718570854*NM + 0.000982374817087489*lm*NM + 
        0.000574464493423984*lm^2*NM + 0.0030246851625215015*NL + 
        0.000982374817087489*lm*NL + 0.000574464493423984*lm^2*NL - 
        0.00023823194847201438*NH + 0.000982374817087489*lm*NH + 
        0.000574464493423984*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.011230883845646905 - 0.00922904958206517*lm - 
          0.0031015021589846834*lm^2) + CF*(0.011655129169044412 + 
          0.009672730621083273*lm + 0.010150370702131692*lm^2) + 
        0.0013207474459084741*NM + 0.0009603060359823356*lm*NM + 
        0.0005639094834517606*lm^2*NM + 0.0029639006703185114*NL + 
        0.0009603060359823356*lm*NL + 0.0005639094834517606*lm^2*NL - 
        0.00023134680592713864*NH + 0.0009603060359823356*lm*NH + 
        0.0005639094834517606*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.010988186873147296 - 0.009037955209987755*lm - 
          0.003044658375761467*lm^2) + CF*(0.011424199152209288 + 
          0.009423627307191864*lm + 0.009964336502492075*lm^2) + 
        0.0012784701608578501*NM + 0.0009387155380033845*lm*NM + 
        0.0005535742501384486*lm^2*NM + 0.002904462505837042*NL + 
        0.0009387155380033845*lm*NL + 0.0005535742501384486*lm^2*NL - 
        0.00022461176679836986*NH + 0.0009387155380033845*lm*NH + 
        0.0005535742501384486*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.01075085346443696 - 0.008850940956962304*lm - 
          0.0029889956181371993*lm^2) + CF*(0.011197924050731823 + 
          0.0091800589159436*lm + 0.009782167477539926*lm^2) + 
        0.0012374395821053209*NM + 0.0009175935846721413*lm*NM + 
        0.000543453748752218*lm^2*NM + 0.002846339922134355*NL + 
        0.0009175935846721413*lm*NL + 0.000543453748752218*lm^2*NL - 
        0.00021802391018741445*NH + 0.0009175935846721413*lm*NH + 
        0.000543453748752218*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.010518771877661712 - 0.00866791966148915*lm - 
          0.0029344868217717666*lm^2) + CF*(0.01097622474914082 + 
          0.00894191935297949*lm + 0.009603775053071235*lm^2) + 
        0.0011976203871149017*NM + 0.0008969305912657176*lm*NM + 
        0.0005335430585039576*lm^2*NM + 0.0027895028229482405*NL + 
        0.0008969305912657176*lm*NL + 0.0005335430585039576*lm^2*NL - 
        0.0002115803615003844*NH + 0.0008969305912657176*lm*NH + 
        0.0005335430585039576*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.01029183204281477 - 0.008488805856960904*lm - 
          0.002881105586800803*lm^2) + CF*(0.010759022539847455 + 
          0.008709103672141111*lm + 0.009429072829529902*lm^2) + 
        0.0011589781916682524*NM + 0.0008767171274604742*lm*NM + 
        0.0005238373794183278*lm^2*NM + 0.002733921754270243*NL + 
        0.0008767171274604742*lm*NL + 0.0005238373794183278*lm^2*NL - 
        0.0002052782922588112*NH + 0.0008767171274604742*lm*NH + 
        0.0005238373794183278*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.010069925586142316 - 0.008313515752391164*lm - 
          0.002828826161038889*lm^2) + CF*(0.010546239182742655 + 
          0.008481508123592984*lm + 0.009257976527036364*lm^2) + 
        0.001121479529462981*NM + 0.0008569439177150142*lm*NM + 
        0.0005143320292797979*lm^2*NM + 0.002679567895589993*NL + 
        0.0008569439177150142*lm*NL + 0.0005143320292797979*lm^2*NL - 
        0.00019911491987586013*NH + 0.0008569439177150142*lm*NH + 
        0.0005143320292797979*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.009852945849927271 - 0.008141967212336275*lm - 
          0.0027776234235879224*lm^2) + CF*(0.010337796960276691 + 
          0.008259030196621811*lm + 0.009090403931742291*lm^2) + 
        0.0010850918318044685*NM + 0.0008376018414126961*lm*NM + 
        0.0005050224406523495*lm^2*NM + 0.0026264130508544723*NL + 
        0.0008376018414126961*lm*NL + 0.0005050224406523495*lm^2*NL - 
        0.00019308750740033238*NH + 0.0008376018414126961*lm*NH + 
        0.0005050224406523495*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.009640787908008847 - 0.00797407973610479*lm - 
          0.002727472868843354*lm^2) + CF*(0.010133618728254483 + 
          0.00804156865747083*lm + 0.00892627484348734*lm^2) + 
        0.0010497834074229512*NM + 0.0008186819327825741*lm*NM + 
        0.0004959041579715189*lm^2*NM + 0.002574429639182674*NL + 
        0.0008186819327825741*lm*NL + 0.0004959041579715189*lm^2*NL - 
        0.00018719336323090357*NH + 0.0008186819327825741*lm*NH + 
        0.0004959041579715189*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.009433348577372052 - 0.0078097744363426445*lm - 
          0.002678350590890882*lm^2) + CF*(0.009933627962570335 + 
          0.007829023582546203*lm + 0.008765511024733797*lm^2) + 
        0.0010155234224444056*NM + 0.0008001753806164749*lm*NM + 
        0.0004869728347074331*lm^2*NM + 0.0025235906853730123*NL + 
        0.0008001753806164749*lm*NL + 0.0004869728347074331*lm^2*NL - 
        0.00018142984080291128*NH + 0.0008001753806164749*lm*NH + 
        0.0004869728347074331*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.009230526426119419 - 0.007648974017075801*lm - 
          0.002630233268286167*lm^2) + CF*(0.00973774880209641 + 
          0.0076212963873123745*lm + 0.00860803615075473*lm^2) + 
        0.0009822818805408262*NM + 0.0007820735277988012*lm*NM + 
        0.0004782242305974849*lm^2*NM + 0.002473869810237888*NL + 
        0.0007820735277988012*lm*NL + 0.0004782242305974849*lm^2*NL - 
        0.0001757943382498782*NH + 0.0007820735277988012*lm*NH + 
        0.0004782242305974849*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.009032221778116592 - 0.007491602751286245*lm - 
          0.002583098149210076*lm^2) + CF*(0.009545906087930059 + 
          0.007418289851174233*lm + 0.008453775761051156*lm^2) + 
        0.0009500296032827451*NM + 0.000764367870664589*lm*NM + 
        0.0004696542089472865*lm^2*NM + 0.002425241220797109*NL + 
        0.000764367870664589*lm*NL + 0.0004696542089472865*lm^2*NL - 
        0.00017028429804183542*NH + 0.000764367870664589*lm*NH + 
        0.0004696542089472865*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.008838336714584151 - 0.0073375864580917174*lm - 
          0.002536923036991961*lm^2) + CF*(0.009358025399196286 + 
          0.0072199081386261086*lm + 0.008302657211973692*lm^2) + 
        0.0009187382107143116*NM + 0.0007470500582003543*lm*NM + 
        0.0004612587339985384*lm^2*NM + 0.002377679700359306*NL + 
        0.0007470500582003543*lm*NL + 0.0004612587339985384*lm^2*NL - 
        0.00016489720660239568*NH + 0.0007470500582003543*lm*NH + 
        0.0004612587339985384*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.008648775072889841 - 0.007186852479594425*lm - 
          0.0024916862759934715*lm^2) + CF*(0.00917403308559307 + 
          0.007026056816930756*lm + 0.008154609630524088*lm^2) + 
        0.0008883801021689125*NM + 0.0007301118911013235*lm*NM + 
        0.00045303386836244937*lm^2*NM + 0.0023311605985181167*NL + 
        0.0007301118911013235*lm*NL + 0.00045303386836244937*lm^2*NL - 
        0.00015963059390641644*NH + 0.0007301118911013235*lm*NH + 
        0.00045303386836244937*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.0084634424427784 - 0.0070393296574591*lm - 
          0.002447366737845399*lm^2) + CF*(0.008993856296858983 + 
          0.006836642870575531*lm + 0.008009563869312213*lm^2) + 
        0.0008589284373411505*NM + 0.0007135453206977607*lm*NM + 
        0.0004449757705173452*lm^2*NM + 0.0022856598210877007*NL + 
        0.0007135453206977607*lm*NL + 0.0004449757705173452*lm^2*NL - 
        0.00015448203305998872*NH + 0.0007135453206977607*lm*NH + 
        0.0004449757705173452*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.00828224616026019 - 0.0068949483092762935*lm - 
          0.0024039438080301063*lm^2) + CF*(0.008817423009334573 + 
          0.006651574712737993*lm + 0.007867452462643984*lm^2) + 
        0.0008303571176290062*NM + 0.0006973424477622767*lm*NM + 
        0.0004370806923691102*lm^2*NM + 0.002241153820000077*NL + 
        0.0006973424477622767*lm*NL + 0.0004370806923691102*lm^2*NL - 
        0.00014944913986438875*NH + 0.0006973424477622767*lm*NH + 
        0.0004370806923691102*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.008105095299364878 - 0.00675364020476249*lm - 
          0.002361397372802106*lm^2) + CF*(0.008644662049781269 + 
          0.006470762193979001*lm + 0.007728209583715983*lm^2) + 
        0.0008026407677581752*NM + 0.0006814955212092216*lm*NM + 
        0.00042934497687311014*lm^2*NM + 0.002197619583184866*NL + 
        0.0006814955212092216*lm*NL + 0.00042934497687311014*lm^2*NL - 
        0.00014452957236553492*NH + 0.0006814955212092216*lm*NH + 
        0.00042934497687311014*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.007931900661952367 - 0.006615338541844697*lm - 
          0.002319707806439409*lm^2) + CF*(0.008475503116614122 + 
          0.006294116608368045*lm + 0.007591771002892611*lm^2) + 
        0.0007757547176988768*NM + 0.0006659969366965279*lm*NM + 
        0.00042176505571625615*lm^2*NM + 0.002155034624450225*NL + 
        0.0006659969366965279*lm*NL + 0.00042176505571625615*lm^2*NL - 
        0.0001397210303904043*NH + 0.0006659969366965279*lm*NH + 
        0.00042176505571625615*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.0077625747657599975 - 0.006479977922673418*lm - 
          0.002278855958818331*lm^2) + CF*(0.008309876798697567 + 
          0.0061215506972329805*lm + 0.00745807404704181*lm^2) + 
        0.0007496749848838831*NM + 0.0006508392351396855*lm*NM + 
        0.0004143374470578784*lm^2*NM + 0.0021133769733821025*NL + 
        0.0006508392351396855*lm*NL + 0.0004143374470578784*lm^2*NL - 
        0.00013502125507177683*NH + 0.0006508392351396855*lm*NH + 
        0.0004143374470578784*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.007597031830852734 - 0.006347494329604436*lm - 
          0.0022388231433045*lm^2) + CF*(0.008147714591846456 + 
          0.0059529786507144826*lm + 0.007327057559905635*lm^2) + 
        0.0007243782567350808*NM + 0.0006360151011468728*lm*NM + 
        0.00040705875332809084*lm^2*NM + 0.002072625165277394*NL + 
        0.0006360151011468728*lm*NL + 0.00040705875332809084*lm^2*NL - 
        0.00013042802836259583*NH + 0.0006360151011468728*lm*NH + 
        0.00040705875332809084*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.007435187764631459 - 0.006217825101186572*lm - 
          0.0021995911249528873*lm^2) + CF*(0.007988948913168011 + 
          0.005788316107294379*lm + 0.007198661863482177*lm^2) + 
        0.0006998418735045771*NM + 0.0006215173613836673*lm*NM + 
        0.00039992565908234315*lm^2*NM + 0.0020327582311251407*NL + 
        0.0006215173613836673*lm*NL + 0.00039992565908234315*lm^2*NL - 
        0.0001259391725411562*NH + 0.0006215173613836673*lm*NH + 
        0.00039992565908234315*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.007276960145543676 - 0.006090908908189554*lm - 
          0.0021611421090097717*lm^2) + CF*(0.007833513113373916 + 
          0.0056274801514565*lm + 0.007072828720395616*lm^2) + 
        0.0006760438114351549*NM + 0.0006073389828751784*lm*NM + 
        0.00039293492891086755*lm^2*NM + 0.0019937556876485772*NL + 
        0.0006073389828751784*lm*NL + 0.00039293492891086755*lm^2*NL - 
        0.00012155254970825986*NH + 0.0006073389828751784*lm*NH + 
        0.00039293492891086755*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.007122268205630783 - 0.005966685729703246*lm - 
          0.002123458729709619*lm^2) + CF*(0.007681341487185686 + 
          0.005470389309628765*lm + 0.00694950129723148*lm^2) + 
        0.0006529626662437871*NM + 0.0005934730712529098*lm*NM + 
        0.00038608340540174886*lm^2*NM + 0.0019555975274195966*NL + 
        0.0005934730712529098*lm*NL + 0.00038608340540174886*lm^2*NL - 
        0.00011726606127740818*NH + 0.0005934730712529098*lm*NH + 
        0.00038608340540174886*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.006971032812036567 - 0.005845096829336858*lm - 
          0.0020865240393599747*lm^2) + CF*(0.00753236928195047 + 
          0.005316963544545918*lm + 0.006828624128814463*lm^2) + 
        0.0006305776369309182*NM + 0.0005799128689531536*lm*NM + 
        0.00037936800715635905*lm^2*NM + 0.001918264209056049*NL + 
        0.0005799128689531536*lm*NL + 0.00037936800715635905*lm^2*NL - 
        0.00011307764745903684*NH + 0.0005799128689531536*lm*NH + 
        0.00037936800715635905*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.006823176447592668 - 0.005726084731544256*lm - 
          0.0020503214977075444*lm^2) + CF*(0.007386532704578851 + 
          0.00516712424816349*lm + 0.006710143083406509*lm^2) + 
        0.0006088685099173035*NM + 0.0005666517533732429*lm*NM + 
        0.00037278572685591713*lm^2*NM + 0.0018817366475112186*NL + 
        0.0005666517533732429*lm*NL + 0.00037278572685591713*lm^2*NL - 
        0.00010898528673973549*NH + 0.0005666517533732429*lm*NH + 
        0.00037278572685591713*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.006678623190588461 - 0.005609593198099155*lm - 
          0.0020148349615787507*lm^2) + CF*(0.007243768926910728 + 
          0.005020794233245339*lm + 0.006594005328803184*lm^2) + 
        0.0005878156435093683*NM + 0.0005536832349915404*lm*NM + 
        0.00036633362937795464*lm^2*NM + 0.0018459962044638466*NL + 
        0.0005536832349915404*lm*NL + 0.00036633362937795464*lm^2*NL - 
        0.00010498699535733665*NH + 0.0005536832349915404*lm*NH + 
        0.00036633362937795464*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0065372986938249614 - 0.005495567204741842*lm - 
          0.0019800486747881606*lm^2) + CF*(0.007104016089610118 + 
          0.004877897723739281*lm + 0.006480159299306707*lm^2) + 
        0.0005673999526932881*NM + 0.0005410009554566285*lm*NM + 
        0.0003600088499614837*lm^2*NM + 0.0018110246788161327*NL + 
        0.0005410009554566285*lm*NL + 0.0003600088499614837*lm^2*NL - 
        0.00010108082677270196*NH + 0.0005410009554566285*lm*NH + 
        0.0003600088499614837*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.00639913016304513 - 0.005383952918017023*lm - 
          0.0019459472583082797*lm^2) + CF*(0.006967213304684775 + 
          0.004738360344048008*lm + 0.00636855466355437*lm^2) + 
        0.0005476028942573097*NM + 0.0005285986856507658*lm*NM + 
        0.0003538085924196872*lm^2*NM + 0.0017768042973063212*NL + 
        0.0005285986856507658*lm*NL + 0.0003538085924196872*lm^2*NL - 
        0.00009726487113898145*NH + 0.0005285986856507658*lm*NH + 
        0.0003538085924196872*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.006264046334826072 - 0.005274697672320514*lm - 
          0.00191251570069433*lm^2) + CF*(0.006833300656721643 + 
          0.004602109107295583*lm + 0.006259142293181443*lm^2) + 
        0.0005284064522412085*NM + 0.0005164703237323147*lm*NM + 
        0.00034773012739896907*lm^2*NM + 0.0017433177052416742*NL + 
        0.0005164703237323147*lm*NL + 0.00034773012739896907*lm^2*NL - 
        0.00009353725476907091*NH + 0.0005164703237323147*lm*NH + 
        0.00034773012739896907*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.006131977454012291 - 0.0051677499471707595*lm - 
          0.0018797393487577296*lm^2) + CF*(0.00670221920292463 + 
          0.004469072402683301*lm + 0.006151874232298024*lm^2) + 
        0.0005097931237112213*NM + 0.0005046098931614899*lm*NM + 
        0.0003417707906832235*lm^2*NM + 0.0017105479573569248*NL + 
        0.0005046098931614899*lm*NL + 0.0003417707906832235*lm^2*NL - 
        0.00008989613960194572*NH + 0.0005046098931614899*lm*NH + 
        0.0003417707906832235*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.006002855250763175 - 0.00506305934471947*lm - 
          0.0018476038984821211*lm^2) + CF*(0.006573910972036727 + 
          0.00433917998202257*lm + 0.006046703667759669*lm^2) + 
        0.0004917459048582877*NM + 0.0004930115407134624*lm*NM + 
        0.0003359279815422038*lm^2*NM + 0.001678478508802621*NL + 
        0.0004930115407134624*lm*NL + 0.0003359279815422038*lm^2*NL - 
        0.00008633972266850372*NH + 0.0004930115407134624*lm*NH + 
        0.0003359279815422038*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.005876612917282311 - 0.004960576567514225*lm - 
          0.0018160953861759018*lm^2) + CF*(0.006448318962224311 + 
          0.004212362945526742*lm + 0.005943584900212043*lm^2) + 
        0.0004742482774169809*NM + 0.00048166953448254297*lm*NM + 
        0.0003301991611228913*lm^2*NM + 0.0016470932062671647*NL + 
        0.00048166953448254297*lm*NL + 0.0003301991611228913*lm^2*NL - 
        0.00008286623555750772*NH + 0.00048166953448254297*lm*NH + 
        0.0003301991611228913*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.005753185084291048 - 0.004860253396524399*lm - 
          0.001785200179855329*lm^2) + CF*(0.006325387137997429 + 
          0.004088553726938378*lm + 0.005842473315890167*lm^2) + 
        0.00045728419540210836*NM + 0.0004705782618808891*lm*NM + 
        0.0003245818508827871*lm^2*NM + 0.0016163762792357715*NL + 
        0.0004705782618808891*lm*NL + 0.0003245818508827871*lm^2*NL - 
        0.00007947394388217763*NH + 0.0004705782618808891*lm*NH + 
        0.0003245818508827871*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.0056325077973038125 - 0.004762042669440489*lm - 
          0.0017549049708523914*lm^2) + CF*(0.006205060426235983 + 
          0.003967686078063375*lm + 0.0057433253591532805*lm^2) + 
        0.0004408380721595996*NM + 0.00045973222763490753*lm*NM + 
        0.00031907363106407113*lm^2*NM + 0.0015863123313890604*NL + 
        0.00045973222763490753*lm*NL + 0.00031907363106407113*lm^2*NL - 
        0.00007616114674794434*NH + 0.00045973222763490753*lm*NH + 
        0.00031907363106407113*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.005514518492758185 - 0.004665898259255689*lm - 
          0.001725196765641759*lm^2) + CF*(0.006087284711388084 + 
          0.0038496950527785456*lm + 0.005646098505736666*lm^2) + 
        0.0004248947677279815*NM + 0.0004491260517822803*lm*NM + 
        0.00031367213920759253*lm^2*NM + 0.0015568863321434917*NL + 
        0.0004491260517822803*lm*NL + 0.00031367213920759253*lm^2*NL - 
        0.0000729261762218409*NH + 0.0004491260517822803*lm*NH + 
        0.00031367213920759253*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.005399155974048474 - 0.0045717750531374226*lm - 
          0.0016960628778812353*lm^2) + CF*(0.0059720068299032565 + 
          0.003734516990574791*lm + 0.005550751236702225*lm^2) + 
        0.00040943957650646024*NM + 0.0004387544676723033*lm*NM + 
        0.00030837506870567917*lm^2*NM + 0.0015280836083354384*NL + 
        0.0004387544676723033*lm*NL + 0.00030837506870567917*lm^2*NL - 
        0.00006976739680397298*NH + 0.0004387544676723033*lm*NH + 
        0.00030837506870567917*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.0052863603875075655 - 0.004479628931595477*lm - 
          0.0016674909206602592*lm^2) + CF*(0.005859174563959868 + 
          0.003622089499693731*lm + 0.00545724301306994*lm^2) + 
        0.00039445821522538345*NM + 0.0004286123199720103*lm*NM + 
        0.0003031801673927744*lm^2*NM + 0.0014998898360502595*NL + 
        0.0004286123199720103*lm*NL + 0.0003031801673927744*lm^2*NL - 
        0.0000666832049014778*NH + 0.0004286123199720103*lm*NH + 
        0.0003031801673927744*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0051760731983781574 - 0.004389416747952431*lm - 
          0.0016394687989511189*lm^2) + CF*(0.005748736634542904 + 
          0.0035123514399117073*lm + 0.005365534251112753*lm^2) + 
        0.000379936811214641*NM + 0.00041869456268034844*lm*NM + 
        0.00029808523617293073*lm^2*NM + 0.001472291032597376*NL + 
        0.00041869456268034844*lm*NL + 0.00029808523617293073*lm^2*NL - 
        0.0000636720283053505*NH + 0.00041869456268034844*lm*NH + 
        0.00029808523617293073*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.00506823716681099 - 0.004301096308121119*lm - 
          0.0016119847022576586*lm^2) + CF*(0.005640642693925147 + 
          0.0034052429050213102*lm + 0.0052755862982977915*lm^2) + 
        0.0003658618909653784*NM + 0.00040899625715248075*lm*NM + 
        0.0002930881276832106*lm^2*NM + 0.0014452735486320094*NL + 
        0.00040899625715248075*lm*NL + 0.0002930881276832106*lm^2*NL - 
        0.000060732325670488035*NH + 0.00040899625715248075*lm*NH + 
        0.0002930881276832106*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.004962796323924527 - 0.004214626350693088*lm - 
          0.0015850270974563725*lm^2) + CF*(0.005534843317601888 + 
          0.003300705205057095*lm + 0.005187361409857219*lm^2) + 
        0.00035222036898023996*NM + 0.00039951257013611164*lm*NM + 
        0.0002881867449920677*lm^2*NM + 0.0014188240604239256*NL + 
        0.00039951257013611164*lm*NL + 0.0002881867449920677*lm^2*NL - 
        0.00005786258599927307*NH + 0.00039951257013611164*lm*NH + 
        0.0002881867449920677*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0048596959479575074 - 0.004129966527341191*lm - 
          0.0015585847218248991*lm^2) + CF*(0.005431289995726522 + 
          0.0031986808483088222*lm + 0.005100822725972397*lm^2) + 
        0.00033899953690722423*NM + 0.00039023877182156223*lm*NM + 
        0.00028337904033179986*lm^2*NM + 0.0013929295622732473*NL + 
        0.00039023877182156223*lm*NL + 0.00028337904033179986*lm^2*NL - 
        0.000055061328128995316*NH + 0.00039023877182156223*lm*NH + 
        0.00028337904033179986*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.004758882540543005 - 0.004047077383538749*lm - 
          0.0015326465762530393*lm^2) + CF*(0.005329935124091687 + 
          0.003099113523162481*lm + 0.005015934249555401*lm^2) + 
        0.0003261870529521257*NM + 0.00038117023390716844*lm*NM + 
        0.00027866301386418894*lm^2*NM + 0.0013675773590731365*NL + 
        0.00038117023390716844*lm*NL + 0.00027866301386418894*lm^2*NL - 
        0.000052327100223382696*NH + 0.00038117023390716844*lm*NH + 
        0.00027866301386418894*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.004660303803130045 - 0.00396592033959707*lm - 
          0.0015072019186315375*lm^2) + CF*(0.005230731994698095 + 
          0.0030019480798064288*lm + 0.004932660824612305*lm^2) + 
        0.0003137709315644457*NM + 0.0003723024276814254*lm*NM + 
        0.0002740367124784614*lm^2*NM + 0.0013427550590189086*NL + 
        0.0003723024276814254*lm*NL + 0.0002740367124784614*lm^2*NL - 
        0.000049658479268492234*NH + 0.0003723024276814254*lm*NH + 
        0.0002740367124784614*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.004563908613576386 - 0.0038864576720224813*lm - 
          0.0014822402574139757*lm^2) + CF*(0.005133634785950775 + 
          0.0029071305118372566*lm + 0.0048509681151730115*lm^2) + 
        0.00030173953339158674*NM + 0.0003636309221231675*lm*NM + 
        0.00026949822862072284*lm^2*NM + 0.0013184505664629333*NL + 
        0.0003636309221231675*lm*NL + 0.00026949822862072284*lm^2*NL - 
        0.00004705407057318882*NH + 0.0003636309221231675*lm*NH + 
        0.00026949822862072284*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.004469647002933842 - 0.003808652495193499*lm - 
          0.0014577513453472388*lm^2) + CF*(0.005038598552520138 + 
          0.0028146079377974163*lm + 0.0047708225847727815*lm^2) + 
        0.000290081555496089*NM + 0.0003551513820209446*lm*NM + 
        0.0002650456991540434*lm^2*NM + 0.0012946520749144764*NL + 
        0.0003551513820209446*lm*NL + 0.0002650456991540434*lm^2*NL - 
        0.00004451250727441962*NH + 0.0003551513820209446*lm*NH + 
        0.0002650456991540434*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.004377470132445408 - 0.0037324687433582*lm - 
          0.0014337251733661219*lm^2) + CF*(0.00494557921490312 + 
          0.0027243285826742455*lm + 0.004692191476470944*lm^2) + 
        0.0002787860218306338*NM + 0.0003468595661126363*lm*NM + 
        0.0002606773042483858*lm^2*NM + 0.0012713480601834648*NL + 
        0.0003468595661126363*lm*NL + 0.0002606773042483858*lm^2*NL - 
        0.000042032449847472545*NH + 0.0003468595661126363*lm*NH + 
        0.0002606773042483858*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.004287330270771515 - 0.003657871152951436*lm - 
          0.0014101519646477524*lm^2) + CF*(0.0048545335487175136 + 
          0.0026362417593877602*lm + 0.004615042793392644*lm^2) + 
        0.00026784227396551224*NM + 0.00033875132524623574*lm*NM + 
        0.00025639126629959134*lm^2*NM + 0.001248527273666997*NL + 
        0.00033875132524623574*lm*NL + 0.00025639126629959134*lm^2*NL - 
        0.00003961258562138934*NH + 0.00033875132524623574*lm*NH + 
        0.00025639126629959134*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.004199180771460914 - 0.0035848252452310592*lm - 
          0.0013870221688216098*lm^2) + CF*(0.004765419173760688 + 
          0.0025502978502924788*lm + 0.004539345279779814*lm^2) + 
        0.0002572399620632501*NM + 0.00033082260056262994*lm*NM + 
        0.00025218584887665634*lm^2*NM + 0.0012261787357772853*NL + 
        0.00033082260056262994*lm*NL + 0.00025218584887665634*lm^2*NL - 
        0.00003725162829968643*NH + 0.00033082260056262994*lm*NH + 
        0.00025218584887665634*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.004112976050680035 - 0.003513297309231955*lm - 
          0.0013643264563310278*lm^2) + CF*(0.004678194542861952 + 
          0.0024664482887165368*lm + 0.004465068402537908*lm^2) + 
        0.00024696903609508134*NM + 0.00032306942170110935*lm*NM + 
        0.00024805935569655047*lm^2*NM + 0.0012042917295095787*NL + 
        0.00032306942170110935*lm*NL + 0.00024805935569655047*lm^2*NL - 
        0.000034948317486520965*NH + 0.00032306942170110935*lm*NH + 
        0.00024805935569655047*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.004028671565213065 - 0.003443254385036292*lm - 
          0.0013420557129421606*lm^2) + CF*(0.004592818930556067 + 
          0.0023846455405595116*lm + 0.004392182333265253*lm^2) + 
        0.00023701973729397437*NM + 0.0003154879050282473*lm*NM + 
        0.0002440101296258474*lm^2*NM + 0.0011828557941485158*NL + 
        0.0003154879050282473*lm*NL + 0.0002440101296258474*lm^2*NL - 
        0.00003270141821842418*NH + 0.0003154879050282473*lm*NH + 
        0.0002440101296258474*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.003946223790743581 - 0.003374664247358094*lm - 
          0.0013202010343965087*lm^2) + CF*(0.0045092524216036895 + 
          0.00230484308596861*lm + 0.00432065793075221*lm^2) + 
        0.000227382589838939*NM + 0.0003080742518907093*lm*NM + 
        0.0002400365517084561*lm^2*NM + 0.0011618607191112452*NL + 
        0.0003080742518907093*lm*NL + 0.0002400365517084561*lm^2*NL - 
        0.00003050972050170999*NH + 0.0003080742518907093*lm*NH + 
        0.0002400365517084561*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.003865590200427201 - 0.0033074953894399162*lm - 
          0.0012987537212031776*lm^2) + CF*(0.004427455899382922 + 
          0.0022269954011112526*lm + 0.004250466723937672*lm^2) + 
        0.0002180483927653724*NM + 0.00030082474689247256*lm*NM + 
        0.00023613704021875954*lm^2*NM + 0.00114129653792557*NL + 
        0.00030082474689247256*lm*NL + 0.00023613704021875954*lm^2*NL - 
        0.000028372038855653536*NH + 0.00030082474689247256*lm*NH + 
        0.00023613704021875954*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.0037867292437634785 - 0.003241717007259149*lm - 
          0.0012777052735671612*lm^2) + CF*(0.004347391034174611 + 
          0.0021510579400605525*lm + 0.004181580895310709*lm^2) + 
        0.0002090082120962411*NM + 0.0002937357561968658*lm*NM + 
        0.00023231004973948386*lm^2*NM + 0.0011211535223412934*NL + 
        0.0002937357561968658*lm*NL + 0.00023231004973948386*lm^2*NL - 
        0.000026287211861521627*NH + 0.0002937357561968658*lm*NH + 
        0.00023231004973948386*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.0037096003257741355 - 0.003177298984041219*lm - 
          0.0012570473864500179*lm^2) + CF*(0.004269020271362585 + 
          0.002076987116808747*lm + 0.004113973264745514*lm^2) + 
        0.0002002533731889424*NM + 0.0002868037258537712*lm*NM + 
        0.00022855407026363964*lm^2*NM + 0.001101422176572875*NL + 
        0.0002868037258537712*lm*NL + 0.00022855407026363964*lm^2*NL - 
        0.000024254101717525528*NH + 0.0002868037258537712*lm*NH + 
        0.00022855407026363964*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.0036341637864936217 - 0.003114211875076739*lm - 
          0.001236771944759412*lm^2) + CF*(0.004192306819568622 + 
          0.002004740287422311*lm + 0.004047617273758076*lm^2) + 
        0.00019177545329274054*NM + 0.0002800251801522704*lm*NM + 
        0.0002248676263198931*lm^2*NM + 0.001082093231671449*NL + 
        0.0002800251801522704*lm*NL + 0.0002248676263198931*lm^2*NL - 
        0.000022271593799755278*NH + 0.0002800251801522704*lm*NH + 
        0.0002248676263198931*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.00356038088077704 - 0.003052426892839451*lm - 
          0.0012168710186640766*lm^2) + CF*(0.0041172146387406655 + 
          0.0019342757323512164*lm + 0.003982486970173341*lm^2) + 
        0.0001835662743117304*NM + 0.0002733967199989568*lm*NM + 
        0.00022124927612074118*lm^2*NM + 0.0010631576400242095*NL + 
        0.0002733967199989568*lm*NL + 0.00022124927612074118*lm^2*NL - 
        0.000020338596229144534*NH + 0.0002733967199989568*lm*NH + 
        0.00022124927612074118*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.0034882137584295475 - 0.002991915892401638*lm - 
          0.0011973368590308486*lm^2) + CF*(0.004043708428211533 + 
          0.0018655526389036283*lm + 0.003918556993191868*lm^2) + 
        0.0001756178957683441*NM + 0.00026691502132208494*lm*NM + 
        0.00021769761073288157*lm^2*NM + 0.0010446065699791192*NL + 
        0.00026691502132208494*lm*NL + 0.00021769761073288157*lm^2*NL - 
        0.000018454039444505103*NH + 0.00026691502132208494*lm*NH + 
        0.00021769761073288157*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0034176254446605047 - 0.0029326513571435193*lm - 
          0.00117816189298051*lm^2) + CF*(0.003971753614744202 + 
          0.0017985310838962416*lm + 0.003855802558845305*lm^2) + 
        0.00016792260796248286*NM + 0.0002605768335016789*lm*NM + 
        0.0002142112532691836*lm^2*NM + 0.0010264314005928757*NL + 
        0.0002605768335016789*lm*NL + 0.0002142112532691836*lm^2*NL - 
        0.00001661687578166142*NH + 0.0002605768335016789*lm*NH + 
        0.0002142112532691836*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0033485798208648778 - 0.0028746063847529834*lm - 
          0.0011593387195592522*lm^2) + CF*(0.0039013163405786453 + 
          0.0017331720164894242*lm + 0.0037941994458302805*lm^2) + 
        0.00016047292532142635*NM + 0.00025437897782567415*lm*NM + 
        0.00021078885810168224*lm^2*NM + 0.0010086237165000283*NL + 
        0.00025437897782567415*lm*NL + 0.00021078885810168224*lm^2*NL - 
        0.000014826079058706616*NH + 0.00025437897782567415*lm*NH + 
        0.00021078885810168224*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.003281041605733677 - 0.002817754673511928*lm - 
          0.0011408601055226746*lm^2) + CF*(0.003832363451494135 + 
          0.0016694372412153823*lm + 0.0037337239817105713*lm^2) + 
        0.0001532615799357466*NM + 0.00024831834597212836*lm*NM + 
        0.00020742911009503175*lm^2*NM + 0.000991175302901127*NL + 
        0.00024831834597212836*lm*NL + 0.00020742911009503175*lm^2*NL - 
        0.00001308064416739397*NH + 0.00024831834597212836*lm*NH + 
        0.00020742911009503175*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.003214976336694567 - 0.0027620705088653246*lm - 
          0.0011227189812292903*lm^2) + CF*(0.0037648624848999317 + 
          0.0016072894012066697*lm + 0.0036743530294776777*lm^2) + 
        0.00014628151527652843*NM + 0.00024239189851749598*lm*NM + 
        0.00020413072385987098*lm^2*NM + 0.0009740781406677658*NL + 
        0.00024239189851749598*lm*NL + 0.00020413072385987098*lm^2*NL - 
        0.000011379586670670086*NH + 0.00024239189851749598*lm*NH + 
        0.00020413072385987098*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.003150350351683171 - 0.002707528750269062*lm - 
          0.0011049084366406162*lm^2) + CF*(0.003698781657966333 + 
          0.0015466919616315283*lm + 0.003616063974460199*lm^2) + 
        0.00013952588008927876*NM + 0.00023659666347092652*lm*NM + 
        0.0002008924430255666*lm^2*NM + 0.0009573244015623714*NL + 
        0.00023659666347092652*lm*NL + 0.0002008924430255666*lm^2*NL - 
        9.721942406349341*^-6*NH + 0.00023659666347092652*lm*NH + 
        0.0002008924430255666*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.003087130771245056 - 0.0026541048183125293*lm - 
          0.0010874217174249782*lm^2) + CF*(0.0036340898558071782 + 
          0.0014876091933417688*lm + 0.003558834711572656*lm^2) + 
        0.00013298802245998733*NM + 0.0002309297348345145*lm*NM + 
        0.00019771303953181423*lm^2*NM + 0.0009409064435705834*NL + 
        0.0002309297348345145*lm*NL + 0.00019771303953181423*lm^2*NL - 
        8.106767096922593*^-6*NH + 0.0002309297348345145*lm*NH + 
        0.00019771303953181423*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.003025285480967862 - 0.0026017746821118347*lm - 
          0.0010702522211622563*lm^2) + CF*(0.003570756619724044 + 
          0.0014300061567381766*lm + 0.0035026436328946566*lm^2) + 
        0.00012666148404888303*NM + 0.00022538827118939828*lm*NM + 
        0.00019459131293859204*lm^2*NM + 0.0009248168063440704*NL + 
        0.00022538827118939828*lm*NL + 0.00019459131293859204*lm^2*NL - 
        6.533135965487276*^-6*NH + 0.00022538827118939828*lm*NH + 
        0.00019459131293859204*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0029647831142425854 - 0.002550514846969498*lm - 
          0.001053393493646857*lm^2) + CF*(0.0035087521355215783 + 
          0.001373848685857757*lm + 0.003447469615571532*lm^2) + 
        0.0001205399944875151*NM + 0.00021996949430757814*lm*NM + 
        0.00019152608975397402*lm^2*NM + 0.0009090482067516283*NL + 
        0.00021996949430757814*lm*NL + 0.00019152608975397402*lm^2*NL - 
        5.000143357780395*^-6*NH + 0.00021996949430757814*lm*NH + 
        0.00019152608975397402*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.002905593035352609 - 0.002500302342296408*lm - 
          0.001036839225286281*lm^2) + CF*(0.0034480472219026803 + 
          0.0013191033726864996*lm + 0.0033932920100278293*lm^2) + 
        0.00011461746593487219*NM + 0.00021467068778929842*lm*NM + 
        0.00018851622277932383*lm^2*NM + 0.0008935935345364127*NL + 
        0.00021467068778929842*lm*NL + 0.00018851622277932383*lm^2*NL - 
        3.5069023702907993*^-6*NH + 0.00021467068778929842*lm*NH + 
        0.00018851622277932383*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.0028476853228886715 - 0.002451114709791813*lm - 
          0.0010205832475927161*lm^2) + CF*(0.0033886133189514975 + 
          0.0012657375517007626*lm + 0.003340090628485253*lm^2) + 
        0.00010888798778833769*NM + 0.00020948919572581678*lm*NM + 
        0.00018556059047140295*lm^2*NM + 0.0008784458480771675*NL + 
        0.00020948919572581678*lm*NL + 0.00018556059047140295*lm^2*NL - 
        2.0525444844223347*^-6*NH + 0.00020948919572581678*lm*NH + 
        0.00018556059047140295*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.0027910307534876368 - 0.002402929991877058*lm - 
          0.001004619529765162*lm^2) + CF*(0.0033304224767115725 + 
          0.0012137192846398365*lm + 0.0032878457337768945*lm^2) + 
        0.00010334582154536595*NM + 0.0002044224213873615*lm*NM + 
        0.00018265809632093857*lm^2*NM + 0.0008635983702513215*NL + 
        0.0002044224213873615*lm*NL + 0.00018265809632093857*lm^2*NL - 
        6.36219206675058*^-7*NH + 0.0002044224213873615*lm*NH + 
        0.00018265809632093857*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.002735600785892594 - 0.002355726720378803*lm - 
          0.0009889421753596576*lm^2) + CF*(0.003273447343865821 + 
          0.0011630173455117372*lm + 0.0032365380284497887*lm^2) + 
        0.00009798539581184992*NM + 0.00019946782593605993*lm*NM + 
        0.00017980766824721048*lm^2*NM + 0.0008490444843978427*NL + 
        0.00019946782593605993*lm*NL + 0.00017980766824721048*lm^2*NL + 
        7.429062851923823*^-7*NH + 0.00019946782593605993*lm*NH + 
        0.00017980766824721048*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.0026813675453315447 - 0.0023094839054574033*lm - 
          0.000973545419045243*lm^2) + CF*(0.003217661156524435 + 
          0.0011136012058338184*lm + 0.003186148644148068*lm^2) + 
        0.00009280130145323678*NM + 0.00019462292716360385*lm*NM + 
        0.00017700825800822601*lm^2*NM + 0.0008347777303777522*NL + 
        0.00019462292716360385*lm*NL + 0.00017700825800822601*lm^2*NL + 
        2.085647490059862*^-6*NH + 0.00019462292716360385*lm*NH + 
        0.00017700825800822601*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.0026283038082116623 - 0.0022641810247761717*lm - 
          0.0009584236234433613*lm^2) + CF*(0.0031630377271262443 + 
          0.001065441020109352*lm + 0.003136659131269182*lm^2) + 
        0.00008778828688453427*NM + 0.00018988529825340216*lm*NM + 
        0.0001742588406260657*lm^2*NM + 0.0008207918007302248*NL + 
        0.00018988529825340216*lm*NL + 0.0001742588406260657*lm^2*NL + 
        3.3928029254465124*^-6*NH + 0.00018988529825340216*lm*NH + 
        0.0001742588406260657*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.002576382987125886 - 0.0022197980129072107*lm - 
          0.0009435712760484572*lm^2) + CF*(0.003109551433458546 + 
          0.0010185076115408365*lm + 0.00308805144888586*lm^2) + 
        0.00008294125349543611*NM + 0.0001852525665669573*lm*NM + 
        0.00017155841382699222*lm^2*NM + 0.0008070805369222182*NL + 
        0.0001852525665669573*lm*NL + 0.00017155841382699222*lm^2*NL + 
        4.665154463662363*^-6*NH + 0.0001852525665669573*lm*NH + 
        0.00017155841382699222*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.002525579116168409 - 0.0021763152509695345*lm - 
          0.0009289829862275985*lm^2) + CF*(0.0030571772077999065 + 
          0.0009727724579804074*lm + 0.0030403079549266862*lm^2) + 
        0.00007825525120688012*NM + 0.0001807224124541901*lm*NM + 
        0.000168905997495927*lm^2*NM + 0.0007936379256895998*NL + 
        0.0001807224124541901*lm*NL + 0.000168905997495927*lm^2*NL + 
        5.903467662161111*^-6*NH + 0.0001807224124541901*lm*NH + 
        0.000168905997495927*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.0024758668365554163 - 0.0021337135564952056*lm - 
          0.0009146534822969993*lm^2) + CF*(0.0030058905261899885 + 
          0.0009282076781173957*lm + 0.0029934113966083617*lm^2) + 
        0.00007372547415543731*NM + 0.00017629256808742594*lm*NM + 
        0.00016630063314490898*lm^2*NM + 0.0007804580954677622*NL + 
        0.00017629256808742594*lm*NL + 0.00016630063314490898*lm^2*NL + 
        7.108492088146862*^-6*NH + 0.00017629256808742594*lm*NH + 
        0.00016630063314490898*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.002427221382547292 - 0.002091974173519232*lm - 
          0.0009005776086733865*lm^2) + CF*(0.0029556673978299985 + 
          0.0008847860179027543*lm + 0.002947344901112901*lm^2) + 
        0.0000693472565020143*NM + 0.00017196081631874613*lm*NM + 
        0.00016374138339516118*lm^2*NM + 0.0007675353129097447*NL + 
        0.00017196081631874613*lm*NL + 0.00016374138339516118*lm^2*NL + 
        8.280961637490158*^-6*NH + 0.00017196081631874613*lm*NH + 
        0.00016374138339516118*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.002379618567668347 - 0.0020510787628890016*lm - 
          0.0008867503230982027*lm^2) + CF*(0.0029064843546169608 + 
          0.0008424808372097877*lm + 0.002902091966503209*lm^2) + 
        0.00006511606836143434*NM + 0.00016772498956039967*lm*NM + 
        0.00016122733147240048*lm^2*NM + 0.0007548639794899049*NL + 
        0.00016772498956039967*lm*NL + 0.00016122733147240048*lm^2*NL + 
        9.421594848010726*^-6*NH + 0.00016772498956039967*lm*NH + 
        0.00016122733147240048*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.002333034771220007 - 0.0020110093927890467*lm - 
          0.000873166693932697*lm^2) + CF*(0.0028583184408146156 + 
          0.0008012660967303488*lm + 0.0028576364528706444*lm^2) + 
        0.000061027511849544855*NM + 0.00016358296868796289*lm*NM + 
        0.0001587575807150358*lm^2*NM + 0.0007424386281912116*NL + 
        0.00016358296868796289*lm*NL + 0.0001587575807150358*lm^2*NL + 
        0.000010531095207186456*NH + 0.00016358296868796289*lm*NH + 
        0.0001587575807150358*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.002287446925083288 - 0.001971748529476976*lm - 
          0.0008598218975220052*lm^2) + CF*(0.0028111472028633936 + 
          0.0007611163451054238*lm + 0.0028139625737083804*lm^2) + 
        0.00005707731724458028*NM + 0.0001595326819659283*lm*NM + 
        0.00015633125409491002*lm^2*NM + 0.0007302539202742588*NL + 
        0.0001595326819659283*lm*NL + 0.00015633125409491002*lm^2*NL + 
        0.000011610151454349793*NH + 0.0001595326819659283*lm*NH + 
        0.00015633125409491002*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.00224283250080629 - 0.0019332790282264427*lm - 
          0.0008467112156263753*lm^2) + CF*(0.0027649486793315707 + 
          0.0007220067062887988*lm + 0.002771054887504501*lm^2) + 
        0.000053261339259589535*NM + 0.0001555721039953986*lm*NM + 
        0.00015394749375025006*lm^2*NM + 0.0007183046421261322*NL + 
        0.0001555721039953986*lm*NL + 0.00015394749375025006*lm^2*NL + 
        0.000012659437877434455*NH + 0.0001555721039953986*lm*NH + 
        0.00015394749375025006*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.0021991694969723673 - 0.0018955841244730541*lm - 
          0.0008338300329177422*lm^2) + CF*(0.002719701391009389 + 
          0.0006839128671422967*lm + 0.0027288982895489746*lm^2) + 
        0.00004957555342281634*NM + 0.00015169925468355708*lm*NM + 
        0.00015160546053049858*lm^2*NM + 0.0007065857021872851*NL + 
        0.00015169925468355708*lm*NL + 0.00015160546053049858*lm^2*NL + 
        0.00001367961460433667*NH + 0.00015169925468355708*lm*NH + 
        0.00015160546053049858*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.0021564364268445596 - 0.0018586474251591734*lm - 
          0.0008211738345399069*lm^2) + CF*(0.0026753843311476404 + 
          0.0006468110652608864*lm + 0.0026874780039487863*lm^2) + 
        0.000046016052562998667*NM + 0.000147912198234582*lm*NM + 
        0.00014930433355271036*lm^2*NM + 0.0006950921279546161*NL + 
        0.000147912198234582*lm*NL + 0.00014930433355271036*lm^2*NL + 
        0.00001467132788895649*NH + 0.000147912198234582*lm*NH + 
        0.00014930433355271036*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.0021146123062818246 - 0.001822452900273607*lm - 
          0.0008087382037306213*lm^2) + CF*(0.0026319769558419163 + 
          0.0006106780770257907*lm + 0.0026467795758456695*lm^2) + 
        0.00004257904339663014*NM + 0.00014420904216166905*lm*NM + 
        0.00014704330976920388*lm^2*NM + 0.0006838190630589677*NL + 
        0.00014420904216166905*lm*NL + 0.00014704330976920388*lm^2*NL + 
        0.00001563521039198579*NH + 0.00014420904216166905*lm*NH + 
        0.00014704330976920388*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.0020736766419225615 - 0.0017869848745822165*lm - 
          0.0007965188195039271*lm^2) + CF*(0.0025894591745634857 + 
          0.000575491205883571*lm + 0.0026067888638310346*lm^2) + 
        0.000039260843214301836*NM + 0.00014058793631982483*lm*NM + 
        0.00014482160354616858*lm^2*NM + 0.0006727617644152992*NL + 
        0.00014058793631982483*lm*NL + 0.00014482160354616858*lm^2*NL + 
        0.000016571881456510515*NH + 0.00014058793631982483*lm*NH + 
        0.00014482160354616858*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.00203360941963089 - 0.001752228019545548*lm - 
          0.0007845114543911434*lm^2) + CF*(0.0025478113408375 + 
          0.0005412282708490172*lm + 0.002567492032552833*lm^2) + 
        0.00003605787666331683*NM + 0.00013704707195909122*lm*NM + 
        0.00014263844625293516*lm^2*NM + 0.0006619155994438176*NL + 
        0.00013704707195909122*lm*NL + 0.00014263844625293516*lm^2*NL + 
        0.000017481947378495552*NH + 0.00013704707195909122*lm*NH + 
        0.00014263844625293516*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.0019943910932011225 - 0.0017181673454196096*lm - 
          0.0007727119722389379*lm^2) + CF*(0.002507014243069016 + 
          0.0005078675952295547*lm + 0.0025288755455092514*lm^2) + 
        0.00003296667262384281*NM + 0.00013358468079786075*lm*NM + 
        0.0001404930858616251*lm^2*NM + 0.0006512760433603813*NL + 
        0.00013358468079786075*lm*NL + 0.0001404930858616251*lm^2*NL + 
        0.00001836600167222135*NH + 0.00013358468079786075*lm*NH + 
        0.0001404930858616251*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.001956002573315861 - 0.001684788193535999*lm - 
          0.0007611163260629665*lm^2) + CF*(0.00246704909551711 + 
          0.00047538799556875555*lm + 0.002490926158024254*lm^2) + 
        0.00002998386117593942*NM + 0.00013019903411594144*lm*NM + 
        0.000138384786556903*lm^2*NM + 0.0006408386765345233*NL + 
        0.00013019903411594144*lm*NL + 0.000138384786556903*lm^2*NL + 
        0.000019224625330741857*NH + 0.00013019903411594144*lm*NH + 
        0.000138384786556903*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.0019184252167531364 - 0.0016520762287576117*lm - 
          0.0007497205559555981*lm^2) + CF*(0.0024278975294171504 + 
          0.0004437687708064476*lm + 0.0024536309104001394*lm^2) + 
        0.000027106170654867073*NM + 0.00012688844186703067*lm*NM + 
        0.0001363128283555633*lm^2*NM + 0.0006305991819134751*NL + 
        0.00012688844186703067*lm*NL + 0.0001363128283555633*lm^2*NL + 
        0.000020058387081433936*NH + 0.00012688844186703067*lm*NH + 
        0.0001363128283555633*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.001881640815838017 - 0.0016200174321062408*lm - 
          0.0007385207870462923*lm^2) + CF*(0.0023895415842511343 + 
          0.0004129896916528207*lm + 0.002416977121242411*lm^2) + 
        0.000024330424792152733*NM + 0.00012365125181025717*lm*NM + 
        0.0001342765067356895*lm^2*NM + 0.0006205533425105995*NL + 
        0.00012365125181025717*lm*NL + 0.0001342765067356895*lm^2*NL + 
        0.00002086784363670868*NH + 0.00012365125181025717*lm*NH + 
        0.0001342765067356895*lm^2*NH)}, 
     {1., 1.525592094936152*^-15*CF*NC*
       (420.*CF*(3.670649309228857*^9 + 5.97786624*^8*lm + 
          3.7158912*^9*lm^2) - 6.*CA*(2.016300855976144*^11 + 
          1.7354989568*^11*lm + 7.9478784*^10*lm^2) + 1.4193531817468912*^10*
         NM + 7.897645056*^10*lm*NM + 8.6704128*^10*lm^2*NM + 
        4.00301654016*^11*NL + 7.897645056*^10*lm*NL + 
        8.6704128*^10*lm^2*NL + 1.4193531817468912*^10*NH + 
        7.897645056*^10*lm*NH + 8.6704128*^10*lm^2*NH)}}
 
CbarTable["s", 2, 4] = {{0., -9.720394788002078*^-11*CF*NC*
       (CF*(-6.680692866407926*^8 - 7.327430668528489*^8*lm - 
          1.1573604*^9*lm^2) + 35.*CA*(7.177114445052359*^6 + 
          1.9947862188032452*^7*lm + 6.73596*^6*lm^2) + 
        70.*(9.*(-252382.29040926497 - 114897.19381850964*lm - 68040.*lm^2)*
           NM + 9.*(-252382.29040926497 - 114897.19381850964*lm - 
            68040.*lm^2)*NL + (496876.36851328495 - 1.0340747443665867*^6*
             lm - 612360.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.027909450272946196 - 0.06727703704354628*lm - 
          0.02244698750237752*lm^2) + CF*(0.06259226058931384 + 
          0.0737055891576725*lm + 0.11019430228439873*lm^2) + 
        0.015725790034975408*NM + 0.007037844337945846*lm*NM + 
        0.004081270454977731*lm^2*NM + 0.015727760213130288*NL + 
        0.007037844337945846*lm*NL + 0.004081270454977731*lm^2*NL - 
        0.00332426783334012*NH + 0.007037844337945846*lm*NH + 
        0.004081270454977731*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.03117350736123241 - 0.06661402217000628*lm - 
          0.02196066290977983*lm^2) + CF*(0.060532765524598665 + 
          0.07600935838643161*lm + 0.10780689064801008*lm^2) + 
        0.015942018914119352*NM + 0.007029834101374404*lm*NM + 
        0.003992847801778151*lm^2*NM + 0.015951770744380513*NL + 
        0.007029834101374404*lm*NL + 0.003992847801778151*lm^2*NL - 
        0.003265503627797085*NH + 0.007029834101374404*lm*NH + 
        0.003992847801778151*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.03413416349813016 - 0.06587671200815806*lm - 
          0.021463939418622204*lm^2) + CF*(0.05876154865554243 + 
          0.07806726212306922*lm + 0.10536842987323629*lm^2) + 
        0.016096271053822084*NM + 0.007010721987256658*lm*NM + 
        0.003902534439749492*lm^2*NM + 0.016120579636963353*NL + 
        0.007010721987256658*lm*NL + 0.003902534439749492*lm^2*NL - 
        0.003205195837323854*NH + 0.007010721987256658*lm*NH + 
        0.003902534439749492*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.03677385172799773 - 0.06507054183148456*lm - 
          0.020961213008449567*lm^2) + CF*(0.057243122213157055 + 
          0.07985573766294277*lm + 0.10290050022329787*lm^2) + 
        0.01618939340445319*NM + 0.00698047897567002*lm*NM + 
        0.003811129637899921*lm^2*NM + 0.01623497803902863*NL + 
        0.00698047897567002*lm*NL + 0.003811129637899921*lm^2*NL - 
        0.003143785992645114*NH + 0.00698047897567002*lm*NH + 
        0.003811129637899921*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.039095788711218944 - 0.06420235871315501*lm - 
          0.020455826565210517*lm^2) + CF*(0.05593807855576398 + 
          0.08137018955312342*lm + 0.10041951222921526*lm^2) + 
        0.016225052803522266*NM + 0.006939576428624097*lm*NM + 
        0.003719241193674639*lm^2*NM + 0.016298149297875823*NL + 
        0.006939576428624097*lm*NL + 0.003719241193674639*lm^2*NL - 
        0.0030816221899701247*NH + 0.006939576428624097*lm*NH + 
        0.003719241193674639*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.04111271528374107 - 0.06327933940998685*lm - 
          0.01995040720935217*lm^2) + CF*(0.054809585406973074 + 
          0.08261582180990197*lm + 0.09793836266409248*lm^2) + 
        0.016207991617279784*NM + 0.0068887112822962815*lm*NM + 
        0.003627346765336759*lm^2*NM + 0.016314157969050516*NL + 
        0.0068887112822962815*lm*NL + 0.003627346765336759*lm^2*NL - 
        0.0030189883634528306*NH + 0.0068887112822962815*lm*NH + 
        0.003627346765336759*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.04284195263912153 - 0.06230854302517038*lm - 
          0.019447056175034026*lm^2) + CF*(0.053825034315097706 + 
          0.08360327162710042*lm + 0.09546736667743976*lm^2) + 
        0.01614329265452461*NM + 0.006828680773990048*lm*NM + 
        0.003535828395460732*lm^2*NM + 0.016287331630407017*NL + 
        0.006828680773990048*lm*NL + 0.003535828395460732*lm^2*NL - 
        0.002956120707419597*NH + 0.006828680773990048*lm*NH + 
        0.003535828395460732*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.04430288189824876 - 0.06129670572642733*lm - 
          0.01894747048014117*lm^2) + CF*(0.05295625496689106 + 
          0.08434621097076525*lm + 0.09301485508432938*lm^2) + 
        0.01603602565348017*NM + 0.006760316963119409*lm*NM + 
        0.00344499463275294*lm^2*NM + 0.016221971280888994*NL + 
        0.006760316963119409*lm*NL + 0.00344499463275294*lm^2*NL - 
        0.0028932181690469734*NH + 0.006760316963119409*lm*NH + 
        0.00344499463275294*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.04551555350891994 - 0.060250146263869896*lm - 
          0.018453027189501533*lm^2) + CF*(0.05217924595063247 + 
          0.08485991965006692*lm + 0.09058758802118935*lm^2) + 
        0.015891068329472943*NM + 0.006684450053711527*lm*NM + 
        0.0033550958526366425*lm^2*NM + 0.01612220844148802*NL + 
        0.006684450053711527*lm*NL + 0.0033550958526366425*lm^2*NL - 
        0.002830449702792584*NH + 0.006684450053711527*lm*NH + 
        0.0033550958526366425*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.04649988772938667 - 0.05917472767683619*lm - 
          0.017964844890244944*lm^2) + CF*(0.051473750061317325 + 
          0.08516039468456148*lm + 0.08819105673392973*lm^2) + 
        0.015713016461377436*NM + 0.006601887206310229*lm*NM + 
        0.00326633543458999*lm^2*NM + 0.01599193541224612*NL + 
        0.006601887206310229*lm*NL + 0.00326633543458999*lm^2*NL - 
        0.002767959562469787*NH + 0.006601887206310229*lm*NH + 
        0.00326633543458999*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.047275208640568826 - 0.0580758492400506*lm - 
          0.017483830241837833*lm^2) + CF*(0.05082279995754987 + 
          0.0852637787118044*lm + 0.08582971209629482*lm^2) + 
        0.015506142531884922*NM + 0.006513400301732677*lm*NM + 
        0.0031788782257886968*lm^2*NM + 0.015834774577894166*NL + 
        0.006513400301732677*lm*NL + 0.0031788782257886968*lm^2*NL - 
        0.0027058713155022583*NH + 0.006513400301732677*lm*NH + 
        0.0031788782257886968*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.04785997636991929 - 0.05695845516515867*lm - 
          0.017010714216484014*lm^2) + CF*(0.050212283973811785 + 
          0.08518598848518062*lm + 0.08350714251728517*lm^2) + 
        0.015274381917627693*NM + 0.006419719136958168*lm*NM + 
        0.003092857130269821*lm^2*NM + 0.015654069413207527*NL + 
        0.006419719136958168*lm*NL + 0.003092857130269821*lm^2*NL - 
        0.0026442909797477804*NH + 0.006419719136958168*lm*NH + 
        0.003092857130269821*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.04827164138161337 - 0.05582705259545905*lm - 
          0.016546080922441496*lm^2) + CF*(0.0496305506762583 + 
          0.08494247376831479*lm + 0.08122621543744006*lm^2) + 
        0.015021335001771318*NM + 0.006321528027039151*lm*NM + 
        0.0030083783495348172*lm^2*NM + 0.015452887765121472*NL + 
        0.006321528027039151*lm*NL + 0.0030083783495348172*lm^2*NL - 
        0.0025833095326274606*NH + 0.006321528027039151*lm*NH + 
        0.0030083783495348172*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.048526575710823396 - 0.05468573457482734*lm - 
          0.016090390917449703*lm^2) + CF*(0.04906805728710124 + 
          0.08454806362491323*lm + 0.07898919177657127*lm^2) + 
        0.014750278463708967*NM + 0.006219464586426527*lm*NM + 
        0.0029255256213544913*lm^2*NM + 0.015234032044764275*NL + 
        0.006219464586426527*lm*NL + 0.0029255256213544913*lm^2*NL - 
        0.002523004956306633*NH + 0.006219464586426527*lm*NH + 
        0.0029255256213544913*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.04864005331975802 - 0.05353820541257077*lm - 
          0.015644000322040417*lm^2) + CF*(0.04851706123629719 + 
          0.08401687247673668*lm + 0.07679781976274386*lm^2) + 
        0.014464181699308657*NM + 0.006114119917846489*lm*NM + 
        0.0028443636949164394*lm^2*NM + 0.015000053167147951*NL + 
        0.006114119917846489*lm*NL + 0.0028443636949164394*lm^2*NL - 
        0.0024634439306794177*NH + 0.006114119917846489*lm*NH + 
        0.0028443636949164394*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.04862626188467692 - 0.05238780687561993*lm - 
          0.015207176662746414*lm^2) + CF*(0.04797135165497592 + 
          0.0833622475995037*lm + 0.07465341270802786*lm^2) + 
        0.014165725888372588*NM + 0.006006039708320156*lm*NM + 
        0.0027649412114084393*lm^2*NM + 0.014753266332183686*NL + 
        0.006006039708320156*lm*NL + 0.0027649412114084393*lm^2*NL - 
        0.00240468325297578*NH + 0.006006039708320156*lm*NH + 
        0.0027649412114084393*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.04849833449636013 - 0.05123754424678221*lm - 
          0.014780112124195648*lm^2) + CF*(0.04742601676766822 + 
          0.0825967455770748*lm + 0.07255691406423319*lm^2) + 
        0.013857324165289764*NM + 0.005895725900427524*lm*NM + 
        0.002687293113490118*lm^2*NM + 0.014495767483211866*NL + 
        0.005895725900427524*lm*NL + 0.002687293113490118*lm^2*NL - 
        0.0023467710411358544*NH + 0.005895725900427524*lm*NH + 
        0.002687293113490118*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.048268393642028444 - 0.05009011166363478*lm - 
          0.014362934717594282*lm^2) + CF*(0.046877243022288906 + 
          0.08173212903938981*lm + 0.07050895225000829*lm^2) + 
        0.013541141929842567*NM + 0.005783638714936572*lm*NM + 
        0.0026114426759262332*lm^2*NM + 0.014229449731235095*NL + 
        0.005783638714936572*lm*NL + 0.0026114426759262332*lm^2*NL - 
        0.002289747763365943*NH + 0.005783638714936572*lm*NH + 
        0.0026114426759262332*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.04794760234861386 - 0.04894791639035909*lm - 
          0.013955717752616928*lm^2) + CF*(0.046322142012725755 + 
          0.08077937755375278*lm + 0.06850988714921039*lm^2) + 
        0.013219116702606106*NM + 0.005670198872021702*lm*NM + 
        0.0025374032277485324*lm^2*NM + 0.013956019314477593*NL + 
        0.005670198872021702*lm*NL + 0.0025374032277485324*lm^2*NL - 
        0.002233647126001079*NH + 0.005670198872021702*lm*NH + 
        0.0025374032277485324*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.047546219027444214 - 0.04781310182755662*lm - 
          0.01355848791299005*lm^2) + CF*(0.04575860160108687 + 
          0.07974870828019333*lm + 0.06655984975467842*lm^2) + 
        0.01289297716572875*NM + 0.0055557899061365636*lm*NM + 
        0.002465179620543645*lm^2*NM + 0.013677010841084355*NL + 
        0.0055557899061365636*lm*NL + 0.002465179620543645*lm^2*NL - 
        0.0021784968444393637*NH + 0.0055557899061365636*lm*NH + 
        0.002465179620543645*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.04707365367773661 - 0.04668756916418667*lm - 
          0.013171232172284462*lm^2) + CF*(0.04518515803841354 + 
          0.07864960321700386*lm + 0.06465877611848736*lm^2) + 
        0.01256426118363533*NM + 0.005440760502381336*lm*NM + 
        0.002394769485869902*lm^2*NM + 0.013393801676856575*NL + 
        0.005440760502381336*lm*NL + 0.002394769485869902*lm^2*NL - 
        0.002124319316539192*NH + 0.005440760502381336*lm*NH + 
        0.002394769485869902*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.04653852386942696 - 0.045572997640292844*lm - 
          0.012793903738666077*lm^2) + CF*(0.04460088626756736 + 
          0.07749084072527905*lm + 0.06280643653526984*lm^2) + 
        0.012234332698821753*NM + 0.005325426804990019*lm*NM + 
        0.002326164316121105*lm^2*NM + 0.013107625413350059*NL + 
        0.005325426804990019*lm*NL + 0.002326164316121105*lm^2*NL - 
        0.0020711322138740936*NH + 0.005325426804990019*lm*NH + 
        0.002326164316121105*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.04594870945315684 - 0.044470863431034166*lm - 
          0.012426427180981066*lm^2) + CF*(0.04400530594914892 + 
          0.0762805296424585*lm + 0.06100246070663432*lm^2) + 
        0.011904397463777461*NM + 0.005210074664589105*lm*NM + 
        0.0022593503965420117*lm^2*NM + 0.01281958439886591*NL + 
        0.005210074664589105*lm*NL + 0.0022593503965420117*lm^2*NL - 
        0.0020189490032194936*NH + 0.005210074664589105*lm*NH + 
        0.0022593503965420117*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.045311405312746064 - 0.043382457189307125*lm - 
          0.012068702860446852*lm^2) + CF*(0.04339830107276045 + 
          0.07502614474752425*lm + 0.05924635949673909*lm^2) + 
        0.011575517612883784*NM + 0.005094961802249958*lm*NM + 
        0.0021943096109903366*lm^2*NM + 0.012530661344911365*NL + 
        0.005094961802249958*lm*NL + 0.0021943096109903366*lm^2*NL - 
        0.001967779408329474*NH + 0.005094961802249958*lm*NH + 
        0.0021943096109903366*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.04463317173309556 - 0.042308900300884335*lm - 
          0.011720610770218184*lm^2) + CF*(0.042780051300249 + 
          0.0737345626736657*lm + 0.05753754378107108*lm^2) + 
        0.01124862510549532*NM + 0.004980319876473936*lm*NM + 
        0.0021310201400396695*lm^2*NM + 0.01224173003942225*NL + 
        0.004980319876473936*lm*NL + 0.0021310201400396695*lm^2*NL - 
        0.0019176298202620047*NH + 0.004980319876473936*lm*NH + 
        0.0021310201400396695*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.04391998213753952 - 0.041251159915780385*lm - 
          0.01138201386766988*lm^2) + CF*(0.04215097343645374 + 
          0.0724120976114554*lm + 0.055875340804924865*lm^2) + 
        0.010924534088339167*NM + 0.004866356445061254*lm*NM + 
        0.002069457066849069*lm^2*NM + 0.01195356520921083*NL + 
        0.004866356445061254*lm*NL + 0.002069457066849069*lm^2*NL - 
        0.0018685036630961336*NH + 0.004866356445061254*lm*NH + 
        0.002069457066849069*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.043177268075850414 - 0.040210062824688794*lm - 
          0.011052760970286795*lm^2) + CF*(0.04151167163949409 + 
          0.07106453633023559*lm + 0.05425900839958972*lm^2) + 
        0.01060395223522692*NM + 0.004753256817976225*lm*NM + 
        0.0020095929036885083*lm^2*NM + 0.011666851580243066*NL + 
        0.004753256817976225*lm*NL + 0.0020095929036885083*lm^2*NL - 
        0.001820401720759963*NH + 0.004753256817976225*lm*NH + 
        0.0020095929036885083*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.042409961433010034 - 0.03918630825131404*lm - 
          0.010732689274776375*lm^2) + CF*(0.04086289517028957 + 
          0.0696971721840067*lm + 0.05268774734890221*lm^2) + 
        0.01028749112714765*NM + 0.0046411858002906635*lm*NM + 
        0.0019513980499593412*lm^2*NM + 0.01138219218713549*NL + 
        0.0046411858002906635*lm*NL + 0.0019513980499593412*lm^2*NL - 
        0.0017733224297853077*NH + 0.0046411858002906635*lm*NH + 
        0.0019513980499593412*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.04162253389039084 - 0.03818047963127858*lm - 
          0.0104216265498277*lm^2) + CF*(0.04020550264330335 + 
          0.06831483787246088*lm + 0.05116071215369962*lm^2) + 
        0.009975675737661442*NM + 0.004530289326388042*lm*NM + 
        0.0018948411908777639*lm^2*NM + 0.011100115983828639*NL + 
        0.004530289326388042*lm*NL + 0.0018948411908777639*lm^2*NL - 
        0.001727262142073409*NH + 0.004530289326388042*lm*NH + 
        0.0018948411908777639*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.040819033712838654 - 0.03719305544673128*lm - 
          0.01011939304538858*lm^2) + CF*(0.03954043188072203 + 
          0.06692193680649569*lm + 0.04967702040463484*lm^2) + 
        0.00966895308823185*NM + 0.0044206959880761*lm*NM + 
        0.0018398896446161052*lm^2*NM + 0.010821084806512088*NL + 
        0.0044206959880761*lm*NL + 0.0018398896446161052*lm^2*NL - 
        0.0016822153611582976*NH + 0.0044206959880761*lm*NH + 
        0.0018398896446161052*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.04000311996279077 - 0.036224419183316356*lm - 
          0.009825803155082614*lm^2) + CF*(0.038868674593372066 + 
          0.06552247298686496*lm + 0.04823576094313284*lm^2) + 
        0.009367700136503707*NM + 0.004312518460253278*lm*NM + 
        0.0017865096645604754*lm^2*NM + 0.010545499738073604*NL + 
        0.004312518460253278*lm*NL + 0.0017865096645604754*lm^2*NL - 
        0.0016381749549620797*NH + 0.004312518460253278*lm*NH + 
        0.0017865096645604754*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.039178094259937124 - 0.035274868473129516*lm - 
          0.009540666863182319*lm^2) + CF*(0.03819125521622027 + 
          0.06412007934923789*lm + 0.0468360009647132*lm^2) + 
        0.009072230958156211*NM + 0.004205854828427639*lm*NM + 
        0.0017346667023967852*lm^2*NM + 0.010273706920983092*NL + 
        0.004205854828427639*lm*NL + 0.0017346667023967852*lm^2*NL - 
        0.001595132347627946*NH + 0.004205854828427639*lm*NH + 
        0.0017346667023967852*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.03834693021486687 - 0.034344623483932954*lm - 
          0.009263791003192192*lm^2) + CF*(0.03750921331653929 + 
          0.0627180445623254*lm + 0.045476792197488944*lm^2) + 
        0.008782803280404232*NM + 0.004100789822786311*lm*NM + 
        0.0016843256369440348*lm^2*NM + 0.010006002862848523*NL + 
        0.004100789822786311*lm*NL + 0.0016843256369440348*lm^2*NL - 
        0.001553077692675457*NH + 0.004100789822786311*lm*NH + 
        0.0016843256369440348*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.03751230066966043 - 0.033433834611393244*lm - 
          0.008994980351420523*lm^2) + CF*(0.03682358907059293 + 
          0.061319338290520685*lm + 0.04415717627060983*lm^2) + 
        0.008499624423182675*NM + 0.003997395963726253*lm*NM + 
        0.0016354509729855494*lm^2*NM + 0.009742639276064812*NL + 
        0.003997395963726253*lm*NL + 0.0016354509729855494*lm^2*NL - 
        0.0015120000294357513*NH + 0.003997395963726253*lm*NH + 
        0.0016354509729855494*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.03667660287887285 - 0.03254258952756334*lm - 
          0.008734038575806579*lm^2) + CF*(0.036135411371436145 + 
          0.0599266349506787*lm + 0.04287618937214139*lm^2) + 
        0.008222856703652753*NM + 0.0038957346238331337*lm*NM + 
        0.0015880070137830144*lm^2*NM + 0.009483827490131765*NL + 
        0.0038957346238331337*lm*NL + 0.0015880070137830144*lm^2*NL - 
        0.001471887424481612*NH + 0.0038957346238331337*lm*NH + 
        0.0015880070137830144*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.035841981761630545 - 0.031670919635333104*lm - 
          0.008480769057622633*lm^2) + CF*(0.03544568818699586 + 
          0.05854233600575009*lm + 0.04163286628287475*lm^2) + 
        0.007952622362960298*NM + 0.0037958570112718555*lm*NM + 
        0.0015419580104768424*lm^2*NM + 0.00922974247241964*NL + 
        0.0037958570112718555*lm*NL + 0.0015419580104768424*lm^2*NL - 
        0.0014327270995608792*NH + 0.0037958570112718555*lm*NH + 
        0.0015419580104768424*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.03501035134983586 - 0.03081880597517541*lm - 
          0.008234975601408779*lm^2) + CF*(0.03475539883402139 + 
          0.0571685908471558*lm + 0.040426243861461285*lm^2) + 
        0.007689008084974385*NM + 0.0036978050794579604*lm*NM + 
        0.0014972682911652327*lm^2*NM + 0.00898052649045968*NL + 
        0.0036978050794579604*lm*NL + 0.0014972682911652327*lm^2*NL - 
        0.0013945055473651067*NH + 0.0036978050794579604*lm*NH + 
        0.0014972682911652327*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.034183414548131584 - 0.02998618462725276*lm - 
          0.00799646304655912*lm^2) + CF*(0.034065487868404715 + 
          0.05580731632394112*lm + 0.03925536404674477*lm^2) + 
        0.007432069202020262*NM + 0.0036016123677347547*lm*NM + 
        0.001453902372101658*lm^2*NM + 0.008736292446262735*NL + 
        0.0036016123677347547*lm*NL + 0.001453902372101658*lm^2*NL - 
        0.001357208636313591*NH + 0.0036016123677347547*lm*NH + 
        0.001453902372101658*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.033362681306484364 - 0.029172951648843905*lm - 
          0.00776503779230868*lm^2) + CF*(0.03337686031212979 + 
          0.05446021498058161*lm + 0.03811927643496989*lm^2) + 
        0.007181833734626048*NM + 0.003507304777602668*lm*NM + 
        0.0014118250531470328*lm^2*NM + 0.008497126910739086*NL + 
        0.003507304777602668*lm*NL + 0.0014118250531470328*lm^2*NL - 
        0.0013208217054018177*NH + 0.003507304777602668*lm*NH + 
        0.0014118250531470328*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.032549487336231815 - 0.02837896758411315*lm - 
          0.007540508246429029*lm^2) + CF^2*(0.03269038204231261 + 
          0.05312879206737079*lm + 0.037017040482469774*lm^2) + 
        CF*((0.006938289794193112 + 0.0034149012888469135*lm + 
            0.0013710014993507324*lm^2)*NM + (0.008263092884015237 + 
            0.0034149012888469135*lm + 0.0013710014993507324*lm^2)*NL + 
          (-0.0012853296500496632 + 0.0034149012888469135*lm + 
            0.0013710014993507324*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.03174500389881096 - 0.02760406158048193*lm - 
          0.007322685206692055*lm^2) + CF^2*(0.032006866005848095 + 
          0.051814371388026075*lm + 0.03594772737830645*lm^2) + 
        CF*((0.006701436063786477 + 0.003324414619696074*lm + 
            0.0013313973103076463*lm^2)*NM + (0.008034232305320715 + 
            0.003324414619696074*lm + 0.0013313973103076463*lm^2)*NL + 
          (-0.0012507169997856282 + 0.003324414619696074*lm + 
            0.0013313973103076463*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.030950258877381374 - 0.026848035143272886*lm - 
          0.0071113821830769385*lm^2) + CF^2*(0.0313270843228235 + 
          0.05051811004883214*lm + 0.034910421626014064*lm^2) + 
        CF*((0.0064712263311672525 + 0.0032358518349243737*lm + 
            0.0012929785787412615*lm^2)*NM + (0.007810568334147966 + 
            0.0032358518349243737*lm + 0.0012929785787412615*lm^2)*NL + 
          (-0.0012169679885167502 + 0.0032358518349243737*lm + 
            0.0012929785787412615*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.030166145979625143 - 0.026110665557878776*lm - 
          0.006906415667750834*lm^2) + CF^2*(0.030651759652194206 + 
          0.04924101217256686*lm + 0.03390422236895864*lm^2) + 
        CF*((0.006247604891672563 + 0.0031492149055893366*lm + 
            0.0012557119395910608*lm^2)*NM + (0.0075921074225661 + 
            0.0031492149055893366*lm + 0.0012557119395910608*lm^2)*NL + 
          (-0.0011840666180577262 + 0.0031492149055893366*lm + 
            0.0012557119395910608*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.029393437585904132 - 0.02539170900645518*lm - 
          0.006707605359029313*lm^2) + CF^2*(0.029981566556087056 + 
          0.04798394163881681*lm + 0.03292824448978027*lm^2) + 
        CF*((0.006030501535867776 + 0.003064501223877629*lm + 
            0.0012195646107326025*lm^2)*NM + (0.007378841196888036 + 
            0.003064501223877629*lm + 0.0012195646107326025*lm^2)*NL + 
          (-0.0011519967155261333 + 0.003064501223877629*lm + 
            0.0012195646107326025*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.02863279578123635 - 0.024690903404041807*lm - 
          0.006514774344801203*lm^2) + CF^2*(0.029317131675800606 + 
          0.0467476339102543*lm + 0.03198161951084227*lm^2) + 
        CF*((0.005819833518526479 + 0.002981704076318067*lm + 
            0.0011845044263274914*lm^2)*NM + (0.007170748165342847 + 
            0.002981704076318067*lm + 0.0011845044263274914*lm^2)*NL + 
          (-0.0011207419851494316 + 0.002981704076318067*lm + 
            0.0011845044263274914*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.027884782485626126 - 0.0240079709770736*lm - 
          0.006327749250269914*lm^2) + CF^2*(0.028659034310211023 + 
          0.04553270700213577*lm + 0.031063496319506848*lm^2) + 
        CF*((0.005615507331000925 + 0.0029008130784137325*lm + 
            0.0011504998636854388*lm^2)*NM + (0.006967795266982551 + 
            0.0029008130784137325*lm + 0.0011504998636854388*lm^2)*NL + 
          (-0.0010902860549835988 + 0.0029008130784137325*lm + 
            0.0011504998636854388*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.02714986875280506 - 0.02334262060544136*lm - 
          0.006146360354307753*lm^2) + CF^2*(0.02800780732140055 + 
          0.044339671649789636*lm + 0.03017304173932897*lm^2) + 
        CF*((0.005417420294729905 + 0.002821814573546222*lm + 
            0.0011175200644195915*lm^2)*NM + (0.006769939275746875 + 
            0.002821814573546222*lm + 0.0011175200644195915*lm^2)*NL + 
          (-0.0010606125189829715 + 0.002821814573546222*lm + 
            0.0011175200644195915*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.02642844330212244 - 0.02269454994759472*lm - 
          0.0059704416782307285*lm^2) + CF^2*(0.027363938302543873 + 
          0.04316894072626583*lm + 0.02930944096585994*lm^2) + 
        CF*((0.005225461992699386 + 0.0027446919988150693*lm + 
            0.0010855348505874052*lm^2)*NM + (0.006577128072412375 + 
            0.0027446919988150693*lm + 0.0010855348505874052*lm^2)*NL + 
          (-0.0010317049748364534 + 0.0027446919988150693*lm + 
            0.0010855348505874052*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.025720820343831715 - 0.022063447366638195*lm - 
          0.005799831050370336*lm^2) + CF^2*(0.02672787095295269 + 
          0.04202083795967697*lm + 0.02847189788363619*lm^2) + 
        CF*((0.005039515553400728 + 0.0026694262202948005*lm + 
            0.0010545147364309701*lm^2)*NM + (0.006389301796055554 + 
            0.0026694262202948005*lm + 0.0010545147364309701*lm^2)*NL + 
          (-0.0010035470579342353 + 0.0026694262202948005*lm + 
            0.0010545147364309701*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.0250272467532628 - 0.021448993673946787*lm - 
          0.005634370149438344*lm^2) + CF^2*(0.026100006612694758 + 
          0.040895605997117036*lm + 0.027659635279060964*lm^2) + 
        CF*((0.004859458801167424 + 0.0025959958400211215*lm + 
            0.001024430936261517*lm^2)*NM + (0.006206393885655637 + 
            0.0025959958400211215*lm + 0.001024430936261517*lm^2)*NL + 
          (-0.000976122471802534 + 0.0025959958400211215*lm + 
            0.001024430936261517*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.02434790864523512 - 0.020850863705512025*lm - 
          0.005473904529344202*lm^2) + CF^2*(0.025480705916315658 + 
          0.03979341385943068*lm + 0.026871894962235174*lm^2) + 
        CF*((0.004685165285229493 + 0.0025243774768564206*lm + 
            0.000995255368971673*lm^2)*NM + (0.006028332021544077 + 
            0.0025243774768564206*lm + 0.000995255368971673*lm^2)*NL + 
          (-0.0009494150153119214 + 0.0025243774768564206*lm + 
            0.000995255368971673*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.02368293739601891 - 0.02026872774501564*lm - 
          0.005318283627826915*lm^2) + CF^2*(0.024870290530987525 + 
          0.038714363828550966*lm + 0.026107937809332127*lm^2) + 
        CF*((0.004516505198805978 + 0.002454546023232979*lm + 
            0.0009669606596048936*lm^2)*NM + (0.0058550389755677055 + 
            0.002454546023232979*lm + 0.0009669606596048936*lm^2)*NL + 
          (-0.000923408606938643 + 0.002454546023232979*lm + 
            0.0009669606596048936*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.02303241515629951 - 0.019702252806508364*lm - 
          0.0051673607609993765*lm^2) + CF^2*(0.02426904494924606 + 
          0.03765849780664323*lm + 0.025367043735815123*lm^2) + 
        CF*((0.004353346198497602 + 0.0023864748796297644*lm + 
            0.000939520138363523*lm^2)*NM + (0.005686433378064395 + 
            0.0023864748796297644*lm + 0.000939520138363523*lm^2)*NL + 
          (-0.0008980873063329395 + 0.0023864748796297644*lm + 
            0.000939520138363523*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.02239637989485598 - 0.01915110378853903*lm - 
          0.005020993105668986*lm^2) + CF^2*(0.02367721831031456 + 
          0.03662580318390062*lm + 0.02464851160964775*lm^2) + 
        CF*((0.004195554133461358 + 0.002320136168505182*lm + 
            0.0009129078373943611*lm^2)*NM + (0.00552243040904807 + 
            0.002320136168505182*lm + 0.0009129078373943611*lm^2)*NL + 
          (-0.000873435333427285 + 0.002320136168505182*lm + 
            0.0009129078373943611*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.02177483000897814 - 0.018614944510627573*lm - 
          0.004879041671090435*lm^2) + CF^2*(0.023095026226863526 + 
          0.03561621824954304*lm + 0.02395165911262577*lm^2) + 
        CF*((0.004042993692748377 + 0.00225550092928326*lm + 
            0.0008870984856528064*lm^2)*NM + (0.005362942420358342 + 
            0.00225550092928326*lm + 0.0008870984856528064*lm^2)*NL + 
          (-0.0008494370852973025 + 0.00225550092928326*lm + 
            0.0008870984856528064*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.02116772853379911 - 0.018093438642098898*lm - 
          0.00474137126162173*lm^2) + CF^2*(0.022522652595591157 + 
          0.03462963717837928*lm + 0.02327582255705213*lm^2) + 
        CF*((0.003895528978721216 + 0.0021925392958741102*lm + 
            0.0008620675021130419*lm^2)*NM + (0.0052078794949439134 + 
            0.0021925392958741102*lm + 0.0008620675021130419*lm^2)*NL + 
          (-0.000826077150969902 + 0.0021925392958741102*lm + 
            0.0008620675021130419*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.020575006978756905 - 0.017586250532486674*lm - 
          0.004607850431590037*lm^2) + CF^2*(0.021960251370417013 + 
          0.03366591462320713*lm + 0.022620356664169276*lm^2) + 
        CF*((0.003753024013489292 + 0.002131220658100709*lm + 
            0.000837790987561825*lm^2)*NM + (0.00505714994891334 + 
            0.002131220658100709*lm + 0.000837790987561825*lm^2)*NL + 
          (-0.0008033403243561489 + 0.002131220658100709*lm + 
            0.000837790987561825*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.019996568815136877 - 0.01709304595197238*lm - 
          0.0044783514335275205*lm^2) + CF^2*(0.021407948276082465 + 
          0.03272486994134738*lm + 0.02198463431004419*lm^2) + 
        CF*((0.0036153431849305956 + 0.0020715138083026593*lm + 
            0.0008142457151868219*lm^2)*NM + (0.004910660781497532 + 
            0.0020715138083026593*lm + 0.0008142457151868219*lm^2)*NL + 
          (-0.0007812116154747731 + 0.0020715138083026593*lm + 
            0.0008142457151868219*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.019432292634457175 - 0.016613492749639663*lm - 
          0.004352750160806889*lm^2) + CF^2*(0.020865842438367026 + 
          0.0318062910817358*lm + 0.021368046243961093*lm^2) + 
        CF*((0.003482351637908204 + 0.0020133870742932206*lm + 
            0.0007914091201467071*lm^2)*NM + (0.004768318077621477 + 
            0.0020133870742932206*lm + 0.0007914091201467071*lm^2)*NL + 
          (-0.0007596762601114836 + 0.0020133870742932206*lm + 
            0.0007914091201467071*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.018881773572880588 - 0.016147261436693424*lm - 
          0.004230926085590075*lm^2) + CF^2*(0.02033348506410755 + 
          0.030909938157229918*lm + 0.020770000783805823*lm^2) + 
        CF*((0.003353915616376048 + 0.0019568084397581257*lm + 
            0.0007692592882891046*lm^2)*NM + (0.0046300273673743845 + 
            0.0019568084397581257*lm + 0.0007692592882891046*lm^2)*NL + 
          (-0.000738719728056471 + 0.0019568084397581257*lm + 
            0.0007692592882891046*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.01834540367075104 - 0.015694025701212217*lm - 
          0.004112762192899702*lm^2) + CF^2*(0.0198120364575784 + 
          0.030035546725122052*lm + 0.020189923492416717*lm^2) + 
        CF*((0.0032299027607172394 + 0.0019017456531031166*lm + 
            0.0007477749441635822*lm^2)*NM + (0.004495693946294565 + 
            0.0019017456531031166*lm + 0.0007477749441635822*lm^2)*NL + 
          (-0.0007183277300422901 + 0.0019017456531031166*lm + 
            0.0007477749441635822*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.017822710651902888 - 0.015253462860468*lm - 
          0.0039981449115304565*lm^2) + CF^2*(0.019300940295894756 + 
          0.02918283079728405*lm + 0.019627256838422244*lm^2) + 
        CF*((0.003110182365313517 + 0.0018481663256813487*lm + 
            0.0007269354384600831*lm^2)*NM + (0.004365223160044631 + 
            0.0018481663256813487*lm + 0.0007269354384600831*lm^2)*NL + 
          (-0.0006984862234997362 + 0.0018481663256813487*lm + 
            0.0007269354384600831*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.017313501552036002 - 0.014825254256355253*lm - 
          0.0038869640424348214*lm^2) + CF^2*(0.018800207979911658 + 
          0.02835148559989803*lm + 0.019081459844680033*lm^2) + 
        CF*((0.002994625599474977 + 0.001796038020261492*lm + 
            0.0007067207349881493*lm^2)*NM + (0.004238520656741417 + 
            0.001796038020261492*lm + 0.0007067207349881493*lm^2)*NL + 
          (-0.0006791814172383215 + 0.001796038020261492*lm + 
            0.0007067207349881493*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.01681757094519785 - 0.014409085599018516*lm - 
          0.00377911268514382*lm^2) + CF^2*(0.018309832520671112 + 
          0.027541190101347895*lm + 0.01855200772706966*lm^2) + 
        CF*((0.0028831056964451294 + 0.0017453283305320694*lm + 
            0.0006871113972988763*lm^2)*NM + (0.004115492609920653 + 
            0.0017453283305320694*lm + 0.0006871113972988763*lm^2)*NL + 
          (-0.0006603997751467138 + 0.0017453283305320694*lm + 
            0.0006871113972988763*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.01633470277705533 - 0.01400464726335072*lm - 
          0.003674487162717524*lm^2) + CF^2*(0.017829789944421887 + 
          0.026751609325553653*lm + 0.018038391526067846*lm^2) + 
        CF*((0.0027754981121919787 + 0.0016960049523770675*lm + 
            0.0006680885750395498*lm^2)*NM + (0.003996045914856685 + 
            0.0016960049523770675*lm + 0.0006680885750395498*lm^2)*NL + 
          (-0.0006421280190059743 + 0.0016960049523770675*lm + 
            0.0006680885750395498*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.015864672275235633 - 0.01361163454265104*lm - 
          0.003572986945661165*lm^2) + CF^2*(0.017360041125763056 + 
          0.025982396466820875*lm + 0.01754011773324572*lm^2) + 
        CF*((0.0026716801346983216 + 0.0016480357476017374*lm + 
            0.0006496339901202118*lm^2)*NM + (0.003880088360720175 + 
            0.0016480357476017374*lm + 0.0006496339901202118*lm^2)*NL + 
          (-0.0006243531304946976 + 0.0016480357476017374*lm + 
            0.0006496339901202118*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.015407246219817665 - 0.01322974786337813*lm - 
          0.0034745145751900785*lm^2) + CF^2*(0.01690053058707842 + 
          0.02523319482114653*lm + 0.017056707914569477*lm^2) + 
        CF*((0.0025715336260331225 + 0.0016013888007355096*lm + 
            0.0006317299227618325*lm^2)*NM + (0.0037675287808398446 + 
            0.0016013888007355096*lm + 0.0006317299227618325*lm^2)*NL + 
          (-0.0006070623524611012 + 0.0016013888007355096*lm + 
            0.0006317299227618325*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.014962186813054902 - 0.012858692964609853*lm - 
          0.003378975586179707*lm^2) + CF^2*(0.016451192717149826 + 
          0.024503639547865445*lm + 0.016587698332154923*lm^2) + 
        CF*((0.002474939796097861 + 0.0015560324694907852*lm + 
            0.0006143591974872194*lm^2)*NM + (0.003658277183136188 + 
            0.0015560324694907852*lm + 0.0006143591974872194*lm^2)*NL + 
          (-0.0005902431895452647 + 0.0015560324694907852*lm + 
            0.0006143591974872194*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.01452925031562652 - 0.012498181045521785*lm - 
          0.003286278430094865*lm^2) + CF^2*(0.016011947720728663 + 
          0.02379335927453506*lm + 0.016132639565920245*lm^2) + 
        CF*((0.0023817847582913625 + 0.0015119354294117608*lm + 
            0.0005975051691081572*lm^2)*NM + (0.0035522448626139637 + 
            0.0015119354294117608*lm + 0.0005975051691081572*lm^2)*NL + 
          (-0.0005738834081847578 + 0.0015119354294117608*lm + 
            0.0005975051691081572*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.014108189638510366 - 0.012147928883921922*lm - 
          0.003196334398154966*lm^2) + CF^2*(0.015582705656661805 + 
          0.02310197755703557*lm + 0.015691096136397104*lm^2) + 
        CF*((0.0022919565284380394 + 0.0014690667132061424*lm + 
            0.0005811517087554483*lm^2)*NM + (0.003449344497634822 + 
            0.0014690667132061424*lm + 0.0005811517087554483*lm^2)*NL + 
          (-0.0005579710361015371 + 0.0014690667132061424*lm + 
            0.0005811517087554483*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.013698754867639376 - 0.01180765892862613*lm - 
          0.0031090575449583793*lm^2) + CF^2*(0.01516336650031362 + 
          0.022429114206003985*lm + 0.01526264612979568*lm^2) + 
        CF*((0.002205346003853013 + 0.001427395745214382*lm + 
            0.0005652831899924327*lm^2)*NM + (0.003349490231540174 + 
            0.001427395745214382*lm + 0.0005652831899924327*lm^2)*NL + 
          (-0.0005424943612870057 + 0.001427395745214382*lm + 
            0.0005652831899924327*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.01330069428593095 - 0.01147709936822621*lm - 
          0.0030243646127591757*lm^2) + CF^2*(0.014753821342697994 + 
          0.021774386489920895*lm + 0.014846880826272318*lm^2) + 
        CF*((0.0021218467829114272 + 0.0013868923714357*lm + 
            0.0005498844750471229*lm^2)*NM + (0.0032525977410561924 + 
            0.0013868923714357*lm + 0.0005498844750471229*lm^2)*NL + 
          (-0.0005274419305708003 + 0.0013868923714357*lm + 
            0.0005498844750471229*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.012913755164410434 - 0.011155984178588478*lm - 
          0.0029421749565627943*lm^2) + CF^2*(0.014353953254639475 + 
          0.021137410224423236*lm + 0.014443404332217354*lm^2) + 
        CF*((0.002041355219813671 + 0.0013475268854974238*lm + 
            0.0005349409011932353*lm^2)*NM + (0.0031585842927865167 + 
            0.0013475268854974238*lm + 0.0005349409011932353*lm^2)*NL + 
          (-0.0005128025477776052 + 0.0013475268854974238*lm + 
            0.0005349409011932353*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.012537684492338599 - 0.010844053151223946*lm - 
          0.0028624104701833555*lm^2) + CF^2*(0.013963638142144656 + 
          0.020517800756722673*lm + 0.014051833217263745*lm^2) + 
        CF*((0.0019637704257824623 + 0.001309270050923908*lm + 
            0.0005204382673060647*lm^2)*NM + (0.0030673687889827632 + 
            0.001309270050923908*lm + 0.0005204382673060647*lm^2)*NL + 
          (-0.000498565271558099 + 0.001309270050923908*lm + 
            0.0005204382673060647*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.012172229629953686 - 0.010541051904490154*lm - 
          0.002784995513384086*lm^2) + CF^2*(0.013582745547907863 + 
          0.01991517385336331*lm + 0.013671796156612783*lm^2) + 
        CF*((0.001888994264463351 + 0.0012720931200332973*lm + 
            0.0005063628206152883*lm^2)*NM + (0.002978871803677418 + 
            0.0012720931200332973*lm + 0.0005063628206152883*lm^2)*NL + 
          (-0.00048471941289907045 + 0.0012720931200332973*lm + 
            0.0005063628206152883*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.01181713889120231 - 0.010246731879418226*lm - 
          0.0027098568402033904*lm^2) + CF^2*(0.013211139402616173 + 
          0.01932914649895155*lm + 0.01330293357918028*lm^2) + 
        CF*((0.0018169313367491623 + 0.0012359678497645128*lm + 
            0.0004927012436733437*lm^2)*NM + (0.00289301561016723 + 
            0.0012359678497645128*lm + 0.0004927012436733437*lm^2)*NL + 
          (-0.0004712545323582695 + 0.0012359678497645128*lm + 
            0.0004927012436733437*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.011472162062019188 - 0.009960850321805688*lm - 
          0.0026369235285522716*lm^2) + CF^2*(0.012848678727186468 + 
          0.01875933761293213*lm + 0.01294489732198388*lm^2) + 
        CF*((0.0017474889595424884 + 0.0012008665147129054*lm + 
            0.0004794406415549585*lm^2)*NM + (0.00280972420074705 + 
            0.0012008665147129054*lm + 0.0004794406415549585*lm^2)*NL + 
          (-0.00045816043706727136 + 0.0012008665147129054*lm + 
            0.0004794406415549585*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.01113705085989773 - 0.00968317025207476*lm - 
          0.0025661269111537863*lm^2) + CF^2*(0.012495218288423118 + 
          0.018205368690964632*lm + 0.012597350291118588*lm^2) + 
        CF*((0.0016805771380877742 + 0.0011667619176308982*lm + 
            0.0004665685293006884*lm^2)*NM + (0.0027289232995134916 + 
            0.0011667619176308982*lm + 0.0004665685293006884*lm^2)*NL + 
          (-0.0004454271775087465 + 0.0011667619176308982*lm + 
            0.0004665685293006884*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.0108115593398086 - 0.009413460424266504*lm - 
          0.00249740050788193*lm^2) + CF^2*(0.012150609210111187 + 
          0.01766686437697185*lm + 0.012259966129602201*lm^2) + 
        CF*((0.001616108533271685 + 0.0011336273976294963*lm + 
            0.0004540728196148963*lm^2)*NM + (0.0026505403689841187 + 
            0.0011336273976294963*lm + 0.0004540728196148963*lm^2)*NL + 
          (-0.00043304504412325085 + 0.0011336273976294963*lm + 
            0.0004540728196148963*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.010495444251230016 - 0.009151495275422248*lm - 
          0.0024306799595455154*lm^2) + CF^2*(0.011814699541783557 + 
          0.01714345297148238*lm + 0.01193242889231435*lm^2) + 
        CF*((0.0015539984240267556 + 0.001101436836297645*lm + 
            0.00044194181082645736*lm^2)*NM + (0.0025745046112105653 + 
            0.001101436836297645*lm + 0.00044194181082645736*lm^2)*NL + 
          (-0.00042100456375758396 + 0.001101436836297645*lm + 
            0.00044194181082645736*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.010188465350563947 - 0.00889705486649434*lm - 
          0.002365902963152143*lm^2) + CF^2*(0.011487334787153664 + 
          0.01663476688147292*lm + 0.01161443272820143*lm^2) + 
        CF*((0.0014941646660567214 + 0.0010701646619389706*lm + 
            0.0004301641751185715*lm^2)*NM + (0.0025007469640024485 + 
            0.0010701646619389706*lm + 0.0004301641751185715*lm^2)*NL + 
          (-0.0004092964959363665 + 0.0010701646619389706*lm + 
            0.0004301641751185715*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.00989038567293713 - 0.008649924815827839*lm - 
          0.002303009208678097*lm^2) + CF^2*(0.01116835839431686 + 
          0.01614044301652833*lm + 0.011305681569874293*lm^2) + 
        CF*((0.0014365276471436225 + 0.0010397858521093036*lm + 
            0.0004187289470323813*lm^2)*NM + (0.002429200092822729 + 
            0.0010397858521093036*lm + 0.0004187289470323813*lm^2)*NL + 
          (-0.0003979118290997906 + 0.0010397858521093036*lm + 
            0.0004187289470323813*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.00960097176704728 - 0.008409896226162469*lm - 
          0.002241940317361824*lm^2) + CF^2*(0.010857612209744648 + 
          0.01566012313577772*lm + 0.011005888830685318*lm^2) + 
        CF*((0.0013810102395454096 + 0.0010102759346234979*lm + 
            0.0004076255122476043*lm^2)*NM + (0.0023597983788637856 + 
            0.0010102759346234979*lm + 0.0004076255122476043*lm^2)*NL + 
          (-0.0003868417766437014 + 0.0010102759346234979*lm + 
            0.0004076255122476043*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.009319993896310249 - 0.008176765606019263*lm - 
          0.0021826397815314477*lm^2) + CF^2*(0.010554936897827445 + 
          0.015193454149730992*lm + 0.010714777109336198*lm^2) + 
        CF*((0.0013275377508716517 + 0.000981610987186308*lm + 
            0.0003968435966420814*lm^2)*NM + (0.0022924779037665132 + 
            0.000981610987186308*lm + 0.0003968435966420814*lm^2)*NL + 
          (-0.00037607777295853957 + 0.000981610987186308*lm + 
            0.0003968435966420814*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.009047226209624702 - 0.007950334786258497*lm - 
          0.0021250529059704316*lm^2) + CF^2*(0.010260172328331535 + 
          0.014740088380830086*lm + 0.010432077902036666*lm^2) + 
        CF*((0.0012760378711931457 + 0.000953767635789379*lm + 
            0.0003863732556309876*lm^2)*NM + (0.0022271764314018773 + 
            0.000953767635789379*lm + 0.0003863732556309876*lm^2)*NL + 
          (-0.00036561146937359707 + 0.000953767635789379*lm + 
            0.0003863732556309876*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.008782446884222368 - 0.007730410832523946*lm - 
          0.002069126750819954*lm^2) + CF^2*(0.009973157932880254 + 
          0.014299683786241548*lm + 0.010157531322207047*lm^2) + 
        CF*((0.0012264406214459592 + 0.000926723052004695*lm + 
            0.00037620486378544616*lm^2)*NM + (0.002163833387095152 + 
            0.000926723052004695*lm + 0.00037620486378544616*lm^2)*NL + 
          (-0.0003554347300615433 + 0.000926723052004695*lm + 
            0.00037620486378544616*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.008525438243523743 - 0.0075168059542227855*lm - 
          0.002014810076011709*lm^2) + CF^2*(0.009693733032871547 + 
          0.013871904146149921*lm + 0.009890885827693846*lm^2) + 
        CF*((0.0011786782981996263 + 0.0009004549492939952*lm + 
            0.0003663291047294017*lm^2)*NM + (0.002102389834637292 + 
            0.0009004549492939952*lm + 0.0003663291047294017*lm^2)*NL + 
          (-0.0003455396278170254 + 0.0009004549492939952*lm + 
            0.0003663291047294017*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.008275986852181724 - 0.0073093374106302286*lm - 
          0.001962053287220627*lm^2) + CF^2*(0.009421737140129368 + 
          0.013456419220563872*lm + 0.009631897955446715*lm^2) + 
        CF*((0.001132685419056248 + 0.0008749415784436981*lm + 
            0.0003567369613128413*lm^2)*NM + (0.0020427884513951862 + 
            0.0008749415784436981*lm + 0.0003567369613128413*lm^2)*NL + 
          (-0.00033591844007711157 + 0.0008749415784436981*lm + 
            0.0003567369613128413*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.008033883590591739 - 0.0071078274146525846*lm - 
          0.0019108083833233357*lm^2) + CF^2*(0.009157010232103382 + 
          0.013052904877417042*lm + 0.009380332063587285*lm^2) + 
        CF*((0.0010883986667055373 + 0.0008501617222256485*lm + 
            0.00034741970605878833*lm^2)*NM + (0.0019849735018026963 + 
            0.0008501617222256485*lm + 0.00034741970605878833*lm^2)*NL + 
          (-0.00032656364454311504 + 0.0008501617222256485*lm + 
            0.00034741970605878833*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.00779892371078524 - 0.006912103034731722*lm - 
          0.001861028905345044*lm^2) + CF^2*(0.008899393003001502 + 
          0.012661043194532618*lm + 0.009135960080784761*lm^2) + 
        CF*((0.0010457568340775456 + 0.0008260946893755095*lm + 
            0.00033836889188091707*lm^2)*NM + (0.0019288908094871322 + 
            0.0008260946893755095*lm + 0.00033836889188091707*lm^2)*NL + 
          (-0.0003174679151137413 + 0.0008260946893755095*lm + 
            0.00033836889188091707*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.007570906875648591 - 0.00672199609532733*lm - 
          0.0018126698868748132*lm^2) + CF^2*(0.008648727092554789 + 
          0.012280522537822872*lm + 0.008898561262839992*lm^2) + 
        CF*((0.0010047007663946457 + 0.000802720307972781*lm + 
            0.0003295763430681479*lm^2)*NM + (0.0018744877282609387 + 
            0.000802720307972781*lm + 0.0003295763430681479*lm^2)*NL + 
          (-0.0003086241176772536 + 0.000802720307972781*lm + 
            0.0003295763430681479*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.007349637183006417 - 0.006537343076370714*lm - 
          0.0017656878059268794*lm^2) + CF^2*(0.008404855293547078 + 
          0.011911037617911813*lm + 0.008667921956368316*lm^2) + 
        CF*((0.0009651733072657108 + 0.0007800189182991989*lm + 
            0.0003210341465321599*lm^2)*NM + (0.0018217131121856737 + 
            0.0007800189182991989*lm + 0.0003210341465321599*lm^2)*NL + 
          (-0.0003000253059495249 + 0.0007800189182991989*lm + 
            0.0003210341465321599*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.00713492317625604 - 0.006357985012044684*lm - 
          0.0017200405382237504*lm^2) + CF^2*(0.008167621739752213 + 
          0.011552289527199135*lm + 0.008443835369462048*lm^2) + 
        CF*((0.0009271192420736224 + 0.0007579713652456036*lm + 
            0.00031273464331340917*lm^2)*NM + (0.0017705172848946453 + 
            0.0007579713652456036*lm + 0.00031273464331340917*lm^2)*NL + 
          (-0.0002916647173021333 + 0.0007579713652456036*lm + 
            0.00031273464331340917*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.006926577842836483 - 0.0061837673892083415*lm - 
          0.0016756873118751793*lm^2) + CF^2*(0.00793687207530955 + 
          0.011203985759226294*lm + 0.008226101349205426*lm^2) + 
        CF*((0.0008904852428780621 + 0.0007365589903312272*lm + 
            0.0003046704203409417*lm^2)*NM + (0.001720852008341694 + 
            0.0007365589903312272*lm + 0.0003046704203409417*lm^2)*NL + 
          (-0.00028353576881352295 + 0.0007365589903312272*lm + 
            0.0003046704203409417*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.006724418601911929 - 0.006014540045752635*lm - 
          0.0016325886634257763*lm^2) + CF^2*(0.007712453606936087 + 
          0.010865840212059639*lm + 0.008014526165908357*lm^2) + 
        CF*((0.0008552198138759507 + 0.0007157636233936878*lm + 
            0.00029683430244105023*lm^2)*NM + (0.0016726704511263839 + 
            0.0007157636233936878*lm + 0.00029683430244105023*lm^2)*NL + 
          (-0.0002756320528409576 + 0.0007157636233936878*lm + 
            0.00029683430244105023*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.006528267282368482 - 0.005850157069142601*lm - 
          0.0015907063952429461*lm^2) + CF^2*(0.007494215439969112 + 
          0.010537573177270335*lm + 0.007808922303919918*lm^2) + 
        CF*((0.0008212732373748553 + 0.0006955675740027663*lm + 
            0.0002892193445896266*lm^2)*NM + (0.0016259271565301743 + 
            0.0006955675740027663*lm + 0.0002892193445896266*lm^2)*NL + 
          (-0.0002679473333364799 + 0.0006955675740027663*lm + 
            0.0002892193445896266*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.006337950092285461 - 0.005690476695374652*lm - 
          0.0015500035342159795*lm^2) + CF^2*(0.007282008599499704 + 
          0.010218911315965647*lm + 0.0076091082588784454*lm^2) + 
        CF*((0.0007885975204101613 + 0.0006759536226462389*lm + 
            0.0002818188244029054*lm^2)*NM + (0.0015805780103838468 + 
            0.0006759536226462389*lm + 0.0002818188244029054*lm^2)*NL + 
          (-0.00026047554159801034 + 0.0006759536226462389*lm + 
            0.0002818188244029054*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.006153297580784099 - 0.005535361208552148*lm - 
          0.0015104442917364764*lm^2) + CF^2*(0.007075686137468404 + 
          0.009909587623210156*lm + 0.007414908341251794*lm^2) + 
        CF*((0.0007571463423931103 + 0.0006569050117316191*lm + 
            0.0002746262348611775*lm^2)*NM + (0.0015365802088734394 + 
            0.0006569050117316191*lm + 0.0002746262348611775*lm^2)*NL + 
          (-0.0002532107724697506 + 0.0006569050117316191*lm + 
            0.0002746262348611775*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.00597414459320514 - 0.005384676841259523*lm - 
          0.001471994024929805*lm^2) + CF^2*(0.006875103226806195 + 
          0.009609341382068067*lm + 0.007226152486019043*lm^2) + 
        CF*((0.000726875003636411 + 0.0006384054364435947*lm + 
            0.00026763527725996456*lm^2)*NM + (0.0014938922263800893 + 
            0.0006384054364435947*lm + 0.00026763527725996456*lm^2)*NL + 
          (-0.0002461472803677861 + 0.0006384054364435947*lm + 
            0.00026763527725996456*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.005800623239476507 - 0.00523838335297651*lm - 
          0.0014346268310117928*lm^2) + CF*(0.006680280759002342 + 
          0.009318271110568078*lm + 0.007042713534057892*lm^2) + 
        0.0006977933063373325*NM + 0.0006204535743566366*lm*NM + 
        0.0002608412420021442*lm^2*NM + 0.001452518909768883*NL + 
        0.0006204535743566366*lm*NL + 0.0002608412420021442*lm^2*NL - 
        0.00023928127035664515*NH + 0.0006204535743566366*lm*NH + 
        0.0002608412420021442*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.005631945335660141 - 0.005096161333082816*lm - 
          0.0013982937831179322*lm^2) + CF*(0.006490726888839841 + 
          0.00903536801486853*lm + 0.006864351298942576*lm^2) + 
        0.0006697455150574468*NM + 0.000603002672731569*lm*NM + 
        0.00025423523329416947*lm^2*NM + 0.0014123239216765368*NL + 
        0.000603002672731569*lm*NL + 0.00025423523329416947*lm^2*NL - 
        0.00023260343808084797*NH + 0.000603002672731569*lm*NH + 
        0.00025423523329416947*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.005468303448042366 - 0.004957993890450796*lm - 
          0.0013629724673903804*lm^2) + CF*(0.006306495038050245 + 
          0.008760805359726256*lm + 0.006690955749007322*lm^2) + 
        0.0006427539181720124*NM + 0.0005860548471321228*lm*NM + 
        0.00024781317588916006*lm^2*NM + 0.001373322566704023*NL + 
        0.0005860548471321228*lm*NL + 0.00024781317588916006*lm^2*NL - 
        0.0002261106056692431*NH + 0.0005860548471321228*lm*NH + 
        0.00024781317588916006*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.005309548109908948 - 0.0048237617889634364*lm - 
          0.0013286324343390105*lm^2) + CF*(0.0061274491175657584 + 
          0.008494345834325864*lm + 0.00652237740493696*lm^2) + 
        0.0006167796289518598*NM + 0.0005695954644273*lm*NM + 
        0.00024156953351618372*lm^2*NM + 0.0013354779669589507*NL + 
        0.0005695954644273*lm*NL + 0.00024156953351618372*lm^2*NL - 
        0.00021979762219435258*NH + 0.0005695954644273*lm*NH + 
        0.00024156953351618372*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.0051555339779828105 - 0.004693349297981724*lm - 
          0.001295244207570652*lm^2) + CF*(0.005953455522408755 + 
          0.008235758214305229*lm + 0.006358471564437746*lm^2) + 
        0.0005917851623673379*NM + 0.0005536103036662784*lm*NM + 
        0.00023549894683102762*lm^2*NM + 0.0012987543847521946*NL + 
        0.0005536103036662784*lm*NL + 0.00023549894683102762*lm^2*NL - 
        0.00021365947835149654*NH + 0.0005536103036662784*lm*NH + 
        0.00023549894683102762*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.005006119746578733 - 0.004566644095441355*lm - 
          0.0012627792514268619*lm^2) + CF*(0.005784383159073953 + 
          0.007984817255940623*lm + 0.006199098143368231*lm^2) + 
        0.000567734386830595*NM + 0.0005380855459484106*lm*NM + 
        0.00022959622753215668*lm^2*NM + 0.001263117189613105*NL + 
        0.0005380855459484106*lm*NL + 0.00022959622753215668*lm^2*NL - 
        0.00020769130281166317*NH + 0.0005380855459484106*lm*NH + 
        0.00022959622753215668*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.004861168061347024 - 0.004443537173082742*lm - 
          0.0012312099397142886*lm^2) + CF*(0.00562010346602144 + 
          0.007741303588316426*lm + 0.006044121522233781*lm^2) + 
        0.0005445924774271727*NM + 0.0005230077644282665*lm*NM + 
        0.00022385635267532523*lm^2*NM + 0.0012285328260520623*NL + 
        0.0005230077644282665*lm*NL + 0.00022385635267532523*lm^2*NL - 
        0.00020188835864952458*NH + 0.0005230077644282665*lm*NH + 
        0.00022385635267532523*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.004720545432818241 - 0.00432392274380717*lm - 
          0.001200509525491373*lm^2) + CF*(0.0054604904278232076 + 
          0.007505003603858597*lm + 0.00589341039786674*lm^2) + 
        0.0005223258706028465*NM + 0.0005083639144628042*lm*NM + 
        0.00021827445918024964*lm^2*NM + 0.001194968782069012*NL + 
        0.0005083639144628042*lm*NL + 0.00021827445918024964*lm^2*NL - 
        0.00019624603984632453*NH + 0.0005083639144628042*lm*NH + 
        0.00021827445918024964*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.004584122149942992 - 0.004207698151148648*lm - 
          0.0011706521118762592*lm^2) + CF*(0.0053054205834725966 + 
          0.007275709347582067*lm + 0.005746837640119818*lm^2) + 
        0.0005009022202716165*NM + 0.0004941413239069008*lm*NM + 
        0.00021284583852295623*lm^2*NM + 0.0011623935584052615*NL + 
        0.0004941413239069008*lm*NL + 0.00021284583852295623*lm^2*NL - 
        0.00019075986786726499*NH + 0.0004941413239069008*lm*NH + 
        0.00021284583852295623*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.0044517721938039795 - 0.004094763780847996*lm - 
          0.0011416126238418954*lm^2) + CF*(0.005154773029334439 + 
          0.0070532184053749445*lm + 0.005604280153405668*lm^2) + 
        0.0004802903553107898*NM + 0.00048032768356266807*lm*NM + 
        0.00020756593160761733*lm^2*NM + 0.00113077663853458*NL + 
        0.00048032768356266807*lm*NL + 0.00020756593160761733*lm^2*NL - 
        0.0001854254883129296*NH + 0.00048032768356266807*lm*NH + 
        0.00020756593160761733*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.004323373151661559 - 0.003985022974513007*lm - 
          0.0011133667809653624*lm^2) + CF*(0.005008429417183847 + 
          0.006837333791616779*lm + 0.00546561874292087*lm^2) + 
        0.0004604602384091985*NM + 0.00046691103778723984*lm*NM + 
        0.00020243032381188407*lm^2*NM + 0.00110008845938852*NL + 
        0.00046691103778723984*lm*NL + 0.00020243032381188407*lm^2*NL - 
        0.00018023866764419797*NH + 0.00046691103778723984*lm*NH + 
        0.00020243032381188407*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.004198806131479326 - 0.0038783819453460005*lm - 
          0.0010858910710995174*lm^2) + CF*(0.004866273947753323 + 
          0.0066278638364040635*lm + 0.005330737985397631*lm^2) + 
        0.00044138292623475706*NM + 0.00045387977526302085*lm*NM + 
        0.00019743474019991226*lm^2*NM + 0.0010703003828098486*NL + 
        0.00045387977526302085*lm*NL + 0.00019743474019991226*lm^2*NL - 
        0.00017519528998003012*NH + 0.00045387977526302085*lm*NH + 
        0.00019743474019991226*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.004077955677062352 - 0.0037747496959178537*lm - 
          0.0010591627249360443*lm^2) + CF*(0.004728193360181116 + 
          0.006424622072633519*lm + 0.00519952610423149*lm^2) + 
        0.00042303053088777235*NM + 0.00044122261993374823*lm*NM + 
        0.0001925750408974626*lm^2*NM + 0.0010413846677270586*NL + 
        0.00044122261993374823*lm*NL + 0.0001925750408974626*lm^2*NL - 
        0.00017029135396743128*NH + 0.00044122261993374823*lm*NH + 
        0.0001925750408974626*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.003960709683927779 - 0.003674037937965578*lm - 
          0.001033159691429989*lm^2) + CF*(0.004594076917728507 + 
          0.006227427123172548*lm + 0.005071874848838129*lm^2) + 
        0.0004053761826066826*NM + 0.0004289286221091159*lm*NM + 
        0.0001878472166236344*lm^2*NM + 0.0010133144430420817*NL + 
        0.0004289286221091159*lm*NL + 0.0001878472166236344*lm^2*NL - 
        0.0001655229697228456*NH + 0.0004289286221091159*lm*NH + 
        0.0001878472166236344*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.003846959316015377 - 0.00357616101418865*lm - 
          0.0010078606140568108*lm^2) + CF*(0.004463816390109784 + 
          0.006036102588326352*lm + 0.004947679378097072*lm^2) + 
        0.0003883939936932052*NM + 0.0004169871497401619*lm*NM + 
        0.00018324738437396561*lm^2*NM + 0.0009860636812225895*NL + 
        0.0004169871497401619*lm*NL + 0.00018324738437396561*lm^2*NL - 
        0.00016088635584416946*NH + 0.0004169871497401619*lm*NH + 
        0.00018324738437396561*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.0037365989233344343 - 0.003481035822017703*lm - 
          0.0009832448078739065*lm^2) + CF*(0.004337306032756145 + 
          0.005850476933792587*lm + 0.004826838147744632*lm^2) + 
        0.0003720590236242176*NM + 0.00040538787986710815*lm*NM + 
        0.00017877178324980119*lm^2*NM + 0.0009596071725895816*NL + 
        0.00040538787986710815*lm*NL + 0.00017877178324980119*lm^2*NL - 
        0.00015637783649252634*NH + 0.00040538787986710815*lm*NH + 
        0.00017877178324980119*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.0036295259606328404 - 0.00338858173932773*lm - 
          0.0009592922373594707*lm^2) + CF*(0.004214442563313424 + 
          0.005670383379277054*lm + 0.004709252801582856*lm^2) + 
        0.0003563472453180773*NM + 0.00039412079024086675*lm*NM + 
        0.00017441677042899468*lm^2*NM + 0.0009339205002903785*NL + 
        0.00039412079024086675*lm*NL + 0.00017441677042899468*lm^2*NL - 
        0.00015199383854289808*NH + 0.00039412079024086675*lm*NH + 
        0.00017441677042899468*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.0035256409071644673 - 0.0032987205520666574*lm - 
          0.0009359834950024258*lm^2) + CF*(0.004095125135653452 + 
          0.005495659787927601*lm + 0.004594828066375544*lm^2) + 
        0.00034123551252350097*NM + 0.0003831761511189962*lm*NM + 
        0.00017017881727316833*lm^2*NM + 0.0009089800159466004*NL + 
        0.0003831761511189962*lm*NL + 0.00017017881727316833*lm^2*NL - 
        0.00014773088880266772*NH + 0.0003831761511189962*lm*NH + 
        0.00017017881727316833*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.0034248471876218807 - 0.003211376383769046*lm - 
          0.0009132997806180061*lm^2) + CF*(0.003979255311659893 + 
          0.005326148556728191*lm + 0.004483471650306575*lm^2) + 
        0.00032670152829956505*NM + 0.0003725445172364863*lm*NM + 
        0.0001660545055669102*lm^2*NM + 0.0008847628159662585*NL + 
        0.0003725445172364863*lm*NL + 0.0001660545055669102*lm^2*NL - 
        0.00014358561129709387*NH + 0.0003725445172364863*lm*NH + 
        0.0001660545055669102*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.0033270510942929763 - 0.003126475626923687*lm - 
          0.0008912228813644088*lm^2) + CF*(0.0038667370310315062 + 
          0.005161696507980934*lm + 0.004375094144879825*lm^2) + 
        0.0003127238145558604*NM + 0.0003622167199513858*lm*NM + 
        0.00016204052388443793*lm^2*NM + 0.0008612467185086837*NL + 
        0.0003622167199513858*lm*NL + 0.00016204052388443793*lm^2*NL - 
        0.00013955472462070362*NH + 0.0003622167199513858*lm*NH + 
        0.00016204052388443793*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.0032321617104923302 - 0.0030439468761630363*lm - 
          0.0008697351524367203*lm^2) + CF*(0.003757476579328915 + 
          0.005002154781990573*lm + 0.0042696089301439*lm^2) + 
        0.00029928168262232535*NM + 0.0003521838595649473*lm*NM + 
        0.0001581336640794037*lm^2*NM + 0.0008384102410906718*NL + 
        0.0003521838595649473*lm*NL + 0.0001581336640794037*lm^2*NL - 
        0.00013563503935356568*NH + 0.0003521838595649473*lm*NH + 
        0.0001581336640794037*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.0031400908353108096 - 0.002963720863241721*lm - 
          0.000848819498415111*lm^2) + CF*(0.0036513825544751063 + 
          0.004847378731053586*lm + 0.004166932083128726*lm^2) + 
        0.0002863552048187956*NM + 0.00034243729781565914*lm*NM + 
        0.00015433081789365652*lm^2*NM + 0.0008162325788219402*NL + 
        0.00034243729781565914*lm*NL + 0.00015433081789365652*lm^2*NL - 
        0.0001318234555413805*NH + 0.00034243729781565914*lm*NH + 
        0.00015433081789365652*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.0030507529097202877 - 0.002885730393770773*lm - 
          0.000828459355245036*lm^2) + CF*(0.0035483658319048995 + 
          0.004697227814842597*lm + 0.004066982289384722*lm^2) + 
        0.00027392518699483916*NM + 0.0003329686505462479*lm*NM + 
        0.00015062897368091563*lm^2*NM + 0.0007946935832577433*NL + 
        0.0003329686505462479*lm*NL + 0.00015062897368091563*lm^2*NL - 
        0.0001281169602383049*NH + 0.0003329686505462479*lm*NH + 
        0.00015062897368091563*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.0029640649440641283 - 0.0028099102856737556*lm - 
          0.0008086386728279235*lm^2) + CF*(0.003448339528544573 + 
          0.004551565497266054*lm + 0.003969680757518897*lm^2) + 
        0.00026197314201099*NM + 0.00032376978054248564*lm*NM + 
        0.00014702521324144063*lm^2*NM + 0.000773773741856302*NL + 
        0.00032376978054248564*lm*NL + 0.00014702521324144063*lm^2*NL - 
        0.0001245126251114124*NH + 0.00032376978054248564*lm*NH + 
        0.00014702521324144063*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.0028799464469583874 - 0.0027361973093306*lm - 
          0.0007893418982015295*lm^2) + CF*(0.0033512189657895802 + 
          0.00441025914487323*lm + 0.0038749511366256905*lm^2) + 
        0.0002504812641330557*NM + 0.00031483279054239974*lm*NM + 
        0.00014351670876391445*lm^2*NM + 0.0007534541580285487*NL + 
        0.00031483279054239974*lm*NL + 0.00014351670876391445*lm^2*NL - 
        0.00012100760410567697*NH + 0.00031483279054239974*lm*NH + 
        0.00014351670876391445*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.002798319355623433 - 0.002664530129374673*lm - 
          0.0007705539592898378*lm^2) + CF*(0.003256921631635841 + 
          0.004273179926865373*lm + 0.003782719436513749*lm^2) + 
        0.00023943240431173978*NM + 0.00030615001641427563*lm*NM + 
        0.00014010071987087958*lm^2*NM + 0.0007337165317675711*NL + 
        0.00030615001641427563*lm*NL + 0.00014010071987087958*lm^2*NL - 
        0.00011759913116835676*NH + 0.00030615001641427563*lm*NH + 
        0.00014010071987087958*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.002719107967660846 - 0.0025948492481084316*lm - 
          0.0007522602492030426*lm^2) + CF*(0.0031653671421084037 + 
          0.004140202716765293*lm + 0.003692913950633118*lm^2) + 
        0.00022881004632040332*NM + 0.0002977140205016554*lm*NM + 
        0.00013677459076418956*lm^2*NM + 0.0007145431408450664*NL + 
        0.0002977140205016554*lm*NL + 0.00013677459076418956*lm^2*NL - 
        0.00011428451803164803*NH + 0.0002977140205016554*lm*NH + 
        0.00013677459076418956*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.0026422388742860267 - 0.002527096950502893*lm - 
          0.0007344466110688053*lm^2) + CF*(0.003076477202120273 + 
          0.0040112059957897565*lm + 0.0036054651816104987*lm^2) + 
        0.00021859828372437063*NM + 0.0002895175851333644*lm*NM + 
        0.0001335357474670555*lm^2*NM + 0.0006959168225620625*NL + 
        0.0002895175851333644*lm*NL + 0.0001335357474670555*lm^2*NL - 
        0.0001110611520524728*NH + 0.0002895175851333644*lm*NH + 
        0.0001335357474670555*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.0025676408950228782 - 0.002461217250746142*lm - 
          0.0007170993233765986*lm^2) + CF*(0.0029901755658838978 + 
          0.003886071757961757*lm + 0.0035203057693033025*lm^2) + 
        0.00020878179765577846*NM + 0.0002815537062964493*lm*NM + 
        0.00013038169515938158*lm^2*NM + 0.0006778209560411556*NL + 
        0.0002815537062964493*lm*NL + 0.00013038169515938158*lm^2*NL - 
        0.00010792649410826175*NH + 0.0002815537062964493*lm*NH + 
        0.00013038169515938158*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.0024952450138632162 - 0.0023971558403061287*lm - 
          0.0007002050858175649*lm^2) + CF*(0.0029063879969881265 + 
          0.0037646854169929612*lm + 0.0034373704212862276*lm^2) + 
        0.00019934583536856092*NM + 0.000273815587469777*lm*NM + 
        0.00012731001560319362*lm^2*NM + 0.0006602394450475223*NL + 
        0.000273815587469777*lm*NL + 0.00012731001560319362*lm^2*NL - 
        0.0001048780765475926*NH + 0.000273815587469777*lm*NH + 
        0.00012731001560319362*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.002424984316890167 - 0.0023348600374731017*lm - 
          0.0006837510056028996*lm^2) + CF*(0.0028250422282443707 + 
          0.0036469357149604307*lm + 0.003356595845686962*lm^2) + 
        0.0001902761895487581*NM + 0.00026629663361592596*lm*NM + 
        0.00012431836465507266*lm^2*NM + 0.0006431567013260035*NL + 
        0.00026629663361592596*lm*NL + 0.00012431836465507266*lm^2*NL - 
        0.0001019135011945458*NH + 0.00026629663361592596*lm*NH + 
        0.00012431836465507266*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.002356793931361744 - 0.0022742787383472096*lm - 
          0.0006677245842443463*lm^2) + CF*(0.002746067921397223 + 
          0.003532714632795964*lm + 0.0032779206862904274*lm^2) + 
        0.00018155917835593476*NM + 0.0002589904453289001*lm*NM + 
        0.00012140446986260842*lm^2*NM + 0.0006265576284416179*NL + 
        0.0002589904453289001*lm*NL + 0.00012140446986260842*lm^2*NL - 
        0.00009903043740564181*NH + 0.0002589904453289001*lm*NH + 
        0.00012140446986260842*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.0022906109662479846 - 0.002215362369237*lm - 
          0.0006521137047809391*lm^2) + CF*(0.0026693966267867936 + 
          0.0034219173026011507*lm + 0.003201285459833701*lm^2) + 
        0.00017318162617209042*NM + 0.000251890813135105*lm*NM + 
        0.00011856612814198893*lm^2*NM + 0.000610427606110947*NL + 
        0.000251890813135105*lm*NL + 0.00011856612814198893*lm^2*NL - 
        0.00009622662017822968*NH + 0.000251890813135105*lm*NH + 
        0.00011856612814198893*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.0022263744542125163 - 0.0021580628404348065*lm - 
          0.0006369066194366661*lm^2) + CF*(0.002594961743042611 + 
          0.00331444192179641*lm + 0.003126632495416361*lm^2) + 
        0.0001651308450350385*NM + 0.00024499171194495114*lm*NM + 
        0.00011580120353393931*lm^2*NM + 0.0005947524750119361*NL + 
        0.00024499171194495114*lm*NL + 0.00011580120353393931*lm^2*NL - 
        0.00009349984830920205*NH + 0.00024499171194495114*lm*NH + 
        0.00011580120353393931*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.002164025295027122 - 0.0021023335013353383*lm - 
          0.0006220919376942462*lm^2) + CF*(0.002522698476881929 + 
          0.0032101896691078386*lm + 0.0030539058759535727*lm^2) + 
        0.00015739461673382204*NM + 0.0002382872956523847*lm*NM + 
        0.0001131076250353175*lm^2*NM + 0.0005795185220597707*NL + 
        0.0002382872956523847*lm*NL + 0.0001131076250353175*lm^2*NL - 
        0.00009084798260292018*NH + 0.0002382872956523847*lm*NH + 
        0.0001131076250353175*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.0021035062004058484 - 0.002048129096864122*lm - 
          0.0006076586147707123*lm^2) + CF*(0.0024525438030788015 + 
          0.0031090646223916794*lm + 0.0029830513816016787*lm^2) + 
        0.00014996117554432305*NM + 0.00023177189187959283*lm*NM + 
        0.00011048338450376587*lm^2*NM + 0.0005647124661366297*NL + 
        0.00023177189187959283*lm*NL + 0.00011048338450376587*lm^2*NL - 
        0.00008826894412724073*NH + 0.00023177189187959283*lm*NH + 
        0.00011048338450376587*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.002044761640243347 - 0.0019954057251828188*lm - 
          0.0005935959404809819*lm^2) + CF*(0.002384436424664178 + 
          0.003010973678292531*lm + 0.0029140164350884568*lm^2) + 
        0.000142819191583805*NM + 0.0002254399968640869*lm*NM + 
        0.0001079265346329058*lm^2*NM + 0.0005503214442632577*NL + 
        0.0002254399968640869*lm*NL + 0.0001079265346329058*lm^2*NL - 
        0.00008576071251654681*NH + 0.0002254399968640869*lm*NH + 
        0.0001079265346329058*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.001987737790240532 - 0.001944120796638883*lm - 
          0.0005798935284760667*lm^2) + CF*(0.0023183167334116174 + 
          0.0029158264737280683*lm + 0.002846750048882509*lm^2) + 
        0.0001359577547637055*NM + 0.0002192862704853352*lm*NM + 
        0.00010543518699564848*lm^2*NM + 0.0005363329982004676*NL + 
        0.0002192862704853352*lm*NL + 0.00010543518699564848*lm^2*NL - 
        0.00008332132432069637*NH + 0.0002192862704853352*lm*NH + 
        0.00010543518699564848*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0019323824808991689 - 0.001894232993927435*lm - 
          0.0005665413058430261*lm^2) + CF*(0.002254126770657904 + 
          0.0028235353091900107*lm + 0.002781202774138492*lm^2) + 
        0.00012936635932056772*NM + 0.00021330553142808958*lm*NM + 
        0.00010300751015327748*lm^2*NM + 0.0005227350614688515*NL + 
        0.00021330553142808958*lm*NL + 0.00010300751015327748*lm^2*NL - 
        0.00008094887139881354*NH + 0.00021330553142808958*lm*NH + 
        0.00010300751015327748*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.0018786451478657532 - 0.0018457022334337158*lm - 
          0.0005535295030542141*lm^2) + CF*(0.0021918101885029296 + 
          0.0027340150738483387*lm + 0.002717326651357051*lm^2) + 
        0.0001230348889055633*NM + 0.00020749275247953513*lm*NM + 
        0.00010064172782803894*lm^2*NM + 0.0005095159467751627*NL + 
        0.00020749275247953513*lm*NL + 0.00010064172782803894*lm^2*NL - 
        0.00007864149935686145*NH + 0.00020749275247953513*lm*NH + 
        0.00010064172782803894*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.0018264767836039296 - 0.0017984896277249678*lm - 
          0.0005408486442537917*lm^2) + CF*(0.002131312211428608 + 
          0.00264718317244328*lm + 0.0026550751627004324*lm^2) + 
        0.00011695360221361647*NM + 0.0002018430559573812*lm*NM + 
        0.00009833611713705304*lm^2*NM + 0.0004966643338340227*NL + 
        0.0002018430559573812*lm*NL + 0.00009833611713705304*lm^2*NL - 
        0.00007639740602794833*NH + 0.0002018430559573812*lm*NH + 
        0.00009833611713705304*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.0017758298903737242 - 0.0017525574491610988*lm - 
          0.0005284895378698923*lm^2) + CF*(0.0020725795983723054 + 
          0.002562959453947368*lm + 0.0025944031859067443*lm^2) + 
        0.00011111311913368677*NM + 0.0001963517092660098*lm*NM + 
        0.00009608900688543498*lm^2*NM + 0.000484169257573802*NL + 
        0.0001963517092660098*lm*NL + 0.00009608900688543498*lm^2*NL - 
        0.00007421483999433372*NH + 0.0001963517092660098*lm*NH + 
        0.00009608900688543498*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.0017266584344950541 - 0.0017078690945940076*lm - 
          0.0005164432675412259*lm^2) + CF*(0.002015560605286317 + 
          0.0024812661419778936*lm + 0.0025352669497478364*lm^2) + 
        0.0001055044074023088*NM + 0.00019101412057780036*lm*NM + 
        0.00009389877591658653*lm^2*NM + 0.00047202009671573245*NL + 
        0.00019101412057780036*lm*NL + 0.00009389877591658653*lm^2*NL - 
        0.00007209209915011635*NH + 0.00019101412057780036*lm*NH + 
        0.00009389877591658653*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.0016789178018722722 - 0.0016643890511259967*lm - 
          0.0005047011833472927*lm^2) + CF*(0.001960204948211207 + 
          0.002402027766938317*lm + 0.0024776239909776185*lm^2) + 
        0.00010011876974301749*NM + 0.00018582583463675815*lm*NM + 
        0.00009176385151768958*lm^2*NM + 0.0004602065627155138*NL + 
        0.00018582583463675815*lm*NL + 0.00009176385151768958*lm^2*NL - 
        0.00007002752930360066*NH + 0.00018582583463675815*lm*NH + 
        0.00009176385151768958*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.0016325647547559264 - 0.0016220828628982385*lm - 
          0.0004932548933317523*lm^2) + CF*(0.001906463766887421 + 
          0.0023251710998656227*lm + 0.002421433112719511*lm^2) + 
        0.00009494783147480918*NM + 0.0001807825286815883*lm*NM + 
        0.0000896827078785004*lm^2*NM + 0.00044871868905689327*NL + 
        0.0001807825286815883*lm*NL + 0.0000896827078785004*lm^2*NL - 
        0.00006801952281835507*NH + 0.0001807825286815883*lm*NH + 
        0.0000896827078785004*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.0015875573897174374 - 0.0015809170988808317*lm - 
          0.000482096255308853*lm^2) + CF*(0.0018542895889264068 + 
          0.002250625087959259*lm + 0.0023666543442434603*lm^2) + 
        0.00008998352857330047*NM + 0.0001758800084853753*lm*NM + 
        0.00008765386460160964*lm^2*NM + 0.00043754682088691495*NL + 
        0.0001758800084853753*lm*NL + 0.00008765386460160964*lm^2*NL - 
        0.00006606651729199174*NH + 0.0001758800084853753*lm*NH + 
        0.00008765386460160964*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.001543855096812027 - 0.0015408593216365482*lm - 
          0.0004712173689431777*lm^2) + CF*(0.0018036362945595384 + 
          0.0021783207917660734*lm + 0.0023132489020846908*lm^2) + 
        0.00008521809616874844*NM + 0.0001711142045090503*lm*NM + 
        0.00008567588526239595*lm^2*NM + 0.00042668160498275323*NL + 
        0.0001711142045090503*lm*NL + 0.00008567588526239595*lm^2*NL - 
        0.00006416699427171362*NH + 0.0001711142045090503*lm*NH + 
        0.00008567588526239595*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.001501418519904939 - 0.0015018780570309452*lm - 
          0.00046061056809329606*lm^2) + CF*(0.0017544590819804134 + 
          0.0021081913239946524*lm + 0.002261179152457999*lm^2) + 
        0.0000806440574655877*NM + 0.0001664811681658554*lm*NM + 
        0.00008374737601696292*lm^2*NM + 0.00041611398004026917*NL + 
        0.0001664811681658554*lm*NL + 0.00008374737601696292*lm^2*NL - 
        0.00006231947800569247*NH + 0.0001664811681658554*lm*NH + 
        0.00008374737601696292*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.001460209518135804 - 0.0014639427648620955*lm - 
          0.0004502684134102428*lm^2) + CF*(0.0017067144332936037 + 
          0.0020401717899315615*lm + 0.0022104085749230103*lm^2) + 
        0.00007625421306862014*NM + 0.00016197706819404383*lm*NM + 
        0.00008186698425640779*lm^2*NM + 0.00040583516727465014*NL + 
        0.00016197706819404383*lm*NL + 0.00008186698425640779*lm^2*NL - 
        0.000060522534229357754*NH + 0.00016197706819404383*lm*NH + 
        0.00008186698425640779*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0014201911284958616 - 0.0014270238103837765*lm - 
          0.00044018368518205505*lm^2) + CF*(0.0016603600810806056 + 
          0.001974199229431249*lm + 0.0021609017272573613*lm^2) + 
        0.00007204163070146462*NM + 0.00015759818713508713*lm*NM + 
        0.0000800333973058282*lm^2*NM + 0.00039583666132371833*NL + 
        0.00015759818713508713*lm*NL + 0.0000800333973058282*lm^2*NL - 
        0.00005877476898569481*NH + 0.00015759818713508713*lm*NH + 
        0.0000800333973058282*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.001381327529492704 - 0.0013910924366965294*lm - 
          0.00043034937641590524*lm^2) + CF*(0.0016153549755916117 + 
          0.0019102125604507567*lm + 0.0021126242114962624*lm^2) + 
        0.00006799963530333304*NM + 0.00015334091791469672*lm*NM + 
        0.00007824534116652822*lm^2*NM + 0.0003861102214447162*NL + 
        0.00015334091791469672*lm*NL + 0.00007824534116652822*lm^2*NL - 
        0.0000570748274786671*NH + 0.00015334091791469672*lm*NH + 
        0.00007824534116652822*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.001343584005877211 - 0.0013561207379815935*lm - 
          0.0004207586861496624*lm^2) + CF*(0.00157165925256976 + 
          0.001848152524099863*lm + 0.002065542641098343*lm^2) + 
        0.00006412179949064868*NM + 0.00014920176052400422*lm*NM + 
        0.00007650157929993862*lm^2*NM + 0.00037664786299560285*NL + 
        0.00014920176052400422*lm*NL + 0.00007650157929993862*lm^2*NL - 
        0.0000554213929588958*NH + 0.00014920176052400422*lm*NH + 
        0.00007650157929993862*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0013069269144074089 - 0.0013220816335532942*lm - 
          0.00041140501298499697*lm^2) + CF*(0.001529234201712717 + 
          0.0017879616311769092*lm + 0.002019624609199076*lm^2) + 
        0.000060401934370460886*NM + 0.00014517731879828562*lm*NM + 
        0.00007480091145181763*lm^2*NM + 0.0003674418491921158*NL + 
        0.00014517731879828562*lm*NL + 0.00007480091145181763*lm^2*NL - 
        0.00005381318564074724*NH + 0.00014517731879828562*lm*NH + 
        0.00007480091145181763*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.001271323650624096 - 0.0012889488427060478*lm - 
          0.00040228194883442*lm^2) + CF*(0.0014880422357747903 + 
          0.0017295841101602446*lm + 0.0019748386579144252*lm^2) + 
        0.00005683408069303754*NM + 0.00014126429729065533*lm*NM + 
        0.00007314217251534909*lm^2*NM + 0.00035848468313207603*NL + 
        0.00014126429729065533*lm*NL + 0.00007314217251534909*lm^2*NL - 
        0.00005224896164999645*NH + 0.00014126429729065533*lm*NH + 
        0.00007314217251534909*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.001236742616613247 - 0.0012566968603327146*lm - 
          0.0003933832728749123*lm^2) + CF*(0.0014480468603112599 + 
          0.0016729658566250309*lm + 0.0019311542486586603*lm^2) + 
        0.000053412500331433845*NM + 0.00013745949823819982*lm*NM + 
        0.00007152423143180223*lm^2*NM + 0.00034976910007863303*NL + 
        0.00013745949823819982*lm*NL + 0.00007152423143180223*lm^2*NL - 
        0.00005072751200125271*NH + 0.00013745949823819982*lm*NH + 
        0.00007152423143180223*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.001203153189730402 - 0.00122530093329161*lm - 
          0.00038470294570105523*lm^2) + CF*(0.0014092126440652278 + 
          0.0016180543840550157*lm + 0.001888541733441544*lm^2) + 
        0.00005013166807624121*NM + 0.00013375981861806505*lm*NM + 
        0.00006994599012746459*lm^2*NM + 0.0003412880599943649*NL + 
        0.00013375981861806505*lm*NL + 0.00006994599012746459*lm^2*NL - 
        0.00004924766160435063*NH + 0.00013375981861806505*lm*NH + 
        0.00006994599012746459*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0011705256922624916 - 0.001194737037500045*lm - 
          0.0003762351036708219*lm^2) + CF*(0.0013715051899960246 + 
          0.0015647987760188423*lm + 0.0018469723271113078*lm^2) + 
        0.00004698626373411561*NM + 0.00013016224729105763*lm*NM + 
        0.00006840638248560399*lm^2*NM + 0.00033303474031836375*NL + 
        0.00013016224729105763*lm*NL + 0.00006840638248560399*lm^2*NL - 
        0.00004780826829892771*NH + 0.00013016224729105763*lm*NH + 
        0.00006840638248560399*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.0011388313620028217 - 0.001164981855732828*lm - 
          0.0003679740534374275*lm^2) + CF*(0.0013348911069470655 + 
          0.0015131496396804762*lm + 0.0018064180805110078*lm^2) + 
        0.000043971164519069*NM + 0.00012666386223036567*lm*NM + 
        0.00006690437335225954*lm^2*NM + 0.00032500252897865023*NL + 
        0.00012666386223036567*lm*NL + 0.00006690437335225954*lm^2*NL - 
        0.00004640822191642697*NH + 0.00012666386223036567*lm*NH + 
        0.00006690437335225954*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0011080423237152393 - 0.0011360127561047164*lm - 
          0.00035991426666086616*lm^2) + CF*(0.0012993379819500005 + 
          0.0014630590606134193*lm + 0.0017668518545169791*lm^2) + 
        0.00004108143772588146*NM + 0.00012326182783305381*lm*NM + 
        0.00006543895757470293*lm^2*NM + 0.0003171850176324703*NL + 
        0.00012326182783305381*lm*NL + 0.00006543895757470293*lm^2*NL - 
        0.00004504644336878011*NH + 0.00012326182783305381*lm*NH + 
        0.00006543895757470293*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0010781315614638363 - 0.0011078077712163477*lm - 
          0.00035205037489298674*lm^2) + CF*(0.0012648143531610674 + 
          0.0014144805588885115*lm + 0.0017282472949292076*lm^2) + 
        0.00003831233367535479*NM + 0.00011995339231203324*lm*NM + 
        0.00006400915907145214*lm^2*NM + 0.0003095759951272349*NL + 
        0.00011995339231203324*lm*NL + 0.00006400915907145214*lm^2*NL - 
        0.000043721883763044256*NH + 0.00011995339231203324*lm*NH + 
        0.00006400915907145214*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0010490728917848917 - 0.0010803455779437251*lm - 
          0.0003443771646301729*lm^2) + CF*(0.0012312896834246934 + 
          0.0013673690464053184*lm + 0.0016905788081844854*lm^2) + 
        0.00003565927892148162*NM + 0.0001167358851662571*lm*NM + 
        0.00006261402993275871*lm^2*NM + 0.0003021694411750672*NL + 
        0.0001167358851662571*lm*NL + 0.00006261402993275871*lm^2*NL - 
        0.00004243352354128207*NH + 0.0001167358851662571*lm*NH + 
        0.00006261402993275871*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0010208409376781281 - 0.0010536054778518594*lm - 
          0.0003368895725279011*lm^2) + CF*(0.0011987343344586358 + 
          0.0013216807854373332*lm + 0.0016538215378642418*lm^2) + 
        0.00003311786971094679*NM + 0.00011360671472693948*lm*NM + 
        0.00006125264955052748*lm^2*NM + 0.00029495952023412186*NL + 
        0.00011360671472693948*lm*NL + 0.00006125264955052748*lm^2*NL - 
        0.00004118037164499176*NH + 0.00011360671472693948*lm*NH + 
        0.00006125264955052748*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0009934111033947435 - 0.0010275673782136935*lm - 
          0.0003295826807716506*lm^2) + CF*(0.0011671195416542556 + 
          0.0012773733483614973*lm + 0.0016179513419699212*lm^2) + 
        0.00003068386568571038*NM + 0.00011056336577764497*lm*NM + 
        0.00005992412377666375*lm^2*NM + 0.00028794057559003715*NL + 
        0.00011056336577764497*lm*NL + 0.00005992412377666375*lm^2*NL - 
        0.00003996146470341026*NH + 0.00011056336577764497*lm*NH + 
        0.00005992412377666375*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.0009667595500000823 - 0.001002211773615947*lm - 
          0.00032245171259883326*lm^2) + CF*(0.00113641738948491 + 
          0.0012344055785428604*lm + 0.0015829447709397267*lm^2) + 
        0.000028353183819744736*NM + 0.00010760339724614465*lm*NM + 
        0.00005862758410887877*lm^2*NM + 0.000281107123631076*NL + 
        0.00010760339724614465*lm*NL + 0.00005862758410887877*lm^2*NL - 
        0.00003877586624502916*NH + 0.00010760339724614465*lm*NH + 
        0.00005862758410887877*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.0009408631716892191 - 0.0009775197281340275*lm - 
          0.00031549202796659557*lm^2) + CF*(0.001106600787514903 + 
          0.001192737552345543*lm + 0.001548779046381469*lm^2) + 
        0.00002612189258131067*NM + 0.0001047244399659829*lm*NM + 
        0.00005736218690301738*lm^2*NM + 0.0002744538483106979*NL + 
        0.0001047244399659829*lm*NL + 0.00005736218690301738*lm^2*NL - 
        0.00003762266593167905*NH + 0.0001047244399659829*lm*NH + 
        0.00005736218690301738*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.0009156995728341602 - 0.0009534728580586476*lm - 
          0.00030869911936052836*lm^2) + CF*(0.0010776434470009518 + 
          0.0011523305422415366*lm + 0.0015154320404971392*lm^2) + 
        0.00002398620631246164*NM + 0.00010192419450574754*lm*NM + 
        0.000056127112611005156*lm^2*NM + 0.0002679755957914931*NL + 
        0.00010192419450574754*lm*NL + 0.000056127112611005156*lm^2*NL - 
        0.00003650097881455408*NH + 0.00010192419450574754*lm*NH + 
        0.000056127112611005156*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.0008912470457417908 - 0.0009300533151572703*lm - 
          0.0003020686077394904*lm^2) + CF*(0.0010495198580777027 + 
          0.0011131469809892837*lm + 0.00148288225617568*lm^2) + 
        0.000021942479817758612*NM + 0.00009920042906408442*lm*NM + 
        0.00005492156504354371*lm^2*NM + 0.0002616673692645875*NL + 
        0.00009920042906408442*lm*NL + 0.00005492156504354371*lm^2*NL - 
        0.00003540994461156392*NH + 0.00009920042906408442*lm*NH + 
        0.00005492156504354371*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.0008674845491021401 - 0.0009072437704539888*lm - 
          0.000295596238611922*lm^2) + CF*(0.001022205267518465 + 
          0.00107515042685439*lm + 0.0014511088077312536*lm^2) + 
        0.000019987203154463155*NM + 0.00009655097742854494*lm*NM + 
        0.00005374477065671309*lm^2*NM + 0.00025552432393880837*NL + 
        0.00009655097742854494*lm*NL + 0.00005374477065671309*lm^2*NL - 
        0.00003434872700541596*NH + 0.00009655097742854494*lm*NH + 
        0.00005374477065671309*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.0008443916871069716 - 0.0008850273985119045*lm - 
          0.00028927787823918553*lm^2) + CF*(0.0009956756570620102 + 
          0.00103830552984527*lm + 0.0014200914022650926*lm^2) + 
        0.00001811699661675209*NM + 0.00009397373699640251*lm*NM + 
        0.000052595977861670096*lm^2*NM + 0.000249541762194072*NL + 
        0.00009397373699640251*lm*NL + 0.000052595977861670096*lm^2*NL - 
        0.000033316512961845666*NH + 0.00009397373699640251*lm*NH + 
        0.000052595977861670096*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0008219486892191593 - 0.0008633878622025297*lm - 
          0.0002831095099616254*lm^2) + CF*(0.0009699077222960127 + 
          0.0010025779989369808*lm + 0.0013898103216297977*lm^2) + 
        0.000016328605906763974*NM + 0.000091466666855621*lm*NM + 
        0.00005147445635665917*lm^2*NM + 0.00024371512889362362*NL + 
        0.000091466666855621*lm*NL + 0.00005147445635665917*lm^2*NL - 
        0.000032312512067427975*NH + 0.000091466666855621*lm*NH + 
        0.00005147445635665917*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0008001363905737504 - 0.0008423092979471846*lm - 
          0.0002770872306431922*lm^2) + CF*(0.0009448788520874813 + 
          0.000967934570256966*lm + 0.0013602464049756707*lm^2) + 
        0.000014618897485545942*NM + 0.00008902778592420397*lm*NM + 
        0.000050379496480580396*lm^2*NM + 0.00023804000684992746*NL + 
        0.00008902778592420397*lm*NL + 0.000050379496480580396*lm^2*NL - 
        0.000031335955886417055*NH + 0.00008902778592420397*lm*NH + 
        0.000050379496480580396*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0007789362129920651 - 0.0008217763014157959*lm - 
          0.00027120724723061855*lm^2) + CF*(0.0009205671085503394 + 
          0.0009343429762069201*lm + 0.0013313810318594*lm^2) + 
        0.000012984854097219303*NM + 0.00008665517114619993*lm*NM + 
        0.000049310408587385185*lm^2*NM + 0.00023251211243916357*NL + 
        0.00008665517114619993*lm*NL + 0.000049310408587385185*lm^2*NL - 
        0.00003038609733607648*NH + 0.00008665517114619993*lm*NH + 
        0.000049310408587385185*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.0007583301465906278 - 0.0008017739136689298*lm - 
          0.0002654658734232777*lm^2) + CF*(0.000896951207540158 + 
          0.0009017719154954648*lm + 0.0013031961058960905*lm^2) + 
        0.000011423570459923984*NM + 0.0000843469557426833*lm*NM + 
        0.00004826652244059595*lm^2*NM + 0.00022712729135944678*NL + 
        0.0000843469557426833*lm*NL + 0.00004826652244059595*lm^2*NL - 
        0.00002946221007997552*NH + 0.0000843469557426833*lm*NH + 
        0.00004826652244059595*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.0007383007319671751 - 0.0007822876077293094*lm - 
          0.0002598595264499873*lm^2) + CF*(0.0008740104996659297 + 
          0.0008701910240568376*lm + 0.0012756740389363013*lm^2) + 
        9.932249117335358*^-6*NM + 0.00008210132751607572*lm*NM + 
        0.00004724718662727042*lm^2*NM + 0.0002218815145280362*NL + 
        0.00008210132751607572*lm*NL + 0.00004724718662727042*lm^2*NL - 
        0.000028563587938741435*NH + 0.00008210132751607572*lm*NH + 
        0.00004724718662727042*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.0007188310429464193 - 0.0007633032755694718*lm - 
          0.00025438472394915434*lm^2) + CF*(0.0008517249518086766 + 
          0.0008395708468312872*lm + 0.001248797735750394*lm^2) + 
        8.508196444772896*^-6*NM + 0.00007991652720621534*lm*NM + 
        0.000046251767990755336*lm^2*NM + 0.00021677087411295219*NL + 
        0.00007991652720621534*lm*NL + 0.000046251767990755336*lm^2*NL - 
        0.000027689544317770926*NH + 0.00007991652720621534*lm*NH + 
        0.000046251767990755336*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.0006999046698686898 - 0.0007448072155026167*lm - 
          0.00024903808094878146*lm^2) + CF*(0.0008300751291366305 + 
          0.0008098828103833849*lm + 0.0012225505792031089*lm^2) + 
        7.148818804138172*^-6*NM + 0.00007779084689662551*lm*NM + 
        0.00004527965108159663*lm^2*NM + 0.00021179157969456383*NL + 
        0.00007779084689662551*lm*NL + 0.00004527965108159663*lm^2*NL - 
        0.00002683941165141731*NH + 0.00007779084689662551*lm*NH + 
        0.00004527965108159663*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0006815057034050115 - 0.000726786119964086*lm - 
          0.00024381630694297635*lm^2) + CF*(0.0008090421776066817 + 
          0.0007810991963349653*lm + 0.0011969164159018838*lm^2) + 
        5.851618842130438*^-6*NM + 0.00007572262846947566*lm*NM + 
        0.0000443302376259957*lm^2*NM + 0.00020693995455285056*NL + 
        0.00007572262846947566*lm*NL + 0.0000443302376259957*lm^2*NL - 
        0.000026012540863182896*NH + 0.00007572262846947566*lm*NH + 
        0.0000443302376259957*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.0006636187188826011 - 0.000709227063671288*lm - 
          0.00023871620306172383*lm^2) + CF*(0.0007886078069417859 + 
          0.0007531931155899253*lm + 0.0011718795423030079*lm^2) + 
        4.614191926391577*^-6*NM + 0.00007371026210776915*lm*NM + 
        0.00004340294601122252*lm^2*NM + 0.00020221243207617915*NL + 
        0.00007371026210776915*lm*NL + 0.00004340294601122252*lm^2*NL - 
        0.000025208300841458634*NH + 0.00007371026210776915*lm*NH + 
        0.00004340294601122252*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.0006462287611051958 - 0.0006921174921502491*lm - 
          0.00023373465933079185*lm^2) + CF*(0.0007687542740740243 + 
          0.0007261384833286186*lm + 0.0011474246912602508*lm^2) + 
        3.4342227144286716*^-6*NM + 0.00007175218484333313*lm*NM + 
        0.0000424972107874167*lm^2*NM + 0.0001976055522875713*NL + 
        0.00007175218484333313*lm*NL + 0.0000424972107874167*lm^2*NL - 
        0.000024426077930365753*NH + 0.00007175218484333313*lm*NH + 
        0.0000424972107874167*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.0006293213296530404 - 0.0006754452106173331*lm - 
          0.00022886865201875238*lm^2) + CF*(0.0007494643670430407 + 
          0.0006999099947500939*lm + 0.001123537019001148*lm^2) + 
        2.3094818503521617*^-6*NM + 0.00006984687914922531*lm*NM + 
        0.0000416124821852277*lm^2*NM + 0.0001931159584845663*NL + 
        0.00006984687914922531*lm*NL + 0.0000416124821852277*lm^2*NL - 
        0.00002366527543526596*NH + 0.00006984687914922531*lm*NH + 
        0.0000416124821852277*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.000612882364647776 - 0.0006591983732050133*lm - 
          0.00022411524106820342*lm^2) + CF*(0.000730721389339629 + 
          0.0006744831015409304*lm + 0.001100202092516635*lm^2) + 
        1.2378227846506019*^-6*NM + 0.00006799287157521155*lm*NM + 
        0.00004074822564876426*lm^2*NM + 0.00018874039398890906*NL + 
        0.00006799287157521155*lm*NL + 0.00004074822564876426*lm^2*NL - 
        0.000022925313142518837*NH + 0.00006799287157521155*lm*NH + 
        0.00004074822564876426*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.0005968982329678751 - 0.0006433654725209253*lm - 
          0.0002194715676083788*lm^2) + CF*(0.0007125091446842991 + 
          0.0006498339890499316*lm + 0.0010774058773502233*lm^2) + 
        2.1717871239971133*^-7*NM + 0.0000661887314250062*lm*NM + 
        0.000039903921383341606*lm^2*NM + 0.00018447569900241793*NL + 
        0.0000661887314250062*lm*NL + 0.000039903921383341606*lm^2*NL - 
        0.000022205626853076562*NH + 0.0000661887314250062*lm*NH + 
        0.000039903921383341606*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.0005813557149006717 - 0.0006279353295297549*lm - 
          0.00021493485154643074*lm^2) + CF*(0.0006948119222307332 + 
          0.0006259395541484354*lm + 0.0010551347257733872*lm^2) - 
        7.544403745261771*^-7*NM + 0.00006443306947400452*lm*NM + 
        0.000039079063917532864*lm^2*NM + 0.00018031880756550278*NL + 
        0.00006443306947400452*lm*NL + 0.000039079063917532864*lm^2*NL - 
        0.000021505667929517347*NH + 0.00006443306947400452*lm*NH + 
        0.000039079063917532864*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.0005662419912174203 - 0.0006128970837478367*lm - 
          0.0002105023892347642*lm^2) + CF*(0.0006776144821841291 + 
          0.0006027773837564965*lm + 0.001033375365334297*lm^2) - 
        1.6789505255077667*^-6*NM + 0.0000627245367262728*lm*NM + 
        0.000038273161679048036*lm^2*NM + 0.00017626674461492184*NL + 
        0.0000627245367262728*lm*NL + 0.000038273161679048036*lm^2*NL - 
        0.000020824902856130176*NH + 0.0000627245367262728*lm*NH + 
        0.000038273161679048036*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.0005515446306582097 - 0.0005982401837406509*lm - 
          0.00020617155121189346*lm^2) + CF*(0.0006609020418245266 + 
          0.0005803257340156863*lm + 0.0010121148877674769*lm^2) - 
        2.5581965636084964*^-6*NM + 0.00006106182320959757*lm*NM + 
        0.00003748573658398063*lm^2*NM + 0.00017231662313747608*NL + 
        0.00006106182320959757*lm*NL + 0.00003748573658398063*lm^2*NL - 
        0.00002016281281167404*NH + 0.00006106182320959757*lm*NH + 
        0.00003748573658398063*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.0005372515778139266 - 0.0005839543779137083*lm - 
          0.00020193978001437757*lm^2) + CF*(0.0006446602619253285 + 
          0.0005585635100897401*lm + 0.000991340738252399*lm^2) - 
        3.3939547163323686*^-6*NM + 0.000059443656807429835*lm*NM + 
        0.00003671632363897774*lm^2*NM + 0.00016846564141644887*NL + 
        0.000059443656807429835*lm*NL + 0.00003671632363897774*lm^2*NL - 
        0.000019518893254445463*NH + 0.000059443656807429835*lm*NH + 
        0.00003671632363897774*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.0005233511413928379 - 0.0005700297055876062*lm - 
          0.00019780458805747803*lm^2) + CF*(0.0006288752335573429 + 
          0.00053747024657476*lm + 0.0009710407050094376*lm^2) - 
        4.187935148520591*^-6*NM + 0.00005786880212659464*lm*NM + 
        0.000035964470555905096*lm^2*NM + 0.0001647110803677038*NL + 
        0.00005786880212659464*lm*NL + 0.000035964470555905096*lm^2*NL - 
        0.00001889265351929835*NH + 0.00005786880212659464*lm*NH + 
        0.000035964470555905096*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.0005098319828597208 - 0.0005564564883483283*lm - 
          0.00019376355558226138*lm^2) + CF*(0.0006135334652688049 + 
          0.0005170260885011534*lm + 0.0009512029092220105*lm^2) - 
        4.941784401053633*^-6*NM + 0.00005633605939966864*lm*NM + 
        0.00003522973737859298*lm^2*NM + 0.00016105030096245581*NL + 
        0.00005633605939966864*lm*NL + 0.00003522973737859298*lm^2*NL - 
        0.00001828361642627021*NH + 0.00005633605939966864*lm*NH + 
        0.00003522973737859298*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.0004966831054358206 - 0.0005432253216641335*lm - 
          0.00018981432866694976*lm^2) + CF*(0.0005986218706319676 + 
          0.0004972117729099488*lm + 0.0009318157952741171*lm^2) - 
        5.657087738888368*^-6*NM + 0.00005484426342096153*lm*NM + 
        0.000034511696121263594*lm^2*NM + 0.00015748074173382902*NL + 
        0.00005484426342096153*lm*NL + 0.000034511696121263594*lm^2*NL - 
        0.000017691317900478498*NH + 0.00005484426342096153*lm*NH + 
        0.000034511696121263594*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.0004838938434482648 - 0.0005303270667606516*lm - 
          0.0001859546173003973*lm^2) + CF*(0.000584127756146998 + 
          0.000478008610986592*lm + 0.0009128681212928595*lm^2) - 
        6.335371411827983*^-6*NM + 0.00005339228251506787*lm*NM + 
        0.00003380993041825405*lm^2*NM + 0.00015399991636441102*NL + 
        0.00005339228251506787*lm*NL + 0.00003380993041825405*lm^2*NL - 
        0.000017115306602960354*NH + 0.00005339228251506787*lm*NH + 
        0.00003380993041825405*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.000471453852017897 - 0.0005177528427460663*lm - 
          0.00018218219351564372*lm^2) + CF*(0.0005700388094940561 + 
          0.0004593984707357695*lm + 0.0008943489499858874*lm^2) - 
        6.978104831295175*^-6*NM + 0.00005197901753698706*lm*NM + 
        0.00003312403518466249*lm^2*NM + 0.00015060541135210553*NL + 
        0.00005197901753698706*lm*NL + 0.00003312403518466249*lm^2*NL - 
        0.000016555143572138326*NH + 0.00005197901753698706*lm*NH + 
        0.00003312403518466249*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.0004593530970748235 - 0.0005054940189785169*lm - 
          0.0001784948895815673*lm^2) + CF*(0.0005563430881245876 + 
          0.0004413637601812515*lm + 0.0008762476397640577*lm^2) - 
        7.586702666256641*^-6*NM + 0.000050603400902838735*lm*NM + 
        0.00003245361628755769*lm^2*NM + 0.00014729488375167591*NL + 
        0.000050603400902838735*lm*NL + 0.00003245361628755769*lm^2*NL - 
        0.000016010401875603556*NH + 0.000050603400902838735*lm*NH + 
        0.00003245361628755769*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.00044758184569128806 - 0.0004935422076681004*lm - 
          0.000174890596250727*lm^2) + CF*(0.0005430290081830173 + 
          0.00042388741107517543*lm + 0.0008585538361399324*lm^2) - 
        8.162526861328806*^-6*NM + 0.0000492643956502302*lm*NM + 
        0.00003179829022740491*lm^2*NM + 0.00014406605898945813*NL + 
        0.0000492643956502302*lm*NL + 0.00003179829022740491*lm^2*NL - 
        0.000015480666271916806*NH + 0.0000492643956502302*lm*NH + 
        0.00003179829022740491*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.0004361306567218017 - 0.0004818892567060914*lm - 
          0.00017136726106154907*lm^2) + CF*(0.0005300853337501863 + 
          0.0004069528631016189*lm + 0.0008412574633930592*lm^2) - 
        8.706888579981074*^-6*NM + 0.000047960994527360627*lm*NM + 
        0.00003115768382937256*lm^2*NM + 0.00014091672874880657*NL + 
        0.000047960994527360627*lm*NL + 0.00003115768382937256*lm^2*NL - 
        0.000014965532882136244*NH + 0.000047960994527360627*lm*NH + 
        0.00003115768382937256*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.00042499037174076185 - 0.0004705272427142318*lm - 
          0.00016792288669307805*lm^2) + CF*(0.000517501166400039 + 
          0.000390544048559725*lm + 0.0008243487164932922*lm^2) - 
        9.221050075643317*^-6*NM + 0.000046692219109974494*lm*NM + 
        0.00003053143394419601*lm^2*NM + 0.0001378447489239177*NL + 
        0.000046692219109974494*lm*NL + 0.00003053143394419601*lm^2*NL - 
        0.000014464608870789113*NH + 0.000046692219109974494*lm*NH + 
        0.00003053143394419601*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.0004141521062680909 - 0.0004594484643071675*lm - 
          0.00016455552937057075*lm^2) + CF*(0.0005052659350612264 + 
          0.0003746453775120507*lm + 0.000807818053273711*lm^2) - 
        9.7062264934189*^-6*NM + 0.000045457118945303336*lm*NM + 
        0.000029919187158285593*lm^2*NM + 0.00013484803763975464*NL + 
        0.000045457118945303336*lm*NL + 0.000029919187158285593*lm^2*NL - 
        0.000013977512136012725*NH + 0.000045457118945303336*lm*NH + 
        0.000029919187158285593*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.00040360724127371466 - 0.0004486454355613256*lm - 
          0.00016126329732027347*lm^2) + CF*(0.0004933693861754586 + 
          0.00035924172338420854*lm + 0.0007916561868449788*lm^2) - 
        0.00001016358760500295*NM + 0.000044254770722161215*lm*NM + 
        0.000029320599512776994*lm^2*NM + 0.00013192457333587325*NL + 
        0.000044254770722161215*lm*NL + 0.000029320599512776994*lm^2*NL - 
        0.000013503871008597895*NH + 0.000044254770722161215*lm*NH + 
        0.000029320599512776994*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.0003933474149519841 - 0.0004381108796837396*lm - 
          0.00015804434927177714*lm^2) + CF*(0.00048180157414460373 + 
          0.0003443184090022604*lm + 0.0007758540782432697*lm^2) - 
        0.000010594259479307741*NM + 0.000043084277466384385*lm*NM + 
        0.00002873533623123221*lm^2*NM + 0.00012907239291202297*NL + 
        0.000043084277466384385*lm*NL + 0.00002873533623123221*lm^2*NL - 
        0.000013043323959675767*NH + 0.000043084277466384385*lm*NH + 
        0.00002873533623123221*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.0003833645147574171 - 0.0004278377228745339*lm - 
          0.00015489689300640175*lm^2) + CF*(0.0004705528520586971 + 
          0.00032986119305470675*lm + 0.0007604029293041541*lm^2) - 
        0.000010999326091202984*NM + 0.000041944767760830555*lm*NM + 
        0.00002816307145570941*lm^2*NM + 0.00012628958993346812*NL + 
        0.000041944767760830555*lm*NL + 0.00002816307145570941*lm^2*NL - 
        0.000012595519316796372*NH + 0.000041944767760830555*lm*NH + 
        0.00002816307145570941*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.00037365066969340463 - 0.0004178190883769799*lm - 
          0.00015181918395011266*lm^2) + CF*(0.00045961386269719015 + 
          0.00031585625696628304*lm + 0.0007452941757550985*lm^2) - 
        0.000011379830870688046*NM + 0.00004083539498917688*lm*NM + 
        0.000027603487990929573*lm^2*NM + 0.00012357431289404387*NL + 
        0.00004083539498917688*lm*NL + 0.000027603487990929573*lm^2*NL - 
        0.000012160114988154548*NH + 0.00004083539498917688*lm*NH + 
        0.000027603487990929573*lm^2*NH)}, 
     {1., 3.2104210752023403*^-19*CF*NC*
       (-10.*CA*(1.134425155811787*^14 + 1.27101174939648*^14*lm + 
          4.63520268288*^13*lm^2) + 36.*CF*(3.884706149814173*^13 + 
          2.615529111552*^13*lm + 6.3207309312*^13*lm^2) - 
        3.6558376361849*^13*NM + 1.2383215681536*^14*lm*NM + 
        8.4276412416*^13*lm^2*NM + 3.76663249780736*^14*NL + 
        1.2383215681536*^14*lm*NL + 8.4276412416*^13*lm^2*NL - 
        3.6558376361849*^13*NH + 1.2383215681536*^14*lm*NH + 
        8.4276412416*^13*lm^2*NH)}}


(* pseudo  *)

CbarData["p", 0, -1] = (-4*NC*(1 - x + x^2))/(3*ep) - 
     (4*NC*(1 + lm + x^3 + lm*x^3 - 2*x^3*HPL[{0}, x]))/(3*(1 + x))
 
CbarData["p", 0, 0] = (2*NC)/(3*ep) + 
     NC*((1 + 4*x + x^2 + 2*lm*(1 + x)^2)/(3*(1 + x)^2) - 
       (4*x^3*(2 + x)*HPL[{0}, x])/(3*(-1 + x)*(1 + x)^3))
 
CbarData["p", 0, 1] = (2*NC*(-1 - 3*x + 3*x^2 - 3*x^4 + 3*x^5 + x^6 - 
       12*x^3*HPL[{0}, x]))/(9*(-1 + x)^3*(1 + x)^5)
 
CbarData["p", 0, 2] = NC*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
       (18*(-1 + x)^4*(1 + x)^6) + (4*x^3*(-2 + x - 2*x^2)*HPL[{0}, x])/
       (3*(-1 + x)^5*(1 + x)^7))
 
CbarData["p", 0, 3] = NC*((1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 
        14*x^6 + 5*x^7 + x^8)/(45*(-1 + x)^6*(1 + x)^8) - 
      (8*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
       (3*(-1 + x)^7*(1 + x)^9))
 
CbarData["p", 0, 4] = NC*((1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 956*x^5 - 
        398*x^6 + 356*x^7 - 23*x^8 + 6*x^9 + x^10)/(90*(-1 + x)^8*
        (1 + x)^10) - (4*x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*x^5 + 
         2*x^6)*HPL[{0}, x])/(3*(-1 + x)^9*(1 + x)^11))
 
CbarData["p", 0, 5] = 
    NC*((2*(1 + 7*x - 34*x^2 + 714*x^3 - 1133*x^4 + 3689*x^5 - 2708*x^6 + 
         3689*x^7 - 1133*x^8 + 714*x^9 - 34*x^10 + 7*x^11 + x^12))/
       (315*(-1 + x)^10*(1 + x)^12) - 
      (8*x^3*(1 - 2*x + 10*x^2 - 10*x^3 + 20*x^4 - 10*x^5 + 10*x^6 - 2*x^7 + 
         x^8)*HPL[{0}, x])/(3*(-1 + x)^11*(1 + x)^13))
 
CbarData["p", 0, 6] = NC*((5 + 40*x - 235*x^2 + 6312*x^3 - 12975*x^4 + 
        53352*x^5 - 56095*x^6 + 102352*x^7 - 56095*x^8 + 53352*x^9 - 
        12975*x^10 + 6312*x^11 - 235*x^12 + 40*x^13 + 5*x^14)/
       (1260*(-1 + x)^12*(1 + x)^14) - 
      (4*x^3*(2 - 5*x + 30*x^2 - 40*x^3 + 100*x^4 - 75*x^5 + 100*x^6 - 
         40*x^7 + 30*x^8 - 5*x^9 + 2*x^10)*HPL[{0}, x])/
       (3*(-1 + x)^13*(1 + x)^15))
 
CbarData["p", 0, 7] = NC*((5 + 45*x - 310*x^2 + 10233*x^3 - 25834*x^4 + 
        128421*x^5 - 175774*x^6 + 401841*x^7 - 316894*x^8 + 401841*x^9 - 
        175774*x^10 + 128421*x^11 - 25834*x^12 + 10233*x^13 - 310*x^14 + 
        45*x^15 + 5*x^16)/(1890*(-1 + x)^14*(1 + x)^16) - 
      (8*x^3*(1 - 3*x + 21*x^2 - 35*x^3 + 105*x^4 - 105*x^5 + 175*x^6 - 
         105*x^7 + 105*x^8 - 35*x^9 + 21*x^10 - 3*x^11 + x^12)*HPL[{0}, x])/
       (3*(-1 + x)^15*(1 + x)^17))
 
CbarData["p", 0, 8] = NC*((7 + 70*x - 553*x^2 + 21796*x^3 - 65254*x^4 + 
        380644*x^5 - 641830*x^6 + 1763620*x^7 - 1814890*x^8 + 2874940*x^9 - 
        1814890*x^10 + 1763620*x^11 - 641830*x^12 + 380644*x^13 - 
        65254*x^14 + 21796*x^15 - 553*x^16 + 70*x^17 + 7*x^18)/
       (3780*(-1 + x)^16*(1 + x)^18) - 
      (4*x^3*(2 - 7*x + 56*x^2 - 112*x^3 + 392*x^4 - 490*x^5 + 980*x^6 - 
         784*x^7 + 980*x^8 - 490*x^9 + 392*x^10 - 112*x^11 + 56*x^12 - 
         7*x^13 + 2*x^14)*HPL[{0}, x])/(3*(-1 + x)^17*(1 + x)^19))
 
CbarData["p", 0, 9] = NC*((14 + 154*x - 1372*x^2 + 63173*x^3 - 218798*x^4 + 
        1465607*x^5 - 2936744*x^6 + 9426791*x^7 - 11967920*x^8 + 
        22737935*x^9 - 18759320*x^10 + 22737935*x^11 - 11967920*x^12 + 
        9426791*x^13 - 2936744*x^14 + 1465607*x^15 - 218798*x^16 + 
        63173*x^17 - 1372*x^18 + 154*x^19 + 14*x^20)/(10395*(-1 + x)^18*
        (1 + x)^20) - (8*x^3*(1 - 4*x + 36*x^2 - 84*x^3 + 336*x^4 - 504*x^5 + 
         1176*x^6 - 1176*x^7 + 1764*x^8 - 1176*x^9 + 1176*x^10 - 504*x^11 + 
         336*x^12 - 84*x^13 + 36*x^14 - 4*x^15 + x^16)*HPL[{0}, x])/
       (3*(-1 + x)^19*(1 + x)^21))
 
CbarData["p", 1, -1] = (2*CF*NC*(1 - x + x^2))/ep^2 - 
     (2*CF*NC*(1 - x + x^2))/(3*ep) - 
     (2*CF*NC*(5 + 5*lm + 3*lm^2 + 5*x^3 + 5*lm*x^3 + 3*lm^2*x^3 - 
        10*x^3*HPL[{0}, x] - 12*lm*x^3*HPL[{0}, x] + 24*x^3*HPL[{0, 0}, x]))/
      (3*(1 + x))
 
CbarData["p", 1, 0] = -(CF*NC)/(2*ep^2) + (5*CF*NC)/(12*ep) + 
     CF*NC*(lm^2/2 + (39 + 198*x + 39*x^2 + 4*Pi^2*(-1 + x^2))/
        (72*(1 + x)^2) - (2*x^2*(1 + 5*x + x^2)*HPL[{0}, x])/
        (3*(-1 + x)*(1 + x)^3) + lm*((1 + 5*x + x^2)/(3*(1 + x)^2) - 
         (2*x^3*(2 + x)*HPL[{0}, x])/((-1 + x)*(1 + x)^3)) + 
       ((2 - 2*x)*HPL[{-1, 0}, x])/(3 + 3*x) + 
       (8*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
        (3*(-1 + x)^2*(1 + x)^4) + (2*(-1 + x)*HPL[{1, 0}, x])/(3*(1 + x)))
 
CbarData["p", 1, 1] = CF*NC*((-4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) + 
        3*(1 + 36*x - 22*x^2 + 36*x^3 + x^4))/(108*(-1 + x)^2*(1 + x)^4) + 
      (4*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(9*(-1 + x)^3*(1 + x)^5) + 
      (4*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(9*(-1 + x)*(1 + x)^3) - 
      (8*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
       (9*(-1 + x)^4*(1 + x)^6) - (4*(1 + 3*x + x^2)*HPL[{1, 0}, x])/
       (9*(-1 + x)*(1 + x)^3))
 
CbarData["p", 1, 2] = CF*NC*((-4*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 
        3*(3 + 72*x - 127*x^2 + 112*x^3 - 127*x^4 + 72*x^5 + 3*x^6))/
       (432*(-1 + x)^4*(1 + x)^6) + (x^2*(2 + 122*x - 27*x^2 + 230*x^3 - 
         22*x^4 + 12*x^5 + 3*x^6)*HPL[{0}, x])/(18*(-1 + x)^5*(1 + x)^7) + 
      lm*(-(1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
         (12*(-1 + x)^4*(1 + x)^6) + (2*x^3*(2 - x + 2*x^2)*HPL[{0}, x])/
         ((-1 + x)^5*(1 + x)^7)) + ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0}, x])/
       (9*(-1 + x)^3*(1 + x)^5) - (2*x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 
         136*x^4 - 3*x^5 + 4*x^6 + x^7)*HPL[{0, 0}, x])/
       (9*(-1 + x)^6*(1 + x)^8) - ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/
       (9*(-1 + x)^3*(1 + x)^5))
 
CbarData["p", 1, 3] = 
    CF*NC*(-(11 - 219*x + 658*x^2 + 1479*x^3 + 1326*x^4 + 1479*x^5 + 
         658*x^6 - 219*x^7 + 11*x^8 + 4*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 
           15*x^5 - 2*x^6 + 5*x^7 + x^8))/(1080*(-1 + x)^6*(1 + x)^8) + 
      (2*x^2*(1 + 263*x - 184*x^2 + 1109*x^3 - 424*x^4 + 683*x^5 - 44*x^6 + 
         15*x^7 + 3*x^8)*HPL[{0}, x])/(45*(-1 + x)^7*(1 + x)^9) + 
      lm*(-(1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 5*x^7 + 
           x^8)/(15*(-1 + x)^6*(1 + x)^8) + 
        (8*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
         ((-1 + x)^7*(1 + x)^9)) + (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + 
         x^6)*HPL[{-1, 0}, x])/(45*(-1 + x)^5*(1 + x)^7) - 
      (4*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 1940*x^4 - 535*x^5 + 
         545*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{0, 0}, x])/
       (45*(-1 + x)^8*(1 + x)^10) - (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 
         5*x^5 + x^6)*HPL[{1, 0}, x])/(45*(-1 + x)^5*(1 + x)^7))
 
CbarData["p", 1, 4] = 
    CF*NC*(-(61 - 201*x + 978*x^2 + 19344*x^3 - 7591*x^4 + 51570*x^5 - 
         7591*x^6 + 19344*x^7 + 978*x^8 - 201*x^9 + 61*x^10 + 
         6*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*x^4 - 16*x^6 + 48*x^7 - 
           3*x^8 + 6*x^9 + x^10))/(3240*(-1 + x)^8*(1 + x)^10) + 
      (x^2*(2 + 1512*x - 1780*x^2 + 11358*x^3 - 7758*x^4 + 16758*x^5 - 
         5155*x^6 + 4662*x^7 - 214*x^8 + 54*x^9 + 9*x^10)*HPL[{0}, x])/
       (90*(-1 + x)^9*(1 + x)^11) + 
      lm*(-(1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 956*x^5 - 398*x^6 + 
           356*x^7 - 23*x^8 + 6*x^9 + x^10)/(20*(-1 + x)^8*(1 + x)^10) + 
        (6*x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*x^5 + 2*x^6)*
          HPL[{0}, x])/((-1 + x)^9*(1 + x)^11)) + 
      ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
        HPL[{-1, 0}, x])/(45*(-1 + x)^7*(1 + x)^9) - 
      (2*x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 13200*x^4 - 7055*x^5 + 
         9810*x^6 - 2169*x^7 + 1476*x^8 - 5*x^9 + 6*x^10 + x^11)*
        HPL[{0, 0}, x])/(45*(-1 + x)^10*(1 + x)^12) - 
      ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
        HPL[{1, 0}, x])/(45*(-1 + x)^7*(1 + x)^9))
 
CbarData["p", 1, 5] = 
    CF*NC*(-(4519 + 2230*x + 7106*x^2 + 2867370*x^3 - 2876915*x^4 + 
         14316800*x^5 - 7125020*x^6 + 14316800*x^7 - 2876915*x^8 + 
         2867370*x^9 + 7106*x^10 + 2230*x^11 + 4519*x^12 + 
         240*Pi^2*(-1 - 7*x + 4*x^2 - 105*x^3 + 65*x^4 - 140*x^5 + 140*x^7 - 
           65*x^8 + 105*x^9 - 4*x^10 + 7*x^11 + x^12))/
       (226800*(-1 + x)^10*(1 + x)^12) + 
      (x^2*(4 + 6928*x - 11460*x^2 + 81817*x^3 - 81218*x^4 + 217254*x^5 - 
         119018*x^6 + 153217*x^7 - 37836*x^8 + 23896*x^9 - 836*x^10 + 
         168*x^11 + 24*x^12)*HPL[{0}, x])/(315*(-1 + x)^11*(1 + x)^13) + 
      lm*((-4*(1 + 7*x - 34*x^2 + 714*x^3 - 1133*x^4 + 3689*x^5 - 2708*x^6 + 
           3689*x^7 - 1133*x^8 + 714*x^9 - 34*x^10 + 7*x^11 + x^12))/
         (105*(-1 + x)^10*(1 + x)^12) + (16*x^3*(1 - 2*x + 10*x^2 - 10*x^3 + 
           20*x^4 - 10*x^5 + 10*x^6 - 2*x^7 + x^8)*HPL[{0}, x])/
         ((-1 + x)^11*(1 + x)^13)) + 
      (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*x^7 - 
         3*x^8 + 7*x^9 + x^10)*HPL[{-1, 0}, x])/(315*(-1 + x)^9*(1 + x)^11) - 
      (8*x^3*(630 - 1260*x + 12285*x^2 - 16310*x^3 + 58975*x^4 - 47040*x^5 + 
         83860*x^6 - 36344*x^7 + 34902*x^8 - 6356*x^9 + 3241*x^10 - 6*x^11 + 
         7*x^12 + x^13)*HPL[{0, 0}, x])/(315*(-1 + x)^12*(1 + x)^14) - 
      (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*x^7 - 
         3*x^8 + 7*x^9 + x^10)*HPL[{1, 0}, x])/(315*(-1 + x)^9*(1 + x)^11))
 
CbarData["p", 1, 6] = 
    CF*NC*(-(33887 + 88456*x - 357835*x^2 + 38148864*x^3 - 58045437*x^4 + 
         308482680*x^5 - 254107015*x^6 + 581132800*x^7 - 254107015*x^8 + 
         308482680*x^9 - 58045437*x^10 + 38148864*x^11 - 357835*x^12 + 
         88456*x^13 + 33887*x^14 + 1200*Pi^2*(-1 - 8*x + 5*x^2 - 192*x^3 + 
           171*x^4 - 600*x^5 + 225*x^6 - 225*x^8 + 600*x^9 - 171*x^10 + 
           192*x^11 - 5*x^12 + 8*x^13 + x^14))/(1814400*(-1 + x)^12*
        (1 + x)^14) + (x^2*(10 + 34310*x - 73129*x^2 + 587186*x^3 - 
         767766*x^4 + 2446244*x^5 - 1929345*x^6 + 3181244*x^7 - 1414566*x^8 + 
         1292786*x^9 - 264229*x^10 + 128390*x^11 - 3590*x^12 + 600*x^13 + 
         75*x^14)*HPL[{0}, x])/(1260*(-1 + x)^13*(1 + x)^15) + 
      lm*(-(5 + 40*x - 235*x^2 + 6312*x^3 - 12975*x^4 + 53352*x^5 - 
           56095*x^6 + 102352*x^7 - 56095*x^8 + 53352*x^9 - 12975*x^10 + 
           6312*x^11 - 235*x^12 + 40*x^13 + 5*x^14)/(168*(-1 + x)^12*
          (1 + x)^14) + (10*x^3*(2 - 5*x + 30*x^2 - 40*x^3 + 100*x^4 - 
           75*x^5 + 100*x^6 - 40*x^7 + 30*x^8 - 5*x^9 + 2*x^10)*HPL[{0}, x])/
         ((-1 + x)^13*(1 + x)^15)) + 
      ((1 + 8*x - 4*x^2 + 200*x^3 - 175*x^4 + 800*x^5 - 400*x^6 + 800*x^7 - 
         175*x^8 + 200*x^9 - 4*x^10 + 8*x^11 + x^12)*HPL[{-1, 0}, x])/
       (126*(-1 + x)^11*(1 + x)^13) - 
      (x^3*(1008 - 2520*x + 28224*x^2 - 47432*x^3 + 201488*x^4 - 214228*x^5 + 
         467264*x^6 - 301924*x^7 + 376880*x^8 - 135520*x^9 + 99008*x^10 - 
         15280*x^11 + 6224*x^12 - 7*x^13 + 8*x^14 + x^15)*HPL[{0, 0}, x])/
       (63*(-1 + x)^14*(1 + x)^16) - 
      ((1 + 8*x - 4*x^2 + 200*x^3 - 175*x^4 + 800*x^5 - 400*x^6 + 800*x^7 - 
         175*x^8 + 200*x^9 - 4*x^10 + 8*x^11 + x^12)*HPL[{1, 0}, x])/
       (126*(-1 + x)^11*(1 + x)^13))
 
CbarData["p", 1, 7] = 
    CF*NC*(-(106795 + 447867*x - 2475714*x^2 + 195845265*x^3 - 
         393705676*x^4 + 2342972583*x^5 - 2676880150*x^6 + 7136097885*x^7 - 
         4801356910*x^8 + 7136097885*x^9 - 2676880150*x^10 + 
         2342972583*x^11 - 393705676*x^12 + 195845265*x^13 - 2475714*x^14 + 
         447867*x^15 + 106795*x^16 + 2800*Pi^2*(-1 - 9*x + 6*x^2 - 315*x^3 + 
           364*x^4 - 1701*x^5 + 1106*x^6 - 1575*x^7 + 1575*x^9 - 1106*x^10 + 
           1701*x^11 - 364*x^12 + 315*x^13 - 6*x^14 + 9*x^15 + x^16))/
       (6350400*(-1 + x)^14*(1 + x)^16) + 
      (x^2*(15 + 92115*x - 240375*x^2 + 2157813*x^3 - 3507887*x^4 + 
         12971727*x^5 - 13369639*x^6 + 26775333*x^7 - 17179879*x^8 + 
         20354067*x^9 - 7556267*x^10 + 5348889*x^11 - 929523*x^12 + 
         367191*x^13 - 8490*x^14 + 1215*x^15 + 135*x^16)*HPL[{0}, x])/
       (2835*(-1 + x)^15*(1 + x)^17) + 
      lm*(-(5 + 45*x - 310*x^2 + 10233*x^3 - 25834*x^4 + 128421*x^5 - 
           175774*x^6 + 401841*x^7 - 316894*x^8 + 401841*x^9 - 175774*x^10 + 
           128421*x^11 - 25834*x^12 + 10233*x^13 - 310*x^14 + 45*x^15 + 
           5*x^16)/(210*(-1 + x)^14*(1 + x)^16) + 
        (24*x^3*(1 - 3*x + 21*x^2 - 35*x^3 + 105*x^4 - 105*x^5 + 175*x^6 - 
           105*x^7 + 105*x^8 - 35*x^9 + 21*x^10 - 3*x^11 + x^12)*HPL[{0}, x])/
         ((-1 + x)^15*(1 + x)^17)) + 
      ((1 + 9*x - 5*x^2 + 324*x^3 - 369*x^4 + 2025*x^5 - 1475*x^6 + 
         3600*x^7 - 1475*x^8 + 2025*x^9 - 369*x^10 + 324*x^11 - 5*x^12 + 
         9*x^13 + x^14)*HPL[{-1, 0}, x])/(189*(-1 + x)^13*(1 + x)^15) - 
      (2*x^3*(1512 - 4536*x + 57456*x^2 - 116928*x^3 + 571536*x^4 - 
         760284*x^5 + 1963332*x^6 - 1687392*x^7 + 2595348*x^8 - 1393476*x^9 + 
         1332072*x^10 - 407616*x^11 + 239976*x^12 - 32103*x^13 + 10881*x^14 - 
         8*x^15 + 9*x^16 + x^17)*HPL[{0, 0}, x])/(189*(-1 + x)^16*
        (1 + x)^18) - ((1 + 9*x - 5*x^2 + 324*x^3 - 369*x^4 + 2025*x^5 - 
         1475*x^6 + 3600*x^7 - 1475*x^8 + 2025*x^9 - 369*x^10 + 324*x^11 - 
         5*x^12 + 9*x^13 + x^14)*HPL[{1, 0}, x])/(189*(-1 + x)^13*(1 + x)^15))
 
CbarData["p", 1, 8] = 
    CF*NC*(-(948403 + 5256730*x - 35145481*x^2 + 2659091040*x^3 - 
         6611849840*x^4 + 44230292960*x^5 - 64503115824*x^6 + 
         198683465120*x^7 - 180536005258*x^8 + 320641292300*x^9 - 
         180536005258*x^10 + 198683465120*x^11 - 64503115824*x^12 + 
         44230292960*x^13 - 6611849840*x^14 + 2659091040*x^15 - 
         35145481*x^16 + 5256730*x^17 + 948403*x^18 + 
         19600*Pi^2*(-1 - 10*x + 7*x^2 - 480*x^3 + 680*x^4 - 3920*x^5 + 
           3528*x^6 - 7840*x^7 + 3136*x^8 - 3136*x^10 + 7840*x^11 - 
           3528*x^12 + 3920*x^13 - 680*x^14 + 480*x^15 - 7*x^16 + 10*x^17 + 
           x^18))/(63504000*(-1 + x)^16*(1 + x)^18) + 
      (x^2*(42 + 428316*x - 1322892*x^2 + 13167258*x^3 - 25623722*x^4 + 
         107884186*x^5 - 137408132*x^6 + 323292470*x^7 - 271097002*x^8 + 
         393305630*x^9 - 211310912*x^10 + 195011674*x^11 - 61948010*x^12 + 
         35774682*x^13 - 5399055*x^14 + 1797054*x^15 - 35238*x^16 + 
         4410*x^17 + 441*x^18)*HPL[{0}, x])/(11340*(-1 + x)^17*(1 + x)^19) + 
      lm*(-(7 + 70*x - 553*x^2 + 21796*x^3 - 65254*x^4 + 380644*x^5 - 
           641830*x^6 + 1763620*x^7 - 1814890*x^8 + 2874940*x^9 - 
           1814890*x^10 + 1763620*x^11 - 641830*x^12 + 380644*x^13 - 
           65254*x^14 + 21796*x^15 - 553*x^16 + 70*x^17 + 7*x^18)/
         (360*(-1 + x)^16*(1 + x)^18) + (14*x^3*(2 - 7*x + 56*x^2 - 112*x^3 + 
           392*x^4 - 490*x^5 + 980*x^6 - 784*x^7 + 980*x^8 - 490*x^9 + 
           392*x^10 - 112*x^11 + 56*x^12 - 7*x^13 + 2*x^14)*HPL[{0}, x])/
         ((-1 + x)^17*(1 + x)^19)) + 
      ((1 + 10*x - 6*x^2 + 490*x^3 - 686*x^4 + 4410*x^5 - 4214*x^6 + 
         12250*x^7 - 7350*x^8 + 12250*x^9 - 4214*x^10 + 4410*x^11 - 
         686*x^12 + 490*x^13 - 6*x^14 + 10*x^15 + x^16)*HPL[{-1, 0}, x])/
       (270*(-1 + x)^15*(1 + x)^17) - 
      (x^3*(2160 - 7560*x + 106920*x^2 - 255600*x^3 + 1414080*x^4 - 
         2259900*x^5 + 6746040*x^6 - 7239636*x^7 + 13238640*x^8 - 
         9456396*x^9 + 11179560*x^10 - 5114340*x^11 + 3954720*x^12 - 
         1051575*x^13 + 518130*x^14 - 61145*x^15 + 17740*x^16 - 9*x^17 + 
         10*x^18 + x^19)*HPL[{0, 0}, x])/(135*(-1 + x)^18*(1 + x)^20) - 
      ((1 + 10*x - 6*x^2 + 490*x^3 - 686*x^4 + 4410*x^5 - 4214*x^6 + 
         12250*x^7 - 7350*x^8 + 12250*x^9 - 4214*x^10 + 4410*x^11 - 
         686*x^12 + 490*x^13 - 6*x^14 + 10*x^15 + x^16)*HPL[{1, 0}, x])/
       (270*(-1 + x)^15*(1 + x)^17))
 
CbarData["p", 1, 9] = 
    CF*NC*(-(6925253 + 46878933*x - 363460124*x^2 + 28270305819*x^3 - 
         83584045413*x^4 + 624881491560*x^5 - 1107817911192*x^6 + 
         3890395556376*x^7 - 4453872501456*x^8 + 9239726703312*x^9 - 
         6947690102136*x^10 + 9239726703312*x^11 - 4453872501456*x^12 + 
         3890395556376*x^13 - 1107817911192*x^14 + 624881491560*x^15 - 
         83584045413*x^16 + 28270305819*x^17 - 363460124*x^18 + 
         46878933*x^19 + 6925253*x^20 + 117600*Pi^2*(-1 - 11*x + 8*x^2 - 
           693*x^3 + 1161*x^4 - 7920*x^5 + 9024*x^6 - 25872*x^7 + 17052*x^8 - 
           19404*x^9 + 19404*x^11 - 17052*x^12 + 25872*x^13 - 9024*x^14 + 
           7920*x^15 - 1161*x^16 + 693*x^17 - 8*x^18 + 11*x^19 + x^20))/
       (523908000*(-1 + x)^18*(1 + x)^20) + 
      (x^2*(168 + 2685648*x - 9584214*x^2 + 104910591*x^3 - 237933368*x^4 + 
         1123823546*x^5 - 1705383141*x^6 + 4605758962*x^7 - 4769843125*x^8 + 
         8176180026*x^9 - 5747804725*x^10 + 6522563698*x^11 - 
         3005872485*x^12 + 2270234042*x^13 - 629317592*x^14 + 
         306861087*x^15 - 40893558*x^16 + 11760384*x^17 - 199416*x^18 + 
         22176*x^19 + 2016*x^20)*HPL[{0}, x])/(62370*(-1 + x)^19*
        (1 + x)^21) + lm*((-4*(14 + 154*x - 1372*x^2 + 63173*x^3 - 
           218798*x^4 + 1465607*x^5 - 2936744*x^6 + 9426791*x^7 - 
           11967920*x^8 + 22737935*x^9 - 18759320*x^10 + 22737935*x^11 - 
           11967920*x^12 + 9426791*x^13 - 2936744*x^14 + 1465607*x^15 - 
           218798*x^16 + 63173*x^17 - 1372*x^18 + 154*x^19 + 14*x^20))/
         (3465*(-1 + x)^18*(1 + x)^20) + 
        (32*x^3*(1 - 4*x + 36*x^2 - 84*x^3 + 336*x^4 - 504*x^5 + 1176*x^6 - 
           1176*x^7 + 1764*x^8 - 1176*x^9 + 1176*x^10 - 504*x^11 + 336*x^12 - 
           84*x^13 + 36*x^14 - 4*x^15 + x^16)*HPL[{0}, x])/
         ((-1 + x)^19*(1 + x)^21)) + 
      (4*(1 + 11*x - 7*x^2 + 704*x^3 - 1168*x^4 + 8624*x^5 - 10192*x^6 + 
         34496*x^7 - 27244*x^8 + 53900*x^9 - 27244*x^10 + 34496*x^11 - 
         10192*x^12 + 8624*x^13 - 1168*x^14 + 704*x^15 - 7*x^16 + 11*x^17 + 
         x^18)*HPL[{-1, 0}, x])/(1485*(-1 + x)^17*(1 + x)^19) - 
      (8*x^3*(2970 - 11880*x + 185625*x^2 - 509850*x^3 + 3150675*x^4 - 
         5881095*x^5 + 19929690*x^6 - 25653276*x^7 + 54373374*x^8 - 
         48489540*x^9 + 68311914*x^10 - 41594916*x^11 + 39863670*x^12 - 
         15860460*x^13 + 10289400*x^14 - 2417360*x^15 + 1023770*x^16 - 
         108064*x^17 + 27401*x^18 - 10*x^19 + 11*x^20 + x^21)*HPL[{0, 0}, x])/
       (1485*(-1 + x)^20*(1 + x)^22) - 
      (4*(1 + 11*x - 7*x^2 + 704*x^3 - 1168*x^4 + 8624*x^5 - 10192*x^6 + 
         34496*x^7 - 27244*x^8 + 53900*x^9 - 27244*x^10 + 34496*x^11 - 
         10192*x^12 + 8624*x^13 - 1168*x^14 + 704*x^15 - 7*x^16 + 11*x^17 + 
         x^18)*HPL[{1, 0}, x])/(1485*(-1 + x)^17*(1 + x)^19))
 

CbarData["p", 2, -1] = NC*(CA*CF*((-11*lm^3*(1 - x + x^2))/18 + 
        lm^2*((-38*(1 - x + x^2))/9 + (11*x^3*HPL[{0}, x])/(3*(1 + x))) - 
        (304*x^3*HPL[{0, 0}, x])/(9*(1 + x)) + (88*x^3*HPL[{0, 0, 0}, x])/
         (3 + 3*x) - (x^3*HPL[{0}, x]*(-247 + 48*Zeta[3]))/(12*(1 + x)) + 
        lm*((152*x^3*HPL[{0}, x])/(9*(1 + x)) - (44*x^3*HPL[{0, 0}, x])/
           (3*(1 + x)) + ((1 - x + x^2)*(-247 + 48*Zeta[3]))/24) - 
        ((1 - x + x^2)*(88*Pi^4 + 480*Pi^2*Log[2]^2 - 
           15*(-749 + 32*Log[2]^4 + 768*PolyLog[4, 1/2] + 392*Zeta[3])))/
         1080) + CF^2*(-2*lm^3*(1 - x + x^2) + 
        lm^2*((-9*(1 - x + x^2))/4 + (12*x^3*HPL[{0}, x])/(1 + x)) - 
        (18*x^3*HPL[{0, 0}, x])/(1 + x) + (96*x^3*HPL[{0, 0, 0}, x])/
         (1 + x) + (x^3*HPL[{0}, x]*(-5 + 96*Zeta[3]))/(12*(1 + x)) + 
        lm*((9*x^3*HPL[{0}, x])/(1 + x) - (48*x^3*HPL[{0, 0}, x])/(1 + x) - 
          ((1 - x + x^2)*(-5 + 96*Zeta[3]))/24) + 
        ((1 - x + x^2)*(176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           15*(-139 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 1008*Zeta[3])))/
         1080) + CF*(NL*((lm^3*(1 - x + x^2))/9 - (5*x^3*HPL[{0}, x])/
           (2*(1 + x)) + lm^2*((5*(1 - x + x^2))/9 - (2*x^3*HPL[{0}, x])/
             (3*(1 + x))) + (40*x^3*HPL[{0, 0}, x])/(9*(1 + x)) + 
          lm*((5*(1 - x + x^2))/4 - (20*x^3*HPL[{0}, x])/(9*(1 + x)) + 
            (8*x^3*HPL[{0, 0}, x])/(3*(1 + x))) - (16*x^3*HPL[{0, 0, 0}, x])/
           (3 + 3*x) + ((1 - x + x^2)*(45 + 32*Zeta[3]))/36) + 
        NM*((lm^3*(1 - x + x^2))/9 - (x^2*(16 + 39*x)*HPL[{0}, x])/
           (6*(1 + x)) + lm^2*((5*(1 - x + x^2))/9 - (2*x^3*HPL[{0}, x])/
             (3*(1 + x))) + (4*x^2*(3 + 10*x)*HPL[{0, 0}, x])/(9*(1 + x)) + 
          lm*((5 - 5*x + 13*x^2)/4 - (20*x^3*HPL[{0}, x])/(9*(1 + x)) + 
            (8*x^3*HPL[{0, 0}, x])/(3*(1 + x))) - 
          (2*(4 - x + x^2)*HPL[{-1, 0, 0}, x])/3 - (16*x^3*HPL[{0, 0, 0}, x])/
           (3 + 3*x) - (2*(-4 + 3*x + x^3)*HPL[{1, 0, 0}, x])/(3*(1 + x)) + 
          (45 + 80*x^2 + x^3*(125 - 112*Zeta[3]) + 32*Zeta[3])/
           (36*(1 + x))) + NH*((lm^3*(1 - x + x^2))/9 - 
          (x*(8 + 15*x^2)*HPL[{0}, x])/(6*(1 + x)) + 
          lm^2*((5*(1 - x + x^2))/9 - (2*x^3*HPL[{0}, x])/(3*(1 + x))) + 
          (4*x*(3 + 10*x^2)*HPL[{0, 0}, x])/(9*(1 + x)) + 
          lm*((13 - 5*x + 5*x^2)/4 - (20*x^3*HPL[{0}, x])/(9*(1 + x)) + 
            (8*x^3*HPL[{0, 0}, x])/(3*(1 + x))) - 
          (2*(1 - x + 4*x^2)*HPL[{-1, 0, 0}, x])/3 - 
          ((2 + 6*x^2 - 8*x^3)*HPL[{1, 0, 0}, x])/(3 + 3*x) + 
          (125 + 80*x - 112*Zeta[3] + x^3*(45 + 32*Zeta[3]))/(36*(1 + x)))))
 
CbarData["p", 2, 0] = 
    NC*(CF^2*(lm^3/4 + (Pi^2*(1 + x^2)*HPL[{-2}, x])/(9*(1 + x)^2) + 
        lm^2*(-(7 + 2*x + 7*x^2)/(16*(1 + x)^2) - (3*x^3*(2 + x)*HPL[{0}, x])/
           (2*(-1 + x)*(1 + x)^3)) - (Pi^2*(1 + x^2)*HPL[{2}, x])/
         (9*(1 + x)^2) + (x^2*(6 - 12*x - 57*x^2 + 39*x^3 + 46*x^4 - 22*x^5 - 
           22*x^6 - x^7 + 5*x^8 + 2*x^9)*HPL[{-2, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) - 
        ((12 + 30*x + 12*x^2 + (181 - 12*Pi^2)*x^3 - 6*x^4 - 554*x^5 - 
           6*x^6 + (181 + 12*Pi^2)*x^7 + 12*x^8 + 30*x^9 + 12*x^10)*
          HPL[{-1, 0}, x])/(108*(-1 + x)*x^3*(1 + x)^3) + 
        (x^2*(-384 + 747*x + 99*x^2 + 1746*x^3 + 3923*x^4 + 15*x^6 + 6*x^7)*
          HPL[{0, 0}, x])/(27*(-1 + x)^2*(1 + x)^4) + 
        ((12 + 30*x + 12*x^2 + (181 - 12*Pi^2)*x^3 - 6*x^4 - 554*x^5 - 
           6*x^6 + (181 + 12*Pi^2)*x^7 + 12*x^8 + 30*x^9 + 12*x^10)*
          HPL[{1, 0}, x])/(108*(-1 + x)*x^3*(1 + x)^3) + 
        (x^2*(-6 + 12*x + 57*x^2 - 39*x^3 - 46*x^4 + 22*x^5 + 22*x^6 + x^7 - 
           5*x^8 - 2*x^9)*HPL[{2, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) - 
        (4*(1 + x^2)*HPL[{-2, -1, 0}, x])/(3*(1 + x)^2) + 
        (8*(1 + x^2)*HPL[{-2, 0, 0}, x])/(3*(1 + x)^2) + 
        (4*(1 + x^2)*HPL[{-2, 1, 0}, x])/(3*(1 + x)^2) + 
        (4*(1 + x^2)*HPL[{-1, -2, 0}, x])/(3*(1 + x)^2) + 
        ((2 + x - x^2 - 11*x^3 + 5*x^4 - 5*x^6 + 11*x^7 + x^8 - x^9 - 2*x^10)*
          HPL[{-1, -1, 0}, x])/(18*x^5) + 
        ((-56 + 85*x - 39*x^2 - 3*x^3 + 3*x^4 + 9*x^5 - 13*x^6 - 5*x^7 + 
           x^8 + 2*x^9)*HPL[{-1, 0, 0}, x])/(9*(-1 + x^2)^2) + 
        ((-2 - x + x^2 + 11*x^3 - 5*x^4 + 5*x^6 - 11*x^7 - x^8 + x^9 + 
           2*x^10)*HPL[{-1, 1, 0}, x])/(18*x^5) - 
        (4*(1 + x^2)*HPL[{-1, 2, 0}, x])/(3*(1 + x)^2) - 
        (2*x^2*(-3 + 366*x + 309*x^2 - 828*x^3 - 1415*x^4 + 652*x^5 + 
           1155*x^6 - 21*x^7 - 27*x^8 - 3*x^9 + 5*x^10 + 2*x^11)*
          HPL[{0, 0, 0}, x])/(9*(-1 + x)^3*(1 + x)^5) - 
        (4*(1 + x^2)*HPL[{1, -2, 0}, x])/(3*(1 + x)^2) + 
        ((-2 - x + x^2 + 11*x^3 - 5*x^4 + 5*x^6 - 11*x^7 - x^8 + x^9 + 
           2*x^10)*HPL[{1, -1, 0}, x])/(18*x^5) + 
        ((56 + 91*x + 51*x^2 + 39*x^3 + 69*x^4 + 39*x^5 + x^6 - 15*x^7 - 
           9*x^8 - 2*x^9)*HPL[{1, 0, 0}, x])/(9*(1 + x)^4) + 
        ((2 + x - x^2 - 11*x^3 + 5*x^4 - 5*x^6 + 11*x^7 + x^8 - x^9 - 2*x^10)*
          HPL[{1, 1, 0}, x])/(18*x^5) + (4*(1 + x^2)*HPL[{1, 2, 0}, x])/
         (3*(1 + x)^2) + (4*(1 + x^2)*HPL[{2, -1, 0}, x])/(3*(1 + x)^2) - 
        (8*(1 + x^2)*HPL[{2, 0, 0}, x])/(3*(1 + x)^2) - 
        (4*(1 + x^2)*HPL[{2, 1, 0}, x])/(3*(1 + x)^2) + 
        (8*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/(3*(1 + x)^2) + 
        (8*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/(3*(1 + x)^2) + 
        ((-1 + 3*x + x^2 + x^3)*master3l10a[x])/(12*(-1 + x)*(1 + x)^3) + 
        (x*(-1 - x - 3*x^2 + x^3)*master3l10b[x])/(12*(-1 + x)*(1 + x)^3) - 
        ((-11 + 6*x + x^2)*master3l8a[x])/(12*(-1 + x)^2*(1 + x)^4) + 
        ((5 - 18*x - 39*x^2)*master3l8b[x])/(36*(-1 + x)^2*(1 + x)^4) - 
        ((-9 + x^2)*master3l9a[x])/(3*(-1 + x)^2*(1 + x)^4) + 
        ((1 - 9*x^2)*master3l9b[x])/(9*(-1 + x)^2*(1 + x)^4) + 
        (HPL[{-1}, x]*(Pi^2*(1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 
             11*x^6 - x^8 + 2*x^9) + 288*x^5*(1 + x^2)*Zeta[3]))/
         (216*x^5*(1 + x)^2) - (HPL[{1}, x]*(Pi^2*(1 + x)^3*
            (-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 11*x^6 - x^8 + 2*x^9) + 
           288*x^5*(1 + x^2)*Zeta[3]))/(216*x^5*(1 + x)^2) + 
        (HPL[{0}, x]*(24 + 60*x + 12*x^2 - 4*(-2947 + 6*Pi^2)*x^3 + 
           8*(-3 + 11*Pi^2)*x^8 + 88*Pi^2*x^9 + 4*Pi^2*x^10 - 20*Pi^2*x^11 - 
           8*Pi^2*x^12 + 6*x^4*(-2283 + 8*Pi^2 + 576*Zeta[3]) - 
           6*x^6*(1499 + 26*Pi^2 + 576*Zeta[3]) - x^7*(21885 + 184*Pi^2 + 
             1728*Zeta[3]) + x^5*(-12643 + 228*Pi^2 + 1728*Zeta[3])))/
         (432*(-1 + x)^2*x*(1 + x)^4) + 
        lm*((x^2*(-4 + 2*x + 7*x^2)*HPL[{0}, x])/(4*(-1 + x)*(1 + x)^3) + 
          ((1 - x)*HPL[{-1, 0}, x])/(1 + x) + 
          (4*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
           ((-1 + x)^2*(1 + x)^4) + ((-1 + x)*HPL[{1, 0}, x])/(1 + x) + 
          (-95 + 8*Pi^2*(-1 + x^2) + 144*Zeta[3] + x^2*(-95 + 144*Zeta[3]) + 
            x*(-82 + 288*Zeta[3]))/(96*(1 + x)^2)) + 
        (-24*Pi^4*x^3*(-1 + x^2)^2*(39 + 88*x + 39*x^2) + 
          10*Pi^2*(-1 + x^2)*(12 + 30*x + 12*x^2 - 554*x^5 + 12*x^8 + 
            30*x^9 + 12*x^10 + x^7*(181 - 576*Log[2]^2) + 
            6*x^4*(-1 + 192*Log[2]^2) - 6*x^6*(1 + 192*Log[2]^2) + 
            x^3*(181 + 576*Log[2]^2)) + 15*x^2*(-12 - 528*x^9*Zeta[3] - 
            24*x^10*Zeta[3] + 120*x^11*Zeta[3] + 48*x^12*Zeta[3] - 
            12*x^8*(1 + 44*Zeta[3]) + 3*x^2*(377 + 256*Log[2]^4 + 
              6144*PolyLog[4, 1/2] + 4072*Zeta[3]) - 
            6*x^4*(-2927 + 256*Log[2]^4 + 6144*PolyLog[4, 1/2] + 
              4192*Zeta[3]) + 3*x^6*(377 + 256*Log[2]^4 + 6144*PolyLog[4, 
                1/2] + 4384*Zeta[3]) - x^3*(10405 + 384*Log[2]^4 + 
              9216*PolyLog[4, 1/2] + 6288*Zeta[3]) - 
            x^5*(-17675 + 384*Log[2]^4 + 9216*PolyLog[4, 1/2] + 
              6504*Zeta[3]) + x*(-14255 + 384*Log[2]^4 + 9216*PolyLog[4, 
                1/2] + 9096*Zeta[3]) + x^7*(6625 + 384*Log[2]^4 + 
              9216*PolyLog[4, 1/2] + 9768*Zeta[3])))/(12960*(-1 + x)^2*x^3*
          (1 + x)^4)) + CA*CF*((11*lm^3)/72 - (Pi^2*(1 + x^2)*HPL[{-2}, x])/
         (18*(1 + x)^2) + lm^2*((119 + 304*x + 119*x^2)/(144*(1 + x)^2) - 
          (11*x^3*(2 + x)*HPL[{0}, x])/(12*(-1 + x)*(1 + x)^3)) + 
        (Pi^2*(1 + x^2)*HPL[{2}, x])/(18*(1 + x)^2) + 
        (x^2*(-6 + 6*x + 42*x^2 - 21*x^3 - 31*x^4 + 6*x^5 + 9*x^6 + 3*x^7)*
          HPL[{-2, 0}, x])/(18*(-1 + x)^2*(1 + x)^4) + 
        ((-6 - (161 + 4*Pi^2)*x + 12*x^2 + 294*x^3 + 12*x^4 + 
           (-161 + 4*Pi^2)*x^5 - 6*x^6)*HPL[{-1, 0}, x])/
         (72*(-1 + x)*x*(1 + x)^3) + (x^2*(326 - 1666*x - 711*x^2 - 598*x^3 - 
           2229*x^4 + 6*x^5)*HPL[{0, 0}, x])/(36*(-1 + x)^2*(1 + x)^4) + 
        ((6 + (161 + 4*Pi^2)*x - 12*x^2 - 294*x^3 - 12*x^4 + 
           (161 - 4*Pi^2)*x^5 + 6*x^6)*HPL[{1, 0}, x])/
         (72*(-1 + x)*x*(1 + x)^3) - (x^2*(-6 + 6*x + 42*x^2 - 21*x^3 - 
           31*x^4 + 6*x^5 + 9*x^6 + 3*x^7)*HPL[{2, 0}, x])/
         (18*(-1 + x)^2*(1 + x)^4) + (2*(1 + x^2)*HPL[{-2, -1, 0}, x])/
         (3*(1 + x)^2) - (8*x^2*HPL[{-2, 0, 0}, x])/(3*(1 + x)^2) - 
        (2*(1 + x^2)*HPL[{-2, 1, 0}, x])/(3*(1 + x)^2) - 
        (2*(1 + x^2)*HPL[{-1, -2, 0}, x])/(3*(1 + x)^2) + 
        ((3 + 6*x + 6*x^2 - 41*x^3 + 41*x^4 - 6*x^5 - 6*x^6 - 3*x^7)*
          HPL[{-1, -1, 0}, x])/(36*x^3*(1 + x)) + 
        ((67 - 101*x + 93*x^2 - 107*x^3 + 61*x^4 - 3*x^5 + 3*x^6 + 3*x^7)*
          HPL[{-1, 0, 0}, x])/(18*(-1 + x^2)^2) + 
        ((-3 - 6*x - 6*x^2 + 41*x^3 - 41*x^4 + 6*x^5 + 6*x^6 + 3*x^7)*
          HPL[{-1, 1, 0}, x])/(36*x^3*(1 + x)) + 
        (2*(1 + x^2)*HPL[{-1, 2, 0}, x])/(3*(1 + x)^2) + 
        (x^2*(-9 + 330*x + 72*x^2 + 366*x^3 + 907*x^4 - 6*x^5 - 9*x^6 - 
           3*x^7)*HPL[{0, 0, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) + 
        (2*(1 + x^2)*HPL[{1, -2, 0}, x])/(3*(1 + x)^2) + 
        ((-3 - 6*x - 6*x^2 + 41*x^3 - 41*x^4 + 6*x^5 + 6*x^6 + 3*x^7)*
          HPL[{1, -1, 0}, x])/(36*x^3*(1 + x)) - 
        ((67 + 119*x + 129*x^2 + 149*x^3 + 109*x^4 + 33*x^5 + 15*x^6 + 3*x^7)*
          HPL[{1, 0, 0}, x])/(18*(1 + x)^4) + 
        ((3 + 6*x + 6*x^2 - 41*x^3 + 41*x^4 - 6*x^5 - 6*x^6 - 3*x^7)*
          HPL[{1, 1, 0}, x])/(36*x^3*(1 + x)) - 
        (2*(1 + x^2)*HPL[{1, 2, 0}, x])/(3*(1 + x)^2) - 
        (2*(1 + x^2)*HPL[{2, -1, 0}, x])/(3*(1 + x)^2) + 
        (8*x^2*HPL[{2, 0, 0}, x])/(3*(1 + x)^2) + 
        (2*(1 + x^2)*HPL[{2, 1, 0}, x])/(3*(1 + x)^2) + 
        (4*(-1 + x)*HPL[{-1, 0, 0, 0}, x])/(3*(1 + x)) - 
        (4*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/(3*(1 + x)^2) - 
        (4*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/(3*(1 + x)^2) + 
        ((4 - 4*x)*HPL[{1, 0, 0, 0}, x])/(3 + 3*x) - 
        ((-1 + 3*x + x^2 + x^3)*master3l10a[x])/(24*(-1 + x)*(1 + x)^3) + 
        ((x + x^2 + 3*x^3 - x^4)*master3l10b[x])/(24*(-1 + x)*(1 + x)^3) + 
        ((-11 + 6*x + x^2)*master3l8a[x])/(24*(-1 + x)^2*(1 + x)^4) + 
        ((-5 + 18*x + 39*x^2)*master3l8b[x])/(72*(-1 + x)^2*(1 + x)^4) + 
        ((-9 + x^2)*master3l9a[x])/(6*(-1 + x)^2*(1 + x)^4) + 
        ((-1 + 9*x^2)*master3l9b[x])/(18*(-1 + x)^2*(1 + x)^4) + 
        (HPL[{-1}, x]*(Pi^2*(-3 - 9*x - 12*x^2 + 35*x^3 - 35*x^5 + 12*x^6 + 
             9*x^7 + 3*x^8) - 288*x^3*(1 + x^2)*Zeta[3]))/
         (432*x^3*(1 + x)^2) + (HPL[{1}, x]*
          (Pi^2*(3 + 9*x + 12*x^2 - 35*x^3 + 35*x^5 - 12*x^6 - 9*x^7 - 
             3*x^8) + 288*x^3*(1 + x^2)*Zeta[3]))/(432*x^3*(1 + x)^2) + 
        (x*HPL[{0}, x]*(18 + 12*(-426 + Pi^2)*x - 12*Pi^2*x^6 - 18*Pi^2*x^7 - 
           6*Pi^2*x^8 + x^3*(6345 - 84*Pi^2 - 864*Zeta[3]) - 
           6*x^2*(-1905 + 2*Pi^2 + 288*Zeta[3]) + 6*x^4*(-18 + 7*Pi^2 + 
             288*Zeta[3]) + x^5*(10107 + 62*Pi^2 + 864*Zeta[3])))/
         (432*(-1 + x)^2*(1 + x)^4) + 
        (8*Pi^4*x*(-1 + x^2)^2*(47 + 88*x + 31*x^2) + 10*Pi^2*(-1 + x^2)*
           (6 - 294*x^3 + 6*x^6 + x*(161 - 192*Log[2]^2) + 
            12*x^4*(-1 + 32*Log[2]^2) - 12*x^2*(1 + 32*Log[2]^2) + 
            x^5*(161 + 192*Log[2]^2)) + 15*x*(5269 - 128*Log[2]^4 - 
            3072*PolyLog[4, 1/2] - 2256*Zeta[3] + 48*x^7*Zeta[3] + 
            72*x^8*Zeta[3] + 24*x^9*Zeta[3] + 16*x^3*(-878 + 32*Log[2]^4 + 
              768*PolyLog[4, 1/2] + 415*Zeta[3]) - 4*x*(-931 + 64*Log[2]^4 + 
              1536*PolyLog[4, 1/2] + 806*Zeta[3]) - 
            4*x^5*(-931 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 848*Zeta[3]) + 
            x^2*(2951 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 1096*Zeta[3]) + 
            x^4*(-6409 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 
              2008*Zeta[3]) - x^6*(1691 + 128*Log[2]^4 + 3072*PolyLog[4, 
                1/2] + 2680*Zeta[3])))/(8640*(-1 + x)^2*x*(1 + x)^4) + 
        lm*(-(x^2*(22 + 304*x + 119*x^2)*HPL[{0}, x])/(36*(-1 + x)*
            (1 + x)^3) - (11*(-1 + x)*HPL[{-1, 0}, x])/(18*(1 + x)) + 
          (22*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
           (9*(-1 + x)^2*(1 + x)^4) + (11*(-1 + x)*HPL[{1, 0}, x])/
           (18*(1 + x)) + (44*Pi^2*(-1 + x^2) - 9*(-137 + 72*Zeta[3] + 
              2*x*(-275 + 72*Zeta[3]) + x^2*(-137 + 72*Zeta[3])))/
           (864*(1 + x)^2))) + 
      CF*(NH*(-lm^3/36 + (x*(48 + 472*x + 2985*x^2 + 1552*x^3 - 807*x^4 - 
             521*x^5 + 102*x^6 + 49*x^7)*HPL[{0}, x])/(36*(-1 + x)^3*
            (1 + x)^5) + lm^2*(-(7 + 20*x + 7*x^2)/(72*(1 + x)^2) + 
            (x^3*(2 + x)*HPL[{0}, x])/(6*(-1 + x)*(1 + x)^3)) - 
          (x*(24 + 136*x + 1016*x^2 + 523*x^3 - 378*x^4 - 208*x^5 + 58*x^6 + 
             29*x^7)*HPL[{0, 0}, x])/(18*(-1 + x)^3*(1 + x)^5) + 
          lm*(-(4*Pi^2*(-1 + x^2) + 9*(9 + 38*x + 9*x^2))/(432*(1 + x)^2) + 
            (x^2*(2 + 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x)*(1 + x)^3) + 
            ((-1 + x)*HPL[{-1, 0}, x])/(9*(1 + x)) - 
            (4*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
             (9*(-1 + x)^2*(1 + x)^4) + ((1 - x)*HPL[{1, 0}, x])/(9 + 9*x)) + 
          ((2 - 43*x - 12*x^2 + 5*x^3 + 8*x^4)*HPL[{-1, 0, 0}, x])/
           (9*(-1 + x^2)^2) - (2*x^3*(-54 - 33*x + 6*x^2 + x^5)*
            HPL[{0, 0, 0}, x])/(9*(-1 + x)^3*(1 + x)^5) - 
          ((14 - 5*x + 19*x^3 + 8*x^4)*HPL[{1, 0, 0}, x])/(9*(1 + x)^4) + 
          ((9 + 54*x + 28*x^2 - 6*x^3 - 5*x^4)*master3l8a[x])/
           (18*(-1 + x)^3*(1 + x)^5) + ((27 + 108*x + 51*x^2 - 12*x^3 - 
             15*x^4 + x^6)*master3l9a[x])/(18*(-1 + x)^3*(1 + x)^5) + 
          (x^5*(7671 - 768*Zeta[3]) + 39*(-99 + 32*Zeta[3]) - 
            4*x^8*(113 + 32*Zeta[3]) + 3*x^3*(-6687 + 64*Zeta[3]) - 
            3*x^7*(309 + 64*Zeta[3]) - 3*x^4*(3253 + 96*Zeta[3]) + 
            3*x*(-5641 + 256*Zeta[3]) + x^6*(4517 + 320*Zeta[3]) - 
            3*x^2*(3535 + 384*Zeta[3]))/(432*(-1 + x)^3*(1 + x)^5)) + 
        NM*(-lm^3/36 + ((2*Pi^2*(-1 + x^2)^4 + 3*(38 - 219*x^2 + 9*x^3 - 188*
                x^4 + 459*x^5 + 1030*x^6 + 1860*x^7 + 891*x^8))*HPL[{0}, x])/
           (108*(-1 + x)^3*(1 + x)^5) + lm^2*(-(7 + 20*x + 7*x^2)/
             (72*(1 + x)^2) + (x^3*(2 + x)*HPL[{0}, x])/(6*(-1 + x)*
              (1 + x)^3)) + ((2 - 2*x)*HPL[{-2, 0}, x])/(9 + 9*x) - 
          ((12 + 14*x^2 + 32*x^3 - 601*x^4 - 30*x^5 + 978*x^6 + 2446*x^7 + 
             1229*x^8)*HPL[{0, 0}, x])/(18*(-1 + x)^3*(1 + x)^5) + 
          lm*(-(4*Pi^2*(-1 + x^2) + 9*(9 + 38*x + 9*x^2))/(432*(1 + x)^2) + 
            (x^2*(2 + 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x)*(1 + x)^3) + 
            ((-1 + x)*HPL[{-1, 0}, x])/(9*(1 + x)) - 
            (4*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
             (9*(-1 + x)^2*(1 + x)^4) + ((1 - x)*HPL[{1, 0}, x])/(9 + 9*x)) + 
          (2*(-1 + x)*HPL[{2, 0}, x])/(9*(1 + x)) - 
          ((-12 + 3*x + 12*x^2 + 35*x^3 + 2*x^4)*HPL[{-1, 0, 0}, x])/
           (9*(-1 + x^2)^2) + (2*(1 + 28*x^2 + 30*x^3 - 243*x^4 - 138*x^5 + 
             332*x^6 + 1020*x^7 + 490*x^8)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x)^3*(1 + x)^5) - ((12 + 27*x - 13*x^3 + 10*x^4)*
            HPL[{1, 0, 0}, x])/(9*(1 + x)^4) + 
          ((2 - 15*x^2 - 6*x^3 + 18*x^4 + 54*x^5 + 27*x^6)*master3l8b[x])/
           (54*(-1 + x)^3*x^2*(1 + x)^5) + ((1 - 15*x^2 - 12*x^3 + 51*x^4 + 
             108*x^5 + 27*x^6)*master3l9b[x])/(54*(-1 + x)^3*x^2*(1 + x)^5) + 
          (15 - 156*x^10*(9 + 8*Zeta[3]) + 3*x^3*(249 + 64*Zeta[3]) - 
            3*x^7*(1173 + 64*Zeta[3]) + 12*x^8*(-485 + 96*Zeta[3]) + 
            3*x^6*(283 + 96*Zeta[3]) + x^2*(-13 + 128*Zeta[3]) - 
            3*x^9*(1379 + 256*Zeta[3]) - x^4*(347 + 320*Zeta[3]) + 
            x^5*(-3171 + 768*Zeta[3]))/(432*(-1 + x)^3*x^2*(1 + x)^5)) + 
        NL*(-lm^3/36 + (Pi^2*(-1 + x)*HPL[{-1}, x])/(54*(1 + x)) + 
          (x^2*(-84 + 6*(-57 + 4*Pi^2)*x + 3*(1 + 4*Pi^2)*x^2 + 342*x^3 + 
             (81 - 4*Pi^2)*x^4)*HPL[{0}, x])/(216*(-1 + x)^2*(1 + x)^4) + 
          lm^2*(-(7 + 20*x + 7*x^2)/(72*(1 + x)^2) + 
            (x^3*(2 + x)*HPL[{0}, x])/(6*(-1 + x)*(1 + x)^3)) - 
          (Pi^2*(-1 + x)*HPL[{1}, x])/(54*(1 + x)) + 
          (2*x^3*(-6 - 3*x + x^3)*HPL[{-2, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) + 
          ((7 + 6*x - 10*x^2 + 6*x^3 + 7*x^4)*HPL[{-1, 0}, x])/
           (18*(-1 + x)*(1 + x)^3) + (2*x^3*(20 + 10*x - 13*x^2 - 7*x^3)*
            HPL[{0, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) - 
          ((7 + 6*x - 10*x^2 + 6*x^3 + 7*x^4)*HPL[{1, 0}, x])/
           (18*(-1 + x)*(1 + x)^3) + 
          lm*(-(4*Pi^2*(-1 + x^2) + 9*(9 + 38*x + 9*x^2))/(432*(1 + x)^2) + 
            (x^2*(2 + 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x)*(1 + x)^3) + 
            ((-1 + x)*HPL[{-1, 0}, x])/(9*(1 + x)) - 
            (4*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
             (9*(-1 + x)^2*(1 + x)^4) + ((1 - x)*HPL[{1, 0}, x])/(9 + 9*x)) - 
          (2*x^3*(-6 - 3*x + x^3)*HPL[{2, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) + 
          ((2 - 2*x)*HPL[{-1, -1, 0}, x])/(9 + 9*x) + 
          (2*(-1 + x)*HPL[{-1, 1, 0}, x])/(9*(1 + x)) + 
          (8*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x)^2*(1 + x)^4) + (2*(-1 + x)*HPL[{1, -1, 0}, x])/
           (9*(1 + x)) + ((2 - 2*x)*HPL[{1, 1, 0}, x])/(9 + 9*x) - 
          (4*Pi^2*(-7 - 6*x + 17*x^2 - 17*x^4 + 6*x^5 + 7*x^6) + 
            3*(73 + 96*Zeta[3] + 8*x*(41 + 16*Zeta[3]) + 8*x^5*(41 + 
                16*Zeta[3]) - 16*x^3*(41 + 28*Zeta[3]) - x^4*(73 + 
                64*Zeta[3]) + x^6*(73 + 64*Zeta[3]) - x^2*(73 + 
                160*Zeta[3])))/(864*(-1 + x)^2*(1 + x)^4))))
 
CbarData["p", 2, 1] = 
    NC*(CA*CF*((Pi^2*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2}, x])/
         (27*(-1 + x)^2*(1 + x)^4) - (Pi^2*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{2}, x])/(27*(-1 + x)^2*(1 + x)^4) + 
        (x^2*(18 + 36*x + 54*x^2 - 309*x^3 - 96*x^4 + 171*x^5 + 134*x^6 - 
           27*x^7 - 78*x^8 - 15*x^9 + 20*x^10 + 8*x^11)*HPL[{-2, 0}, x])/
         (27*(-1 + x)^4*(1 + x)^6) + 
        ((-24 - 60*x + 9*x^2 + (293 + 6*Pi^2)*x^3 + 2*(374 + 9*Pi^2)*x^4 - 
           (311 + 30*Pi^2)*x^5 - 1058*x^6 + (-311 + 30*Pi^2)*x^7 + 
           (748 - 18*Pi^2)*x^8 + (293 - 6*Pi^2)*x^9 + 9*x^10 - 60*x^11 - 
           24*x^12)*HPL[{-1, 0}, x])/(162*(-1 + x)^3*x^3*(1 + x)^5) + 
        (x^2*(486 - 84942*x + 37827*x^2 + 699990*x^3 - 298536*x^4 + 
           978312*x^5 + 1600633*x^6 - 160972*x^7 - 462668*x^8 + 10686*x^9 + 
           22362*x^10 - 4530*x^11 + 1080*x^12 + 432*x^13)*HPL[{0, 0}, x])/
         (162*(-1 + x)^4*(1 + x)^6*(9 - 82*x^2 + 9*x^4)) + 
        ((24 + 60*x - 9*x^2 - (293 + 6*Pi^2)*x^3 - 2*(374 + 9*Pi^2)*x^4 + 
           (311 + 30*Pi^2)*x^5 + 1058*x^6 + (311 - 30*Pi^2)*x^7 + 
           2*(-374 + 9*Pi^2)*x^8 + (-293 + 6*Pi^2)*x^9 - 9*x^10 + 60*x^11 + 
           24*x^12)*HPL[{1, 0}, x])/(162*(-1 + x)^3*x^3*(1 + x)^5) + 
        lm*((-11*(4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) - 3*(1 + 36*x - 22*x^2 + 36*
                x^3 + x^4)))/(1296*(-1 + x)^2*(1 + x)^4) + 
          (11*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x)^3*(1 + x)^5) + 
          (11*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x)*(1 + x)^3) - 
          (22*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
           (27*(-1 + x)^4*(1 + x)^6) - (11*(1 + 3*x + x^2)*HPL[{1, 0}, x])/
           (27*(-1 + x)*(1 + x)^3)) - (x^2*(18 + 36*x + 54*x^2 - 309*x^3 - 
           96*x^4 + 171*x^5 + 134*x^6 - 27*x^7 - 78*x^8 - 15*x^9 + 20*x^10 + 
           8*x^11)*HPL[{2, 0}, x])/(27*(-1 + x)^4*(1 + x)^6) - 
        (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2, -1, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) + (16*x^2*(-2 + 3*x + x^2)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) + 
        (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2, 1, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) + (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) - 
        ((8 + 20*x + 9*x^2 - 18*x^3 - 24*x^4 + 42*x^5 + 146*x^6 + 42*x^7 - 
           24*x^8 - 18*x^9 + 9*x^10 + 20*x^11 + 8*x^12)*HPL[{-1, -1, 0}, x])/
         (54*(-1 + x)*x^5*(1 + x)^3) - ((51 + x - 179*x^2 + 152*x^3 - 
           119*x^4 + 28*x^5 + 7*x^6 - 44*x^7 + 20*x^8 + 31*x^9 - 4*x^10 - 
           8*x^11)*HPL[{-1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        ((8 + 20*x + 9*x^2 - 18*x^3 - 24*x^4 + 42*x^5 + 146*x^6 + 42*x^7 - 
           24*x^8 - 18*x^9 + 9*x^10 + 20*x^11 + 8*x^12)*HPL[{-1, 1, 0}, x])/
         (54*(-1 + x)*x^5*(1 + x)^3) - (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) - 
        (2*x^2*(27 - 5049*x + 2679*x^2 + 34182*x^3 - 35826*x^4 + 123906*x^5 + 
           208865*x^6 - 30821*x^7 - 72525*x^8 + 3906*x^9 + 12030*x^10 + 
           1059*x^11 - 2342*x^12 - 791*x^13 + 180*x^14 + 72*x^15)*
          HPL[{0, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^6*(9 - 82*x^2 + 9*x^4)) - 
        (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{1, -2, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) + ((8 + 20*x + 9*x^2 - 18*x^3 - 24*x^4 + 
           42*x^5 + 146*x^6 + 42*x^7 - 24*x^8 - 18*x^9 + 9*x^10 + 20*x^11 + 
           8*x^12)*HPL[{1, -1, 0}, x])/(54*(-1 + x)*x^5*(1 + x)^3) + 
        ((51 + 157*x - 7*x^2 - 200*x^3 - 99*x^4 + 120*x^5 + 139*x^6 + 
           108*x^7 + 16*x^8 - 49*x^9 - 36*x^10 - 8*x^11)*HPL[{1, 0, 0}, x])/
         (27*(-1 + x)^2*(1 + x)^6) - ((8 + 20*x + 9*x^2 - 18*x^3 - 24*x^4 + 
           42*x^5 + 146*x^6 + 42*x^7 - 24*x^8 - 18*x^9 + 9*x^10 + 20*x^11 + 
           8*x^12)*HPL[{1, 1, 0}, x])/(54*(-1 + x)*x^5*(1 + x)^3) + 
        (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{1, 2, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) + (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) - 
        (16*x^2*(-2 + 3*x + x^2)*HPL[{2, 0, 0}, x])/(9*(-1 + x)^2*
          (1 + x)^4) - (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{2, 1, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) - (8*(1 + 3*x + x^2)*HPL[{-1, 0, 0, 0}, x])/
         (9*(-1 + x)*(1 + x)^3) + (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) + 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{1, -1, 0, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) + (8*(1 + 3*x + x^2)*HPL[{1, 0, 0, 0}, x])/
         (9*(-1 + x)*(1 + x)^3) - ((2 + 7*x - 8*x^2 + 12*x^3 + 2*x^4 + x^5)*
          master3l10a[x])/(36*(-1 + x)^3*(1 + x)^5) + 
        (x*(1 + 2*x + 12*x^2 - 8*x^3 + 7*x^4 + 2*x^5)*master3l10b[x])/
         (36*(-1 + x)^3*(1 + x)^5) + ((-81 - 819*x + 795*x^2 - 264*x^3 - 
           129*x^4 + 43*x^5 + 7*x^6)*master3l8a[x])/(108*(-1 + x)^4*(1 + x)^6*
          (-9 + x^2)) + ((15 - 31*x - 169*x^2 + 384*x^3 + 903*x^4 - 81*x^5 - 
           189*x^6)*master3l8b[x])/(108*(-1 + x)^4*(1 + x)^6*(-1 + 9*x^2)) + 
        ((-135 - 450*x + 849*x^2 + 60*x^3 - 149*x^4 + 6*x^5 + 11*x^6)*
          master3l9a[x])/(36*(-1 + x)^4*(1 + x)^6*(-9 + x^2)) + 
        ((11 + 6*x - 149*x^2 + 60*x^3 + 849*x^4 - 450*x^5 - 135*x^6)*
          master3l9b[x])/(108*(-1 + x)^4*(1 + x)^6*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(8 + 20*x + x^2 - 38*x^3 - 33*x^4 + 60*x^5 + 
             170*x^6 - 170*x^8 - 60*x^9 + 33*x^10 + 38*x^11 - x^12 - 
             20*x^13 - 8*x^14) - 288*x^5*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
            Zeta[3]))/(648*(-1 + x)^2*x^5*(1 + x)^4) + 
        (HPL[{-1}, x]*(Pi^2*(-8 - 20*x - x^2 + 38*x^3 + 33*x^4 - 60*x^5 - 
             170*x^6 + 170*x^8 + 60*x^9 - 33*x^10 - 38*x^11 + x^12 + 
             20*x^13 + 8*x^14) + 288*x^5*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
            Zeta[3]))/(648*(-1 + x)^2*x^5*(1 + x)^4) + 
        (HPL[{0}, x]*(432 + 1080*x - 4314*x^2 - 12*(2230 + 27*Pi^2)*x^3 + 
           (27611 + 1980*Pi^2)*x^5 + 12*(30898 + 855*Pi^2)*x^7 - 
           2*(1238827 + 9564*Pi^2)*x^9 + 4*(198036 + 6277*Pi^2)*x^11 - 
           6*(6463 + 1206*Pi^2)*x^12 - 3*(19359 + 5188*Pi^2)*x^13 - 
           6*(72 + 353*Pi^2)*x^14 + 4684*Pi^2*x^15 + 1582*Pi^2*x^16 - 
           360*Pi^2*x^17 - 144*Pi^2*x^18 - 6*x^4*(-25021 + 108*Pi^2 + 
             3888*Zeta[3]) + 6*x^10*(98447 + 5682*Pi^2 + 3888*Zeta[3]) + 
           2*x^6*(-651148 + 5733*Pi^2 + 117936*Zeta[3]) - 
           2*x^8*(866990 + 27201*Pi^2 + 117936*Zeta[3])))/
         (648*(-1 + x)^4*x*(1 + x)^6*(9 - 82*x^2 + 9*x^4)) + 
        (48*Pi^4*x^3*(-1 + x^2)^2*(-27 - 81*x + 66*x^2 + 1089*x^3 + 
            1730*x^4 - 3279*x^5 - 1246*x^6 + 351*x^7 + 117*x^8) + 
          40*Pi^2*(-216 - 540*x + 2265*x^2 + 8097*x^3 + 3729*x^4 - 
            34922*x^5 - 76555*x^6 + 52705*x^7 + 170997*x^8 - 170997*x^10 - 
            52705*x^11 + 76555*x^12 + 34922*x^13 - 3729*x^14 - 8097*x^15 - 
            2265*x^16 + 540*x^17 + 216*x^18) + 
          15*x^2*(-864 + x^6*(9692024 - 1586256*Zeta[3]) + 
            x^3*(1308406 - 378720*Zeta[3]) - 112416*x^15*Zeta[3] - 
            37968*x^16*Zeta[3] + 8640*x^17*Zeta[3] + 3456*x^18*Zeta[3] + 
            144*x^14*(-6 + 353*Zeta[3]) + 45*x*(-1817 + 576*Zeta[3]) - 
            48*x^2*(6253 + 639*Zeta[3]) + 48*x^12*(4817 + 3573*Zeta[3]) + 
            45*x^13*(1891 + 9088*Zeta[3]) + 24*x^4*(71881 + 18430*Zeta[3]) - 
            24*x^10*(102719 + 30698*Zeta[3]) + 8*x^8*(394483 + 
              110994*Zeta[3]) + 4*x^7*(-68983 + 179304*Zeta[3]) + 
            3*x^5*(-1590085 + 402432*Zeta[3]) - 2*x^11*(588157 + 
              547344*Zeta[3]) + 3*x^9*(1297295 + 632192*Zeta[3])))/
         (77760*(-1 + x)^4*x^3*(1 + x)^6*(9 - 82*x^2 + 9*x^4))) + 
      CF^2*((-2*Pi^2*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2}, x])/
         (27*(-1 + x)^2*(1 + x)^4) + (2*Pi^2*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{2}, x])/(27*(-1 + x)^2*(1 + x)^4) + 
        (x^2*(-36 - 24*x - 132*x^2 + 786*x^3 + 204*x^4 - 658*x^5 - 486*x^6 + 
           337*x^7 + 519*x^8 - 23*x^9 - 285*x^10 - 73*x^11 + 63*x^12 + 
           27*x^13)*HPL[{-2, 0}, x])/(27*(-1 + x)^4*(1 + x)^6) + 
        ((-108 - 252*x + 130*x^2 + 762*x^3 + 332*x^4 - (735 + 16*Pi^2)*x^5 - 
           2*(107 + 24*Pi^2)*x^6 + (531 + 80*Pi^2)*x^7 - 1768*x^8 + 
           (531 - 80*Pi^2)*x^9 + (-214 + 48*Pi^2)*x^10 + (-735 + 16*Pi^2)*
            x^11 + 332*x^12 + 762*x^13 + 130*x^14 - 252*x^15 - 108*x^16)*
          HPL[{-1, 0}, x])/(216*(-1 + x)^3*x^5*(1 + x)^5) + 
        (x^2*(-2412 + 69444*x - 22538*x^2 - 539634*x^3 + 286706*x^4 - 
           1311030*x^5 - 2100677*x^6 + 323352*x^7 + 561810*x^8 - 4856*x^9 + 
           47481*x^10 + 18670*x^11 - 29790*x^12 - 10998*x^13 + 2268*x^14 + 
           972*x^15)*HPL[{0, 0}, x])/(108*(-1 + x)^4*(1 + x)^6*
          (9 - 82*x^2 + 9*x^4)) + ((108 + 252*x - 130*x^2 - 762*x^3 - 
           332*x^4 + (735 + 16*Pi^2)*x^5 + (214 + 48*Pi^2)*x^6 - 
           (531 + 80*Pi^2)*x^7 + 1768*x^8 + (-531 + 80*Pi^2)*x^9 + 
           (214 - 48*Pi^2)*x^10 + (735 - 16*Pi^2)*x^11 - 332*x^12 - 
           762*x^13 - 130*x^14 + 252*x^15 + 108*x^16)*HPL[{1, 0}, x])/
         (216*(-1 + x)^3*x^5*(1 + x)^5) + 
        (x^2*(36 + 24*x + 132*x^2 - 786*x^3 - 204*x^4 + 658*x^5 + 486*x^6 - 
           337*x^7 - 519*x^8 + 23*x^9 + 285*x^10 + 73*x^11 - 63*x^12 - 
           27*x^13)*HPL[{2, 0}, x])/(27*(-1 + x)^4*(1 + x)^6) + 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2, -1, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) - (16*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) - 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2, 1, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) - (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) + 
        ((27 + 36*x - x^2 - 32*x^3 - 13*x^4 + 22*x^5 + 33*x^6 - 33*x^7 - 
           22*x^8 + 13*x^9 + 32*x^10 + x^11 - 36*x^12 - 27*x^13)*
          HPL[{-1, -1, 0}, x])/(54*x^7*(1 + x)) + 
        ((101 - 55*x - 106*x^2 - 218*x^3 + 263*x^4 + 17*x^5 - 172*x^6 - 
           184*x^7 + 155*x^8 + 211*x^9 - 58*x^10 - 118*x^11 + 9*x^12 + 
           27*x^13)*HPL[{-1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        ((-27 - 36*x + x^2 + 32*x^3 + 13*x^4 - 22*x^5 - 33*x^6 + 33*x^7 + 
           22*x^8 - 13*x^9 - 32*x^10 - x^11 + 36*x^12 + 27*x^13)*
          HPL[{-1, 1, 0}, x])/(54*x^7*(1 + x)) + 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-1, 2, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) - (2*x^2*(270 + 9342*x + 2796*x^2 - 
           89910*x^3 - 78174*x^4 + 130956*x^5 + 552146*x^6 - 416260*x^7 - 
           628902*x^8 + 159854*x^9 + 235426*x^10 - 41508*x^11 - 87402*x^12 - 
           1760*x^13 + 36339*x^14 + 8893*x^15 - 8298*x^16 - 3114*x^17 + 
           567*x^18 + 243*x^19)*HPL[{0, 0, 0}, x])/(27*(-1 + x)^5*(1 + x)^7*
          (9 - 82*x^2 + 9*x^4)) + (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) + 
        ((-27 - 36*x + x^2 + 32*x^3 + 13*x^4 - 22*x^5 - 33*x^6 + 33*x^7 + 
           22*x^8 - 13*x^9 - 32*x^10 - x^11 + 36*x^12 + 27*x^13)*
          HPL[{1, -1, 0}, x])/(54*x^7*(1 + x)) - 
        ((101 + 253*x + 2*x^2 - 382*x^3 - 469*x^4 + 121*x^5 + 548*x^6 + 
           368*x^7 - 197*x^8 - 425*x^9 - 134*x^10 + 134*x^11 + 117*x^12 + 
           27*x^13)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*(1 + x)^6) + 
        ((27 + 36*x - x^2 - 32*x^3 - 13*x^4 + 22*x^5 + 33*x^6 - 33*x^7 - 
           22*x^8 + 13*x^9 + 32*x^10 + x^11 - 36*x^12 - 27*x^13)*
          HPL[{1, 1, 0}, x])/(54*x^7*(1 + x)) - 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{1, 2, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) - (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) + 
        (16*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{2, 0, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) + (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{2, 1, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) - 
        (16*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-1, 1, 0, 0}, x])/
         (9*(-1 + x)^2*(1 + x)^4) - (16*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x)^2*(1 + x)^4) + 
        ((2 + 7*x - 8*x^2 + 12*x^3 + 2*x^4 + x^5)*master3l10a[x])/
         (18*(-1 + x)^3*(1 + x)^5) - (x*(1 + 2*x + 12*x^2 - 8*x^3 + 7*x^4 + 
           2*x^5)*master3l10b[x])/(18*(-1 + x)^3*(1 + x)^5) + 
        ((81 + 819*x - 795*x^2 + 264*x^3 + 129*x^4 - 43*x^5 - 7*x^6)*
          master3l8a[x])/(54*(-1 + x)^4*(1 + x)^6*(-9 + x^2)) + 
        ((-15 + 31*x + 169*x^2 - 384*x^3 - 903*x^4 + 81*x^5 + 189*x^6)*
          master3l8b[x])/(54*(-1 + x)^4*(1 + x)^6*(-1 + 9*x^2)) + 
        ((135 + 450*x - 849*x^2 - 60*x^3 + 149*x^4 - 6*x^5 - 11*x^6)*
          master3l9a[x])/(18*(-1 + x)^4*(1 + x)^6*(-9 + x^2)) + 
        ((-11 - 6*x + 149*x^2 - 60*x^3 - 849*x^4 + 450*x^5 + 135*x^6)*
          master3l9b[x])/(54*(-1 + x)^4*(1 + x)^6*(-1 + 9*x^2)) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(27 + 63*x + 62*x^2 + 30*x^3 + 
             17*x^4 + 39*x^5 + 72*x^6 + 39*x^7 + 17*x^8 + 30*x^9 + 62*x^10 + 
             63*x^11 + 27*x^12) - 576*x^7*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
            Zeta[3]))/(648*(-1 + x)^2*x^7*(1 + x)^4) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(27 + 63*x + 62*x^2 + 30*x^3 + 
              17*x^4 + 39*x^5 + 72*x^6 + 39*x^7 + 17*x^8 + 30*x^9 + 62*x^10 + 
              63*x^11 + 27*x^12)) + 576*x^7*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
            Zeta[3]))/(648*(-1 + x)^2*x^7*(1 + x)^4) + 
        (HPL[{0}, x]*(2916 + 6804*x - 31536*x^2 - 85968*x^3 + 40485*x^4 + 
           9*(33467 + 144*Pi^2)*x^5 - 6*(38797 + 1176*Pi^2)*x^7 - 
           24*(50235 + 2056*Pi^2)*x^9 + (9717342 + 89160*Pi^2)*x^11 - 
           27*(123089 + 6868*Pi^2)*x^13 + (89115 + 135052*Pi^2)*x^14 + 
           12*(26064 + 16499*Pi^2)*x^15 - 8*(-3942 + 2131*Pi^2)*x^16 - 
           12*(567 + 9536*Pi^2)*x^17 - 4*(729 + 6022*Pi^2)*x^18 + 
           30924*Pi^2*x^19 + 11484*Pi^2*x^20 - 2268*Pi^2*x^21 - 
           972*Pi^2*x^22 + 9*x^6*(-62581 + 96*Pi^2 + 10368*Zeta[3]) - 
           6*x^8*(-946879 + 6028*Pi^2 + 157248*Zeta[3]) + 
           6*x^10*(1012361 + 47060*Pi^2 + 157248*Zeta[3]) - 
           x^12*(256252*Pi^2 + 729*(2699 + 128*Zeta[3]))))/
         (1296*(-1 + x)^4*x^3*(1 + x)^6*(9 - 82*x^2 + 9*x^4)) + 
        (-64*Pi^4*x^5*(-1 + x^2)^2*(9 + 27*x - 118*x^2 - 219*x^3 + 346*x^4 - 
            219*x^5 - 118*x^6 + 27*x^7 + 9*x^8) + 
          4*Pi^2*(-972 - 2268*x + 10998*x^2 + 29790*x^3 - 18670*x^4 - 
            98889*x^5 - 19336*x^6 + 143274*x^7 + 32604*x^8 - 117285*x^9 + 
            136500*x^10 - 136500*x^12 + 117285*x^13 - 32604*x^14 - 
            143274*x^15 + 19336*x^16 + 98889*x^17 + 18670*x^18 - 29790*x^19 - 
            10998*x^20 + 2268*x^21 + 972*x^22) + 
          x^2*(-5832 - 13608*x + 65016*x^2 - 742176*x^19*Zeta[3] - 
            275616*x^20*Zeta[3] + 54432*x^21*Zeta[3] + 23328*x^22*Zeta[3] - 
            48*x^4*(-36811 + 1782*Zeta[3]) + 24*x^16*(2709 + 17048*Zeta[3]) - 
            9*x^3*(-56615 + 17568*Zeta[3]) + 16*x^6*(-841013 + 
              22626*Zeta[3]) + 24*x^18*(-243 + 24088*Zeta[3]) + 
            72*x^17*(-189 + 38144*Zeta[3]) - 48*x^14*(7469 + 69308*Zeta[3]) - 
            48*x^10*(139373 + 75948*Zeta[3]) + 48*x^8*(-684053 + 
              83316*Zeta[3]) - 12*x^9*(634843 + 94592*Zeta[3]) - 
            39*x^7*(-622855 + 176576*Zeta[3]) - 33*x^11*(313855 + 
              278656*Zeta[3]) + 16*x^12*(206587 + 408300*Zeta[3]) - 
            9*x^15*(17545 + 545536*Zeta[3]) + x^5*(-6251894 + 
              2213856*Zeta[3]) + x^13*(3686986 + 6695424*Zeta[3])))/
         (10368*(-1 + x)^4*x^5*(1 + x)^6*(9 - 82*x^2 + 9*x^4))) + 
      CF*(NH*((x*(-2592 - 19728*x - 430128*x^2 - 114871*x^3 + 64570*x^4 + 
             6624*x^5 - 4322*x^6 + 4382*x^7 - 74*x^8 - 592*x^9 + 66*x^10 + 
             25*x^11)*HPL[{0}, x])/(216*(-1 + x)^5*(1 + x)^7*(-9 + x^2)) + 
          (x*(648 + 3060*x + 77256*x^2 + 18407*x^3 - 19194*x^4 - 1708*x^5 - 
             1278*x^6 - 640*x^7 + 162*x^8 + 84*x^9 + 6*x^10 - 3*x^11)*
            HPL[{0, 0}, x])/(54*(-1 + x)^5*(1 + x)^7*(-9 + x^2)) + 
          lm*((4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) - 3*(1 + 36*x - 22*x^2 + 
                36*x^3 + x^4))/(648*(-1 + x)^2*(1 + x)^4) - 
            (2*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x)^3*(1 + x)^5) - 
            (2*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x)*(1 + x)^3) + 
            (4*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x)^4*(1 + x)^6) + (2*(1 + 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x)*(1 + x)^3)) - (2*(-13 + 188*x - 61*x^2 + 52*x^3 - 
             10*x^4 + 2*x^5 + 2*x^6)*HPL[{-1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
          (4*x^3*(-2646 - 549*x + 549*x^2 - 108*x^3 + 219*x^4 + 24*x^5 - 
             45*x^6 - 8*x^7 + 3*x^8 + x^9)*HPL[{0, 0, 0}, x])/
           (27*(-1 + x)^5*(1 + x)^7*(-9 + x^2)) + 
          (2*(-31 + 100*x + 65*x^2 + 20*x^3 + 14*x^4 + 10*x^5 + 2*x^6)*
            HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*(1 + x)^6) - 
          ((189 + 3798*x + 1044*x^2 + 18*x^3 + 66*x^4 + 26*x^5 - 20*x^6 - 
             2*x^7 + x^8)*master3l8a[x])/(54*(-1 + x)^5*(1 + x)^7*
            (-9 + x^2)) - ((567 + 6102*x + 2034*x^2 + 1152*x^3 - 18*x^4 + 
             516*x^5 - 12*x^6 - 96*x^7 - 13*x^8 + 6*x^9 + 2*x^10)*
            master3l9a[x])/(54*(-1 + x)^5*(1 + x)^7*(-9 + x^2)) + 
          (76302 + x^2*(395631 - 19968*Zeta[3]) + x^9*(1271 - 5376*Zeta[3]) + 
            x^10*(3255 - 768*Zeta[3]) - 22464*Zeta[3] + 
            x^12*(-135 + 64*Zeta[3]) + x^11*(-515 + 192*Zeta[3]) + 
            4*x^8*(-5643 + 752*Zeta[3]) + 27*x*(40457 + 832*Zeta[3]) - 
            6*x^6*(5841 + 2944*Zeta[3]) + 6*x^7*(5683 + 2976*Zeta[3]) + 
            6*x^5*(-63735 + 25952*Zeta[3]) + x^4*(388965 + 57792*Zeta[3]) - 
            3*x^3*(-558139 + 63616*Zeta[3]))/(1296*(-1 + x)^5*(1 + x)^7*
            (-9 + x^2))) + 
        NM*(((-8*Pi^2*(-1 + x^2)^4*(-1 - 3*x + 8*x^2 + 27*x^3 + 9*x^4) + 
             3*(152 + 456*x - 796*x^2 - 6748*x^3 - 847*x^4 + 28838*x^5 - 7304*
                x^6 + 142394*x^7 + 15966*x^8 + 151650*x^9 + 80116*x^10 + 
               55890*x^11 + 36873*x^12))*HPL[{0}, x])/(648*(-1 + x)^5*
            (1 + x)^7*(-1 + 9*x^2)) + (4*(1 + 3*x + x^2)*HPL[{-2, 0}, x])/
           (27*(-1 + x)*(1 + x)^3) - ((24 + 72*x + 16*x^2 - 756*x^3 - 
             1167*x^4 - 2010*x^5 + 108*x^6 + 66378*x^7 - 4936*x^8 + 
             96354*x^9 + 45720*x^10 + 35802*x^11 + 25515*x^12)*
            HPL[{0, 0}, x])/(54*(-1 + x)^5*(1 + x)^7*(-1 + 9*x^2)) + 
          lm*((4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) - 3*(1 + 36*x - 22*x^2 + 
                36*x^3 + x^4))/(648*(-1 + x)^2*(1 + x)^4) - 
            (2*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x)^3*(1 + x)^5) - 
            (2*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x)*(1 + x)^3) + 
            (4*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x)^4*(1 + x)^6) + (2*(1 + 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x)*(1 + x)^3)) - (4*(1 + 3*x + x^2)*HPL[{2, 0}, x])/
           (27*(-1 + x)*(1 + x)^3) + (2*(-6 - 6*x + 30*x^2 - 52*x^3 + 
             41*x^4 - 184*x^5 + 17*x^6)*HPL[{-1, 0, 0}, x])/
           (27*(-1 + x^2)^4) + (4*(1 + 3*x + 20*x^2 + 3*x^3 - 191*x^4 - 
             939*x^5 + 116*x^6 + 7371*x^7 - 2061*x^8 + 21456*x^9 + 
             9424*x^10 + 8586*x^11 + 4851*x^12)*HPL[{0, 0, 0}, x])/
           (27*(-1 + x)^5*(1 + x)^7*(-1 + 9*x^2)) + 
          ((12 + 60*x + 84*x^2 + 40*x^3 + 74*x^4 + 160*x^5 - 70*x^6)*
            HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*(1 + x)^6) + 
          ((4 + 12*x - 29*x^2 - 186*x^3 + 36*x^4 + 954*x^5 - 234*x^6 + 
             2250*x^7 + 936*x^8 + 810*x^9 + 567*x^10)*master3l8b[x])/
           (162*(-1 + x)^5*x^2*(1 + x)^7*(-1 + 9*x^2)) + 
          ((2 + 6*x - 13*x^2 - 96*x^3 - 12*x^4 + 516*x^5 - 18*x^6 + 
             1152*x^7 + 2034*x^8 + 6102*x^9 + 567*x^10)*master3l9b[x])/
           (162*(-1 + x)^5*x^2*(1 + x)^7*(-1 + 9*x^2)) + 
          (30 + 90*x + x^8*(2124 - 17664*Zeta[3]) + 
            x^5*(30881 - 5376*Zeta[3]) + x^4*(5805 - 768*Zeta[3]) + 
            x^2*(-810 + 64*Zeta[3]) + x^3*(-3395 + 192*Zeta[3]) + 
            27*x^13*(-3613 + 832*Zeta[3]) - 27*x^14*(1269 + 832*Zeta[3]) + 
            6*x^7*(-8957 + 2976*Zeta[3]) + x^6*(-17427 + 3008*Zeta[3]) + 
            12*x^10*(-7265 + 4816*Zeta[3]) - 3*x^12*(45693 + 6656*Zeta[3]) + 
            12*x^9*(-55665 + 12976*Zeta[3]) - 3*x^11*(4901 + 63616*Zeta[3]))/
           (1296*(-1 + x)^5*x^2*(1 + x)^7*(-1 + 9*x^2))) + 
        NL*(-(Pi^2*(1 + 3*x + x^2)*HPL[{-1}, x])/(81*(-1 + x)*(1 + x)^3) + 
          (x^2*(18 + 12*(29 + 6*Pi^2)*x + 69*x^2 + 12*(-38 + 3*Pi^2)*x^3 - 
             2*(45 + 4*Pi^2)*x^4 + 12*(9 + Pi^2)*x^5 + (3 + 4*Pi^2)*x^6)*
            HPL[{0}, x])/(324*(-1 + x)^4*(1 + x)^6) + 
          (Pi^2*(1 + 3*x + x^2)*HPL[{1}, x])/(81*(-1 + x)*(1 + x)^3) - 
          (4*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{-2, 0}, x])/
           (27*(-1 + x)^4*(1 + x)^6) + ((-3 - 14*x + x^2 + 148*x^3 + x^4 - 
             14*x^5 - 3*x^6)*HPL[{-1, 0}, x])/(54*(-1 + x)^3*(1 + x)^5) + 
          (x^3*(120 + 6*x^2 + 4*x^3 + 14*x^4 + 3*x^5)*HPL[{0, 0}, x])/
           (27*(-1 + x)^4*(1 + x)^6) - ((-3 - 14*x + x^2 + 148*x^3 + x^4 - 
             14*x^5 - 3*x^6)*HPL[{1, 0}, x])/(54*(-1 + x)^3*(1 + x)^5) + 
          lm*((4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) - 3*(1 + 36*x - 22*x^2 + 
                36*x^3 + x^4))/(648*(-1 + x)^2*(1 + x)^4) - 
            (2*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x)^3*(1 + x)^5) - 
            (2*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x)*(1 + x)^3) + 
            (4*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x)^4*(1 + x)^6) + (2*(1 + 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x)*(1 + x)^3)) + (4*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + 
             x^5)*HPL[{2, 0}, x])/(27*(-1 + x)^4*(1 + x)^6) + 
          (4*(1 + 3*x + x^2)*HPL[{-1, -1, 0}, x])/(27*(-1 + x)*(1 + x)^3) - 
          (4*(1 + 3*x + x^2)*HPL[{-1, 1, 0}, x])/(27*(-1 + x)*(1 + x)^3) - 
          (8*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0, 0}, x])/
           (27*(-1 + x)^4*(1 + x)^6) - (4*(1 + 3*x + x^2)*HPL[{1, -1, 0}, x])/
           (27*(-1 + x)*(1 + x)^3) + (4*(1 + 3*x + x^2)*HPL[{1, 1, 0}, x])/
           (27*(-1 + x)*(1 + x)^3) + (4*Pi^2*(-3 - 14*x + 4*x^2 + 162*x^3 - 
              162*x^5 - 4*x^6 + 14*x^7 + 3*x^8) - 3*(15 + 338*x^4 - 184*x^6 + 
              360*x^7 + 15*x^8 - 64*Zeta[3] - 24*x*(-15 + 8*Zeta[3]) - 
              72*x^3*(5 + 8*Zeta[3]) + 8*x^2*(-23 + 16*Zeta[3]) - 
              72*x^5*(5 + 16*Zeta[3])))/(2592*(-1 + x)^4*(1 + x)^6))))
 
CbarData["p", 2, 2] = 
    NC*(CA*CF*((Pi^2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-2}, x])/(108*(-1 + x)^4*(1 + x)^6) + 
        lm^2*((-11*(1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6))/
           (288*(-1 + x)^4*(1 + x)^6) + (11*x^3*(2 - x + 2*x^2)*HPL[{0}, x])/
           (12*(-1 + x)^5*(1 + x)^7)) - (Pi^2*(1 + 4*x - 19*x^2 + 56*x^3 - 
           19*x^4 + 4*x^5 + x^6)*HPL[{2}, x])/(108*(-1 + x)^4*(1 + x)^6) + 
        (x*(-3 + 165*x + 6*x^2 + 789*x^3 - 5754*x^4 + 461*x^5 + 1310*x^6 + 
           2175*x^7 - 1582*x^8 - 3313*x^9 + 540*x^10 + 2682*x^11 + 372*x^12 - 
           1110*x^13 - 348*x^14 + 189*x^15 + 81*x^16)*HPL[{-2, 0}, x])/
         (216*(-1 + x)^6*(1 + x)^8) + ((-1620 - 3780*x + 4530*x^2 + 
           16530*x^3 + 30*x^4 + (-24331 + 80*Pi^2)*x^5 + 80*(69 + 4*Pi^2)*
            x^6 + (8784 - 1600*Pi^2)*x^7 + 40*(1133 + 104*Pi^2)*x^8 - 
           35166*x^9 + (45320 - 4160*Pi^2)*x^10 + 16*(549 + 100*Pi^2)*x^11 - 
           80*(-69 + 4*Pi^2)*x^12 - (24331 + 80*Pi^2)*x^13 + 30*x^14 + 
           16530*x^15 + 4530*x^16 - 3780*x^17 - 1620*x^18)*HPL[{-1, 0}, x])/
         (8640*(-1 + x)^5*x^5*(1 + x)^7) + 
        (x*(-14580 + 2165292*x - 19896030*x^2 - 21856833*x^3 + 
           294211440*x^4 - 82997683*x^5 - 376333390*x^6 + 1348334612*x^7 - 
           5464656740*x^8 - 3527388452*x^9 - 2746622870*x^10 + 
           1456475729*x^11 - 454371390*x^12 - 661341095*x^13 + 
           271517850*x^14 - 27492126*x^15 - 66953460*x^16 + 49956750*x^17 + 
           20597220*x^18 - 7224390*x^19 - 2889270*x^20 + 306180*x^21 + 
           131220*x^22)*HPL[{0, 0}, x])/(4320*(-1 + x)^6*(1 + x)^8*
          (9 - 82*x^2 + 9*x^4)^2) + ((1620 + 3780*x - 4530*x^2 - 16530*x^3 - 
           30*x^4 + (24331 - 80*Pi^2)*x^5 - 80*(69 + 4*Pi^2)*x^6 + 
           16*(-549 + 100*Pi^2)*x^7 - 40*(1133 + 104*Pi^2)*x^8 + 35166*x^9 + 
           40*(-1133 + 104*Pi^2)*x^10 - 16*(549 + 100*Pi^2)*x^11 + 
           80*(-69 + 4*Pi^2)*x^12 + (24331 + 80*Pi^2)*x^13 - 30*x^14 - 
           16530*x^15 - 4530*x^16 + 3780*x^17 + 1620*x^18)*HPL[{1, 0}, x])/
         (8640*(-1 + x)^5*x^5*(1 + x)^7) + 
        lm*(-(44*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 
             3*(161 - 16*x + 39*x^2 + 6528*x^3 + 39*x^4 - 16*x^5 + 161*x^6))/
           (5184*(-1 + x)^4*(1 + x)^6) + (x^2*(22 + 2506*x - 879*x^2 + 
             3694*x^3 - 242*x^4 + 132*x^5 + 33*x^6)*HPL[{0}, x])/
           (216*(-1 + x)^5*(1 + x)^7) + (11*(1 + 4*x + 4*x^3 + x^4)*
            HPL[{-1, 0}, x])/(108*(-1 + x)^3*(1 + x)^5) - 
          (11*x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*x^5 + 4*x^6 + 
             x^7)*HPL[{0, 0}, x])/(54*(-1 + x)^6*(1 + x)^8) - 
          (11*(1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/(108*(-1 + x)^3*
            (1 + x)^5)) - (x*(-3 + 165*x + 6*x^2 + 789*x^3 - 5754*x^4 + 
           461*x^5 + 1310*x^6 + 2175*x^7 - 1582*x^8 - 3313*x^9 + 540*x^10 + 
           2682*x^11 + 372*x^12 - 1110*x^13 - 348*x^14 + 189*x^15 + 81*x^16)*
          HPL[{2, 0}, x])/(216*(-1 + x)^6*(1 + x)^8) - 
        ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-2, -1, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        (4*x^2*(-9 + 28*x - 10*x^2 + 4*x^3 + x^4)*HPL[{-2, 0, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^6) + ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{-2, 1, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        ((81 + 189*x - 105*x^2 - 543*x^3 - 186*x^4 + 486*x^5 + 378*x^6 + 
           7*x^7 + 184*x^8 - 102*x^9 + 184*x^10 + 7*x^11 + 378*x^12 + 
           486*x^13 - 186*x^14 - 543*x^15 - 105*x^16 + 189*x^17 + 81*x^18)*
          HPL[{-1, -1, 0}, x])/(432*(-1 + x)^3*x^7*(1 + x)^5) + 
        ((797 - 809*x - 2299*x^2 + 7267*x^3 - 865*x^4 + 4747*x^5 + 221*x^6 + 
           4951*x^7 - 2533*x^8 - 7875*x^9 + 2295*x^10 + 5985*x^11 - 
           855*x^12 - 2415*x^13 + 135*x^14 + 405*x^15)*HPL[{-1, 0, 0}, x])/
         (1080*(-1 + x^2)^6) + ((81 + 189*x - 105*x^2 - 543*x^3 - 186*x^4 + 
           486*x^5 + 378*x^6 + 7*x^7 + 184*x^8 - 102*x^9 + 184*x^10 + 
           7*x^11 + 378*x^12 + 486*x^13 - 186*x^14 - 543*x^15 - 105*x^16 + 
           189*x^17 + 81*x^18)*HPL[{-1, 1, 0}, x])/(432*(-1 + x)^3*x^7*
          (1 + x)^5) - ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        (x*(-1215 + 57105*x - 3662550*x^2 + 3206655*x^3 + 45744330*x^4 - 
           80230173*x^5 + 70296690*x^6 + 612033039*x^7 - 1595727840*x^8 - 
           1810115311*x^9 - 498635290*x^10 + 1016478681*x^11 - 
           439968730*x^12 - 715901371*x^13 + 154641870*x^14 + 
           323189703*x^15 + 15419505*x^16 - 125149782*x^17 - 30212160*x^18 + 
           31570560*x^19 + 11015460*x^20 - 3688740*x^21 - 1477440*x^22 + 
           153090*x^23 + 65610*x^24)*HPL[{0, 0, 0}, x])/
         (1080*(-1 + x)^6*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^2) - 
        ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        ((81 + 189*x - 105*x^2 - 543*x^3 - 186*x^4 + 486*x^5 + 378*x^6 + 
           7*x^7 + 184*x^8 - 102*x^9 + 184*x^10 + 7*x^11 + 378*x^12 + 
           486*x^13 - 186*x^14 - 543*x^15 - 105*x^16 + 189*x^17 + 81*x^18)*
          HPL[{1, -1, 0}, x])/(432*(-1 + x)^3*x^7*(1 + x)^5) - 
        ((797 + 2859*x + 3721*x^2 + 4203*x^3 + 9015*x^4 + 1263*x^5 - 
           4679*x^6 - 2721*x^7 + 8747*x^8 + 12705*x^9 + 675*x^10 - 
           8655*x^11 - 4575*x^12 + 1365*x^13 + 1755*x^14 + 405*x^15)*
          HPL[{1, 0, 0}, x])/(1080*(-1 + x)^4*(1 + x)^8) - 
        ((81 + 189*x - 105*x^2 - 543*x^3 - 186*x^4 + 486*x^5 + 378*x^6 + 
           7*x^7 + 184*x^8 - 102*x^9 + 184*x^10 + 7*x^11 + 378*x^12 + 
           486*x^13 - 186*x^14 - 543*x^15 - 105*x^16 + 189*x^17 + 81*x^18)*
          HPL[{1, 1, 0}, x])/(432*(-1 + x)^3*x^7*(1 + x)^5) + 
        ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        (4*x^2*(-9 + 28*x - 10*x^2 + 4*x^3 + x^4)*HPL[{2, 0, 0}, x])/
         (9*(-1 + x)^4*(1 + x)^6) - ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{2, 1, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        (2*(1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0, 0, 0}, x])/
         (9*(-1 + x)^3*(1 + x)^5) + (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        (2*(1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0, 0, 0}, x])/
         (9*(-1 + x)^3*(1 + x)^5) - ((2 + 11*x - 31*x^2 + 177*x^3 - 76*x^4 + 
           73*x^5 + 9*x^6 + 3*x^7)*master3l10a[x])/(144*(-1 + x)^5*
          (1 + x)^7) + (x*(3 + 9*x + 73*x^2 - 76*x^3 + 177*x^4 - 31*x^5 + 
           11*x^6 + 2*x^7)*master3l10b[x])/(144*(-1 + x)^5*(1 + x)^7) + 
        ((-78489 + 266355*x - 335988*x^2 + 795960*x^3 - 323646*x^4 - 
           63690*x^5 + 88764*x^6 - 17120*x^7 - 6641*x^8 + 1535*x^9 + 
           128*x^10)*master3l8a[x])/(4320*(-1 + x)^6*(1 + x)^8*
          (-9 + x^2)^2) + ((10 - 638*x + 1425*x^2 + 13729*x^3 - 29180*x^4 - 
           124352*x^5 + 127290*x^6 + 475446*x^7 + 85770*x^8 - 105786*x^9 + 
           111645*x^10 + 68769*x^11)*master3l8b[x])/(4320*(-1 + x)^6*x*
          (1 + x)^8*(1 - 9*x^2)^2) + ((8181 - 8595*x + 13698*x^2 - 
           40410*x^3 + 45916*x^4 + 6120*x^5 - 6738*x^6 + 10*x^7 + 383*x^8 - 
           5*x^9)*master3l9a[x])/(1440*(-1 + x)^6*(1 + x)^8*(-9 + x^2)) + 
        ((-5 + 383*x + 10*x^2 - 6738*x^3 + 6120*x^4 + 45916*x^5 - 40410*x^6 + 
           13698*x^7 - 8595*x^8 + 8181*x^9)*master3l9b[x])/
         (4320*(-1 + x)^6*x*(1 + x)^8*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(81 + 189*x - 186*x^2 - 732*x^3 - 81*x^4 + 
             1029*x^5 + 564*x^6 - 479*x^7 - 194*x^8 - 109*x^9 + 109*x^11 + 
             194*x^12 + 479*x^13 - 564*x^14 - 1029*x^15 + 81*x^16 + 
             732*x^17 + 186*x^18 - 189*x^19 - 81*x^20) - 
           576*x^7*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
            Zeta[3]))/(5184*(-1 + x)^4*x^7*(1 + x)^6) + 
        (HPL[{-1}, x]*(Pi^2*(-81 - 189*x + 186*x^2 + 732*x^3 + 81*x^4 - 
             1029*x^5 - 564*x^6 + 479*x^7 + 194*x^8 + 109*x^9 - 109*x^11 - 
             194*x^12 - 479*x^13 + 564*x^14 + 1029*x^15 - 81*x^16 - 
             732*x^17 - 186*x^18 + 189*x^19 + 81*x^20) + 
           576*x^7*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
            Zeta[3]))/(5184*(-1 + x)^4*x^7*(1 + x)^6) + 
        (HPL[{0}, x]*(393660 + 918540*x - 8470980*x^2 - 21213900*x^3 + 
           405*(142879 + 12*Pi^2)*x^4 - 243*(-513079 + 1100*Pi^2)*x^5 + 
           150*(186761105 + 5559046*Pi^2)*x^12 - 216*(4261087 + 2332230*Pi^2)*
            x^19 + (2065095 - 43132380*Pi^2)*x^20 + 
           15*(4117311 + 16199212*Pi^2)*x^21 + 60*(141183 + 1007072*Pi^2)*
            x^22 - 34020*(27 + 1856*Pi^2)*x^23 - 540*(729 + 40798*Pi^2)*
            x^24 + 7377480*Pi^2*x^25 + 2954880*Pi^2*x^26 - 306180*Pi^2*x^27 - 
           131220*Pi^2*x^28 + 10*x^13*(882854985 + 2910812*Pi^2 - 
             86697216*Zeta[3]) + 20*x^16*(52902375 + 14060194*Pi^2 - 
             15303168*Zeta[3]) - 12*x^15*(375783054 + 32446255*Pi^2 - 
             13452480*Zeta[3]) + 20*x^17*(217112874 + 30034819*Pi^2 - 
             419904*Zeta[3]) - 90*x^18*(8028935 + 1240516*Pi^2 - 
             186624*Zeta[3]) + 180*x^7*(882815 + 19959*Pi^2 + 
             46656*Zeta[3]) - 90*x^6*(923281 + 1092*Pi^2 + 186624*Zeta[3]) + 
           60*x^8*(-7921179 + 165196*Pi^2 + 5101056*Zeta[3]) - 
           12*x^9*(192759431 + 14945*Pi^2 + 13452480*Zeta[3]) - 
           30*x^10*(72129745 + 5763172*Pi^2 + 47036160*Zeta[3]) + 
           x^11*(812707740 - 93705060*Pi^2 + 866972160*Zeta[3]) + 
           x^14*(-397856440*Pi^2 + 30*(403031513 + 47036160*Zeta[3]))))/
         (51840*(-1 + x)^6*x^3*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^2) + 
        (64*Pi^4*x^5*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(-3 - 12*x - 87*x^2 + 
            280*x^3 - 103*x^4 + 52*x^5 + 13*x^6) + 
          4*Pi^2*(9 - 82*x^2 + 9*x^4)^2*(-1620 - 3780*x + 6150*x^2 + 
            20310*x^3 - 4500*x^4 - 40861*x^5 + 5490*x^6 + 33115*x^7 + 
            39800*x^8 - 43950*x^9 + 43950*x^11 - 39800*x^12 - 33115*x^13 - 
            5490*x^14 + 40861*x^15 + 4500*x^16 - 20310*x^17 - 6150*x^18 + 
            3780*x^19 + 1620*x^20) + x^2*(-787320 - 1837080*x + 
            17277300*x^2 + x^7*(3482676640 - 4766682432*Zeta[3]) - 
            177059520*x^25*Zeta[3] - 70917120*x^26*Zeta[3] + 
            7348320*x^27*Zeta[3] + 3149280*x^28*Zeta[3] + 
            204120*x^23*(-9 + 7424*Zeta[3]) - 810*x^4*(380303 + 
              69456*Zeta[3]) + 3240*x^24*(-243 + 163192*Zeta[3]) - 
            81*x^3*(-1934245 + 387552*Zeta[3]) - 720*x^22*
             (-23895 + 2014144*Zeta[3]) + 1620*x^18*(21251 + 2194784*Zeta[
                3]) - 440*x^14*(-884767 + 2322768*Zeta[3]) + 
            360*x^6*(6009217 + 2824368*Zeta[3]) + 90*x^20*(-1389447 + 
              10954192*Zeta[3]) - 320*x^8*(-31792037 + 13526943*Zeta[3]) - 
            320*x^16*(-11961617 + 31276620*Zeta[3]) - 
            80*x^10*(1217950169 + 64332792*Zeta[3]) + 
            9*x^5*(-218927495 + 73606848*Zeta[3]) - 224*x^17*
             (-3789035 + 84157938*Zeta[3]) + 64*x^9*(347633345 + 
              250085748*Zeta[3]) + 64*x^15*(-385627570 + 386667183*Zeta[3]) + 
            60*x^12*(-1766691143 + 417676856*Zeta[3]) - 
            9*x^21*(1114875 + 651266368*Zeta[3]) + 
            9*x^19*(45603745 + 1412224608*Zeta[3]) - 
            6*x^11*(-5283157295 + 5244788752*Zeta[3]) - 
            6*x^13*(-4027677815 + 5601577472*Zeta[3])))/(414720*(-1 + x)^6*
          x^5*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF^2*(-(Pi^2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
           HPL[{-2}, x])/(54*(-1 + x)^4*(1 + x)^6) + 
        lm^2*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
           (16*(-1 + x)^4*(1 + x)^6) + (3*x^3*(-2 + x - 2*x^2)*HPL[{0}, x])/
           (2*(-1 + x)^5*(1 + x)^7)) + (Pi^2*(1 + 4*x - 19*x^2 + 56*x^3 - 
           19*x^4 + 4*x^5 + x^6)*HPL[{2}, x])/(54*(-1 + x)^4*(1 + x)^6) + 
        (x*(15 - 825*x + 2730*x^2 - 5085*x^3 + 38610*x^4 - 4885*x^5 - 
           22950*x^6 - 22695*x^7 + 38830*x^8 + 53827*x^9 - 28334*x^10 - 
           66964*x^11 + 4306*x^12 + 47356*x^13 + 8706*x^14 - 18099*x^15 - 
           6129*x^16 + 2916*x^17 + 1296*x^18)*HPL[{-2, 0}, x])/
         (540*(-1 + x)^6*(1 + x)^8) + ((-77760 - 174960*x + 251100*x^2 + 
           823500*x^3 - 113310*x^4 - 1533210*x^5 - 529710*x^6 + 
           (1396573 - 1200*Pi^2)*x^7 - 30*(-33893 + 160*Pi^2)*x^8 + 
           4*(-132403 + 6000*Pi^2)*x^9 - 30*(55317 + 2080*Pi^2)*x^10 + 
           902658*x^11 + 30*(-55317 + 2080*Pi^2)*x^12 - 
           4*(132403 + 6000*Pi^2)*x^13 + 30*(33893 + 160*Pi^2)*x^14 + 
           (1396573 + 1200*Pi^2)*x^15 - 529710*x^16 - 1533210*x^17 - 
           113310*x^18 + 823500*x^19 + 251100*x^20 - 174960*x^21 - 
           77760*x^22)*HPL[{-1, 0}, x])/(64800*(-1 + x)^5*x^7*(1 + x)^7) + 
        (x*(218700 - 34442820*x + 268201530*x^2 + 422417295*x^3 - 
           3936086460*x^4 + 34005585*x^5 + 4471314990*x^6 - 15570856200*x^7 + 
           75196130610*x^8 + 51845369792*x^9 + 49208866590*x^10 - 
           8825980267*x^11 - 6172209750*x^12 - 11251412923*x^13 + 
           1308159510*x^14 + 19488145758*x^15 + 2486885130*x^16 - 
           10709350038*x^17 - 2883444480*x^18 + 2869395030*x^19 + 
           1050369930*x^20 - 339116220*x^21 - 141411420*x^22 + 
           14171760*x^23 + 6298560*x^24)*HPL[{0, 0}, x])/
         (32400*(-1 + x)^6*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^2) + 
        ((77760 + 174960*x - 251100*x^2 - 823500*x^3 + 113310*x^4 + 
           1533210*x^5 + 529710*x^6 + (-1396573 + 1200*Pi^2)*x^7 + 
           30*(-33893 + 160*Pi^2)*x^8 + (529612 - 24000*Pi^2)*x^9 + 
           30*(55317 + 2080*Pi^2)*x^10 - 902658*x^11 - 
           30*(-55317 + 2080*Pi^2)*x^12 + 4*(132403 + 6000*Pi^2)*x^13 - 
           30*(33893 + 160*Pi^2)*x^14 - (1396573 + 1200*Pi^2)*x^15 + 
           529710*x^16 + 1533210*x^17 + 113310*x^18 - 823500*x^19 - 
           251100*x^20 + 174960*x^21 + 77760*x^22)*HPL[{1, 0}, x])/
         (64800*(-1 + x)^5*x^7*(1 + x)^7) + 
        lm*((2*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 
            3*(4 - 14*x + 25*x^2 + 164*x^3 + 25*x^4 - 14*x^5 + 4*x^6))/
           (144*(-1 + x)^4*(1 + x)^6) - (x^2*(2 + 188*x - 60*x^2 + 296*x^3 - 
             22*x^4 + 12*x^5 + 3*x^6)*HPL[{0}, x])/(12*(-1 + x)^5*
            (1 + x)^7) - ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0}, x])/
           (6*(-1 + x)^3*(1 + x)^5) + (x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 
             136*x^4 - 3*x^5 + 4*x^6 + x^7)*HPL[{0, 0}, x])/
           (3*(-1 + x)^6*(1 + x)^8) + ((1 + 4*x + 4*x^3 + x^4)*
            HPL[{1, 0}, x])/(6*(-1 + x)^3*(1 + x)^5)) - 
        (x*(15 - 825*x + 2730*x^2 - 5085*x^3 + 38610*x^4 - 4885*x^5 - 
           22950*x^6 - 22695*x^7 + 38830*x^8 + 53827*x^9 - 28334*x^10 - 
           66964*x^11 + 4306*x^12 + 47356*x^13 + 8706*x^14 - 18099*x^15 - 
           6129*x^16 + 2916*x^17 + 1296*x^18)*HPL[{2, 0}, x])/
         (540*(-1 + x)^6*(1 + x)^8) + (2*(1 + 4*x - 19*x^2 + 56*x^3 - 
           19*x^4 + 4*x^5 + x^6)*HPL[{-2, -1, 0}, x])/(9*(-1 + x)^4*
          (1 + x)^6) - (4*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-2, 1, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        ((1296 + 2916*x + 351*x^2 - 3519*x^3 - 2499*x^4 + 601*x^5 + 
           1261*x^6 + 391*x^7 - 9*x^8 - 178*x^9 - 9*x^10 + 391*x^11 + 
           1261*x^12 + 601*x^13 - 2499*x^14 - 3519*x^15 + 351*x^16 + 
           2916*x^17 + 1296*x^18)*HPL[{-1, -1, 0}, x])/(1080*(-1 + x)*x^9*
          (1 + x)^3) - ((961 + 45*x - 7709*x^2 + 22375*x^3 - 23329*x^4 + 
           16909*x^5 + 2303*x^6 + 12607*x^7 - 11765*x^8 - 26645*x^9 + 
           12009*x^10 + 30961*x^11 - 6967*x^12 - 21333*x^13 + 2277*x^14 + 
           8073*x^15 - 324*x^16 - 1296*x^17)*HPL[{-1, 0, 0}, x])/
         (540*(-1 + x^2)^6) + ((1296 + 2916*x + 351*x^2 - 3519*x^3 - 
           2499*x^4 + 601*x^5 + 1261*x^6 + 391*x^7 - 9*x^8 - 178*x^9 - 
           9*x^10 + 391*x^11 + 1261*x^12 + 601*x^13 - 2499*x^14 - 3519*x^15 + 
           351*x^16 + 2916*x^17 + 1296*x^18)*HPL[{-1, 1, 0}, x])/
         (1080*(-1 + x)*x^9*(1 + x)^3) + 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        (x*(-1215 + 76545*x + 3181545*x^2 - 655290*x^3 - 47253120*x^4 - 
           31166748*x^5 + 129241320*x^6 + 620025492*x^7 - 26451570*x^8 - 
           3373313510*x^9 + 3535336414*x^10 + 3028346856*x^11 - 
           986161904*x^12 - 2610887716*x^13 + 1542414584*x^14 + 
           2708218538*x^15 - 738676569*x^16 - 2213587489*x^17 + 
           7544639*x^18 + 1324611878*x^19 + 234137292*x^20 - 509769612*x^21 - 
           150588612*x^22 + 112799142*x^23 + 42170382*x^24 - 12012462*x^25 - 
           5028642*x^26 + 472392*x^27 + 209952*x^28)*HPL[{0, 0, 0}, x])/
         (540*(-1 + x)^7*(1 + x)^9*(9 - 82*x^2 + 9*x^4)^2) + 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        ((1296 + 2916*x + 351*x^2 - 3519*x^3 - 2499*x^4 + 601*x^5 + 
           1261*x^6 + 391*x^7 - 9*x^8 - 178*x^9 - 9*x^10 + 391*x^11 + 
           1261*x^12 + 601*x^13 - 2499*x^14 - 3519*x^15 + 351*x^16 + 
           2916*x^17 + 1296*x^18)*HPL[{1, -1, 0}, x])/(1080*(-1 + x)*x^9*
          (1 + x)^3) + ((961 + 4369*x + 3039*x^2 + 6471*x^3 + 16575*x^4 - 
           3543*x^5 - 17909*x^6 - 393*x^7 + 34795*x^8 + 32895*x^9 - 
           22051*x^10 - 48663*x^11 - 8311*x^12 + 27735*x^13 + 16425*x^14 - 
           3591*x^15 - 5508*x^16 - 1296*x^17)*HPL[{1, 0, 0}, x])/
         (540*(-1 + x)^4*(1 + x)^8) - ((1296 + 2916*x + 351*x^2 - 3519*x^3 - 
           2499*x^4 + 601*x^5 + 1261*x^6 + 391*x^7 - 9*x^8 - 178*x^9 - 
           9*x^10 + 391*x^11 + 1261*x^12 + 601*x^13 - 2499*x^14 - 3519*x^15 + 
           351*x^16 + 2916*x^17 + 1296*x^18)*HPL[{1, 1, 0}, x])/
         (1080*(-1 + x)*x^9*(1 + x)^3) - 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        (4*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{2, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{2, 1, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        (4*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) - 
        (4*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x)^4*(1 + x)^6) + 
        ((2 + 11*x - 31*x^2 + 177*x^3 - 76*x^4 + 73*x^5 + 9*x^6 + 3*x^7)*
          master3l10a[x])/(72*(-1 + x)^5*(1 + x)^7) - 
        (x*(3 + 9*x + 73*x^2 - 76*x^3 + 177*x^4 - 31*x^5 + 11*x^6 + 2*x^7)*
          master3l10b[x])/(72*(-1 + x)^5*(1 + x)^7) + 
        ((78489 - 266355*x + 335988*x^2 - 795960*x^3 + 323646*x^4 + 
           63690*x^5 - 88764*x^6 + 17120*x^7 + 6641*x^8 - 1535*x^9 - 
           128*x^10)*master3l8a[x])/(2160*(-1 + x)^6*(1 + x)^8*
          (-9 + x^2)^2) - ((10 - 638*x + 1425*x^2 + 13729*x^3 - 29180*x^4 - 
           124352*x^5 + 127290*x^6 + 475446*x^7 + 85770*x^8 - 105786*x^9 + 
           111645*x^10 + 68769*x^11)*master3l8b[x])/(2160*(-1 + x)^6*x*
          (1 + x)^8*(1 - 9*x^2)^2) - ((8181 - 8595*x + 13698*x^2 - 
           40410*x^3 + 45916*x^4 + 6120*x^5 - 6738*x^6 + 10*x^7 + 383*x^8 - 
           5*x^9)*master3l9a[x])/(720*(-1 + x)^6*(1 + x)^8*(-9 + x^2)) - 
        ((-5 + 383*x + 10*x^2 - 6738*x^3 + 6120*x^4 + 45916*x^5 - 40410*x^6 + 
           13698*x^7 - 8595*x^8 + 8181*x^9)*master3l9b[x])/
         (2160*(-1 + x)^6*x*(1 + x)^8*(-1 + 9*x^2)) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(1296 + 2916*x + 351*x^2 - 
             3519*x^3 - 2499*x^4 + 601*x^5 + 1261*x^6 + 391*x^7 - 9*x^8 - 
             178*x^9 - 9*x^10 + 391*x^11 + 1261*x^12 + 601*x^13 - 2499*x^14 - 
             3519*x^15 + 351*x^16 + 2916*x^17 + 1296*x^18) - 
           2880*x^9*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
            Zeta[3]))/(12960*(-1 + x)^4*x^9*(1 + x)^6) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(1296 + 2916*x + 351*x^2 - 
              3519*x^3 - 2499*x^4 + 601*x^5 + 1261*x^6 + 391*x^7 - 9*x^8 - 
              178*x^9 - 9*x^10 + 391*x^11 + 1261*x^12 + 601*x^13 - 
              2499*x^14 - 3519*x^15 + 351*x^16 + 2916*x^17 + 1296*x^18)) + 
           2880*x^9*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
            Zeta[3]))/(12960*(-1 + x)^4*x^9*(1 + x)^6) + 
        (HPL[{0}, x]*(6298560 + 14171760*x - 138262140*x^2 - 332030340*x^3 + 
           981763740*x^4 + 2704560840*x^5 - 405*(5938783 + 60*Pi^2)*x^6 + 
           81*(-114940631 + 16500*Pi^2)*x^7 - 450*(329642927 + 13282650*Pi^2)*
            x^14 + 2*(6617526093 + 6137645260*Pi^2)*x^21 - 
           5*(-422257293 + 245083300*Pi^2)*x^22 - 
           5*(581025393 + 1824970348*Pi^2)*x^23 - 
           60*(16362729 + 20150062*Pi^2)*x^24 + 1620*(204957 + 2521670*Pi^2)*
            x^25 + 540*(256041 + 2096980*Pi^2)*x^26 - 
           19440*(729 + 52088*Pi^2)*x^27 - 3240*(1944 + 115283*Pi^2)*x^28 + 
           115400700*Pi^2*x^29 + 48186900*Pi^2*x^30 - 4723920*Pi^2*x^31 - 
           2099520*Pi^2*x^32 - 4*x^15*(14719840269 + 58291660*Pi^2 - 
             1083715200*Zeta[3]) + 6*x^13*(1955538721 + 94752150*Pi^2 - 
             722476800*Zeta[3]) - 10*x^11*(413940491 + 2857650*Pi^2 - 
             80714880*Zeta[3]) + 10*x^17*(3678653861 + 468704262*Pi^2 - 
             80714880*Zeta[3]) - 2*x^19*(18123623319 + 5064295570*Pi^2 - 
             20995200*Zeta[3]) - 100*x^18*(146845419 + 69310952*Pi^2 - 
             15303168*Zeta[3]) + 300*x^10*(35738039 + 53252*Pi^2 - 
             5101056*Zeta[3]) + 160*x^20*(20297529 + 32491303*Pi^2 - 
             524880*Zeta[3]) - 360*x^8*(-2088386 + 11055*Pi^2 - 
             233280*Zeta[3]) - 6*x^9*(-2366373523 + 2686050*Pi^2 + 
             6998400*Zeta[3]) + 300*x^12*(-37570841 + 2671378*Pi^2 + 
             23518080*Zeta[3]) + 60*x^16*(91469688*Pi^2 - 
             5*(96743131 + 23518080*Zeta[3]))))/(129600*(-1 + x)^6*x^5*
          (1 + x)^8*(9 - 82*x^2 + 9*x^4)^2) + 
        (-4800*Pi^4*x^7*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(1 + 4*x - 19*x^2 + 
            56*x^3 - 19*x^4 + 4*x^5 + x^6) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^2*
           (-77760 - 174960*x + 328860*x^2 + 998460*x^3 - 364410*x^4 - 
            2356710*x^5 - 416400*x^6 + 2929783*x^7 + 1546500*x^8 - 
            1926185*x^9 - 2676300*x^10 + 1432270*x^11 - 1432270*x^13 + 
            2676300*x^14 + 1926185*x^15 - 1546500*x^16 - 2929783*x^17 + 
            416400*x^18 + 2356710*x^19 + 364410*x^20 - 998460*x^21 - 
            328860*x^22 + 174960*x^23 + 77760*x^24) + 
          3*x^2*(-12597120 - 28343520*x + 280723320*x^2 + 673508520*x^3 - 
            2054492100*x^4 - 2769616800*x^29*Zeta[3] - 1156485600*x^30*
             Zeta[3] + 113374080*x^31*Zeta[3] + 50388480*x^32*Zeta[3] + 
            77760*x^28*(-162 + 115283*Zeta[3]) + 1620*x^6*
             (4131611 + 122904*Zeta[3]) + 116640*x^27*
             (-243 + 208352*Zeta[3]) + 405*x^5*(-15285113 + 349536*Zeta[3]) - 
            3600*x^8*(5203229 + 1118340*Zeta[3]) - 3240*x^26*
             (-86643 + 8387920*Zeta[3]) - 9720*x^25*(-69291 + 
              10086680*Zeta[3]) + 720*x^24*(-2852955 + 40300124*Zeta[3]) - 
            9*x^7*(-3140185031 + 321283200*Zeta[3]) - 
            120*x^14*(-3207606931 + 461701996*Zeta[3]) + 
            60*x^22*(96303897 + 493008728*Zeta[3]) - 
            40*x^12*(-13835275103 + 493167000*Zeta[3]) + 
            40*x^10*(-1002124325 + 578262672*Zeta[3]) - 
            160*x^16*(-401777807 + 793721172*Zeta[3]) - 
            60*x^20*(134786115 + 2138700832*Zeta[3]) + 
            8*x^9*(-5223864701 + 2505966960*Zeta[3]) + 
            40*x^18*(-208907525 + 4661504832*Zeta[3]) - 
            8*x^11*(16228902977 + 8652628200*Zeta[3]) + 
            15*x^23*(-357128811 + 14608733696*Zeta[3]) + 
            10*x^13*(-12916743709 + 16056549648*Zeta[3]) + 
            10*x^15*(-9150305269 + 17650532544*Zeta[3]) - 
            8*x^17*(-13101533623 + 22493175960*Zeta[3]) + 
            8*x^19*(-3577656701 + 32717701080*Zeta[3]) - 
            3*x^21*(-5452586493 + 99105974560*Zeta[3])))/
         (3110400*(-1 + x)^6*x^7*(1 + x)^8*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF*(NH*((x*(466560 + 3873744*x + 172225440*x^2 - 9453555*x^3 + 
             90194760*x^4 + 32261800*x^5 - 38253440*x^6 - 6593175*x^7 + 
             3974640*x^8 - 380392*x^9 - 153280*x^10 + 167455*x^11 - 
             760*x^12 - 10352*x^13 + 480*x^14 + 75*x^15)*HPL[{0}, x])/
           (4320*(-1 + x)^7*(1 + x)^9*(-9 + x^2)^2) + 
          lm^2*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
             (144*(-1 + x)^4*(1 + x)^6) + (x^3*(-2 + x - 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x)^5*(1 + x)^7)) + (x*(-116640 - 598428*x - 
             31298400*x^2 + 2336427*x^3 - 14110200*x^4 - 5818448*x^5 + 
             10848640*x^6 + 949125*x^7 - 528320*x^8 + 78880*x^9 - 
             129680*x^10 - 19991*x^11 + 6360*x^12 + 396*x^13 + 240*x^14 + 
             39*x^15)*HPL[{0, 0}, x])/(1080*(-1 + x)^7*(1 + x)^9*
            (-9 + x^2)^2) + lm*((4*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + 
                x^6) + 3*(7 - 32*x + 57*x^2 + 288*x^3 + 57*x^4 - 32*x^5 + 
                7*x^6))/(2592*(-1 + x)^4*(1 + x)^6) - 
            (x^2*(2 + 182*x - 57*x^2 + 290*x^3 - 22*x^4 + 12*x^5 + 3*x^6)*
              HPL[{0}, x])/(108*(-1 + x)^5*(1 + x)^7) - 
            ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0}, x])/(54*(-1 + x)^3*
              (1 + x)^5) + (x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*
                x^5 + 4*x^6 + x^7)*HPL[{0, 0}, x])/(27*(-1 + x)^6*
              (1 + x)^8) + ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/
             (54*(-1 + x)^3*(1 + x)^5)) - ((-41 + 689*x - 494*x^2 + 977*x^3 - 
             308*x^4 + 182*x^5 - 8*x^6 + 2*x^7 + x^8)*HPL[{-1, 0, 0}, x])/
           (27*(-1 + x^2)^6) + (x^3*(1132380 - 130707*x + 558360*x^2 + 
             226062*x^3 - 521820*x^4 + 17331*x^5 - 2760*x^6 - 11412*x^7 + 
             12300*x^8 + 1211*x^9 - 880*x^10 - 90*x^11 + 20*x^12 + 5*x^13)*
            HPL[{0, 0, 0}, x])/(135*(-1 + x)^7*(1 + x)^9*(-9 + x^2)^2) + 
          ((-77 + 471*x + 26*x^2 + 423*x^3 + 216*x^4 + 114*x^5 + 8*x^6 + 
             6*x^7 + x^8)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^8) + 
          ((38799 + 1532520*x - 73116*x^2 + 974880*x^3 + 263763*x^4 - 
             164880*x^5 - 19360*x^6 + 13600*x^7 - 5915*x^8 - 920*x^9 + 
             636*x^10 - 7*x^12)*master3l8a[x])/(1080*(-1 + x)^7*(1 + x)^9*
            (-9 + x^2)^2) - ((12933 + 259200*x + 6111*x^2 + 229680*x^3 + 
             38364*x^4 + 86520*x^5 - 6042*x^6 + 14760*x^7 - 107*x^8 - 
             1400*x^9 - 69*x^10 + 40*x^11 + 10*x^12)*master3l9a[x])/
           (1080*(-1 + x)^7*(1 + x)^9*(-9 + x^2)) + 
          (x^10*(1345891 - 901760*Zeta[3]) + x^14*(67707 - 7040*Zeta[3]) + 
            40*x^15*(-167 + 32*Zeta[3]) + 5*x^16*(-143 + 64*Zeta[3]) - 
            200*x^11*(-12577 + 160*Zeta[3]) - 60*x^13*(599 + 1024*Zeta[3]) - 
            4860*x*(90497 + 1792*Zeta[3]) + 300*x^5*(-855625 + 
              2176*Zeta[3]) + 1458*(-10473 + 3040*Zeta[3]) + 
            19*x^12*(-49467 + 5120*Zeta[3]) + 405*x^2*(-17675 + 
              34432*Zeta[3]) + 1080*x^3*(-857527 + 60832*Zeta[3]) + 
            180*x^9*(-157913 + 66432*Zeta[3]) - 120*x^7*(-1373397 + 
              579232*Zeta[3]) - 45*x^4*(446239 + 717056*Zeta[3]) + 
            3*x^8*(11157259 + 755200*Zeta[3]) + 9*x^6*(-13384447 + 
              1381760*Zeta[3]))/(25920*(-1 + x)^7*(1 + x)^9*(-9 + x^2)^2)) + 
        NM*(((-40*Pi^2*(1 - 9*x^2)^2*(-1 + x^2)^4*(1 + 4*x + 4*x^3 + x^4) + 
             3*(-760 - 3040*x + 11388*x^2 + 130640*x^3 - 94735*x^4 - 1793440*
                x^5 + 1010188*x^6 - 934840*x^7 - 3670395*x^8 + 62244640*x^9 - 
               13303220*x^10 + 128239520*x^11 + 4780955*x^12 + 35655840*
                x^13 + 23572044*x^14 + 4915080*x^15 + 7560135*x^16))*
            HPL[{0}, x])/(12960*(-1 + x)^7*(1 + x)^9*(1 - 9*x^2)^2) + 
          lm^2*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
             (144*(-1 + x)^4*(1 + x)^6) + (x^3*(-2 + x - 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x)^5*(1 + x)^7)) + ((1 + 4*x + 4*x^3 + x^4)*
            HPL[{-2, 0}, x])/(27*(-1 + x)^3*(1 + x)^5) - 
          ((-120 - 480*x + 1096*x^2 + 22000*x^3 - 5959*x^4 - 189360*x^5 + 
             78588*x^6 - 2698200*x^7 + 484687*x^8 + 17415440*x^9 - 
             7591900*x^10 + 75562320*x^11 - 2252733*x^12 + 27077760*x^13 + 
             14498136*x^14 + 2925720*x^15 + 5233005*x^16)*HPL[{0, 0}, x])/
           (1080*(-1 + x)^7*(1 + x)^9*(1 - 9*x^2)^2) + 
          lm*((4*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 3*(7 - 32*x + 
                57*x^2 + 288*x^3 + 57*x^4 - 32*x^5 + 7*x^6))/
             (2592*(-1 + x)^4*(1 + x)^6) - (x^2*(2 + 182*x - 57*x^2 + 290*
                x^3 - 22*x^4 + 12*x^5 + 3*x^6)*HPL[{0}, x])/
             (108*(-1 + x)^5*(1 + x)^7) - ((1 + 4*x + 4*x^3 + x^4)*
              HPL[{-1, 0}, x])/(54*(-1 + x)^3*(1 + x)^5) + 
            (x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*x^5 + 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x)^6*(1 + x)^8) + 
            ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x)^3*
              (1 + x)^5)) - ((1 + 4*x + 4*x^3 + x^4)*HPL[{2, 0}, x])/
           (27*(-1 + x)^3*(1 + x)^5) + ((-3 - 6*x + 24*x^2 - 194*x^3 + 
             308*x^4 - 965*x^5 + 478*x^6 - 685*x^7 + 43*x^8)*
            HPL[{-1, 0, 0}, x])/(27*(-1 + x^2)^6) + 
          ((-5 - 20*x - 50*x^2 + 1040*x^3 + 862*x^4 + 7540*x^5 - 3336*x^6 - 
             347200*x^7 + 165088*x^8 + 194580*x^9 - 1203214*x^10 + 
             14289040*x^11 - 750338*x^12 + 7127820*x^13 + 2739240*x^14 + 
             1101600*x^15 + 997353*x^16)*HPL[{0, 0, 0}, x])/
           (135*(-1 + x)^7*(1 + x)^9*(1 - 9*x^2)^2) + 
          ((3 + 18*x + 24*x^2 + 118*x^3 + 216*x^4 + 419*x^5 + 10*x^6 + 
             459*x^7 - 79*x^8)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^8) + 
          ((-20 - 80*x + 339*x^2 + 3520*x^3 - 2936*x^4 - 51960*x^5 + 
             27903*x^6 + 51840*x^7 - 127404*x^8 + 1592640*x^9 - 112959*x^10 + 
             691200*x^11 + 303480*x^12 + 68040*x^13 + 116397*x^14)*
            master3l8b[x])/(3240*(-1 + x)^7*x^2*(1 + x)^9*(1 - 9*x^2)^2) + 
          ((10 + 40*x - 69*x^2 - 1400*x^3 - 107*x^4 + 14760*x^5 - 6042*x^6 + 
             86520*x^7 + 38364*x^8 + 229680*x^9 + 6111*x^10 + 259200*x^11 + 
             12933*x^12)*master3l9b[x])/(3240*(-1 + x)^7*x^2*(1 + x)^9*
            (-1 + 9*x^2)) + (-150 - 600*x + x^6*(1108413 - 97280*Zeta[3]) + 
            x^2*(5500 - 320*Zeta[3]) - 40*x^3*(-1067 + 32*Zeta[3]) + 
            200*x^7*(22013 + 160*Zeta[3]) + 60*x^5*(-13151 + 1024*Zeta[3]) + 
            4860*x^17*(-3103 + 1792*Zeta[3]) - 300*x^13*(830921 + 
              2176*Zeta[3]) - 729*x^18*(10189 + 6080*Zeta[3]) + 
            x^4*(-111627 + 7040*Zeta[3]) - 540*x^9*(-57181 + 22144*Zeta[3]) + 
            2760*x^11*(-100899 + 25184*Zeta[3]) - 405*x^16*
             (71555 + 34432*Zeta[3]) - 1080*x^15*(-12697 + 60832*Zeta[3]) + 
            45*x^14*(-1209029 + 717056*Zeta[3]) - 3*x^10*(2372209 + 
              755200*Zeta[3]) + x^8*(-3855751 + 901760*Zeta[3]) - 
            9*x^12*(-6419567 + 1381760*Zeta[3]))/(25920*(-1 + x)^7*(1 + x)^9*
            (x - 9*x^3)^2)) + NL*(-(Pi^2*(1 + 4*x + 4*x^3 + x^4)*
             HPL[{-1}, x])/(324*(-1 + x)^3*(1 + x)^5) + 
          (x^2*(78 + 240*(89 + 9*Pi^2)*x - 3*(1777 + 360*Pi^2)*x^2 + 
             480*(10 + 9*Pi^2)*x^3 + (6081 - 1000*Pi^2)*x^4 + 
             80*(-333 + 25*Pi^2)*x^5 - 3*(241 + 20*Pi^2)*x^6 + 
             80*(6 + Pi^2)*x^7 + 5*(-21 + 4*Pi^2)*x^8)*HPL[{0}, x])/
           (6480*(-1 + x)^6*(1 + x)^8) + 
          lm^2*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
             (144*(-1 + x)^4*(1 + x)^6) + (x^3*(-2 + x - 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x)^5*(1 + x)^7)) + (Pi^2*(1 + 4*x + 4*x^3 + x^4)*
            HPL[{1}, x])/(324*(-1 + x)^3*(1 + x)^5) - 
          (x^3*(108 - 54*x + 216*x^2 - 50*x^3 + 100*x^4 - 3*x^5 + 4*x^6 + 
             x^7)*HPL[{-2, 0}, x])/(27*(-1 + x)^6*(1 + x)^8) - 
          ((13 + 80*x + 198*x^2 - 4360*x^3 + 1698*x^4 - 4360*x^5 + 198*x^6 + 
             80*x^7 + 13*x^8)*HPL[{-1, 0}, x])/(1080*(-1 + x)^5*(1 + x)^7) + 
          (x^3*(2400 - 1200*x + 5040*x^2 - 640*x^3 + 2560*x^4 - 45*x^5 + 
             200*x^6 + 43*x^7)*HPL[{0, 0}, x])/(540*(-1 + x)^6*(1 + x)^8) + 
          ((13 + 80*x + 198*x^2 - 4360*x^3 + 1698*x^4 - 4360*x^5 + 198*x^6 + 
             80*x^7 + 13*x^8)*HPL[{1, 0}, x])/(1080*(-1 + x)^5*(1 + x)^7) + 
          lm*((4*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 3*(7 - 32*x + 
                57*x^2 + 288*x^3 + 57*x^4 - 32*x^5 + 7*x^6))/
             (2592*(-1 + x)^4*(1 + x)^6) - (x^2*(2 + 182*x - 57*x^2 + 290*
                x^3 - 22*x^4 + 12*x^5 + 3*x^6)*HPL[{0}, x])/
             (108*(-1 + x)^5*(1 + x)^7) - ((1 + 4*x + 4*x^3 + x^4)*
              HPL[{-1, 0}, x])/(54*(-1 + x)^3*(1 + x)^5) + 
            (x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*x^5 + 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x)^6*(1 + x)^8) + 
            ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x)^3*
              (1 + x)^5)) + (x^3*(108 - 54*x + 216*x^2 - 50*x^3 + 100*x^4 - 
             3*x^5 + 4*x^6 + x^7)*HPL[{2, 0}, x])/(27*(-1 + x)^6*(1 + x)^8) + 
          ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, -1, 0}, x])/(27*(-1 + x)^3*
            (1 + x)^5) - ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 1, 0}, x])/
           (27*(-1 + x)^3*(1 + x)^5) - (2*x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 
             136*x^4 - 3*x^5 + 4*x^6 + x^7)*HPL[{0, 0, 0}, x])/
           (27*(-1 + x)^6*(1 + x)^8) - ((1 + 4*x + 4*x^3 + x^4)*
            HPL[{1, -1, 0}, x])/(27*(-1 + x)^3*(1 + x)^5) + 
          ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 1, 0}, x])/(27*(-1 + x)^3*
            (1 + x)^5) + (4*Pi^2*(-13 - 80*x - 185*x^2 + 4440*x^3 - 
              1500*x^4 + 1500*x^6 - 4440*x^7 + 185*x^8 + 80*x^9 + 13*x^10) - 
            3*(5 - 5111*x^8 + 3920*x^9 + 5*x^10 - 320*Zeta[3] - 
              80*x*(-49 + 16*Zeta[3]) - 480*x^7*(7 + 72*Zeta[3]) - 
              160*x^3*(21 + 200*Zeta[3]) - 160*x^5*(7 + 432*Zeta[3]) + 
              x^2*(-5111 + 960*Zeta[3]) + 6*x^6*(851 + 2880*Zeta[3]) + 
              2*x^4*(2553 + 8000*Zeta[3])))/(51840*(-1 + x)^6*(1 + x)^8))))
 
CbarData["p", 2, 3] = 
    NC*(CF*(NL*(-(Pi^2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*
             HPL[{-1}, x])/(810*(-1 + x)^5*(1 + x)^7) + 
          (x^2*(-6 + 90*(1047 + 80*Pi^2)*x - 3*(23143 + 2400*Pi^2)*x^2 + 
             45*(5027 + 720*Pi^2)*x^3 - 20*(1033 + 800*Pi^2)*x^4 + 
             25*(-7029 + 1264*Pi^2)*x^5 + (88824 - 7100*Pi^2)*x^6 + 
             5*(-28863 + 1460*Pi^2)*x^7 + (1626 - 80*Pi^2)*x^8 + 
             5*(-81 + 20*Pi^2)*x^9 + 5*(-71 + 4*Pi^2)*x^10)*HPL[{0}, x])/
           (16200*(-1 + x)^8*(1 + x)^10) + 
          lm^2*((1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 
              5*x^7 + x^8)/(180*(-1 + x)^6*(1 + x)^8) - 
            (2*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x)^7*(1 + x)^9)) + (Pi^2*(1 + 5*x - x^2 + 20*x^3 - 
             x^4 + 5*x^5 + x^6)*HPL[{1}, x])/(810*(-1 + x)^5*(1 + x)^7) - 
          (2*x^3*(360 - 360*x + 1620*x^2 - 800*x^3 + 1580*x^4 - 355*x^5 + 
             365*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{-2, 0}, x])/
           (135*(-1 + x)^8*(1 + x)^10) + ((1 - 25*x - 803*x^2 + 17070*x^3 - 
             14378*x^4 + 44510*x^5 - 14378*x^6 + 17070*x^7 - 803*x^8 - 
             25*x^9 + x^10)*HPL[{-1, 0}, x])/(2700*(-1 + x)^7*(1 + x)^9) + 
          (x^3*(6000 - 6000*x + 33000*x^2 - 16000*x^3 + 43000*x^4 - 
             9725*x^5 + 13525*x^6 - 116*x^7 + 325*x^8 + 59*x^9)*
            HPL[{0, 0}, x])/(1350*(-1 + x)^8*(1 + x)^10) + 
          ((-1 + 25*x + 803*x^2 - 17070*x^3 + 14378*x^4 - 44510*x^5 + 
             14378*x^6 - 17070*x^7 + 803*x^8 + 25*x^9 - x^10)*HPL[{1, 0}, x])/
           (2700*(-1 + x)^7*(1 + x)^9) + 
          lm*((71 + 81*x - 182*x^2 + 10179*x^3 - 4314*x^4 + 10179*x^5 - 
              182*x^6 + 81*x^7 + 71*x^8 + 4*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 
                15*x^5 - 2*x^6 + 5*x^7 + x^8))/(6480*(-1 + x)^6*(1 + x)^8) - 
            (x^2*(1 + 413*x - 334*x^2 + 1559*x^3 - 574*x^4 + 833*x^5 - 44*
                x^6 + 15*x^7 + 3*x^8)*HPL[{0}, x])/(135*(-1 + x)^7*
              (1 + x)^9) + ((-1 - 5*x + x^2 - 20*x^3 + x^4 - 5*x^5 - x^6)*
              HPL[{-1, 0}, x])/(135*(-1 + x)^5*(1 + x)^7) + 
            (2*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 1940*x^4 - 535*x^5 + 
               545*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x)^8*(1 + x)^10) + ((1 + 5*x - x^2 + 20*x^3 - x^4 + 5*
                x^5 + x^6)*HPL[{1, 0}, x])/(135*(-1 + x)^5*(1 + x)^7)) + 
          (2*x^3*(360 - 360*x + 1620*x^2 - 800*x^3 + 1580*x^4 - 355*x^5 + 
             365*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{2, 0}, x])/
           (135*(-1 + x)^8*(1 + x)^10) + (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 
             5*x^5 + x^6)*HPL[{-1, -1, 0}, x])/(135*(-1 + x)^5*(1 + x)^7) - 
          (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{-1, 1, 0}, x])/
           (135*(-1 + x)^5*(1 + x)^7) - (4*x^3*(180 - 180*x + 1260*x^2 - 
             800*x^3 + 1940*x^4 - 535*x^5 + 545*x^6 - 4*x^7 + 5*x^8 + x^9)*
            HPL[{0, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^10) - 
          (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{1, -1, 0}, x])/
           (135*(-1 + x)^5*(1 + x)^7) + (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 
             5*x^5 + x^6)*HPL[{1, 1, 0}, x])/(135*(-1 + x)^5*(1 + x)^7) + 
          (96972*x^10 - 48285*x^11 + 2365*x^12 - 12*Pi^2*(-1 + 25*x + 
              804*x^2 - 17095*x^3 + 13575*x^4 - 27440*x^5 + 27440*x^7 - 
              13575*x^8 + 17095*x^9 - 804*x^10 - 25*x^11 + x^12) + 
            45*x*(-1073 + 320*Zeta[3]) + 5*(473 + 576*Zeta[3]) - 
            12*x^2*(-8081 + 960*Zeta[3]) + 135*x^9*(2693 + 7680*Zeta[3]) + 
            45*x^3*(8079 + 23360*Zeta[3]) + 90*x^5*(-3503 + 50560*Zeta[3]) + 
            90*x^7*(-3503 + 51840*Zeta[3]) - 15*x^4*(6499 + 68160*Zeta[3]) - 
            15*x^8*(6499 + 69120*Zeta[3]) - 8*x^6*(463 + 288000*Zeta[3]))/
           (388800*(-1 + x)^8*(1 + x)^10)) + 
        NM*(((-2280 - 11400*x + 73452*x^2 + 1081140*x^3 - 1828239*x^4 - 
             32627445*x^5 + 38392273*x^6 + 278469990*x^7 - 405309622*x^8 + 
             1048381530*x^9 + 1130622306*x^10 - 19689020010*x^11 + 
             7281803612*x^12 + 16827011280*x^13 - 27485371124*x^14 + 
             232524544050*x^15 - 65392370802*x^16 + 204095829870*x^17 + 
             13529755458*x^18 + 7817020830*x^19 + 25940545731*x^20 - 
             2331134235*x^21 + 5314639635*x^22 - 40*Pi^2*(1 - 10*x^2 + 9*x^4)^
               4*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6))*HPL[{0}, x])/
           (32400*(-1 + x)^9*(1 + x)^11*(1 - 9*x^2)^4) + 
          lm^2*((1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 
              5*x^7 + x^8)/(180*(-1 + x)^6*(1 + x)^8) - 
            (2*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x)^7*(1 + x)^9)) + (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 
             5*x^5 + x^6)*HPL[{-2, 0}, x])/(135*(-1 + x)^5*(1 + x)^7) + 
          ((120 + 600*x - 3208*x^2 - 68600*x^3 + 90533*x^4 + 1696515*x^5 - 
             1792587*x^6 - 783270*x^7 + 9734400*x^8 - 276847440*x^9 + 
             120564172*x^10 + 1752361370*x^11 - 1334871578*x^12 + 
             4293282030*x^13 + 1240110138*x^14 - 34742728530*x^15 + 
             14251168728*x^16 - 44722497600*x^17 - 462919860*x^18 - 
             4142068650*x^19 - 5576432283*x^20 + 629691975*x^21 - 
             1226742975*x^22)*HPL[{0, 0}, x])/(2700*(-1 + x)^9*(1 + x)^11*
            (1 - 9*x^2)^4) + lm*((71 + 81*x - 182*x^2 + 10179*x^3 - 
              4314*x^4 + 10179*x^5 - 182*x^6 + 81*x^7 + 71*x^8 + 
              4*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 15*x^5 - 2*x^6 + 5*x^7 + 
                x^8))/(6480*(-1 + x)^6*(1 + x)^8) - 
            (x^2*(1 + 413*x - 334*x^2 + 1559*x^3 - 574*x^4 + 833*x^5 - 44*
                x^6 + 15*x^7 + 3*x^8)*HPL[{0}, x])/(135*(-1 + x)^7*
              (1 + x)^9) + ((-1 - 5*x + x^2 - 20*x^3 + x^4 - 5*x^5 - x^6)*
              HPL[{-1, 0}, x])/(135*(-1 + x)^5*(1 + x)^7) + 
            (2*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 1940*x^4 - 535*x^5 + 
               545*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x)^8*(1 + x)^10) + ((1 + 5*x - x^2 + 20*x^3 - x^4 + 5*
                x^5 + x^6)*HPL[{1, 0}, x])/(135*(-1 + x)^5*(1 + x)^7)) - 
          (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{2, 0}, x])/
           (135*(-1 + x)^5*(1 + x)^7) + (2*(-3 - 9*x + 33*x^2 - 692*x^3 + 
             1461*x^4 - 5405*x^5 + 4504*x^6 - 8648*x^7 + 2887*x^8 - 
             2676*x^9 + 148*x^10)*HPL[{-1, 0, 0}, x])/(135*(-1 + x^2)^8) + 
          (2*(-5 - 25*x + 45*x^2 + 3700*x^3 - 2879*x^4 - 32075*x^5 + 
             52445*x^6 - 1425030*x^7 + 946068*x^8 + 18388770*x^9 - 
             24935088*x^10 + 78965010*x^11 + 127888324*x^12 - 
             1785206170*x^13 + 303221596*x^14 + 4552985070*x^15 - 
             2696106015*x^16 + 9675214695*x^17 - 245293677*x^18 + 
             1804632210*x^19 + 994008267*x^20 + 38349045*x^21 + 
             232777719*x^22)*HPL[{0, 0, 0}, x])/(675*(-1 + x)^9*(1 + x)^11*
            (1 - 9*x^2)^4) + ((6 + 42*x + 54*x^2 + 1016*x^3 + 1178*x^4 + 
             4590*x^5 + 552*x^6 + 9624*x^7 - 2214*x^8 + 3988*x^9 - 476*x^10)*
            HPL[{1, 0, 0}, x])/(135*(-1 + x)^6*(1 + x)^10) + 
          ((-20 - 100*x + 677*x^2 + 10175*x^3 - 16927*x^4 - 319510*x^5 + 
             354946*x^6 + 3089550*x^7 - 4007742*x^8 + 5099130*x^9 + 
             15884316*x^10 - 198305460*x^11 + 38331132*x^12 + 
             548521470*x^13 - 307774962*x^14 + 1037858850*x^15 - 
             27042174*x^16 + 131308290*x^17 + 119366703*x^18 - 
             13380795*x^19 + 27278451*x^20)*master3l8b[x])/
           (8100*(-1 + x)^9*x^2*(1 + x)^11*(1 - 9*x^2)^4) + 
          ((10 + 50*x - 217*x^2 - 4525*x^3 + 3218*x^4 + 125585*x^5 - 
             81860*x^6 - 715605*x^7 + 971994*x^8 - 4605915*x^9 - 
             3343890*x^10 + 25139745*x^11 - 1347762*x^12 + 63294795*x^13 - 
             4941612*x^14 + 197741025*x^15 - 28697220*x^16 + 97495245*x^17 + 
             3030939*x^18)*master3l9b[x])/(8100*(-1 + x)^9*x^2*(1 + x)^11*
            (-1 + 9*x^2)^3) + (-450 - 2250*x + x^6*(22682778 - 
              993600*Zeta[3]) + x^3*(303330 - 4800*Zeta[3]) - 
            40*x^2*(-625 + 24*Zeta[3]) + 31744*x^10*(32942 + 375*Zeta[3]) + 
            15*x^5*(-693941 + 17280*Zeta[3]) + x^4*(-1014583 + 
              39360*Zeta[3]) + 98415*x^23*(-50041 + 93120*Zeta[3]) + 
            15*x^7*(9282743 + 360000*Zeta[3]) - 6561*x^24*
             (825139 + 452160*Zeta[3]) + 17*x^8*(-14902651 + 
              724800*Zeta[3]) + 2160*x^11*(-6037489 + 2033440*Zeta[3]) - 
            120*x^9*(1536061 + 2653280*Zeta[3]) - 10935*x^21*
             (-3585523 + 5919360*Zeta[3]) - 1458*x^22*(17315719 + 
              13286880*Zeta[3]) - 2430*x^19*(94107691 + 40065120*Zeta[3]) + 
            72*x^18*(1611206789 + 131067000*Zeta[3]) + 
            90*x^15*(-1422197881 + 173735680*Zeta[3]) + 
            243*x^20*(-340442729 + 183672000*Zeta[3]) + 
            810*x^17*(-893865471 + 192368000*Zeta[3]) - 
            90*x^13*(-1175315371 + 251241600*Zeta[3]) - 
            6*x^12*(-758669363 + 296812800*Zeta[3]) - 
            16*x^16*(-8521779803 + 2853572400*Zeta[3]) + 
            4*x^14*(-14407418483 + 3921134400*Zeta[3]))/(194400*(-1 + x)^9*
            x^2*(1 + x)^11*(1 - 9*x^2)^4)) + 
        NH*((x*(283435200 + 2636052336*x + 196662563280*x^2 - 
             73189006947*x^3 + 345787606395*x^4 + 7855418313*x^5 - 
             82125137250*x^6 + 36080629506*x^7 - 31408549470*x^8 - 
             15667801998*x^9 + 13035465990*x^10 + 2298151356*x^11 - 
             1812974520*x^12 - 41658812*x^13 + 120645690*x^14 - 
             23162002*x^15 - 3491970*x^16 + 2409006*x^17 - 20910*x^18 - 
             80713*x^19 + 3165*x^20 + 355*x^21)*HPL[{0}, x])/
           (32400*(-1 + x)^9*(1 + x)^11*(-9 + x^2)^4) + 
          lm^2*((1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 
              5*x^7 + x^8)/(180*(-1 + x)^6*(1 + x)^8) - 
            (2*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x)^7*(1 + x)^9)) + (x*(-23619600 - 135620244*x - 
             11978913420*x^2 + 4633602489*x^3 - 20372261805*x^4 - 
             532364643*x^5 + 7795632330*x^6 - 2772998208*x^7 + 
             2996508960*x^8 + 960603844*x^9 - 1234599070*x^10 - 
             82937602*x^11 + 104931950*x^12 - 7532486*x^13 + 5059230*x^14 + 
             1726192*x^15 - 990280*x^16 - 96128*x^17 + 27330*x^18 + 
             729*x^19 + 375*x^20 + 57*x^21)*HPL[{0, 0}, x])/
           (2700*(-1 + x)^9*(1 + x)^11*(-9 + x^2)^4) + 
          lm*((71 + 81*x - 182*x^2 + 10179*x^3 - 4314*x^4 + 10179*x^5 - 
              182*x^6 + 81*x^7 + 71*x^8 + 4*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 
                15*x^5 - 2*x^6 + 5*x^7 + x^8))/(6480*(-1 + x)^6*(1 + x)^8) - 
            (x^2*(1 + 413*x - 334*x^2 + 1559*x^3 - 574*x^4 + 833*x^5 - 44*
                x^6 + 15*x^7 + 3*x^8)*HPL[{0}, x])/(135*(-1 + x)^7*
              (1 + x)^9) + ((-1 - 5*x + x^2 - 20*x^3 + x^4 - 5*x^5 - x^6)*
              HPL[{-1, 0}, x])/(135*(-1 + x)^5*(1 + x)^7) + 
            (2*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 1940*x^4 - 535*x^5 + 
               545*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x)^8*(1 + x)^10) + ((1 + 5*x - x^2 + 20*x^3 - x^4 + 5*
                x^5 + x^6)*HPL[{1, 0}, x])/(135*(-1 + x)^5*(1 + x)^7)) - 
          (2*(-146 + 2682*x - 2909*x^2 + 8696*x^3 - 4568*x^4 + 5405*x^5 - 
             1397*x^6 + 644*x^7 - 11*x^8 + 3*x^9 + x^10)*HPL[{-1, 0, 0}, x])/
           (135*(-1 + x^2)^8) + (2*x^3*(445419000 - 190336311*x + 
             775432845*x^2 + 5632443*x^3 - 332973360*x^4 + 150293358*x^5 - 
             192779280*x^6 - 33539190*x^7 + 65856240*x^8 - 1896240*x^9 - 
             3466830*x^10 + 1149504*x^11 - 621840*x^12 - 122062*x^13 + 
             76600*x^14 + 5878*x^15 - 2600*x^16 - 185*x^17 + 25*x^18 + 
             5*x^19)*HPL[{0, 0, 0}, x])/(675*(-1 + x)^9*(1 + x)^11*
            (-9 + x^2)^4) + (2*(-236 + 2008*x - 1089*x^2 + 4844*x^3 + 
             332*x^4 + 2295*x^5 + 533*x^6 + 476*x^7 + 9*x^8 + 7*x^9 + x^10)*
            HPL[{1, 0, 0}, x])/(135*(-1 + x)^6*(1 + x)^10) + 
          ((9092817 + 589431735*x - 213992847*x^2 + 1077679890*x^3 - 
             1504134*x^4 - 98011530*x^5 + 97799490*x^6 - 74198550*x^7 - 
             31941876*x^8 + 21706500*x^9 + 2766452*x^10 - 2922730*x^11 + 
             196758*x^12 + 200730*x^13 - 44434*x^14 - 4370*x^15 + 2195*x^16 - 
             75*x^17 - 21*x^18)*master3l8a[x])/(2700*(-1 + x)^9*(1 + x)^11*
            (-9 + x^2)^4) + ((-3030939 - 97495245*x + 28697220*x^2 - 
             197741025*x^3 + 4941612*x^4 - 63294795*x^5 + 1347762*x^6 - 
             25139745*x^7 + 3343890*x^8 + 4605915*x^9 - 971994*x^10 + 
             715605*x^11 + 81860*x^12 - 125585*x^13 - 3218*x^14 + 4525*x^15 + 
             217*x^16 - 50*x^17 - 10*x^18)*master3l9a[x])/(2700*(-1 + x)^9*
            (1 + x)^11*(-9 + x^2)^3) + 
          (x^10*(70930497362 - 15684537600*Zeta[3]) + 
            x^14*(663879382 - 11904000*Zeta[3]) + 
            x^17*(60655830 - 5400000*Zeta[3]) + x^20*(566698 - 
              39360*Zeta[3]) + 5*x^22*(-797 + 192*Zeta[3]) + 
            15*x^21*(-2897 + 320*Zeta[3]) - 590490*x*(860959 + 
              15520*Zeta[3]) - 15*x^19*(41839 + 17280*Zeta[3]) + 
            52488*(-200887 + 56520*Zeta[3]) + 3*x^18*(-4717421 + 
              331200*Zeta[3]) - 16*x^16*(-6230327 + 770100*Zeta[3]) + 
            60*x^15*(-18832693 + 5306560*Zeta[3]) - 270*x^13*
             (-38093777 + 16267520*Zeta[3]) + 3645*x^3*(-454059989 + 
              17758080*Zeta[3]) + 729*x^2*(217379693 + 26573760*Zeta[3]) - 
            360*x^9*(-184326259 + 43433920*Zeta[3]) - 
            486*x^4*(-578858207 + 91836000*Zeta[3]) - 
            1620*x^7*(-269517793 + 96184000*Zeta[3]) + 
            12*x^12*(-1129346239 + 148406400*Zeta[3]) + 
            405*x^5*(-2865596539 + 240390720*Zeta[3]) + 
            90*x^11*(-549165631 + 251241600*Zeta[3]) - 
            9*x^6*(12466764877 + 1048536000*Zeta[3]) + 
            8*x^8*(-14383222201 + 5707144800*Zeta[3]))/(194400*(-1 + x)^9*
            (1 + x)^11*(-9 + x^2)^4))) + 
      CA*CF*((Pi^2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 
           5*x^7 + x^8)*HPL[{-2}, x])/(270*(-1 + x)^6*(1 + x)^8) + 
        lm^2*((-11*(1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 
             5*x^7 + x^8))/(360*(-1 + x)^6*(1 + x)^8) + 
          (11*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
           (3*(-1 + x)^7*(1 + x)^9)) - (Pi^2*(1 + 5*x - 50*x^2 + 245*x^3 - 
           242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{2}, x])/
         (270*(-1 + x)^6*(1 + x)^8) + (x*(-30 + 1290*x - 2475*x^2 + 
           9840*x^3 - 75135*x^4 + 35780*x^5 - 50015*x^6 + 37750*x^7 - 
           38600*x^8 - 61052*x^9 + 31597*x^10 + 82454*x^11 - 9660*x^12 - 
           68520*x^13 - 7500*x^14 + 35160*x^15 + 9105*x^16 - 10230*x^17 - 
           3735*x^18 + 1296*x^19 + 576*x^20)*HPL[{-2, 0}, x])/
         (1350*(-1 + x)^8*(1 + x)^10) + 
        ((-5760 - 12960*x + 28710*x^2 + 82860*x^3 - 45585*x^4 - 221910*x^5 - 
           5100*x^6 + 4*(80718 + 25*Pi^2)*x^7 + (145569 + 500*Pi^2)*x^8 - 
           2*(147523 + 2550*Pi^2)*x^9 + 2*(77257 + 12000*Pi^2)*x^10 - 
           32*(6083 + 600*Pi^2)*x^11 + 914024*x^12 + 32*(-6083 + 600*Pi^2)*
            x^13 + (154514 - 24000*Pi^2)*x^14 + (-295046 + 5100*Pi^2)*x^15 + 
           (145569 - 500*Pi^2)*x^16 - 4*(-80718 + 25*Pi^2)*x^17 - 5100*x^18 - 
           221910*x^19 - 45585*x^20 + 82860*x^21 + 28710*x^22 - 12960*x^23 - 
           5760*x^24)*HPL[{-1, 0}, x])/(27000*(-1 + x)^7*x^7*(1 + x)^9) + 
        (x*(-11809800 + 520637220*x - 10141162740*x^2 - 547327125*x^3 + 
           303619643865*x^4 - 323011723050*x^5 - 2599762873275*x^6 + 
           5368484145330*x^7 - 1054252087425*x^8 - 33864946932034*x^9 + 
           95235525626947*x^10 + 87203138478249*x^11 - 193499362766224*x^12 - 
           98497791861664*x^13 - 589685341071424*x^14 + 217859066411444*
            x^15 - 271223390649598*x^16 - 71406459566864*x^17 + 
           175121593852890*x^18 - 50666613438579*x^19 - 33777658550463*x^20 + 
           55787234655174*x^21 + 11899592917101*x^22 - 26407866755694*x^23 - 
           7076793104109*x^24 + 7543074059694*x^25 + 2519461764567*x^26 - 
           1317043155969*x^27 - 500083749450*x^28 + 135205894980*x^29 + 
           55407404430*x^30 - 7455133080*x^31 - 3206885580*x^32 + 
           170061120*x^33 + 75582720*x^34)*HPL[{0, 0}, x])/
         (27000*(-1 + x)^8*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^4) + 
        ((5760 + 12960*x - 28710*x^2 - 82860*x^3 + 45585*x^4 + 221910*x^5 + 
           5100*x^6 - 4*(80718 + 25*Pi^2)*x^7 - (145569 + 500*Pi^2)*x^8 + 
           (295046 + 5100*Pi^2)*x^9 - 2*(77257 + 12000*Pi^2)*x^10 + 
           32*(6083 + 600*Pi^2)*x^11 - 914024*x^12 - 32*(-6083 + 600*Pi^2)*
            x^13 + 2*(-77257 + 12000*Pi^2)*x^14 + (295046 - 5100*Pi^2)*x^15 + 
           (-145569 + 500*Pi^2)*x^16 + 4*(-80718 + 25*Pi^2)*x^17 + 
           5100*x^18 + 221910*x^19 + 45585*x^20 - 82860*x^21 - 28710*x^22 + 
           12960*x^23 + 5760*x^24)*HPL[{1, 0}, x])/(27000*(-1 + x)^7*x^7*
          (1 + x)^9) + lm*(-(1285 + 3411*x - 9058*x^2 + 185049*x^3 - 
             94830*x^4 + 185049*x^5 - 9058*x^6 + 3411*x^7 + 1285*x^8 + 
             44*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 15*x^5 - 2*x^6 + 5*x^7 + x^
                8))/(12960*(-1 + x)^6*(1 + x)^8) + 
          (x^2*(11 + 5803*x - 4934*x^2 + 20929*x^3 - 7574*x^4 + 10423*x^5 - 
             484*x^6 + 165*x^7 + 33*x^8)*HPL[{0}, x])/(270*(-1 + x)^7*
            (1 + x)^9) + (11*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*
            HPL[{-1, 0}, x])/(270*(-1 + x)^5*(1 + x)^7) - 
          (11*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 1940*x^4 - 535*x^5 + 
             545*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{0, 0}, x])/
           (135*(-1 + x)^8*(1 + x)^10) - (11*(1 + 5*x - x^2 + 20*x^3 - x^4 + 
             5*x^5 + x^6)*HPL[{1, 0}, x])/(270*(-1 + x)^5*(1 + x)^7)) + 
        (x*(30 - 1290*x + 2475*x^2 - 9840*x^3 + 75135*x^4 - 35780*x^5 + 
           50015*x^6 - 37750*x^7 + 38600*x^8 + 61052*x^9 - 31597*x^10 - 
           82454*x^11 + 9660*x^12 + 68520*x^13 + 7500*x^14 - 35160*x^15 - 
           9105*x^16 + 10230*x^17 + 3735*x^18 - 1296*x^19 - 576*x^20)*
          HPL[{2, 0}, x])/(1350*(-1 + x)^8*(1 + x)^10) - 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-2, -1, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        (8*x^2*(-24 + 115*x - 121*x^2 + 130*x^3 - 26*x^4 + 5*x^5 + x^6)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-2, 1, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-1, -2, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) - 
        ((576 + 1296*x - 2007*x^2 - 6342*x^3 + 1356*x^4 + 12246*x^5 + 
           3165*x^6 - 11460*x^7 - 6240*x^8 + 5104*x^9 + 5318*x^10 - 
           844*x^11 + 2264*x^12 - 844*x^13 + 5318*x^14 + 5104*x^15 - 
           6240*x^16 - 11460*x^17 + 3165*x^18 + 12246*x^19 + 1356*x^20 - 
           6342*x^21 - 2007*x^22 + 1296*x^23 + 576*x^24)*HPL[{-1, -1, 0}, x])/
         (2700*(-1 + x)^5*x^9*(1 + x)^7) + 
        ((-203 + 582*x - 1331*x^2 + 26360*x^3 - 44714*x^4 + 74114*x^5 - 
           37514*x^6 + 41480*x^7 - 11411*x^8 - 31053*x^9 + 11245*x^10 + 
           39816*x^11 - 8736*x^12 - 32004*x^13 + 4224*x^14 + 16056*x^15 - 
           1176*x^16 - 4599*x^17 + 144*x^18 + 576*x^19)*HPL[{-1, 0, 0}, x])/
         (1350*(-1 + x^2)^8) + ((576 + 1296*x - 2007*x^2 - 6342*x^3 + 
           1356*x^4 + 12246*x^5 + 3165*x^6 - 11460*x^7 - 6240*x^8 + 
           5104*x^9 + 5318*x^10 - 844*x^11 + 2264*x^12 - 844*x^13 + 
           5318*x^14 + 5104*x^15 - 6240*x^16 - 11460*x^17 + 3165*x^18 + 
           12246*x^19 + 1356*x^20 - 6342*x^21 - 2007*x^22 + 1296*x^23 + 
           576*x^24)*HPL[{-1, 1, 0}, x])/(2700*(-1 + x)^5*x^9*(1 + x)^7) - 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-1, 2, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        (x*(196830 - 8070030*x + 356513805*x^2 - 370005651*x^3 - 
           9139532535*x^4 + 19576634256*x^5 + 42301223811*x^6 - 
           306290660436*x^7 + 638260657491*x^8 + 2261731865694*x^9 - 
           6554153714892*x^10 - 8665747640091*x^11 + 12546516066138*x^12 + 
           18271448612816*x^13 + 21126767941126*x^14 - 25328170972448*x^15 + 
           30430975020202*x^16 + 22842828791530*x^17 - 18465495677669*x^18 - 
           17527820957353*x^19 + 4294376328381*x^20 + 12886004067648*x^21 + 
           430808558487*x^22 - 7497482831004*x^23 - 1329704954265*x^24 + 
           3052037815194*x^25 + 829593175014*x^26 - 820531553769*x^27 - 
           276736945680*x^28 + 138419510688*x^29 + 52752336048*x^30 - 
           13891928976*x^31 - 5700454866*x^32 + 754016364*x^33 + 
           324467694*x^34 - 17006112*x^35 - 7558272*x^36)*HPL[{0, 0, 0}, x])/
         (1350*(-1 + x)^8*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^4) - 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{1, -2, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        ((576 + 1296*x - 2007*x^2 - 6342*x^3 + 1356*x^4 + 12246*x^5 + 
           3165*x^6 - 11460*x^7 - 6240*x^8 + 5104*x^9 + 5318*x^10 - 
           844*x^11 + 2264*x^12 - 844*x^13 + 5318*x^14 + 5104*x^15 - 
           6240*x^16 - 11460*x^17 + 3165*x^18 + 12246*x^19 + 1356*x^20 - 
           6342*x^21 - 2007*x^22 + 1296*x^23 + 576*x^24)*HPL[{1, -1, 0}, x])/
         (2700*(-1 + x)^5*x^9*(1 + x)^7) - 
        ((-203 + 10*x + 1053*x^2 + 28376*x^3 + 32774*x^4 + 10266*x^5 + 
           14558*x^6 + 21464*x^7 + 32805*x^8 + 33751*x^9 - 26375*x^10 - 
           55008*x^11 - 1500*x^12 + 42348*x^13 + 17676*x^14 - 14496*x^15 - 
           11508*x^16 + 585*x^17 + 2448*x^18 + 576*x^19)*HPL[{1, 0, 0}, x])/
         (1350*(-1 + x)^6*(1 + x)^10) - 
        ((576 + 1296*x - 2007*x^2 - 6342*x^3 + 1356*x^4 + 12246*x^5 + 
           3165*x^6 - 11460*x^7 - 6240*x^8 + 5104*x^9 + 5318*x^10 - 
           844*x^11 + 2264*x^12 - 844*x^13 + 5318*x^14 + 5104*x^15 - 
           6240*x^16 - 11460*x^17 + 3165*x^18 + 12246*x^19 + 1356*x^20 - 
           6342*x^21 - 2007*x^22 + 1296*x^23 + 576*x^24)*HPL[{1, 1, 0}, x])/
         (2700*(-1 + x)^5*x^9*(1 + x)^7) + 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{1, 2, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{2, -1, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) - 
        (8*x^2*(-24 + 115*x - 121*x^2 + 130*x^3 - 26*x^4 + 5*x^5 + x^6)*
          HPL[{2, 0, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) - 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{2, 1, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) - 
        (4*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{-1, 0, 0, 0}, 
           x])/(45*(-1 + x)^5*(1 + x)^7) + 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-1, 1, 0, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{1, -1, 0, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        (4*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{1, 0, 0, 0}, x])/
         (45*(-1 + x)^5*(1 + x)^7) - ((1 + 8*x - 39*x^2 + 359*x^3 - 353*x^4 + 
           651*x^5 - 161*x^6 + 119*x^7 + 12*x^8 + 3*x^9)*master3l10a[x])/
         (180*(-1 + x)^7*(1 + x)^9) + (x*(3 + 12*x + 119*x^2 - 161*x^3 + 
           651*x^4 - 353*x^5 + 359*x^6 - 39*x^7 + 8*x^8 + x^9)*
          master3l10b[x])/(180*(-1 + x)^7*(1 + x)^9) + 
        ((-22599 + 62421354*x - 196915212*x^2 + 366482556*x^3 - 
           205839180*x^4 + 149609106*x^5 + 9454680*x^6 - 88567884*x^7 + 
           25698522*x^8 + 10580814*x^9 - 6134716*x^10 + 118580*x^11 + 
           550620*x^12 - 84170*x^13 - 19792*x^14 + 3612*x^15 + 157*x^16)*
          master3l8a[x])/(10800*(-1 + x)^8*(1 + x)^10*(-9 + x^2)^4) + 
        ((40 - 1837*x + 2848*x^2 + 72224*x^3 - 125038*x^4 - 1250220*x^5 + 
           1582952*x^6 + 11916132*x^7 - 7274646*x^8 - 61801058*x^9 + 
           4353216*x^10 + 139324296*x^11 + 6170022*x^12 - 29581524*x^13 + 
           173969208*x^14 + 26955828*x^15 + 5346486*x^16 - 764721*x^17)*
          master3l8b[x])/(10800*(-1 + x)^8*x*(1 + x)^10*(1 - 9*x^2)^4) + 
        ((-41229 - 3170826*x + 12432699*x^2 - 11047500*x^3 + 11173503*x^4 - 
           9196338*x^5 + 8456479*x^6 + 4140468*x^7 - 3921479*x^8 - 
           531918*x^9 + 567105*x^10 + 22252*x^11 - 37035*x^12 + 202*x^13 + 
           997*x^14 - 20*x^15)*master3l9a[x])/(3600*(-1 + x)^8*(1 + x)^10*
          (-9 + x^2)^3) + ((-20 + 997*x + 202*x^2 - 37035*x^3 + 22252*x^4 + 
           567105*x^5 - 531918*x^6 - 3921479*x^7 + 4140468*x^8 + 
           8456479*x^9 - 9196338*x^10 + 11173503*x^11 - 11047500*x^12 + 
           12432699*x^13 - 3170826*x^14 - 41229*x^15)*master3l9b[x])/
         (10800*(-1 + x)^8*x*(1 + x)^10*(-1 + 9*x^2)^3) + 
        (HPL[{1}, x]*(Pi^2*(576 + 1296*x - 2583*x^2 - 7638*x^3 + 3363*x^4 + 
             18588*x^5 + 1809*x^6 - 23706*x^7 - 9405*x^8 + 16564*x^9 + 
             11558*x^10 - 5948*x^11 - 3054*x^12 + 3054*x^14 + 5948*x^15 - 
             11558*x^16 - 16564*x^17 + 9405*x^18 + 23706*x^19 - 1809*x^20 - 
             18588*x^21 - 3363*x^22 + 7638*x^23 + 2583*x^24 - 1296*x^25 - 
             576*x^26) - 1440*x^9*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
             245*x^5 - 50*x^6 + 5*x^7 + x^8)*Zeta[3]))/(32400*(-1 + x)^6*x^9*
          (1 + x)^8) + (HPL[{-1}, x]*(Pi^2*(-576 - 1296*x + 2583*x^2 + 
             7638*x^3 - 3363*x^4 - 18588*x^5 - 1809*x^6 + 23706*x^7 + 
             9405*x^8 - 16564*x^9 - 11558*x^10 + 5948*x^11 + 3054*x^12 - 
             3054*x^14 - 5948*x^15 + 11558*x^16 + 16564*x^17 - 9405*x^18 - 
             23706*x^19 + 1809*x^20 + 18588*x^21 + 3363*x^22 - 7638*x^23 - 
             2583*x^24 + 1296*x^25 + 576*x^26) + 1440*x^9*(1 + 5*x - 50*x^2 + 
             245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*Zeta[3]))/
         (32400*(-1 + x)^6*x^9*(1 + x)^8) + 
        (HPL[{0}, x]*(226748160 + 510183360*x - 9507282660*x^2 - 
           22110307560*x^3 + 161487467640*x^4 + 394605046440*x^5 + 
           1215*(-1168778563 + 3240*Pi^2)*x^6 - 4374*(861149891 + 38700*Pi^2)*
            x^7 - 20*(-9377207229065 + 657157005176*Pi^2)*x^19 + 
           24*(159633707391 + 1271156451320*Pi^2)*x^31 + 
           180*(7925412789 + 46079914813*Pi^2)*x^32 - 
           135*(2929020669 + 60778996808*Pi^2)*x^33 - 
           360*(448576299 + 7687137380*Pi^2)*x^34 + 
           29160*(758241 + 47468968*Pi^2)*x^35 + 
           1620*(5868693 + 325631704*Pi^2)*x^36 - 349920*(1458 + 397003*Pi^2)*
            x^37 - 43740*(5184 + 1303259*Pi^2)*x^38 + 7540163640*Pi^2*x^39 + 
           3244676940*Pi^2*x^40 - 170061120*Pi^2*x^41 - 75582720*Pi^2*x^42 + 
           30*x^18*(10007221817567 + 1964244353636*Pi^2 - 5220591091200*
              Zeta[3]) + 12*x^15*(-18243162336697 + 45222440320*Pi^2 - 
             2195366976000*Zeta[3]) + 3*x^28*(2435097086541 + 
             1842971916740*Pi^2 - 97627680000*Zeta[3]) - 
           81*x^10*(214085735633 + 4500*Pi^2 - 3615840000*Zeta[3]) - 
           6*x^30*(1116927497007 + 2216188370180*Pi^2 - 1417176000*Zeta[3]) + 
           27*x^8*(253885802771 + 6714900*Pi^2 - 314928000*Zeta[3]) + 
           81*x^9*(260701084897 + 60220800*Pi^2 + 104976000*Zeta[3]) - 
           450*x^11*(162555269027 + 94723992*Pi^2 + 688642560*Zeta[3]) - 
           6*x^29*(3840147140247 + 12437287972580*Pi^2 + 1417176000*
              Zeta[3]) + 30*x^27*(3372238047255 + 4140862781336*Pi^2 + 
             10329638400*Zeta[3]) + 18*x^13*(8962990419283 + 
             2694022500*Pi^2 + 236703384000*Zeta[3]) + 
           60*x^14*(2200981212237 + 62149398400*Pi^2 + 291744828000*
              Zeta[3]) - 9*x^12*(-1036110693347 + 22448026500*Pi^2 + 
             403597728000*Zeta[3]) - 6*x^16*(101178006747923 + 
             4207986708690*Pi^2 + 929879568000*Zeta[3]) + 
           3*x^26*(44423908626009 + 7204364199380*Pi^2 + 1210793184000*
              Zeta[3]) - 5*x^24*(173931429546279 + 9820611655840*Pi^2 + 
             3500937936000*Zeta[3]) - x^25*(373899649098169 + 
             143381162972080*Pi^2 + 4260660912000*Zeta[3]) + 
           x^22*(1198090137251163 + 37941449649460*Pi^2 + 5579277408000*
              Zeta[3]) + 2*x^23*(508827579850707 + 57525698624360*Pi^2 + 
             13172201856000*Zeta[3]) - 4*x^21*(338470872522069 + 
             13975303708100*Pi^2 + 15711784488000*Zeta[3]) + 
           3*x^17*(57129955100017 + 755498057080*Pi^2 + 20949045984000*
              Zeta[3]) + 10*x^20*(305602153708*Pi^2 + 
             51*(6096140591399 + 307093593600*Zeta[3]))))/
         (324000*(-1 + x)^8*x^5*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^4) + 
        (240*Pi^4*x^7*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (-3 - 15*x - 234*x^2 + 1105*x^3 - 1210*x^4 + 1345*x^5 - 266*x^6 + 
            65*x^7 + 13*x^8) + 12*Pi^2*(9 - 82*x^2 + 9*x^4)^4*
           (-5760 - 12960*x + 34470*x^2 + 95820*x^3 - 74295*x^4 - 
            304770*x^5 + 40485*x^6 + 544782*x^7 + 150669*x^8 - 617918*x^9 + 
            8945*x^10 + 100390*x^11 + 759510*x^12 - 759510*x^14 - 
            100390*x^15 - 8945*x^16 + 617918*x^17 - 150669*x^18 - 
            544782*x^19 - 40485*x^20 + 304770*x^21 + 74295*x^22 - 
            95820*x^23 - 34470*x^24 + 12960*x^25 + 5760*x^26) + 
          x^2*(-680244480 - 1530550080*x + 28748596140*x^2 + 
            66841106040*x^3 - 493796081520*x^4 - 271445891040*x^39*Zeta[3] - 
            116808369840*x^40*Zeta[3] + 6122200320*x^41*Zeta[3] + 
            2720977920*x^42*Zeta[3] + 32805*x^5*(-36950231 + 35712*Zeta[3]) - 
            29160*x^6*(-143812181 + 373734*Zeta[3]) + 6298560*x^37*
             (-243 + 794006*Zeta[3]) + 1574640*x^38*(-432 + 1303259*Zeta[
                3]) - 2916*x^7*(-4377968929 + 22298040*Zeta[3]) + 
            324*x^8*(-48848934413 + 50043420*Zeta[3]) - 262440*x^35*
             (-254691 + 189875872*Zeta[3]) - 14580*x^36*(-1971783 + 
              1302526816*Zeta[3]) + 243*x^9*(-409374449101 + 5484234240*Zeta[
                3]) - 3888*x^12*(63319044551 + 43904811430*Zeta[3]) + 
            1620*x^34*(-304867071 + 61497099040*Zeta[3]) - 
            2376*x^28*(-39647528981 + 79567955540*Zeta[3]) + 
            108*x^10*(158282931857 + 81467820360*Zeta[3]) - 
            3240*x^32*(-1372570209 + 92162347592*Zeta[3]) - 
            72*x^11*(-8741359875197 + 191986282800*Zeta[3]) + 
            1215*x^33*(-991342287 + 243117379136*Zeta[3]) - 
            180*x^15*(-20146975664831 + 3888368468320*Zeta[3]) + 
            108*x^30*(-218759101089 + 4431734617720*Zeta[3]) - 
            108*x^26*(3544925516111 + 8908407494360*Zeta[3]) - 
            108*x^31*(-105503235183 + 10170104676640*Zeta[3]) + 
            108*x^14*(24738394306711 + 11888060251000*Zeta[3]) + 
            5*x^13*(-508973095636355 + 19571874780096*Zeta[3]) - 
            180*x^23*(5148170516389 + 26935017844496*Zeta[3]) - 
            96*x^16*(45015231369733 + 40838011131840*Zeta[3]) - 
            256*x^19*(-39778711073069 + 45761028781590*Zeta[3]) - 
            72*x^27*(-1528442446997 + 62364673334640*Zeta[3]) + 
            36*x^24*(25186501622883 + 88528634951200*Zeta[3]) + 
            27*x^29*(-2124046149759 + 99566730260800*Zeta[3]) + 
            24*x^18*(-645092073920849 + 101631649404120*Zeta[3]) - 
            48*x^22*(-42754999128709 + 127233754812630*Zeta[3]) + 
            12*x^20*(-765758728457623 + 351105001992240*Zeta[3]) + 
            5*x^25*(48848328816415 + 1054649176336512*Zeta[3]) + 
            3*x^17*(931574668022351 + 1384278704792640*Zeta[3]) + 
            x^21*(-3111682800853497 + 6272777047512960*Zeta[3])))/
         (3888000*(-1 + x)^8*x^7*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^4)) + 
      CF^2*(-(Pi^2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 
            5*x^7 + x^8)*HPL[{-2}, x])/(135*(-1 + x)^6*(1 + x)^8) + 
        lm^2*((1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 
            5*x^7 + x^8)/(10*(-1 + x)^6*(1 + x)^8) - 
          (12*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
           ((-1 + x)^7*(1 + x)^9)) + (Pi^2*(1 + 5*x - 50*x^2 + 245*x^3 - 
           242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{2}, x])/
         (135*(-1 + x)^6*(1 + x)^8) + (x*(60 - 2580*x + 16890*x^2 - 
           28500*x^3 + 216150*x^4 - 102320*x^5 + 43190*x^6 - 147130*x^7 + 
           325660*x^8 + 412803*x^9 - 418722*x^10 - 812413*x^11 + 
           317296*x^12 + 989548*x^13 - 61264*x^14 - 773847*x^15 - 
           109254*x^16 + 379803*x^17 + 106026*x^18 - 106896*x^19 - 
           40512*x^20 + 13200*x^21 + 6000*x^22)*HPL[{-2, 0}, x])/
         (1350*(-1 + x)^8*(1 + x)^10) + ((-360000 - 792000*x + 1890720*x^2 + 
           5225760*x^3 - 3375480*x^4 - 14619540*x^5 + 719220*x^6 + 
           22357110*x^7 + 6087840*x^8 - (19946173 + 1200*Pi^2)*x^9 - 
           20*(505147 + 300*Pi^2)*x^10 + 3*(3422023 + 20400*Pi^2)*x^11 - 
           40*(-90929 + 7200*Pi^2)*x^12 + (2858734 + 230400*Pi^2)*x^13 - 
           21084240*x^14 + (2858734 - 230400*Pi^2)*x^15 + 
           40*(90929 + 7200*Pi^2)*x^16 + (10266069 - 61200*Pi^2)*x^17 + 
           20*(-505147 + 300*Pi^2)*x^18 + (-19946173 + 1200*Pi^2)*x^19 + 
           6087840*x^20 + 22357110*x^21 + 719220*x^22 - 14619540*x^23 - 
           3375480*x^24 + 5225760*x^25 + 1890720*x^26 - 792000*x^27 - 
           360000*x^28)*HPL[{-1, 0}, x])/(162000*(-1 + x)^7*x^9*(1 + x)^9) + 
        (x*(70858800 - 3317897700*x + 71883628200*x^2 + 12478132620*x^3 - 
           2150931959550*x^4 + 1738112221170*x^5 + 18679600823850*x^6 - 
           29584605691575*x^7 + 1022929740630*x^8 + 180954915419358*x^9 - 
           610476981434370*x^10 - 403923962550363*x^11 + 1044673618325640*
            x^12 + 193054704625498*x^13 + 5107315230871640*x^14 - 
           354355949021818*x^15 + 315663050111780*x^16 - 1743757818268912*
            x^17 + 67099971371540*x^18 + 3401247748578478*x^19 - 
           349345453104030*x^20 - 3278082703495218*x^21 - 
           174097018768470*x^22 + 2058560083476093*x^23 + 
           382888271550270*x^24 - 868106451224538*x^25 - 244356928116570*
            x^26 + 239270788678113*x^27 + 83224339080660*x^28 - 
           41099739060330*x^29 - 16104161938860*x^30 + 4178057178420*x^31 + 
           1758604578840*x^32 - 228859227360*x^33 - 100847293920*x^34 + 
           5196312000*x^35 + 2361960000*x^36)*HPL[{0, 0}, x])/
         (81000*(-1 + x)^8*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^4) + 
        ((360000 + 792000*x - 1890720*x^2 - 5225760*x^3 + 3375480*x^4 + 
           14619540*x^5 - 719220*x^6 - 22357110*x^7 - 6087840*x^8 + 
           (19946173 + 1200*Pi^2)*x^9 + 20*(505147 + 300*Pi^2)*x^10 - 
           3*(3422023 + 20400*Pi^2)*x^11 + 40*(-90929 + 7200*Pi^2)*x^12 - 
           2*(1429367 + 115200*Pi^2)*x^13 + 21084240*x^14 + 
           (-2858734 + 230400*Pi^2)*x^15 - 40*(90929 + 7200*Pi^2)*x^16 + 
           3*(-3422023 + 20400*Pi^2)*x^17 - 20*(-505147 + 300*Pi^2)*x^18 + 
           (19946173 - 1200*Pi^2)*x^19 - 6087840*x^20 - 22357110*x^21 - 
           719220*x^22 + 14619540*x^23 + 3375480*x^24 - 5225760*x^25 - 
           1890720*x^26 + 792000*x^27 + 360000*x^28)*HPL[{1, 0}, x])/
         (162000*(-1 + x)^7*x^9*(1 + x)^9) + 
        lm*((22 - 27*x + 98*x^2 + 3132*x^3 - 888*x^4 + 3132*x^5 + 98*x^6 - 
            27*x^7 + 22*x^8 + 2*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 15*x^5 - 
              2*x^6 + 5*x^7 + x^8))/(180*(-1 + x)^6*(1 + x)^8) - 
          (x^2*(2 + 691*x - 533*x^2 + 2713*x^3 - 1013*x^4 + 1531*x^5 - 
             88*x^6 + 30*x^7 + 6*x^8)*HPL[{0}, x])/(15*(-1 + x)^7*
            (1 + x)^9) - (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*
            HPL[{-1, 0}, x])/(15*(-1 + x)^5*(1 + x)^7) + 
          (4*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 1940*x^4 - 535*x^5 + 
             545*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{0, 0}, x])/
           (15*(-1 + x)^8*(1 + x)^10) + (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 
             5*x^5 + x^6)*HPL[{1, 0}, x])/(15*(-1 + x)^5*(1 + x)^7)) - 
        (x*(60 - 2580*x + 16890*x^2 - 28500*x^3 + 216150*x^4 - 102320*x^5 + 
           43190*x^6 - 147130*x^7 + 325660*x^8 + 412803*x^9 - 418722*x^10 - 
           812413*x^11 + 317296*x^12 + 989548*x^13 - 61264*x^14 - 
           773847*x^15 - 109254*x^16 + 379803*x^17 + 106026*x^18 - 
           106896*x^19 - 40512*x^20 + 13200*x^21 + 6000*x^22)*HPL[{2, 0}, x])/
         (1350*(-1 + x)^8*(1 + x)^10) + (4*(1 + 5*x - 50*x^2 + 245*x^3 - 
           242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x)^6*(1 + x)^8) - (8*(1 + 5*x - 50*x^2 + 245*x^3 - 
           242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{-2, 0, 0}, x])/
         (45*(-1 + x)^6*(1 + x)^8) - (4*(1 + 5*x - 50*x^2 + 245*x^3 - 
           242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{-2, 1, 0}, x])/
         (45*(-1 + x)^6*(1 + x)^8) - (4*(1 + 5*x - 50*x^2 + 245*x^3 - 
           242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{-1, -2, 0}, x])/
         (45*(-1 + x)^6*(1 + x)^8) + ((-6000 - 13200*x + 10512*x^2 + 
           40896*x^3 + 6534*x^4 - 43323*x^5 - 23196*x^6 + 16272*x^7 + 
           15064*x^8 + 2*x^9 - 3236*x^10 - 847*x^11 - 356*x^12 - 847*x^13 - 
           3236*x^14 + 2*x^15 + 15064*x^16 + 16272*x^17 - 23196*x^18 - 
           43323*x^19 + 6534*x^20 + 40896*x^21 + 10512*x^22 - 13200*x^23 - 
           6000*x^24)*HPL[{-1, -1, 0}, x])/(2700*(-1 + x)^3*x^11*(1 + x)^5) + 
        ((153 - 2802*x + 14646*x^2 - 101362*x^3 + 193122*x^4 - 253486*x^5 + 
           130774*x^6 - 164026*x^7 + 85492*x^8 + 228740*x^9 - 119834*x^10 - 
           408550*x^11 + 125034*x^12 + 475778*x^13 - 87042*x^14 - 
           362958*x^15 + 39111*x^16 + 175482*x^17 - 10272*x^18 - 48912*x^19 + 
           1200*x^20 + 6000*x^21)*HPL[{-1, 0, 0}, x])/(1350*(-1 + x^2)^8) + 
        ((6000 + 13200*x - 10512*x^2 - 40896*x^3 - 6534*x^4 + 43323*x^5 + 
           23196*x^6 - 16272*x^7 - 15064*x^8 - 2*x^9 + 3236*x^10 + 847*x^11 + 
           356*x^12 + 847*x^13 + 3236*x^14 - 2*x^15 - 15064*x^16 - 
           16272*x^17 + 23196*x^18 + 43323*x^19 - 6534*x^20 - 40896*x^21 - 
           10512*x^22 + 13200*x^23 + 6000*x^24)*HPL[{-1, 1, 0}, x])/
         (2700*(-1 + x)^3*x^11*(1 + x)^5) + 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-1, 2, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) - 
        (x*(-196830 + 8857350*x + 332588025*x^2 - 355269159*x^3 - 
           9018876960*x^4 + 562710753*x^5 + 71409011454*x^6 + 
           152761356072*x^7 - 64358188680*x^8 - 2674235367660*x^9 + 
           300284572803*x^10 + 18039998897457*x^11 - 19094877285798*x^12 - 
           46282689270877*x^13 + 83161616473588*x^14 + 24387812783387*x^15 - 
           12282103060040*x^16 - 86774374448164*x^17 + 88623403078063*x^18 + 
           135012094617754*x^19 - 77789478865834*x^20 - 164926038657617*
            x^21 + 38199573272414*x^22 + 158484501831526*x^23 - 
           3152853262384*x^24 - 112692046835100*x^25 - 13874744389707*x^26 + 
           57693941276433*x^27 + 13055621594886*x^28 - 20734392938211*x^29 - 
           6264061915392*x^30 + 5044216698951*x^31 + 1801819466862*x^32 - 
           791032772106*x^33 - 313066501632*x^34 + 75391852491*x^35 + 
           31847661162*x^36 - 3944228256*x^37 - 1739837232*x^38 + 
           86605200*x^39 + 39366000*x^40)*HPL[{0, 0, 0}, x])/
         (675*(-1 + x)^9*(1 + x)^11*(9 - 82*x^2 + 9*x^4)^4) + 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{1, -2, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        ((6000 + 13200*x - 10512*x^2 - 40896*x^3 - 6534*x^4 + 43323*x^5 + 
           23196*x^6 - 16272*x^7 - 15064*x^8 - 2*x^9 + 3236*x^10 + 847*x^11 + 
           356*x^12 + 847*x^13 + 3236*x^14 - 2*x^15 - 15064*x^16 - 
           16272*x^17 + 23196*x^18 + 43323*x^19 - 6534*x^20 - 40896*x^21 - 
           10512*x^22 + 13200*x^23 + 6000*x^24)*HPL[{1, -1, 0}, x])/
         (2700*(-1 + x)^3*x^11*(1 + x)^5) + 
        ((-153 + 2670*x - 1302*x^2 + 73598*x^3 + 84254*x^4 - 12390*x^5 - 
           4358*x^6 + 83734*x^7 + 224412*x^8 + 133392*x^9 - 378366*x^10 - 
           470166*x^11 + 249934*x^12 + 652738*x^13 + 65994*x^14 - 
           459486*x^15 - 211119*x^16 + 146502*x^17 + 124320*x^18 - 
           3888*x^19 - 25200*x^20 - 6000*x^21)*HPL[{1, 0, 0}, x])/
         (1350*(-1 + x)^6*(1 + x)^10) + 
        ((-6000 - 13200*x + 10512*x^2 + 40896*x^3 + 6534*x^4 - 43323*x^5 - 
           23196*x^6 + 16272*x^7 + 15064*x^8 + 2*x^9 - 3236*x^10 - 847*x^11 - 
           356*x^12 - 847*x^13 - 3236*x^14 + 2*x^15 + 15064*x^16 + 
           16272*x^17 - 23196*x^18 - 43323*x^19 + 6534*x^20 + 40896*x^21 + 
           10512*x^22 - 13200*x^23 - 6000*x^24)*HPL[{1, 1, 0}, x])/
         (2700*(-1 + x)^3*x^11*(1 + x)^5) - 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{1, 2, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) - 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{2, -1, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        (8*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{2, 0, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{2, 1, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) - 
        (8*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-1, 1, 0, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) - 
        (8*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{1, -1, 0, 0}, x])/(45*(-1 + x)^6*(1 + x)^8) + 
        ((1 + 8*x - 39*x^2 + 359*x^3 - 353*x^4 + 651*x^5 - 161*x^6 + 
           119*x^7 + 12*x^8 + 3*x^9)*master3l10a[x])/(90*(-1 + x)^7*
          (1 + x)^9) - (x*(3 + 12*x + 119*x^2 - 161*x^3 + 651*x^4 - 353*x^5 + 
           359*x^6 - 39*x^7 + 8*x^8 + x^9)*master3l10b[x])/
         (90*(-1 + x)^7*(1 + x)^9) - ((-22599 + 62421354*x - 196915212*x^2 + 
           366482556*x^3 - 205839180*x^4 + 149609106*x^5 + 9454680*x^6 - 
           88567884*x^7 + 25698522*x^8 + 10580814*x^9 - 6134716*x^10 + 
           118580*x^11 + 550620*x^12 - 84170*x^13 - 19792*x^14 + 3612*x^15 + 
           157*x^16)*master3l8a[x])/(5400*(-1 + x)^8*(1 + x)^10*
          (-9 + x^2)^4) - ((40 - 1837*x + 2848*x^2 + 72224*x^3 - 125038*x^4 - 
           1250220*x^5 + 1582952*x^6 + 11916132*x^7 - 7274646*x^8 - 
           61801058*x^9 + 4353216*x^10 + 139324296*x^11 + 6170022*x^12 - 
           29581524*x^13 + 173969208*x^14 + 26955828*x^15 + 5346486*x^16 - 
           764721*x^17)*master3l8b[x])/(5400*(-1 + x)^8*x*(1 + x)^10*
          (1 - 9*x^2)^4) + ((41229 + 3170826*x - 12432699*x^2 + 
           11047500*x^3 - 11173503*x^4 + 9196338*x^5 - 8456479*x^6 - 
           4140468*x^7 + 3921479*x^8 + 531918*x^9 - 567105*x^10 - 
           22252*x^11 + 37035*x^12 - 202*x^13 - 997*x^14 + 20*x^15)*
          master3l9a[x])/(1800*(-1 + x)^8*(1 + x)^10*(-9 + x^2)^3) + 
        ((20 - 997*x - 202*x^2 + 37035*x^3 - 22252*x^4 - 567105*x^5 + 
           531918*x^6 + 3921479*x^7 - 4140468*x^8 - 8456479*x^9 + 
           9196338*x^10 - 11173503*x^11 + 11047500*x^12 - 12432699*x^13 + 
           3170826*x^14 + 41229*x^15)*master3l9b[x])/(5400*(-1 + x)^8*x*
          (1 + x)^10*(-1 + 9*x^2)^3) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(6000 + 13200*x - 10512*x^2 - 
             40896*x^3 - 6534*x^4 + 43323*x^5 + 23196*x^6 - 16272*x^7 - 
             15064*x^8 - 2*x^9 + 3236*x^10 + 847*x^11 + 356*x^12 + 847*x^13 + 
             3236*x^14 - 2*x^15 - 15064*x^16 - 16272*x^17 + 23196*x^18 + 
             43323*x^19 - 6534*x^20 - 40896*x^21 - 10512*x^22 + 13200*x^23 + 
             6000*x^24) - 2880*x^11*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
             245*x^5 - 50*x^6 + 5*x^7 + x^8)*Zeta[3]))/(32400*(-1 + x)^6*x^11*
          (1 + x)^8) + (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(6000 + 13200*x - 
              10512*x^2 - 40896*x^3 - 6534*x^4 + 43323*x^5 + 23196*x^6 - 
              16272*x^7 - 15064*x^8 - 2*x^9 + 3236*x^10 + 847*x^11 + 
              356*x^12 + 847*x^13 + 3236*x^14 - 2*x^15 - 15064*x^16 - 
              16272*x^17 + 23196*x^18 + 43323*x^19 - 6534*x^20 - 40896*x^21 - 
              10512*x^22 + 13200*x^23 + 6000*x^24)) + 
           2880*x^11*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 
             50*x^6 + 5*x^7 + x^8)*Zeta[3]))/(32400*(-1 + x)^6*x^11*
          (1 + x)^8) + (HPL[{0}, x]*(2361960000 + 5196312000*x - 
           99666313920*x^2 - 226261071360*x^3 + 1708968251880*x^4 + 
           4065359668740*x^5 - 15257884924080*x^6 - 39085697802240*x^7 - 
           90*(-841480793707 + 87480*Pi^2)*x^8 + 9*(24453266583499 + 
             37616400*Pi^2)*x^9 + 40*(-1067590990125 + 67347665356*Pi^2)*
            x^21 - 3*(73409723590197 + 275219744708300*Pi^2)*x^33 - 
           120*(631195103694 + 1385051667943*Pi^2)*x^34 + 
           30*(1302921558243 + 10939773241478*Pi^2)*x^35 + 
           240*(63574520517 + 395430146686*Pi^2)*x^36 - 
           60*(67755994479 + 1441572718760*Pi^2)*x^37 - 
           120*(14241402099 + 253150025860*Pi^2)*x^38 + 
           540*(419001984 + 26648094173*Pi^2)*x^39 + 
           1080*(92283624 + 5239246513*Pi^2)*x^40 - 
           72900*(71280 + 19625303*Pi^2)*x^41 - 145800*(16200 + 4135417*Pi^2)*
            x^42 + 77152461120*Pi^2*x^43 + 34009424640*Pi^2*x^44 - 
           1732104000*Pi^2*x^45 - 787320000*Pi^2*x^46 + 
           20*x^22*(-196956623369393 + 10306452272572*Pi^2 - 
             15661773273600*Zeta[3]) - 20*x^20*(159989558716117 + 
             11133338135460*Pi^2 - 15661773273600*Zeta[3]) + 
           18*x^15*(-139526265847877 + 19244079300*Pi^2 - 473406768000*
              Zeta[3]) - 270*x^14*(99360124033 + 222429620*Pi^2 - 
             26906515200*Zeta[3]) + 30*x^12*(9506002496831 + 
             1615196700*Pi^2 - 19525536000*Zeta[3]) - 
           90*x^10*(2308101097681 + 21437460*Pi^2 - 188956800*Zeta[3]) + 
           120*x^32*(1727993960877 + 927664667132*Pi^2 - 141717600*Zeta[3]) - 
           144*x^11*(5290119729517 + 59711175*Pi^2 + 118098000*Zeta[3]) + 
           18*x^31*(42560441575511 + 79299363083680*Pi^2 + 
             944784000*Zeta[3]) - 160*x^29*(11007900948687 + 
             10817628087980*Pi^2 + 3873614400*Zeta[3]) + 
           120*x^13*(14172502601531 + 392571360*Pi^2 + 5164819200*Zeta[3]) + 
           10*x^30*(-26522862153783 + 17098645091924*Pi^2 + 
             58576608000*Zeta[3]) + 20*x^18*(119461452102271 + 
             3510358060782*Pi^2 + 557927740800*Zeta[3]) - 
           10*x^28*(24487340011839 + 53963807540636*Pi^2 + 726475910400*
              Zeta[3]) - 10*x^24*(313548979755737 + 52711150882220*Pi^2 + 
             1115855481600*Zeta[3]) - 20*x^16*(37809675891739 + 
             359568484620*Pi^2 + 1750468968000*Zeta[3]) + 
           4*x^27*(738097172779509 + 370076282866310*Pi^2 + 
             2130330456000*Zeta[3]) + 10*x^26*(210272084631443 + 
             69984338447424*Pi^2 + 3500937936000*Zeta[3]) - 
           9*x^25*(435695304656879 + 98287583861140*Pi^2 + 5854311936000*
              Zeta[3]) - 6*x^19*(204125831035669 + 309329879770*Pi^2 + 
             20949045984000*Zeta[3]) + 4*x^23*(801613783049991 + 
             85080835391795*Pi^2 + 31423568976000*Zeta[3]) + 
           x^17*(-3067446117660*Pi^2 + 99*(23868572330689 + 532210176000*
                Zeta[3]))))/(324000*(-1 + x)^8*x^7*(1 + x)^10*
          (9 - 82*x^2 + 9*x^4)^4) + (-4800*Pi^4*x^9*(-1 + x^2)^2*
           (9 - 82*x^2 + 9*x^4)^4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
            245*x^5 - 50*x^6 + 5*x^7 + x^8) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^4*
           (-360000 - 792000*x + 2250720*x^2 + 6017760*x^3 - 5266200*x^4 - 
            19845300*x^5 + 4094700*x^6 + 36976650*x^7 + 5368620*x^8 - 
            42303283*x^9 - 16190780*x^10 + 30212242*x^11 + 13740100*x^12 - 
            7407335*x^13 - 24721400*x^14 + 24721400*x^16 + 7407335*x^17 - 
            13740100*x^18 - 30212242*x^19 + 16190780*x^20 + 42303283*x^21 - 
            5368620*x^22 - 36976650*x^23 - 4094700*x^24 + 19845300*x^25 + 
            5266200*x^26 - 6017760*x^27 - 2250720*x^28 + 792000*x^29 + 
            360000*x^30) + x^2*(-14171760000 - 31177872000*x + 
            602721803520*x^2 + 1367959052160*x^3 - 10451370669120*x^4 - 
            24840782921160*x^5 + 94891126168800*x^6 + 
            x^23*(21385978407334551 - 38368262276942400*Zeta[3]) + 
            x^11*(5124021431135679 - 9563875571520*Zeta[3]) - 
            5554977200640*x^43*Zeta[3] - 2448678574080*x^44*Zeta[3] + 
            124711488000*x^45*Zeta[3] + 56687040000*x^46*Zeta[3] + 
            10497600*x^42*(-1350 + 4135417*Zeta[3]) - 
            1215*x^7*(-199590778795 + 7177248*Zeta[3]) + 
            1080*x^8*(-446908487201 + 13629384*Zeta[3]) + 
            5248800*x^41*(-5940 + 19625303*Zeta[3]) + 
            360*x^10*(3773725899173 + 1227315240*Zeta[3]) - 
            77760*x^40*(-7751052 + 5239246513*Zeta[3]) - 
            4320*x^12*(429641255719 + 6961503204*Zeta[3]) + 
            54*x^9*(-25931427110713 + 8880833520*Zeta[3]) - 
            38880*x^39*(-35184132 + 26648094173*Zeta[3]) + 
            8640*x^38*(-1209649383 + 253150025860*Zeta[3]) + 
            720*x^14*(1581331416599 + 705169925640*Zeta[3]) + 
            36*x^13*(-369257561718367 + 2458956703680*Zeta[3]) - 
            2160*x^36*(-43931240955 + 3163441173488*Zeta[3]) - 
            8640*x^22*(-4243906014317 + 3959111613024*Zeta[3]) + 
            1080*x^37*(-23000724927 + 5766290875040*Zeta[3]) - 
            720*x^20*(-85888566797409 + 6786728434624*Zeta[3]) + 
            1080*x^34*(-447847614161 + 11080410701648*Zeta[3]) + 
            2880*x^28*(585148840991 + 13679519349434*Zeta[3]) - 
            720*x^30*(3006225157749 + 17146377549848*Zeta[3]) - 
            360*x^32*(-3860380656593 + 22261436203008*Zeta[3]) + 
            90*x^17*(-357958617378017 + 22526303064672*Zeta[3]) - 
            120*x^16*(64394914339355 + 31126677591264*Zeta[3]) - 
            675*x^35*(-359217941391 + 35007292330624*Zeta[3]) - 
            5*x^15*(-5393814643684217 + 86519143468224*Zeta[3]) + 
            120*x^18*(126138856679801 + 96215483140752*Zeta[3]) + 
            120*x^24*(-86317882309279 + 449804167666656*Zeta[3]) - 
            120*x^26*(5560496782655 + 455411214775248*Zeta[3]) + 
            90*x^25*(-155597447928257 + 729639872223552*Zeta[3]) + 
            54*x^33*(-25829811703513 + 1100890858481120*Zeta[3]) + 
            36*x^29*(-311554222292767 + 3464697277478080*Zeta[3]) - 
            3*x^19*(746549604115883 + 4520600529945600*Zeta[3]) + 
            8*x^21*(-5300158343875999 + 5946737595334560*Zeta[3]) - 
            9*x^31*(-550611827864831 + 11420486445758400*Zeta[3]) - 
            5*x^27*(-3162528945873137 + 21413527913448000*Zeta[3])))/
         (7776000*(-1 + x)^8*x^9*(1 + x)^10*(9 - 82*x^2 + 9*x^4)^4)))
 
CbarData["p", 2, 4] = 
    NC*(CF*(NL*(-(Pi^2*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 
              6*x^7 + x^8)*HPL[{-1}, x])/(1620*(-1 + x)^7*(1 + x)^9) + 
          (x^2*(-1233 + 63*(45809 + 3000*Pi^2)*x - 18*(195203 + 15750*Pi^2)*
              x^2 + 63*(254581 + 24000*Pi^2)*x^3 - 4*(1953451 + 301875*Pi^2)*
              x^4 + 210*(18871 + 13200*Pi^2)*x^5 + (5742014 - 1198050*Pi^2)*
              x^6 + 252*(-70094 + 5925*Pi^2)*x^7 + (5504139 - 285390*Pi^2)*
              x^8 + 63*(-82579 + 3120*Pi^2)*x^9 + (89398 - 1050*Pi^2)*x^10 + 
             105*(-203 + 12*Pi^2)*x^11 + 70*(-98 + 3*Pi^2)*x^12)*HPL[{0}, x])/
           (340200*(-1 + x)^10*(1 + x)^12) + 
          lm^2*((1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 956*x^5 - 398*x^6 + 
              356*x^7 - 23*x^8 + 6*x^9 + x^10)/(240*(-1 + x)^8*(1 + x)^10) - 
            (x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*x^5 + 2*x^6)*
              HPL[{0}, x])/(2*(-1 + x)^9*(1 + x)^11)) + 
          (Pi^2*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + 
             x^8)*HPL[{1}, x])/(1620*(-1 + x)^7*(1 + x)^9) - 
          (x^3*(900 - 1350*x + 7200*x^2 - 5750*x^3 + 13200*x^4 - 5705*x^5 + 
             7110*x^6 - 1359*x^7 + 936*x^8 - 5*x^9 + 6*x^10 + x^11)*
            HPL[{-2, 0}, x])/(135*(-1 + x)^10*(1 + x)^12) + 
          ((137 + 602*x - 13968*x^2 + 347774*x^3 - 454821*x^4 + 1706264*x^5 - 
             1046216*x^6 + 1706264*x^7 - 454821*x^8 + 347774*x^9 - 
             13968*x^10 + 602*x^11 + 137*x^12)*HPL[{-1, 0}, x])/
           (37800*(-1 + x)^9*(1 + x)^11) + 
          (x^3*(84000 - 126000*x + 861000*x^2 - 721000*x^3 + 2212000*x^4 - 
             1045275*x^5 + 1668450*x^6 - 344757*x^7 + 291228*x^8 - 1365*x^9 + 
             3178*x^10 + 493*x^11)*HPL[{0, 0}, x])/(18900*(-1 + x)^10*
            (1 + x)^12) - ((137 + 602*x - 13968*x^2 + 347774*x^3 - 
             454821*x^4 + 1706264*x^5 - 1046216*x^6 + 1706264*x^7 - 
             454821*x^8 + 347774*x^9 - 13968*x^10 + 602*x^11 + 137*x^12)*
            HPL[{1, 0}, x])/(37800*(-1 + x)^9*(1 + x)^11) + 
          lm*((196 + 609*x - 2127*x^2 + 67404*x^3 - 61321*x^4 + 180630*x^5 - 
              61321*x^6 + 67404*x^7 - 2127*x^8 + 609*x^9 + 196*x^10 + 
              6*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*x^4 - 16*x^6 + 48*x^7 - 
                3*x^8 + 6*x^9 + x^10))/(19440*(-1 + x)^8*(1 + x)^10) - 
            (x^2*(2 + 2412*x - 3130*x^2 + 16758*x^3 - 11358*x^4 + 22158*x^5 - 
               6505*x^6 + 5562*x^7 - 214*x^8 + 54*x^9 + 9*x^10)*HPL[{0}, x])/
             (540*(-1 + x)^9*(1 + x)^11) - ((1 + 6*x - 2*x^2 + 54*x^3 - 18*
                x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*HPL[{-1, 0}, x])/
             (270*(-1 + x)^7*(1 + x)^9) + (x^3*(360 - 540*x + 4500*x^2 - 4400*
                x^3 + 13200*x^4 - 7055*x^5 + 9810*x^6 - 2169*x^7 + 1476*x^8 - 
               5*x^9 + 6*x^10 + x^11)*HPL[{0, 0}, x])/(135*(-1 + x)^10*
              (1 + x)^12) + ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*
                x^6 + 6*x^7 + x^8)*HPL[{1, 0}, x])/(270*(-1 + x)^7*
              (1 + x)^9)) + (x^3*(900 - 1350*x + 7200*x^2 - 5750*x^3 + 
             13200*x^4 - 5705*x^5 + 7110*x^6 - 1359*x^7 + 936*x^8 - 5*x^9 + 
             6*x^10 + x^11)*HPL[{2, 0}, x])/(135*(-1 + x)^10*(1 + x)^12) + 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{-1, -1, 0}, x])/(135*(-1 + x)^7*(1 + x)^9) - 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{-1, 1, 0}, x])/(135*(-1 + x)^7*(1 + x)^9) - 
          (2*x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 13200*x^4 - 7055*x^5 + 
             9810*x^6 - 2169*x^7 + 1476*x^8 - 5*x^9 + 6*x^10 + x^11)*
            HPL[{0, 0, 0}, x])/(135*(-1 + x)^10*(1 + x)^12) - 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{1, -1, 0}, x])/(135*(-1 + x)^7*(1 + x)^9) + 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{1, 1, 0}, x])/(135*(-1 + x)^7*(1 + x)^9) + 
          (2759767*x^12 - 1083390*x^13 + 131005*x^14 - 
            36*Pi^2*(-137 - 602*x + 14105*x^2 - 347172*x^3 + 440853*x^4 - 
              1358490*x^5 + 591395*x^6 - 591395*x^8 + 1358490*x^9 - 
              440853*x^10 + 347172*x^11 - 14105*x^12 + 602*x^13 + 137*x^14) + 
            x^2*(2759767 - 302400*Zeta[3]) + 210*x*(-5159 + 1728*Zeta[3]) + 
            35*(3743 + 1728*Zeta[3]) + 252*x^11*(174391 + 216000*Zeta[3]) + 
            252*x^3*(174391 + 224640*Zeta[3]) + 630*x^5*
             (56909 + 682560*Zeta[3]) + 630*x^9*(56909 + 691200*Zeta[3]) - 
            27*x^10*(1007201 + 3024000*Zeta[3]) - 27*x^4*(1007201 + 
              3044160*Zeta[3]) + 168*x^7*(-937093 + 4752000*Zeta[3]) - 
            5*x^6*(-4860731 + 69007680*Zeta[3]) - 5*x^8*(-4860731 + 
              69552000*Zeta[3]))/(16329600*(-1 + x)^10*(1 + x)^12)) + 
        NH*((x*(964246550400 + 9949254819696*x + 1126512716072436*x^2 - 
             769700029364811*x^3 + 4117798490348970*x^4 - 1013461146341658*
              x^5 + 789271041204450*x^6 + 786249767764188*x^7 - 
             1542223615448250*x^8 - 13589688309966*x^9 + 349982760245202*
              x^10 - 107396456038263*x^11 + 17631537296436*x^12 + 
             36590998182732*x^13 - 18664867884348*x^14 - 5538763746576*x^15 + 
             3349681943580*x^16 + 377572057828*x^17 - 303704730840*x^18 + 
             2089773639*x^19 + 15103115202*x^20 - 2192465554*x^21 - 
             348743430*x^22 + 143855348*x^23 - 478338*x^24 - 3447078*x^25 + 
             124530*x^26 + 12475*x^27)*HPL[{0}, x])/(1360800*(-1 + x)^11*
            (1 + x)^13*(-9 + x^2)^6) + lm^2*((1 + 6*x - 23*x^2 + 356*x^3 - 
              398*x^4 + 956*x^5 - 398*x^6 + 356*x^7 - 23*x^8 + 6*x^9 + x^10)/
             (240*(-1 + x)^8*(1 + x)^10) - (x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 
               12*x^4 - 3*x^5 + 2*x^6)*HPL[{0}, x])/(2*(-1 + x)^9*
              (1 + x)^11)) + (x*(-26784626400 - 170660454228*x - 
             22931072966088*x^2 + 15945043536945*x^3 - 82825302376278*x^4 + 
             20448773578314*x^5 - 7938559171998*x^6 - 19190717670402*x^7 + 
             40133549561490*x^8 - 869188316886*x^9 - 8907586415910*x^10 + 
             3067531468587*x^11 - 1356306125244*x^12 - 811715479484*x^13 + 
             701210282388*x^14 + 77603957236*x^15 - 88091577084*x^16 + 
             961382592*x^17 + 2699426380*x^18 - 816897961*x^19 + 
             307758290*x^20 + 67738770*x^21 - 27222006*x^22 - 2218834*x^23 + 
             569226*x^24 + 14922*x^25 + 3234*x^26 + 429*x^27)*HPL[{0, 0}, x])/
           (37800*(-1 + x)^11*(1 + x)^13*(-9 + x^2)^6) + 
          lm*((196 + 609*x - 2127*x^2 + 67404*x^3 - 61321*x^4 + 180630*x^5 - 
              61321*x^6 + 67404*x^7 - 2127*x^8 + 609*x^9 + 196*x^10 + 
              6*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*x^4 - 16*x^6 + 48*x^7 - 
                3*x^8 + 6*x^9 + x^10))/(19440*(-1 + x)^8*(1 + x)^10) - 
            (x^2*(2 + 2412*x - 3130*x^2 + 16758*x^3 - 11358*x^4 + 22158*x^5 - 
               6505*x^6 + 5562*x^7 - 214*x^8 + 54*x^9 + 9*x^10)*HPL[{0}, x])/
             (540*(-1 + x)^9*(1 + x)^11) - ((1 + 6*x - 2*x^2 + 54*x^3 - 18*
                x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*HPL[{-1, 0}, x])/
             (270*(-1 + x)^7*(1 + x)^9) + (x^3*(360 - 540*x + 4500*x^2 - 4400*
                x^3 + 13200*x^4 - 7055*x^5 + 9810*x^6 - 2169*x^7 + 1476*x^8 - 
               5*x^9 + 6*x^10 + x^11)*HPL[{0, 0}, x])/(135*(-1 + x)^10*
              (1 + x)^12) + ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*
                x^6 + 6*x^7 + x^8)*HPL[{1, 0}, x])/(270*(-1 + x)^7*
              (1 + x)^9)) - ((-381 + 7641*x - 11226*x^2 + 43865*x^3 - 
             32485*x^4 + 57545*x^5 - 24160*x^6 + 20745*x^7 - 4395*x^8 + 
             1660*x^9 - 14*x^10 + 4*x^11 + x^12)*HPL[{-1, 0, 0}, x])/
           (135*(-1 + x^2)^10) + (x^3*(867831999300 - 638448236757*x + 
             3157253788878*x^2 - 832176116496*x^3 + 277665815322*x^4 + 
             829097131050*x^5 - 1916783213814*x^6 + 172454857920*x^7 + 
             295176047418*x^8 - 180985589163*x^9 + 133513748676*x^10 + 
             34850023624*x^11 - 44483948292*x^12 - 935467276*x^13 + 
             4389159852*x^14 - 484600760*x^15 - 5063184*x^16 + 
             69255485*x^17 - 28060242*x^18 - 4059928*x^19 + 1862826*x^20 + 
             116226*x^21 - 40950*x^22 - 1960*x^23 + 210*x^24 + 35*x^25)*
            HPL[{0, 0, 0}, x])/(4725*(-1 + x)^11*(1 + x)^13*(-9 + x^2)^6) + 
          ((-561 + 6027*x - 6750*x^2 + 28387*x^3 - 10357*x^4 + 29839*x^5 - 
             220*x^6 + 9591*x^7 + 657*x^8 + 1328*x^9 + 10*x^10 + 8*x^11 + 
             x^12)*HPL[{1, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^12) + 
          ((35187738687 + 3409851309102*x - 2289614951250*x^2 + 
             12551343804342*x^3 - 3201193243764*x^4 + 3618822460554*x^5 + 
             1866748472586*x^6 - 3595112653230*x^7 + 81885700683*x^8 + 
             661450533660*x^9 - 256118713668*x^10 + 25571691180*x^11 + 
             72060163104*x^12 - 29801473884*x^13 - 8702743100*x^14 + 
             5557322484*x^15 + 349712181*x^16 - 513303210*x^17 + 
             24773558*x^18 + 23212350*x^19 - 3145260*x^20 - 323022*x^21 + 
             109074*x^22 - 4326*x^23 - 831*x^24)*master3l8a[x])/
           (113400*(-1 + x)^11*(1 + x)^13*(-9 + x^2)^6) - 
          ((3909748743 + 186020812278*x - 112089858777*x^2 + 
             713650782096*x^3 - 183214541061*x^4 + 419682401334*x^5 + 
             2815518825*x^6 + 73126241748*x^7 - 28912055148*x^8 + 
             16024964508*x^9 + 8548934390*x^10 - 25047871296*x^11 + 
             1212116694*x^12 + 3790950156*x^13 - 624410206*x^14 + 
             63328104*x^15 + 77167055*x^16 - 48872082*x^17 - 4063373*x^18 + 
             3384528*x^19 + 101247*x^20 - 73794*x^21 - 2459*x^22 + 420*x^23 + 
             70*x^24)*master3l9a[x])/(37800*(-1 + x)^11*(1 + x)^13*
            (-9 + x^2)^5) + (x^16*(31427468457173 - 7395694689600*Zeta[3]) + 
            x^20*(89645769594 - 20287834560*Zeta[3]) + 
            x^22*(8131736582 - 209664000*Zeta[3]) + 160*x^28*
             (-799 + 126*Zeta[3]) + 840*x^27*(-1855 + 144*Zeta[3]) - 
            42*x^25*(1306741 + 54720*Zeta[3]) - 3*x^26*(-8111431 + 
              403200*Zeta[3]) - 252*x^23*(-22625159 + 2940480*Zeta[3]) + 
            5*x^24*(-164879341 + 7640640*Zeta[3]) - 2480058*x*
             (1188166087 + 19414080*Zeta[3]) + 177147*(-227381303 + 
              62354880*Zeta[3]) + 168*x^21*(-892430297 + 215952480*Zeta[3]) + 
            918540*x^3*(-16298018147 + 329228064*Zeta[3]) + 
            653184*x^11*(-2465847488 + 879682925*Zeta[3]) + 
            19683*x^2*(93915887267 + 6383059200*Zeta[3]) + 
            204120*x^5*(-88204117829 + 6530650272*Zeta[3]) - 
            39366*x^4*(-141045318583 + 6768367200*Zeta[3]) - 
            84*x^19*(-23640974107 + 8390152800*Zeta[3]) - 
            567*x^10*(-846489483349 + 34079366400*Zeta[3]) - 
            672*x^13*(-140512977119 + 41770148400*Zeta[3]) + 
            126*x^17*(-116399370607 + 53165937600*Zeta[3]) - 
            7290*x^6*(-293560885831 + 68994938880*Zeta[3]) - 
            6804*x^7*(-140830579657 + 135498536640*Zeta[3]) - 
            168*x^15*(-296857672441 + 160371432000*Zeta[3]) + 
            84*x^14*(-1925198681443 + 562126118400*Zeta[3]) + 
            x^18*(-2990523728897 + 591327878400*Zeta[3]) + 
            243*x^8*(-13115632192829 + 3065320802880*Zeta[3]) - 
            378*x^9*(-13172226917561 + 3150735278400*Zeta[3]) - 
            28*x^12*(-11836691874121 + 4757528840400*Zeta[3]))/
           (8164800*(-1 + x)^11*(1 + x)^13*(-9 + x^2)^6)) + 
        NM*(-((47880 + 287280*x - 2339892*x^2 - 48039012*x^3 + 
              114690807*x^4 + 2288301750*x^5 - 4125733846*x^6 - 
              37885939602*x^7 + 76121183196*x^8 + 93818078970*x^9 - 
              619748750198*x^10 + 3735043460190*x^11 + 446080343251*x^12 - 
              36646840032852*x^13 + 23947565715348*x^14 + 56658458220924*x^
                15 - 107959083615352*x^16 + 518539707710388*x^17 - 
              102681631474704*x^18 - 1043595489588120*x^19 + 
              900844778821437*x^20 - 3354795372249090*x^21 + 
              777493194172578*x^22 - 1196783585624970*x^23 - 
              229749460520364*x^24 + 173451939151554*x^25 - 164705104901286*x^
                26 + 35044926646590*x^27 - 20570244390855*x^28 + 
              840*Pi^2*(1 - 9*x^2)^6*(-1 + x^2)^4*(1 + 6*x - 2*x^2 + 54*x^3 - 
                18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8))*HPL[{0}, x])/
           (1360800*(-1 + x)^11*(1 + x)^13*(1 - 9*x^2)^6) + 
          lm^2*((1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 956*x^5 - 398*x^6 + 
              356*x^7 - 23*x^8 + 6*x^9 + x^10)/(240*(-1 + x)^8*(1 + x)^10) - 
            (x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*x^5 + 2*x^6)*
              HPL[{0}, x])/(2*(-1 + x)^9*(1 + x)^11)) + 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{-2, 0}, x])/(135*(-1 + x)^7*(1 + x)^9) - 
          ((-840 - 5040*x + 36856*x^2 + 1092336*x^3 - 2220125*x^4 - 
             44783634*x^5 + 75086814*x^6 + 373807238*x^7 - 1001744606*x^8 + 
             8365811062*x^9 - 207313406*x^10 - 172810817130*x^11 + 
             129292238241*x^12 + 856889383308*x^13 - 1085477324404*x^14 + 
             2666798430492*x^15 + 1362416357700*x^16 - 30116700228132*x^17 + 
             16761322434204*x^18 + 16475984895132*x^19 - 42845516091531*
              x^20 + 202848684308550*x^21 - 61118586897930*x^22 + 
             100150586849502*x^23 + 10168351607106*x^24 - 6918601666914*
              x^25 + 12157161030666*x^26 - 2797253284770*x^27 + 
             1582778625255*x^28)*HPL[{0, 0}, x])/(37800*(-1 + x)^11*
            (1 + x)^13*(1 - 9*x^2)^6) + 
          lm*((196 + 609*x - 2127*x^2 + 67404*x^3 - 61321*x^4 + 180630*x^5 - 
              61321*x^6 + 67404*x^7 - 2127*x^8 + 609*x^9 + 196*x^10 + 
              6*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*x^4 - 16*x^6 + 48*x^7 - 
                3*x^8 + 6*x^9 + x^10))/(19440*(-1 + x)^8*(1 + x)^10) - 
            (x^2*(2 + 2412*x - 3130*x^2 + 16758*x^3 - 11358*x^4 + 22158*x^5 - 
               6505*x^6 + 5562*x^7 - 214*x^8 + 54*x^9 + 9*x^10)*HPL[{0}, x])/
             (540*(-1 + x)^9*(1 + x)^11) - ((1 + 6*x - 2*x^2 + 54*x^3 - 18*
                x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*HPL[{-1, 0}, x])/
             (270*(-1 + x)^7*(1 + x)^9) + (x^3*(360 - 540*x + 4500*x^2 - 4400*
                x^3 + 13200*x^4 - 7055*x^5 + 9810*x^6 - 2169*x^7 + 1476*x^8 - 
               5*x^9 + 6*x^10 + x^11)*HPL[{0, 0}, x])/(135*(-1 + x)^10*
              (1 + x)^12) + ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*
                x^6 + 6*x^7 + x^8)*HPL[{1, 0}, x])/(270*(-1 + x)^7*
              (1 + x)^9)) - ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 
             2*x^6 + 6*x^7 + x^8)*HPL[{2, 0}, x])/(135*(-1 + x)^7*
            (1 + x)^9) + ((-3 - 12*x + 42*x^2 - 1780*x^3 + 4625*x^4 - 
             20905*x^5 + 24160*x^6 - 57385*x^7 + 32255*x^8 - 43745*x^9 + 
             11198*x^10 - 7633*x^11 + 383*x^12)*HPL[{-1, 0, 0}, x])/
           (135*(-1 + x^2)^10) + ((-35 - 210*x + 980*x^2 + 60270*x^3 - 
             104543*x^4 - 1247988*x^5 + 2950602*x^6 - 20801256*x^7 + 
             5059073*x^8 + 680091678*x^9 - 1137659238*x^10 - 668975454*x^11 + 
             14399514113*x^12 - 120887950848*x^13 - 30013517540*x^14 + 
             1300332630072*x^15 - 588303062241*x^16 - 4104391691358*x^17 + 
             4019345188416*x^18 - 5793750622422*x^19 - 5086246984893*x^20 + 
             35572598168436*x^21 - 13033331718822*x^22 + 25093047136752*
              x^23 + 575824989123*x^24 + 1062205932690*x^25 + 
             2115707837202*x^26 - 293032906362*x^27 + 299056435803*x^28)*
            HPL[{0, 0, 0}, x])/(4725*(-1 + x)^11*(1 + x)^13*(1 - 9*x^2)^6) + 
          ((3 + 24*x + 30*x^2 + 1424*x^3 + 811*x^4 + 9623*x^5 - 220*x^6 + 
             29807*x^7 - 10511*x^8 + 28291*x^9 - 6770*x^10 + 6011*x^11 - 
             563*x^12)*HPL[{1, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^12) - 
          ((140 + 840*x - 7009*x^2 - 159474*x^3 + 355830*x^4 + 7774326*x^5 - 
             13094452*x^6 - 135453318*x^7 + 252248382*x^8 + 493050474*x^9 - 
             2288115221*x^10 + 11999316924*x^11 + 4960873996*x^12 - 
             148134319284*x^13 + 67339931392*x^14 + 508483303524*x^15 - 
             467823642984*x^16 + 519253656012*x^17 + 607933730997*x^18 - 
             4072020202026*x^19 + 1449640051614*x^20 - 2508159199266*x^21 - 
             127511222220*x^22 + 77671351170*x^23 - 264177995778*x^24 + 
             61476688098*x^25 - 35187738687*x^26)*master3l8b[x])/
           (113400*(-1 + x)^11*x^2*(1 + x)^13*(1 - 9*x^2)^6) + 
          ((70 + 420*x - 2459*x^2 - 73794*x^3 + 101247*x^4 + 3384528*x^5 - 
             4063373*x^6 - 48872082*x^7 + 77167055*x^8 + 63328104*x^9 - 
             624410206*x^10 + 3790950156*x^11 + 1212116694*x^12 - 
             25047871296*x^13 + 8548934390*x^14 + 16024964508*x^15 - 
             28912055148*x^16 + 73126241748*x^17 + 2815518825*x^18 + 
             419682401334*x^19 - 183214541061*x^20 + 713650782096*x^21 - 
             112089858777*x^22 + 186020812278*x^23 + 3909748743*x^24)*
            master3l9b[x])/(113400*(-1 + x)^11*x^2*(1 + x)^13*
            (-1 + 9*x^2)^5) + (-9450 - 56700*x + 
            x^2*(696055 - 20160*Zeta[3]) - 210*x^3*(-61609 + 576*Zeta[3]) + 
            336*x^5*(-1959853 + 6840*Zeta[3]) + 3*x^4*(-15846571 + 
              403200*Zeta[3]) - 50*x^6*(-35140849 + 764064*Zeta[3]) + 
            504*x^7*(27018623 + 1470240*Zeta[3]) - 4251528*x^30*
             (5051023 + 2598120*Zeta[3]) + 14880348*x^29*
             (572707 + 3235680*Zeta[3]) + 4*x^8*(-8503721543 + 
              52416000*Zeta[3]) - 168*x^9*(489607633 + 215952480*Zeta[3]) - 
            1377810*x^27*(-296477323 + 219485376*Zeta[3]) - 
            3674160*x^25*(168134441 + 362813904*Zeta[3]) + 
            1049760*x^24*(644707449 + 479131520*Zeta[3]) - 
            177147*x^28*(831123283 + 709228800*Zeta[3]) + 
            714*x^11*(-2063086267 + 987076800*Zeta[3]) + 
            9*x^10*(36149997109 + 2254203840*Zeta[3]) + 45927*x^26*
             (-14436209219 + 5801457600*Zeta[3]) - 252*x^13*(-121008798071 + 
              26582968800*Zeta[3]) + 672*x^15*(-304486972789 + 
              40092858000*Zeta[3]) - 10206*x^19*(-187441279357 + 
              56299707200*Zeta[3]) + 13608*x^23*(-525563267201 + 
              67749268320*Zeta[3]) + 81*x^20*(-857332362703 + 
              238555564800*Zeta[3]) + 84*x^17*(3962869501313 + 
              334161187200*Zeta[3]) - x^12*(581014861183 + 591327878400*Zeta[
                3]) + 1512*x^21*(-3442703985209 + 787683819600*Zeta[3]) - 
            486*x^22*(-6153817157107 + 1532660401440*Zeta[3]) + 
            4*x^14*(-4666709974547 + 1848923672400*Zeta[3]) - 
            6*x^16*(-30483124287137 + 7869765657600*Zeta[3]) + 
            7*x^18*(-85674134501449 + 19030115361600*Zeta[3]))/
           (8164800*(-1 + x)^11*x^2*(1 + x)^13*(1 - 9*x^2)^6))) + 
      CA*CF*((Pi^2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 
           1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2}, x])/
         (540*(-1 + x)^8*(1 + x)^10) + 
        lm^2*((-11*(1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 956*x^5 - 
             398*x^6 + 356*x^7 - 23*x^8 + 6*x^9 + x^10))/(480*(-1 + x)^8*
            (1 + x)^10) + (11*x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 
             3*x^5 + 2*x^6)*HPL[{0}, x])/(4*(-1 + x)^9*(1 + x)^11)) - 
        (Pi^2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{2}, x])/
         (540*(-1 + x)^8*(1 + x)^10) + (x*(-29 + 1227*x - 4734*x^2 + 
           15486*x^3 - 114753*x^4 + 97607*x^5 - 229200*x^6 + 140617*x^7 - 
           176793*x^8 - 93480*x^9 + 87858*x^10 + 205013*x^11 - 75517*x^12 - 
           255366*x^13 + 23760*x^14 + 218790*x^15 + 19800*x^16 - 
           127490*x^17 - 28160*x^18 + 48510*x^19 + 15444*x^20 - 10902*x^21 - 
           4296*x^22 + 1100*x^23 + 500*x^24)*HPL[{-2, 0}, x])/
         (1080*(-1 + x)^10*(1 + x)^12) + 
        ((-210000 - 462000*x + 1489320*x^2 + 3885840*x^3 - 4165000*x^4 - 
           14352940*x^5 + 4967900*x^6 + 30416540*x^7 + 812420*x^8 + 
           (-40351757 + 1680*Pi^2)*x^9 + 14*(-689677 + 720*Pi^2)*x^10 + 
           (32926448 - 174720*Pi^2)*x^11 + 14*(2376641 + 83280*Pi^2)*x^12 - 
           3*(13847733 + 590800*Pi^2)*x^13 + 56*(1349519 + 37440*Pi^2)*x^14 - 
           42304904*x^15 - 56*(-1349519 + 37440*Pi^2)*x^16 + 
           3*(-13847733 + 590800*Pi^2)*x^17 - 14*(-2376641 + 83280*Pi^2)*
            x^18 + 16*(2057903 + 10920*Pi^2)*x^19 - 14*(689677 + 720*Pi^2)*
            x^20 - (40351757 + 1680*Pi^2)*x^21 + 812420*x^22 + 
           30416540*x^23 + 4967900*x^24 - 14352940*x^25 - 4165000*x^26 + 
           3885840*x^27 + 1489320*x^28 - 462000*x^29 - 210000*x^30)*
          HPL[{-1, 0}, x])/(907200*(-1 + x)^9*x^9*(1 + x)^11) + 
        (x*(-38837708280 + 2284087674708*x - 22995042112476*x^2 - 
           57991406106951*x^3 + 967670437408542*x^4 - 197065243403307*x^5 - 
           12257742375553248*x^6 + 21080359707338628*x^7 - 
           8497494629846712*x^8 - 261959354008296228*x^9 + 
           1493676232917171408*x^10 + 1129459021235738064*x^11 - 
           12376909031034473352*x^12 + 640217370687886848*x^13 + 
           27073695318424678896*x^14 - 12557180532030800316*x^15 + 
           78594043247676304320*x^16 - 20693805227905902244*x^17 - 
           234728663965565217224*x^18 + 143409535463545355274*x^19 - 
           448864882775746425324*x^20 + 114924912174267800434*x^21 + 
           148595730066986462064*x^22 - 182676550195879922756*x^23 + 
           33549156789665782496*x^24 + 137725146622439668124*x^25 - 
           15853827165424906896*x^26 - 88560059469416773032*x^27 - 
           7462965888643214712*x^28 + 46554978037072633832*x^29 + 
           9616389697344860528*x^30 - 18389402616248191572*x^31 - 
           5149028205191257800*x^32 + 5265421143815099040*x^33 + 
           1744479184787090052*x^34 - 1070310716887260267*x^35 - 
           394989492472222914*x^36 + 151305200386183665*x^37 + 
           60056561917522800*x^38 - 14451569132479920*x^39 - 
           6035474991326760*x^40 + 886409847401400*x^41 + 
           384018595803360*x^42 - 31465388666880*x^43 - 14008062000240*x^44 + 
           491051484000*x^45 + 223205220000*x^46)*HPL[{0, 0}, x])/
         (907200*(-1 + x)^10*(1 + x)^12*(9 - 82*x^2 + 9*x^4)^6) + 
        ((210000 + 462000*x - 1489320*x^2 - 3885840*x^3 + 4165000*x^4 + 
           14352940*x^5 - 4967900*x^6 - 30416540*x^7 - 812420*x^8 + 
           (40351757 - 1680*Pi^2)*x^9 - 14*(-689677 + 720*Pi^2)*x^10 + 
           16*(-2057903 + 10920*Pi^2)*x^11 - 14*(2376641 + 83280*Pi^2)*x^12 + 
           3*(13847733 + 590800*Pi^2)*x^13 - 56*(1349519 + 37440*Pi^2)*x^14 + 
           42304904*x^15 + 56*(-1349519 + 37440*Pi^2)*x^16 + 
           (41543199 - 1772400*Pi^2)*x^17 + 14*(-2376641 + 83280*Pi^2)*x^18 - 
           16*(2057903 + 10920*Pi^2)*x^19 + 14*(689677 + 720*Pi^2)*x^20 + 
           (40351757 + 1680*Pi^2)*x^21 - 812420*x^22 - 30416540*x^23 - 
           4967900*x^24 + 14352940*x^25 + 4165000*x^26 - 3885840*x^27 - 
           1489320*x^28 + 462000*x^29 + 210000*x^30)*HPL[{1, 0}, x])/
         (907200*(-1 + x)^9*x^9*(1 + x)^11) + 
        lm*(-(3290 + 13503*x - 49479*x^2 + 1145148*x^3 - 1125863*x^4 + 
             3071034*x^5 - 1125863*x^6 + 1145148*x^7 - 49479*x^8 + 
             13503*x^9 + 3290*x^10 + 66*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*
                x^4 - 16*x^6 + 48*x^7 - 3*x^8 + 6*x^9 + x^10))/
           (38880*(-1 + x)^8*(1 + x)^10) + (x^2*(22 + 34092*x - 45770*x^2 + 
             229698*x^3 - 155178*x^4 + 289098*x^5 - 82895*x^6 + 68742*x^7 - 
             2354*x^8 + 594*x^9 + 99*x^10)*HPL[{0}, x])/(1080*(-1 + x)^9*
            (1 + x)^11) + (11*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 
             2*x^6 + 6*x^7 + x^8)*HPL[{-1, 0}, x])/(540*(-1 + x)^7*
            (1 + x)^9) - (11*x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 
             13200*x^4 - 7055*x^5 + 9810*x^6 - 2169*x^7 + 1476*x^8 - 5*x^9 + 
             6*x^10 + x^11)*HPL[{0, 0}, x])/(270*(-1 + x)^10*(1 + x)^12) - 
          (11*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + 
             x^8)*HPL[{1, 0}, x])/(540*(-1 + x)^7*(1 + x)^9)) - 
        (x*(-29 + 1227*x - 4734*x^2 + 15486*x^3 - 114753*x^4 + 97607*x^5 - 
           229200*x^6 + 140617*x^7 - 176793*x^8 - 93480*x^9 + 87858*x^10 + 
           205013*x^11 - 75517*x^12 - 255366*x^13 + 23760*x^14 + 
           218790*x^15 + 19800*x^16 - 127490*x^17 - 28160*x^18 + 48510*x^19 + 
           15444*x^20 - 10902*x^21 - 4296*x^22 + 1100*x^23 + 500*x^24)*
          HPL[{2, 0}, x])/(1080*(-1 + x)^10*(1 + x)^12) - 
        ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) + (4*x^2*(-50 + 326*x - 571*x^2 + 
           974*x^3 - 587*x^4 + 374*x^5 - 53*x^6 + 6*x^7 + x^8)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) + 
        ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2, 1, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) + ((1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{-1, -2, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) + 
        ((-250 - 550*x + 1398*x^2 + 3801*x^3 - 2778*x^4 - 11202*x^5 + 
           1302*x^6 + 18186*x^7 + 3738*x^8 - 17430*x^9 - 7350*x^10 + 
           9611*x^11 + 5650*x^12 - 2474*x^13 - 4350*x^14 + 996*x^15 - 
           4350*x^16 - 2474*x^17 + 5650*x^18 + 9611*x^19 - 7350*x^20 - 
           17430*x^21 + 3738*x^22 + 18186*x^23 + 1302*x^24 - 11202*x^25 - 
           2778*x^26 + 3801*x^27 + 1398*x^28 - 550*x^29 - 250*x^30)*
          HPL[{-1, -1, 0}, x])/(1080*(-1 + x)^7*x^11*(1 + x)^9) + 
        ((5731 - 2166*x - 72344*x^2 + 789090*x^3 - 1576725*x^4 + 
           3664582*x^5 - 3567802*x^6 + 4134282*x^7 - 1798100*x^8 - 
           254260*x^9 + 335756*x^10 + 1817624*x^11 - 471844*x^12 - 
           2190300*x^13 + 388500*x^14 + 1829100*x^15 - 217875*x^16 - 
           1046850*x^17 + 80500*x^18 + 393050*x^19 - 17675*x^20 - 
           87430*x^21 + 1750*x^22 + 8750*x^23)*HPL[{-1, 0, 0}, x])/
         (18900*(-1 + x^2)^10) + ((250 + 550*x - 1398*x^2 - 3801*x^3 + 
           2778*x^4 + 11202*x^5 - 1302*x^6 - 18186*x^7 - 3738*x^8 + 
           17430*x^9 + 7350*x^10 - 9611*x^11 - 5650*x^12 + 2474*x^13 + 
           4350*x^14 - 996*x^15 + 4350*x^16 + 2474*x^17 - 5650*x^18 - 
           9611*x^19 + 7350*x^20 + 17430*x^21 - 3738*x^22 - 18186*x^23 - 
           1302*x^24 + 11202*x^25 + 2778*x^26 - 3801*x^27 - 1398*x^28 + 
           550*x^29 + 250*x^30)*HPL[{-1, 1, 0}, x])/(1080*(-1 + x)^7*x^11*
          (1 + x)^9) - ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 
           1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) - (x*(-539412615 + 22376323305*x - 
           744174011070*x^2 + 812145134178*x^3 + 27085708472382*x^4 - 
           74286875645712*x^5 - 214270183141812*x^6 + 1793620625287590*x^7 - 
           3730578902246322*x^8 - 21560753147307336*x^9 + 83496870266489736*
            x^10 + 148179865580754306*x^11 - 597325957982667298*x^12 - 
           639990712284597904*x^13 + 1453720495375196804*x^14 + 
           2139925984722381066*x^15 + 1401034991670733048*x^16 - 
           6648485057937832258*x^17 - 2615792915889228124*x^18 + 
           13233994609820065458*x^19 - 30775793310362726878*x^20 - 
           7216427388312290468*x^21 + 14454125154855576484*x^22 + 
           10247260919733392878*x^23 - 3435072871872619558*x^24 - 
           14443297249962006252*x^25 + 1047045267963666552*x^26 + 
           13488255641023872354*x^27 + 504464298748656498*x^28 - 
           9147599962136546156*x^29 - 1264409268452469524*x^30 + 
           4641244545672532566*x^31 + 1026924191693311527*x^32 - 
           1750815948233734095*x^33 - 499928047783646790*x^34 + 
           482897055109762580*x^35 + 161428336388367272*x^36 - 
           95422126022504748*x^37 - 35376900229414800*x^38 + 
           13205266031708100*x^39 + 5253572970220680*x^40 - 
           1241014366744740*x^41 - 518860520912160*x^42 + 
           75175135064820*x^43 + 32583668864040*x^44 - 2642576200740*x^45 - 
           1176638717520*x^46 + 40920957000*x^47 + 18600435000*x^48)*
          HPL[{0, 0, 0}, x])/(37800*(-1 + x)^10*(1 + x)^12*
          (9 - 82*x^2 + 9*x^4)^6) - ((1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{1, -2, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) + 
        ((250 + 550*x - 1398*x^2 - 3801*x^3 + 2778*x^4 + 11202*x^5 - 
           1302*x^6 - 18186*x^7 - 3738*x^8 + 17430*x^9 + 7350*x^10 - 
           9611*x^11 - 5650*x^12 + 2474*x^13 + 4350*x^14 - 996*x^15 + 
           4350*x^16 + 2474*x^17 - 5650*x^18 - 9611*x^19 + 7350*x^20 + 
           17430*x^21 - 3738*x^22 - 18186*x^23 - 1302*x^24 + 11202*x^25 + 
           2778*x^26 - 3801*x^27 - 1398*x^28 + 550*x^29 + 250*x^30)*
          HPL[{1, -1, 0}, x])/(1080*(-1 + x)^7*x^11*(1 + x)^9) - 
        ((5731 + 22438*x - 21720*x^2 + 669318*x^3 + 298267*x^4 + 
           1148254*x^5 + 1486814*x^6 + 1230714*x^7 + 1181212*x^8 + 
           1336348*x^9 - 1470580*x^10 - 1949672*x^11 + 1080476*x^12 + 
           2795940*x^13 + 47460*x^14 - 2285220*x^15 - 789075*x^16 + 
           1053570*x^17 + 665140*x^18 - 216090*x^19 - 248395*x^20 - 
           10430*x^21 + 36750*x^22 + 8750*x^23)*HPL[{1, 0, 0}, x])/
         (18900*(-1 + x)^8*(1 + x)^12) + 
        ((-250 - 550*x + 1398*x^2 + 3801*x^3 - 2778*x^4 - 11202*x^5 + 
           1302*x^6 + 18186*x^7 + 3738*x^8 - 17430*x^9 - 7350*x^10 + 
           9611*x^11 + 5650*x^12 - 2474*x^13 - 4350*x^14 + 996*x^15 - 
           4350*x^16 - 2474*x^17 + 5650*x^18 + 9611*x^19 - 7350*x^20 - 
           17430*x^21 + 3738*x^22 + 18186*x^23 + 1302*x^24 - 11202*x^25 - 
           2778*x^26 + 3801*x^27 + 1398*x^28 - 550*x^29 - 250*x^30)*
          HPL[{1, 1, 0}, x])/(1080*(-1 + x)^7*x^11*(1 + x)^9) + 
        ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) + ((1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{2, -1, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) - 
        (4*x^2*(-50 + 326*x - 571*x^2 + 974*x^3 - 587*x^4 + 374*x^5 - 
           53*x^6 + 6*x^7 + x^8)*HPL[{2, 0, 0}, x])/(45*(-1 + x)^8*
          (1 + x)^10) - ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 
           1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{2, 1, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) - (2*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 
           54*x^5 - 2*x^6 + 6*x^7 + x^8)*HPL[{-1, 0, 0, 0}, x])/
         (45*(-1 + x)^7*(1 + x)^9) + (2*(1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{-1, 1, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) + 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{1, -1, 0, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) + (2*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 
           54*x^5 - 2*x^6 + 6*x^7 + x^8)*HPL[{1, 0, 0, 0}, x])/
         (45*(-1 + x)^7*(1 + x)^9) - ((1 + 11*x - 79*x^2 + 983*x^3 - 
           1519*x^4 + 4040*x^5 - 2444*x^6 + 2792*x^7 - 464*x^8 + 289*x^9 + 
           25*x^10 + 5*x^11)*master3l10a[x])/(360*(-1 + x)^9*(1 + x)^11) + 
        (x*(5 + 25*x + 289*x^2 - 464*x^3 + 2792*x^4 - 2444*x^5 + 4040*x^6 - 
           1519*x^7 + 983*x^8 - 79*x^9 + 11*x^10 + x^11)*master3l10b[x])/
         (360*(-1 + x)^9*(1 + x)^11) + ((-36780231168 + 219984864687*x - 
           1577323152297*x^2 + 5156784534762*x^3 - 6203142941544*x^4 + 
           5606272174671*x^5 - 240649731351*x^6 - 1706932920168*x^7 + 
           973764252864*x^8 - 540328340034*x^9 - 98219048346*x^10 + 
           273934359132*x^11 - 45280970640*x^12 - 41091162378*x^13 + 
           13008879026*x^14 + 2236800216*x^15 - 1442524416*x^16 + 
           48383027*x^17 + 77601939*x^18 - 9956534*x^19 - 1794248*x^20 + 
           292635*x^21 + 6677*x^22)*master3l8a[x])/(907200*(-1 + x)^10*
          (1 + x)^12*(-9 + x^2)^6) + ((4060 - 176777*x + 150325*x^2 + 
           10004580*x^3 - 12840366*x^4 - 259152035*x^5 + 274778189*x^6 + 
           3964932000*x^7 - 2672435808*x^8 - 38371794922*x^9 + 
           12743040170*x^10 + 231109171192*x^11 - 40785838212*x^12 - 
           781009535382*x^13 + 292551429954*x^14 + 1040815666800*x^15 - 
           1816581627756*x^16 + 577131299235*x^17 + 3655791054657*x^18 - 
           717237731772*x^19 + 1711026799650*x^20 - 40656095991*x^21 + 
           48140635473*x^22 + 34101768528*x^23)*master3l8b[x])/
         (907200*(-1 + x)^10*x*(1 + x)^12*(1 - 9*x^2)^6) + 
        ((3937888872 - 9546901623*x + 85807935225*x^2 - 192491752131*x^3 + 
           314306726679*x^4 - 129748034682*x^5 + 80355249108*x^6 - 
           20508043164*x^7 + 12653439564*x^8 + 43992426870*x^9 - 
           36526867106*x^10 - 12596407978*x^11 + 11296467090*x^12 + 
           1591188144*x^13 - 1599318876*x^14 - 95936652*x^15 + 
           122712148*x^16 + 1917881*x^17 - 5073871*x^18 + 52885*x^19 + 
           91727*x^20 - 2030*x^21)*master3l9a[x])/(302400*(-1 + x)^10*
          (1 + x)^12*(-9 + x^2)^5) + ((-2030 + 91727*x + 52885*x^2 - 
           5073871*x^3 + 1917881*x^4 + 122712148*x^5 - 95936652*x^6 - 
           1599318876*x^7 + 1591188144*x^8 + 11296467090*x^9 - 
           12596407978*x^10 - 36526867106*x^11 + 43992426870*x^12 + 
           12653439564*x^13 - 20508043164*x^14 + 80355249108*x^15 - 
           129748034682*x^16 + 314306726679*x^17 - 192491752131*x^18 + 
           85807935225*x^19 - 9546901623*x^20 + 3937888872*x^21)*
          master3l9b[x])/(907200*(-1 + x)^10*x*(1 + x)^12*(-1 + 9*x^2)^5) + 
        (HPL[{1}, x]*(Pi^2*(250 + 550*x - 1648*x^2 - 4351*x^3 + 4176*x^4 + 
             15003*x^5 - 4080*x^6 - 29388*x^7 - 2436*x^8 + 35616*x^9 + 
             11088*x^10 - 27041*x^11 - 13000*x^12 + 12085*x^13 + 10000*x^14 - 
             3470*x^15 + 3470*x^17 - 10000*x^18 - 12085*x^19 + 13000*x^20 + 
             27041*x^21 - 11088*x^22 - 35616*x^23 + 2436*x^24 + 29388*x^25 + 
             4080*x^26 - 15003*x^27 - 4176*x^28 + 4351*x^29 + 1648*x^30 - 
             550*x^31 - 250*x^32) - 288*x^11*(1 + 6*x - 103*x^2 + 700*x^3 - 
             1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + 
             x^10)*Zeta[3]))/(12960*(-1 + x)^8*x^11*(1 + x)^10) + 
        (HPL[{-1}, x]*(Pi^2*(-250 - 550*x + 1648*x^2 + 4351*x^3 - 4176*x^4 - 
             15003*x^5 + 4080*x^6 + 29388*x^7 + 2436*x^8 - 35616*x^9 - 
             11088*x^10 + 27041*x^11 + 13000*x^12 - 12085*x^13 - 10000*x^14 + 
             3470*x^15 - 3470*x^17 + 10000*x^18 + 12085*x^19 - 13000*x^20 - 
             27041*x^21 + 11088*x^22 + 35616*x^23 - 2436*x^24 - 29388*x^25 - 
             4080*x^26 + 15003*x^27 + 4176*x^28 - 4351*x^29 - 1648*x^30 + 
             550*x^31 + 250*x^32) + 288*x^11*(1 + 6*x - 103*x^2 + 700*x^3 - 
             1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + 
             x^10)*Zeta[3]))/(12960*(-1 + x)^8*x^11*(1 + x)^10) + 
        (HPL[{0}, x]*(669615660000 + 1473154452000*x - 41689378170720*x^2 - 
           93659588774640*x^3 + 1131266899629720*x^4 + 2612522510687880*x^5 - 
           17544237738360480*x^6 - 42056189726391540*x^7 + 
           612360*(280049084941 + 21141*Pi^2)*x^8 - 
           17496*(-24752600277626 + 31306905*Pi^2)*x^9 + 
           1680*(620379792518444825 + 12434167663613526*Pi^2)*x^26 - 
           3*(144744418081838907 + 1931522995525397960*Pi^2)*x^43 - 
           210*(816499516011615 + 9224500983427964*Pi^2)*x^44 + 
           405*(103893725206071 + 2827313422686368*Pi^2)*x^45 + 
           90720*(193388863959 + 4679484157330*Pi^2)*x^46 - 
           204120*(12798954099 + 776323693810*Pi^2)*x^47 - 
           204120*(5542165881 + 308852026468*Pi^2)*x^48 + 
           1224720*(76474287 + 12159654779*Pi^2)*x^49 + 
           2449440*(17019963 + 2541938668*Pi^2)*x^50 - 
           33067440*(44550 + 27280661*Pi^2)*x^51 - 66134880*
            (10125 + 5912221*Pi^2)*x^52 + 31710914408880*Pi^2*x^53 + 
           14119664610240*Pi^2*x^54 - 491051484000*Pi^2*x^55 - 
           223205220000*Pi^2*x^56 + 144*x^41*(145871095024886455*Pi^2 + 
             27*(777351155693173 - 8928208800*Zeta[3])) - 
           8*x^31*(-2134408344070302028 + 19425358561203709905*Pi^2 - 
             944274647073643200*Zeta[3]) + 168*x^24*(-5556647351870891849 + 
             31797301627372560*Pi^2 - 410807471955062400*Zeta[3]) + 
           8*x^33*(14611941684268865474 + 22691597012462908845*Pi^2 - 
             350010488321726400*Zeta[3]) + 24*x^23*(775357814610594553 + 
             235241647549475595*Pi^2 - 120530949548385600*Zeta[3]) - 
           504*x^22*(-196018615306448773 + 20185226352660540*Pi^2 - 
             57449513274796800*Zeta[3]) - 12*x^35*(8997085371295203163 + 
             13507180784798466150*Pi^2 - 38255347012579200*Zeta[3]) + 
           560*x^20*(116012790364159348 + 5702282920638507*Pi^2 - 
             4668414937272000*Zeta[3]) - 168*x^34*(-556919285760906203 + 
             135245303216964000*Pi^2 - 4357523820844800*Zeta[3]) + 
           12*x^37*(4080714715632289503 + 9127746123675213230*Pi^2 - 
             3350971039651200*Zeta[3]) - 36*x^39*(405032337331745009 + 
             1545737785293561090*Pi^2 - 51105067171200*Zeta[3]) - 
           126*x^12*(-37365166658167723 + 381768187500*Pi^2 - 
             9122078476800*Zeta[3]) + 6804*x^10*(-161792844953239 + 
             206584020*Pi^2 - 3401222400*Zeta[3]) + 
           252*x^42*(4368478491287073 + 23806361535983740*Pi^2 + 
             91833004800*Zeta[3]) + 243*x^11*(-12330374870254243 + 
             94774957200*Pi^2 + 142851340800*Zeta[3]) - 
           504*x^40*(9418794272891332 + 24441469934316975*Pi^2 + 
             2280519619200*Zeta[3]) - 504*x^14*(26741428762555979 + 
             502613982900*Pi^2 + 44899536902400*Zeta[3]) + 
           1680*x^16*(15923706918476849 + 16332032158083*Pi^2 + 
             126028422417600*Zeta[3]) + 168*x^38*(86324604711803817 + 
             89422592862300700*Pi^2 + 134698610707200*Zeta[3]) - 
           9*x^13*(-1588477073587759091 + 38998575864360*Pi^2 + 
             204420268684800*Zeta[3]) - 840*x^36*(45062123919731773 + 
             5007784841903574*Pi^2 + 252056844835200*Zeta[3]) + 
           72*x^15*(-662400224900929763 + 29234999458035*Pi^2 + 
             558495173275200*Zeta[3]) - 168*x^18*(263411923845474083 + 
             2629180702116720*Pi^2 + 4357523820844800*Zeta[3]) + 
           280*x^32*(-146819638906071461 + 190876667784415410*Pi^2 + 
             9336829874544000*Zeta[3]) - 24*x^17*(-4613264696301836264 + 
             164029897104885*Pi^2 + 19127673506289600*Zeta[3]) - 
           504*x^30*(1895648439501076253 + 137177145409717620*Pi^2 + 
             57449513274796800*Zeta[3]) + 12*x^19*(-13869051427606184731 + 
             6040957751273970*Pi^2 + 233340325547817600*Zeta[3]) + 
           6*x^29*(31208915380324645703 + 17889133048558671900*Pi^2 + 
             482123798193542400*Zeta[3]) + 84*x^28*(28356611282019229033 + 
             532261198377337560*Pi^2 + 821614943910124800*Zeta[3]) - 
           42*x^27*(28084438840721332099 + 1455150096058891340*Pi^2 + 
             1226387823950534400*Zeta[3]) - 4*x^21*(-28013769960182051219 + 
             301627635852516750*Pi^2 + 1888549294147286400*Zeta[3]) + 
           8*x^25*(46393824342611695256 + 151528677277569585*Pi^2 + 
             6438536075740305600*Zeta[3])))/(10886400*(-1 + x)^10*x^7*
          (1 + x)^12*(9 - 82*x^2 + 9*x^4)^6) + 
        (4032*Pi^4*x^9*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^6*
           (-3 - 18*x - 491*x^2 + 3116*x^3 - 5662*x^4 + 9740*x^5 - 5918*x^6 + 
            3884*x^7 - 539*x^8 + 78*x^9 + 13*x^10) + 
          12*Pi^2*(9 - 82*x^2 + 9*x^4)^6*(-210000 - 462000*x + 1699320*x^2 + 
            4347840*x^3 - 5654320*x^4 - 18238780*x^5 + 9132900*x^6 + 
            44769480*x^7 - 4155480*x^8 - 70768297*x^9 - 10467898*x^10 + 
            73278205*x^11 + 42928452*x^12 - 74469647*x^13 + 42300090*x^14 - 
            761705*x^15 + 761705*x^17 - 42300090*x^18 + 74469647*x^19 - 
            42928452*x^20 - 73278205*x^21 + 10467898*x^22 + 70768297*x^23 + 
            4155480*x^24 - 44769480*x^25 - 9132900*x^26 + 18238780*x^27 + 
            5654320*x^28 - 4347840*x^29 - 1699320*x^30 + 462000*x^31 + 
            210000*x^32) + x^2*(-2008846980000 - 4419463356000*x + 
            125737750172160*x^2 + 282451920775920*x^3 - 3435238971187380*
             x^4 - 7930674687918780*x^5 + 53748777383971740*x^6 + 
            x^33*(945508478323245855324 - 6430224102065715457728*Zeta[3]) + 
            x^25*(6121511437130707020858 - 3052437854539743854784*Zeta[3]) + 
            x^27*(588910402336373971398 - 767213266512819248064*Zeta[3]) - 
            1141592918719680*x^53*Zeta[3] - 508307925968640*x^54*Zeta[3] + 
            17677853424000*x^55*Zeta[3] + 8035387920000*x^56*Zeta[3] + 
            595213920*x^52*(-3375 + 23648884*Zeta[3]) + 595213920*x^51*
             (-7425 + 54561322*Zeta[3]) - 91854*x^8*(5790498413329 + 
              385588512*Zeta[3]) - 352719360*x^50*(-356481 + 635484667*Zeta[
                3]) - 19683*x^7*(-6544360713613 + 1125855936*Zeta[3]) + 
            20412*x^10*(170099421452689 + 8892656928*Zeta[3]) - 
            11022480*x^49*(-25625079 + 48638619116*Zeta[3]) + 
            6561*x^9*(-204425763126989 + 198781807104*Zeta[3]) + 
            918540*x^48*(-3739890447 + 2470816211744*Zeta[3]) + 
            918540*x^47*(-8634000357 + 6210589550480*Zeta[3]) - 
            91008*x^15*(-1518635200415149 + 29810088351801*Zeta[3]) - 
            729*x^11*(-12833715948327709 + 44141781829824*Zeta[3]) - 
            204120*x^46*(-263318078097 + 74871746517280*Zeta[3]) + 
            378*x^12*(-39574502567230789 + 129194849407392*Zeta[3]) - 
            504*x^14*(-74048142702213103 + 2963602945899072*Zeta[3]) + 
            4788*x^16*(1478384459284177 + 4062168209810880*Zeta[3]) + 
            27*x^13*(-1633692548611227629 + 15449478924817152*Zeta[3]) - 
            729*x^45*(-176545152041841 + 56546297881859392*Zeta[3]) + 
            36*x^17*(-8331399419965729145 + 61800107526684576*Zeta[3]) - 
            2268*x^42*(-1526560652678481 + 95225434838334688*Zeta[3]) - 
            1008*x^18*(478356098063734115 + 125261983902574368*Zeta[3]) + 
            378*x^44*(-1406253412585557 + 184489938427527904*Zeta[3]) + 
            1008*x^34*(-24281882968484975 + 672361240961639232*Zeta[3]) + 
            252*x^36*(-212536498654759337 + 681988067593434720*Zeta[3]) + 
            2688*x^30*(494554197459835673 + 949856378263085466*Zeta[3]) + 
            5364*x^35*(-82742258112201475 + 1088113865288701104*Zeta[3]) + 
            378*x^40*(-39545514246054979 + 1173325363979696352*Zeta[3]) + 
            224*x^20*(6517058009304522311 + 1493749405548144432*Zeta[3]) - 
            252*x^38*(-161756199531789641 + 2152224702772880064*Zeta[3]) + 
            168*x^22*(2495633779842948353 + 2300031895315971456*Zeta[3]) + 
            27*x^43*(-49571695025751177 + 7726137993118293632*Zeta[3]) + 
            12*x^19*(59717073839774160947 + 8459641989969073056*Zeta[3]) - 
            81*x^41*(-115849827471058011 + 9336123891753956416*Zeta[3]) - 
            112*x^32*(640959997941431003 + 13292115119962406136*Zeta[3]) - 
            36*x^21*(62016115395424092997 + 21777495451895480288*Zeta[3]) - 
            84*x^24*(56030174884897219993 + 46266535762544542176*Zeta[3]) - 
            72*x^37*(-2258323049256598561 + 54801418984787561304*Zeta[3]) - 
            18*x^29*(15556276426650829065 + 63044034625963431776*Zeta[3]) - 
            84*x^28*(2314706467099847863 + 63770130755027885376*Zeta[3]) + 
            27*x^39*(-1698587586369673859 + 74209842097124666112*Zeta[3]) + 
            56*x^26*(-163541476334647446913 + 113839174302390442080*Zeta[
                3]) + 36*x^31*(-33040399838966576767 + 132517662643664405872*
               Zeta[3]) + 18*x^23*(127452848049239642025 + 
              141468569787246819424*Zeta[3])))/(130636800*(-1 + x)^10*x^9*
          (1 + x)^12*(9 - 82*x^2 + 9*x^4)^6)) + 
      CF^2*(-(Pi^2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 
            1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2}, x])/
         (270*(-1 + x)^8*(1 + x)^10) + 
        lm^2*((9*(1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 956*x^5 - 398*x^6 + 
             356*x^7 - 23*x^8 + 6*x^9 + x^10))/(80*(-1 + x)^8*(1 + x)^10) - 
          (27*x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*x^5 + 2*x^6)*
            HPL[{0}, x])/(2*(-1 + x)^9*(1 + x)^11)) + 
        (Pi^2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{2}, x])/
         (270*(-1 + x)^8*(1 + x)^10) + (x*(1015 - 42945*x + 407610*x^2 - 
           819210*x^3 + 6097875*x^4 - 4870285*x^5 + 8353800*x^6 - 
           7674555*x^7 + 15461075*x^8 + 12868912*x^9 - 20129130*x^10 - 
           37002133*x^11 + 26571699*x^12 + 64173336*x^13 - 19815616*x^14 - 
           76271400*x^15 + 4336204*x^16 + 62992620*x^17 + 7167284*x^18 - 
           35714786*x^19 - 8463716*x^20 + 13303386*x^21 + 4391560*x^22 - 
           2939400*x^23 - 1184500*x^24 + 292500*x^25 + 135000*x^26)*
          HPL[{-2, 0}, x])/(18900*(-1 + x)^10*(1 + x)^12) + 
        ((-56700000 - 122850000*x + 412440000*x^2 + 1050273000*x^3 - 
           1202170200*x^4 - 3960825120*x^5 + 1582017920*x^6 + 
           8626477440*x^7 - 152646900*x^8 - 11908724940*x^9 - 
           2665127780*x^10 + (10725927941 - 58800*Pi^2)*x^11 - 
           70*(-61825937 + 5040*Pi^2)*x^12 + 8*(-770741747 + 764400*Pi^2)*
            x^13 - 210*(20009839 + 194320*Pi^2)*x^14 + 
           25*(126607651 + 2481360*Pi^2)*x^15 - 280*(10510343 + 262080*Pi^2)*
            x^16 + 2096591960*x^17 + 280*(-10510343 + 262080*Pi^2)*x^18 + 
           (3165191275 - 62034000*Pi^2)*x^19 + 210*(-20009839 + 194320*Pi^2)*
            x^20 - 8*(770741747 + 764400*Pi^2)*x^21 + 
           70*(61825937 + 5040*Pi^2)*x^22 + (10725927941 + 58800*Pi^2)*x^23 - 
           2665127780*x^24 - 11908724940*x^25 - 152646900*x^26 + 
           8626477440*x^27 + 1582017920*x^28 - 3960825120*x^29 - 
           1202170200*x^30 + 1050273000*x^31 + 412440000*x^32 - 
           122850000*x^33 - 56700000*x^34)*HPL[{-1, 0}, x])/
         (15876000*(-1 + x)^9*x^11*(1 + x)^11) + 
        (x*(1359319789800 - 81681390868140*x + 1249549482473460*x^2 + 
           1756670570945325*x^3 - 52865231533318890*x^4 + 20781097242417225*
            x^5 + 714420971912889360*x^6 - 955363853684845080*x^7 - 
           957392402072586480*x^8 + 9876230295863685768*x^9 - 
           62100122026979544480*x^10 - 22885777817504974260*x^11 + 
           533519037296663664960*x^12 - 231681514068510290556*x^13 - 
           881428887447366066480*x^14 + 1408595713322251161360*x^15 - 
           6015347228148396590760*x^16 - 1193121273407717687152*x^17 + 
           18076774522125013344440*x^18 - 1691746970857645171794*x^19 + 
           11234379271094508371500*x^20 - 18941885850756276351970*x^21 + 
           3762018594557874725200*x^22 + 33404962118352608800128*x^23 - 
           11223742896708612864440*x^24 - 39036168699626595884200*x^25 + 
           5772426591606935940400*x^26 + 35737148266567336859676*x^27 + 
           689574745375509891520*x^28 - 25020270772894701247452*x^29 - 
           3459622520501745366160*x^30 + 13139781448374437135760*x^31 + 
           2965750585203704696160*x^32 - 5103388011807266293476*x^33 - 
           1488145417940579594700*x^34 + 1441472023426204552365*x^35 + 
           491818636815264000270*x^36 - 290281070088020679327*x^37 - 
           109733151988939298400*x^38 + 40768738979924473560*x^39 + 
           16520351873379487560*x^40 - 3875496101895327840*x^41 - 
           1648755439523645040*x^42 + 236863170922749840*x^43 + 
           104378339433236400*x^44 - 8384994256086000*x^45 - 
           3793149508680000*x^46 + 130575053700000*x^47 + 
           60265409400000*x^48)*HPL[{0, 0}, x])/(15876000*(-1 + x)^10*
          (1 + x)^12*(9 - 82*x^2 + 9*x^4)^6) + 
        ((56700000 + 122850000*x - 412440000*x^2 - 1050273000*x^3 + 
           1202170200*x^4 + 3960825120*x^5 - 1582017920*x^6 - 
           8626477440*x^7 + 152646900*x^8 + 11908724940*x^9 + 
           2665127780*x^10 + (-10725927941 + 58800*Pi^2)*x^11 + 
           70*(-61825937 + 5040*Pi^2)*x^12 - 8*(-770741747 + 764400*Pi^2)*
            x^13 + 210*(20009839 + 194320*Pi^2)*x^14 - 
           25*(126607651 + 2481360*Pi^2)*x^15 + 280*(10510343 + 262080*Pi^2)*
            x^16 - 2096591960*x^17 - 280*(-10510343 + 262080*Pi^2)*x^18 + 
           25*(-126607651 + 2481360*Pi^2)*x^19 - 
           210*(-20009839 + 194320*Pi^2)*x^20 + 8*(770741747 + 764400*Pi^2)*
            x^21 - 70*(61825937 + 5040*Pi^2)*x^22 - 
           (10725927941 + 58800*Pi^2)*x^23 + 2665127780*x^24 + 
           11908724940*x^25 + 152646900*x^26 - 8626477440*x^27 - 
           1582017920*x^28 + 3960825120*x^29 + 1202170200*x^30 - 
           1050273000*x^31 - 412440000*x^32 + 122850000*x^33 + 56700000*x^34)*
          HPL[{1, 0}, x])/(15876000*(-1 + x)^9*x^11*(1 + x)^11) + 
        lm*((221 + 192*x - 321*x^2 + 73932*x^3 - 54584*x^4 + 197784*x^5 - 
            54584*x^6 + 73932*x^7 - 321*x^8 + 192*x^9 + 221*x^10 + 
            12*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*x^4 - 16*x^6 + 48*x^7 - 
              3*x^8 + 6*x^9 + x^10))/(1440*(-1 + x)^8*(1 + x)^10) - 
          (x^2*(2 + 1842*x - 2275*x^2 + 13338*x^3 - 9078*x^4 + 18738*x^5 - 
             5650*x^6 + 4992*x^7 - 214*x^8 + 54*x^9 + 9*x^10)*HPL[{0}, x])/
           (20*(-1 + x)^9*(1 + x)^11) - ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 
             54*x^5 - 2*x^6 + 6*x^7 + x^8)*HPL[{-1, 0}, x])/
           (10*(-1 + x)^7*(1 + x)^9) + (x^3*(360 - 540*x + 4500*x^2 - 
             4400*x^3 + 13200*x^4 - 7055*x^5 + 9810*x^6 - 2169*x^7 + 
             1476*x^8 - 5*x^9 + 6*x^10 + x^11)*HPL[{0, 0}, x])/
           (5*(-1 + x)^10*(1 + x)^12) + ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 
             54*x^5 - 2*x^6 + 6*x^7 + x^8)*HPL[{1, 0}, x])/
           (10*(-1 + x)^7*(1 + x)^9)) - (x*(1015 - 42945*x + 407610*x^2 - 
           819210*x^3 + 6097875*x^4 - 4870285*x^5 + 8353800*x^6 - 
           7674555*x^7 + 15461075*x^8 + 12868912*x^9 - 20129130*x^10 - 
           37002133*x^11 + 26571699*x^12 + 64173336*x^13 - 19815616*x^14 - 
           76271400*x^15 + 4336204*x^16 + 62992620*x^17 + 7167284*x^18 - 
           35714786*x^19 - 8463716*x^20 + 13303386*x^21 + 4391560*x^22 - 
           2939400*x^23 - 1184500*x^24 + 292500*x^25 + 135000*x^26)*
          HPL[{2, 0}, x])/(18900*(-1 + x)^10*(1 + x)^12) + 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) - (4*(1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) - 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2, 1, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) - (2*(1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{-1, -2, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) - 
        ((67500 + 146250*x - 254750*x^2 - 738450*x^3 + 247030*x^4 + 
           1496943*x^5 + 225792*x^6 - 1525678*x^7 - 642698*x^8 + 782740*x^9 + 
           508242*x^10 - 157290*x^11 - 171598*x^12 - 9017*x^13 + 24682*x^14 + 
           10404*x^15 + 24682*x^16 - 9017*x^17 - 171598*x^18 - 157290*x^19 + 
           508242*x^20 + 782740*x^21 - 642698*x^22 - 1525678*x^23 + 
           225792*x^24 + 1496943*x^25 + 247030*x^26 - 738450*x^27 - 
           254750*x^28 + 146250*x^29 + 67500*x^30)*HPL[{-1, -1, 0}, x])/
         (18900*(-1 + x)^5*x^13*(1 + x)^7) + 
        ((-6838 - 6970*x + 147286*x^2 - 1199152*x^3 + 2703551*x^4 - 
           5367776*x^5 + 5343984*x^6 - 6317796*x^7 + 3286506*x^8 + 
           3096458*x^9 - 2199838*x^10 - 9808662*x^11 + 3454626*x^12 + 
           16175446*x^13 - 3723798*x^14 - 18635658*x^15 + 2859414*x^16 + 
           15084932*x^17 - 1532968*x^18 - 8435354*x^19 + 546283*x^20 + 
           3110930*x^21 - 116450*x^22 - 682250*x^23 + 11250*x^24 + 
           67500*x^25)*HPL[{-1, 0, 0}, x])/(9450*(-1 + x^2)^10) + 
        ((67500 + 146250*x - 254750*x^2 - 738450*x^3 + 247030*x^4 + 
           1496943*x^5 + 225792*x^6 - 1525678*x^7 - 642698*x^8 + 782740*x^9 + 
           508242*x^10 - 157290*x^11 - 171598*x^12 - 9017*x^13 + 24682*x^14 + 
           10404*x^15 + 24682*x^16 - 9017*x^17 - 171598*x^18 - 157290*x^19 + 
           508242*x^20 + 782740*x^21 - 642698*x^22 - 1525678*x^23 + 
           225792*x^24 + 1496943*x^25 + 247030*x^26 - 738450*x^27 - 
           254750*x^28 + 146250*x^29 + 67500*x^30)*HPL[{-1, 1, 0}, x])/
         (18900*(-1 + x)^5*x^13*(1 + x)^7) + 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) - (x*(-539412615 + 23269144185*x + 
           815230658025*x^2 - 1594211742207*x^3 - 31056118656948*x^4 + 
           24526562452110*x^5 + 391856187431646*x^6 + 445542859704582*x^7 - 
           1105429170372030*x^8 - 19451396874940686*x^9 - 4765615656251142*
            x^10 + 268891916517843306*x^11 - 180655069430656618*x^12 - 
           1818637932471212290*x^13 + 3135607857091037334*x^14 + 
           5765943655416996022*x^15 - 16462210807305905620*x^16 - 
           5541739308455536244*x^17 + 27035029717601729068*x^18 + 
           5537555902617695832*x^19 - 1826432163426790074*x^20 - 
           73788801358987914358*x^21 + 91390327817018674242*x^22 + 
           119748058343114240102*x^23 - 95321900745595850242*x^24 - 
           187457352037323409666*x^25 + 74515713570124355710*x^26 + 
           242547619881425719418*x^27 - 42785702718907981774*x^28 - 
           242118103313941243038*x^29 + 5840933819402051578*x^30 + 
           186904729733820827086*x^31 + 17186839240699541363*x^32 - 
           111458928285775864189*x^33 - 20290944882501327213*x^34 + 
           50920616632389431967*x^35 + 12854789425703681734*x^36 - 
           17583659274820005504*x^37 - 5406980618916577352*x^38 + 
           4508886916054457244*x^39 + 1579129631004308400*x^40 - 
           840569988875067360*x^41 - 321896118155241672*x^42 + 
           111143639859018876*x^43 + 45325759238700336*x^44 - 
           10081617060140280*x^45 - 4302145039468392*x^46 + 
           594035877569652*x^47 + 262126605436920*x^48 - 20430611515800*
            x^49 - 9246541959000*x^50 + 310892985000*x^51 + 
           143489070000*x^52)*HPL[{0, 0, 0}, x])/(18900*(-1 + x)^11*
          (1 + x)^13*(9 - 82*x^2 + 9*x^4)^6) + 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{1, -2, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) + ((67500 + 146250*x - 254750*x^2 - 
           738450*x^3 + 247030*x^4 + 1496943*x^5 + 225792*x^6 - 1525678*x^7 - 
           642698*x^8 + 782740*x^9 + 508242*x^10 - 157290*x^11 - 
           171598*x^12 - 9017*x^13 + 24682*x^14 + 10404*x^15 + 24682*x^16 - 
           9017*x^17 - 171598*x^18 - 157290*x^19 + 508242*x^20 + 
           782740*x^21 - 642698*x^22 - 1525678*x^23 + 225792*x^24 + 
           1496943*x^25 + 247030*x^26 - 738450*x^27 - 254750*x^28 + 
           146250*x^29 + 67500*x^30)*HPL[{1, -1, 0}, x])/
         (18900*(-1 + x)^5*x^13*(1 + x)^7) + 
        ((6838 + 36002*x - 51262*x^2 + 865984*x^3 + 339497*x^4 + 893652*x^5 + 
           1439760*x^6 + 1725552*x^7 + 3320382*x^8 + 1484354*x^9 - 
           8622458*x^10 - 7524430*x^11 + 11946214*x^12 + 18142502*x^13 - 
           7742930*x^14 - 23720554*x^15 - 1562478*x^16 + 18427496*x^17 + 
           6921160*x^18 - 8168818*x^19 - 5401403*x^20 + 1597870*x^21 + 
           1945450*x^22 + 97250*x^23 - 281250*x^24 - 67500*x^25)*
          HPL[{1, 0, 0}, x])/(9450*(-1 + x)^8*(1 + x)^12) - 
        ((67500 + 146250*x - 254750*x^2 - 738450*x^3 + 247030*x^4 + 
           1496943*x^5 + 225792*x^6 - 1525678*x^7 - 642698*x^8 + 782740*x^9 + 
           508242*x^10 - 157290*x^11 - 171598*x^12 - 9017*x^13 + 24682*x^14 + 
           10404*x^15 + 24682*x^16 - 9017*x^17 - 171598*x^18 - 157290*x^19 + 
           508242*x^20 + 782740*x^21 - 642698*x^22 - 1525678*x^23 + 
           225792*x^24 + 1496943*x^25 + 247030*x^26 - 738450*x^27 - 
           254750*x^28 + 146250*x^29 + 67500*x^30)*HPL[{1, 1, 0}, x])/
         (18900*(-1 + x)^5*x^13*(1 + x)^7) - 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) - (2*(1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{2, -1, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) + 
        (4*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{2, 0, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) + (2*(1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{2, 1, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) - 
        (4*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-1, 1, 0, 0}, x])/
         (45*(-1 + x)^8*(1 + x)^10) - (4*(1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{1, -1, 0, 0}, x])/(45*(-1 + x)^8*(1 + x)^10) + 
        ((1 + 11*x - 79*x^2 + 983*x^3 - 1519*x^4 + 4040*x^5 - 2444*x^6 + 
           2792*x^7 - 464*x^8 + 289*x^9 + 25*x^10 + 5*x^11)*master3l10a[x])/
         (180*(-1 + x)^9*(1 + x)^11) - (x*(5 + 25*x + 289*x^2 - 464*x^3 + 
           2792*x^4 - 2444*x^5 + 4040*x^6 - 1519*x^7 + 983*x^8 - 79*x^9 + 
           11*x^10 + x^11)*master3l10b[x])/(180*(-1 + x)^9*(1 + x)^11) + 
        ((36780231168 - 219984864687*x + 1577323152297*x^2 - 
           5156784534762*x^3 + 6203142941544*x^4 - 5606272174671*x^5 + 
           240649731351*x^6 + 1706932920168*x^7 - 973764252864*x^8 + 
           540328340034*x^9 + 98219048346*x^10 - 273934359132*x^11 + 
           45280970640*x^12 + 41091162378*x^13 - 13008879026*x^14 - 
           2236800216*x^15 + 1442524416*x^16 - 48383027*x^17 - 
           77601939*x^18 + 9956534*x^19 + 1794248*x^20 - 292635*x^21 - 
           6677*x^22)*master3l8a[x])/(453600*(-1 + x)^10*(1 + x)^12*
          (-9 + x^2)^6) - ((4060 - 176777*x + 150325*x^2 + 10004580*x^3 - 
           12840366*x^4 - 259152035*x^5 + 274778189*x^6 + 3964932000*x^7 - 
           2672435808*x^8 - 38371794922*x^9 + 12743040170*x^10 + 
           231109171192*x^11 - 40785838212*x^12 - 781009535382*x^13 + 
           292551429954*x^14 + 1040815666800*x^15 - 1816581627756*x^16 + 
           577131299235*x^17 + 3655791054657*x^18 - 717237731772*x^19 + 
           1711026799650*x^20 - 40656095991*x^21 + 48140635473*x^22 + 
           34101768528*x^23)*master3l8b[x])/(453600*(-1 + x)^10*x*(1 + x)^12*
          (1 - 9*x^2)^6) - ((3937888872 - 9546901623*x + 85807935225*x^2 - 
           192491752131*x^3 + 314306726679*x^4 - 129748034682*x^5 + 
           80355249108*x^6 - 20508043164*x^7 + 12653439564*x^8 + 
           43992426870*x^9 - 36526867106*x^10 - 12596407978*x^11 + 
           11296467090*x^12 + 1591188144*x^13 - 1599318876*x^14 - 
           95936652*x^15 + 122712148*x^16 + 1917881*x^17 - 5073871*x^18 + 
           52885*x^19 + 91727*x^20 - 2030*x^21)*master3l9a[x])/
         (151200*(-1 + x)^10*(1 + x)^12*(-9 + x^2)^5) - 
        ((-2030 + 91727*x + 52885*x^2 - 5073871*x^3 + 1917881*x^4 + 
           122712148*x^5 - 95936652*x^6 - 1599318876*x^7 + 1591188144*x^8 + 
           11296467090*x^9 - 12596407978*x^10 - 36526867106*x^11 + 
           43992426870*x^12 + 12653439564*x^13 - 20508043164*x^14 + 
           80355249108*x^15 - 129748034682*x^16 + 314306726679*x^17 - 
           192491752131*x^18 + 85807935225*x^19 - 9546901623*x^20 + 
           3937888872*x^21)*master3l9b[x])/(453600*(-1 + x)^10*x*(1 + x)^12*
          (-1 + 9*x^2)^5) + (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*
            (67500 + 146250*x - 254750*x^2 - 738450*x^3 + 247030*x^4 + 
             1496943*x^5 + 225792*x^6 - 1525678*x^7 - 642698*x^8 + 
             782740*x^9 + 508242*x^10 - 157290*x^11 - 171598*x^12 - 
             9017*x^13 + 24682*x^14 + 10404*x^15 + 24682*x^16 - 9017*x^17 - 
             171598*x^18 - 157290*x^19 + 508242*x^20 + 782740*x^21 - 
             642698*x^22 - 1525678*x^23 + 225792*x^24 + 1496943*x^25 + 
             247030*x^26 - 738450*x^27 - 254750*x^28 + 146250*x^29 + 
             67500*x^30) - 10080*x^13*(1 + 6*x - 103*x^2 + 700*x^3 - 
             1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + 
             x^10)*Zeta[3]))/(226800*(-1 + x)^8*x^13*(1 + x)^10) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(67500 + 146250*x - 254750*x^2 - 
              738450*x^3 + 247030*x^4 + 1496943*x^5 + 225792*x^6 - 
              1525678*x^7 - 642698*x^8 + 782740*x^9 + 508242*x^10 - 
              157290*x^11 - 171598*x^12 - 9017*x^13 + 24682*x^14 + 
              10404*x^15 + 24682*x^16 - 9017*x^17 - 171598*x^18 - 
              157290*x^19 + 508242*x^20 + 782740*x^21 - 642698*x^22 - 
              1525678*x^23 + 225792*x^24 + 1496943*x^25 + 247030*x^26 - 
              738450*x^27 - 254750*x^28 + 146250*x^29 + 67500*x^30)) + 
           10080*x^13*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 
             1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*Zeta[3]))/
         (226800*(-1 + x)^8*x^13*(1 + x)^10) + 
        (HPL[{0}, x]*(180796228200000 + 391725161100000*x - 
           11289050411940000*x^2 - 24959120187708000*x^3 + 
           307505559446089200*x^4 + 698142596437820520*x^5 - 
           4793446759872710520*x^6 - 11279480612267669760*x^7 + 
           47189492097400361520*x^8 + 116723625557193334260*x^9 - 
           3061800*(99938490896131 + 147987*Pi^2)*x^10 + 
           17496*(-46490162340436882 + 1095741675*Pi^2)*x^11 + 
           35280*(-1103636209822708135 + 64717083552992562*Pi^2)*x^28 + 
           27*(30127107064501975761 + 214879623248705657480*Pi^2)*x^45 + 
           210*(1457099411915174805 + 8216941807160399236*Pi^2)*x^46 - 
           945*(123517829924853993 + 1675534473654211952*Pi^2)*x^47 - 
           45360*(1040332718196657 + 12023242135193024*Pi^2)*x^48 + 
           816480*(13814766573912 + 380110107982073*Pi^2)*x^49 + 
           204120*(23483474230221 + 577406338278728*Pi^2)*x^50 - 
           1837080*(380028412719 + 23236382935052*Pi^2)*x^51 - 
           1224720*(251082336735 + 14155225566454*Pi^2)*x^52 + 
           11022480*(2264383350 + 362280936637*Pi^2)*x^53 + 
           198404640*(56899125 + 8571528491*Pi^2)*x^54 - 
           297606960*(1316250 + 809943379*Pi^2)*x^55 - 
           5952139200*(30375 + 17854067*Pi^2)*x^56 + 8450281782936000*Pi^2*
            x^57 + 3823282213380000*Pi^2*x^58 - 130575053700000*Pi^2*x^59 - 
           60265409400000*Pi^2*x^60 + 24*x^33*(2967628209806162231269 + 
             1333510687083964100075*Pi^2 - 11016537549192504000*Zeta[3]) - 
           280*x^26*(-147046066749525853615 + 4960675747302334668*Pi^2 - 
             8626956911056310400*Zeta[3]) - 24*x^25*
            (-2041969763667158443868 + 6560566123387168515*Pi^2 - 
             4218583234193496000*Zeta[3]) + 280*x^24*(-75775987410053966033 + 
             2577475763217288324*Pi^2 - 3619319336312198400*Zeta[3]) - 
           72*x^35*(1068050889964115220433 + 664843373320902548605*Pi^2 - 
             1361151899028936000*Zeta[3]) + 108*x^21*(726388718302498485547 + 
             24639025261251870*Pi^2 - 907434599352624000*Zeta[3]) + 
           36*x^37*(1646619572706069347399 + 1512964466681535671370*Pi^2 - 
             446312381813424000*Zeta[3]) - 72*x^19*(824660045163430892062 + 
             14266876927577715*Pi^2 - 223156190906712000*Zeta[3]) - 
           560*x^22*(-19779106338141174103 + 303817754767697331*Pi^2 - 
             163394522804520000*Zeta[3]) + 840*x^36*(-2224193636641717501 + 
             16017527671322259448*Pi^2 - 30502666745913600*Zeta[3]) - 
           108*x^39*(305906511247585905413 + 437672000537937361350*Pi^2 - 
             13031554043088000*Zeta[3]) - 840*x^38*(-9085165317043054019 + 
             5833646439871289242*Pi^2 - 8821989569232000*Zeta[3]) + 
           216*x^17*(152763225871506665419 + 217132272420525*Pi^2 - 
             6515777021544000*Zeta[3]) - 22680*x^16*(-312724970691484349 + 
             3333667696380*Pi^2 - 34921862035200*Zeta[3]) + 
           3150*x^14*(-1214378431977274649 + 2113697035044*Pi^2 - 
             12770909867520*Zeta[3]) - 648*x^43*(6061470080147249003 + 
             24050548676247654820*Pi^2 - 1874923848000*Zeta[3]) - 
           34020*x^12*(-38983113312035747 + 4620562380*Pi^2 - 
             23808556800*Zeta[3]) + 10125*x^15*(-1324334412638496893 + 
             609276522456*Pi^2 + 6359741692416*Zeta[3]) - 
           81*x^13*(-48480832682694616699 + 8423654778000*Pi^2 + 
             14999390784000*Zeta[3]) + 840*x^42*(4555632518655800430 + 
             5771956754969149607*Pi^2 + 47890912003200*Zeta[3]) - 
           840*x^40*(8486502989474196423 + 2812191163615058372*Pi^2 + 
             942890274950400*Zeta[3]) - 1680*x^18*(4314867079741065157 + 
             271337634582525*Pi^2 + 4410994784616000*Zeta[3]) + 
           840*x^20*(250313134034771701 + 21566077024886100*Pi^2 + 
             30502666745913600*Zeta[3]) - 280*x^34*(43419718085997431231 + 
             63258831800434244394*Pi^2 + 326789045609040000*Zeta[3]) + 
           280*x^32*(182384956436148340313 + 55776131633386338300*Pi^2 + 
             3619319336312198400*Zeta[3]) - 168*x^27*(227554564408455003859 + 
             4795323835129114105*Pi^2 + 10730893459567176000*Zeta[3]) - 
           6*x^31*(9922113138663042083897 + 2730135066788283865340*Pi^2 + 
             16874332936773984000*Zeta[3]) - 140*x^30*
            (636391600454578829705 + 66888954267046923216*Pi^2 + 
             17253913822112620800*Zeta[3]) + 12*x^23*
            (-6206342449038172550213 + 2935591810567462410*Pi^2 + 
             22033075098385008000*Zeta[3]) + 42*x^29*
            (1637089432362168800461 + 155177023014329748540*Pi^2 + 
             42923573838268704000*Zeta[3]) - 420*x^44*
            (8746317158636390060*Pi^2 + 81*(38983276174468487 + 23808556800*
                Zeta[3])) + 60*x^41*(520440257439998484694*Pi^2 - 
             675*(-331318132364530655 + 1589935423104*Zeta[3]))))/
         (190512000*(-1 + x)^10*x^9*(1 + x)^12*(9 - 82*x^2 + 9*x^4)^6) + 
        (-235200*Pi^4*x^11*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^6*
           (1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
            700*x^7 - 103*x^8 + 6*x^9 + x^10) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^6*
           (-56700000 - 122850000*x + 469140000*x^2 + 1173123000*x^3 - 
            1614610200*x^4 - 5011098120*x^5 + 2784188120*x^6 + 
            12587302560*x^7 - 1734664820*x^8 - 20535202380*x^9 - 
            2512480880*x^10 + 22634652881*x^11 + 6992943370*x^12 - 
            16891861917*x^13 - 8529881780*x^14 + 9331125251*x^15 + 
            1259170150*x^16 - 1068599315*x^17 + 1068599315*x^19 - 
            1259170150*x^20 - 9331125251*x^21 + 8529881780*x^22 + 
            16891861917*x^23 - 6992943370*x^24 - 22634652881*x^25 + 
            2512480880*x^26 + 20535202380*x^27 + 1734664820*x^28 - 
            12587302560*x^29 - 2784188120*x^30 + 5011098120*x^31 + 
            1614610200*x^32 - 1173123000*x^33 - 469140000*x^34 + 
            122850000*x^35 + 56700000*x^36) + x^2*(-180796228200000 - 
            391725161100000*x + 11349315821340000*x^2 + 25089695241408000*
             x^3 - 311245976721544200*x^4 - 706413337521919020*x^5 + 
            4894550037013539420*x^6 + 11509102124193000600*x^7 - 
            48749648604584660460*x^8 - 101403381395232000*x^57*Zeta[3] - 
            45879386560560000*x^58*Zeta[3] + 1566900644400000*x^59*Zeta[3] + 
            723184912800000*x^60*Zeta[3] + 17856417600*x^56*
             (-10125 + 71416268*Zeta[3]) + 688905*x^9*(-174768194526857 + 
              351133056*Zeta[3]) + 238140*x^12*(-5974236887006129 + 
              422703360*Zeta[3]) + 1785641760*x^55*(-219375 + 
              1619886758*Zeta[3]) + 153090*x^10*(2097765844308733 + 
              1696248864*Zeta[3]) - 595213920*x^54*(-19067625 + 
              34286113964*Zeta[3]) - 132269760*x^53*(-189685800 + 
              362280936637*Zeta[3]) - 2187*x^11*(-389093062329837797 + 
              6304507473600*Zeta[3]) + 1837080*x^52*(-169424291115 + 
              113241804531632*Zeta[3]) + 2755620*x^51*(-256353683571 + 
              185891063480416*Zeta[3]) - 630*x^14*(-6715010991721366021 + 
              700120671741792*Zeta[3]) + 81*x^13*(-51648761128483043659 + 
              4128233253399360*Zeta[3]) - 306180*x^50*(-15985858112919 + 
              4619250706229824*Zeta[3]) - 612360*x^49*(-18794666738835 + 
              6081761727713168*Zeta[3]) + 2916*x^17*(-12615115779698186063 + 
              10818431693202000*Zeta[3]) - 5184*x^19*(-13087710131850941623 + 
              14842390056764445*Zeta[3]) + 840*x^16*(-9692466508736178931 + 
              15419921253870816*Zeta[3]) - 2940*x^18*(-2751281877145393471 + 
              57085936834470048*Zeta[3]) + 68040*x^48*(-716485085336349 + 
              96185937081544192*Zeta[3]) - 27*x^15*(-540834794318266728799 + 
              162839736080138880*Zeta[3]) + 840*x^20*(6673282757953573819 + 
              1296865020099401424*Zeta[3]) - 1120*x^22*
             (29938607012283120287 + 2454440521985124432*Zeta[3]) + 
            8820*x^44*(-161291393527978323 + 4997895987148689920*Zeta[3]) + 
            2835*x^47*(-42468213508349121 + 6702137972799613376*Zeta[3]) + 
            2940*x^38*(2991907680526552171 + 19942242326987558496*Zeta[3]) - 
            280*x^24*(-101673976576067096845 + 20908106945562264192*Zeta[
                3]) - 7840*x^32*(-2276905104266647855 + 23707247919232799448*
               Zeta[3]) - 630*x^46*(-509751236254048389 + 
              32867767017933034912*Zeta[3]) - 12*x^21*
             (7957619370180444764287 + 55966028755786914240*Zeta[3]) + 
            420*x^40*(-19480552416363901907 + 67523313563151816000*Zeta[3]) - 
            630*x^42*(-6714808073473135351 + 92352056521242420704*Zeta[3]) - 
            210*x^25*(440811481561373176079 + 134326054630249033120*Zeta[
                3]) - 840*x^36*(-316243746620085859 + 190720875305559906912*
               Zeta[3]) + 28*x^23*(4078175546458676256791 + 
              254619869281735990080*Zeta[3]) + 140*x^26*
             (93466729386111932077 + 366080661051349815648*Zeta[3]) + 
            560*x^34*(-27968703319281797449 + 371726374850432220408*Zeta[
                3]) - 280*x^28*(-535695243998140148605 + 
              405042765031164041952*Zeta[3]) - 644*x^33*
             (-158414774483122326667 + 584783929024393482480*Zeta[3]) + 
            66*x^27*(-705126417889052953351 + 726994293471724121760*Zeta[
                3]) + 210*x^31*(-297802357085482704989 + 
              795507850397225268896*Zeta[3]) - 81*x^45*
             (-10505109150739648269 + 859518645460301160320*Zeta[3]) + 
            140*x^30*(-282541549538469672833 + 1060543888899314398848*Zeta[
                3]) + 324*x^39*(-114414329828958841817 + 
              1750776380783604594000*Zeta[3]) + 81*x^43*
             (-51652802274404311009 + 2308856321204929265280*Zeta[3]) - 
            216*x^37*(-321877370739774275177 + 3026270308125146902680*Zeta[
                3]) - 6*x^29*(-3001444748653842887089 + 
              6846739935965560891680*Zeta[3]) - 9*x^41*
             (-1624775709276345804447 + 41635653373459904951360*Zeta[3]) + 
            12*x^35*(-8180164529308457468137 + 47813436133508788580880*Zeta[
                3])))/(762048000*(-1 + x)^10*x^11*(1 + x)^12*
          (9 - 82*x^2 + 9*x^4)^6)))

CbarSeries["p", 2, -1, "x0"] = SeriesData[x, 0, 
     {(CF*NC*(30*(NH*(125 + 117*lm + 20*lm^2 + 4*lm^3 - 112*Zeta[3]) + 
           NM*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3]) + 
           NL*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3])) - 
         CA*(4560*lm^2 + 660*lm^3 + 88*Pi^4 + 480*Pi^2*Log[2]^2 - 
           45*lm*(-247 + 48*Zeta[3]) - 15*(-749 + 32*Log[2]^4 + 
             768*PolyLog[4, 1/2] + 392*Zeta[3])) + 
         CF*(-2430*lm^2 - 2160*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           45*lm*(-5 + 96*Zeta[3]) - 15*(-139 + 64*Log[2]^4 + 
             1536*PolyLog[4, 1/2] + 1008*Zeta[3]))))/1080, 
      -(CF*NC*(30*(NH*(93 + 45*lm + 20*lm^2 + 4*lm^3 - 112*Zeta[3]) + 
            NM*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3]) + 
            NL*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3])) - 
          CA*(4560*lm^2 + 660*lm^3 + 88*Pi^4 + 480*Pi^2*Log[2]^2 - 
            45*lm*(-247 + 48*Zeta[3]) - 15*(-749 + 32*Log[2]^4 + 
              768*PolyLog[4, 1/2] + 392*Zeta[3])) + 
          CF*(-2430*lm^2 - 2160*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
            45*lm*(-5 + 96*Zeta[3]) - 15*(-139 + 64*Log[2]^4 + 
              1536*PolyLog[4, 1/2] + 1008*Zeta[3]))))/1080, 
      (CF*NC*(30*(NH*(93 + 45*lm + 20*lm^2 + 4*lm^3 - 112*Zeta[3]) + 
           NL*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3]) + 
           NM*(5 + 117*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3])) - 
         CA*(4560*lm^2 + 660*lm^3 + 88*Pi^4 + 480*Pi^2*Log[2]^2 - 
           45*lm*(-247 + 48*Zeta[3]) - 15*(-749 + 32*Log[2]^4 + 
             768*PolyLog[4, 1/2] + 392*Zeta[3])) + 
         CF*(-2430*lm^2 - 2160*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           45*lm*(-5 + 96*Zeta[3]) - 15*(-139 + 64*Log[2]^4 + 
             1536*PolyLog[4, 1/2] + 1008*Zeta[3]))))/1080, 
      (CF*NC*(-36*(27*CF*(3 + 8*lm) + 2*CA*(76 + 33*lm) - 
           4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         144*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         8*(2*NH*(109 - 81*Zeta[3]) + 27*NM*(-5 + 6*Zeta[3])) + 
         3*Log[x]*(-2*(3*(117 + 40*lm + 12*lm^2)*NM + 
             3*(45 + 40*lm + 12*lm^2)*NL + (-89 + 120*lm + 36*lm^2)*NH) + 
           3*CA*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]) + 
           9*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3]))))/324, 
      -(CF*NC*(-36*(27*CF*(3 + 8*lm) + 2*CA*(76 + 33*lm) - 
            2*(13*NM + 6*lm*NM + 10*NL + 6*lm*NL + 6*lm*NH))*Log[x]^2 + 
          144*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          16*NH*(-109 + 81*Zeta[3]) - 3*NM*(-511 + 432*Zeta[3]) + 
          3*Log[x]*(-2*(3*(143 + 40*lm + 12*lm^2)*NM + 3*(45 + 40*lm + 
                12*lm^2)*NL + (-89 + 120*lm + 36*lm^2)*NH) + 
            3*CA*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]) + 
            9*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3]))))/324, 
      (CF*NC*(-900*(135*CF*(3 + 8*lm) + 10*CA*(76 + 33*lm) - 
           2*(5*(13 + 6*lm)*NM + 10*(5 + 3*lm)*NL + 6*(2 + 5*lm)*NH))*
          Log[x]^2 + 18000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         375*NM*(-511 + 432*Zeta[3]) + 8*NH*(-24679 + 20250*Zeta[3]) + 
         15*Log[x]*(-2*(75*(143 + 40*lm + 12*lm^2)*NM + 
             75*(45 + 40*lm + 12*lm^2)*NL + (-1097 + 3000*lm + 900*lm^2)*
              NH) + 75*CA*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]) + 
           225*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3]))))/40500, 
      -(CF*NC*(-900*(135*CF*(3 + 8*lm) + 10*CA*(76 + 33*lm) - 
            2*((69 + 30*lm)*NM + 10*(5 + 3*lm)*NL + 6*(2 + 5*lm)*NH))*
           Log[x]^2 + 18000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          NM*(193921 - 162000*Zeta[3]) + 8*NH*(-24679 + 20250*Zeta[3]) + 
          15*Log[x]*(-2*(3*(3647 + 1000*lm + 300*lm^2)*NM + 75*(45 + 40*lm + 
                12*lm^2)*NL + (-1097 + 3000*lm + 900*lm^2)*NH) + 
            75*CA*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]) + 
            225*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3]))))/40500, 
      -(CF*NC*(945*CF*(3 + 8*lm) + 70*CA*(76 + 33*lm) - 
           2*(21*(23 + 10*lm)*NM + 70*(5 + 3*lm)*NL + 3*(37 + 70*lm)*NH))*
          Log[x]^2)/315 + (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + CF*(NM*NC*(193921/40500 - 4*Zeta[3]) + 
         NC*NH*(-67060079/13891500 + 4*Zeta[3])) + 
       (CF*NC*Log[x]*(-2*(147*(3647 + 1000*lm + 300*lm^2)*NM + 
            3675*(45 + 40*lm + 12*lm^2)*NL + (-44087 + 147000*lm + 
              44100*lm^2)*NH) + 3675*CA*(741 + 608*lm + 132*lm^2 - 
            144*Zeta[3]) + 11025*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3])))/
        132300, (CF*NC*(945*CF*(3 + 8*lm) + 70*CA*(76 + 33*lm) - 993*NM - 
          420*lm*NM - 700*NL - 420*lm*NL - 222*NH - 420*lm*NH)*Log[x]^2)/
        315 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NC*NH*(67060079/13891500 - 4*Zeta[3]) + 
         NM*NC*(-533443007/111132000 + 4*Zeta[3])) - 
       (CF*NC*Log[x]*(-1079049*NM - 294000*lm*NM - 88200*lm^2*NM - 
          330750*NL - 294000*lm*NL - 88200*lm^2*NL + 88174*NH - 
          294000*lm*NH - 88200*lm^2*NH + 3675*CA*(741 + 608*lm + 132*lm^2 - 
            144*Zeta[3]) + 11025*CF*(-5 + 108*lm + 144*lm^2 + 96*Zeta[3])))/
        132300, -(CF*NC*(2835*CF*(3 + 8*lm) + 210*CA*(76 + 33*lm) - 
           2979*NM - 1260*lm*NM - 2100*NL - 1260*lm*NL - 746*NH - 
           1260*lm*NH)*Log[x]^2)/945 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(533443007/111132000 - 4*Zeta[3]) + 
         NC*NH*(-1806421133/375070500 + 4*Zeta[3])) + 
       (CF*NC*Log[x]*(-9711441*NM - 2646000*lm*NM - 793800*lm^2*NM - 
          2976750*NL - 2646000*lm*NL - 793800*lm^2*NL + 733966*NH - 
          2646000*lm*NH - 793800*lm^2*NH + 33075*CA*(741 + 608*lm + 
            132*lm^2 - 144*Zeta[3]) + 99225*CF*(-5 + 108*lm + 144*lm^2 + 
            96*Zeta[3])))/1190700, 
      (CF*NC*(2835*CF*(3 + 8*lm) + 210*CA*(76 + 33*lm) - 3027*NM - 
          1260*lm*NM - 2100*NL - 1260*lm*NL - 746*NH - 1260*lm*NH)*
         Log[x]^2)/945 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + CF*(NC*NH*(1806421133/375070500 - 4*Zeta[3]) + 
         NM*NC*(-4805028727/1000188000 + 4*Zeta[3])) - 
       (CF*NC*Log[x]*(-9739137*NM - 2646000*lm*NM - 793800*lm^2*NM - 
          2976750*NL - 2646000*lm*NL - 793800*lm^2*NL + 733966*NH - 
          2646000*lm*NH - 793800*lm^2*NH + 33075*CA*(741 + 608*lm + 
            132*lm^2 - 144*Zeta[3]) + 99225*CF*(-5 + 108*lm + 144*lm^2 + 
            96*Zeta[3])))/1190700, 
      -(CF*NC*(31185*CF*(3 + 8*lm) + 2310*CA*(76 + 33*lm) - 33297*NM - 
           13860*lm*NM - 23100*NL - 13860*lm*NL - 8731*NH - 13860*lm*NH)*
          Log[x]^2)/10395 + (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*
         Log[x]^3)/9 + CF*(NM*NC*(4805028727/1000188000 - 4*Zeta[3]) + 
         NC*NH*(-19219084990559/3993750684000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-3246379/396900 - (20*lm)/9 - (2*lm^2)/3)*NM*NC - 
           (5*NC*NL)/2 - (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (85506061*NC*NH)/144074700 - (20*lm*NC*NH)/9 - 
           (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      (CF*NC*(31185*CF*(3 + 8*lm) + 2310*CA*(76 + 33*lm) - 33647*NM - 
          13860*lm*NM - 23100*NL - 13860*lm*NL - 8731*NH - 13860*lm*NH)*
         Log[x]^2)/10395 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + Log[x]*(CF*((1180233877/144074700 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (85506061*NC*NH)/144074700 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(19219084990559/3993750684000 - 4*Zeta[3]) + 
         NM*NC*(-19193460099911/3993750684000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (33647*NM*NC)/10395 + (4*lm*NM*NC)/3 + (20*NC*NL)/9 + 
           (4*lm*NC*NL)/3 + (118039*NC*NH)/135135 + (4*lm*NC*NH)/3))*
        Log[x]^2 + (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(19193460099911/3993750684000 - 4*Zeta[3]) + 
         NC*NH*(-42209227573587467/8774270252748000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-1180233877/144074700 - (20*lm)/9 - (2*lm^2)/3)*NM*NC - 
           (5*NC*NL)/2 - (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (14148943813*NC*NH)/24348624300 - (20*lm*NC*NH)/9 - 
           (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      (CF*NC*(405405*CF*(3 + 8*lm) + 30030*CA*(76 + 33*lm) - 440651*NM - 
          180180*lm*NM - 300300*NL - 180180*lm*NL - 118039*NH - 
          180180*lm*NH)*Log[x]^2)/135135 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((199641580813/24348624300 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (14148943813*NC*NH)/24348624300 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(42209227573587467/8774270252748000 - 4*Zeta[3]) + 
         NM*NC*(-6025106074165781/1253467178964000 + 4*Zeta[3])), 
      -(CF*NC*(405405*CF*(3 + 8*lm) + 30030*CA*(76 + 33*lm) - 440651*NM - 
           180180*lm*NM - 300300*NL - 180180*lm*NL - 121273*NH - 
           180180*lm*NH)*Log[x]^2)/135135 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(6025106074165781/1253467178964000 - 4*Zeta[3]) + 
         NC*NH*(-42201587873667923/8774270252748000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-199641580813/24348624300 - (20*lm)/9 - (2*lm^2)/3)*NM*NC - 
           (5*NC*NL)/2 - (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (13967729857*NC*NH)/24348624300 - (20*lm*NC*NH)/9 - 
           (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      (CF*NC*(810810*CF*(3 + 8*lm) + 60060*CA*(76 + 33*lm) - 886153*NM - 
          360360*lm*NM - 600600*NL - 360360*lm*NL - 242546*NH - 
          360360*lm*NH)*Log[x]^2)/270270 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((159807425471/19478899440 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (13967729857*NC*NH)/24348624300 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(42201587873667923/8774270252748000 - 4*Zeta[3]) + 
         NM*NC*(-9641152416943673/2005547486342400 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (886153*NM*NC)/270270 + (4*lm*NM*NC)/3 + (20*NC*NL)/9 + 
           (4*lm*NC*NL)/3 + (420565*NC*NH)/459459 + (4*lm*NC*NH)/3))*
        Log[x]^2 + (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(9641152416943673/2005547486342400 - 4*Zeta[3]) + 
         NC*NH*(-29616486431553649669/6158284250250132000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-159807425471/19478899440 - (20*lm)/9 - (2*lm^2)/3)*NM*NC - 
           (5*NC*NL)/2 - (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (4002760325521*NC*NH)/7036752422700 - (20*lm*NC*NH)/9 - 
           (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      (3*CF^2*(3 + 8*lm)*NC + (2*CA*CF*(76 + 33*lm)*NC)/9 - 
         (CF*NC*((3025733 + 1225224*lm)*NM + 2*(204204*(5 + 3*lm)*NL + 
              (420565 + 612612*lm)*NH)))/918918)*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((77004926542153/9382336563600 + (20*lm)/9 + (2*lm^2)/3)*
            NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (4002760325521*NC*NH)/7036752422700 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(29616486431553649669/6158284250250132000 - 4*Zeta[3]) + 
         NM*NC*(-236849429542791214477/49266274002001056000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (3025733*NM*NC)/918918 + (4*lm*NM*NC)/3 + (20*NC*NL)/9 + 
           (4*lm*NC*NL)/3 + (16224713*NC*NH)/17459442 + (4*lm*NC*NH)/3))*
        Log[x]^2 + (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(236849429542791214477/49266274002001056000 - 4*Zeta[3]) + 
         NC*NH*(-1625016656261802799233743/337917373379725243104000 + 
           4*Zeta[3])) + Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 
            144*Zeta[3]))/36 + CF*((-77004926542153/9382336563600 - 
             (20*lm)/9 - (2*lm^2)/3)*NM*NC - (5*NC*NL)/2 - 
           (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + (5746463941547299*NC*NH)/
            10161070498378800 - (20*lm*NC*NH)/9 - (2*lm^2*NC*NH)/3 + 
           CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (288417607*NM*NC)/87297210 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (16224713*NC*NH)/17459442 - (4*lm*NC*NH)/3))*
        Log[x]^2 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((5561354784128141/677404699891920 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (5746463941547299*NC*NH)/10161070498378800 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(1625016656261802799233743/337917373379725243104000 - 
           4*Zeta[3]) + NM*NC*(-1624613731082485277637007/
            337917373379725243104000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (288417607*NM*NC)/87297210 + (4*lm*NM*NC)/3 + (20*NC*NL)/9 + 
           (4*lm*NC*NL)/3 + (2345599*NC*NH)/2494206 + (4*lm*NC*NH)/3))*
        Log[x]^2 + (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(1624613731082485277637007/337917373379725243104000 - 
           4*Zeta[3]) + NC*NH*(-11374673440564897144780201/
            2365421613658076701728000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-5561354784128141/677404699891920 - (20*lm)/9 - (2*lm^2)/3)*NM*
            NC - (5*NC*NL)/2 - (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (272500612484119*NC*NH)/483860499922800 - (20*lm*NC*NH)/9 - 
           (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (289213207*NM*NC)/87297210 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (2345599*NC*NH)/2494206 - (4*lm*NC*NH)/3))*
        Log[x]^2 - (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((5562536486262221/677404699891920 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (272500612484119*NC*NH)/483860499922800 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(11374673440564897144780201/2365421613658076701728000 - 
           4*Zeta[3]) + NM*NC*(-11372592822018734836515049/
            2365421613658076701728000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (289213207*NM*NC)/87297210 + (4*lm*NM*NC)/3 + (20*NC*NL)/9 + 
           (4*lm*NC*NL)/3 + (1906498039*NC*NH)/2007835830 + 
           (4*lm*NC*NH)/3))*Log[x]^2 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(11372592822018734836515049/2365421613658076701728000 - 
           4*Zeta[3]) + NC*NH*(-138392049583313812614866057183/
            28780084773377819229924576000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-5562536486262221/677404699891920 - (20*lm)/9 - (2*lm^2)/3)*NM*
            NC - (5*NC*NL)/2 - (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (201189512429774669*NC*NH)/358347086242825680 - 
           (20*lm*NC*NH)/9 - (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 
             12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (6667146131*NM*NC)/2007835830 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (1906498039*NC*NH)/2007835830 - 
           (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((2943056829358432769/358347086242825680 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (201189512429774669*NC*NH)/
            358347086242825680 + (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(138392049583313812614866057183/
            28780084773377819229924576000 - 4*Zeta[3]) + 
         NM*NC*(-138372838677408433354052498183/
            28780084773377819229924576000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (6667146131*NM*NC)/2007835830 + (4*lm*NM*NC)/3 + (20*NC*NL)/9 + 
           (4*lm*NC*NL)/3 + (9608676851*NC*NH)/10039179150 + 
           (4*lm*NC*NH)/3))*Log[x]^2 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(138372838677408433354052498183/
            28780084773377819229924576000 - 4*Zeta[3]) + 
         NC*NH*(-17298693987653518238116499010019/
            3597510596672227403740572000000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-2943056829358432769/358347086242825680 - (20*lm)/9 - 
             (2*lm^2)/3)*NM*NC - (5*NC*NL)/2 - (20*lm*NC*NL)/9 - 
           (2*lm^2*NC*NL)/3 + (25089359598783200473*NC*NH)/
            44793385780353210000 - (20*lm*NC*NH)/9 - (2*lm^2*NC*NH)/3 + 
           CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (33400196287*NM*NC)/10039179150 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (9608676851*NC*NH)/
            10039179150 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((367928282628777556669/44793385780353210000 + (20*lm)/9 + 
             (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + 
           (2*lm^2*NC*NL)/3 - (25089359598783200473*NC*NH)/
            44793385780353210000 + (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(17298693987653518238116499010019/
            3597510596672227403740572000000 - 4*Zeta[3]) + 
         NM*NC*(-17296828390993605618969623859307/
            3597510596672227403740572000000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (33400196287*NM*NC)/10039179150 + (4*lm*NM*NC)/3 + 
           (20*NC*NL)/9 + (4*lm*NC*NL)/3 + (29019377707*NC*NH)/
            30117537450 + (4*lm*NC*NH)/3))*Log[x]^2 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(17296828390993605618969623859307/
            3597510596672227403740572000000 - 4*Zeta[3]) + 
         NC*NH*(-467058709400221266644143254479177/
            97132786110150139900995444000000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-367928282628777556669/44793385780353210000 - (20*lm)/9 - 
             (2*lm^2)/3)*NM*NC - (5*NC*NL)/2 - (20*lm*NC*NL)/9 - 
           (2*lm^2*NC*NL)/3 + (676166678835784784959*NC*NH)/
            1209421416069536670000 - (20*lm*NC*NH)/9 - (2*lm^2*NC*NH)/3 + 
           CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (1593116111*NM*NC)/478056150 - (4*lm*NM*NC)/3 - (20*NC*NL)/9 - 
           (4*lm*NC*NL)/3 - (29019377707*NC*NH)/30117537450 - 
           (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((3311684143526228561653/403140472023178890000 + 
             (20*lm)/9 + (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + 
           (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - (676166678835784784959*NC*
             NH)/1209421416069536670000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(467058709400221266644143254479177/
            97132786110150139900995444000000 - 4*Zeta[3]) + 
         NM*NC*(-155672931939313225358967308493059/
            32377595370050046633665148000000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (1593116111*NM*NC)/478056150 + (4*lm*NM*NC)/3 + (20*NC*NL)/9 + 
           (4*lm*NC*NL)/3 + (846367030703*NC*NH)/873408586050 + 
           (4*lm*NC*NH)/3))*Log[x]^2 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(155672931939313225358967308493059/
            32377595370050046633665148000000 - 4*Zeta[3]) + 
         NC*NH*(-11390986948423782674115482030140647853/
            2368971520440451762045377883716000000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-3311684143526228561653/403140472023178890000 - (20*lm)/9 - 
             (2*lm^2)/3)*NM*NC - (5*NC*NL)/2 - (20*lm*NC*NL)/9 - 
           (2*lm^2*NC*NL)/3 + (567825020559178820590519*NC*NH)/
            1017123410914480339470000 - (20*lm*NC*NH)/9 - 
           (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (416398219291*NM*NC)/124772655150 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (846367030703*NC*NH)/
            873408586050 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((8356049689812139939032919/1017123410914480339470000 + 
             (20*lm)/9 + (2*lm^2)/3)*NM*NC + (5*NC*NL)/2 + 
           (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - (567825020559178820590519*
             NC*NH)/1017123410914480339470000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(11390986948423782674115482030140647853/
            2368971520440451762045377883716000000 - 4*Zeta[3]) + 
         NM*NC*(-11390202472319336737927923941234271853/
            2368971520440451762045377883716000000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (416398219291*NM*NC)/124772655150 + (4*lm*NM*NC)/3 + 
           (20*NC*NL)/9 + (4*lm*NC*NL)/3 + (3766636158899*NC*NH)/
            3867952309650 + (4*lm*NC*NH)/3))*Log[x]^2 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(11390202472319336737927923941234271853/
            2368971520440451762045377883716000000 - 4*Zeta[3]) + 
         NC*NH*(-339346479274581452622693643644685253188723/
            70574030565441498443093852533783356000000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-8356049689812139939032919/1017123410914480339470000 - 
             (20*lm)/9 - (2*lm^2)/3)*NM*NC - (5*NC*NL)/2 - 
           (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (545035667419860666229318759*NC*NH)/977455597888815606230670000 - 
           (20*lm*NC*NH)/9 - (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 
             12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (25848958386167*NM*NC)/7735904619300 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (3766636158899*NC*NH)/
            3867952309650 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((32122764011820975684556895011/
              3909822391555262424922680000 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (545035667419860666229318759*NC*NH)/977455597888815606230670000 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(339346479274581452622693643644685253188723/
            70574030565441498443093852533783356000000 - 4*Zeta[3]) + 
         NM*NC*(-2714618954592808975065563696627843933103659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (25848958386167*NM*NC)/7735904619300 + (4*lm*NM*NC)/3 + 
           (20*NC*NL)/9 + (4*lm*NC*NL)/3 + (3782768380979*NC*NH)/
            3867952309650 + (4*lm*NC*NH)/3))*Log[x]^2 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(2714618954592808975065563696627843933103659/
            564592244523531987544750820270266848000000 - 4*Zeta[3]) + 
         NC*NH*(-339344633046661304827223791270314000772723/
            70574030565441498443093852533783356000000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-32122764011820975684556895011/3909822391555262424922680000 - 
             (20*lm)/9 - (2*lm^2)/3)*NM*NC - (5*NC*NL)/2 - 
           (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (544508593881525258015205159*NC*NH)/977455597888815606230670000 - 
           (20*lm*NC*NH)/9 - (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 
             12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (25877427013367*NM*NC)/7735904619300 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (3782768380979*NC*NH)/
            3867952309650 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((32124511421186097581557055011/
              3909822391555262424922680000 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (544508593881525258015205159*NC*NH)/977455597888815606230670000 + 
           (20*lm*NC*NH)/9 + (2*lm^2*NC*NH)/3 + 
           CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(339344633046661304827223791270314000772723/
            70574030565441498443093852533783356000000 - 4*Zeta[3]) + 
         NM*NC*(-2714630454053256954084736071362261789103659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (25877427013367*NM*NC)/7735904619300 + (4*lm*NM*NC)/3 + 
           (20*NC*NL)/9 + (4*lm*NC*NL)/3 + (53158015482991*NC*NH)/
            54151332335100 + (4*lm*NC*NH)/3))*Log[x]^2 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(2714630454053256954084736071362261789103659/
            564592244523531987544750820270266848000000 - 4*Zeta[3]) + 
         NC*NH*(-2714745571326530773683860265467556461487659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-32124511421186097581557055011/3909822391555262424922680000 - 
             (20*lm)/9 - (2*lm^2)/3)*NM*NC - (5*NC*NL)/2 - 
           (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (2176287453678091031829805411*NC*NH)/
            3909822391555262424922680000 - (20*lm*NC*NH)/9 - 
           (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (181319107448489*NM*NC)/54151332335100 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (53158015482991*NC*NH)/
            54151332335100 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((32125975433246366478853386211/
              3909822391555262424922680000 + (20*lm)/9 + (2*lm^2)/3)*NM*NC + 
           (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (2176287453678091031829805411*NC*NH)/
            3909822391555262424922680000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(2714745571326530773683860265467556461487659/
            564592244523531987544750820270266848000000 - 4*Zeta[3]) + 
         NM*NC*(-2714639535284307262095271366458053094255659/
            564592244523531987544750820270266848000000 + 4*Zeta[3])), 
      ((-2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(-3*CF*(3 + 8*lm)*NC + 
           (181319107448489*NM*NC)/54151332335100 + (4*lm*NM*NC)/3 + 
           (20*NC*NL)/9 + (4*lm*NC*NL)/3 + (1973399339136427*NC*NH)/
            2003599296398700 + (4*lm*NC*NH)/3))*Log[x]^2 + 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       CF*(NM*NC*(2714639535284307262095271366458053094255659/
            564592244523531987544750820270266848000000 - 4*Zeta[3]) + 
         NC*NH*(-137509547647797015009072206967782649990582647327/
            28598290961850465765104263299149826651744000000 + 4*Zeta[3])) + 
       Log[x]*((CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36 + 
         CF*((-32125975433246366478853386211/3909822391555262424922680000 - 
             (20*lm)/9 - (2*lm^2)/3)*NM*NC - (5*NC*NL)/2 - 
           (20*lm*NC*NL)/9 - (2*lm^2*NC*NL)/3 + 
           (2977333760126732452408127620459*NC*NH)/
            5352546854039154259719148920000 - (20*lm*NC*NH)/9 - 
           (2*lm^2*NC*NH)/3 + CF*NC*(-5/12 + 9*lm + 12*lm^2 + 8*Zeta[3]))), 
      ((2*CA*CF*(76 + 33*lm)*NC)/9 + CF*(3*CF*(3 + 8*lm)*NC - 
           (6714669976989773*NM*NC)/2003599296398700 - (4*lm*NM*NC)/3 - 
           (20*NC*NL)/9 - (4*lm*NC*NL)/3 - (1973399339136427*NC*NH)/
            2003599296398700 - (4*lm*NC*NH)/3))*Log[x]^2 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       Log[x]*(CF*((43982156226223991347508902420459/
              5352546854039154259719148920000 + (20*lm)/9 + (2*lm^2)/3)*NM*
            NC + (5*NC*NL)/2 + (20*lm*NC*NL)/9 + (2*lm^2*NC*NL)/3 - 
           (2977333760126732452408127620459*NC*NH)/
            5352546854039154259719148920000 + (20*lm*NC*NH)/9 + 
           (2*lm^2*NC*NH)/3 + CF*NC*(5/12 - 9*lm - 12*lm^2 - 8*Zeta[3])) - 
         (CA*CF*NC*(741 + 608*lm + 132*lm^2 - 144*Zeta[3]))/36) + 
       CF*(NC*NH*(137509547647797015009072206967782649990582647327/
            28598290961850465765104263299149826651744000000 - 4*Zeta[3]) + 
         NM*NC*(-137505004467196798936188319364970676501038647327/
            28598290961850465765104263299149826651744000000 + 4*Zeta[3]))}, 
     0, 39, 1]
 
CbarSeries["p", 2, -1, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(30*(NM*(125 + 117*lm + 20*lm^2 + 4*lm^3 - 112*Zeta[3]) + 
           NH*(125 + 117*lm + 20*lm^2 + 4*lm^3 - 112*Zeta[3]) + 
           NL*(45 + 45*lm + 20*lm^2 + 4*lm^3 + 32*Zeta[3])) - 
         CA*(4560*lm^2 + 660*lm^3 + 88*Pi^4 + 480*Pi^2*Log[2]^2 - 
           45*lm*(-247 + 48*Zeta[3]) - 15*(-749 + 32*Log[2]^4 + 
             768*PolyLog[4, 1/2] + 392*Zeta[3])) + 
         CF*(-2430*lm^2 - 2160*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           45*lm*(-5 + 96*Zeta[3]) - 15*(-139 + 64*Log[2]^4 + 
             1536*PolyLog[4, 1/2] + 1008*Zeta[3]))))/1080, 
      (CF*NC*(30*(-24*NH + 5*lm*(NL + NH) + 8*lm^2*(NL + NH) + 
           4*lm^3*(NL + NH) + NM*(40 + 149*lm + 8*lm^2 + 4*lm^3 - 
             238*Zeta[3]) + 32*NL*Zeta[3] + 14*NH*Zeta[3]) - 
         CA*(2580*lm^2 + 660*lm^3 + lm*(1995 - 2160*Zeta[3]) + 
           8*(11*Pi^4 + 60*Pi^2*Log[2]^2 - 15*(-1 + 4*Log[2]^4 + 96*
                PolyLog[4, 1/2] + 31*Zeta[3]))) + 
         CF*(4050*lm^2 - 2160*lm^3 - 45*lm*(-113 + 96*Zeta[3]) + 
           4*(44*Pi^4 + 240*Pi^2*Log[2]^2 - 15*(-31 + 16*Log[2]^4 + 384*
                PolyLog[4, 1/2] + 180*Zeta[3])))))/1080, 
      -(CF*NC*(CA*(600*lm^2 + 660*lm^3 + 88*Pi^4 + 480*Pi^2*Log[2]^2 - 
            15*(125 + 32*Log[2]^4 + 768*PolyLog[4, 1/2] + 104*Zeta[3]) - 
            15*lm*(211 + 144*Zeta[3])) + CF*(-10530*lm^2 + 2160*lm^3 - 
            176*Pi^4 - 960*Pi^2*Log[2]^2 + 45*lm*(67 + 96*Zeta[3]) + 
            15*(215 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 432*Zeta[3])) - 
          30*(NH*(7 - 11*lm - 4*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
            NL*(-5 - 11*lm - 4*lm^2 + 4*lm^3 + 32*Zeta[3]) + 
            NM*(61*lm - 4*lm^2 + 4*lm^3 - 7*(15 + 16*Zeta[3])))))/1080, 
      (CF*NC*(3*CF*(155 - 2052*lm + 720*lm^2 + 480*Zeta[3]) + 
         CA*(664*lm + 660*lm^2 - 9*(79 + 80*Zeta[3])) - 
         2*((-39 - 16*lm + 60*lm^2)*NL + NH*(33 - 16*lm + 60*lm^2 - 
             126*Zeta[3]) + NM*(177 - 16*lm + 60*lm^2 + 126*Zeta[3]))))/432, 
      -(CF*NC*(CA*(293 + 872*lm + 132*lm^2 - 144*Zeta[3]) + 
          3*CF*(-1049 + 396*lm + 144*lm^2 + 96*Zeta[3]) - 
          2*((-11 + 64*lm + 12*lm^2)*NL + NH*(7 + 64*lm + 12*lm^2 - 
              63*Zeta[3]) + NM*(7 + 64*lm + 12*lm^2 + 63*Zeta[3]))))/432, 
      (CF*NC*(-160*NM - 320*lm*NM - 24*lm^2*NM - 250*NL - 320*lm*NL - 
         24*lm^2*NL - 268*NH - 320*lm*NH - 24*lm^2*NH + 
         CA*(2461 + 1928*lm + 132*lm^2 - 144*Zeta[3]) - 315*NM*Zeta[3] + 
         315*NH*Zeta[3] + 3*CF*(-905 + 1548*lm + 144*lm^2 + 96*Zeta[3])))/
       2160, -(CF*NC*(1836*CF*(3 + 8*lm) + 136*CA*(76 + 33*lm) - 694*NM - 
          816*lm*NM - 1360*NL - 816*lm*NL - 1234*NH - 816*lm*NH - 
          945*NM*Zeta[3] + 945*NH*Zeta[3]))/12960, 
      -(CF*NC*(5302*NM + 4272*lm*NM - 432*lm^2*NM + 12604*NL + 
          4272*lm*NL - 432*lm^2*NL + 10690*NH + 4272*lm*NH - 
          432*lm^2*NH + CA*(-84886 - 20472*lm + 2376*lm^2 - 2592*Zeta[3]) + 
          6615*NM*Zeta[3] - 6615*NH*Zeta[3] + 54*CF*(-2287 - 1796*lm + 
            144*lm^2 + 96*Zeta[3])))/181440, 
      (CF*NC*(4798*NM + 2400*lm*NM - 864*lm^2*NM + 14968*NL + 
         2400*lm*NL - 864*lm^2*NL + 12298*NH + 2400*lm*NH - 
         864*lm^2*NH + CA*(-91948 - 7152*lm + 4752*lm^2 - 5184*Zeta[3]) + 
         6615*NM*Zeta[3] - 6615*NH*Zeta[3] + 108*CF*(-1903 - 772*lm + 
           144*lm^2 + 96*Zeta[3])))/362880, 
      -(CF*NC*(9666*NM - 192*lm*NM - 4032*lm^2*NM + 50288*NL - 
          192*lm*NL - 4032*lm^2*NL + 41230*NH - 192*lm*NH - 
          4032*lm^2*NH + 19845*NM*Zeta[3] - 19845*NH*Zeta[3] + 
          72*CF*(-12109 - 2556*lm + 1008*lm^2 + 672*Zeta[3]) + 
          8*CA*(3660*lm + 2772*lm^2 - 7*(5029 + 432*Zeta[3]))))/2177280, 
      (CF*NC*(3066*NM - 51072*lm*NM - 28800*lm^2*NM + 268960*NL - 
         51072*lm*NL - 28800*lm^2*NL + 228326*NH - 51072*lm*NH - 
         28800*lm^2*NH + 16*CA*(-83833 + 30156*lm + 9900*lm^2 - 
           10800*Zeta[3]) + 99225*NM*Zeta[3] - 99225*NH*Zeta[3] + 
         144*CF*(-39991 - 2916*lm + 3600*lm^2 + 2400*Zeta[3])))/21772800, 
      -(CF*NC*(-4083882*NM - 6662400*lm*NM - 2188800*lm^2*NM + 
          15016960*NL - 6662400*lm*NL - 2188800*lm^2*NL + 13955882*NH - 
          6662400*lm*NH - 2188800*lm^2*NH + 640*CA*(-97462 + 81195*lm + 
            18810*lm^2 - 20520*Zeta[3]) + 5457375*NM*Zeta[3] - 
          5457375*NH*Zeta[3] + 11520*CF*(-35129 + 1575*lm + 3420*lm^2 + 
            2280*Zeta[3])))/2395008000, 
      (CF*NC*(-11085610*NM - 12203520*lm*NM - 2995200*lm^2*NM + 
         14031360*NL - 12203520*lm*NL - 2995200*lm^2*NL + 15713066*NH - 
         12203520*lm*NH - 2995200*lm^2*NH + 3840*CA*(-10079 + 22939*lm + 
           4290*lm^2 - 4680*Zeta[3]) + 5457375*NM*Zeta[3] - 
         5457375*NH*Zeta[3] + 23040*CF*(-22058 + 3489*lm + 2340*lm^2 + 
           1560*Zeta[3])))/4790016000, 
      -(CF*NC*(-292439074*NM - 264837120*lm*NM - 53452800*lm^2*NM + 
          142502400*NL - 264837120*lm*NL - 53452800*lm^2*NL + 
          235064354*NH - 264837120*lm*NH - 53452800*lm^2*NH + 
          3840*CA*(17563 + 476764*lm + 76560*lm^2 - 83520*Zeta[3]) + 
          70945875*NM*Zeta[3] - 70945875*NH*Zeta[3] + 
          23040*CF*(-356831 + 99024*lm + 41760*lm^2 + 27840*Zeta[3])))/
       124540416000, (CF*NC*(-3739703278*NM - 2973834240*lm*NM - 
         519321600*lm^2*NM + 386081280*NL - 2973834240*lm*NL - 
         519321600*lm^2*NL + 1951294958*NH - 2973834240*lm*NH - 
         519321600*lm^2*NH + 3840*CA*(1965955 + 5206078*lm + 743820*lm^2 - 
           811440*Zeta[3]) + 496621125*NM*Zeta[3] - 496621125*NH*Zeta[3] + 
         23040*CF*(-3091253 + 1275198*lm + 405720*lm^2 + 270480*Zeta[3])))/
       1743565824000, -(CF*NC*(-45590829954*NM - 32857144320*lm*NM - 
          5125478400*lm^2*NM - 5665454592*NL - 32857144320*lm*NL - 
          5125478400*lm^2*NL + 16811969410*NH - 32857144320*lm*NH - 
          5125478400*lm^2*NH + 5376*CA*(25836851 + 40288810*lm + 
            5243700*lm^2 - 5720400*Zeta[3]) + 3476347875*NM*Zeta[3] - 
          3476347875*NH*Zeta[3] + 32256*CF*(-19032089 + 10946610*lm + 
            2860200*lm^2 + 1906800*Zeta[3])))/24409921536000, 
      (CF*NC*(-77619539970*NM - 51662714880*lm*NM - 7360819200*lm^2*NM - 
         21227566080*NL - 51662714880*lm*NL - 7360819200*lm^2*NL + 
         21585804034*NH - 51662714880*lm*NH - 7360819200*lm^2*NH + 
         53760*CA*(5341207 + 6243874*lm + 753060*lm^2 - 821520*Zeta[3]) + 
         3476347875*NM*Zeta[3] - 3476347875*NH*Zeta[3] + 
         322560*CF*(-2325317 + 1821834*lm + 410760*lm^2 + 273840*Zeta[3])))/
       48819843072000, -(CF*NC*(-2224720299042*NM - 1385093713920*lm*NM - 
          183252787200*lm^2*NM - 840705804288*NL - 1385093713920*lm*NL - 
          183252787200*lm^2*NL + 492493860386*NH - 1385093713920*lm*NH - 
          183252787200*lm^2*NH + 21504*CA*(428390151 + 413912990*lm + 
            46869900*lm^2 - 51130800*Zeta[3]) + 59097913875*NM*Zeta[3] - 
          59097913875*NH*Zeta[3] + 129024*CF*(-118991269 + 127188990*lm + 
            25565400*lm^2 + 17043600*Zeta[3])))/1659874664448000, 
      (CF*NC*(-11223317775462*NM - 6597968240640*lm*NM - 
         820979712000*lm^2*NM - 5099242631168*NL - 6597968240640*lm*NL - 
         820979712000*lm^2*NL + 2070130993254*NH - 6597968240640*lm*NH - 
         820979712000*lm^2*NH + 14336*CA*(3486025999 + 2932176570*lm + 
           314968500*lm^2 - 343602000*Zeta[3]) + 177293741625*NM*Zeta[3] - 
         177293741625*NH*Zeta[3] + 774144*CF*(-69650749 + 104099330*lm + 
           19089000*lm^2 + 12726000*Zeta[3])))/9959247986688000, 
      -(CF*NC*(-359114033292178*NM - 200811780341760*lm*NM - 
          23735255040000*lm^2*NM - 183970114936832*NL - 
          200811780341760*lm*NL - 23735255040000*lm^2*NL + 
          57307870380946*NH - 200811780341760*lm*NH - 23735255040000*lm^2*
           NH + 28672*CA*(58630438013 + 44315414940*lm + 4553010000*lm^2 - 
            4966920000*Zeta[3]) + 3368581090875*NM*Zeta[3] - 
          3368581090875*NH*Zeta[3] + 1548288*CF*(-732999163 + 
            1621741360*lm + 275940000*lm^2 + 183960000*Zeta[3])))/
       378451423494144000, (CF*NC*(-607030076588946*NM - 
         324787050577920*lm*NM - 36753879859200*lm^2*NM - 
         338395399602176*NL - 324787050577920*lm*NL - 36753879859200*lm^2*
          NL + 86357413757842*NH - 324787050577920*lm*NH - 
         36753879859200*lm^2*NH + 57344*CA*(51371745577 + 35637659340*lm + 
           3525152400*lm^2 - 3845620800*Zeta[3]) + 3368581090875*NM*
          Zeta[3] - 3368581090875*NH*Zeta[3] + 3096576*CF*
          (-360273447 + 1336027760*lm + 213645600*lm^2 + 142430400*Zeta[3])))/
       756902846988288000, -(CF*NC*(-3093509685349046*NM - 
          1591405178388480*lm*NM - 173494960128000*lm^2*NM - 
          1836094878744576*NL - 1591405178388480*lm*NL - 
          173494960128000*lm^2*NL + 401437864168118*NH - 
          1591405178388480*lm*NH - 173494960128000*lm^2*NH + 
          49152*CA*(313774727999 + 202783064820*lm + 19413702000*lm^2 - 
            21178584000*Zeta[3]) + 10105743272625*NM*Zeta[3] - 
          10105743272625*NH*Zeta[3] + 884736*CF*(-2626712747 + 
            23258664240*lm + 3529764000*lm^2 + 2353176000*Zeta[3])))/
       4541417081929728000, (CF*NC*(-58122744632669650*NM - 
         28865182724259840*lm*NM - 3046644331315200*lm^2*NM - 
         36207487958384640*NL - 28865182724259840*lm*NL - 
         3046644331315200*lm^2*NL + 6998804846835154*NH - 
         28865182724259840*lm*NH - 3046644331315200*lm^2*NH + 
         3932160*CA*(75239370686 + 45797987697*lm + 4261409460*lm^2 - 
           4648810320*Zeta[3]) + 111163175998875*NM*Zeta[3] - 
         111163175998875*NH*Zeta[3] + 17694720*CF*(518887867 + 
           21356897856*lm + 3099206880*lm^2 + 2066137920*Zeta[3])))/
       99911175802454016000, -(CF*NC*(-25259275358391660682*NM - 
          12151418177499955200*lm*NM - 1246568519643955200*lm^2*NM - 
          16352688101135941632*NL - 12151418177499955200*lm*NL - 
          1246568519643955200*lm^2*NL + 2857981114988327050*NH - 
          12151418177499955200*lm*NH - 1246568519643955200*lm^2*NH + 
          7569408*CA*(17267370989647 + 9982125367500*lm + 905767909200*lm^2 - 
            988110446400*Zeta[3]) + 28124283527715375*NM*Zeta[3] - 
          28124283527715375*NH*Zeta[3] + 136249344*CF*(172584266279 + 
            1179896257200*lm + 164685074400*lm^2 + 109790049600*Zeta[3])))/
       50555054956041732096000, (CF*NC*(-43631373952978284682*NM - 
         20390885592544051200*lm*NM - 2039514359345971200*lm^2*NM - 
         29147765338620690432*NL - 20390885592544051200*lm*NL - 
         2039514359345971200*lm^2*NL + 4681378757066125450*NH - 
         20390885592544051200*lm*NH - 2039514359345971200*lm^2*NH + 
         2162688*CA*(105790339118377 + 58458025972500*lm + 
           5186753233200*lm^2 - 5658276254400*Zeta[3]) + 
         28124283527715375*NM*Zeta[3] - 28124283527715375*NH*Zeta[3] + 
         116785152*CF*(596755083963 + 2330763100400*lm + 314348680800*lm^2 + 
           209565787200*Zeta[3])))/101110109912083464192000, 
      -(CF*NC*(-75773471332692816010*NM - 34486933518522777600*lm*NM - 
          3371663370045358080*lm^2*NM - 51961809884002123776*NL - 
          34486933518522777600*lm*NL - 3371663370045358080*lm^2*NL + 
          7761530779486548106*NH - 34486933518522777600*lm*NH - 
          3371663370045358080*lm^2*NH + 4325376*CA*(92874630683963 + 
            49308956710860*lm + 4287291679440*lm^2 - 4677045468480*Zeta[3]) + 
          28124283527715375*NM*Zeta[3] - 28124283527715375*NH*Zeta[3] + 
          233570304*CF*(706856628917 + 1986478797520*lm + 259835859360*lm^2 + 
            173223906240*Zeta[3])))/202220219824166928384000, 
      (CF*NC*(-1719522767628245907202*NM - 763771786155125637120*lm*NM - 
         73138902045976166400*lm^2*NM - 1205604604342376595456*NL - 
         763771786155125637120*lm*NL - 73138902045976166400*lm^2*NL + 
         168994043815188215554*NH - 763771786155125637120*lm*NH - 
         73138902045976166400*lm^2*NH + 8650752*CA*(1063539115542889 + 
           544775429716980*lm + 46500461607600*lm^2 - 50727776299200*
            Zeta[3]) + 365615685860299875*NM*Zeta[3] - 365615685860299875*
          NH*Zeta[3] + 467140608*CF*(9908935291571 + 22149504942320*lm + 
           2818209794400*lm^2 + 1878806529600*Zeta[3])))/
       5257725715428340137984000, 
      -(CF*NC*(-117632278903984411173198*NM - 51085106758299817082880*lm*
           NM - 4799723000322085355520*lm^2*NM - 84063402811580890480640*
           NL - 51085106758299817082880*lm*NL - 4799723000322085355520*lm^2*
           NL + 11134926298784979018062*NH - 51085106758299817082880*lm*
           NH - 4799723000322085355520*lm^2*NH + 2998927360*CA*
           (211524623768798 + 104892886826343*lm + 8802639521676*lm^2 - 
            9602879478192*Zeta[3]) + 14259011748551695125*NM*Zeta[3] - 
          14259011748551695125*NH*Zeta[3] + 13495173120*CF*
           (27447585763613 + 51599545699968*lm + 6401919652128*lm^2 + 
            4267946434752*Zeta[3])))/410102605803410530762752000, 
      (CF*NC*(-207282578720858650763598*NM - 88152349161165108019200*lm*
          NM - 8137961549800396554240*lm^2*NM - 150611386526579227099136*
          NL - 88152349161165108019200*lm*NL - 8137961549800396554240*lm^2*
          NL + 18955224815456978526542*NH - 88152349161165108019200*lm*
          NH - 8137961549800396554240*lm^2*NH + 599785472*CA*
          (1876282640433889 + 903329067688740*lm + 74624662672560*lm^2 - 
           81408722915520*Zeta[3]) + 14259011748551695125*NM*Zeta[3] - 
         14259011748551695125*NH*Zeta[3] + 10796138496*CF*
          (68335194966613 + 111922153766640*lm + 13568120485920*lm^2 + 
           9045413657280*Zeta[3])))/820205211606821061525504000}, 0, 29, 1]
 
CbarSeries["p", 2, 0, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 391*Pi^4 + 
            20*Pi^2*(-73 + 96*Log[2]^2) + 15*(869 + 936*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 144*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              128*Log[2]^4 - 156*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
              2712*Zeta[3]) - 10*lm*(-1233 + 44*Pi^2 + 648*Zeta[3])) + 
          2*(CF*(5670*lm^2 - 3240*lm^3 + 981*Pi^4 + 10*Pi^2*(259 + 
                576*Log[2]^2) + 15*(1025 + 2808*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 432*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                384*Log[2]^4 - 468*PolyGamma[2, 1] - 9216*PolyLog[4, 1/2] - 
                10464*Zeta[3]) + 135*lm*(95 + 8*Pi^2 - 144*Zeta[3])) - 
            15*(NL*(-219 - 162*lm - 84*lm^2 - 24*lm^3 + 28*Pi^2 + 
                8*lm*Pi^2 - 288*Zeta[3]) + NM*(-219 - 84*lm^2 - 24*lm^3 + 
                28*Pi^2 + 2*lm*(-81 + 4*Pi^2) + 8*PolyGamma[2, 1] - 
                272*Zeta[3]) - NH*(-837 + 162*lm + 84*lm^2 + 24*lm^3 - 
                8*lm*Pi^2 - 1296*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                216*PolyGamma[2, 1] + 2928*Zeta[3])))))/25920, 
      (CF*NC*(2*(CF*(3240*lm^2 + 1530*Pi^2 + 7*Pi^4 + 180*lm*(27 + 4*Pi^2) + 
             15*(281 + 1440*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 720*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 240*PolyGamma[2, 1] - 3048*
                Zeta[3])) - 10*(NH*(1905 + 180*lm + 36*lm^2 + 8*lm*Pi^2 - 
               1728*Zeta[3]) + NL*(273 + 180*lm + 36*lm^2 + 16*Pi^2 + 8*lm*
                Pi^2 - 96*Zeta[3]) + NM*(273 + 36*lm^2 + 16*Pi^2 + 4*lm*
                (45 + 2*Pi^2) + 8*PolyGamma[2, 1] - 80*Zeta[3]))) - 
         5*CA*(-792*lm^2 - 614*Pi^2 + 27*Pi^4 - 8*lm*(621 + 22*Pi^2) + 
           12*(-693 + 360*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             180*Im[PolyLog[2, (-1)^(1/3)]]^2 - 60*PolyGamma[2, 1] - 
             586*Zeta[3]))))/8640, 
      (CF*NC*(2*(CF*(-6480*lm^2 - 1970*Pi^2 + 13*Pi^4 - 
             360*lm*(21 + 2*Pi^2) - 360*(32 + 132*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 54*Im[PolyLog[2, (-1)^(1/3)]]^2 - 26*
                PolyGamma[2, 1] - 297*Zeta[3])) + 
           20*(NH*(36*lm^2 + 4*lm*(42 + Pi^2) + 3*(537 + 216*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] - 48*PolyGamma[2, 1] - 
                 896*Zeta[3])) + NL*(231 + 36*lm^2 + 10*Pi^2 + 4*lm*
                (42 + Pi^2) - 48*Zeta[3]) + NM*(771 + 36*lm^2 - 26*Pi^2 + 4*
                lm*(42 + Pi^2) + 16*PolyGamma[2, 1] - 16*Zeta[3]))) + 
         5*CA*(-1584*lm^2 - 630*Pi^2 + 23*Pi^4 - 16*lm*(588 + 11*Pi^2) + 
           6*(-2445 + 1584*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             648*Im[PolyLog[2, (-1)^(1/3)]]^2 - 312*PolyGamma[2, 1] - 
             2972*Zeta[3]))))/8640, 
      (CF*NC*(-2880*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
           4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         11520*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         3*CA*(-11880*lm^2 - 4090*Pi^2 + 1050*Sqrt[3]*Pi^3 + 203*Pi^4 - 
           40*lm*(1731 + 22*Pi^2) + 810*Sqrt[3]*Pi*Log[3]^2 + 
           120*(-920 + 522*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             306*Im[PolyLog[2, (-1)^(1/3)]]^2 + 324*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] - 90*PolyGamma[2, 1] - 
             1235*Zeta[3])) - 120*Log[x]*(-3*CA*(608*lm + 132*lm^2 + 
             3*(241 - 9*Pi^2 + 36*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 96*
                Zeta[3])) + 2*(135*NL + 120*lm*NL + 36*lm^2*NL - 889*NH + 
             120*lm*NH + 36*lm^2*NH - 12*NL*Pi^2 + 
             3*NM*(189 + 40*lm + 12*lm^2 - 4*Pi^2) + 432*Sqrt[3]*NH*
              Im[PolyLog[2, (-1)^(1/3)]] - 3*CF*(60 - 18*lm + 108*lm^2 + 29*
                Pi^2 - 108*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 288*
                Zeta[3]))) + 5*(9*CF*(1735 + 1296*lm^2 + 224*Pi^2 + 
             140*Sqrt[3]*Pi^3 + 10*Pi^4 + 24*lm*(57 + 4*Pi^2) + 
             8352*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             4896*Im[PolyLog[2, (-1)^(1/3)]]^2 + 5184*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 108*Sqrt[3]*Pi*
              Log[3]^2 - 1440*PolyGamma[2, 1] - 23184*Zeta[3]) - 
           4*(NH*(31177 + 1476*lm + 324*lm^2 + 24*lm*Pi^2 - 420*Sqrt[3]*
                Pi^3 + 1728*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 15552*
                Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 324*Sqrt[3]*
                Pi*Log[3]^2 - 504*PolyGamma[2, 1] - 17136*Zeta[3]) + 
             3*NL*(723 + 492*lm + 108*lm^2 + 8*lm*Pi^2 - 384*Zeta[3]) + 
             3*NM*(1443 + 108*lm^2 + lm*(492 + 8*Pi^2) + 32*PolyGamma[2, 
                 1] + 1408*Zeta[3])))))/25920, 
      -(CF*NC*(299475*CF + 174960*CF*lm + 155520*CF*lm^2 - 54600*NM - 
          79920*lm*NM - 17280*lm^2*NM - 115560*NL - 79920*lm*NL - 
          17280*lm^2*NL - 1746600*NH - 79920*lm*NH - 17280*lm^2*NH + 
          8040*CF*Pi^2 + 8640*CF*lm*Pi^2 + 1920*NM*Pi^2 - 960*lm*NM*Pi^2 + 
          1920*NL*Pi^2 - 960*lm*NL*Pi^2 - 960*lm*NH*Pi^2 + 
          20300*Sqrt[3]*CF*Pi^3 + 25200*Sqrt[3]*NH*Pi^3 + 1956*CF*Pi^4 + 
          1207440*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          311040*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          648000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 751680*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 933120*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 15660*Sqrt[3]*CF*Pi*
           Log[3]^2 + 19440*Sqrt[3]*NH*Pi*Log[3]^2 - 
          8640*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
            4*(3*(2 + lm)*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          34560*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          224640*CF*PolyGamma[2, 1] + 13440*NM*PolyGamma[2, 1] + 
          86400*NH*PolyGamma[2, 1] - 2*CA*(-47520*lm^2 - 15375*Pi^2 + 
            5075*Sqrt[3]*Pi^3 + 873*Pi^4 - 60*lm*(4671 + 44*Pi^2) + 
            3915*Sqrt[3]*Pi*Log[3]^2 + 90*(-4883 + 3354*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 1800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              2088*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              624*PolyGamma[2, 1] - 8340*Zeta[3])) - 3435840*CF*Zeta[3] - 
          324480*NM*Zeta[3] + 63360*NL*Zeta[3] + 1336320*NH*Zeta[3] - 
          360*Log[x]*(CA*(-2205 - 1824*lm - 396*lm^2 + 47*Pi^2 - 
              348*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 864*Zeta[3]) + 
            2*(135*NL + 120*lm*NL + 36*lm^2*NL - 889*NH + 120*lm*NH + 
              36*lm^2*NH - 12*NL*Pi^2 + NM*(803 + 120*lm + 36*lm^2 - 
                36*Pi^2) + 432*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
              3*CF*(25 - 18*lm + 108*lm^2 + 15*Pi^2 - 116*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3])))))/51840, 
      (CF*NC*(-86400*(540*CF*(-1 + 7*lm) + 35*CA*(155 + 66*lm) - 
           2*(10*(65 + 21*lm)*NM + 5*(67 + 42*lm)*NL + 6*(4 + 35*lm)*NH))*
          Log[x]^2 + 1728000*(83*CA + 282*CF - 20*NM - 14*NL)*Log[x]^3 - 
         75*CA*(-237600*lm^2 - 75600*Pi^2 + 51100*Sqrt[3]*Pi^3 + 5844*Pi^4 - 
           960*lm*(1470 + 11*Pi^2) + 39420*Sqrt[3]*Pi*Log[3]^2 + 
           45*(-59099 + 32400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             21312*Im[PolyLog[2, (-1)^(1/3)]]^2 + 42048*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 4800*PolyGamma[2, 1] - 
             92704*Zeta[3])) - 360*Log[x]*
          (-8*(-75*NL*(93 + 120*lm + 36*lm^2 - 16*Pi^2) - 
             75*NM*(831 + 120*lm + 36*lm^2 - 16*Pi^2) - 
             NH*(-89219 + 9000*lm + 2700*lm^2 + 45600*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) - 450*CF*(459 - 72*lm + 
             432*lm^2 + 54*Pi^2 - 584*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             1152*Zeta[3]) + 225*CA*(-2593 - 2432*lm - 528*lm^2 + 62*Pi^2 - 
             584*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1152*Zeta[3])) + 
         2*(75*CF*(194400*lm^2 - 3864*Pi^2 + 51100*Sqrt[3]*Pi^3 + 4308*Pi^4 + 
             2160*lm*(105 + 4*Pi^2) + 39420*Sqrt[3]*Pi*Log[3]^2 + 
             135*(-327 + 10800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 7104*
                Im[PolyLog[2, (-1)^(1/3)]]^2 + 14016*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1600*PolyGamma[2, 
                 1] - 34976*Zeta[3])) - 8*(NH*(32731059 + 202500*lm^2 - 
               665000*Sqrt[3]*Pi^3 + 9000*lm*(105 + Pi^2) + 2592000*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 24624000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 513000*Sqrt[3]*Pi*
                Log[3]^2 - 756000*PolyGamma[2, 1] - 12312000*Zeta[3]) + 
             1125*NL*(1653 + 180*lm^2 - 56*Pi^2 + 8*lm*(105 + Pi^2) - 1248*
                Zeta[3]) + 1125*NM*(123 + 180*lm^2 - 128*Pi^2 + 8*lm*
                (105 + Pi^2) - 88*PolyGamma[2, 1] + 7216*Zeta[3])))))/
       7776000, -(CF*NC*(-172800*(15*CA*(753 + 319*lm) + 
            5*CF*(-217 + 1566*lm) - 2858*NM - 870*lm*NM - 1365*NL - 
            870*lm*NL - 108*NH - 870*lm*NH)*Log[x]^2 + 
          1728000*(319*CA + 1270*CF - 80*NM - 58*NL)*Log[x]^3 - 
          25*CA*(-2566080*lm^2 - 1202040*Pi^2 + 647500*Sqrt[3]*Pi^3 + 
            73764*Pi^4 - 1440*lm*(10661 + 66*Pi^2) + 499500*Sqrt[3]*Pi*
             Log[3]^2 + 45*(-504781 + 409936*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 254016*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              532800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              67392*PolyGamma[2, 1] - 1288608*Zeta[3])) - 
          360*Log[x]*(75*CA*(-36671 - 29360*lm - 6336*lm^2 + 1006*Pi^2 - 
              7400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 13824*Zeta[3]) + 
            2*(-8*(-2*NM*(69338 + 9075*lm + 2700*lm^2 - 2325*Pi^2) - 
                75*NL*(169 + 242*lm + 72*lm^2 - 34*Pi^2) - 2*NH*
                 (-92062 + 9075*lm + 2700*lm^2 + 47100*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) - 75*CF*(-199 - 720*lm + 
                5184*lm^2 + 814*Pi^2 - 7400*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 13824*Zeta[3]))) + 
          2*(25*CF*(2099520*lm^2 - 573912*Pi^2 + 647500*Sqrt[3]*Pi^3 + 
              59940*Pi^4 + 25920*lm*(98 + 3*Pi^2) + 499500*Sqrt[3]*Pi*Log[3]^
                2 + 15*(449321 + 1229808*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                762048*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1598400*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 202176*PolyGamma[2, 
                  1] - 4304736*Zeta[3])) - 16*(NH*(364500*lm^2 - 
                1373750*Sqrt[3]*Pi^3 + 2250*lm*(763 + 6*Pi^2) - 
                1059750*Sqrt[3]*Pi*Log[3]^2 + 9*(7115421 + 997000*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]] - 5652000*Sqrt[3]*
                   Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 294000*PolyGamma[
                    2, 1] - 3312000*Zeta[3])) + 2250*NL*(1619 + 162*lm^2 - 
                67*Pi^2 + lm*(763 + 6*Pi^2) - 1296*Zeta[3]) + 
              3*NM*(-1099987 + 121500*lm^2 - 111750*Pi^2 + 750*lm*
                 (763 + 6*Pi^2) - 270000*PolyGamma[2, 1] + 5724000*
                 Zeta[3])))))/23328000, 
      (CF*NC*(-25401600*(105*CA*(1282 + 539*lm) + 35*CF*(-401 + 2646*lm) - 
           41860*NM - 10290*lm*NM - 15645*NL - 10290*lm*NL - 1926*NH - 
           10290*lm*NH)*Log[x]^2 + 1778112000*(565*CA + 2382*CF - 268*NM - 
           98*NL)*Log[x]^3 - 25725*CA*(-2993760*lm^2 - 1703376*Pi^2 + 
           1124900*Sqrt[3]*Pi^3 + 106596*Pi^4 - 2880*lm*(6251 + 33*Pi^2) + 
           867780*Sqrt[3]*Pi*Log[3]^2 + 15*(-1899881 + 1409712*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 1010880*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 2776896*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
             181440*PolyGamma[2, 1] - 5119776*Zeta[3])) - 
         7560*Log[x]*(3675*CA*(-52005 - 44128*lm - 9504*lm^2 + 1626*Pi^2 - 
             12856*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 20736*Zeta[3]) + 
           2*(8*(3675*NL*(143 + 364*lm + 108*lm^2 - 62*Pi^2) + 2450*NM*
                (3616 + 546*lm + 162*lm^2 + 93*Pi^2) + 2*NH*(-8359013 + 
                 668850*lm + 198450*lm^2 + 4375700*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) - 1225*CF*(9017 - 3024*lm + 23328*lm^2 + 
               3918*Pi^2 - 38568*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 62208*
                Zeta[3]))) + 2*(25725*CF*(2449440*lm^2 - 1099152*Pi^2 + 
             1124900*Sqrt[3]*Pi^3 + 92772*Pi^4 + 6480*lm*(469 + 12*Pi^2) + 
             867780*Sqrt[3]*Pi*Log[3]^2 + 15*(455843 + 1409712*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 1010880*Im[PolyLog[2, 
                   (-1)^(1/3)]]^2 + 2776896*Sqrt[3]*Im[PolyLog[3, 
                  -((-1)^(5/6)/Sqrt[3])]] - 181440*PolyGamma[2, 1] - 5665824*
                Zeta[3])) - 8*(NH*(875164500*lm^2 - 5360232500*Sqrt[3]*
                Pi^3 + 9261000*lm*(448 + 3*Pi^2) - 4135036500*Sqrt[3]*Pi*
                Log[3]^2 + 27*(7998655981 + 773808000*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] - 7351176000*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 215061000*
                  PolyGamma[2, 1] - 2117682000*Zeta[3])) + 
             1157625*NL*(10393 + 756*lm^2 - 440*Pi^2 + 8*lm*(448 + 3*Pi^2) - 
               9216*Zeta[3]) + 385875*NM*(5425 + 2268*lm^2 - 5664*Pi^2 + 24*
                lm*(448 + 3*Pi^2) - 4608*PolyGamma[2, 1] + 148032*
                Zeta[3])))))/24004512000, (-3113675*CF^2*NC)/62208 - 
       (2191*CF^2*lm*NC)/288 - 6*CF^2*lm^2*NC - (74597729*CF*NM*NC)/
        83349000 + (8239*CF*lm*NM*NC)/2592 + (2*CF*lm^2*NM*NC)/3 + 
       (53483*CF*NC*NL)/5184 + (8239*CF*lm*NC*NL)/2592 + 
       (2*CF*lm^2*NC*NL)/3 + (2667462601*CF*NC*NH)/14817600 + 
       (8239*CF*lm*NC*NH)/2592 + (2*CF*lm^2*NC*NH)/3 + 
       (196307*CF^2*NC*Pi^2)/51840 - (CF^2*lm*NC*Pi^2)/6 - 
       (166*CF*NM*NC*Pi^2)/81 + (CF*lm*NM*NC*Pi^2)/54 - 
       (295*CF*NC*NL*Pi^2)/648 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (1318625*CF^2*NC*Pi^3)/(139968*Sqrt[3]) - 
       (81515*CF*NC*NH*Pi^3)/(5832*Sqrt[3]) - (1163*CF^2*NC*Pi^4)/4320 - 
       (459233*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(2592*Sqrt[3]) + 
       (217*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(3*Sqrt[3]) - 
       (81*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (37675*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(108*Sqrt[3]) - 
       (4658*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9*Sqrt[3]) - 
       (37675*CF^2*NC*Pi*Log[3]^2)/(5184*Sqrt[3]) - 
       (2329*CF*NC*NH*Pi*Log[3]^2)/(216*Sqrt[3]) + 
       (CF*NC*(70*CA*(20923 + 8448*lm) + 35*CF*(-6959 + 27648*lm) - 
          4*((113123 + 26880*lm)*NM + 30*(1337*NL + 896*lm*NL + 180*NH + 
              896*lm*NH)))*Log[x]^2)/7560 - 
       (CF*NC*(1277*CA + 8*(870*CF - 91*NM - 32*NL))*Log[x]^3)/27 + 
       (26*CF^2*NC*PolyGamma[2, 1])/3 - (77*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (187*CF*NC*NH*PolyGamma[2, 1])/27 + (18941*CF^2*NC*Zeta[3])/72 + 
       (1289*CF*NM*NC*Zeta[3])/27 - (85*CF*NC*NL*Zeta[3])/9 - 
       (500*CF*NC*NH*Zeta[3])/9 + (CA*CF*NC*(-30792960*lm^2 - 
          20973411*Pi^2 + 13186250*Sqrt[3]*Pi^3 + 1254852*Pi^4 - 
          1620*lm*(114821 + 528*Pi^2) + 10172250*Sqrt[3]*Pi*Log[3]^2 + 
          540*(459233*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            314928*Im[PolyLog[2, (-1)^(1/3)]]^2 + 904200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
            9*(34643 + 7488*PolyGamma[2, 1] + 207804*Zeta[3]))))/8398080 + 
       (CF*NC*Log[x]*(1225*CA*(-1488627 - 998424*lm - 213840*lm^2 + 
            66186*Pi^2 - 301400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            466560*Zeta[3]) + 2*(24*(NM*(22618762 + 3369975*lm + 
                992250*lm^2 + 477750*Pi^2) + 5*(735*NL*(260 + 917*lm + 
                  270*lm^2 - 166*Pi^2) + NH*(-8705689 + 673995*lm + 
                  198450*lm^2 + 4564840*Sqrt[3]*Im[PolyLog[2, (-1)^
                      (1/3)]]))) - 1225*CF*(-250395 - 18144*lm + 
              174960*lm^2 + 56106*Pi^2 - 301400*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 466560*Zeta[3]))))/19051200, 
      -(CF*NC*(7144200*(270*CF*(-827 + 3008*lm) + 5*CA*(248209 + 99264*lm) - 
            16*((20099 + 5640*lm)*NM + 60*(137 + 94*lm)*NL + 
              (1369 + 5640*lm)*NH))*Log[x]^2 - 571536000*
           (3873*CA + 22322*CF - 4048*NM - 752*NL)*Log[x]^3 + 
          3675*CA*(-34642080*lm^2 - 27500229*Pi^2 + 19540850*Sqrt[3]*Pi^3 + 
            1655316*Pi^4 - 3240*lm*(64813 + 264*Pi^2) + 15074370*Sqrt[3]*Pi*
             Log[3]^2 + 180*(-895587 + 1526783*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 1178064*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              4019832*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              174960*PolyGamma[2, 1] - 7208460*Zeta[3])) + 
          1890*Log[x]*(525*CA*(-3975459 - 2667744*lm - 570240*lm^2 + 
              194724*Pi^2 - 893296*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1244160*Zeta[3]) + 2*(8*(18900*NL*(2 + 613*lm + 180*lm^2 - 
                  128*Pi^2) + 63*NM*(633821 + 183900*lm + 54000*lm^2 + 
                  186000*Pi^2) + NH*(-175716477 + 11585700*lm + 3402000*
                   lm^2 + 93363200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
              525*CF*(-664047 - 44064*lm + 466560*lm^2 + 165924*Pi^2 - 
                893296*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1244160*
                 Zeta[3]))) - 2*(2625*CF*(39680928*lm^2 - 31989735*Pi^2 + 
              27357190*Sqrt[3]*Pi^3 + 2143260*Pi^4 + 40824*lm*(1253 + 
                24*Pi^2) + 21104118*Sqrt[3]*Pi*Log[3]^2 + 252*(1545108 + 
                1526783*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1178064*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 + 4019832*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 174960*PolyGamma[2, 
                  1] - 7851276*Zeta[3])) - 2*(NH*(5786802000*lm^2 - 
                57184960000*Sqrt[3]*Pi^3 + 5953500*lm*(4655 + 24*Pi^2) - 
                44114112000*Sqrt[3]*Pi*Log[3]^2 + 9*(226308972161 + 
                  25216576000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                  235275264000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[
                        3])]] - 6604416000*PolyGamma[2, 1] - 42293664000*
                   Zeta[3])) + 5953500*NL*(19790 + 4655*lm + 972*lm^2 - 
                812*Pi^2 + 24*lm*Pi^2 - 18720*Zeta[3]) + 3969*NM*(23677871 + 
                1458000*lm^2 - 3876000*Pi^2 + 1500*lm*(4655 + 24*Pi^2) - 
                6300000*PolyGamma[2, 1] + 108792000*Zeta[3])))))/30862944000, 
      (-9925907989*CF^2*NC)/87480000 - (35303*CF^2*lm*NC)/3600 - 
       (15*CF^2*lm^2*NC)/2 + (5902322093*CF*NM*NC)/400075200 + 
       (129803*CF*lm*NM*NC)/32400 + (5*CF*lm^2*NM*NC)/6 + 
       (1245421*CF*NC*NL)/64800 + (129803*CF*lm*NC*NL)/32400 + 
       (5*CF*lm^2*NC*NL)/6 + (128271233501*CF*NC*NH)/400075200 + 
       (129803*CF*lm*NC*NH)/32400 + (5*CF*lm^2*NC*NH)/6 + 
       (891487*CF^2*NC*Pi^2)/362880 - (CF^2*lm*NC*Pi^2)/6 - 
       (3563*CF*NM*NC*Pi^2)/1620 + (CF*lm*NM*NC*Pi^2)/54 - 
       (316*CF*NC*NL*Pi^2)/405 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (7266091*CF^2*NC*Pi^3)/(419904*Sqrt[3]) - 
       (122045*CF*NC*NH*Pi^3)/(4374*Sqrt[3]) - (1987*CF^2*NC*Pi^4)/4320 - 
       (426249803*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(1749600*Sqrt[3]) + 
       (32009*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(243*Sqrt[3]) - 
       (121*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (1038013*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1620*Sqrt[3]) - (27896*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27*Sqrt[3]) - 
       (1038013*CF^2*NC*Pi*Log[3]^2)/(77760*Sqrt[3]) - 
       (3487*CF*NC*NH*Pi*Log[3]^2)/(162*Sqrt[3]) + 
       (CF*NC*(21*CA*(2903787 + 1038400*lm) + 
          2*(7*CF*(-1579457 + 2548800*lm) - 40*((168821 + 49560*lm)*NM + 
              420*(169 + 118*lm)*NL + 3*(4247 + 16520*lm)*NH)))*Log[x]^2)/
        151200 - (CF*NC*(17293*CA + 161570*CF - 27440*NM - 4720*NL)*
         Log[x]^3)/270 + (65*CF^2*NC*PolyGamma[2, 1])/6 - 
       (158*CF*NM*NC*PolyGamma[2, 1])/27 - (322*CF*NC*NH*PolyGamma[2, 1])/
        27 + (CA*CF*NC*(-577368000*lm^2 - 215678295*Pi^2 + 
          363304550*Sqrt[3]*Pi^3 + 30836700*Pi^4 - 
          1944*lm*(1805833 + 6600*Pi^2) + 280263510*Sqrt[3]*Pi*Log[3]^2 + 
          12*(-40978227 + 426249803*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            317552400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1121054040*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 56862000*
             PolyGamma[2, 1] - 2308543740*Zeta[3])))/125971200 + 
       (512329*CF^2*NC*Zeta[3])/1080 + (1694*CF*NM*NC*Zeta[3])/27 - 
       (166*CF*NC*NL*Zeta[3])/9 - (608*CF*NC*NH*Zeta[3])/9 - 
       (CF*NC*Log[x]*(-49*CA*(-2366391117 - 1205949600*lm - 256608000*lm^2 + 
            169044300*Pi^2 - 415205200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            559872000*Zeta[3]) + 2*(-120*(4410*NL*(-923 + 7402*lm + 
                2160*lm^2 - 1640*Pi^2) + NM*(90975009 + 32642820*lm + 
                9525600*lm^2 + 37396800*Pi^2) + NH*(-513600357 + 
                32642820*lm + 9525600*lm^2 + 273380800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 49*CF*(-876992889 - 
              15357600*lm + 209952000*lm^2 + 153060300*Pi^2 - 
              415205200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 559872000*Zeta[
                3]))))/571536000, (100368711811*CF^2*NC)/699840000 + 
       (39281*CF^2*lm*NC)/3600 + (33*CF^2*lm^2*NC)/4 + 
       (335719973*CF*NM*NC)/133358400 - (143231*CF*lm*NM*NC)/32400 - 
       (11*CF*lm^2*NM*NC)/12 - (191711*CF*NC*NL)/7200 - 
       (143231*CF*lm*NC*NL)/32400 - (11*CF*lm^2*NC*NL)/12 - 
       (299838866747759*CF*NC*NH)/684642974400 - (143231*CF*lm*NC*NH)/
        32400 - (11*CF*lm^2*NC*NH)/12 - (543083*CF^2*NC*Pi^2)/362880 + 
       (CF^2*lm*NC*Pi^2)/6 - (4231*CF*NM*NC*Pi^2)/405 - 
       (CF*lm*NM*NC*Pi^2)/54 + (1603*CF*NC*NL*Pi^2)/1620 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (9853375*CF^2*NC*Pi^3)/(419904*Sqrt[3]) + (3161095*CF*NC*NH*Pi^3)/
        (78732*Sqrt[3]) + (2507*CF^2*NC*Pi^4)/4320 + 
       (92272583*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(349920*Sqrt[3]) - 
       (1070818*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
       (145*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (281525*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(324*Sqrt[3]) + 
       (361268*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (243*Sqrt[3]) + (281525*CF^2*NC*Pi*Log[3]^2)/(15552*Sqrt[3]) + 
       (90317*CF*NC*NH*Pi*Log[3]^2)/(2916*Sqrt[3]) - 
       (CF*NC*(385*CA*(2415409 + 844800*lm) + 154*CF*(-2393617 + 
            3456000*lm) - 80*(11*(-80887 + 67200*lm)*NM + 
            7*(3300*(45 + 32*lm)*NL + (30367 + 105600*lm)*NH)))*Log[x]^2)/
        1663200 + (CF*NC*(23319*CA + 236794*CF - 80*(883*NM + 80*NL))*
         Log[x]^3)/270 - (55*CF^2*NC*PolyGamma[2, 1])/6 + 
       (182*CF*NM*NC*PolyGamma[2, 1])/27 + (725*CF*NC*NH*PolyGamma[2, 1])/
        54 - (CA*CF*NC*(-111143340000*lm^2 - 25547288625*Pi^2 + 
          86217031250*Sqrt[3]*Pi^3 + 6723202500*Pi^4 - 
          3742200*lm*(181031 + 600*Pi^2) + 66510281250*Sqrt[3]*Pi*Log[3]^2 + 
          84*(714176931 + 11534072875*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            9513450000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 38005875000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1202850000*
             PolyGamma[2, 1] - 72729535500*Zeta[3])))/22044960000 - 
       (643477*CF^2*NC*Zeta[3])/1080 - (728*CF*NM*NC*Zeta[3])/27 + 
       (232*CF*NC*NL*Zeta[3])/9 + (511*CF*NC*NH*Zeta[3])/9 - 
       (CF*NC*Log[x]*(17787*CA*(-3075388293 - 1509991200*lm - 
            320760000*lm^2 + 239319900*Pi^2 - 563050000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 699840000*Zeta[3]) + 
          2*(40*(6534*NM*(-30621179 + 6816390*lm + 1984500*lm^2 + 
                21182700*Pi^2) - 7*(343035*NL*(7219 - 18548*lm - 5400*lm^2 + 
                  4600*Pi^2) - 2*NH*(-56993941803 + 3181306590*lm + 
                  926194500*lm^2 + 30599399600*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]]))) - 17787*CF*(-1211956527 - 17107200*lm + 
              262440000*lm^2 + 218151900*Pi^2 - 563050000*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 699840000*Zeta[3]))))/207467568000, 
      (-33640376348657*CF^2*NC)/288054144000 - (4809*CF^2*lm*NC)/400 - 
       9*CF^2*lm^2*NC - (51130442724937*CF*NM*NC)/3423214872000 + 
       (5803*CF*lm*NM*NC)/1200 + CF*lm^2*NM*NC + (2547191*CF*NC*NL)/
        77760 + (5803*CF*lm*NC*NL)/1200 + CF*lm^2*NC*NL + 
       (37407496575787441*CF*NC*NH)/71887512312000 + 
       (5803*CF*lm*NC*NH)/1200 + CF*lm^2*NC*NH - (18114149*CF^2*NC*Pi^2)/
        604800 - (CF^2*lm*NC*Pi^2)/6 + (28189*CF*NM*NC*Pi^2)/1620 + 
       (CF*lm*NM*NC*Pi^2)/54 - (1913*CF*NC*NL*Pi^2)/1620 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (35409647*CF^2*NC*Pi^3)/(1259712*Sqrt[3]) - (23130695*CF*NC*NH*Pi^3)/
        (472392*Sqrt[3]) - (1009*CF^2*NC*Pi^4)/1440 - 
       (1659797981*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(5248800*Sqrt[3]) + 
       (4396981*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) - 
       (169*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (5058521*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4860*Sqrt[3]) - (1321754*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (5058521*CF^2*NC*Pi*Log[3]^2)/(233280*Sqrt[3]) - 
       (660877*CF*NC*NH*Pi*Log[3]^2)/(17496*Sqrt[3]) + 
       (CF*NC*(3267*CA*(1363307 + 364000*lm) + 66*CF*(-51961547 + 
            29484000*lm) - 320*(7*(-244034 + 96525*lm)*NM + 
            51975*(18 + 13*lm)*NL + (203551 + 675675*lm)*NH))*Log[x]^2)/
        4989600 - (CF*NC*(442*CA + 178557*CF - 300*(160*NM + 13*NL))*
         Log[x]^3)/135 + 13*CF^2*NC*PolyGamma[2, 1] - 
       (283*CF*NM*NC*PolyGamma[2, 1])/27 - 19*CF*NC*NH*PolyGamma[2, 1] + 
       CA*CF*NC*(-14598502654943/720135360000 - (11*lm^2)/2 + 
         (5909933*Pi^2)/403200 + (35409647*Pi^3)/(2519424*Sqrt[3]) + 
         (631*Pi^4)/1728 - (lm*(725697 + 2200*Pi^2))/21600 + 
         (1659797981*Im[PolyLog[2, (-1)^(1/3)]])/(10497600*Sqrt[3]) + 
         (169*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (5058521*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9720*Sqrt[3]) + 
         (5058521*Pi*Log[3]^2)/(466560*Sqrt[3]) - (13*PolyGamma[2, 1])/2 - 
         (292213*Zeta[3])/720) + (310573*CF^2*NC*Zeta[3])/360 + 
       (223*CF*NM*NC*Zeta[3])/27 - (287*CF*NC*NL*Zeta[3])/9 - 
       (224*CF*NC*NH*Zeta[3])/3 + 
       (CF*NC*Log[x]*(363*CA*(-726234636777 - 259912346400*lm - 
            55010340000*lm^2 + 87166781100*Pi^2 - 99147011600*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 120022560000*Zeta[3]) - 
          40*(-63*NM*(-32144615561 + 4973550120*lm + 1440747000*lm^2 + 
              18180855000*Pi^2) + 5*(1440747*NL*(23025 - 43496*lm - 
                12600*lm^2 + 11400*Pi^2) - NH*(-1165746532353 + 
                62666731512*lm + 18153412200*lm^2 + 626934357280*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 1815*CF*(-4074030159 - 
              21575484*lm + 450084600*lm^2 + 829437651*Pi^2 - 
              991470116*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1200225600*Zeta[
                3]))))/622402704000, 
      (CF*NC*(-10518605697600*(6435*CA*(12299303 + 3092320*lm) + 
           858*CF*(-77555389 + 37951200*lm) - 
           80*(143*(-6366359 + 316260*lm)*NM + 90090*(685 + 502*lm)*NL + 
             (14686289 + 45225180*lm)*NH))*Log[x]^2 - 2526989832791424000*
          (5099*CA - 498830*CF + 40*(6448*NM + 251*NL))*Log[x]^3 + 
         2*(26317863*CF*(126383755680000*lm^2 + 652644514582200*Pi^2 + 
             155643696530000*Sqrt[3]*Pi^3 + 10967061420000*Pi^4 + 
             3600676800*lm*(47281 + 600*Pi^2) + 120067994466000*Sqrt[3]*Pi*
              Log[3]^2 + 3*(449842047591603 + 484444373375200*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 425599997760000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 + 1921087911456000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 46808798400000*
                PolyGamma[2, 1] - 4685164645392000*Zeta[3])) - 
           80*(NH*(2885621182711231925313 + 4619653288071822000*lm^2 - 
               93847881494266900000*Sqrt[3]*Pi^3 + 131614053791220*lm*
                (170131 + 600*Pi^2) + 391253804998843987200*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 3475052983330568640000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 72396937152720180000*
                Sqrt[3]*Pi*Log[3]^2 - 91287507709590192000*PolyGamma[2, 1] - 
               248276751071757408000*Zeta[3]) + 1184303835*NM*
              (-1069076732471 + 3900733200*lm^2 + 373985851680*Pi^2 + 111132*
                lm*(170131 + 600*Pi^2) - 43408159200*PolyGamma[2, 1] - 
               842958446400*Zeta[3]) + 8774270252748*NL*(20969467 + 526500*
                lm^2 - 693900*Pi^2 + 15*lm*(170131 + 600*Pi^2) - 20412000*
                Zeta[3]))) - 26317863*CA*(-154469034720000*lm^2 + 
           646864523386200*Pi^2 + 155643696530000*Sqrt[3]*Pi^3 + 
           11351133612000*Pi^4 - 400075200*lm*(2362841 + 6600*Pi^2) + 
           120067994466000*Sqrt[3]*Pi*Log[3]^2 + 3*(-313734551029863 + 
             484444373375200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             425599997760000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1921087911456000*
              Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
             46808798400000*PolyGamma[2, 1] - 4423995554832000*Zeta[3])) - 
         4324320*Log[x]*(4601025*CA*(-18628387797 - 6246697968*lm - 
             1320248160*lm^2 + 2473409358*Pi^2 - 2541121576*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 2880541440*Zeta[3]) - 
           4*(-10*(1460917458*NL*(-51197 + 65370*lm + 18900*lm^2 - 
                 18800*Pi^2) + 552123*NM*(-3781913783 + 172969020*lm + 
                 50009400*lm^2 + 1575428400*Pi^2) + NH*(-1980323858573799 + 
                 95500174229460*lm + 27611339956200*lm^2 + 1071475741336000*
                  Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             184041*CF*(-137279219262 - 557247600*lm + 13502538000*lm^2 + 
               29584032975*Pi^2 - 31764019700*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 36006768000*Zeta[3])))))/
       682287254853684480000, (134549187079085087*CF^2*NC)/272211166080000 - 
       (2513419*CF^2*lm*NC)/176400 - (21*CF^2*lm^2*NC)/2 - 
       (4927172447824567231*CF*NM*NC)/10529124303297600 + 
       (8996119*CF*lm*NM*NC)/1587600 + (7*CF*lm^2*NM*NC)/6 + 
       (44217739*CF*NC*NL)/850500 + (8996119*CF*lm*NC*NL)/1587600 + 
       (7*CF*lm^2*NC*NL)/6 + (374426277778694186509*CF*NC*NH)/
        473810593648392000 + (8996119*CF*lm*NC*NH)/1587600 + 
       (7*CF*lm^2*NC*NH)/6 - (1820656123*CF^2*NC*Pi^2)/7620480 - 
       (CF^2*lm*NC*Pi^2)/6 + (355115*CF*NM*NC*Pi^2)/2268 + 
       (CF*lm*NM*NC*Pi^2)/54 - (3131*CF*NC*NL*Pi^2)/1890 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (1431585485*CF^2*NC*Pi^3)/(34012224*Sqrt[3]) - 
       (55804735*CF*NC*NH*Pi^3)/(708588*Sqrt[3]) - (4283*CF^2*NC*Pi^4)/
        4320 - (546317957179*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1388832480*Sqrt[3]) + (105193331*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
       (225*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (286317097*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (183708*Sqrt[3]) - (6377684*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (286317097*CF^2*NC*Pi*Log[3]^2)/(8817984*Sqrt[3]) - 
       (1594421*CF*NC*NH*Pi*Log[3]^2)/(26244*Sqrt[3]) + 
       (CF*NC*(143*CA*(8101702097 + 1160359200*lm) + 
          2*(143*CF*(-5416686641 + 949384800*lm) - 
            280*(7*(-200858377 + 7696260*lm)*NM + 2072070*(35 + 26*lm)*NL + 
              (18173081 + 53873820*lm)*NH)))*Log[x]^2)/454053600 + 
       (CF*NC*(924179*CA - 6075482*CF + 280*(8920*NM + 299*NL))*Log[x]^3)/
        1890 + (91*CF^2*NC*PolyGamma[2, 1])/6 - 
       (154*CF*NM*NC*PolyGamma[2, 1])/9 - (770*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-37758687597920827/108884466432000 - (77*lm^2)/12 + 
         (606332953*Pi^2)/5080320 + (1431585485*Pi^3)/(68024448*Sqrt[3]) + 
         (4411*Pi^4)/8640 - (lm*(124888109 + 323400*Pi^2))/3175200 + 
         (546317957179*Im[PolyLog[2, (-1)^(1/3)]])/(2777664960*Sqrt[3]) + 
         (225*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (286317097*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(367416*Sqrt[3]) + 
         (286317097*Pi*Log[3]^2)/(17635968*Sqrt[3]) - (91*PolyGamma[2, 1])/
          12 - (4356967*Zeta[3])/5040) + (4540367*CF^2*NC*Zeta[3])/2520 - 
       (3416*CF*NM*NC*Zeta[3])/9 - (152*CF*NC*NL*Zeta[3])/3 - 
       (224*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((-1094571559231*NM*NC)/
          1490732100 + (17503*lm*NM*NC)/630 + 8*lm^2*NM*NC - 
         (46607*NC*NL)/1800 + (17503*lm*NC*NL)/630 + 8*lm^2*NC*NL - 
         (393100729144987*NC*NH)/657412856100 + (17503*lm*NC*NH)/630 + 
         8*lm^2*NC*NH + (8315*NM*NC*Pi^2)/27 - (227*NC*NL*Pi^2)/27 + 
         (6377684*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
         CF*NC*(17605903704407/13502538000 + (137*lm)/70 - 72*lm^2 - 
           (6020261*Pi^2)/15120 + (286317097*Im[PolyLog[2, (-1)^(1/3)]])/
            (551124*Sqrt[3]) - 192*Zeta[3]) + 
         CA*NC*(-249589972027/275562000 - (263093*lm)/1260 - 44*lm^2 + 
           (6141221*Pi^2)/30240 - (286317097*Im[PolyLog[2, (-1)^(1/3)]])/
            (1102248*Sqrt[3]) + 96*Zeta[3])), 
      -(CF*NC*(31555817092800*(143*CA*(11480628433 + 1439776800*lm) + 
            14*(1001*CF*(-166271593 + 24040800*lm) - 40*(13*(-478300897 + 
                  5142060*lm)*NM + 630630*(141 + 106*lm)*NL + 
                (23804021 + 66846780*lm)*NH)))*Log[x]^2 + 
          7580969498374272000*(1466771*CA - 8449106*CF + 
            280*(26914*NM + 371*NL))*Log[x]^3 - 
          2*(8772621*CF*(9187126855200000*lm^2 + 303380715661014600*Pi^2 + 
              14118812044190000*Sqrt[3]*Pi^3 + 948769335108000*Pi^4 + 
              4629441600*lm*(2710069 + 29400*Pi^2) + 10891655005518000*Sqrt[
                3]*Pi*Log[3]^2 + 3*(-245484565418081217 + 37456263763133600*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 34979134841280000*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 + 174266480088288000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 3402639576000000*
                 PolyGamma[2, 1] - 640745657541360000*Zeta[3])) - 
            560*(NH*(15991107535633230000*lm^2 - 432671472709526050000*
                 Sqrt[3]*Pi^3 + 8058003293340*lm*(9655819 + 29400*Pi^2) - 
                333775136090205810000*Sqrt[3]*Pi*Log[3]^2 + 
                81*(156562676184843202341 + 22826329458319587200*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]] - 197792673238640480000*Sqrt[3]*
                   Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                  5056904422333764000*PolyGamma[2, 1] - 8124974254044648000*
                   Zeta[3])) + 2669355*NM*(-11154819518828287 + 
                5990626026000*lm^2 + 3132263584074240*Pi^2 + 3018708*lm*
                 (9655819 + 29400*Pi^2) - 93720016051200*PolyGamma[2, 1] - 
                7861831346476800*Zeta[3]) + 268600109778*NL*(3138422699 + 
                59535000*lm^2 - 92446200*Pi^2 + 30*lm*(9655819 + 
                  29400*Pi^2) - 3048192000*Zeta[3]))) + 
          43863105*CA*(-2245742120160000*lm^2 + 60678373151367720*Pi^2 + 
            2823762408838000*Sqrt[3]*Pi^3 + 194593176640800*Pi^4 - 
            102876480*lm*(133997009 + 323400*Pi^2) + 2178331001103600*Sqrt[3]*
             Pi*Log[3]^2 + 3*(-61175000523679557 + 7491252752626720*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 6995826968256000*
               Im[PolyLog[2, (-1)^(1/3)]]^2 + 34853296017657600*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 680527915200000*
               PolyGamma[2, 1] - 123515492547888000*Zeta[3])) + 
          4324320*Log[x]*(61347*CA*(-62338553725647 - 13172604555600*lm - 
              2772521136000*lm^2 + 15954543533250*Pi^2 - 5762780426200*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 6049137024000*Zeta[3]) + 
            2*(140*(54756*NM*(-414571392017 + 7016094855*lm + 2017045800*
                   lm^2 + 209764759050*Pi^2) - 7*(44721963*NL*(1445767 - 
                    1227180*lm - 352800*lm^2 + 401800*Pi^2) - 2*NH*
                   (-648244329143223 + 27440949277170*lm + 7888954273200*
                     lm^2 + 352848353858000*Sqrt[3]*Im[PolyLog[2, (-1)^
                        (1/3)]]))) - 61347*CF*(-46380856359549 - 
                48994923600*lm + 2268426384000*lm^2 + 15690493901250*Pi^2 - 
                5762780426200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                6049137024000*Zeta[3])))))/14328032351927374080000, 
      (64234625960004391448507*CF^2*NC)/13043270233889280000 - 
       (23257127*CF^2*lm*NC)/1411200 - 12*CF^2*lm^2*NC - 
       (1476565392157764623917*CF*NM*NC)/421164972131904000 + 
       (82527527*CF*lm*NM*NC)/12700800 + (4*CF*lm^2*NM*NC)/3 + 
       (14856692111*CF*NC*NL)/190512000 + (82527527*CF*lm*NC*NL)/12700800 + 
       (4*CF*lm^2*NC*NL)/3 + (147504631023682089797*CF*NC*NH)/
        129221070995016000 + (82527527*CF*lm*NC*NH)/12700800 + 
       (4*CF*lm^2*NC*NH)/3 - (221759388323*CF^2*NC*Pi^2)/152409600 - 
       (CF^2*lm*NC*Pi^2)/6 + (4416061*CF*NM*NC*Pi^2)/4536 + 
       (CF*lm*NM*NC*Pi^2)/54 - (33373*CF*NC*NL*Pi^2)/15120 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (36408844277*CF^2*NC*Pi^3)/(612220032*Sqrt[3]) - 
       (505537865*CF*NC*NH*Pi^3)/(4251528*Sqrt[3]) - 
       (1151*CF^2*NC*Pi^4)/864 - (118390208729173*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(249989846400*Sqrt[3]) + 
       (478274237*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) - 
       (289*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (36408844277*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (16533720*Sqrt[3]) - (28887878*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (36408844277*CF^2*NC*Pi*Log[3]^2)/(793618560*Sqrt[3]) - 
       (14443939*CF*NC*NH*Pi*Log[3]^2)/(157464*Sqrt[3]) + 
       (CF*NC*(39*CA*(241704744551 + 12351292800*lm) + 
          2*(117*CF*(-71008538449 + 3368534400*lm) - 
            280*((-18620084711 + 156396240*lm)*NM + 22*(57330*(163 + 124*lm)*
                 NL + (2612557 + 7108920*lm)*NH))))*Log[x]^2)/908107200 + 
       (CF*NC*(12601921*CA - 38567860*CF + 1120*(19157*NM + 217*NL))*
         Log[x]^3)/3780 + (52*CF^2*NC*PolyGamma[2, 1])/3 - 
       (235*CF*NM*NC*PolyGamma[2, 1])/9 - (1103*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-13494155677603456505233/5217308093555712000 - 
         (22*lm^2)/3 + (24644728747*Pi^2)/33868800 + (36408844277*Pi^3)/
          (1224440064*Sqrt[3]) + (1961*Pi^4)/2880 + 
         lm*(-1144884397/25401600 - (11*Pi^2)/108) + 
         (118390208729173*Im[PolyLog[2, (-1)^(1/3)]])/(499979692800*
           Sqrt[3]) + (289*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (36408844277*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33067440*Sqrt[3]) + (36408844277*Pi*Log[3]^2)/
          (1587237120*Sqrt[3]) - (26*PolyGamma[2, 1])/3 - 
         (8620957*Zeta[3])/3360) + (26370791*CF^2*NC*Zeta[3])/5040 - 
       (21929*CF*NM*NC*Zeta[3])/9 - (227*CF*NC*NL*Zeta[3])/3 - 
       (196*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((-365906534329883*NM*NC)/
          146091745800 + (92347*lm*NM*NC)/2520 + (21*lm^2*NM*NC)/2 - 
         (410441*NC*NL)/8400 + (92347*lm*NC*NL)/2520 + (21*lm^2*NC*NL)/2 - 
         (643720005898367*NC*NH)/717177661200 + (92347*lm*NC*NH)/2520 + 
         (21*lm^2*NC*NH)/2 + (74941*NM*NC*Pi^2)/54 - (679*NC*NL*Pi^2)/54 + 
         (28887878*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CF*NC*(111609732572366569/33609746016000 + (263*lm)/280 - 
           (189*lm^2)/2 - (57259423*Pi^2)/30240 + 
           (36408844277*Im[PolyLog[2, (-1)^(1/3)]])/(49601160*Sqrt[3]) - 
           252*Zeta[3]) + CA*NC*(-58551698515199389/29408527764000 - 
           (1386257*lm)/5040 - (231*lm^2)/4 + (57625663*Pi^2)/60480 - 
           (36408844277*Im[PolyLog[2, (-1)^(1/3)]])/(99202320*Sqrt[3]) + 
           126*Zeta[3])), (-101887540576605752949661*CF^2*NC)/
        13043270233889280000 + (12416851*CF^2*lm*NC)/705600 + 
       (51*CF^2*lm^2*NC)/4 + (1223289749598709669931*CF*NM*NC)/
        84232994426380800 - (43904251*CF*lm*NM*NC)/6350400 - 
       (17*CF*lm^2*NM*NC)/12 - (127935914321*CF*NC*NL)/1333584000 - 
       (43904251*CF*lm*NC*NL)/6350400 - (17*CF*lm^2*NC*NL)/12 - 
       (2101361959974763137184982279*CF*NC*NH)/1508434777393268332608000 - 
       (43904251*CF*lm*NC*NH)/6350400 - (17*CF*lm^2*NC*NH)/12 + 
       (753041154791*CF^2*NC*Pi^2)/335301120 + (CF^2*lm*NC*Pi^2)/6 - 
       (43639321*CF*NM*NC*Pi^2)/11340 - (CF*lm*NM*NC*Pi^2)/54 + 
       (6373*CF*NC*NL*Pi^2)/2520 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (43597602025*CF^2*NC*Pi^3)/
        (612220032*Sqrt[3]) + (2125416440*CF*NC*NH*Pi^3)/
        (14348907*Sqrt[3]) + (6599*CF^2*NC*Pi^4)/4320 + 
       (24579990291349*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (49997969280*Sqrt[3]) - (108473262304*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) + 
       (325*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (8719520405*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3306744*Sqrt[3]) + (971618944*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) + 
       (8719520405*CF^2*NC*Pi*Log[3]^2)/(158723712*Sqrt[3]) + 
       (60726184*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) - 
       (CF*NC*(202657*CA*(2356306223 + 97574400*lm) + 
          2*(221*CF*(-1952909764867 + 73207411200*lm) - 
            560*(85*(-14900824915 + 37765728*lm)*NM + 12252240*(341 + 
                262*lm)*NL + (1229201627 + 3210086880*lm)*NH)))*Log[x]^2)/
        30875644800 - (CF*NC*(9686411*CA + 16*(-1738526*CF + 2291905*NM + 
            9170*NL))*Log[x]^3)/1890 - (85*CF^2*NC*PolyGamma[2, 1])/6 + 
       (533*CF*NM*NC*PolyGamma[2, 1])/18 + (1232*CF*NC*NH*PolyGamma[2, 1])/
        27 - (37114597*CF^2*NC*Zeta[3])/5040 + (82907*CF*NM*NC*Zeta[3])/9 + 
       (278*CF*NC*NL*Zeta[3])/3 + (308*CF*NC*NH*Zeta[3])/9 + 
       CA*CF*NC*(105466438230358215105589/26086540467778560000 + 
         (187*lm^2)/24 - (4565013275*Pi^2)/4064256 - (43597602025*Pi^3)/
          (1224440064*Sqrt[3]) - (6727*Pi^4)/8640 + 
         lm*(608896361/12700800 + (11*Pi^2)/108) - 
         (24579990291349*Im[PolyLog[2, (-1)^(1/3)]])/(99995938560*Sqrt[3]) - 
         (325*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (8719520405*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6613488*Sqrt[3]) - (8719520405*Pi*Log[3]^2)/(317447424*Sqrt[3]) + 
         (85*PolyGamma[2, 1])/12 + (36527717*Zeta[3])/10080) + 
       CF*Log[x]*((641845481209507*NM*NC)/116873396640 - 
         (52841*lm*NM*NC)/1260 - 12*lm^2*NM*NC + (5820979*NC*NL)/88200 - 
         (52841*lm*NC*NL)/1260 - 12*lm^2*NC*NL + 
         (137184735200862849151*NC*NH)/123115020387559200 - 
         (52841*lm*NC*NH)/1260 - 12*lm^2*NC*NH - (129998*NM*NC*Pi^2)/27 + 
         (416*NC*NL*Pi^2)/27 - (971618944*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (531441*Sqrt[3]) + CA*NC*(467368122365214827/188214577689600 + 
           (792931*lm)/2520 + 66*lm^2 - (86280991*Pi^2)/60480 + 
           (8719520405*Im[PolyLog[2, (-1)^(1/3)]])/(19840464*Sqrt[3]) - 
           144*Zeta[3]) + CF*NC*(-283209545820614509/67219492032000 - 
           (79*lm)/140 + 108*lm^2 + (85844191*Pi^2)/30240 - 
           (8719520405*Im[PolyLog[2, (-1)^(1/3)]])/(9920232*Sqrt[3]) + 
           288*Zeta[3])), (10100628147755113113207527*CF^2*NC)/
        312611614951142707200 - (118856659*CF^2*lm*NC)/6350400 - 
       (27*CF^2*lm^2*NC)/2 - (231205942219490377174393*CF*NM*NC)/
        10611197477354073600 + (418913059*CF*lm*NM*NC)/57153600 + 
       (3*CF*lm^2*NM*NC)/2 + (111821802823*CF*NC*NL)/1000188000 + 
       (418913059*CF*lm*NC*NL)/57153600 + (3*CF*lm^2*NC*NL)/2 + 
       (4183655827157200903244653*CF*NC*NH)/2638661418180644313600 + 
       (418913059*CF*lm*NC*NH)/57153600 + (3*CF*lm^2*NC*NH)/2 - 
       (43793443961461*CF^2*NC*Pi^2)/5029516800 - (CF^2*lm*NC*Pi^2)/6 + 
       (98234077*CF*NM*NC*Pi^2)/17010 + (CF*lm*NM*NC*Pi^2)/54 - 
       (192721*CF*NC*NL*Pi^2)/68040 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (1329802734671*CF^2*NC*Pi^3)/
        (16529940864*Sqrt[3]) - (22095664885*CF*NC*NH*Pi^3)/
        (129140163*Sqrt[3]) - (827*CF^2*NC*Pi^4)/480 - 
       (416617786853111*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (749969539200*Sqrt[3]) + (393983664523*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(502211745*Sqrt[3]) - 
       (361*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (1329802734671*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (446410440*Sqrt[3]) - (10100875376*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (1329802734671*CF^2*NC*Pi*Log[3]^2)/(21427701120*Sqrt[3]) - 
       (631304711*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       (CF*NC*(561*CA*(9010063292873 + 121888166400*lm) + 
          2*(187*CF*(-26178881855443 + 299180044800*lm) - 
            1680*(455*(-4182671545 + 8132256*lm)*NM + 12252240*(389 + 
                302*lm)*NL + 151*(9635051 + 24504480*lm)*NH)))*Log[x]^2)/
        92626934400 + (CF*NC*(111933737*CA + 48*(-5292722*CF + 
            35*(95935*NM + 302*NL)))*Log[x]^3)/5670 + 
       (39*CF^2*NC*PolyGamma[2, 1])/2 - (1022*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (1522*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-36414047197980674732427209/2232940106793876480000 - 
         (33*lm^2)/4 + (3981617500031*Pi^2)/914457600 + (1329802734671*Pi^3)/
          (33059881728*Sqrt[3]) + (7571*Pi^4)/8640 + 
         lm*(-5808269249/114307200 - (11*Pi^2)/108) + 
         (416617786853111*Im[PolyLog[2, (-1)^(1/3)]])/(1499939078400*
           Sqrt[3]) + (361*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (1329802734671*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (892820880*Sqrt[3]) + (1329802734671*Pi*Log[3]^2)/
          (42855402240*Sqrt[3]) - (39*PolyGamma[2, 1])/4 - 
         (1009183577*Zeta[3])/90720) + (1015347497*CF^2*NC*Zeta[3])/45360 - 
       (368902*CF*NM*NC*Zeta[3])/27 - (970*CF*NC*NL*Zeta[3])/9 - 
       (400*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((-85911754448609143*NM*NC)/
          12990927549600 + (529889*lm*NM*NC)/11340 + (40*lm^2*NM*NC)/3 - 
         (32158337*NC*NL)/396900 + (529889*lm*NC*NL)/11340 + 
         (40*lm^2*NC*NL)/3 - (1424477670630920372333*NC*NH)/
          1108035183488032800 + (529889*lm*NC*NH)/11340 + 
         (40*lm^2*NC*NH)/3 + (190738*NM*NC*Pi^2)/27 - 
         (484*NC*NL*Pi^2)/27 + (10100875376*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(5409585278489142743/796681927641600 - (689*lm)/1260 - 
           120*lm^2 - (308152979*Pi^2)/30240 + 
           (1329802734671*Im[PolyLog[2, (-1)^(1/3)]])/(1339231320*Sqrt[3]) - 
           320*Zeta[3]) + CA*NC*(-1487615937162909045391/390374144544384000 - 
           (7945579*lm)/22680 - (220*lm^2)/3 + (308679379*Pi^2)/60480 - 
           (1329802734671*Im[PolyLog[2, (-1)^(1/3)]])/(2678462640*Sqrt[3]) + 
           160*Zeta[3])), (-481865967905541325120438687*CF^2*NC)/
        9552021567951582720000 + (125961659*CF^2*lm*NC)/6350400 + 
       (57*CF^2*lm^2*NC)/4 + (36987660557147583880913*CF*NM*NC)/
        421164972131904000 - (442687859*CF*lm*NM*NC)/57153600 - 
       (19*CF*lm^2*NM*NC)/12 - (1074854408839*CF*NC*NL)/8001504000 - 
       (442687859*CF*lm*NC*NL)/57153600 - (19*CF*lm^2*NC*NL)/12 - 
       (35263830986953209563968755729583*CF*NC*NH)/
        18623437448652769488044889600 - (442687859*CF*lm*NC*NH)/57153600 - 
       (19*CF*lm^2*NC*NH)/12 + (9738287023763*CF^2*NC*Pi^2)/718502400 + 
       (CF^2*lm*NC*Pi^2)/6 - (393711977*CF*NM*NC*Pi^2)/17010 - 
       (CF*lm*NM*NC*Pi^2)/54 + (217151*CF*NC*NL*Pi^2)/68040 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (1557894718351*CF^2*NC*Pi^3)/(16529940864*Sqrt[3]) + 
       (107287348175*CF*NC*NH*Pi^3)/(516560652*Sqrt[3]) + 
       (1679*CF^2*NC*Pi^4)/864 + (142871840184517*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(249989846400*Sqrt[3]) - 
       (1399187096401*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1506635235*Sqrt[3]) + (401*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (1557894718351*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (446410440*Sqrt[3]) + (12261411220*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (1557894718351*CF^2*NC*Pi*Log[3]^2)/(21427701120*Sqrt[3]) + 
       (3065352805*CF*NC*NH*Pi*Log[3]^2)/(19131876*Sqrt[3]) + 
       CF*((446987976890617*CF*NC)/2724321600 + 
         CA*(-152686556848451/1816214400 - (2618*lm)/3)*NC - 1428*CF*lm*NC - 
         (149969814641*NM*NC)/540540 + (476*lm*NM*NC)/3 + (608*NC*NL)/3 + 
         (476*lm*NC*NL)/3 + (6750194497*NC*NH)/104756652 + 
         (476*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-172890519*CA + 80*(4787219*CF - 7563717*NM - 7497*NL))*
         Log[x]^3)/5670 - (95*CF^2*NC*PolyGamma[2, 1])/6 + 
       (1150*CF*NM*NC*PolyGamma[2, 1])/27 + (1127*CF*NC*NH*PolyGamma[2, 1])/
        18 - (1522313281*CF^2*NC*Zeta[3])/45360 + (1423040*CF*NM*NC*Zeta[3])/
        27 + (1160*CF*NC*NL*Zeta[3])/9 + (13*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(485069369206487462935557139/19104043135903165440000 + 
         (209*lm^2)/24 - (9739131908003*Pi^2)/1437004800 - 
         (1557894718351*Pi^3)/(33059881728*Sqrt[3]) - (947*Pi^4)/960 + 
         lm*(6136471249/114307200 + (11*Pi^2)/108) - 
         (142871840184517*Im[PolyLog[2, (-1)^(1/3)]])/(499979692800*
           Sqrt[3]) - (401*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (1557894718351*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (892820880*Sqrt[3]) - (1557894718351*Pi*Log[3]^2)/
          (42855402240*Sqrt[3]) + (95*PolyGamma[2, 1])/12 + 
         (1515267361*Zeta[3])/90720) + CF*Log[x]*
        ((66501689420843*NM*NC)/6956749800 - (596809*lm*NM*NC)/11340 - 
         15*lm^2*NM*NC + (329167571*NC*NL)/3175200 - (596809*lm*NC*NL)/
          11340 - 15*lm^2*NC*NL + (44466910301777603385131*NC*NH)/
          28571478659941417200 - (596809*lm*NC*NH)/11340 - 15*lm^2*NC*NH - 
         (79897*NM*NC*Pi^2)/3 + (193*NC*NL*Pi^2)/9 - 
         (12261411220*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CA*NC*(17546178328477091738953/4294115589988224000 + 
           (8946299*lm)/22680 + (165*lm^2)/2 - (1419512401*Pi^2)/181440 + 
           (1557894718351*Im[PolyLog[2, (-1)^(1/3)]])/(2678462640*Sqrt[3]) - 
           180*Zeta[3]) + CF*NC*(-15546829283991661614037/
            2147057794994112000 + (1459*lm)/1260 + 135*lm^2 + 
           (1417664401*Pi^2)/90720 - (1557894718351*Im[PolyLog[2, (-1)^
                (1/3)]])/(1339231320*Sqrt[3]) + 360*Zeta[3])), 
      (468621442259064601057286422187*CF^2*NC)/2321141241012234600960000 - 
       (133074107*CF^2*lm*NC)/6350400 - 15*CF^2*lm^2*NC - 
       (1885800438708767137440945857581*CF*NM*NC)/
        14192529681948460210368000 + (466470107*CF*lm*NM*NC)/57153600 + 
       (5*CF*lm^2*NM*NC)/3 + (274736662223*CF*NC*NL)/1778112000 + 
       (466470107*CF*lm*NC*NL)/57153600 + (5*CF*lm^2*NC*NL)/3 + 
       (39741250883910330395085459333247*CF*NC*NH)/
        18623437448652769488044889600 + (466470107*CF*lm*NC*NH)/57153600 + 
       (5*CF*lm^2*NC*NH)/3 - (24643722598751*CF^2*NC*Pi^2)/457228800 - 
       (CF^2*lm*NC*Pi^2)/6 + (2393881289*CF*NM*NC*Pi^2)/68040 + 
       (CF*lm*NM*NC*Pi^2)/54 - (48067*CF*NC*NL*Pi^2)/13608 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (1739021814803*CF^2*NC*Pi^3)/(16529940864*Sqrt[3]) - 
       (244890407405*CF*NC*NH*Pi^3)/(1033121304*Sqrt[3]) - 
       (9347*CF^2*NC*Pi^4)/4320 - (1845286197541819*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2892739651200*Sqrt[3]) + 
       (3315740653787*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3013270470*Sqrt[3]) - (441*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (248431687829*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (63772920*Sqrt[3]) - (13993737566*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (248431687829*CF^2*NC*Pi*Log[3]^2)/(3061100160*Sqrt[3]) - 
       (6996868783*CF*NC*NH*Pi*Log[3]^2)/(38263752*Sqrt[3]) + 
       (CF*NC*(323*CA*(1779258703171693 + 5414135126400*lm) + 
          10*(323*CF*(-353325595389973 + 885949384320*lm) - 
            2688*(3*(-9206753965223 + 3942923985*lm)*NM + 43648605*(343 + 
                271*lm)*NL + (4913281024 + 11828771955*lm)*NH)))*Log[x]^2)/
        1759911753600 + (CF*NC*(337138761*CA - 696130532*CF + 
          1260*(360010*NM + 271*NL))*Log[x]^3)/2835 + 
       (65*CF^2*NC*PolyGamma[2, 1])/3 - (1423*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (679*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-469481636421771940242260759561/4642282482024469201920000 - 
         (55*lm^2)/6 + (271088619470461*Pi^2)/10059033600 + 
         (1739021814803*Pi^3)/(33059881728*Sqrt[3]) + (1895*Pi^4)/1728 + 
         lm*(-6464755177/114307200 - (11*Pi^2)/108) + 
         (1845286197541819*Im[PolyLog[2, (-1)^(1/3)]])/(5785479302400*
           Sqrt[3]) + (441*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (248431687829*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (127545840*Sqrt[3]) + (248431687829*Pi*Log[3]^2)/
          (6122200320*Sqrt[3]) - (65*PolyGamma[2, 1])/6 - 
         (1849276943*Zeta[3])/30240) + (1851983423*CF^2*NC*Zeta[3])/15120 - 
       (2140409*CF*NM*NC*Zeta[3])/27 - (1331*CF*NC*NL*Zeta[3])/9 - 
       (88*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((-40388014686871620529*NM*NC)/
          5806325999073600 + (131609*lm*NM*NC)/2268 + (33*lm^2*NM*NC)/2 - 
         (29126231*NC*NL)/235200 + (131609*lm*NC*NL)/2268 + 
         (33*lm^2*NC*NL)/2 - (56780184636394949540389*NC*NH)/
          32000056099134387264 + (131609*lm*NC*NH)/2268 + 
         (33*lm^2*NC*NH)/2 + (79893*NM*NC*Pi^2)/2 - (443*NC*NL*Pi^2)/18 + 
         (13993737566*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(-1777398281369962044803/429411558998822400 - (158*lm)/63 - 
           (297*lm^2)/2 - (1811228023*Pi^2)/30240 + 
           (248431687829*Im[PolyLog[2, (-1)^(1/3)]])/(191318760*Sqrt[3]) - 
           396*Zeta[3]) + CA*NC*(6704173595414537869243/4294115589988224000 - 
           (1971607*lm)/4536 - (363*lm^2)/4 + (1811954903*Pi^2)/60480 - 
           (248431687829*Im[PolyLog[2, (-1)^(1/3)]])/(382637520*Sqrt[3]) + 
           198*Zeta[3])), (-169667381039061009123208028293*CF^2*NC)/
        535647978695131061760000 + (28037311*CF^2*lm*NC)/1270080 + 
       (63*CF^2*lm^2*NC)/4 + (66145717412617897286920241*CF*NM*NC)/
        121716676946120256000 - (98050471*CF*lm*NM*NC)/11430720 - 
       (7*CF*lm^2*NM*NC)/4 - (2186263656377*CF*NC*NL)/12002256000 - 
       (98050471*CF*lm*NC*NL)/11430720 - (7*CF*lm^2*NC*NL)/4 - 
       (1259244420675813089059588200108649*CF*NC*NH)/
        502832811113624776177212019200 - (98050471*CF*lm*NC*NH)/11430720 - 
       (7*CF*lm^2*NC*NH)/4 + (1849481165763391*CF^2*NC*Pi^2)/21794572800 + 
       (CF^2*lm*NC*Pi^2)/6 - (4931227747*CF*NM*NC*Pi^2)/34020 - 
       (CF*lm*NM*NC*Pi^2)/54 + (267299*CF*NC*NL*Pi^2)/68040 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (6007462088485*CF^2*NC*Pi^3)/(49589822592*Sqrt[3]) + 
       (655293737245*CF*NC*NH*Pi^3)/(2324522934*Sqrt[3]) + 
       (3469*CF^2*NC*Pi^4)/1440 + (7912436660818063*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12149506535040*Sqrt[3]) - 
       (52330561635994*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (40679151345*Sqrt[3]) + (485*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        2 + (1201492417697*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (267846264*Sqrt[3]) + (149781425656*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) + 
       (1201492417697*CF^2*NC*Pi*Log[3]^2)/(12856620672*Sqrt[3]) + 
       (18722678207*CF*NC*NH*Pi*Log[3]^2)/(86093442*Sqrt[3]) + 
       CF*((4751363247601*CF*NC)/4656960 + CA*(-1228232990531/2395008 - 
           1155*lm)*NC - 1890*CF*lm*NC - (34815191617*NM*NC)/20020 + 
         210*lm*NM*NC + (2375*NC*NL)/9 + 210*lm*NC*NL + 
         (46898632511*NC*NH)/523783260 + 210*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-1053893987*CA + 8*(270071899*CF - 4725*(95756*NM + 21*NL)))*
         Log[x]^3)/5670 - (35*CF^2*NC*PolyGamma[2, 1])/2 + 
       (3179*CF*NM*NC*PolyGamma[2, 1])/54 + (250*CF*NC*NH*PolyGamma[2, 1])/
        3 - (1723301621*CF^2*NC*Zeta[3])/9072 + (8595065*CF*NM*NC*Zeta[3])/
        27 + (1562*CF*NC*NL*Zeta[3])/9 - (364*CF*NC*NH*Zeta[3])/9 + 
       CA*CF*NC*(33976952704552452571299825221/214259191478052424704000 + 
         (77*lm^2)/8 - (15807880725683*Pi^2)/372556800 - 
         (6007462088485*Pi^3)/(99179645184*Sqrt[3]) - (2107*Pi^4)/1728 + 
         lm*(1358607821/22861440 + (11*Pi^2)/108) - 
         (7912436660818063*Im[PolyLog[2, (-1)^(1/3)]])/(24299013070080*
           Sqrt[3]) - (485*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (1201492417697*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (535692528*Sqrt[3]) - (1201492417697*Pi*Log[3]^2)/
          (25713241344*Sqrt[3]) + (35*PolyGamma[2, 1])/4 + 
         (1721463029*Zeta[3])/18144) + CF*Log[x]*
        ((-134308079205934477*NM*NC)/3311412904800 - (731881*lm*NM*NC)/
          11340 - (55*lm^2*NM*NC)/3 + (181842341*NC*NL)/1190700 - 
         (731881*lm*NC*NL)/11340 - (55*lm^2*NC*NL)/3 + 
         (7580139246845796903321739*NC*NH)/3600006311152618567200 - 
         (731881*lm*NC*NH)/11340 - (55*lm^2*NC*NH)/3 - 
         (1435790*NM*NC*Pi^2)/9 + (260*NC*NL*Pi^2)/9 - 
         (149781425656*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CA*NC*(-9848372710010447836757/
            990949751535744000 + (10961291*lm)/22680 + (605*lm^2)/6 - 
           (1695967685*Pi^2)/36288 + (1201492417697*Im[PolyLog[2, (-1)^
                (1/3)]])/(1607077584*Sqrt[3]) - 220*Zeta[3]) + 
         CF*NC*(2081032578940845693613/99094975153574400 + (4231*lm)/1260 + 
           165*lm^2 + (1695465029*Pi^2)/18144 - 
           (1201492417697*Im[PolyLog[2, (-1)^(1/3)]])/(803538792*Sqrt[3]) + 
           440*Zeta[3])), (395711136417748238197952222038509851*CF^2*NC)/
        307901706761513932051944960000 - (3564769231*CF^2*lm*NC)/153679680 - 
       (33*CF^2*lm^2*NC)/2 - (11806416759948772392086245097803*CF*NM*NC)/
        14192529681948460210368000 + (12439770751*CF*lm*NM*NC)/1383117120 + 
       (11*CF*lm^2*NM*NC)/6 + (200586755638343*CF*NC*NL)/968181984000 + 
       (12439770751*CF*lm*NC*NL)/1383117120 + (11*CF*lm^2*NC*NL)/6 + 
       (2345289364307012207762681497712593*CF*NC*NH)/
        838054685189374626962020032000 + (12439770751*CF*lm*NC*NH)/
        1383117120 + (11*CF*lm^2*NC*NH)/6 - 
       (249582356406741643*CF^2*NC*Pi^2)/719220902400 - (CF^2*lm*NC*Pi^2)/6 + 
       (83536002413*CF*NM*NC*Pi^2)/374220 + (CF*lm*NM*NC*Pi^2)/54 - 
       (3223159*CF*NC*NL*Pi^2)/748440 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (657385749525779*CF^2*NC*Pi^3)/
        (4909392436608*Sqrt[3]) - (493533711055*CF*NC*NH*Pi^3)/
        (1549681956*Sqrt[3]) - (11467*CF^2*NC*Pi^4)/4320 - 
       (47602542250597987199*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (66154063083292800*Sqrt[3]) + (20320014448418*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(13559717115*Sqrt[3]) - 
       (529*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (657385749525779*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (132583900680*Sqrt[3]) - (56403852692*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) - 
       (657385749525779*CF^2*NC*Pi*Log[3]^2)/(6364027232640*Sqrt[3]) - 
       (14100963173*CF*NC*NH*Pi*Log[3]^2)/(57395628*Sqrt[3]) + 
       CF*((-2122606297985169247*CF*NC)/509448139200 + 2130*CF*lm*NC + 
         CA*(708568464300016109/339632092800 + (3905*lm)/3)*NC + 
         (467614753530487*NM*NC)/174594420 - (710*lm*NM*NC)/3 - 
         295*NC*NL - (710*lm*NC*NL)/3 - (10777604503*NC*NH)/104756652 - 
         (710*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(46598824487*CA - 1848*(50796439*CF - 32879580*NM - 5325*NL))*
         Log[x]^3)/62370 + (143*CF^2*NC*PolyGamma[2, 1])/6 - 
       (1918*CF*NM*NC*PolyGamma[2, 1])/27 - (886*CF*NC*NH*PolyGamma[2, 1])/
        9 + CA*CF*NC*(-4354334188725920196136924366658213833/
          6773837548753306505142789120000 - (121*lm^2)/12 + 
         (19198768053711031*Pi^2)/110649369600 + (657385749525779*Pi^3)/
          (9818784873216*Sqrt[3]) + (773*Pi^4)/576 + 
         lm*(-15667044031/251475840 - (11*Pi^2)/108) + 
         (47602542250597987199*Im[PolyLog[2, (-1)^(1/3)]])/
          (132308126166585600*Sqrt[3]) + (529*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 + (657385749525779*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (265167801360*Sqrt[3]) + (657385749525779*Pi*Log[3]^2)/
          (12728054465280*Sqrt[3]) - (143*PolyGamma[2, 1])/12 - 
         (375013544431*Zeta[3])/997920) + (375128804191*CF^2*NC*Zeta[3])/
        498960 - (13126484*CF*NM*NC*Zeta[3])/27 - (1772*CF*NC*NL*Zeta[3])/
        9 + (368*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((18154153119170743813*NM*NC)/181447687471050 + 
         (8800391*lm*NM*NC)/124740 + 20*lm^2*NM*NC - (6243509431*NC*NL)/
          34927200 + (8800391*lm*NC*NL)/124740 + 20*lm^2*NC*NL - 
         (129630468381055952462729*NC*NH)/54545550168979069200 + 
         (8800391*lm*NC*NH)/124740 + 20*lm^2*NC*NH + 243483*NM*NC*Pi^2 - 
         (295*NC*NL*Pi^2)/9 + (56403852692*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(14348907*Sqrt[3]) + 
         CF*NC*(-40815685139894596551403587823/184288411717729615296000 - 
           (68591*lm)/13860 - 180*lm^2 - (373364802511*Pi^2)/997920 + 
           (657385749525779*Im[PolyLog[2, (-1)^(1/3)]])/(397751702040*
             Sqrt[3]) - 480*Zeta[3]) + CA*NC*(5798805729940078432486959997/
            52653831919351318656000 - (11975591*lm)/22680 - 110*lm^2 + 
           (373396883791*Pi^2)/1995840 - (657385749525779*
             Im[PolyLog[2, (-1)^(1/3)]])/(795503404080*Sqrt[3]) + 
           240*Zeta[3])), (-6892406894215677661127983434608780279*CF^2*NC)/
        3386918774376653252571394560000 + (3737023831*CF^2*lm*NC)/153679680 + 
       (69*CF^2*lm^2*NC)/4 + (49401766878482172355326441294289*CF*NM*NC)/
        14192529681948460210368000 - (13015434511*CF*lm*NM*NC)/1383117120 - 
       (23*CF*lm^2*NM*NC)/12 - (698455708205581*CF*NC*NL)/2904545952000 - 
       (13015434511*CF*lm*NC*NL)/1383117120 - (23*CF*lm^2*NC*NL)/12 - 
       (4264301993408058586704441384452173297*CF*NC*NH)/
        1317265581707541958510364778432000 - (13015434511*CF*lm*NC*NH)/
        1383117120 - (23*CF*lm^2*NC*NH)/12 + 
       (79438506536665879*CF^2*NC*Pi^2)/143844180480 + (CF^2*lm*NC*Pi^2)/6 - 
       (88274133698*CF*NM*NC*Pi^2)/93555 - (CF*lm*NM*NC*Pi^2)/54 + 
       (3547609*CF*NC*NL*Pi^2)/748440 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (746517903774187*CF^2*NC*Pi^3)/
        (4909392436608*Sqrt[3]) + (15586265918755*CF*NC*NH*Pi^3)/
        (41841412812*Sqrt[3]) + (2527*CF^2*NC*Pi^4)/864 + 
       (48273646079485861327*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (66154063083292800*Sqrt[3]) - (634216020294179*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) + 
       (577*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (746517903774187*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (132583900680*Sqrt[3]) + (1781287533572*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) + 
       (746517903774187*CF^2*NC*Pi*Log[3]^2)/(6364027232640*Sqrt[3]) + 
       (445321883393*CF*NC*NH*Pi*Log[3]^2)/(1549681956*Sqrt[3]) + 
       CF*((482493810090696953*CF*NC)/72778305600 + 
         CA*(-3381009750136427911/1018896278400 - (4477*lm)/3)*NC - 
         2442*CF*lm*NC - (1976785167020353*NM*NC)/174594420 + 
         (814*lm*NM*NC)/3 + (3025*NC*NL)/9 + (814*lm*NC*NL)/3 + 
         (76422576787*NC*NH)/634053420 + (814*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-73705765591*CA + 40*(3705310177*CF - 
            693*(9095594*NM + 407*NL)))*Log[x]^3)/62370 - 
       (115*CF^2*NC*PolyGamma[2, 1])/6 + (2128*CF*NM*NC*PolyGamma[2, 1])/
        27 + (649*CF*NC*NH*PolyGamma[2, 1])/6 - 
       (592296590623*CF^2*NC*Zeta[3])/498960 + (54544364*CF*NM*NC*Zeta[3])/
        27 + (2048*CF*NC*NL*Zeta[3])/9 - (307*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(6894055788903816648390858764824649231/
          6773837548753306505142789120000 + (253*lm^2)/24 - 
         (79438888192293463*Pi^2)/287688360960 - (746517903774187*Pi^3)/
          (9818784873216*Sqrt[3]) - (12763*Pi^4)/8640 + 
         lm*(16389402031/251475840 + (11*Pi^2)/108) - 
         (48273646079485861327*Im[PolyLog[2, (-1)^(1/3)]])/
          (132308126166585600*Sqrt[3]) - (577*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 - (746517903774187*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (265167801360*Sqrt[3]) - (746517903774187*Pi*Log[3]^2)/
          (12728054465280*Sqrt[3]) + (115*PolyGamma[2, 1])/12 + 
         (592167193663*Zeta[3])/997920) + CF*Log[x]*
        ((-1859487201745972733443*NM*NC)/2540267624594700 - 
         (9688691*lm*NM*NC)/124740 - 22*lm^2*NM*NC + (22487040623*NC*NL)/
          104781600 - (9688691*lm*NC*NL)/124740 - 22*lm^2*NC*NL + 
         (625764460560972416782872239*NC*NH)/225521447992073907874200 - 
         (9688691*lm*NC*NH)/124740 - 22*lm^2*NC*NH - (9094901*NM*NC*Pi^2)/
          9 + (341*NC*NL*Pi^2)/9 - (1781287533572*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(387420489*Sqrt[3]) + 
         CA*NC*(-15599064184918293808055603203/73715364687091846118400 + 
           (13181411*lm)/22680 + 121*lm^2 - (590344603663*Pi^2)/1995840 + 
           (746517903774187*Im[PolyLog[2, (-1)^(1/3)]])/(795503404080*
             Sqrt[3]) - 264*Zeta[3]) + CF*NC*(78240305578574363779898799299/
            184288411717729615296000 + (83711*lm)/13860 + 198*lm^2 + 
           (590308087183*Pi^2)/997920 - (746517903774187*
             Im[PolyLog[2, (-1)^(1/3)]])/(397751702040*Sqrt[3]) + 
           528*Zeta[3])), (5140498368006288004302542190102551406509*CF^2*NC)/
        609556509798965544998497835520000 - (3909379861*CF^2*lm*NC)/
        153679680 - 18*CF^2*lm^2*NC - (186159907173435107065107361932003499*
         CF*NM*NC)/34536101728053383075909491200 + 
       (13591199701*CF*lm*NM*NC)/1383117120 + 2*CF*lm^2*NM*NC + 
       (4720590217022947*CF*NC*NL)/17427275712000 + 
       (13591199701*CF*lm*NC*NL)/1383117120 + 2*CF*lm^2*NC*NL + 
       (593193354064244421111746736343677255047*CF*NC*NH)/
        165185103946125761597199743215372800 + (13591199701*CF*lm*NC*NH)/
        1383117120 + 2*CF*lm^2*NC*NH - (554318487252025829*CF^2*NC*Pi^2)/
        239740300800 - (CF^2*lm*NC*Pi^2)/6 + (366778494101*CF*NM*NC*Pi^2)/
        249480 + (CF*lm*NM*NC*Pi^2)/54 - (482288*CF*NC*NL*Pi^2)/93555 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (7365474785631145*CF^2*NC*Pi^3)/(44184531929472*Sqrt[3]) - 
       (104731360750765*CF*NC*NH*Pi^3)/(251048476872*Sqrt[3]) - 
       (4601*CF^2*NC*Pi^4)/1440 - (95191817534864355791*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(119077313549927040*Sqrt[3]) + 
       (4372145423941403*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2196674172630*Sqrt[3]) - (625*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        2 - (1473094957126229*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (238651021224*Sqrt[3]) - (5984649185758*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (1473094957126229*CF^2*NC*Pi*Log[3]^2)/(11455249018752*Sqrt[3]) - 
       (2992324592879*CF*NC*NH*Pi*Log[3]^2)/(9298091736*Sqrt[3]) + 
       (CF*NC*(23*CA*(53734307412447730669 + 6454730565803520*lm) + 
          66*(69*CF*(-542618232339808367 + 53344880709120*lm) - 
            224*(3*(-35421295190124941 + 608597349360*lm)*NM + 
              22*(334639305*(305 + 248*lm)*NL + 4*(9372834481 + 20747636910*
                   lm)*NH))))*Log[x]^2)/89051534732160 + 
       (CF*NC*(304510583175*CA + 8*(-76242683656*CF + 
            1155*(42226963*NM + 1364*NL)))*Log[x]^3)/62370 + 
       26*CF^2*NC*PolyGamma[2, 1] - (839*CF*NM*NC*PolyGamma[2, 1])/9 - 
       (3395*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-1763302408954677291633903625529200295895899/
          418155765722090363868969515166720000 - 11*lm^2 + 
         (554319225712209829*Pi^2)/479480601600 + (7365474785631145*Pi^3)/
          (88369063858944*Sqrt[3]) + (13931*Pi^4)/8640 + 
         lm*(-17111861461/251475840 - (11*Pi^2)/108) + 
         (95191817534864355791*Im[PolyLog[2, (-1)^(1/3)]])/
          (238154627099854080*Sqrt[3]) + (625*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 + (1473094957126229*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (477302042448*Sqrt[3]) + (1473094957126229*Pi*Log[3]^2)/
          (22910498037504*Sqrt[3]) - 13*PolyGamma[2, 1] - 
         (487788916973*Zeta[3])/199584) + (487818133853*CF^2*NC*Zeta[3])/
        99792 - (28140643*CF*NM*NC*Zeta[3])/9 - (767*CF*NC*NL*Zeta[3])/3 + 
       (988*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((12356783602334785698125201*NM*NC)/9214639360529803200 + 
         (2628629*lm*NM*NC)/31185 + (143*lm^2*NM*NC)/6 - 
         (155442823553*NC*NL)/628689600 + (2628629*lm*NC*NL)/31185 + 
         (143*lm^2*NC*NL)/6 - (319305570286976807300772069509*NC*NH)/
          102837780284385701990635200 + (2628629*lm*NC*NH)/31185 + 
         (143*lm^2*NC*NH)/6 + (84449251*NM*NC*Pi^2)/54 - 
         (2299*NC*NL*Pi^2)/54 + (5984649185758*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CF*NC*(-289495887352077584160207893336587/
            119750609934180704019340800 - (109121*lm)/13860 - (429*lm^2)/2 - 
           (487365256505*Pi^2)/199584 + (1473094957126229*
             Im[PolyLog[2, (-1)^(1/3)]])/(715953063672*Sqrt[3]) - 
           572*Zeta[3]) + CA*NC*(1446624925660182131245530042359939/
            1197506099341807040193408000 - (1787287*lm)/2835 - 
           (1573*lm^2)/12 + (487373616857*Pi^2)/399168 - 
           (1473094957126229*Im[PolyLog[2, (-1)^(1/3)]])/(1431906127344*
             Sqrt[3]) + 286*Zeta[3])), 
      (-11501581024319657843138830209873140988659*CF^2*NC)/
        853379113718551762997896969728000 + (4081735891*CF^2*lm*NC)/
        153679680 + (75*CF^2*lm^2*NC)/4 + (2458250353348081815741030785617*CF*
         NM*NC)/106710749488334287296000 - (14166964891*CF*lm*NM*NC)/
        1383117120 - (25*CF*lm^2*NM*NC)/12 - (7436657402259149*CF*NC*NL)/
        23962504104000 - (14166964891*CF*lm*NC*NL)/1383117120 - 
       (25*CF*lm^2*NC*NL)/12 - (115562559388564268216581534791533825810843*
         CF*NC*NH)/28156551808998709363159047138984000000 - 
       (14166964891*CF*lm*NC*NH)/1383117120 - (25*CF*lm^2*NC*NH)/12 + 
       (242844778595175761*CF^2*NC*Pi^2)/65383718400 + (CF^2*lm*NC*Pi^2)/6 - 
       (339205561459*CF*NM*NC*Pi^2)/53460 - (CF*lm*NM*NC*Pi^2)/54 + 
       (4210579*CF*NC*NL*Pi^2)/748440 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (8268756687441053*CF^2*NC*Pi^3)/
        (44184531929472*Sqrt[3]) + (45310295194360*CF*NC*NH*Pi^3)/
        (94143178827*Sqrt[3]) + (15079*CF^2*NC*Pi^4)/4320 + 
       (479772559969062634343*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (595386567749635200*Sqrt[3]) - (82558792476029992*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(36245123848395*Sqrt[3]) + 
       (677*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (8268756687441053*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1193255106120*Sqrt[3]) + (20713277803136*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) + 
       (8268756687441053*CF^2*NC*Pi*Log[3]^2)/(57276245093760*Sqrt[3]) + 
       (1294579862696*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) + 
       CF*((431446172002783058389*CF*NC)/9679514644800 + 
         CA*(-143843918915136005183/6453009763200 - (17006*lm)/9)*NC - 
         3092*CF*lm*NC - (699662558983943*NM*NC)/9189180 + 
         (3092*lm*NM*NC)/9 + (3782*NC*NL)/9 + (3092*lm*NC*NL)/9 + 
         (1057806311489*NC*NH)/6692786100 + (3092*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-973354502061*CA + 1948865442358*CF - 
          36960*(90007210*NM + 773*NL))*Log[x]^3)/124740 - 
       (125*CF^2*NC*PolyGamma[2, 1])/6 + (5551*CF*NM*NC*PolyGamma[2, 1])/
        54 + (3712*CF*NC*NH*PolyGamma[2, 1])/27 - 
       (3896793548573*CF^2*NC*Zeta[3])/498960 + (359992429*CF*NM*NC*Zeta[3])/
        27 + (2626*CF*NC*NL*Zeta[3])/9 - (1652*CF*NC*NH*Zeta[3])/9 + 
       CA*CF*NC*(2818008502280026218739175837071829696188327/
          418155765722090363868969515166720000 + (275*lm^2)/24 - 
         (242845007965206161*Pi^2)/130767436800 - (8268756687441053*Pi^3)/
          (88369063858944*Sqrt[3]) - (5069*Pi^4)/2880 + 
         lm*(17834320891/251475840 + (11*Pi^2)/108) - 
         (479772559969062634343*Im[PolyLog[2, (-1)^(1/3)]])/
          (1190773135499270400*Sqrt[3]) - (677*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 - (8268756687441053*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2386510212240*Sqrt[3]) - (8268756687441053*Pi*Log[3]^2)/
          (114552490187520*Sqrt[3]) + (125*PolyGamma[2, 1])/12 + 
         (3896630776733*Zeta[3])/997920) + CF*Log[x]*
        ((-23412176118924753209897*NM*NC)/3208759104751200 - 
         (11478941*lm*NM*NC)/124740 - 26*lm^2*NM*NC + (62844921859*NC*NL)/
          216112050 - (11478941*lm*NC*NL)/124740 - 26*lm^2*NC*NL + 
         (13793304828189662431479853993991*NC*NH)/
          3856416760664463824648820000 - (11478941*lm*NC*NH)/124740 - 
         26*lm^2*NC*NH - (180011848*NM*NC*Pi^2)/27 + (1312*NC*NL*Pi^2)/
          27 - (20713277803136*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CA*NC*(-511877819365882225312352579646269/
            239501219868361408038681600 + (15606701*lm)/22680 + 143*lm^2 - 
           (3894309633293*Pi^2)/1995840 + (8268756687441053*
             Im[PolyLog[2, (-1)^(1/3)]])/(7159530636720*Sqrt[3]) - 
           312*Zeta[3]) + CF*NC*(2560315123805203671871942208965381/
            598753049670903520096704000 + (127601*lm)/13860 + 234*lm^2 + 
           (3894262546253*Pi^2)/997920 - (8268756687441053*
             Im[PolyLog[2, (-1)^(1/3)]])/(3579765318360*Sqrt[3]) + 
           624*Zeta[3])), (199011168769127035623015068781372270269858083*CF^2*
         NC)/3494587470677469469476388091036160000 - 
       (718954874899*CF^2*lm*NC)/25971865920 - (39*CF^2*lm^2*NC)/2 - 
       (778109009637988637476489616279508973579*CF*NM*NC)/
        21585063580033364422443432000000 + (2491534723939*CF*lm*NM*NC)/
        233746793280 + (13*CF*lm^2*NM*NC)/6 + 
       (1403867652212264381*CF*NC*NL)/4049663193576000 + 
       (2491534723939*CF*lm*NC*NL)/233746793280 + (13*CF*lm^2*NC*NL)/6 + 
       (60917417404121267406733328145282922223189*CF*NC*NH)/
        13466176952129817521510848631688000000 + (2491534723939*CF*lm*NC*NH)/
        233746793280 + (13*CF*lm^2*NC*NH)/6 - 
       (29634910201568916247*CF^2*NC*Pi^2)/1869974346240 - 
       (CF^2*lm*NC*Pi^2)/6 + (24293458033079*CF*NM*NC*Pi^2)/2432430 + 
       (CF*lm*NM*NC*Pi^2)/54 - (59138077*CF*NC*NL*Pi^2)/9729720 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (1053192585177534437*CF^2*NC*Pi^3)/(5169590235748224*Sqrt[3]) - 
       (100722682588745*CF*NC*NH*Pi^3)/(188286357654*Sqrt[3]) - 
       (3271*CF^2*NC*Pi^4)/864 - (793637088731599009394771*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(905582969547195139200*Sqrt[3]) + 
       (13397318863962859*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5177874835485*Sqrt[3]) - (729*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        2 - (1053192585177534437*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(139610847416040*Sqrt[3]) - 
       (23022327448856*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) - (1053192585177534437*CF^2*NC*Pi*Log[3]^2)/
        (6701320675969920*Sqrt[3]) - (2877790931107*CF*NC*NH*Pi*Log[3]^2)/
        (6973568802*Sqrt[3]) + CF*((-23930667039934212497549*CF*NC)/
          125833690382400 + 3428*CF*lm*NC + 
         CA*(23931901877459085618469/251667380764800 + (18854*lm)/9)*NC + 
         (2406334985598240707*NM*NC)/20078358300 - (3428*lm*NM*NC)/9 - 
         (4166*NC*NL)/9 - (3428*lm*NC*NL)/9 - (3980549009*NC*NH)/
          22383900 - (3428*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-53440721949021*CA + 130*(822410534059*CF - 
            3696*(140894098*NM + 857*NL)))*Log[x]^3)/1621620 + 
       (169*CF^2*NC*PolyGamma[2, 1])/6 - (3230*CF*NM*NC*PolyGamma[2, 1])/
        27 - (4258*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-55723745745538594317809634877306533341852989/
          1956968983579382902906777330980249600 - (143*lm^2)/12 + 
         (29634917631864428887*Pi^2)/3739948692480 + 
         (1053192585177534437*Pi^3)/(10339180471496448*Sqrt[3]) + 
         (16483*Pi^4)/8640 + lm*(-3136109214499/42499416960 - 
           (11*Pi^2)/108) + (793637088731599009394771*
           Im[PolyLog[2, (-1)^(1/3)]])/(1811165939094390278400*Sqrt[3]) + 
         (729*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (1053192585177534437*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (279221694832080*Sqrt[3]) + (1053192585177534437*Pi*Log[3]^2)/
          (13402641351939840*Sqrt[3]) - (169*PolyGamma[2, 1])/12 - 
         (5482303021267*Zeta[3])/332640) + (5482363765027*CF^2*NC*Zeta[3])/
        166320 - (563536726*CF*NM*NC*Zeta[3])/27 - (2926*CF*NC*NL*Zeta[3])/
        9 + (1792*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((10175337505085117296981974329*NM*NC)/806280944046357780000 + 
         (160951793*lm*NM*NC)/1621620 + 28*lm^2*NM*NC - 
         (7434264546851*NC*NL)/22475653200 + (160951793*lm*NC*NL)/1621620 + 
         28*lm^2*NC*NL - (666081250313987548328135526313*NC*NH)/
          167670293941933209767340000 + (160951793*lm*NC*NH)/1621620 + 
         28*lm^2*NC*NH + (281785330*NM*NC*Pi^2)/27 - (1462*NC*NL*Pi^2)/
          27 + (23022327448856*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*
          (-1510849608640718122249494252378079489/
            70054106811495711851314368000 - (2033033*lm)/180180 - 252*lm^2 - 
           (71258363884951*Pi^2)/4324320 + (1053192585177534437*
             Im[PolyLog[2, (-1)^(1/3)]])/(418832542248120*Sqrt[3]) - 
           672*Zeta[3]) + CA*NC*(215819150731028918047114577705368171/
            20015459088998774814661248000 - (218740433*lm)/294840 - 
           154*lm^2 + (71258594835671*Pi^2)/8648640 - 
           (1053192585177534437*Im[PolyLog[2, (-1)^(1/3)]])/
            (837665084496240*Sqrt[3]) + 336*Zeta[3])), 
      (-561254636786610776470442074443913031280902053*CF^2*NC)/
        6115528073685571571583679159313280000 + (748096384219*CF^2*lm*NC)/
        25971865920 + (81*CF^2*lm^2*NC)/4 + 
       (27075649133169470280551815449048604529*CF*NM*NC)/
        172680508640266915379547456000 - (2588852381299*CF*lm*NM*NC)/
        233746793280 - (9*CF*lm^2*NM*NC)/4 - (6363632845245094511*CF*NC*NL)/
        16198652774304000 - (2588852381299*CF*lm*NC*NL)/233746793280 - 
       (9*CF*lm^2*NC*NL)/4 - (14265099537315059515491328371169294132285523*
         CF*NC*NH)/2787498629090872226952745666759416000000 - 
       (2588852381299*CF*lm*NC*NH)/233746793280 - (9*CF*lm^2*NC*NH)/4 + 
       (11425793961074675263*CF^2*NC*Pi^2)/445231987200 + 
       (CF^2*lm*NC*Pi^2)/6 - (9690621742021*CF*NM*NC*Pi^2)/221130 - 
       (CF*lm*NM*NC*Pi^2)/54 + (64079167*CF*NC*NL*Pi^2)/9729720 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (1171047885051135125*CF^2*NC*Pi^3)/(5169590235748224*Sqrt[3]) + 
       (2067606001884185*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) + 
       (657*CF^2*NC*Pi^4)/160 + (159119337452113911513343*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(181116593909439027840*Sqrt[3]) - 
       (957321095326641149*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (326206114635555*Sqrt[3]) + (785*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 + (234209577010227025*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27922169483208*Sqrt[3]) + 
       (236297828786764*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) + (234209577010227025*CF^2*NC*Pi*Log[3]^2)/
        (1340264135193984*Sqrt[3]) + (59074457196691*CF*NC*NH*Pi*Log[3]^2)/
        (125524238436*Sqrt[3]) + CF*((861135861514174939921*CF*NC)/
          2796304230720 + CA*(-7750499961839396523793/50333476152960 - 
           (21164*lm)/9)*NC - 3848*CF*lm*NC - (2111751581584092407*NM*NC)/
          4015671660 + (3848*lm*NM*NC)/9 + (4654*NC*NL)/9 + 
         (3848*lm*NC*NL)/9 + (1110203491039*NC*NH)/5475915900 + 
         (3848*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-86170531244693*CA + 172378028318894*CF - 
          480480*(612667357*NM + 962*NL))*Log[x]^3)/1621620 - 
       (45*CF^2*NC*PolyGamma[2, 1])/2 + (3542*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (9269*CF*NC*NH*PolyGamma[2, 1])/54 - (68947407283033*CF^2*NC*Zeta[3])/
        1297296 + (2450624752*CF*NM*NC*Zeta[3])/27 + 
       (3304*CF*NC*NL*Zeta[3])/9 - (859*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(2245035297127644231855786526855537090841147971/
          48924224589484572572669433274506240000 + (99*lm^2)/8 - 
         (3808598645905710541*Pi^2)/296821324800 - (1171047885051135125*Pi^3)/
          (10339180471496448*Sqrt[3]) - (17867*Pi^4)/8640 + 
         lm*(3258218198419/42499416960 + (11*Pi^2)/108) - 
         (159119337452113911513343*Im[PolyLog[2, (-1)^(1/3)]])/
          (362233187818878055680*Sqrt[3]) - 
         (785*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (234209577010227025*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55844338966416*Sqrt[3]) - (234209577010227025*Pi*Log[3]^2)/
          (2680528270387968*Sqrt[3]) + (45*PolyGamma[2, 1])/4 + 
         (68946882887161*Zeta[3])/2594592) + 
       CF*Log[x]*((-510436474752645983156164469*NM*NC)/8062809440463577800 - 
         (174479153*lm*NM*NC)/1621620 - (91*lm^2*NM*NC)/3 + 
         (17204974587847*NC*NL)/44951306400 - (174479153*lm*NC*NL)/
          1621620 - (91*lm^2*NC*NL)/3 + (892265862032293388511316251641*NC*
           NH)/197203129806705536487723750 - (174479153*lm*NC*NH)/1621620 - 
         (91*lm^2*NC*NH)/3 - (1225331581*NM*NC*Pi^2)/27 + 
         (1651*NC*NL*Pi^2)/27 - (236297828786764*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CA*NC*(-236873240411262795362044150078043963/
            12737110329362856700238976000 + (237083513*lm)/294840 + 
           (1001*lm^2)/6 - (68939330654473*Pi^2)/5189184 + 
           (234209577010227025*Im[PolyLog[2, (-1)^(1/3)]])/(167533016899248*
             Sqrt[3]) - 364*Zeta[3]) + 
         CF*NC*(521145984552111236478994605431567909/
            14010821362299142370262873600 + (2317163*lm)/180180 + 273*lm^2 + 
           (68939175939913*Pi^2)/2594592 - (234209577010227025*
             Im[PolyLog[2, (-1)^(1/3)]])/(83766508449624*Sqrt[3]) + 
           728*Zeta[3])), 
      (234639653790936430846676568921640400238504270243367*CF^2*NC)/
        595261040580258794491668994650917422080000 - 
       (777248478619*CF^2*lm*NC)/25971865920 - 21*CF^2*lm^2*NC - 
       (1233512542220471616747244848714935917531*CF*NM*NC)/
        4981168518469237943640792000000 + (2686180623739*CF*lm*NM*NC)/
        233746793280 + (7*CF*lm^2*NM*NC)/3 + (57602958668188169*CF*NC*NL)/
        132233900198400 + (2686180623739*CF*lm*NC*NL)/233746793280 + 
       (7*CF*lm^2*NC*NL)/3 + (21270677649171191663854553541857171290223*CF*
         NC*NH)/3792515141620234322384687981985600000 + 
       (2686180623739*CF*lm*NC*NH)/233746793280 + (7*CF*lm^2*NC*NH)/3 - 
       (1039608316903021131991*CF^2*NC*Pi^2)/9349871731200 - 
       (CF^2*lm*NC*Pi^2)/6 + (19345809311593*CF*NM*NC*Pi^2)/277992 + 
       (CF*lm*NM*NC*Pi^2)/54 - (68841067*CF*NC*NL*Pi^2)/9729720 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (422401360819623091*CF^2*NC*Pi^3)/(1723196745249408*Sqrt[3]) - 
       (1521964460627345*CF*NC*NH*Pi^3)/(2259436291848*Sqrt[3]) - 
       (19123*CF^2*NC*Pi^4)/4320 - (859847446362761047798499*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(905582969547195139200*Sqrt[3]) + 
       (143606963842953001*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (43494148618074*Sqrt[3]) - (841*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        2 - (422401360819623091*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(46536949138680*Sqrt[3]) - 
       (86969397750134*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (422401360819623091*CF^2*NC*Pi*Log[3]^2)/
        (2233773558656640*Sqrt[3]) - (43484698875067*CF*NC*NH*Pi*Log[3]^2)/
        (83682825624*Sqrt[3]) + CF*((-351058077112869788934553*CF*NC)/
          263106807163200 + 4238*CF*lm*NC + 
         CA*(143024962602367099092809/214383324355200 + (23309*lm)/9)*NC + 
         (4191829944585635467*NM*NC)/5019589575 - (4238*lm*NM*NC)/9 - 
         (5096*NC*NL)/9 - (4238*lm*NC*NL)/9 - (32443806464*NC*NH)/
          143416845 - (4238*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(370352194734235*CA - 740746155421878*CF + 
          240240*(1936805675*NM + 2119*NL))*Log[x]^3)/1621620 + 
       (91*CF^2*NC*PolyGamma[2, 1])/3 - (4067*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (5257*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-10665458945526651688201804820275295781965877321889/
          54114640052750799499242635877356129280000 - (77*lm^2)/6 + 
         (1039608363121396114771*Pi^2)/18699743462400 + 
         (422401360819623091*Pi^3)/(3446393490498816*Sqrt[3]) + 
         (713*Pi^4)/320 + lm*(-3380337767419/42499416960 - (11*Pi^2)/108) + 
         (859847446362761047798499*Im[PolyLog[2, (-1)^(1/3)]])/
          (1811165939094390278400*Sqrt[3]) + 
         (841*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (422401360819623091*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (93073898277360*Sqrt[3]) + (422401360819623091*Pi*Log[3]^2)/
          (4467547117313280*Sqrt[3]) - (91*PolyGamma[2, 1])/6 - 
         (1481467052327497*Zeta[3])/12972960) + 
       (1481469966198457*CF^2*NC*Zeta[3])/6486480 - 
       (3873562927*CF*NM*NC*Zeta[3])/27 - (3655*CF*NC*NL*Zeta[3])/9 + 
       (2800*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((24711981746083502018867911811*NM*NC)/230365984013245080000 + 
         (187194713*lm*NM*NC)/1621620 + (65*lm^2*NM*NC)/2 - 
         (38728315479449*NC*NL)/89902612800 + (187194713*lm*NC*NL)/
          1621620 + (65*lm^2*NC*NL)/2 - (23104329819294099133016339732513*NC*
           NH)/4627700112797356589578584000 + (187194713*lm*NC*NH)/
          1621620 + (65*lm^2*NC*NH)/2 + (3873604421*NM*NC*Pi^2)/54 - 
         (3653*NC*NL*Pi^2)/54 + (86969397750134*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-2218255562136023993081464856742748330853/
            12352874167760410523115100224000 - (1367719*lm)/90090 - 
           (585*lm^2)/2 - (211631994802711*Pi^2)/1853280 + 
           (422401360819623091*Im[PolyLog[2, (-1)^(1/3)]])/(139610847416040*
             Sqrt[3]) - 780*Zeta[3]) + 
         CA*NC*(2218232322539791414155993186121401756107/
            24705748335520821046230200448000 - (254270813*lm)/294840 - 
           (715*lm^2)/4 + (211632118697911*Pi^2)/3706560 - 
           (422401360819623091*Im[PolyLog[2, (-1)^(1/3)]])/(279221694832080*
             Sqrt[3]) + 390*Zeta[3])), 
      (-1142750443982299836953760176619652156040366201659993*CF^2*NC)/
        1785783121740776383475006983952752266240000 + 
       (806400573019*CF^2*lm*NC)/25971865920 + (87*CF^2*lm^2*NC)/4 + 
       (23586352529442578043430265488900934339521*CF*NM*NC)/
        21585063580033364422443432000000 - (2783508866179*CF*lm*NM*NC)/
        233746793280 - (29*CF*lm^2*NM*NC)/12 - 
       (5149264482423512107*CF*NC*NL)/10529124303297600 - 
       (2783508866179*CF*lm*NC*NL)/233746793280 - (29*CF*lm^2*NC*NL)/12 - 
       (1282691269539310458641099237740717794921520498309*CF*NC*NH)/
        203952912194691848229451542199786190472000000 - 
       (2783508866179*CF*lm*NC*NH)/233746793280 - (29*CF*lm^2*NC*NH)/12 + 
       (823397435912481134609*CF^2*NC*Pi^2)/4541366269440 + 
       (CF^2*lm*NC*Pi^2)/6 - (43011926895563*CF*NM*NC*Pi^2)/138996 - 
       (CF*lm*NM*NC*Pi^2)/54 + (74143507*CF*NC*NL*Pi^2)/9729720 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (4192658457496366079*CF^2*NC*Pi^3)/(15508770707244672*Sqrt[3]) + 
       (3867020149944385*CF*NC*NH*Pi^3)/(5083731656658*Sqrt[3]) + 
       (4123*CF^2*NC*Pi^4)/864 + (2572606917316653170012357*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2716748908641585417600*Sqrt[3]) - 
       (47264847547946426018*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12722038470786645*Sqrt[3]) + (901*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 + (4192658457496366079*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(418832542248120*Sqrt[3]) + 
       (883890319987288*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31381059609*Sqrt[3]) + (4192658457496366079*CF^2*NC*Pi*Log[3]^2)/
        (20103962027909760*Sqrt[3]) + (110486289998411*CF*NC*NH*Pi*Log[3]^2)/
        (188286357654*Sqrt[3]) + CF*((6296947152198711393058903*CF*NC)/
          2894174878795200 + CA*(-6296986271139049609368863/
            5788349757590400 - (25949*lm)/9)*NC - 4718*CF*lm*NC - 
         (74558290761510526433*NM*NC)/20078358300 + (4718*lm*NM*NC)/9 + 
         (1883*NC*NL)/3 + (4718*lm*NC*NL)/9 + (445866439234379*NC*NH)/
          1746817172100 + (4718*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-601730450831291*CA + 10*(120350877404489*CF - 
            24024*(8552161634*NM + 2359*NL)))*Log[x]^3)/1621620 - 
       (145*CF^2*NC*PolyGamma[2, 1])/6 + (8875*CF*NM*NC*PolyGamma[2, 1])/
        54 + (5698*CF*NC*NH*PolyGamma[2, 1])/27 - 
       (185153036553169*CF^2*NC*Zeta[3])/498960 + 
       (17104269205*CF*NM*NC*Zeta[3])/27 + (4090*CF*NC*NL*Zeta[3])/9 - 
       (3716*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (1142751879275139297650360784330665574879938233713391/
          3571566243481552766950013967905504532480000 + (319*lm^2)/24 - 
         (9687028948838370821*Pi^2)/106855676928 - (4192658457496366079*Pi^3)/
          (31017541414489344*Sqrt[3]) - (20743*Pi^4)/8640 + 
         lm*(3502457336419/42499416960 + (11*Pi^2)/108) - 
         (2572606917316653170012357*Im[PolyLog[2, (-1)^(1/3)]])/
          (5433497817283170835200*Sqrt[3]) - 
         (901*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (4192658457496366079*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (837665084496240*Sqrt[3]) - (4192658457496366079*Pi*Log[3]^2)/
          (40207924055819520*Sqrt[3]) + (145*PolyGamma[2, 1])/12 + 
         (185152789956049*Zeta[3])/997920) + 
       CF*Log[x]*((-420229335967972409836218220121*NM*NC)/
          806280944046357780000 - (201712073*lm*NM*NC)/1621620 - 
         35*lm^2*NM*NC + (71864974104559*NC*NL)/146091745800 - 
         (201712073*lm*NC*NL)/1621620 - 35*lm^2*NC*NL + 
         (493153174955564581904605234815043957*NC*NH)/
          87567655384407980066300755740000 - (201712073*lm*NC*NH)/1621620 - 
         35*lm^2*NC*NH - (8552157868*NM*NC*Pi^2)/27 + (2044*NC*NL*Pi^2)/
          27 - (883890319987288*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CA*NC*
          (-34080179159899626076215866882267104641913/
            222351735019687389416071804032000 + (273947873*lm)/294840 + 
           (385*lm^2)/2 - (185149209881089*Pi^2)/1995840 + 
           (4192658457496366079*Im[PolyLog[2, (-1)^(1/3)]])/
            (2512995253488720*Sqrt[3]) - 420*Zeta[3]) + 
         CF*NC*(34080402649566316127389636767354253499977/
            111175867509843694708035902016000 + (3063623*lm)/180180 + 
           315*lm^2 + (185149135961089*Pi^2)/997920 - 
           (4192658457496366079*Im[PolyLog[2, (-1)^(1/3)]])/
            (1256497626744360*Sqrt[3]) + 840*Zeta[3])), 
      (98199423040705584058959808189068607886804265674386181*CF^2*NC)/
        35245719508041639147533032578014847360000000 - 
       (4177806034607*CF^2*lm*NC)/129859329600 - (45*CF^2*lm^2*NC)/2 - 
       (3532899300388467940747912923667447124996231741*CF*NM*NC)/
        2030547017520387224610323900328000000 + (14404228240607*CF*lm*NM*NC)/
        1168733966400 + (5*CF*lm^2*NM*NC)/2 + 
       (37820316882330077191*CF*NC*NL)/70194162021984000 + 
       (14404228240607*CF*lm*NC*NL)/1168733966400 + (5*CF*lm^2*NC*NL)/2 + 
       (599439169161220693490156443865865684331008632011*CF*NC*NH)/
        87408390940582220669764946657051224488000000 + 
       (14404228240607*CF*lm*NC*NH)/1168733966400 + (5*CF*lm^2*NC*NH)/2 - 
       (1080761608357372280659*CF^2*NC*Pi^2)/1358528371200 - 
       (CF^2*lm*NC*Pi^2)/6 + (2409163319371733*CF*NM*NC*Pi^2)/4864860 + 
       (CF*lm*NM*NC*Pi^2)/54 - (15853325*CF*NC*NL*Pi^2)/1945944 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (13539904870147534745*CF^2*NC*Pi^3)/(46526312121734016*Sqrt[3]) - 
       (25469551076405765*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) - 
       (7369*CF^2*NC*Pi^4)/1440 - (8295446573098639129060643*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8150246725924756252800*Sqrt[3]) + 
       (158223361792794096818*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (38166115412359935*Sqrt[3]) - (961*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 - (2707980974029506949*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(251299525348872*Sqrt[3]) - 
       (2910805837303516*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) - (2707980974029506949*CF^2*NC*Pi*Log[3]^2)/
        (12062377216745856*Sqrt[3]) - (727701459325879*CF*NC*NH*Pi*Log[3]^2)/
        (1129718145924*Sqrt[3]) + CF*((-2423609394905881414269511*CF*NC)/
          253874989368000 + 5166*CF*lm*NC + 
         CA*(660985405954014286217383/138477266928000 + 3157*lm)*NC + 
         (4448849781159605842081*NM*NC)/748635930900 - 574*lm*NM*NC - 
         (2051*NC*NL)/3 - 574*lm*NC*NL - (1481693126060177*NC*NH)/
          5240451516300 - 574*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-2623040204397891*CA + 5246134119802882*CF - 
          720720*(4543888208*NM + 861*NL))*Log[x]^3)/1621620 + 
       (65*CF^2*NC*PolyGamma[2, 1])/2 - (5038*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (2134*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-98199453726530141382775737938408046787662535013701181/
          70491439016083278295066065156029694720000000 - (55*lm^2)/4 + 
         (190722638204780655881*Pi^2)/479480601600 + 
         (13539904870147534745*Pi^3)/(93052624243468032*Sqrt[3]) + 
         (4447*Pi^4)/1728 + lm*(-18122927224607/212497084800 - 
           (11*Pi^2)/108) + (8295446573098639129060643*
           Im[PolyLog[2, (-1)^(1/3)]])/(16300493451849512505600*Sqrt[3]) + 
         (961*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (2707980974029506949*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (502599050697744*Sqrt[3]) + (2707980974029506949*Pi*Log[3]^2)/
          (24124754433491712*Sqrt[3]) - (65*PolyGamma[2, 1])/4 - 
         (2098446429682829*Zeta[3])/2594592) + 
       (2098447137574013*CF^2*NC*Zeta[3])/1297296 - 
       (27263270912*CF*NM*NC*Zeta[3])/27 - (4496*CF*NC*NL*Zeta[3])/9 + 
       448*CF*NC*NH*Zeta[3] + CF*Log[x]*
        ((381679193978657293938746676150709*NM*NC)/
          435910033249063002630000 + (43083553*lm*NM*NC)/324324 + 
         (112*lm^2*NM*NC)/3 - (35629706409071*NC*NL)/64929664800 + 
         (43083553*lm*NC*NL)/324324 + (112*lm^2*NC*NL)/3 - 
         (811549695285200566634412276943707773*NC*NH)/
          131351483076611970099451133610000 + (43083553*lm*NC*NH)/324324 + 
         (112*lm^2*NC*NH)/3 + (1514628943*NM*NC*Pi^2)/3 - 
         (749*NC*NL*Pi^2)/9 + (2910805837303516*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(-4456604345768521737999851609470411404839/
            3068895864276141738352113600000 - (705217*lm)/36036 - 336*lm^2 - 
           (2098435886510189*Pi^2)/2594592 + (2707980974029506949*
             Im[PolyLog[2, (-1)^(1/3)]])/(753898576046616*Sqrt[3]) - 
           896*Zeta[3]) + CA*NC*(637293490563038367557802062978148655367677/
            877704217182976537168704489600000 - (58493857*lm)/58968 - 
           (616*lm^2)/3 + (2098436100227693*Pi^2)/5189184 - 
           (2707980974029506949*Im[PolyLog[2, (-1)^(1/3)]])/
            (1507797152093232*Sqrt[3]) + 448*Zeta[3])), 
      (-1016183285303609762783967963800686619943261871863758251*CF^2*NC)/
        223222890217597047934375872994094033280000000 + 
       (4323609204119*CF^2*lm*NC)/129859329600 + (93*CF^2*lm^2*NC)/4 + 
       (4527640988099915862955967338392086031949613*CF*NM*NC)/
        582796716660900839405972664000000 - (14890912150319*CF*lm*NM*NC)/
        1168733966400 - (31*CF*lm^2*NM*NC)/12 - 
       (18050351609602458733*CF*NC*NL)/30083212295136000 - 
       (14890912150319*CF*lm*NC*NL)/1168733966400 - (31*CF*lm^2*NC*NL)/12 - 
       (417316578188229669510406650120129527461922332619832829*CF*NC*NH)/
        54683650864728583655432318043064473603162168000000 - 
       (14890912150319*CF*lm*NC*NH)/1168733966400 - (31*CF*lm^2*NC*NH)/12 + 
       (207454922377868554718111*CF^2*NC*Pi^2)/158947819430400 + 
       (CF^2*lm*NC*Pi^2)/6 - (902494001848808*CF*NM*NC*Pi^2)/405405 - 
       (CF*lm*NM*NC*Pi^2)/54 + (84930283*CF*NC*NL*Pi^2)/9729720 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (4942738338319149595*CF^2*NC*Pi^3)/(15508770707244672*Sqrt[3]) + 
       (85554583483073495*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) + 
       (23707*CF^2*NC*Pi^4)/4320 + (548834030360644360191149*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(543349781728317083520*Sqrt[3]) - 
       (530317353946853853227*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (114498346237079805*Sqrt[3]) + 
       (1025*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (988547667663829919*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (83766508449624*Sqrt[3]) + (9777666683779828*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (988547667663829919*CF^2*NC*Pi*Log[3]^2)/(4020792405581952*Sqrt[3]) + 
       (2444416670944957*CF*NC*NH*Pi*Log[3]^2)/(3389154437772*Sqrt[3]) + 
       CF*((20604054196342409832428789*CF*NC)/1315534035816000 + 
         CA*(-75548277680566092855513173/9647249595984000 - (31405*lm)/9)*
          NC - 5710*CF*lm*NC - (689618848008968202799*NM*NC)/25815032100 + 
         (5710*lm*NM*NC)/9 + (6775*NC*NL)/9 + (5710*lm*NC*NL)/9 + 
         (51367913239960423*NC*NH)/162453997005300 + (5710*lm*NC*NH)/9)*
        Log[x]^2 + (CF*NC*(-4289980692705303*CA + 8580022409275258*CF - 
          240240*(60935012218*NM + 2855*NL))*Log[x]^3)/1621620 - 
       (155*CF^2*NC*PolyGamma[2, 1])/6 + (608*CF*NM*NC*PolyGamma[2, 1])/3 + 
       (13825*CF*NC*NH*PolyGamma[2, 1])/54 - 
       (264000077872129*CF^2*NC*Zeta[3])/99792 + 
       (13541106644*CF*NM*NC*Zeta[3])/3 + (1664*CF*NC*NL*Zeta[3])/3 - 
       (5089*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (1016183494580315993277615095202902109484658464806347251/
          446445780435194095868751745988188066560000000 + (341*lm^2)/24 - 
         (207454923416006650753151*Pi^2)/317895638860800 - 
         (4942738338319149595*Pi^3)/(31017541414489344*Sqrt[3]) - 
         (1589*Pi^4)/576 + lm*(18733567767119/212497084800 + (11*Pi^2)/108) - 
         (548834030360644360191149*Im[PolyLog[2, (-1)^(1/3)]])/
          (1086699563456634167040*Sqrt[3]) - 
         (1025*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (988547667663829919*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (167533016899248*Sqrt[3]) - (988547667663829919*Pi*Log[3]^2)/
          (8041584811163904*Sqrt[3]) + (155*PolyGamma[2, 1])/12 + 
         (264000018285217*Zeta[3])/199584) + 
       CF*Log[x]*((-7607964804960191496397566380899*NM*NC)/
          1814132124104305005000 - (230925257*lm*NM*NC)/1621620 - 
         40*lm^2*NM*NC + (362172156494327*NC*NL)/584366983200 - 
         (230925257*lm*NC*NL)/1621620 - 40*lm^2*NC*NL + 
         (2617247849170143897150413041540787217791*NC*NH)/
          378686325709872309796717618197630000 - (230925257*lm*NC*NH)/
          1621620 - 40*lm^2*NC*NH - (60935007743*NM*NC*Pi^2)/27 + 
         (2495*NC*NL*Pi^2)/27 - (9777666683779828*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(-40591669815498053448663568306228504610693/
            32892268494036596067466243200000 + (313480457*lm)/294840 + 
           220*lm^2 - (263999147474353*Pi^2)/399168 + 
           (988547667663829919*Im[PolyLog[2, (-1)^(1/3)]])/(502599050697744*
             Sqrt[3]) - 480*Zeta[3]) + 
         CF*NC*(6859998462911442275333352927128883402883817/
            2779396687746092367700897550400000 + (3898457*lm)/180180 + 
           360*lm^2 + (263999129378737*Pi^2)/199584 - 
           (988547667663829919*Im[PolyLog[2, (-1)^(1/3)]])/(251299525348872*
             Sqrt[3]) + 960*Zeta[3])), 
      (2899948169170174486094979953365589248201296206220160172081*CF^2*NC)/
        144648432861002887061475565700172933565440000000 - 
       (35755578547327*CF^2*lm*NC)/1038874636800 - 24*CF^2*lm^2*NC - 
       (291082019353641514991006918360347338960255880230071*CF*NM*NC)/
        23362437704422013277713827045666214400000 + 
       (123021048038527*CF*lm*NM*NC)/9349871731200 + (8*CF*lm^2*NM*NC)/3 + 
       (1107286164055381485143*CF*NC*NL)/1684659888527616000 + 
       (123021048038527*CF*lm*NC*NL)/9349871731200 + (8*CF*lm^2*NC*NL)/3 + 
       (1812008175830711817127485744191189665934682671986169431*CF*NC*NH)/
        218734603458914334621729272172257894412648672000000 + 
       (123021048038527*CF*lm*NC*NH)/9349871731200 + (8*CF*lm^2*NC*NH)/3 - 
       (3679616600931935669999641*CF^2*NC*Pi^2)/635791277721600 - 
       (CF^2*lm*NC*Pi^2)/6 + (23266951775694103*CF*NM*NC*Pi^2)/6486480 + 
       (CF*lm*NM*NC*Pi^2)/54 - (361658047*CF*NC*NL*Pi^2)/38918880 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (78002293288843286245*CF^2*NC*Pi^3)/(228401895870330624*Sqrt[3]) - 
       (186859046399013415*CF*NC*NH*Pi^3)/(183014339639688*Sqrt[3]) - 
       (25307*CF^2*NC*Pi^4)/4320 - (86458121406818390356222721*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(80020604218170334118400*Sqrt[3]) + 
       (106830675972852255659*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (20817881134014510*Sqrt[3]) - 
       (1089*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (15600458657768657249*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1233652215349008*Sqrt[3]) - (10677659794229338*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (15600458657768657249*CF^2*NC*Pi*Log[3]^2)/(59215306336752384*
         Sqrt[3]) - (5338829897114669*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((-669996924858946604146280587*CF*NC)/
          9647249595984000 + 6220*CF*lm*NC + 
         CA*(2009991291002861970194595691/57883497575904000 + (34210*lm)/9)*
          NC + (96450400675115938816711*NM*NC)/2240744786280 - 
         (6220*lm*NM*NC)/9 - (7345*NC*NL)/9 - (6220*lm*NC*NL)/9 - 
         (56539921766218873*NC*NH)/162453997005300 - (6220*lm*NC*NH)/9)*
        Log[x]^2 - (CF*NC*(-37841000955522591*CA + 75682137990742436*CF - 
          960960*(48921316127*NM + 1555*NL))*Log[x]^3)/3243240 + 
       (104*CF^2*NC*PolyGamma[2, 1])/3 - (2051*CF*NM*NC*PolyGamma[2, 1])/9 - 
       (7703*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-2899948315604049450535969508810019017034637749935639669081/
          289296865722005774122951131400345867130880000000 - (44*lm^2)/3 + 
         (3679616605452998546890201*Pi^2)/1271582555443200 + 
         (78002293288843286245*Pi^3)/(456803791740661248*Sqrt[3]) + 
         (5087*Pi^4)/1728 + lm*(-154753946035327/1699976678400 - 
           (11*Pi^2)/108) + (86458121406818390356222721*
           Im[PolyLog[2, (-1)^(1/3)]])/(160041208436340668236800*Sqrt[3]) + 
         (1089*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (15600458657768657249*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2467304430698016*Sqrt[3]) + (15600458657768657249*Pi*Log[3]^2)/
          (118430612673504768*Sqrt[3]) - (52*PolyGamma[2, 1])/3 - 
         (50454725423436443*Zeta[3])/8648640) + 
       (50454728257787963*CF^2*NC*Zeta[3])/4324320 - 
       (65228398345*CF*NM*NC*Zeta[3])/9 - (1819*CF*NC*NL*Zeta[3])/3 + 
       612*CF*NC*NH*Zeta[3] + CF*Log[x]*
        ((567918080175161752180587011477939417*NM*NC)/
          80892877066660601894952000 + (982484753*lm*NM*NC)/6486480 + 
         (85*lm^2*NM*NC)/2 - (100236164825813*NC*NL)/146091745800 + 
         (982484753*lm*NC*NL)/6486480 + (85*lm^2*NC*NL)/2 - 
         (5713324807151367830334966998295484542637*NC*NH)/
          757372651419744619593435236395260000 + (982484753*lm*NC*NH)/
          6486480 + (85*lm^2*NC*NH)/2 + (195685254733*NM*NC*Pi^2)/54 - 
         (5455*NC*NL*Pi^2)/54 + (10677659794229338*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(-10439018240582334141383464011333399259501475501/
            900524526829733927135090806329600000 - (17620853*lm)/720720 - 
           (765*lm^2)/2 - (16818227652707851*Pi^2)/2882880 + 
           (15600458657768657249*Im[PolyLog[2, (-1)^(1/3)]])/
            (3700956646047024*Sqrt[3]) - 1020*Zeta[3]) + 
         CA*NC*(5219508054234053260930548679979781849557370163/
            900524526829733927135090806329600000 - (1333344353*lm)/1179360 - 
           (935*lm^2)/4 + (16818227941316171*Pi^2)/5765760 - 
           (15600458657768657249*Im[PolyLog[2, (-1)^(1/3)]])/
            (7401913292094048*Sqrt[3]) + 510*Zeta[3])), 
      (-1588472098338599894398589694361718144791765053206138296963*CF^2*NC)/
        48216144287000962353825188566724311188480000000 + 
       (18461141730851*CF^2*lm*NC)/519437318400 + (99*CF^2*lm^2*NC)/4 + 
       (53687849340283164491986998533954787257206825231*CF*NM*NC)/
        955551537656652811581328894272000000 - (63457399437251*CF*lm*NM*NC)/
        4674935865600 - (11*CF*lm^2*NM*NC)/4 - 
       (122442948271470634037*CF*NC*NL)/168465988852761600 - 
       (63457399437251*CF*lm*NC*NL)/4674935865600 - (11*CF*lm^2*NC*NL)/4 - 
       (61628453790202408705020481951561765714497705203998669*CF*NC*NH)/
        6730295491043517988360900682223319828081497600000 - 
       (63457399437251*CF*lm*NC*NH)/4674935865600 - (11*CF*lm^2*NC*NH)/4 + 
       (12813290017890977519098561*CF^2*NC*Pi^2)/1342226030745600 + 
       (CF^2*lm*NC*Pi^2)/6 - (52772204796916907*CF*NM*NC*Pi^2)/3243240 - 
       (CF*lm*NM*NC*Pi^2)/54 + (192878561*CF*NC*NL*Pi^2)/19459440 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (23947503777228618325*CF^2*NC*Pi^3)/(64421047553170176*Sqrt[3]) + 
       (25960476471583360*CF*NC*NH*Pi^3)/(22876792454961*Sqrt[3]) + 
       (1801*CF^2*NC*Pi^4)/288 + (24084932535279778560288497*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22569914010253171161600*Sqrt[3]) - 
       (652274627920398965024*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (114498346237079805*Sqrt[3]) + 
       (1157*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (4789500755445723665*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (347953188944592*Sqrt[3]) + (11867646387009536*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (4789500755445723665*CF^2*NC*Pi*Log[3]^2)/(16701753069340416*
         Sqrt[3]) + (741727899188096*CF*NC*NH*Pi*Log[3]^2)/
        (847288609443*Sqrt[3]) + CF*((135324041554370706249309527*CF*NC)/
          1181295868896000 + CA*(-6630879170520756243580649983/
            115766995151808000 - (37576*lm)/9)*NC - 6832*CF*lm*NC - 
         (10943707866598562434363*NM*NC)/56047609800 + (6832*lm*NM*NC)/9 + 
         (2680*NC*NL)/3 + (6832*lm*NC*NL)/9 + (25099108948399159*NC*NH)/
          64981598802120 + (6832*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-15561930862859407*CA + 5*(6224780015952083*CF - 
            48048*(220895861783*NM + 1708*NL)))*Log[x]^3)/810810 - 
       (55*CF^2*NC*PolyGamma[2, 1])/2 + (493*CF*NM*NC*PolyGamma[2, 1])/2 + 
       (8288*CF*NC*NH*PolyGamma[2, 1])/27 - 
       (35570155942529341*CF^2*NC*Zeta[3])/1853280 + 
       (98175930073*CF*NM*NC*Zeta[3])/3 + (2006*CF*NC*NL*Zeta[3])/3 - 
       (6716*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (1588472150757641658530803051851971463187991419726045135963/
          96432288574001924707650377133448622376960000000 + (121*lm^2)/8 - 
         (2023151057086422863681297*Pi^2)/423860851814400 - 
         (23947503777228618325*Pi^3)/(128842095106340352*Sqrt[3]) - 
         (27143*Pi^4)/8640 + lm*(79819674966851/849988339200 + 
           (11*Pi^2)/108) - (24084932535279778560288497*
           Im[PolyLog[2, (-1)^(1/3)]])/(45139828020506342323200*Sqrt[3]) - 
         (1157*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (4789500755445723665*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (695906377889184*Sqrt[3]) - (4789500755445723665*Pi*Log[3]^2)/
          (33403506138680832*Sqrt[3]) + (55*PolyGamma[2, 1])/4 + 
         (35570154619699261*Zeta[3])/3706560) + 
       CF*Log[x]*((-47968551802644348258938602079756033*NM*NC)/
          1435938933055736949840000 - (524237839*lm*NM*NC)/3243240 - 
         (136*lm^2*NM*NC)/3 + (12818724704389*NC*NL)/16696199520 - 
         (524237839*lm*NC*NL)/3243240 - (136*lm^2*NC*NL)/3 + 
         (5075793407198257952590445894728960542673*NC*NH)/
          605898121135795695674748189116208000 - (524237839*lm*NC*NH)/
          3243240 - (136*lm^2*NC*NH)/3 - (441791718302*NM*NC*Pi^2)/27 + 
         (3008*NC*NL*Pi^2)/27 - (11867646387009536*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(-11809205264316088042062428507349112084740317771/
            1200699369106311902846787741772800000 + (711362959*lm)/589680 + 
           (748*lm^2)/3 - (35570135181194461*Pi^2)/7413120 + 
           (4789500755445723665*Im[PolyLog[2, (-1)^(1/3)]])/
            (2087719133667552*Sqrt[3]) - 544*Zeta[3]) + 
         CF*NC*(11809206767086750618569789579708755757245063471/
            600349684553155951423393870886400000 + (9643759*lm)/360360 + 
           408*lm^2 + (35570134775120221*Pi^2)/3706560 - 
           (4789500755445723665*Im[PolyLog[2, (-1)^(1/3)]])/
            (1043859566833776*Sqrt[3]) + 1088*Zeta[3])), 
      (7188762891095057908824703068415052548417664723653534803233452409*CF^2*
         NC)/49068916931290082738088738044982927685391815680000000 - 
       (5503892299701539*CF^2*lm*NC)/150117385017600 - (51*CF^2*lm^2*NC)/2 - 
       (307214826021379264860099024115691428188556213488293039*CF*NM*NC)/
        3387553467141191925268504921621601088000000 + 
       (18901868912522339*CF*lm*NM*NC)/1351056465158400 + 
       (17*CF*lm^2*NM*NC)/6 + (27547004477484702906961*CF*NC*NL)/
        34776193413177216000 + (18901868912522339*CF*lm*NC*NL)/
        1351056465158400 + (17*CF*lm^2*NC*NL)/6 + 
       (12992116400267966058838797734618082105810572753682634289*CF*NC*NH)/
        1312407620753486007730375633033547366475892032000000 + 
       (18901868912522339*CF*lm*NC*NH)/1351056465158400 + 
       (17*CF*lm^2*NC*NH)/6 - (8771252330516730734176975573*CF^2*NC*Pi^2)/
        205360582704076800 - (CF^2*lm*NC*Pi^2)/6 + 
       (41552816818722683*CF*NM*NC*Pi^2)/1575288 + (CF*lm*NM*NC*Pi^2)/54 - 
       (3477674077*CF*NC*NL*Pi^2)/330810480 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (152502604657746215596535*CF^2*NC*Pi^3)/
        (384400390749766440192*Sqrt[3]) - (84656271961756250*CF*NC*NH*Pi^3)/
        (68630377364883*Sqrt[3]) - (28723*CF^2*NC*Pi^4)/4320 - 
       (74345131812624528033753626089*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (65413414493887755127472640*Sqrt[3]) + 
       (430926631138821585721*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (68699007742247883*Sqrt[3]) - 
       (1225*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (4357217275935606159901*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (296605239776054352*Sqrt[3]) - (38700010039660000*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (4357217275935606159901*CF^2*NC*Pi*Log[3]^2)/(14237051509250608896*
         Sqrt[3]) - (2418750627478750*CF*NC*NH*Pi*Log[3]^2)/
        (2541865828329*Sqrt[3]) + 
       CF*((-14626063505515333001310330085207*CF*NC)/28536564304920672000 + 
         7408*CF*lm*NC + CA*(4875354704085182251152086971429/
            19024376203280448000 + (40744*lm)/9)*NC + 
         (9349523138137809277879541*NM*NC)/29537090364600 - 
         (7408*lm*NM*NC)/9 - (8680*NC*NL)/9 - (7408*lm*NC*NL)/9 - 
         (19622029646840987*NC*NH)/46415427715800 - (7408*lm*NC*NH)/9)*
        Log[x]^2 + (CF*NC*(1178293982383651255*CA - 
          561*(4200692847920207*CF - 7280*(356999843519*NM + 1852*NL)))*
         Log[x]^3)/13783770 + (221*CF^2*NC*PolyGamma[2, 1])/6 - 
       (2474*CF*NM*NC*PolyGamma[2, 1])/9 - (9170*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*
        (-79076392433804193981301434976149974450837158535630263717558995499/
          1079516172488381820237952236989624409078619944960000000 - 
         (187*lm^2)/12 + (461644859590681575314267767*Pi^2)/
          21616903442534400 + (152502604657746215596535*Pi^3)/
          (768800781499532880384*Sqrt[3]) + (9617*Pi^4)/2880 + 
         lm*(-23773860408093539/245646630028800 - (11*Pi^2)/108) + 
         (74345131812624528033753626089*Im[PolyLog[2, (-1)^(1/3)]])/
          (130826828987775510254945280*Sqrt[3]) + 
         (1225*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (4357217275935606159901*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (593210479552108704*Sqrt[3]) + (4357217275935606159901*Pi*Log[3]^2)/
          (28474103018501217792*Sqrt[3]) - (221*PolyGamma[2, 1])/12 - 
         (3770541444537793139*Zeta[3])/88216128) + 
       (3770541478917578579*CF^2*NC*Zeta[3])/44108064 - 
       (475999764058*CF*NM*NC*Zeta[3])/9 - (2182*CF*NC*NL*Zeta[3])/3 + 
       (2416*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((1310564239514711093938593847532425865881*NM*NC)/
          23458934349331574549536080000 + (9445376063*lm*NM*NC)/55135080 + 
         48*lm^2*NM*NC - (8388138493848013*NC*NL)/9934238714400 + 
         (9445376063*lm*NC*NL)/55135080 + 48*lm^2*NC*NL - 
         (82720880049205771462594720783436471422681*NC*NH)/
          9088471817036935435121222836743120000 + (9445376063*lm*NC*NH)/
          55135080 + 48*lm^2*NC*NH + (713999681318*NM*NC*Pi^2)/27 - 
         (3272*NC*NL*Pi^2)/27 + (38700010039660000*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(-21331848221922321695908972075402564800537952647324877/
            231746384881524707212507078645697241600000 - (182682623*lm)/
            6126120 - 432*lm^2 - (3770540926885361843*Pi^2)/88216128 + 
           (4357217275935606159901*Im[PolyLog[2, (-1)^(1/3)]])/
            (889815719328163056*Sqrt[3]) - 1152*Zeta[3]) + 
         CA*NC*(21331847614921065265438917364162092767471396881128577/
            463492769763049414425014157291394483200000 - (12813628223*lm)/
            10024560 - 264*lm^2 + (3770540937490900787*Pi^2)/176432256 - 
           (4357217275935606159901*Im[PolyLog[2, (-1)^(1/3)]])/
            (1779631438656326112*Sqrt[3]) + 576*Zeta[3])), 
      (-26121390387560935083362051419724099419437632863482759339375548977*
         CF^2*NC)/107951617248838182023795223698962440907861994496000000 + 
       (5672514639187139*CF^2*lm*NC)/150117385017600 + (105*CF^2*lm^2*NC)/4 + 
       (1396981963566447748306513293333710186263574224054039601*CF*NM*NC)/
        3387553467141191925268504921621601088000000 - 
       (19464549387679139*CF*lm*NM*NC)/1351056465158400 - 
       (35*CF*lm^2*NM*NC)/12 - (60545968025371025974487*CF*NC*NL)/
        69552386826354432000 - (19464549387679139*CF*lm*NC*NL)/
        1351056465158400 - (35*CF*lm^2*NC*NL)/12 - 
       (385456892974155040135937293665370322286567556696821537103*CF*NC*NH)/
        35435005760344122208720142091905778894849084864000000 - 
       (19464549387679139*CF*lm*NC*NH)/1351056465158400 - 
       (35*CF*lm^2*NC*NH)/12 + (14537502626220966877175502437*CF^2*NC*Pi^2)/
        205360582704076800 + (CF^2*lm*NC*Pi^2)/6 - 
       (1108002216099866767*CF*NM*NC*Pi^2)/9189180 - 
       (CF*lm*NM*NC*Pi^2)/54 + (3694790977*CF*NC*NL*Pi^2)/330810480 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (165112611685312591980895*CF^2*NC*Pi^3)/(384400390749766440192*
         Sqrt[3]) + (10096002065759493205*CF*NC*NH*Pi^3)/
        (7412080755407364*Sqrt[3]) + (30539*CF^2*NC*Pi^4)/4320 + 
       (2557810449894517813646472403123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2289469507286071429461542400*Sqrt[3]) - 
       (128423670244801377146171*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (18548732090406928410*Sqrt[3]) + 
       (1297*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (33022522337062518396179*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2076236678432380464*
         Sqrt[3]) + (1153828807515370652*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) + 
       (33022522337062518396179*CF^2*NC*Pi*Log[3]^2)/(99659360564754262272*
         Sqrt[3]) + (288457201878842663*CF*NC*NH*Pi*Log[3]^2)/
        (274521509459532*Sqrt[3]) + 
       CF*((1616085726362479124474342117009*CF*NC)/1902437620328044800 + 
         CA*(-440750664693197782164035624273/1037693247451660800 - 
           (44506*lm)/9)*NC - 8092*CF*lm*NC - (470116520156357005170881179*
           NM*NC)/324907994010600 + (8092*lm*NM*NC)/9 + (9452*NC*NL)/9 + 
         (8092*lm*NC*NL)/9 + (151419196966350479*NC*NH)/324907994010600 + 
         (8092*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-1948209222611476607*CA + 13*(299724558052243127*CF - 
            314160*(1625595185981*NM + 2023*NL)))*Log[x]^3)/13783770 - 
       (175*CF^2*NC*PolyGamma[2, 1])/6 + (2666*CF*NM*NC*PolyGamma[2, 1])/9 + 
       (19669*CF*NC*NH*PolyGamma[2, 1])/54 - 
       (31171351560684115279*CF^2*NC*Zeta[3])/220540320 + 
       (2167460218096*CF*NM*NC*Zeta[3])/9 + (2392*CF*NC*NL*Zeta[3])/3 - 
       (8617*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (26121390522903279342624006462151278245800528163368377173010283777/
          215903234497676364047590447397924881815723988992000000 + 
         (385*lm^2)/24 - (14537502628054062270721398917*Pi^2)/
          410721165408153600 - (165112611685312591980895*Pi^3)/
          (768800781499532880384*Sqrt[3]) - (30667*Pi^4)/8640 + 
         lm*(24479834750767139/245646630028800 + (11*Pi^2)/108) - 
         (2557810449894517813646472403123*Im[PolyLog[2, (-1)^(1/3)]])/
          (4578939014572142858923084800*Sqrt[3]) - 
         (1297*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (33022522337062518396179*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4152473356864760928*Sqrt[3]) - (33022522337062518396179*Pi*
           Log[3]^2)/(199318721129508524544*Sqrt[3]) + (175*PolyGamma[2, 1])/
          12 + (31171351374303040399*Zeta[3])/441080640) + 
       CF*Log[x]*((-1554680105295199482018907953335593558051*NM*NC)/
          5864733587332893637384020000 - (10039970063*lm*NM*NC)/55135080 - 
         51*lm^2*NM*NC + (37247919340812067*NC*NL)/39736954857600 - 
         (10039970063*lm*NC*NL)/55135080 - 51*lm^2*NC*NL + 
         (616119744989826218539503183949682548085903*NC*NH)/
          61347184764999314187068254148016060000 - (10039970063*lm*NC*NH)/
          55135080 - 51*lm^2*NC*NH - (3251190365825*NM*NC*Pi^2)/27 + 
         (3587*NC*NL*Pi^2)/27 - (1153828807515370652*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CA*NC*(-556786294665760876312055097443405885407738405214917/
            7130657996354606375769448573713761280000 + (13618737983*lm)/
            10024560 + (561*lm^2)/2 - (31171348622833839919*Pi^2)/882161280 + 
           (33022522337062518396179*Im[PolyLog[2, (-1)^(1/3)]])/
            (12457420070594282784*Sqrt[3]) - 612*Zeta[3]) + 
         CF*NC*(7238221958439118353798403371474096312890653488858781/
            46349276976304941442501415729139448320000 + (198358283*lm)/
            6126120 + 459*lm^2 + (31171348565101285039*Pi^2)/441080640 - 
           (33022522337062518396179*Im[PolyLog[2, (-1)^(1/3)]])/
            (6228710035297141392*Sqrt[3]) + 1224*Zeta[3])), 
      (4710867984335877590958500323891868052209031072665956949132596395473949\
47*CF^2*NC)/434158194977118667890569273744131660406625751534095360000000 - 
       (216339445729657*CF^2*lm*NC)/5559903148800 - 27*CF^2*lm^2*NC - 
       (26068081057648555640821903069197511655022702443008433*CF*NM*NC)/
        38937396174036688796189711742777024000000 + 
       (741750293291257*CF*lm*NM*NC)/50039128339200 + 3*CF*lm^2*NM*NC + 
       (131371116671305073364119*CF*NC*NL)/139104773652708864000 + 
       (741750293291257*CF*lm*NC*NL)/50039128339200 + 3*CF*lm^2*NC*NL + 
       (120536134896589705114665584652193106819923608520873968163*CF*NC*NH)/
        10287582317519261286402621897650064840440056896000000 + 
       (741750293291257*CF*lm*NC*NH)/50039128339200 + 3*CF*lm^2*NC*NH - 
       (5041999953614246991386257097*CF^2*NC*Pi^2)/15796967900313600 - 
       (CF^2*lm*NC*Pi^2)/6 + (394037727034766515*CF*NM*NC*Pi^2)/2004912 + 
       (CF*lm*NM*NC*Pi^2)/54 - (3905801777*CF*NC*NL*Pi^2)/330810480 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (4740690212290087585879045*CF^2*NC*Pi^3)/(10378810550243693885184*
         Sqrt[3]) - (196713007774326958775*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) - (719*CF^2*NC*Pi^4)/96 - 
       (73269070621151255976402550485577*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (61815676696723928595461644800*Sqrt[3]) + 
       (506273261864870968160117*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (66775435525464942276*Sqrt[3]) - 
       (1369*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (948138042458017517175809*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(56058390317674272528*
         Sqrt[3]) - (11240743301390111930*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (948138042458017517175809*CF^2*NC*Pi*Log[3]^2)/(2690802735248365081344*
         Sqrt[3]) - (5620371650695055965*CF*NC*NH*Pi*Log[3]^2)/
        (4941387170271576*Sqrt[3]) + 
       CF*((-10164709748494647700929708265221659*CF*NC)/
          2653900480357622496000 + 8738*CF*lm*NC + 
         CA*(207443057450583922656089578676651/108322468586025408000 + 
           (48059*lm)/9)*NC + (366989499585841635206383*NM*NC)/
          155607276825 - (8738*lm*NM*NC)/9 - (10166*NC*NL)/9 - 
         (8738*lm*NC*NL)/9 - (221635774688044*NC*NH)/436704293025 - 
         (8738*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(8750105114097818914*CA + 35*(-500006032032507365*CF + 
            58344*(5284888014266*NM + 4369*NL)))*Log[x]^3)/13783770 + 
       39*CF^2*NC*PolyGamma[2, 1] - (8855*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (10813*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-47108679901796649846529567486514253593666638828241994500249\
2090852535447/868316389954237335781138547488263320813251503068190720000000 - 
         (33*lm^2)/2 + (5041999953765603784337356217*Pi^2)/
          31593935800627200 + (4740690212290087585879045*Pi^3)/
          (20757621100487387770368*Sqrt[3]) + (32483*Pi^4)/8640 + 
         lm*(-932808783313657/9098023334400 - (11*Pi^2)/108) + 
         (73269070621151255976402550485577*Im[PolyLog[2, (-1)^(1/3)]])/
          (123631353393447857190923289600*Sqrt[3]) + 
         (1369*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (948138042458017517175809*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (112116780635348545056*Sqrt[3]) + (948138042458017517175809*Pi*
           Log[3]^2)/(5381605470496730162688*Sqrt[3]) - (39*PolyGamma[2, 1])/
          2 - (46667228657915030141*Zeta[3])/147026880) + 
       (46667228725441208861*CF^2*NC*Zeta[3])/73513440 - 
       (10569775932841*CF*NM*NC*Zeta[3])/27 - (7771*CF*NC*NL*Zeta[3])/9 + 
       (9272*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((239147479074853916948635522158962289389*NM*NC)/
          539285847111070679299680000 + (10606976503*lm*NM*NC)/55135080 + 
         (323*lm^2*NM*NC)/6 - (81456811795227629*NC*NL)/79473909715200 + 
         (10606976503*lm*NC*NL)/55135080 + (323*lm^2*NC*NL)/6 - 
         (1548319347790722597639943479497164466048479*NC*NH)/
          142483783970320987789319816085714720000 + (10606976503*lm*NC*NH)/
          55135080 + (323*lm^2*NC*NH)/6 + (10569776015255*NM*NC*Pi^2)/54 - 
         (7769*NC*NL*Pi^2)/54 + (11240743301390111930*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(-337650039813259273701059437521391361166550427085090797627/
            462547957578532429080224705355377409830400000 - 
           (218608513*lm)/6126120 - (969*lm^2)/2 - 
           (140001682910740906183*Pi^2)/441080640 + 
           (948138042458017517175809*Im[PolyLog[2, (-1)^(1/3)]])/
            (168175170953022817584*Sqrt[3]) - 1292*Zeta[3]) + 
         CA*NC*(4389450500287281583817712421671378433203950909557654391051/
            12026246897041843156085842339239812655590400000 - 
           (14384564863*lm)/10024560 - (3553*lm^2)/12 + 
           (140001682973750092423*Pi^2)/882161280 - 
           (948138042458017517175809*Im[PolyLog[2, (-1)^(1/3)]])/
            (336350341906045635168*Sqrt[3]) + 646*Zeta[3])), 
      (-781627330883681563140125296908057381063056012966132079288006189533571\
949*CF^2*NC)/434158194977118667890569273744131660406625751534095360000000 + 
       (6009815430214339*CF^2*lm*NC)/150117385017600 + (111*CF^2*lm^2*NC)/4 + 
       (17168060900234494467607515276197028240393227748524261*CF*NM*NC)/
        5599261929158994917799181688630745600000 - 
       (20589966450048739*CF*lm*NM*NC)/1351056465158400 - 
       (37*CF*lm^2*NM*NC)/12 - (474613531525830679696547*CF*NC*NL)/
        459818557352009856000 - (20589966450048739*CF*lm*NC*NL)/
        1351056465158400 - (37*CF*lm^2*NC*NL)/12 - 
       (206884350634226212116264220894240050337202778977586417888034099*CF*NC*
         NH)/16154004121008397400144712216431730765247116260545728000000 - 
       (20589966450048739*CF*lm*NC*NH)/1351056465158400 - 
       (37*CF*lm^2*NC*NH)/12 + (5195404395877605965758267909*CF^2*NC*Pi^2)/
        9779075366860800 + (CF^2*lm*NC*Pi^2)/6 - 
       (49858950881888828431*CF*NM*NC*Pi^2)/55135080 - 
       (CF*lm*NM*NC*Pi^2)/54 + (1378396979*CF*NC*NL*Pi^2)/110270160 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (300499660754138938192465*CF^2*NC*Pi^3)/(610518267661393757952*
         Sqrt[3]) + (53993466926833309295*CF*NC*NH*Pi^3)/
        (33354363399333138*Sqrt[3]) + (34279*CF^2*NC*Pi^4)/4320 + 
       (843266334733944403201026058433*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (727243255255575630534842880*Sqrt[3]) - 
       (11813263956735108685347353*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1418978004916130023365*Sqrt[3]) + 
       (1445*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (60099932150827787638493*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3297552371627898384*
         Sqrt[3]) + (12341363868990470696*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (60099932150827787638493*CF^2*NC*Pi*Log[3]^2)/(158282513838139122432*
         Sqrt[3]) + (1542670483623808837*CF*NC*NH*Pi*Log[3]^2)/
        (1235346792567894*Sqrt[3]) + 
       CF*((16919496858518976065988100078811143*CF*NC)/
          2653900480357622496000 + CA*(-2417070990126568269533574579123769/
            758257280102177856000 - (17413*lm)/3)*NC - 9498*CF*lm*NC - 
         (705158532630927356696899501*NM*NC)/64981598802120 + 
         (3166*lm*NM*NC)/3 + (3673*NC*NL)/3 + (3166*lm*NC*NL)/3 + 
         (6686484633712790497*NC*NH)/12021595778392200 + (3166*lm*NC*NH)/3)*
        Log[x]^2 + (CF*NC*(-4844557677215741179*CA + 9689115685683403317*CF - 
          2042040*(8079069085100*NM + 1583*NL))*Log[x]^3)/4594590 - 
       (185*CF^2*NC*PolyGamma[2, 1])/6 + (19019*CF*NM*NC*PolyGamma[2, 1])/
        54 + (3854*CF*NC*NH*PolyGamma[2, 1])/9 - 
       (15502584881192813773*CF^2*NC*Zeta[3])/14702688 + 
       (48474414406409*CF*NM*NC*Zeta[3])/27 + (8474*CF*NC*NL*Zeta[3])/9 - 
       (3604*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*
        (85893113352540971100921248295425026456800181047342949299211931671504\
39/9541938351145465228364159862508388140804961572177920000000 + 
         (407*lm^2)/24 - (5195404395977713271758294949*Pi^2)/
          19558150733721600 - (300499660754138938192465*Pi^3)/
          (1221036535322787515904*Sqrt[3]) - (3823*Pi^4)/960 + 
         lm*(25891839548170339/245646630028800 + (11*Pi^2)/108) - 
         (843266334733944403201026058433*Im[PolyLog[2, (-1)^(1/3)]])/
          (1454486510511151261069685760*Sqrt[3]) - 
         (1445*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (60099932150827787638493*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6595104743255796768*Sqrt[3]) - (60099932150827787638493*Pi*
           Log[3]^2)/(316565027676278244864*Sqrt[3]) + (185*PolyGamma[2, 1])/
          12 + (15502584866607747277*Zeta[3])/29405376) + 
       CF*Log[x]*((-9864907124337583620940584056278760681539*NM*NC)/
          4691786869866314909907216000 - (3745081381*lm*NM*NC)/18378360 - 
         57*lm^2*NM*NC + (95420674314558181*NC*NL)/84441029072400 - 
         (3745081381*lm*NC*NL)/18378360 - 57*lm^2*NC*NL + 
         (2120462750900797501994746000365621723991201549*NC*NH)/
          177849097291660364729145402201813147120000 - (3745081381*lm*NC*NH)/
          18378360 - 57*lm^2*NC*NH - 897674342526*NM*NC*Pi^2 + 
         (1412*NC*NL*Pi^2)/9 - (12341363868990470696*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(-7451479688531409458320993686329812139549666137472840416867/
            12026246897041843156085842339239812655590400000 + 
           (5078347861*lm)/3341520 + (627*lm^2)/2 - 
           (15502584650450461933*Pi^2)/58810752 + (60099932150827787638493*
             Im[PolyLog[2, (-1)^(1/3)]])/(19785314229767390304*Sqrt[3]) - 
           684*Zeta[3]) + CF*NC*
          (7451479706653669955046773930547764710408677163498558908967/
            6013123448520921578042921169619906327795200000 + 
           (78598561*lm)/2042040 + 513*lm^2 + (5167528215299358031*Pi^2)/
            9801792 - (60099932150827787638493*Im[PolyLog[2, (-1)^(1/3)]])/
            (9892657114883695152*Sqrt[3]) + 1368*Zeta[3])), 
      (2874820891058381194474699857436742583385253172073684743022349064085003\
6901*CF^2*NC)/3535288159099394867108921229059357806168238262491919360000000 - 
       (2230434734605140379*CF^2*lm*NC)/54192375991353600 - 
       (57*CF^2*lm^2*NC)/2 - 
       (174754904899462910290348492054504311823042301553525793289*CF*NM*NC)/
        34925655560981639444458697291858123328000000 + 
       (7636124239742661979*CF*lm*NM*NC)/487731383922182400 + 
       (19*CF*lm^2*NM*NC)/6 + (370230456334681799553547003*CF*NC*NL)/
        331988998408151116032000 + (7636124239742661979*CF*lm*NC*NL)/
        487731383922182400 + (19*CF*lm^2*NC*NL)/6 + 
       (448667054393827256549725958425645431278738562451553176339283*CF*NC*
         NH)/32634351759612924040696388316023698515650739920294400000 + 
       (7636124239742661979*CF*lm*NC*NH)/487731383922182400 + 
       (19*CF*lm^2*NC*NH)/6 - (9409336594457876041176888302903*CF^2*NC*Pi^2)/
        3901851071377459200 - (CF^2*lm*NC*Pi^2)/6 + 
       (2518982676943644292*CF*NM*NC*Pi^2)/1700595 + 
       (CF*lm*NM*NC*Pi^2)/54 - (27603655301*CF*NC*NL*Pi^2)/2095133040 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (23742230752530828586133545*CF^2*NC*Pi^3)/(45507092412606965496576*
         Sqrt[3]) - (38816802779815544785*CF*NC*NH*Pi^3)/
        (22236242266222092*Sqrt[3]) - (36203*CF^2*NC*Pi^4)/4320 - 
       (485613707391488337910967766190051*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (396132413387881743602869593600*Sqrt[3]) + 
       (2860709848430924842988663*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (315328445536917782970*Sqrt[3]) - 
       (1521*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (4748446150506165717226709*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(245794480623648733392*
         Sqrt[3]) - (4436206031978919404*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (4748446150506165717226709*CF^2*NC*Pi*Log[3]^2)/
        (11798135069935139202816*Sqrt[3]) - (1109051507994729851*CF*NC*NH*Pi*
         Log[3]^2)/(823564528378596*Sqrt[3]) + 
       CF*((-1459176396331059771669128211458349713*CF*NC)/
          50424109126794827424000 + 10218*CF*lm*NC + 
         CA*(12261986536226254859264671116218767/847464018937728192000 + 
           (18733*lm)/3)*NC + (213681857318320864415732972867*NM*NC)/
          12021595778392200 - (3406*lm*NM*NC)/3 - (3937*NC*NL)/3 - 
         (3406*lm*NC*NL)/3 - (1449788341807132097*NC*NH)/2404319155678440 - 
         (3406*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(416413878933685874155*CA + 57*(-14611013417166713583*CF + 
            680680*(13201090309436*NM + 1703*NL)))*Log[x]^3)/87297210 + 
       (247*CF^2*NC*PolyGamma[2, 1])/6 - (10462*CF*NM*NC*PolyGamma[2, 1])/
        27 - (4214*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-20123746241219905142219347331712159311901504670530898380829\
6841628125389307/
          49494034227391528139524897206831009286355335674886871040000000 - 
         (209*lm^2)/12 + (9409336594500522092106588120503*Pi^2)/
          7803702142754918400 + (23742230752530828586133545*Pi^3)/
          (91014184825213930993152*Sqrt[3]) + (36331*Pi^4)/8640 + 
         lm*(-9601829514338124379/88678433440396800 - (11*Pi^2)/108) + 
         (485613707391488337910967766190051*Im[PolyLog[2, (-1)^(1/3)]])/
          (792264826775763487205739187200*Sqrt[3]) + 
         (1521*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (4748446150506165717226709*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (491588961247297466784*Sqrt[3]) + (4748446150506165717226709*Pi*
           Log[3]^2)/(23596270139870278405632*Sqrt[3]) - 
         (247*PolyGamma[2, 1])/12 - (6662622093761072934991*Zeta[3])/
          2793510720) + (6662622095260722606511*CF^2*NC*Zeta[3])/1396755360 - 
       (79206541745708*CF*NM*NC*Zeta[3])/27 - (9140*CF*NC*NL*Zeta[3])/9 + 
       (11600*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((28268280053533148650060252192652559617636111*NM*NC)/
          8028820281058731389578723380000 + (74960866759*lm*NM*NC)/
          349188840 + 60*lm^2*NM*NC - (2254072612396131077*NC*NL)/
          1833576631286400 + (74960866759*lm*NC*NL)/349188840 + 
         60*lm^2*NC*NL - (647631558181366981592120626314652271369714827*NC*
           NH)/50390577565970436673257863957180391684000 + 
         (74960866759*lm*NC*NH)/349188840 + 60*lm^2*NC*NH + 
         (4400363435629*NM*NC*Pi^2)/3 - (1523*NC*NL*Pi^2)/9 + 
         (4436206031978919404*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CF*NC*(-198593605477095151182938830948305602167252358471158705580743\
1/342748036565692529948446506668334660684326400000 - (1631210359*lm)/
            38798760 - 540*lm^2 - (6662622071005227182351*Pi^2)/2793510720 + 
           (4748446150506165717226709*Im[PolyLog[2, (-1)^(1/3)]])/
            (737383441870946200176*Sqrt[3]) - 1440*Zeta[3]) + 
         CA*NC*(1985936053697422636939571809350613474604894244470732042109731/
            685496073131385059896893013336669321368652800000 - 
           (101626196359*lm)/63488880 - 330*lm^2 + 
           (6662622071474950836751*Pi^2)/5587021440 - 
           (4748446150506165717226709*Im[PolyLog[2, (-1)^(1/3)]])/
            (1474766883741892400352*Sqrt[3]) + 720*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["p", 2, 0, "x1"] = SeriesData[x, 1, 
     {-(CF*NC*(20*(NM*(-25 + 5*lm + 8*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
            NH*(-25 + 5*lm + 8*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
            NL*(-1 + 5*lm + 8*lm^2 + 4*lm^3 + 32*Zeta[3])) + 
          CF*(2340*lm^2 - 720*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 + 
            lm*(3030 - 4320*Zeta[3]) - 15*(-51 + 64*Log[2]^4 + 
              1536*PolyLog[4, 1/2] + 576*Zeta[3])) - 
          2*CA*(860*lm^2 + 220*lm^3 - 5*lm*(-85 + 216*Zeta[3]) + 
            4*(11*Pi^4 + 60*Pi^2*Log[2]^2 - 10*(9 + 6*Log[2]^4 + 
                144*PolyLog[4, 1/2] + 28*Zeta[3])))))/2880, 
      -(CF*NC*(-2*((41 + 16*lm + 12*lm^2)*NM + (5 + 16*lm + 12*lm^2)*NL + 
            (-31 + 16*lm + 12*lm^2)*NH) + CA*(85 + 344*lm + 132*lm^2 - 
            216*Zeta[3]) + 3*CF*(-101 - 156*lm + 72*lm^2 + 144*Zeta[3])))/
       288, (CF*NC*(-70*NM - 384*lm*NM - 304*NL - 384*lm*NL + 794*NH - 
         384*lm*NH - 567*NM*Zeta[3] - 567*NH*Zeta[3] + 
         6*CF*(-1258 + 576*lm + 561*Zeta[3]) + 
         CA*(1102 + 2112*lm + 1773*Zeta[3])))/3456, 
      (CF*NC*(-170*NM + 64*lm*NM - 96*lm^2*NM + 568*NL + 64*lm*NL - 
         96*lm^2*NL - 1358*NH + 64*lm*NH - 96*lm^2*NH + 
         2*CA*(76 + 160*lm + 264*lm^2 - 2205*Zeta[3]) + 
         12*CF*(401 - 300*lm + 72*lm^2 - 417*Zeta[3]) + 819*NM*Zeta[3] + 
         1449*NH*Zeta[3]))/6912, 
      -(CF*NC*(-148162*NM - 82560*lm*NM - 31104*lm^2*NM + 76128*NL - 
          82560*lm*NL - 31104*lm^2*NL - 478642*NH - 82560*lm*NH - 
          31104*lm^2*NH + 432*CF*(22005 - 548*lm + 648*lm^2 - 
            20240*Zeta[3]) + 192*CA*(11164 + 3499*lm + 891*lm^2 - 
            12150*Zeta[3]) + 169155*NM*Zeta[3] + 509355*NH*Zeta[3]))/
       2488320, (CF*NC*(-95854*NM - 51456*lm*NM - 10368*lm^2*NM - 
         8352*NL - 51456*lm*NL - 10368*lm^2*NL - 220390*NH - 
         51456*lm*NH - 10368*lm^2*NH + 24*CA*(78378 + 14816*lm + 
           2376*lm^2 - 62829*Zeta[3]) + 432*CF*(21147 + 316*lm + 216*lm^2 - 
           18299*Zeta[3]) + 50085*NM*Zeta[3] + 220185*NH*Zeta[3]))/1244160, 
      -(CF*NC*(-563576050*NM - 248033280*lm*NM - 33177600*lm^2*NM - 
          171952128*NL - 248033280*lm*NL - 33177600*lm^2*NL - 
          1055144050*NH - 248033280*lm*NH - 33177600*lm^2*NH + 
          4*CA*(3547953674 + 399106560*lm + 45619200*lm^2 - 
            2659103775*Zeta[3]) + 120*CF*(784301866 + 9893376*lm + 
            2488320*lm^2 - 658801935*Zeta[3]) + 199276875*NM*Zeta[3] + 
          993076875*NH*Zeta[3]))/6967296000, 
      (CF*NC*(-1069226870*NM - 365383680*lm*NM - 33177600*lm^2*NM - 
         411772928*NL - 365383680*lm*NL - 33177600*lm^2*NL - 
         1701406050*NH - 365383680*lm*NH - 33177600*lm^2*NH + 
         8*CA*(4362972382 + 280231680*lm + 22809600*lm^2 - 
           3286439325*Zeta[3]) + 720*CF*(429911018 + 3115776*lm + 
           414720*lm^2 - 357693135*Zeta[3]) + 346460625*NM*Zeta[3] + 
         1526245875*NH*Zeta[3]))/13934592000, 
      -(CF*NC*(-377123151650*NM - 95727206400*lm*NM - 5419008000*lm^2*NM - 
          150331817984*NL - 95727206400*lm*NL - 5419008000*lm^2*NL - 
          514393370610*NH - 95727206400*lm*NH - 5419008000*lm^2*NH + 
          3584*CF*(52033157864 + 192758400*lm + 13608000*lm^2 - 
            43192741725*Zeta[3]) + 768*CA*(21133917472 + 734938400*lm + 
            38808000*lm^2 - 16307022375*Zeta[3]) + 132741385875*NM*Zeta[3] + 
          444494428875*NH*Zeta[3]))/5462360064000, 
      (CF*NC*(-331035467350*NM - 59165245440*lm*NM - 1445068800*lm^2*NM - 
         124030107648*NL - 59165245440*lm*NL - 1445068800*lm^2*NL - 
         383609589370*NH - 59165245440*lm*NH - 1445068800*lm^2*NH + 
         1792*CF*(152404832362 + 271745280*lm + 7257600*lm^2 - 
           126509923575*Zeta[3]) + 384*CA*(49373621342 + 873761280*lm + 
           20697600*lm^2 - 39027496725*Zeta[3]) + 134961710625*NM*Zeta[3] + 
         322003812375*NH*Zeta[3]))/5462360064000, 
      (CF*NC*(7*CA*(-37276887410224402 - 310508775014400*lm + 
           3678732288000*lm^2 + 30020719857226875*Zeta[3]) + 
         2*(9*CF*(-254416252917374194 - 208769502412800*lm + 
             2341011456000*lm^2 + 211302441443212875*Zeta[3]) - 
           5*(65536*(-1721408749 - 612109260*lm + 7144200*lm^2)*NL + 
             63*NM*(-5439914307826 - 636749086720*lm + 7431782400*lm^2 + 
               2591712844875*Zeta[3]) + 63*NH*(-5257659240106 - 636749086720*
                lm + 7431782400*lm^2 + 4314911745375*Zeta[3])))))/
       64892837560320000, 
      -(CF*NC*(5*CA*(-12015618251539430 - 41760469352448*lm + 
            2832623861760*lm^2 + 9801610576842105*Zeta[3]) + 
          2*(9*CF*(-69725722441155826 - 25127186595840*lm + 1287556300800*lm^
                2 + 57940962104486475*Zeta[3]) - 
            2*(32768*(-1249832978 - 314647515*lm + 19646550*lm^2)*NL + 
              504*NM*(-296845521586 - 20457082880*lm + 1277337600*lm^2 + 
                162700720875*Zeta[3]) + 63*NH*(-1873773150886 - 
                163656663040*lm + 10218700800*lm^2 + 1510988873625*
                 Zeta[3])))))/12978567512064000, 
      (CF*NC*(CA*(-2162540378411210580602 - 2406611670840115200*lm + 
           498022485295104000*lm^2 + 1778625847222152996375*Zeta[3]) + 
         22*CF*(-2399857654973655010898 - 355800285285580800*lm + 
           37042994774016000*lm^2 + 1995048455047805878875*Zeta[3]) + 
         5*(-65536*(-10949978379581 - 1687044161880*lm + 276335274600*lm^2)*
            NL - 495*NH*(-4216958213339366 - 223357830692864*lm + 
             36585673850880*lm^2 + 3354068729036025*Zeta[3]) - 
           99*NM*(-1116789153464320*lm + 182928369254400*lm^2 + 
             99*(-336326703325274 + 206821454214375*Zeta[3])))))/
       408305733929533440000, 
      -(CF*NC*(66*CF*(-523861697899935702278 - 28401191239680000*lm + 
            5600869908480000*lm^2 + 435614920617642467625*Zeta[3]) + 
          CA*(-1229414867342521287226 - 67347255951360000*lm + 
            225901752975360000*lm^2 + 1016247897081805224375*Zeta[3]) - 
          5*(65536*(-3674370424799 - 196898625000*lm + 125344989000*lm^2)*
             NL + 99*NH*(-7333631148616718 - 130342912000000*lm + 
              82975850496000*lm^2 + 5770428077539125*Zeta[3]) + 
            33*NM*(-43471332595159762 - 391028736000000*lm + 
              248927551488000*lm^2 + 29200352248942875*Zeta[3]))))/
       204152866964766720000, CA*CF*NC*((23365357*lm)/9658958400 + 
         lm^2/1092 + (-4780316872823269317132998 + 3963173323605883753991625*
            Zeta[3])/702582811983473541120000) + 
       (CF*NC*(1872*CF*(-7196443550388252933376966 - 105473597308718284800*
             lm + 49491604112670720000*lm^2 + 5985207749035315207031625*
             Zeta[3]) - 35*(16777216*(-402058831012459 + 23997476362860*lm + 
              17531009496000*lm^2)*NL + 3003*NM*(-17521645448068699262 + 
              134069545252945920*lm + 97942568435712000*lm^2 + 
              12545378701510780125*Zeta[3]) + 1287*NH*
             (-16878546907968692518 + 312828938923540480*lm + 
              228532659683328000*lm^2 + 13168544203006817625*Zeta[3]))))/
        61827287454545671618560000, 
      -(CF*NC*(16*CA*(-8434785323960229564396322 + 3913033972099527475200*
             lm + 797600407231660032000*lm^2 + 7004781299419704295369875*
             Zeta[3]) + 416*CF*(-11720745631272390570691286 + 
            6690509104191897600*lm + 50198627028566016000*lm^2 + 
            9749061982606978885478625*Zeta[3]) - 
          5*(16777216*(-500305046603983 + 100496679863580*lm + 
              27660037204800*lm^2)*NL + 2145*NM*(-38798901561436994398 + 
              786039396435492864*lm + 216344251166883840*lm^2 + 
              28998623710724993325*Zeta[3]) + 1287*NH*
             (1310065660725821440*lm + 360573751944806400*lm^2 + 
              1859*(-12532942909947794 + 9712669142050875*Zeta[3])))))/
       17664939272727334748160000, 
      (CF*NC*(360*CA*(-398355929809003662475378466 + 176983412963251081707520*
            lm + 25950097756410347520000*lm^2 + 331130003110745538407382675*
            Zeta[3]) + 16*CF*(-362512467311339804628597958406 + 
           1956174803352136817049600*lm + 955435417395108249600000*lm^2 + 
           301549360682751068208155459625*Zeta[3]) - 
         35*(603979776*(-1117182349322211 + 445737516163940*lm + 
             80350460190000*lm^2)*NL + 143*NH*(-19717071795902346298862 + 
             1882632483688761262080*lm + 339370999629742080000*lm^2 + 
             15198377778600600709125*Zeta[3]) + 143*NM*
            (-52139206632723565221758 + 1882632483688761262080*lm + 
             339370999629742080000*lm^2 + 39885863000342069836125*Zeta[3]))))/
       16817022187636422680248320000, 
      -(CF*NC*(192*CA*(-829049994158996185816207342 + 
            314861742030913850572800*lm + 36959230137917767680000*lm^2 + 
            689485944819476290926565125*Zeta[3]) + 
          5*(128*CF*(-11188029397272107948978488126 + 67973931673856161873920*
               lm + 18143622067705085952000*lm^2 + 
              9306912001270074002179292925*Zeta[3]) - 
            7*(805306368*(-458025568947511 + 331708637900640*lm + 
                45775413684000*lm^2)*NL + 1001*NH*(
                -1957992952375922374198 + 266860218203787755520*lm + 
                36826405731827712000*lm^2 + 1502706165967382000625*Zeta[3]) + 
              143*NM*(-15159425918201686785766 + 1868021527426514288640*lm + 
                257784840122793984000*lm^2 + 11137140645060754949625*
                 Zeta[3])))))/16817022187636422680248320000, 
      (CF*NC*(64*CA*(-361903221782216472397918365517958 + 
           111293402945419051786882252800*lm + 11061196141272766108139520000*
            lm^2 + 301056467080055178942775744043625*Zeta[3]) + 
         2176*CF*(-529566597236089799313989252078042 + 
           2815572053886778872535449600*lm + 532357033537191951728640000*
            lm^2 + 440536921299631980454968392430375*Zeta[3]) - 
         105*(77309411328*(-98700032291897931 + 139357776678880760*lm + 
             15856148792484000*lm^2)*NL + 2431*NM*
            (95239169142237482386563802 + 4431784318808374514810880*lm + 
             504249086415514632192000*lm^2 - 79884196531171064880222375*
              Zeta[3]) + 2431*NH*(4431784318808374514810880*lm + 
             504249086415514632192000*lm^2 + 2431*(-10216981010003834869226 + 
               7812915848150315277375*Zeta[3])))))/
       2216214451975478326493844602880000, 
      -(CF*NC*(430848*CF*(-2156319374701140974056494511442 + 
            9113247614763039876710400*lm + 1360510399397989711872000*lm^2 + 
            1793826692451069587555311942875*Zeta[3]) + 
          128*CA*(-132545976728757083548283335996906 + 
            32102761189657337022696652800*lm + 2798569891561664837320704000*
             lm^2 + 110274308511513079808115047181375*Zeta[3]) - 
          35*(17179869184*(-270303040967809516 + 1104657718269600495*lm + 
              108316730042621100*lm^2)*NL + 2431*NM*
             (572182319311668595145804926 + 7806612543384476901703680*lm + 
              765473982957989815910400*lm^2 - 473679899756493926791420125*
               Zeta[3]) + 2431*NH*(-35257819765670172339612086 + 
              7806612543384476901703680*lm + 765473982957989815910400*lm^2 + 
              26878092065958480594872625*Zeta[3]))))/
       1477476301316985550995896401920000, 
      (CF*NC*(28424*CF*(-339460500769796433897527888197702934 + 
           1090099344999949981300083916800*lm + 
           136555564181365005823770624000*lm^2 + 
           282396904269785618742665202856514625*Zeta[3]) + 
         44*CA*(-3653735206776283488815107565908272446 + 
           687640439154479929979532056985600*lm + 
           53909102170709985076873003008000*lm^2 + 
           3039946914657420898015971205371376125*Zeta[3]) - 
         105*(8589934592*(568648667351095047007 + 5490624253359368803680*lm + 
             478159655512709570400*lm^2)*NL + 4199*NH*
            (11232222721030201070258749440*lm + 978175795519749329466163200*
              lm^2 + 4199*(-10112309860374660933421358 + 
               7687740910317087512017125*Zeta[3])) + 
           4199*NM*(11232222721030201070258749440*lm + 
             978175795519749329466163200*lm^2 - 
             247*(-7547332040222509354071857282 + 
               6249909140760969926683315875*Zeta[3])))))/
       12800854674610362813828446426234880000, 
      -(CF*NC*(2584*CF*(-317169033397749292493307258696254198 + 
            757157336613679375462485196800*lm + 82801573980004867953917952000*
             lm^2 + 263853803524503414377042140945316625*Zeta[3]) + 
          20*CA*(-625223838945489651446931700399492486 + 
            90984171283429674874372746117120*lm + 
            6537644274465717685339344076800*lm^2 + 
            520199238617157628095315151360782825*Zeta[3]) - 
          15*(8589934592*(886855201601507165389 + 2332921651161751409760*lm + 
              184504718109562250400*lm^2)*NL + 4199*NM*
             (1576299535066507016228601637766 + 4772480207606593336985518080*
               lm + 377443072273526463607603200*lm^2 - 
              1307049698249193864181210619625*Zeta[3]) + 
            20995*NH*(954496041521318667397103616*lm + 
              75488614454705292721520640*lm^2 + 4199*(
                -740705867885632826430766 + 561697153929984739191525*
                 Zeta[3])))))/914346762472168772416317601873920000, 
      (CF*NC*(5*CA*(-3201979214289817502316605742557823522026 + 
           360474453051377353189534472507228160*lm + 
           24100146034991427022843051140710400*lm^2 + 
           2664099097298366474376249590631092406975*Zeta[3]) + 
         2*CF*(-571133707547180633103577602738414676236142 + 
           1004117845064169780887213682406195200*lm + 
           98591506506783110547994300121088000*lm^2 + 
           475128915021003915681243846618280946797125*Zeta[3]) - 
         385*(6493990551552*(72924909138258502757 + 119918893350112479480*
              lm + 8763036227268523200*lm^2)*NL + 46189*NM*
            (10407550473953410995876032466038 + 16860121681963290083343728640*
              lm + 1232048203312253441251737600*lm^2 - 
             8639327874185620812642013196625*Zeta[3]) + 
           4199*NH*(185461338501596190916781015040*lm + 
             13552530236434787853769113600*lm^2 + 
             4199*(-127068763625759580746405602 + 96133615890698246039053875*
                Zeta[3])))))/1079538744225473930632865648612474880000, 
      -(CF*NC*(8*CA*(-4715811503363095450568103233441240327326 + 
            412392784588766789626884143657779200*lm + 
            25967099648679715672933049303040000*lm^2 + 
            3923582782874145352386587652089525050125*Zeta[3]) + 
          7*(16*CF*(-26092164981827114202215339614690943077646 + 
              33715975313207492936954739582566400*lm + 
              3035115543352174559173992775680000*lm^2 + 
              21706230233690340688001121077309948371125*Zeta[3]) - 
            15*(2886218022912*(1458237416255272751047 + 
                1820714268592770356520*lm + 124632787570114824000*lm^2)*NL + 
              4199*NM*(1390425729705159102568053531059014 + 
                1251483290446652487461775605760*lm + 
                85667396458830220505382912000*lm^2 - 
                1155085174134939403902929581823625*Zeta[3]) + 
              4199*NH*(1251483290446652487461775605760*lm + 
                85667396458830220505382912000*lm^2 + 4199*
                 (-772495889466833639457528202 + 583136375301204704624019375*
                   Zeta[3]))))))/2355357260128306757744434142427217920000, 
      (CF*NC*(392*CA*(-4819446919672825992511948619615413732035154 + 
           329502439662330200331570598085079859200*lm + 
           19734253768132470242840507682757017600*lm^2 + 
           4009748881816135963015287791523347322358875*Zeta[3]) + 
         368*CF*(-430801935005208515040483327319708505544826594 + 
           410175718446021122713289298306033254400*lm + 
           34398442338918653664397880980615987200*lm^2 + 
           358387030581651701239401714773505303435661875*Zeta[3]) - 
         1155*(4947802324992*(3670991707483054447507907 + 
             3796242028382426274571920*lm + 246121618059700000057440*lm^2)*
            NL + 37145*NM*(985461427952550937779892561917586138 + 
             505668465049479466260357376376832*lm + 
             32783984764209898401998227636224*lm^2 - 
             819081155915239378904423981116791975*Zeta[3]) + 
           7429*NH*(2528342325247397331301786881884160*lm + 
             163919923821049492009991138181120*lm^2 + 
             7429*(-808442207099706674735837317846 + 
               608996639310310215824040806625*Zeta[3])))))/
       109646591173492936186518898198271848611840000, 
      -(CF*NC*(672*CA*(-1003973234213211094715474153989101412999714 + 
            54099673969533001345832615088331161600*lm + 
            3106491359852782897627344168340684800*lm^2 + 
            835287246277984418996986102506534441894675*Zeta[3]) + 
          4416*CF*(-13866194635286342093329570555935385509445822 + 
            9779501936102511857261789945895321600*lm + 
            773553184469270049606809022155980800*lm^2 + 
            11535385860856107272938324810804009662980925*Zeta[3]) - 
          385*(2199023255552*(8048219927737096487634017 + 
              7236889838667745993016280*lm + 448318005879984409128960*lm^2)*
             NL + 7429*NM*(7183491707983338931369545486090959726 + 
              2142157632669044938487072701808640*lm + 
              132704498696026920710427880980480*lm^2 - 
              5972624192702346460613592013273645125*Zeta[3]) + 
            156009*NH*(102007506317573568499384414371840*lm + 
              6319261842667948605258470522880*lm^2 + 
              7429*(-30328616147217448221741748942 + 
                22801764805419598183507447125*Zeta[3])))))/
       36548863724497645395506299399423949537280000}, 0, 26, 1]
 
CbarSeries["p", 2, 1, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(2*CA*(-5540*Pi^2 + 324*Pi^4 - 660*lm*(3 + 4*Pi^2) + 
            15*(-175 + 3024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1728*Im[PolyLog[2, (-1)^(1/3)]]^2 - 504*PolyGamma[2, 1] - 
              5616*Zeta[3])) + 15*(CF*(-484*Pi^2 + 16*Pi^4 - 
              9*(103 + 1344*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                768*Im[PolyLog[2, (-1)^(1/3)]]^2 - 224*PolyGamma[2, 1] - 
                3168*Zeta[3])) + 4*(NL*(4*lm*(3 + 4*Pi^2) + 
                3*(15 + 4*Pi^2 - 64*Zeta[3])) + NM*(45 + 12*Pi^2 + 
                4*lm*(3 + 4*Pi^2) + 16*PolyGamma[2, 1] - 160*Zeta[3]) + 
              NH*(-891 + 4*lm*(3 + 4*Pi^2) - 3024*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 504*PolyGamma[2, 1] + 6000*Zeta[3])))))/
       155520, (CF*NC*(-4*CA*(-6040*Pi^2 + 243*Pi^4 - 660*lm*(51 + 2*Pi^2) - 
           15*(7235 + 2376*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             1296*Im[PolyLog[2, (-1)^(1/3)]]^2 - 396*PolyGamma[2, 1] - 
             4512*Zeta[3])) - 120*(NH*(7383 + 204*lm + 8*lm*Pi^2 + 
             864*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 144*PolyGamma[2, 1] - 
             7776*Zeta[3]) + NL*(495 + 204*lm + 16*Pi^2 + 8*lm*Pi^2 - 
             96*Zeta[3]) + NM*(495 + 16*Pi^2 + 4*lm*(51 + 2*Pi^2) + 
             8*PolyGamma[2, 1] - 80*Zeta[3])) + CF*(36940*Pi^2 + 408*Pi^4 + 
           15*(9083 - 19008*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             10368*Im[PolyLog[2, (-1)^(1/3)]]^2 + 3168*PolyGamma[2, 1] + 
             25056*Zeta[3]))))/155520, 
      (CF*NC*(3*CA*(-3220*Pi^2 + 28*Pi^4 - 220*lm*(291 + 4*Pi^2) + 
           15*(-12429 - 1200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             2880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 328*PolyGamma[2, 1] + 
             1296*Zeta[3])) + 
         10*(3*(NL*(4*lm*(291 + 4*Pi^2) + 3*(823 + 4*Pi^2 - 64*Zeta[3])) + 
             NH*(32349 + 4*lm*(291 + 4*Pi^2) + 18864*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 3480*PolyGamma[2, 1] - 61872*
                Zeta[3]) + NM*(3909 - 84*Pi^2 + 4*lm*(291 + 4*Pi^2) - 80*
                PolyGamma[2, 1] - 352*Zeta[3])) + CF*(-3916*Pi^2 + 60*Pi^4 + 
             3*(-7321 + 3600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 8640*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 984*PolyGamma[2, 1] + 2736*
                Zeta[3])))))/77760, (CF*NC*(1886355*CF - 1497960*NM - 
         263520*lm*NM - 616680*NL - 263520*lm*NL - 14754600*NH - 
         263520*lm*NH + 189684*CF*Pi^2 + 21600*NM*Pi^2 - 5760*lm*NM*Pi^2 + 
         30240*NL*Pi^2 - 5760*lm*NL*Pi^2 - 5760*lm*NH*Pi^2 + 
         86800*Sqrt[3]*CF*Pi^3 + 274400*Sqrt[3]*NH*Pi^3 + 7128*CF*Pi^4 - 
         544320*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 2125440*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 3888000*CF*Im[PolyLog[2, (-1)^(1/3)]]^
           2 + 3214080*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         10160640*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         66960*Sqrt[3]*CF*Pi*Log[3]^2 + 211680*Sqrt[3]*NH*Pi*Log[3]^2 + 
         25920*(135*CF - 2*CA*(76 + 33*lm) + 4*(5*NM + 3*lm*NM + 5*NL + 
             3*lm*NL + 3*lm*NH))*Log[x]^2 + 103680*(11*CA + 36*CF - 
           2*(NM + NL))*Log[x]^3 + 286560*CF*PolyGamma[2, 1] + 
         11520*NM*PolyGamma[2, 1] + 512640*NH*PolyGamma[2, 1] - 
         4304160*CF*Zeta[3] - 529920*NM*Zeta[3] + 380160*NL*Zeta[3] + 
         8040960*NH*Zeta[3] + 2160*Log[x]*(8*(NM*(-43 + 3*lm + 3*Pi^2) + 
             NL*(11 + 3*lm + 3*Pi^2) + NH*(355 + 3*lm - 196*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) - 4*CA*(145 + 33*lm + 12*Pi^2 - 
             62*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 108*Zeta[3]) + 
           CF*(1209 + 80*Pi^2 - 496*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             864*Zeta[3])) - 4*CA*(-37470*Pi^2 + 10850*Sqrt[3]*Pi^3 + 
           2043*Pi^4 - 1980*lm*(183 + 4*Pi^2) + 8370*Sqrt[3]*Pi*Log[3]^2 - 
           90*(12367 + 756*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             5400*Im[PolyLog[2, (-1)^(1/3)]]^2 - 4464*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 398*PolyGamma[2, 1] + 
             2588*Zeta[3]))))/233280, 
      -(CF*NC*(5346225*CF - 5472900*NM - 969840*lm*NM - 2219940*NL - 
          969840*lm*NL - 51259140*NH - 969840*lm*NH + 309324*CF*Pi^2 + 
          242640*NM*Pi^2 - 14400*lm*NM*Pi^2 + 147600*NL*Pi^2 - 
          14400*lm*NL*Pi^2 - 14400*lm*NH*Pi^2 + 411600*Sqrt[3]*CF*Pi^3 + 
          996800*Sqrt[3]*NH*Pi^3 + 33120*CF*Pi^4 + 2482560*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] - 14811840*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 15552000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 15240960*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 36910080*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 317520*Sqrt[3]*CF*Pi*
           Log[3]^2 + 768960*Sqrt[3]*NH*Pi*Log[3]^2 + 
          103680*(126*CF - 2*CA*(76 + 33*lm) + 23*NM + 12*lm*NM + 20*NL + 
            12*lm*NL + 12*lm*NH)*Log[x]^2 + 414720*(11*CA + 36*CF - 
            2*(NM + NL))*Log[x]^3 + 500640*CF*PolyGamma[2, 1] + 
          223200*NM*PolyGamma[2, 1] + 3388800*NH*PolyGamma[2, 1] - 
          30*CA*(-576723 - 14944*Pi^2 + 6860*Sqrt[3]*Pi^3 + 936*Pi^4 - 
            132*lm*(1347 + 20*Pi^2) + 41376*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 259200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            254016*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
            5292*Sqrt[3]*Pi*Log[3]^2 + 8344*PolyGamma[2, 1] - 
            311920*Zeta[3]) - 27860640*CF*Zeta[3] - 2491200*NM*Zeta[3] + 
          1416960*NL*Zeta[3] + 40715520*NH*Zeta[3] + 
          4320*Log[x]*(4*(3*NL*(13 + 3*lm + 4*Pi^2) + 3*NM*(-71 + 3*lm + 
                6*Pi^2) + NH*(1295 + 9*lm - 712*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) - CA*(1095 + 198*lm + 43*Pi^2 - 
              588*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 864*Zeta[3]) + 
            CF*(46*Pi^2 + 3*(727 - 392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                576*Zeta[3])))))/466560, 
      (CF*NC*(-35056125*CF - 896265000*NM - 130248000*lm*NM - 
         387423000*NL - 130248000*lm*NL - 10946146248*NH - 
         130248000*lm*NH - 29650500*CF*Pi^2 + 42120000*NM*Pi^2 - 
         1944000*lm*NM*Pi^2 + 34344000*NL*Pi^2 - 1944000*lm*NL*Pi^2 - 
         1944000*lm*NH*Pi^2 + 110915000*Sqrt[3]*CF*Pi^3 + 
         290500000*Sqrt[3]*NH*Pi^3 + 10233000*CF*Pi^4 + 
         170244000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         1676736000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         2671056000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 4107024000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10756800000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 85563000*Sqrt[3]*CF*Pi*
          Log[3]^2 + 224100000*Sqrt[3]*NH*Pi*Log[3]^2 + 
         2332800*(1625*CF - 15*CA*(126 + 55*lm) + 450*NM + 150*lm*NM + 
           235*NL + 150*lm*NL + 8*NH + 150*lm*NH)*Log[x]^2 + 
         23328000*(61*CA + 210*CF - 16*NM - 10*NL)*Log[x]^3 + 
         184524000*CF*PolyGamma[2, 1] + 31104000*NM*PolyGamma[2, 1] + 
         442056000*NH*PolyGamma[2, 1] - 25*CA*(-3451896*Pi^2 + 
           2218300*Sqrt[3]*Pi^3 + 266868*Pi^4 - 427680*lm*(67 + Pi^2) + 
           1711260*Sqrt[3]*Pi*Log[3]^2 + 15*(-7432263 + 226992*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 3561408*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 5476032*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             246032*PolyGamma[2, 1] - 4248704*Zeta[3])) - 
         4623468000*CF*Zeta[3] - 1104192000*NM*Zeta[3] + 
         373248000*NL*Zeta[3] + 3512400000*NH*Zeta[3] - 
         1080*Log[x]*(25*CA*(58761 + 10296*lm + 1686*Pi^2 - 
             25352*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 31104*Zeta[3]) - 
           2*(4*(150*NM*(-637 + 39*lm + 27*Pi^2) + 75*NL*(427 + 78*lm + 
                 90*Pi^2) + 2*NH*(375633 + 2925*lm - 207500*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]])) + 25*CF*(53643 + 582*Pi^2 - 
               25352*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 31104*Zeta[3])))))/
       34992000, -(CF*NC*(3034918125*CF - 5135690250*NM - 903879000*lm*NM - 
          2853488250*NL - 903879000*lm*NL - 77017153482*NH - 
          903879000*lm*NH - 633444300*CF*Pi^2 + 438453000*NM*Pi^2 - 
          10692000*lm*NM*Pi^2 + 271593000*NL*Pi^2 - 10692000*lm*NL*Pi^2 - 
          10692000*lm*NH*Pi^2 + 916405000*Sqrt[3]*CF*Pi^3 + 
          2121980000*Sqrt[3]*NH*Pi^3 + 86022000*CF*Pi^4 + 
          4241376000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          17064972000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          19945440000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 33933168000*Sqrt[3]*
           CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 78573888000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 706941000*Sqrt[3]*CF*Pi*
           Log[3]^2 + 1636956000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          777600*(39760*CF - 15*CA*(3071 + 1298*lm) + 11725*NM + 
            3540*lm*NM + 5430*NL + 3540*lm*NL + 216*NH + 3540*lm*NH)*
           Log[x]^2 + 31104000*(329*CA + 1367*CF - 91*NM - 59*NL)*
           Log[x]^3 + 1257102000*CF*PolyGamma[2, 1] + 691578000*NM*
           PolyGamma[2, 1] + 4368888000*NH*PolyGamma[2, 1] - 
          25*CA*(-26926344*Pi^2 + 18328100*Sqrt[3]*Pi^3 + 2062584*Pi^4 - 
            17820*lm*(11159 + 132*Pi^2) + 14138820*Sqrt[3]*Pi*Log[3]^2 + 
            45*(-16080621 + 1885056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              8864640*Im[PolyLog[2, (-1)^(1/3)]]^2 + 15081408*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 558712*PolyGamma[2, 1] - 
              15662320*Zeta[3])) - 45874872000*CF*Zeta[3] - 
          8636220000*NM*Zeta[3] + 2881008000*NL*Zeta[3] + 
          32524560000*NH*Zeta[3] - 2160*Log[x]*
           (25*CA*(172515 + 34254*lm + 8631*Pi^2 - 104732*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 116640*Zeta[3]) - 
            2*(2*(225*NL*(1119 + 173*lm + 236*Pi^2) + 75*NM*(-11141 + 
                  519*lm + 750*Pi^2) + NH*(5502669 + 38925*lm - 3031400*
                   Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 25*CF*(3825*Pi^2 - 
                104732*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                15*(9965 + 7776*Zeta[3]))))))/157464000, 
      (CF*NC*(-90944949375*CF - 758293767000*NM - 78977808000*lm*NM - 
         336600306000*NL - 78977808000*lm*NL - 9463941748584*NH - 
         78977808000*lm*NH - 115998787800*CF*Pi^2 + 39266640000*NM*Pi^2 - 
         889056000*lm*NM*Pi^2 + 31413312000*NL*Pi^2 - 
         889056000*lm*NL*Pi^2 - 889056000*lm*NH*Pi^2 + 
         118735452500*Sqrt[3]*CF*Pi^3 + 293834380000*Sqrt[3]*NH*Pi^3 + 
         10774247400*CF*Pi^4 + 230440434000*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] - 1509156096000*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 2028381264000*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 4396604184000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10880267328000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 91595920500*Sqrt[3]*CF*Pi*
          Log[3]^2 + 226672236000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         1587600*(105*CA*(28525 + 12232*lm) - 
           4*(644735*CF + 35*(5545 + 1668*lm)*NM + 86310*NL + 
             58380*lm*NL + 5913*NH + 58380*lm*NH))*Log[x]^2 + 
         222264000*(6689*CA + 4*(7319*CF - 964*NM - 278*NL))*Log[x]^3 + 
         175537796000*CF*PolyGamma[2, 1] + 4223016000*NM*PolyGamma[2, 1] + 
         406987336000*NH*PolyGamma[2, 1] - 17150*CA*(-4833027*Pi^2 + 
           3461675*Sqrt[3]*Pi^3 + 355590*Pi^4 - 47520*lm*(533 + 6*Pi^2) + 
           2670435*Sqrt[3]*Pi*Log[3]^2 + 10*(-10620531 + 671838*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 5913648*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 12818088*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             511772*PolyGamma[2, 1] - 10532564*Zeta[3])) - 
         4671868544000*CF*Zeta[3] - 1301133456000*NM*Zeta[3] + 
         381405024000*NL*Zeta[3] + 1829276624000*NH*Zeta[3] - 
         7560*Log[x]*(67992400*NM - 6056400*lm*NM - 45672900*NL - 
           6056400*lm*NL - 867850232*NH - 6056400*lm*NH + 
           9937200*NM*Pi^2 - 8173200*NL*Pi^2 + 479729600*Sqrt[3]*NH*
            Im[PolyLog[2, (-1)^(1/3)]] + 1225*CA*(145906 + 27192*lm + 
             5805*Pi^2 - 79124*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             77760*Zeta[3]) - 1225*CF*(243371 + 4350*Pi^2 - 
             158248*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 155520*Zeta[3]))))/
       9001692000, -(CF*NC*(3400288584714*CF - 6245272575738*NM - 
          663277450500*lm*NM - 3126243873375*NL - 663277450500*lm*NL - 
          82952695895634*NH - 663277450500*lm*NH - 932200419150*CF*Pi^2 + 
          500399613000*NM*Pi^2 - 6334524000*lm*NM*Pi^2 + 
          289582209000*NL*Pi^2 - 6334524000*lm*NL*Pi^2 - 
          6334524000*lm*NH*Pi^2 + 1142725937500*Sqrt[3]*CF*Pi^3 + 
          2650487910000*Sqrt[3]*NH*Pi^3 + 104069561400*CF*Pi^4 + 
          3707411883000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          16514161692000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          18183417840000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          42313509000000*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          98143780896000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          881531437500*Sqrt[3]*CF*Pi*Log[3]^2 + 2044662102000*Sqrt[3]*NH*Pi*
           Log[3]^2 + 9525600*(4812283*CF - 14*CA*(369851 + 145695*lm) + 
            1376564*NM + 370860*lm*NM + 536445*NL + 370860*lm*NL + 
            42012*NH + 370860*lm*NH)*Log[x]^2 + 1333584000*
           (8989*CA + 52629*CF - 6172*NM - 1766*NL)*Log[x]^3 + 
          2822764462000*CF*PolyGamma[2, 1] + 945511056000*NM*
           PolyGamma[2, 1] + 4399317314000*NH*PolyGamma[2, 1] - 
          343*CA*(-39667449726 - 1770014025*Pi^2 + 1665781250*Sqrt[3]*Pi^3 + 
            166479300*Pi^4 - 4232250*lm*(2513 + 24*Pi^2) + 5404390500*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 26506440000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 61681500000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1285031250*Sqrt[3]*Pi*
             Log[3]^2 + 4114817000*PolyGamma[2, 1] - 59459960000*Zeta[3]) - 
          50414341684000*CF*Zeta[3] - 10887379776000*NM*Zeta[3] + 
          3608678304000*NL*Zeta[3] + 20163437476000*NH*Zeta[3] - 
          3780*Log[x]*(6*(-3675*NL*(40119 + 4628*lm + 7064*Pi^2) + 
              196*NM*(1021352 - 86775*lm + 131550*Pi^2) - 
              2*NH*(1306757747 + 8503950*lm - 721221200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 98*CA*(22572186 + 
              5727150*lm + 2754675*Pi^2 - 19037500*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 17496000*Zeta[3]) - 
            49*CF*(66724869 + 7254900*Pi^2 - 76150000*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 69984000*Zeta[3]))))/54010152000, 
      (CF*NC*(456052766393889*CF - 1621041305148720*NM - 
         133223041224000*lm*NM - 825851230848000*NL - 133223041224000*lm*
          NL - 21774826112094000*NH - 133223041224000*lm*NH - 
         319185138384000*CF*Pi^2 - 102851332416000*NM*Pi^2 - 
         1200225600000*lm*NM*Pi^2 + 69893137440000*NL*Pi^2 - 
         1200225600000*lm*NL*Pi^2 - 1200225600000*lm*NH*Pi^2 + 
         301494770500000*Sqrt[3]*CF*Pi^3 + 739738496000000*Sqrt[3]*NH*Pi^3 + 
         26074901160000*CF*Pi^4 + 469916039544000*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] - 3596344265472000*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 4083167491200000*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 11163920644800000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 27391459737600000*Sqrt[3]*
          NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 232581680100000*Sqrt[3]*
          CF*Pi*Log[3]^2 + 570655411200000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         171460800*(7*CA*(10883659 + 4414080*lm) - 
           8*(8625792*CF + 35*(19381 + 20064*lm)*NM + 
             15*(66122*NL + 46816*lm*NL + 6785*NH + 46816*lm*NH)))*
          Log[x]^2 + 384072192000*(9283*CA + 54626*CF - 12086*NM - 1672*NL)*
          Log[x]^3 + 507895927392000*CF*PolyGamma[2, 1] - 
         459686404800000*NM*PolyGamma[2, 1] + 964898140416000*NH*
          PolyGamma[2, 1] - 196*CA*(-912531035250*Pi^2 + 769119312500*Sqrt[3]*
            Pi^3 + 71416485000*Pi^4 - 56133000*lm*(66599 + 600*Pi^2) + 
           593320612500*Sqrt[3]*Pi*Log[3]^2 + 21*(-721171315473 + 
             57084067000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             496011600000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1356161400000*
              Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             61697756000*PolyGamma[2, 1] - 1186130516000*Zeta[3])) - 
         11943788088288000*CF*Zeta[3] - 3480174149760000*NM*Zeta[3] + 
         977655764736000*NL*Zeta[3] + 2434851213312000*NH*Zeta[3] - 
         15120*Log[x]*(40*(-1323*NM*(515999 + 128100*lm - 1009200*Pi^2) - 
             5*(15876*NL*(20784 + 2135*lm + 3344*Pi^2) + NH*(5455811463 + 
                 33895260*lm - 3019340800*Sqrt[3]*Im[PolyLog[2, (-1)^
                     (1/3)]]))) + 49*CA*(3127102743 + 760914000*lm + 
             315827100*Pi^2 - 2511410000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             2099520000*Zeta[3]) - 49*CF*(4470532161 + 385317000*Pi^2 - 
             5022820000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             4199040000*Zeta[3]))))/7777461888000, 
      -(CF*NC*(3723187024783377*CF - 12036823076008800*NM - 
          876832413508800*lm*NM - 6084394351131600*NL - 
          876832413508800*lm*NL - 151422197486179680*NH - 
          876832413508800*lm*NH + 353824777983600*CF*Pi^2 - 
          443151296784000*NM*Pi^2 - 6961308480000*lm*NM*Pi^2 + 
          495889209648000*NL*Pi^2 - 6961308480000*lm*NL*Pi^2 - 
          6961308480000*lm*NH*Pi^2 + 2221255473640000*Sqrt[3]*CF*Pi^3 + 
          5259490381600000*Sqrt[3]*NH*Pi^3 + 191375971920000*CF*Pi^4 + 
          4975396239004800*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          28939335539520000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          28491435383040000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          82249916966784000*Sqrt[3]*CF*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]] + 194751415272960000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1713539936808000*Sqrt[3]*
           CF*Pi*Log[3]^2 + 4057321151520000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          342921600*(369173171*CF - 12*CA*(28482077 + 9536450*lm) + 
            20*(4*(380893 + 260085*lm)*NM + 15*(96117*NL + 69356*lm*NL + 
                10972*NH + 69356*lm*NH)))*Log[x]^2 + 192036096000*
           (92071*CA + 947700*CF - 182500*NM - 24770*NL)*Log[x]^3 + 
          14010652218080000*CF*PolyGamma[2, 1] + 1056198528000000*NM*
           PolyGamma[2, 1] + 7732479331360000*NH*PolyGamma[2, 1] - 
          80*CA*(-248168415666861 + 1500511864635*Pi^2 + 13882846710250*
             Sqrt[3]*Pi^3 + 1265712909300*Pi^4 - 27505170*lm*
             (2191669 + 17400*Pi^2) + 31096226493780*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 178071471144000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 514061981042400*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10709624605050*Sqrt[3]*
             Pi*Log[3]^2 + 87566576363000*PolyGamma[2, 1] - 
            432666192072800*Zeta[3]) - 84870811292288000*CF*Zeta[3] - 
          16547750392320000*NM*Zeta[3] + 7218636848640000*NL*Zeta[3] + 
          21108899524160000*NH*Zeta[3] - 15120*Log[x]*
           (-40*(108*NM*(103609238 + 10530345*lm - 91279650*Pi^2) + 
              19845*NL*(626381 + 57308*lm + 99080*Pi^2) + 
              2*NH*(97056132591 + 568638630*lm - 53668269200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 8*CA*(75545210688 + 
              31275124650*lm + 32446277325*Pi^2 - 113329360900*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 90016920000*Zeta[3]) - 
            CF*(556810094931 + 424733803200*Pi^2 - 1813269774400*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 1440270720000*Zeta[3]))))/
       38887309440000, (CF*NC*(15648869200308002109*CF + 
         13751788513329876240*NM - 2301004249087420800*lm*NM - 
         20214298797053961600*NL - 2301004249087420800*lm*NL - 
         494792161109572672080*NH - 2301004249087420800*lm*NH - 
         2658723014460189600*CF*Pi^2 - 22343501476717344000*NM*Pi^2 - 
         17253002954880000*lm*NM*Pi^2 + 1489796805153888000*NL*Pi^2 - 
         17253002954880000*lm*NL*Pi^2 - 17253002954880000*lm*NH*Pi^2 + 
         7174988961739060000*Sqrt[3]*CF*Pi^3 + 17828372225232800000*Sqrt[3]*
          NH*Pi^3 + 587584563134184000*CF*Pi^4 + 7744969496616475200*Sqrt[3]*
          CF*Im[PolyLog[2, (-1)^(1/3)]] - 84440478375496320000*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 81727474997266560000*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 265679591268966336000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 660159154397191680000*
          Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         5534991484770132000*Sqrt[3]*CF*Pi*Log[3]^2 + 13753315716608160000*
          Sqrt[3]*NH*Pi*Log[3]^2 - 62240270400*
          (11*CA*(532661849 + 190436400*lm) - 20*(299447401*CF + 
             126*(33*(-41327 + 4580*lm)*NM + 110*(1873 + 1374*lm)*NL + 
               (27767 + 151140*lm)*NH)))*Log[x]^2 + 383400065664000*
          (182713*CA + 1667342*CF - 180*(3535*NM + 229*NL))*Log[x]^3 + 
         19579425364637600000*CF*PolyGamma[2, 1] - 61541461540056960000*NM*
          PolyGamma[2, 1] + 22248187481175040000*NH*PolyGamma[2, 1] - 
         5324*CA*(-9694427845597191 - 251716365567450*Pi^2 + 
           673834425407500*Sqrt[3]*Pi^3 + 57775109679000*Pi^4 - 
           29705583600*lm*(80021 + 600*Pi^2) + 727363776917400*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 7675382700720000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 24951126152232000*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 519815128171500*Sqrt[3]*
            Pi*Log[3]^2 + 1838789008700000*PolyGamma[2, 1] - 
           23160813651836000*Zeta[3]) - 292561090633595168000*CF*Zeta[3] - 
         125360319470158080000*NM*Zeta[3] + 23912662095463680000*NL*
          Zeta[3] + 27691950084296960000*NH*Zeta[3] - 
         166320*Log[x]*(280*(-882090*NM*(1583753 + 53592*lm - 1282260*
                Pi^2) - 9261945*NL*(61273 + 5104*lm + 9160*Pi^2) - 
             2*NH*(4263197455389 + 23636483640*lm - 2362625526800*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) + 121*CA*(1253648624757 + 
             601655947200*lm + 531984518100*Pi^2 - 2200275674800*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 1620304560000*Zeta[3]) - 
           121*CF*(803949766887 + 836045242200*Pi^2 - 4400551349600*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 3240609120000*Zeta[3]))))/
       77638513296960000, (13507236143437397*CF^2*NC)/11666192832000 - 
       (64297574557*CF*NM*NC)/385786800 + (3634481*CF*lm*NM*NC)/97200 + 
       (428498329*CF*NC*NL)/1166400 + (3634481*CF*lm*NC*NL)/97200 + 
       (23670062228163469*CF*NC*NH)/2772804046320 + (3634481*CF*lm*NC*NH)/
        97200 - (140964569*CF^2*NC*Pi^2)/272160 + (3606043*CF*NM*NC*Pi^2)/
        9720 + (41*CF*lm*NM*NC*Pi^2)/162 - (27869*CF*NC*NL*Pi^2)/1080 + 
       (41*CF*lm*NC*NL*Pi^2)/162 + (41*CF*lm*NC*NH*Pi^2)/162 - 
       (4913919745*CF^2*NC*Pi^3)/(12754584*Sqrt[3]) - 
       (5988749515*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) - 
       (1691*CF^2*NC*Pi^4)/162 - (6053757989*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10628820*Sqrt[3]) + 
       (5147974187*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1062882*Sqrt[3]) - 
       1400*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (280795414*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (19683*Sqrt[3]) - (684428516*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (140397707*CF^2*NC*Pi*Log[3]^2)/(472392*Sqrt[3]) - 
       (171107129*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) - 
       (CF*NC*(-99*CA*(384821363 + 89273800*lm) + 
          20*(2583934683*CF + 7*(22*(-4237919 + 521730*lm)*NM + 
              5*(99*(31111 + 23188*lm)*NL + 34*(13289 + 67518*lm)*NH))))*
         Log[x]^2)/3742200 + (2*CF*NC*(13411*CA - 3007245*CF + 906620*NM + 
          57970*NL)*Log[x]^3)/405 - (18286459415*CF^2*NC*PolyGamma[2, 1])/
        6377292 + (22765*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (1355408795*CF*NC*NH*PolyGamma[2, 1])/3188646 + 
       CA*CF*NC*(-46091119435968703/29165482080000 + (4444369*Pi^2)/17010 + 
         (4913919745*Pi^3)/(25509168*Sqrt[3]) + (8783*Pi^4)/1620 - 
         (11*lm*(3634481 + 24600*Pi^2))/194400 + 
         (6053757989*Im[PolyLog[2, (-1)^(1/3)]])/(21257640*Sqrt[3]) + 
         700*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (140397707*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) + 
         (140397707*Pi*Log[3]^2)/(944784*Sqrt[3]) + 
         (18286459415*PolyGamma[2, 1])/12754584 - (3667801321*Zeta[3])/
          6377292) + (3133952969*CF^2*NC*Zeta[3])/1594323 + 
       (22573*CF*NM*NC*Zeta[3])/54 - (3892*CF*NC*NL*Zeta[3])/9 - 
       (988438943*CF*NC*NH*Zeta[3])/1594323 - 
       (CF*NC*Log[x]*(-121*CA*(9928390906929 + 7009810453800*lm + 
            18396243558000*Pi^2 - 27517950572000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 19443654720000*Zeta[3]) + 
          5*(-28*(-39204*NM*(1332199684 + 28097685*lm - 735975450*Pi^2) - 
              5*(20376279*NL*(143139 + 10812*lm + 21080*Pi^2) + 
                2*NH*(20928944469651 + 110154164274*lm - 11594219061040*
                   Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
            121*CF*(-365602782291 + 6759156196800*Pi^2 - 11007180228800*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 7777461888000*Zeta[3]))))/
        4201218252000, (-97355510998456507*CF^2*NC)/116661928320000 + 
       (72603598400099*CF*NM*NC)/10802030400 - (4582699*CF*lm*NM*NC)/
        97200 - (1652471699*CF*NC*NL)/2916000 - (4582699*CF*lm*NC*NL)/
        97200 - (5021420674669602438247*CF*NC*NH)/387663212985048000 - 
       (4582699*CF*lm*NC*NH)/97200 + (11418278*CF^2*NC*Pi^2)/25515 - 
       (6212327*CF*NM*NC*Pi^2)/2430 - (49*CF*lm*NM*NC*Pi^2)/162 + 
       (58639*CF*NC*NL*Pi^2)/1620 - (49*CF*lm*NC*NL*Pi^2)/162 - 
       (49*CF*lm*NC*NH*Pi^2)/162 + (29299101965*CF^2*NC*Pi^3)/
        (51018336*Sqrt[3]) + (9310038185*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) + 
       (32081*CF^2*NC*Pi^4)/2160 + (15203397007*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(42515280*Sqrt[3]) - 
       (18172899874*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) + 
       (5705*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (837117199*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (39366*Sqrt[3]) + (1064004364*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) + 
       (837117199*CF^2*NC*Pi*Log[3]^2)/(1889568*Sqrt[3]) + 
       (266001091*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) + 
       (CF*NC*(-39*CA*(3045835613 + 818202000*lm) + 
          8*(18664825881*CF + 5*(65*(-99331951 + 2231460*lm)*NM + 
              114660*(1677 + 1265*lm)*NL + (31595833 + 145044900*lm)*NH)))*
         Log[x]^2)/8845200 + (2*CF*NC*(130197*CA + 4601828*CF - 3316120*NM - 
          88550*NL)*Log[x]^3)/405 + (27311603261*CF^2*NC*PolyGamma[2, 1])/
        19131876 - (213437*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (5607948605*CF*NC*NH*PolyGamma[2, 1])/9565938 - 
       (CA*CF*NC*(-1824793470123169041 + 240691622269581000*Pi^2 + 
          100495919739950000*Sqrt[3]*Pi^3 + 8051212343412000*Pi^4 - 
          59411167200*lm*(4582699 + 29400*Pi^2) + 62577182080812000*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 998334451598400000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 3721220342370720000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 77525423799390000*Sqrt[3]*
           Pi*Log[3]^2 + 749430393481840000*PolyGamma[2, 1] - 
          3361794616489456000*Zeta[3]))/1049957354880000 - 
       (721873375807*CF^2*NC*Zeta[3])/95659380 - (299926*CF*NM*NC*Zeta[3])/
        27 + (5936*CF*NC*NL*Zeta[3])/9 + (973546889*CF*NC*NH*Zeta[3])/
        4782969 + (CF*NC*Log[x]*
         (-40*(-301158*NM*(25904460049 + 577052910*lm - 41528308500*Pi^2) - 
            199216017*NL*(12497529 + 872340*lm + 1771000*Pi^2) - 
            2*NH*(17463184312836117 + 86892050134890*lm - 9692122152112400*
               Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
          37180*CA*(-537245927832 + 1028308285620*lm + 2197475369145*Pi^2 - 
            4101874275100*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            2722111660800*Zeta[3]) + 1859*CF*(-89241875638059 + 
            78984124795800*Pi^2 - 164074971004000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 108884466432000*Zeta[3])))/
        129091979016000, (9422047554100811317187*CF^2*NC)/
        652163511694464000 - (30890539858939933*CF*NM*NC)/3594375615600 + 
       (54926339*CF*lm*NM*NC)/952560 + (220243651459*CF*NC*NL)/285768000 + 
       (54926339*CF*lm*NC*NL)/952560 + (53859814587916049396323*CF*NC*NH)/
        3198221507126646000 + (54926339*CF*lm*NC*NH)/952560 - 
       (54583728877*CF^2*NC*Pi^2)/11430720 + (220188491*CF*NM*NC*Pi^2)/
        68040 + (55*CF*lm*NM*NC*Pi^2)/162 - (212339*CF*NC*NL*Pi^2)/4536 + 
       (55*CF*lm*NC*NL*Pi^2)/162 + (55*CF*lm*NC*NH*Pi^2)/162 - 
       (29250490705*CF^2*NC*Pi^3)/(38263752*Sqrt[3]) - 
       (36830519215*CF*NC*NH*Pi^3)/(19131876*Sqrt[3]) - 
       (3173*CF^2*NC*Pi^4)/162 - (1041713404181*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1562436540*Sqrt[3]) + 
       (152983775059*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15943230*Sqrt[3]) - 2440*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (11700196282*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (413343*Sqrt[3]) - (4209202196*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (5850098141*CF^2*NC*Pi*Log[3]^2)/(9920232*Sqrt[3]) - 
       (1052300549*CF*NC*NH*Pi*Log[3]^2)/(708588*Sqrt[3]) - 
       (CF*NC*(4988703090787*CF - 13*CA*(227578090613 + 25534305720*lm) + 
          28*(26*(-3449727761 + 82903590*lm)*NM + 315315*(8943 + 6836*lm)*
             NL + 2*(248086561 + 1077746670*lm)*NH))*Log[x]^2)/68108040 + 
       (2*CF*NC*(2251775*CA - 14071176*CF + 98*(63646*NM + 1709*NL))*
         Log[x]^3)/567 - (1425010077827*CF^2*NC*PolyGamma[2, 1])/57395628 + 
       (336209*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (23616015743*CF*NC*NH*PolyGamma[2, 1])/28697814 - 
       (5269599814349*CF^2*NC*Zeta[3])/200884698 - (6031*CF*NM*NC*Zeta[3])/
        54 - (8012*CF*NC*NL*Zeta[3])/9 - (6392367227*CF*NC*NH*Zeta[3])/
        14348907 + CA*CF*NC*(-1451726840967187459303/163040877923616000 + 
         (1712923063*Pi^2)/714420 + (29250490705*Pi^3)/(76527504*Sqrt[3]) + 
         (1087*Pi^4)/108 - (11*lm*(54926339 + 323400*Pi^2))/1905120 + 
         (1041713404181*Im[PolyLog[2, (-1)^(1/3)]])/(3124873080*Sqrt[3]) + 
         1220*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (5850098141*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (413343*Sqrt[3]) + (5850098141*Pi*Log[3]^2)/(19840464*Sqrt[3]) + 
         (1425010077827*PolyGamma[2, 1])/114791256 + (5575658812013*Zeta[3])/
          401769396) - (CF*NC*Log[x]*
         (-56*(-164268*NM*(4124878460558 + 43913625525*lm - 3368074282650*Pi^
                2) - 939161223*NL*(119703021 + 7680900*lm + 16748200*Pi^2) - 
            10*NH*(152003169416340681 + 721360343774070*lm - 
              84352496191883920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
          2366*CA*(6149026597433757 + 939048968226600*lm + 7721005572126000*
             Pi^2 - 3964026500341600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            2540896798809600*Zeta[3]) + 169*CF*(125371107207861297 + 
            209892879429987600*Pi^2 - 110992742009564800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 71145110366668800*Zeta[3])))/
        5964049430539200, (-97186774767699195352097*CF^2*NC)/
        7336839506562720000 + (550245683532209683*CF*NM*NC)/8985939039000 - 
       (20988631*CF*lm*NM*NC)/297675 - (8010687217*CF*NC*NL)/7144200 - 
       (20988631*CF*lm*NC*NL)/297675 - (347752498122181502463703*CF*NC*NH)/
        14391996782069907000 - (20988631*CF*lm*NC*NH)/297675 + 
       (16435733849*CF^2*NC*Pi^2)/3742200 - (162155506*CF*NM*NC*Pi^2)/8505 - 
       (32*CF*lm*NM*NC*Pi^2)/81 + (177172*CF*NC*NL*Pi^2)/2835 - 
       (32*CF*lm*NC*NL*Pi^2)/81 - (32*CF*lm*NC*NH*Pi^2)/81 + 
       (370252924007*CF^2*NC*Pi^3)/(344373768*Sqrt[3]) + 
       (120957731720*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) + 
       (4279*CF^2*NC*Pi^4)/162 + (15801086299829*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(70309644300*Sqrt[3]) - 
       (188429109320*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (14348907*Sqrt[3]) + (9544*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (740505848014*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (18600435*Sqrt[3]) + (55294963072*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) + 
       (370252924007*CF^2*NC*Pi*Log[3]^2)/(446410440*Sqrt[3]) + 
       (3455935192*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) + 
       (CF*NC*(-65*CA*(124397163197 + 18347646240*lm) + 
          8*(1605403170319*CF + 140*(13*(-2642871409 + 14892570*lm)*NM + 
              630630*(398 + 307*lm)*NL + (47975171 + 193603410*lm)*NH)))*
         Log[x]^2)/170270100 - (2*CF*NC*(9400493*CA + 
          20*(-4582217*CF + 6625388*NM + 60172*NL))*Log[x]^3)/2835 + 
       (473963166926*CF^2*NC*PolyGamma[2, 1])/43046721 - 
       (1971332*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (47166867988*CF*NC*NH*PolyGamma[2, 1])/43046721 - 
       (9003415053706*CF^2*NC*Zeta[3])/1506635235 - 
       (2864200*CF*NM*NC*Zeta[3])/27 + (11504*CF*NC*NL*Zeta[3])/9 - 
       (14981551960*CF*NC*NH*Zeta[3])/43046721 + 
       CA*CF*NC*(8049390902485034345123/917104938320340000 - 
         (9029698739*Pi^2)/4082400 - (370252924007*Pi^3)/
          (688747536*Sqrt[3]) - (21907*Pi^4)/1620 + 
         lm*(230874941/595350 + (176*Pi^2)/81) - 
         (15801086299829*Im[PolyLog[2, (-1)^(1/3)]])/(140619288600*Sqrt[3]) - 
         (4772*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (370252924007*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (18600435*Sqrt[3]) - (370252924007*Pi*Log[3]^2)/
          (892820880*Sqrt[3]) - (236981583463*PolyGamma[2, 1])/43046721 + 
         (5905494004021*Zeta[3])/3013270470) + 
       CF*Log[x]*((-6083117856643*NM*NC)/648336150 + (3272*lm*NM*NC)/35 + 
         (982691*NC*NL)/630 + (3272*lm*NC*NL)/35 + 
         (1661436482417888887*NC*NH)/79875662016150 + (3272*lm*NC*NH)/35 - 
         (1860320*NM*NC*Pi^2)/81 + (17192*NC*NL*Pi^2)/81 - 
         (55294963072*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CA*NC*(5957879043159067/6616918746900 - (17996*lm)/35 - 
           (36511681*Pi^2)/11340 + (370252924007*Im[PolyLog[2, (-1)^(1/3)]])/
            (55801305*Sqrt[3]) - 1344*Zeta[3]) + 
         CF*NC*(-493578745513533133/132338374938000 + (35088791*Pi^2)/5670 - 
           (740505848014*Im[PolyLog[2, (-1)^(1/3)]])/(55801305*Sqrt[3]) + 
           2688*Zeta[3])), (1549586725298587209893419231*CF^2*NC)/
        12895229116734636672000 - (13738923457927740204953*CF*NM*NC)/
        180499273770816000 + (1604274461*CF*lm*NM*NC)/19051200 + 
       (1690265424971*CF*NC*NL)/1143072000 + (1604274461*CF*lm*NC*NL)/
        19051200 + (1882798693957471980791429*CF*NC*NH)/
        61405852936831603200 + (1604274461*CF*lm*NC*NH)/19051200 - 
       (1855428785869*CF^2*NC*Pi^2)/50295168 + (1570714021*CF*NM*NC*Pi^2)/
        68040 + (71*CF*lm*NM*NC*Pi^2)/162 - (296539*CF*NC*NL*Pi^2)/3780 + 
       (71*CF*lm*NC*NL*Pi^2)/162 + (71*CF*lm*NC*NH*Pi^2)/162 - 
       (1907500472525*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (103528826975*CF*NC*NH*Pi^3)/(28697814*Sqrt[3]) - 
       (21821*CF^2*NC*Pi^4)/648 - (57813230153477*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(112495430880*Sqrt[3]) + 
       (845323607153*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (47829690*Sqrt[3]) - 3970*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (381500094505*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7440174*Sqrt[3]) - (23663731880*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (381500094505*CF^2*NC*Pi*Log[3]^2)/(357128352*Sqrt[3]) - 
       (2957966485*CF*NC*NH*Pi*Log[3]^2)/(1062882*Sqrt[3]) - 
       (CF*NC*(-21*CA*(16176899865913 + 594541147200*lm) + 
          40*(16106834936811*CF + 343*((-27147530401 + 165456720*lm)*NM + 
              5*(5148*(8241 + 6428*lm)*NL + (8577709 + 33091344*lm)*NH))))*
         Log[x]^2)/1362160800 + (CF*NC*(405656693*CA - 
          70*(17244433*CF - 9576632*NM - 89992*NL))*Log[x]^3)/5670 - 
       (114308802097397*CF^2*NC*PolyGamma[2, 1])/516560652 + 
       (1661147*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (762283948369*CF*NC*NH*PolyGamma[2, 1])/516560652 - 
       (1237525332446749*CF^2*NC*Zeta[3])/3615924564 + 
       (302573*CF*NM*NC*Zeta[3])/27 - (15046*CF*NC*NL*Zeta[3])/9 + 
       (56318007335*CF*NC*NH*Zeta[3])/258280326 + 
       CA*CF*NC*(-16187716275431947332758828719/257904582334692733440000 + 
         (168889021345*Pi^2)/9144576 + (1907500472525*Pi^3)/
          (2754990144*Sqrt[3]) + (111377*Pi^4)/6480 - 
         (11*lm*(1604274461 + 8349600*Pi^2))/38102400 + 
         (57813230153477*Im[PolyLog[2, (-1)^(1/3)]])/(224990861760*Sqrt[3]) + 
         1985*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (381500094505*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (14880348*Sqrt[3]) + (381500094505*Pi*Log[3]^2)/
          (714256704*Sqrt[3]) + (114308802097397*PolyGamma[2, 1])/
          1033121304 + (1247174494107349*Zeta[3])/7231849128) + 
       CF*Log[x]*((-452138597483227*NM*NC)/70124037984 - 
         (144763*lm*NM*NC)/1260 - (155987519*NC*NL)/75600 - 
         (144763*lm*NC*NL)/1260 - (11375830225970790473*NC*NH)/
          426003530752800 - (144763*lm*NC*NH)/1260 + (2350408*NM*NC*Pi^2)/
          81 - (22498*NC*NL*Pi^2)/81 + (23663731880*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-431808088232775844141/7156859316647040 - 
           (59789123*Pi^2)/1512 + (381500094505*Im[PolyLog[2, (-1)^(1/3)]])/
            (22320522*Sqrt[3]) - 3360*Zeta[3]) + 
         CA*NC*(11249797373679231308299/357842965832352000 + 
           (1592393*lm)/2520 + (180889603*Pi^2)/9072 - 
           (381500094505*Im[PolyLog[2, (-1)^(1/3)]])/(44641044*Sqrt[3]) + 
           1680*Zeta[3])), (-13970129456916514182983974217*CF^2*NC)/
        128952291167346366720000 + (65181690315944002903007*CF*NM*NC)/
        140388324043968000 - (212891299*CF*lm*NM*NC)/2116800 - 
       (913567957289*CF*NC*NL)/444528000 - (212891299*CF*lm*NC*NL)/
        2116800 - (5448864024345758388799527599*CF*NC*NH)/
        129294409490851571366400 - (212891299*CF*lm*NC*NH)/2116800 + 
       (81131821844477*CF^2*NC*Pi^2)/2514758400 - (24908789*CF*NM*NC*Pi^2)/
        180 - (CF*lm*NM*NC*Pi^2)/2 + (84797*CF*NC*NL*Pi^2)/840 - 
       (CF*lm*NC*NL*Pi^2)/2 - (CF*lm*NC*NH*Pi^2)/2 + 
       (5137758996949*CF^2*NC*Pi^3)/(2754990144*Sqrt[3]) + 
       (216192261530*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) + 
       (94307*CF^2*NC*Pi^4)/2160 - (340292055175379*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1124954308800*Sqrt[3]) - 
       (1688256362834*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (71744535*Sqrt[3]) + 5017*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (5137758996949*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (74401740*Sqrt[3]) + (98830748128*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) + 
       (5137758996949*CF^2*NC*Pi*Log[3]^2)/(3571283520*Sqrt[3]) + 
       (6176921758*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) + 
       ((583550053523183*CF^2*NC)/1362160800 + 
         CA*CF*(-631743595502909/2724321600 - 12584*lm)*NC + 
         CF*NC*((-894987535087/540540 + 2288*lm)*NM + (8738/3 + 2288*lm)*
            NL + (823559879*NH)/1312740 + 2288*lm*NH))*Log[x]^2 + 
       (CF*NC*(-360752627*CA + 462*(2800249*CF - 360*(20375*NM + 52*NL)))*
         Log[x]^3)/5670 + (147965750561507*CF^2*NC*PolyGamma[2, 1])/
        1549681956 - (1322109*CF*NM*NC*PolyGamma[2, 1])/2 + 
       (739808272195*CF*NC*NH*PolyGamma[2, 1])/387420489 + 
       CA*CF*NC*(3709367748342724083009274469/64476145583673183360000 - 
         (27098765341939*Pi^2)/1676505600 - (5137758996949*Pi^3)/
          (5509980288*Sqrt[3]) - (19207*Pi^4)/864 + 
         lm*(2341804289/4233600 + (11*Pi^2)/4) + 
         (340292055175379*Im[PolyLog[2, (-1)^(1/3)]])/(2249908617600*
           Sqrt[3]) - (5017*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
         (5137758996949*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (148803480*Sqrt[3]) - (5137758996949*Pi*Log[3]^2)/
          (7142567040*Sqrt[3]) - (147965750561507*PolyGamma[2, 1])/
          3099363912 - (10036891495201111*Zeta[3])/216955473840) + 
       (9657808008146251*CF^2*NC*Zeta[3])/108477736920 - 
       (3106433*CF*NM*NC*Zeta[3])/3 + 2294*CF*NC*NL*Zeta[3] - 
       (614003778166*CF*NC*NH*Zeta[3])/387420489 + 
       CF*Log[x]*((-39077536061548601*NM*NC)/194788994400 + 
         (21237*lm*NM*NC)/140 + (765511219*NC*NL)/264600 + 
         (21237*lm*NC*NL)/140 + (1958933367801915756019*NC*NH)/
          52763580166096800 + (21237*lm*NC*NH)/140 - (446186*NM*NC*Pi^2)/
          3 + (1144*NC*NL*Pi^2)/3 - (98830748128*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CA*NC*(-149533699969965183629/14605835340096000 - (233607*lm)/280 - 
           (1700409101*Pi^2)/90720 + (5137758996949*Im[PolyLog[2, (-1)^
                (1/3)]])/(446410440*Sqrt[3]) - 2160*Zeta[3]) + 
         CF*NC*(6070310601491674486433/357842965832352000 + 
           (559956427*Pi^2)/15120 - (5137758996949*Im[PolyLog[2, (-1)^
                (1/3)]])/(223205220*Sqrt[3]) + 4320*Zeta[3])), 
      (3209638952584189283300267207143*CF^2*NC)/3481711861518351901440000 - 
       (53716930436775134650117*CF*NM*NC)/97191916645824000 + 
       (20212282171*CF*lm*NM*NC)/171460800 + (63401061529753*CF*NC*NL)/
        24004512000 + (20212282171*CF*lm*NC*NL)/171460800 + 
       (1280741108027108430021253465603*CF*NC*NH)/
        24436643393770946988249600 + (20212282171*CF*lm*NC*NH)/171460800 - 
       (19208939699161*CF^2*NC*Pi^2)/68584320 + (4651550239*CF*NM*NC*Pi^2)/
        29160 + (89*CF*lm*NM*NC*Pi^2)/162 - (12632567*CF*NC*NL*Pi^2)/
        102060 + (89*CF*lm*NC*NL*Pi^2)/162 + (89*CF*lm*NC*NH*Pi^2)/162 - 
       (3223483997935*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (4887271681075*CF*NC*NH*Pi^3)/(774840978*Sqrt[3]) - 
       (175643*CF^2*NC*Pi^4)/3240 + (390305421059683*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3037376633760*Sqrt[3]) + 
       (831777262713569*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27119434230*Sqrt[3]) - (18370*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        3 - (644696799587*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7440174*Sqrt[3]) - (1117090669960*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) - 
       (644696799587*CF^2*NC*Pi*Log[3]^2)/(357128352*Sqrt[3]) - 
       (139636333745*CF*NC*NH*Pi*Log[3]^2)/(28697814*Sqrt[3]) - 
       (CF*NC*(237190718396050934*CF - 51*CA*(2356352444617999 + 
            21859653816000*lm) + 840*(663*(-238022038057 + 363963600*lm)*
             NM + 5*(9189180*(6623 + 5252*lm)*NL + (13737277643 + 
                48261573360*lm)*NH)))*Log[x]^2)/69470200800 + 
       (CF*NC*(9398765873*CA - 36*(585135759*CF - 700*(481031*NM + 
              1313*NL)))*Log[x]^3)/17010 - (9239223981283793*CF^2*NC*
         PolyGamma[2, 1])/4649045868 + (45743405*CF*NM*NC*PolyGamma[2, 1])/
        162 - (11576761798837*CF*NC*NH*PolyGamma[2, 1])/4649045868 - 
       (548697421285825061*CF^2*NC*Zeta[3])/162716605380 + 
       (18128183*CF*NM*NC*Zeta[3])/81 - (78958*CF*NC*NL*Zeta[3])/27 + 
       (3952084521587*CF*NC*NH*Zeta[3])/2324522934 + 
       CA*CF*NC*(-647662824769532431043976567731/1392684744607340760576000 + 
         (42272966878075*Pi^2)/301771008 + (3223483997935*Pi^3)/
          (2754990144*Sqrt[3]) + (59497*Pi^4)/2160 + 
         lm*(-222335103881/342921600 - (979*Pi^2)/324) - 
         (390305421059683*Im[PolyLog[2, (-1)^(1/3)]])/(6074753267520*
           Sqrt[3]) + (9185*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (644696799587*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (14880348*Sqrt[3]) + (644696799587*Pi*Log[3]^2)/
          (714256704*Sqrt[3]) + (9239223981283793*PolyGamma[2, 1])/
          9298091736 + (549418831382318231*Zeta[3])/325433210760) + 
       CF*Log[x]*((5791147379188277*NM*NC)/44951306400 - 
         (6222439*lm*NM*NC)/34020 - (17733298111*NC*NL)/4762800 - 
         (6222439*lm*NC*NL)/34020 - (22138973339679727539763*NC*NH)/
          474872221494871200 - (6222439*lm*NC*NH)/34020 + 
         (531800*NM*NC*Pi^2)/3 - (13130*NC*NL*Pi^2)/27 + 
         (1117090669960*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CF*NC*(-55973398376715643072759/
            89460741458088000 - (19251999271*Pi^2)/68040 + 
           (644696799587*Im[PolyLog[2, (-1)^(1/3)]])/(22320522*Sqrt[3]) - 
           5280*Zeta[3]) + CA*NC*(112753671912533319901109/
            357842965832352000 + (68446829*lm)/68040 + (19291970671*Pi^2)/
            136080 - (644696799587*Im[PolyLog[2, (-1)^(1/3)]])/
            (44641044*Sqrt[3]) + 2640*Zeta[3])), 
      (-274178474735628130241647198501*CF^2*NC)/348171186151835190144000 + 
       (432879146175584910385601*CF*NM*NC)/126349491639571200 - 
       (236939939*CF*lm*NM*NC)/1714608 - (42483760970381*CF*NC*NL)/
        12002256000 - (236939939*CF*lm*NC*NL)/1714608 - 
       (166722268911219983496827868992131*CF*NC*NH)/
        2394441957683927505605771520 - (236939939*CF*lm*NC*NH)/1714608 + 
       (64426198365071*CF^2*NC*Pi^2)/280215936 - (5218964750*CF*NM*NC*Pi^2)/
        5103 - (50*CF*lm*NM*NC*Pi^2)/81 + (789995*CF*NC*NL*Pi^2)/5103 - 
       (50*CF*lm*NC*NL*Pi^2)/81 - (50*CF*lm*NC*NH*Pi^2)/81 + 
       (12592769425025*CF^2*NC*Pi^3)/(4132485216*Sqrt[3]) + 
       (6557649320075*CF*NC*NH*Pi^3)/(774840978*Sqrt[3]) + 
       (44195*CF^2*NC*Pi^4)/648 - (918497962251875*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(607475326752*Sqrt[3]) - 
       (108133850151644*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2711943423*Sqrt[3]) + 7550*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (2518553885005*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (22320522*Sqrt[3]) + (1498891273160*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) + 
       (2518553885005*CF^2*NC*Pi*Log[3]^2)/(1071385056*Sqrt[3]) + 
       (187361409145*CF*NC*NH*Pi*Log[3]^2)/(28697814*Sqrt[3]) + 
       (CF*NC*(-6783*CA*(56224331784461 + 827579712960*lm) + 
          2*(373430345158691053*CF + 840*(2907*(-662960331071 + 208984776*lm)*
               NM + 69837768*(10908 + 8699*lm)*NL + (180768457505 + 
                607518743832*lm)*NH)))*Log[x]^2)/263986763040 - 
       (2*CF*NC*(397905973*CA - 953209429*CF + 252*(14076857*NM + 8699*NL))*
         Log[x]^3)/1701 + (5946892543218211*CF^2*NC*PolyGamma[2, 1])/
        6973568802 - (482520008*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (10974037049782*CF*NC*NH*PolyGamma[2, 1])/3486784401 + 
       CA*CF*NC*(283377321475422633944614043/710553441126194265600 - 
         (4958359312007*Pi^2)/43110144 - (12592769425025*Pi^3)/
          (8264970432*Sqrt[3]) - (14945*Pi^4)/432 + 
         lm*(2606339329/3429216 + (275*Pi^2)/81) + 
         (918497962251875*Im[PolyLog[2, (-1)^(1/3)]])/(1214950653504*
           Sqrt[3]) - 3775*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (2518553885005*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (44641044*Sqrt[3]) - (2518553885005*Pi*Log[3]^2)/
          (2142770112*Sqrt[3]) - (5946892543218211*PolyGamma[2, 1])/
          13947137604 - (115077178561451461*Zeta[3])/195259926456) + 
       (114524202449728069*CF^2*NC*Zeta[3])/97629963228 - 
       (797782216*CF*NM*NC*Zeta[3])/81 + (104588*CF*NC*NL*Zeta[3])/27 - 
       (13573219135216*CF*NC*NH*Zeta[3])/3486784401 + 
       CF*Log[x]*((-10264311294133639*NM*NC)/4869724860 + 
         (397165*lm*NM*NC)/1701 + (23887889089*NC*NL)/4762800 + 
         (397165*lm*NC*NL)/1701 + (3749071117704261893130931*NC*NH)/
          60000105185876976120 + (397165*lm*NC*NH)/1701 - 
         (3124870*NM*NC*Pi^2)/3 + (17398*NC*NL*Pi^2)/27 - 
         (1498891273160*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CA*NC*(-5047677572692473653381/
            30672254214201600 - (4368815*lm)/3402 - (1104976919*Pi^2)/9072 + 
           (2518553885005*Im[PolyLog[2, (-1)^(1/3)]])/(133923132*Sqrt[3]) - 
           3300*Zeta[3]) + CF*NC*(34689564228319672720889/
            107352889749705600 + (367165385*Pi^2)/1512 - 
           (2518553885005*Im[PolyLog[2, (-1)^(1/3)]])/(66961566*Sqrt[3]) + 
           6600*Zeta[3])), (90519441275654686983247920291478111*CF^2*NC)/
        12829237781729747168831040000 - (24173731107372016220348577043*CF*NM*
         NC)/6207550524252133056000 + (5470817083*CF*lm*NM*NC)/34292160 + 
       (106850034431309*CF*NC*NL)/24004512000 + (5470817083*CF*lm*NC*NL)/
        34292160 + (353781793851126110226820653624077*CF*NC*NH)/
        4155643067054750216340595200 + (5470817083*CF*lm*NC*NH)/34292160 - 
       (10604913326134879*CF^2*NC*Pi^2)/4903778880 + 
       (229349191121*CF*NM*NC*Pi^2)/204120 + (109*CF*lm*NM*NC*Pi^2)/162 - 
       (19006933*CF*NC*NL*Pi^2)/102060 + (109*CF*lm*NC*NL*Pi^2)/162 + 
       (109*CF*lm*NC*NH*Pi^2)/162 - (69618852288413*CF^2*NC*Pi^3)/
        (18596183472*Sqrt[3]) - (12127722658345*CF*NC*NH*Pi^3)/
        (1162261467*Sqrt[3]) - (26861*CF^2*NC*Pi^4)/324 + 
       (36250601066828237*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (22780324753200*Sqrt[3]) + (4121766761191651*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(81358302690*Sqrt[3]) - 
       (27148*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (69618852288413*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (502211745*Sqrt[3]) - (5544101786672*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (69618852288413*CF^2*NC*Pi*Log[3]^2)/(24106163760*Sqrt[3]) - 
       (346506361667*CF*NC*NH*Pi*Log[3]^2)/(43046721*Sqrt[3]) - 
       (CF*NC*(17185372120953367873*CF - 19*CA*(453558535986811051 + 
            922016223928800*lm) + 420*(171*(-123810405275269 + 
              44349024720*lm)*NM + 77*(2267460*(54027 + 43436*lm)*NL + 
              (30244517383 + 98489392560*lm)*NH)))*Log[x]^2)/659966907600 + 
       (CF*NC*(72017488729*CA + 30*(-4936553999*CF + 2670713976*NM + 
            1824312*NL))*Log[x]^3)/17010 - (748055057294505275*CF^2*NC*
         PolyGamma[2, 1])/41841412812 + (826665305*CF*NM*NC*PolyGamma[2, 1])/
        324 - (41834803112002*CF*NC*NH*PolyGamma[2, 1])/10460353203 - 
       (23021534296887301747*CF^2*NC*Zeta[3])/732224724210 + 
       (449246597*CF*NM*NC*Zeta[3])/162 - (130526*CF*NC*NL*Zeta[3])/27 + 
       (46406048116768*CF*NC*NH*Zeta[3])/10460353203 + 
       CA*CF*NC*(-72541227747170824748315699376599021/
          20526780450767595470129664000 + (101977319830607*Pi^2)/94303440 + 
         (69618852288413*Pi^3)/(37192366944*Sqrt[3]) + (136049*Pi^4)/3240 - 
         (11*lm*(5470817083 + 23073120*Pi^2))/68584320 - 
         (36250601066828237*Im[PolyLog[2, (-1)^(1/3)]])/(45560649506400*
           Sqrt[3]) + (13574*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (69618852288413*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1004423490*Sqrt[3]) + (69618852288413*Pi*Log[3]^2)/
          (48212327520*Sqrt[3]) + (748055057294505275*PolyGamma[2, 1])/
          83682825624 + (23026695559132218427*Zeta[3])/1464449448420) + 
       CF*Log[x]*((95252108411216586647*NM*NC)/56294019381600 - 
         (9426671*lm*NM*NC)/34020 - (30053572121*NC*NL)/4762800 - 
         (9426671*lm*NC*NL)/34020 - (2291647519003641600385823*NC*NH)/
          29752118273988583200 - (9426671*lm*NC*NH)/34020 + 
         (3528490*NM*NC*Pi^2)/3 - (21718*NC*NL*Pi^2)/27 + 
         (5544101786672*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(-3943992976005063401215754821/
            698062165597460664000 - (72396927383*Pi^2)/34020 + 
           (69618852288413*Im[PolyLog[2, (-1)^(1/3)]])/(1506635235*Sqrt[3]) - 
           7920*Zeta[3]) + CA*NC*(3949258044016966848235254763/
            1396124331194921328000 + (103693381*lm)/68040 + 
           (36214987069*Pi^2)/34020 - (69618852288413*
             Im[PolyLog[2, (-1)^(1/3)]])/(3013270470*Sqrt[3]) + 
           3960*Zeta[3])), (-7879017236787688185187413845067349537*CF^2*NC)/
        1385557680426812694233752320000 + (159267560402916837142391682097*CF*
         NM*NC)/6207550524252133056000 - (6316952959*CF*lm*NM*NC)/
        34292160 - (27807333694811*CF*NC*NL)/4800902400 - 
       (6316952959*CF*lm*NC*NL)/34292160 - 
       (1493808284907061270297349957244633227*CF*NC*NH)/
        13576485900067868956784724518400 - (6316952959*CF*lm*NC*NH)/
        34292160 + (54751953194430911*CF^2*NC*Pi^2)/32691859200 - 
       (396084300677*CF*NM*NC*Pi^2)/51030 - (121*CF*lm*NM*NC*Pi^2)/162 + 
       (46480379*CF*NC*NL*Pi^2)/204120 - (121*CF*lm*NC*NL*Pi^2)/162 - 
       (121*CF*lm*NC*NH*Pi^2)/162 + (9531792541249439*CF^2*NC*Pi^3)/
        (2008387814976*Sqrt[3]) + (1706353158122095*CF*NC*NH*Pi^3)/
        (125524238436*Sqrt[3]) + (219989*CF^2*NC*Pi^4)/2160 - 
       (9322358353744031591*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2460275073345600*Sqrt[3]) - (70855948097030267*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1098337086315*Sqrt[3]) + 
       (32813*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (9531792541249439*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (54238868460*Sqrt[3]) + (195011789499668*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) + 
       (9531792541249439*CF^2*NC*Pi*Log[3]^2)/(2603465686080*Sqrt[3]) + 
       (48752947374917*CF*NC*NH*Pi*Log[3]^2)/(4649045868*Sqrt[3]) + 
       (CF*NC*(-19*CA*(1410796619072837069 + 4750264265947200*lm) + 
          42*(1270325564601665461*CF + 40*(57*(-2567343901508213 + 
                171365954760*lm)*NM + 1920538620*(6297 + 5086*lm)*NL + 
              (3109410220967 + 9767859421320*lm)*NH)))*Log[x]^2)/
        2639867630400 - (CF*NC*(57425002173*CA - 120309060034*CF + 
          2520*(207867328*NM + 27973*NL))*Log[x]^3)/17010 + 
       (961994572864659689*CF^2*NC*PolyGamma[2, 1])/125524238436 - 
       (4343764646*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (311066167042823*CF*NC*NH*PolyGamma[2, 1])/62762119218 + 
       CA*CF*NC*(789960265613814999868189375850928697/
          277111536085362538846750464000 - (1659335851663627*Pi^2)/
          1981324800 - (9531792541249439*Pi^3)/(4016775629952*Sqrt[3]) - 
         (667711*Pi^4)/12960 + lm*(69486482549/68584320 + (1331*Pi^2)/324) + 
         (9322358353744031591*Im[PolyLog[2, (-1)^(1/3)]])/
          (4920550146691200*Sqrt[3]) - (32813*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          6 - (9531792541249439*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (108477736920*Sqrt[3]) - (9531792541249439*Pi*Log[3]^2)/
          (5206931372160*Sqrt[3]) - (961994572864659689*PolyGamma[2, 1])/
          251048476872 - (104180311501968535549*Zeta[3])/17573393381040) + 
       (104102809745542646929*CF^2*NC*Zeta[3])/8786696690520 - 
       (7442988952*CF*NM*NC*Zeta[3])/81 + (168080*CF*NC*NL*Zeta[3])/27 - 
       (243848596807525*CF*NC*NH*Zeta[3])/31381059609 + 
       CF*Log[x]*((-1609444583755337826769*NM*NC)/84441029072400 + 
         (11719499*lm*NM*NC)/34020 + (26149828013*NC*NL)/3175200 + 
         (11719499*lm*NC*NL)/34020 + (1218002371572273449584443199*NC*NH)/
          12150021300140087664300 + (11719499*lm*NC*NH)/34020 - 
         (69273823*NM*NC*Pi^2)/9 + (27973*NC*NL*Pi^2)/27 - 
         (195011789499668*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CA*NC*(-248798159540414843496622505407/
            150781427769051503424000 - (128914489*lm)/68040 - 
           (231833392477*Pi^2)/272160 + (9531792541249439*
             Im[PolyLog[2, (-1)^(1/3)]])/(325433210760*Sqrt[3]) - 
           4840*Zeta[3]) + CF*NC*(248063775305983204072898220643/
            75390713884525751712000 + (231665163577*Pi^2)/136080 - 
           (9531792541249439*Im[PolyLog[2, (-1)^(1/3)]])/(162716605380*
             Sqrt[3]) + 9680*Zeta[3])), 
      (34783629245017870841001659420935749083087*CF^2*NC)/
        633569342003167217983287144192000 - (91305752046124981046833691031131*
         CF*NM*NC)/3275199157372721587008000 + (871437545933*CF*lm*NM*NC)/
        4149351360 + (830756711983651*CF*NC*NL)/116181838080 + 
       (871437545933*CF*lm*NC*NL)/4149351360 + 
       (1285751506158656136502493192917840403*CF*NC*NH)/
        9697489928619906397703374656000 + (871437545933*CF*lm*NC*NH)/
        4149351360 - (229747327733993471*CF^2*NC*Pi^2)/13485391920 + 
       (2615210936267*CF*NM*NC*Pi^2)/320760 + (131*CF*lm*NM*NC*Pi^2)/162 - 
       (302720017*CF*NC*NL*Pi^2)/1122660 + (131*CF*lm*NC*NL*Pi^2)/162 + 
       (131*CF*lm*NC*NH*Pi^2)/162 - (10548033727455505*CF^2*NC*Pi^3)/
        (1841022163728*Sqrt[3]) - (517769263160765*CF*NC*NH*Pi^3)/
        (31381059609*Sqrt[3]) - (39419*CF^2*NC*Pi^4)/324 + 
       (21379756973428239103*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (4961554731246960*Sqrt[3]) + (176345173114526567*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2196674172630*Sqrt[3]) - 
       (38740*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (2109606745491101*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9943792551*Sqrt[3]) - (236694520302064*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (2109606745491101*CF^2*NC*Pi*Log[3]^2)/(477302042448*Sqrt[3]) - 
       (14793407518879*CF*NC*NH*Pi*Log[3]^2)/(1162261467*Sqrt[3]) - 
       (CF*NC*(-3*CA*(49535145984517675067 + 20288155145338080*lm) + 
          2*(148518479742478945817*CF + 462*(819*(-187685658473219 + 
                14623295280*lm)*NM + 5*(384107724*(7667 + 6236*lm)*NL + 
                (783322797017 + 2395295766864*lm)*NH))))*Log[x]^2)/
        1451927196720 + (CF*NC*(6178994289181*CA - 
          7920*(1569942775*CF - 77*(10160927*NM + 1559*NL)))*Log[x]^3)/
        187110 - (60587548638232179095*CF^2*NC*PolyGamma[2, 1])/
        376572715308 + (7445636677*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (580464734127724*CF*NC*NH*PolyGamma[2, 1])/94143178827 - 
       (2092294830756122140376*CF^2*NC*Zeta[3])/7249024769679 + 
       (4769618905*CF*NM*NC*Zeta[3])/162 - (206050*CF*NC*NL*Zeta[3])/27 + 
       (845603377419220*CF*NC*NH*Zeta[3])/94143178827 + 
       CA*CF*NC*(-1913717174399805727343972134866859055729819/
          69692627620348393978161585861120000 + (229750459135027001*Pi^2)/
          26970783840 + (10548033727455505*Pi^3)/(3682044327456*Sqrt[3]) + 
         (66397*Pi^4)/1080 + lm*(-871437545933/754427520 - (1441*Pi^2)/324) - 
         (21379756973428239103*Im[PolyLog[2, (-1)^(1/3)]])/
          (9923109462493920*Sqrt[3]) + (19370*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 + (2109606745491101*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (19887585102*Sqrt[3]) + (2109606745491101*Pi*Log[3]^2)/
          (954604084896*Sqrt[3]) + (60587548638232179095*PolyGamma[2, 1])/
          753145430616 + (4184746192388919948169*Zeta[3])/28996099078716) + 
       CF*Log[x]*((25060536132889102554901*NM*NC)/1563241615135200 - 
         (150946379*lm*NM*NC)/374220 - (532618941157*NC*NL)/52390800 - 
         (150946379*lm*NC*NL)/374220 - (11824193311068965457704935291*NC*
           NH)/97200170401120701314400 - (150946379*lm*NC*NH)/374220 + 
         8277170*NM*NC*Pi^2 - (34298*NC*NL*Pi^2)/27 + 
         (236694520302064*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(-486557680916156078303131837324859/
            9979217494515058668278400 - (309281874074*Pi^2)/18711 + 
           (2109606745491101*Im[PolyLog[2, (-1)^(1/3)]])/(29831377653*
             Sqrt[3]) - 11440*Zeta[3]) + 
         CA*NC*(1216694215708779418616459888544557/
            49896087472575293341392000 + (150946379*lm)/68040 + 
           (618621133399*Pi^2)/74844 - (2109606745491101*
             Im[PolyLog[2, (-1)^(1/3)]])/(59662755306*Sqrt[3]) + 
           5720*Zeta[3])), (-3289551740612729624194631272384600984206233*CF^2*
         NC)/78404206072891943225431784093760000 + 
       (614844664225064133583072329277*CF*NM*NC)/3128864568330789288000 - 
       (1380154607*CF*lm*NM*NC)/5762988 - (732691686478193*CF*NC*NL)/
        80681832000 - (1380154607*CF*lm*NC*NL)/5762988 - 
       (51880236010733197223506897114287794578069*CF*NC*NH)/
        309722069898985802994749518528824000 - (1380154607*CF*lm*NC*NH)/
        5762988 + (3384687245952927323*CF^2*NC*Pi^2)/269707838400 - 
       (53733813685*CF*NM*NC*Pi^2)/891 - (8*CF*lm*NM*NC*Pi^2)/9 + 
       (10093598*CF*NC*NL*Pi^2)/31185 - (8*CF*lm*NC*NL*Pi^2)/9 - 
       (8*CF*lm*NC*NH*Pi^2)/9 + (117741237266773435*CF^2*NC*Pi^3)/
        (16569199473552*Sqrt[3]) + (1975292463238675*CF*NC*NH*Pi^3)/
        (94143178827*Sqrt[3]) + (237497*CF^2*NC*Pi^4)/1620 - 
       (48668880870629474527*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6379141797317520*Sqrt[3]) - (330817613506204196*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3295011258945*Sqrt[3]) + 
       (46060*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (3364035350479241*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (12784876137*Sqrt[3]) + (902990840337680*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) + 
       (3364035350479241*CF^2*NC*Pi*Log[3]^2)/(613674054576*Sqrt[3]) + 
       (56436927521105*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) + 
       ((109452607035309843787*CF^2*NC)/725963598360 + 
         CA*CF*(-109561958517848560309/1451927196720 - 52756*lm)*NC + 
         CF*NC*((-31587161175481798/43648605 + 9592*lm)*NM + 
           44*(267 + 218*lm)*NL + (1081456160342*NH)/334639305 + 
           9592*lm*NH))*Log[x]^2 + (2*CF*NC*(-1166478183613*CA + 
          8*(294726165523*CF - 31185*(44179246*NM + 1199*NL)))*Log[x]^3)/
        93555 + (19475284107627515285*CF^2*NC*PolyGamma[2, 1])/282429536481 - 
       (4343966086*CF*NM*NC*PolyGamma[2, 1])/9 + 
       (2122306707802210*CF*NC*NH*PolyGamma[2, 1])/282429536481 + 
       CA*CF*NC*(411402058190076468922055368046674623494563/
          19601051518222985806357946023440000 - (3384764131490585483*Pi^2)/
          539415676800 - (117741237266773435*Pi^3)/(33138398947104*Sqrt[3]) - 
         (239801*Pi^4)/3240 + lm*(1380154607/1047816 + (44*Pi^2)/9) + 
         (48668880870629474527*Im[PolyLog[2, (-1)^(1/3)]])/
          (12758283594635040*Sqrt[3]) - (23030*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 - (3364035350479241*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (25569752274*Sqrt[3]) - (3364035350479241*Pi*Log[3]^2)/
          (1227348109152*Sqrt[3]) - (19475284107627515285*PolyGamma[2, 1])/
          564859072962 - (4907391523346775870259*Zeta[3])/86988297236148) + 
       (4906814151411026084005*CF^2*NC*Zeta[3])/43494148618074 - 
       (7628084516*CF*NM*NC*Zeta[3])/9 + (28808*CF*NC*NL*Zeta[3])/3 - 
       (3909943210151884*CF*NC*NH*Zeta[3])/282429536481 + 
       CF*Log[x]*((-166902747193607647008443*NM*NC)/1016107049837880 + 
         (5102896*lm*NM*NC)/10395 + (112935823331*NC*NL)/8731800 + 
         (5102896*lm*NC*NL)/10395 + (5960624216924963512959032167103*NC*NH)/
          38564167606644638246488200 + (5102896*lm*NC*NH)/10395 - 
         (176709460*NM*NC*Pi^2)/3 + (4796*NC*NL*Pi^2)/3 - 
         (902990840337680*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CA*NC*(-6587915746761030996985298074413137/
            449064787253177640072528000 - (2551448*lm)/945 - 
           (935004682715*Pi^2)/149688 + (3364035350479241*
             Im[PolyLog[2, (-1)^(1/3)]])/(76709256822*Sqrt[3]) - 
           6864*Zeta[3]) + CF*NC*(119718386771117381345548105512407/
            4082407156847069455204800 + (934861705727*Pi^2)/74844 - 
           (3364035350479241*Im[PolyLog[2, (-1)^(1/3)]])/(38354628411*
             Sqrt[3]) + 13728*Zeta[3])), 
      (1174367176101277927428421035287624568812663*CF^2*NC)/
        2701006142224028666139276772608000 - 
       (8714000432536897162115763264966659*CF*NM*NC)/
        42577589045845380631104000 + (224215084309*CF*lm*NM*NC)/829870272 + 
       (28845988534587773*CF*NC*NL)/2614091356800 + 
       (224215084309*CF*lm*NC*NL)/829870272 + 
       (634980280682732070014724921662224998894323*CF*NC*NH)/
        3185712718960996830803137904867904000 + (224215084309*CF*lm*NC*NH)/
        829870272 - (125839574093479009*CF^2*NC*Pi^2)/922078080 + 
       (136500035162581*CF*NM*NC*Pi^2)/2245320 + (155*CF*lm*NM*NC*Pi^2)/
        162 - (21230663*CF*NC*NL*Pi^2)/56133 + (155*CF*lm*NC*NL*Pi^2)/162 + 
       (155*CF*lm*NC*NH*Pi^2)/162 - (2521058049712769525*CF^2*NC*Pi^3)/
        (298245590523936*Sqrt[3]) - (85152736613264635*CF*NC*NH*Pi^3)/
        (3389154437772*Sqrt[3]) - (12427*CF^2*NC*Pi^4)/72 + 
       (1014195600747945810983*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (114824552351715360*Sqrt[3]) + (1456504337857324337*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(11862040532202*Sqrt[3]) - 
       (53690*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (72030229991793415*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (230127770466*Sqrt[3]) - (9731741327230244*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) - 
       (72030229991793415*CF^2*NC*Pi*Log[3]^2)/(11046132982368*Sqrt[3]) - 
       (2432935331807561*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) - 
       (CF*NC*(-437*CA*(125177699285650783049 + 9736204901623200*lm) + 
          18*(6077394928501012199021*CF + 308*(23*(-382097726073601477 + 
                6066768107400*lm)*NM + 7*(350574510*(69217 + 56860*lm)*NL + 
                (6874282254529 + 19933666638600*lm)*NH))))*Log[x]^2)/
        66788651049120 + (CF*NC*(9818586252913*CA + 
          88*(-223430665225*CF + 103116078534*NM + 3283665*NL))*Log[x]^3)/
        37422 - (4907520349156653632009*CF^2*NC*PolyGamma[2, 1])/
        3389154437772 + (16754984663*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (31125637448020939*CF*NC*NH*PolyGamma[2, 1])/3389154437772 - 
       (687236320963594953762641*CF^2*NC*Zeta[3])/260964891708444 + 
       (23694281254*CF*NM*NC*Zeta[3])/81 - (313040*CF*NC*NL*Zeta[3])/27 + 
       (27158362722361949*CF*NC*NH*Zeta[3])/1694577218886 + 
       CA*CF*NC*(-12918783624026448795568735788277499358108103/
          59422135128928630655064088997376000 + (1635918592336827413*Pi^2)/
          23974030080 + (2521058049712769525*Pi^3)/(596491181047872*
           Sqrt[3]) + (112835*Pi^4)/1296 + lm*(-224215084309/150885504 - 
           (1705*Pi^2)/324) - (1014195600747945810983*
           Im[PolyLog[2, (-1)^(1/3)]])/(229649104703430720*Sqrt[3]) + 
         (26845*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (72030229991793415*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (460255540932*Sqrt[3]) + (72030229991793415*Pi*Log[3]^2)/
          (22092265964736*Sqrt[3]) + (4907520349156653632009*PolyGamma[2, 1])/
          6778308875544 + (687240501065401557360131*Zeta[3])/
          521929783416888) + CF*Log[x]*((3178015251215878757721581*NM*NC)/
          22862408621352300 - (42528037*lm*NM*NC)/74844 - 
         (14815192630867*NC*NL)/943034400 - (42528037*lm*NC*NL)/74844 - 
         (18349794401087936361270608707723*NC*NH)/
          99165002417086212633826800 - (42528037*lm*NC*NH)/74844 + 
         (4910042207*NM*NC*Pi^2)/81 - (156365*NC*NL*Pi^2)/81 + 
         (9731741327230244*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*(-551138006060623519145539396502833/
            1329468120157433802846300 - (19641237131735*Pi^2)/149688 + 
           (72030229991793415*Im[PolyLog[2, (-1)^(1/3)]])/(690383311398*
             Sqrt[3]) - 16016*Zeta[3]) + 
         CA*NC*(3527440066191615137073995119274251/
            17017191938015152676432640 + (42528037*lm)/13608 + 
           (19641585821615*Pi^2)/299376 - (72030229991793415*
             Im[PolyLog[2, (-1)^(1/3)]])/(1380766622796*Sqrt[3]) + 
           8008*Zeta[3])), (-1637764792948204330530586739387306430960829*CF^2*
         NC)/5162416860766547702086043397120000 + 
       (65398087781610097649156055687323893*CF*NM*NC)/
        42577589045845380631104000 - (1265006974723*CF*lm*NM*NC)/
        4149351360 - (987213858981426449*CF*NC*NL)/71887512312000 - 
       (1265006974723*CF*lm*NC*NL)/4149351360 - 
       (76518354970206420804921173456702533863082273*CF*NC*NH)/
        309722069898985802994749518528824000000 - 
       (1265006974723*CF*lm*NC*NH)/4149351360 + 
       (20786979102541568243*CF^2*NC*Pi^2)/215766270720 - 
       (535951997935813*CF*NM*NC*Pi^2)/1122660 - (169*CF*lm*NM*NC*Pi^2)/
        162 + (1003839811*CF*NC*NL*Pi^2)/2245320 - (169*CF*lm*NC*NL*Pi^2)/
        162 - (169*CF*lm*NC*NH*Pi^2)/162 + (682302507438469831*CF^2*NC*Pi^3)/
        (66276797894208*Sqrt[3]) + (2947971294377270*CF*NC*NH*Pi^3)/
        (94143178827*Sqrt[3]) + (265265*CF^2*NC*Pi^4)/1296 - 
       (150504518192550158419*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (11025677180548800*Sqrt[3]) - (5478938980526484178*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(36245123848395*Sqrt[3]) + 
       (62959*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (682302507438469831*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1789882659180*Sqrt[3]) + (1347644020286752*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) + 
       (682302507438469831*CF^2*NC*Pi*Log[3]^2)/(85914367640640*Sqrt[3]) + 
       (84227751267922*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) + 
       (CF*NC*(-667*CA*(579053635333695830947 + 78743927137075200*lm) + 
          14*(55164788609533859149247*CF + 792*(115*(-3000602780291052481 + 
                7489091850240*lm)*NM + 29002073100*(36033 + 29696*lm)*NL + 
              (304562023427261 + 861245562777600*lm)*NH)))*Log[x]^2)/
        667886510491200 + (CF*NC*(-17692563508882*CA + 
          15*(2364283482933*CF - 285824*(40294445*NM + 208*NL)))*Log[x]^3)/
        93555 + (6309706830673590765455*CF^2*NC*PolyGamma[2, 1])/
        10167463313316 - (703728281267*CF*NM*NC*PolyGamma[2, 1])/162 + 
       (28045886240201020*CF*NC*NH*PolyGamma[2, 1])/2541865828329 + 
       CA*CF*NC*(204739764383468014686674591225985152741447/
          1290604215191636925521510849280000 - (1599005261195308157*Pi^2)/
          33194810880 - (682302507438469831*Pi^3)/(132553595788416*Sqrt[3]) - 
         (1337141*Pi^4)/12960 + lm*(1265006974723/754427520 + 
           (1859*Pi^2)/324) + (150504518192550158419*
           Im[PolyLog[2, (-1)^(1/3)]])/(22051354361097600*Sqrt[3]) - 
         (62959*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (682302507438469831*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3579765318360*Sqrt[3]) - (682302507438469831*Pi*Log[3]^2)/
          (171828735281280*Sqrt[3]) - (6309706830673590765455*
           PolyGamma[2, 1])/20334926626632 - (8234666358902804204110427*
           Zeta[3])/15657893502506640) + (8234514486469601099497967*CF^2*NC*
         Zeta[3])/7828946751253320 - (628947851453*CF*NM*NC*Zeta[3])/81 + 
       (386386*CF*NC*NL*Zeta[3])/27 - (58156498092653644*CF*NC*NH*Zeta[3])/
        2541865828329 + CF*Log[x]*((-254699637907216724237828063*NM*NC)/
          182899268970818400 + (254291011*lm*NM*NC)/374220 + 
         (25375705197881*NC*NL)/1296672300 + (254291011*lm*NC*NL)/374220 + 
         (888706027603645267297131722970991*NC*NH)/
          3856416760664463824648820000 + (254291011*lm*NC*NH)/374220 - 
         (37392954436*NM*NC*Pi^2)/81 + (193024*NC*NL*Pi^2)/81 - 
         (1347644020286752*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CA*NC*(-6430265130566871468325119996589693/
            51321689971791730294003200 - (254291011*lm)/68040 - 
           (141595124052691*Pi^2)/2993760 + (682302507438469831*
             Im[PolyLog[2, (-1)^(1/3)]])/(10739295955080*Sqrt[3]) - 
           9464*Zeta[3]) + CF*NC*(56259704060652686771771724366427553/
            224532393626588820036264000 + (141590857062271*Pi^2)/1496880 - 
           (682302507438469831*Im[PolyLog[2, (-1)^(1/3)]])/
            (5369647977540*Sqrt[3]) + 18928*Zeta[3])), 
      (65693894765273379160770608441206322232757537503811*CF^2*NC)/
        18797717070955540878684284041607918592000 - 
       (61296950480360173874013807358890258479*CF*NM*NC)/
        39849348147753903549126336000 + (239036141264191*CF*lm*NM*NC)/
        701240379840 + (399939586706859466669*CF*NC*NL)/24297979161456000 + 
       (239036141264191*CF*lm*NC*NL)/701240379840 + 
       (810504627041446759643902004049206134410577039*CF*NC*NH)/
        2787498629090872226952745666759416000000 + 
       (239036141264191*CF*lm*NC*NH)/701240379840 - 
       (10788109534678911619*CF^2*NC*Pi^2)/9739449720 + 
       (2705651450899723*CF*NM*NC*Pi^2)/5837832 + (181*CF*lm*NM*NC*Pi^2)/
        162 - (1884706259*CF*NC*NL*Pi^2)/3648645 + (181*CF*lm*NC*NL*Pi^2)/
        162 + (181*CF*lm*NC*NH*Pi^2)/162 - (46886625531055756915*CF^2*NC*
         Pi^3)/(3877192676811168*Sqrt[3]) - (125600609104169605*CF*NC*NH*
         Pi^3)/(3389154437772*Sqrt[3]) - (17137*CF^2*NC*Pi^4)/72 + 
       (307397853173991437440573*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (19405349347439895840*Sqrt[3]) + (118850909106954000113*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(652412229271110*Sqrt[3]) - 
       (72590*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (1339617872315878769*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2991661016058*Sqrt[3]) - (14354355326190812*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) - 
       (1339617872315878769*CF^2*NC*Pi*Log[3]^2)/(143599728770784*Sqrt[3]) - 
       (3588588831547703*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) - 
       (CF*NC*(-475*CA*(60744036533005967345221 + 856535286629262240*lm) + 
          6*(9617610749476298126469775*CF + 12012*(5*(-67000576504572292997 + 
                205276673401800*lm)*NM + 72505182750*(17085 + 14156*lm)*
               NL + (370419045446557 + 1026383367009000*lm)*NH)))*Log[x]^2)/
        4341262318192800 + (CF*NC*(5147108226887103*CA - 
          520*(19801418308745*CF - 231*(36980827274*NM + 230035*NL)))*
         Log[x]^3)/2432430 - (397508161903862713364213*CF^2*NC*
         PolyGamma[2, 1])/30502389939948 + (150798453481*CF*NM*NC*
         PolyGamma[2, 1])/81 - (405176110550300767*CF*NC*NH*PolyGamma[2, 1])/
        30502389939948 - (731193856682036755033193045*CF^2*NC*Zeta[3])/
        30532892329887948 + (227642412170*CF*NM*NC*Zeta[3])/81 - 
       (460432*CF*NC*NL*Zeta[3])/27 + (402738808925525369*CF*NC*NH*Zeta[3])/
        15251194969974 + CA*CF*NC*
        (-82118184687774433130050222883084401907971867468451/
          46994292677388852196710710104019796480000 + 
         (517829487072028885577*Pi^2)/934987173120 + 
         (46886625531055756915*Pi^3)/(7754385353622336*Sqrt[3]) + 
         (776957*Pi^4)/6480 + lm*(-239036141264191/127498250880 - 
           (1991*Pi^2)/324) - (307397853173991437440573*
           Im[PolyLog[2, (-1)^(1/3)]])/(38810698694879791680*Sqrt[3]) + 
         (36295*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1339617872315878769*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (5983322032116*Sqrt[3]) + (1339617872315878769*Pi*Log[3]^2)/
          (287199457541568*Sqrt[3]) + (397508161903862713364213*
           PolyGamma[2, 1])/61004779879896 + (731194562488291787771488481*
           Zeta[3])/61065784659775896) + CF*Log[x]*
        ((707082974265722346470633111*NM*NC)/604710708034768335 - 
         (3788607307*lm*NM*NC)/4864860 - (3161382795652483*NC*NL)/
          134853919200 - (3788607307*lm*NC*NL)/4864860 - 
         (4731896927255778539567768674230019*NC*NH)/
          17353875422990087210919690000 - (3788607307*lm*NC*NH)/4864860 + 
         (36980478913*NM*NC*Pi^2)/81 - (230035*NC*NL*Pi^2)/81 + 
         (14354355326190812*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (-2054073003212929785103191400638595867877/
            585136144788651024779136326400 - (2058921455643695*Pi^2)/
            1945944 + (1339617872315878769*Im[PolyLog[2, (-1)^(1/3)]])/
            (8974983048174*Sqrt[3]) - 21840*Zeta[3]) + 
         CA*NC*(5135222485215017821850603949487535011577/
            2925680723943255123895681632000 + (3788607307*lm)/884520 + 
           (2058928121817209*Pi^2)/3891888 - (1339617872315878769*
             Im[PolyLog[2, (-1)^(1/3)]])/(17949966096348*Sqrt[3]) + 
           10920*Zeta[3])), 
      (-2812909609178872766359379300874072672793295710161211*CF^2*NC)/
        1148003435404784817948218775398197885440000 + 
       (3161714910070574855478294079363335746593*CF*NM*NC)/
        259020762960400373069321184000 - (1363873920307*CF*lm*NM*NC)/
        3577757040 - (69890693511758604577*CF*NC*NL)/3471139880208000 - 
       (1363873920307*CF*lm*NC*NL)/3577757040 - 
       (4447859420770357636458854148687789820382171677*CF*NC*NH)/
        12543743830908925021287355500417372000000 - 
       (1363873920307*CF*lm*NC*NH)/3577757040 + 
       (12840549472042661711921*CF^2*NC*Pi^2)/17030123510400 - 
       (2798287180720169*CF*NM*NC*Pi^2)/729729 - (98*CF*lm*NM*NC*Pi^2)/81 + 
       (314164382*CF*NC*NL*Pi^2)/521235 - (98*CF*lm*NC*NL*Pi^2)/81 - 
       (98*CF*lm*NC*NH*Pi^2)/81 + (506080070000774760211*CF^2*NC*Pi^3)/
        (34894734091300512*Sqrt[3]) + (692514295532767855*CF*NC*NH*Pi^3)/
        (15251194969974*Sqrt[3]) + (902293*CF^2*NC*Pi^4)/3240 - 
       (19738911515460906724183721*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (873240720634795312800*Sqrt[3]) - (649380911623056916904*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2935855031719995*Sqrt[3]) + 
       28042*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (72297152857253537173*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (134624745722610*Sqrt[3]) + (158288981836061224*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) + 
       (72297152857253537173*CF^2*NC*Pi*Log[3]^2)/(6461987794685280*
         Sqrt[3]) + (19786122729507653*CF*NC*NH*Pi*Log[3]^2)/
        (564859072962*Sqrt[3]) + 
       (CF*NC*(-3*CA*(935292997940755987860689 + 23529105806294088000*lm) + 
          2*(2805777538156313335929107*CF + 30888*(5*(-92393150151666091069 + 
                41550303394600*lm)*NM + 338357519500*(739 + 614*lm)*NL + 
              (76604895336973 + 207751516973000*lm)*NH)))*Log[x]^2)/
        620180331170400 + (CF*NC*(-254708061581189*CA + 509642330050394*CF - 
          17160*(149090625973*NM + 139685*NL))*Log[x]^3)/173745 + 
       (255541204454592805870417*CF^2*NC*PolyGamma[2, 1])/45753584909922 - 
       (3166781685130*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (360580932977699140*CF*NC*NH*PolyGamma[2, 1])/22876792454961 + 
       CA*CF*NC*(351619550848849824733855971512560537441682666196209/
          287000858851196204487054693849549471360000 - 
         (755327020105965758443*Pi^2)/2003543942400 - 
         (506080070000774760211*Pi^3)/(69789468182601024*Sqrt[3]) - 
         (60571*Pi^4)/432 + lm*(1363873920307/650501280 + (539*Pi^2)/81) + 
         (19738911515460906724183721*Im[PolyLog[2, (-1)^(1/3)]])/
          (1746481441269590625600*Sqrt[3]) - 14021*Im[PolyLog[2, (-1)^(1/3)]]^
           2 - (72297152857253537173*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (269249491445220*Sqrt[3]) - (72297152857253537173*Pi*Log[3]^2)/
          (12923975589370560*Sqrt[3]) - (255541204454592805870417*
           PolyGamma[2, 1])/91507169819844 - (57719174784774972571021259*
           Zeta[3])/11895932076579720) + (57719010438067433853085859*CF^2*NC*
         Zeta[3])/5947966038289860 - (5737209588452*CF*NM*NC*Zeta[3])/81 + 
       (559132*CF*NC*NL*Zeta[3])/27 - (818950120556559124*CF*NC*NH*Zeta[3])/
        22876792454961 + CF*Log[x]*((-56836794886908303249873673213*NM*NC)/
          4837685664278146680 + (159455359*lm*NM*NC)/173745 + 
         (276357569869427*NC*NL)/9632422800 + (159455359*lm*NC*NL)/173745 + 
         (13036290152650651952715192884345021*NC*NH)/
          39046219701727696224569302500 + (159455359*lm*NC*NH)/173745 - 
         (298180847542*NM*NC*Pi^2)/81 + (279370*NC*NL*Pi^2)/81 - 
         (158288981836061224*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (282429536481*Sqrt[3]) + CA*NC*
          (-15082791545932510725928868466405769718311/
            14294040108408475033890330259200 - (159455359*lm)/31590 - 
           (30875938969601*Pi^2)/84240 + (72297152857253537173*
             Im[PolyLog[2, (-1)^(1/3)]])/(807748474335660*Sqrt[3]) - 
           12740*Zeta[3]) + CF*NC*(18853192601442846433327540471574413833251/
            8933775067755296896181456412000 + (30875765054821*Pi^2)/42120 - 
           (72297152857253537173*Im[PolyLog[2, (-1)^(1/3)]])/
            (403874237167830*Sqrt[3]) + 25480*Zeta[3])), 
      (335954615391895408360574935182403016295246342279906739*CF^2*NC)/
        11817682423284549596525781511452037056000000 - 
       (763502587746031535978651150892780259710233*CF*NM*NC)/
        64755190740100093267330296000000 + (5392603298165*CF*lm*NM*NC)/
        12749825088 + (579415768718806451849*CF*NC*NL)/24297979161456000 + 
       (5392603298165*CF*lm*NC*NL)/12749825088 + 
       (545714257540260968939014541269363036164047111*CF*NC*NH)/
        1320394087464097370661826894780776000000 + 
       (5392603298165*CF*lm*NC*NH)/12749825088 - 
       (170917571264200672547*CF^2*NC*Pi^2)/18814846050 + 
       (20997475323273227*CF*NM*NC*Pi^2)/5837832 + (209*CF*lm*NM*NC*Pi^2)/
        162 - (457477417*CF*NC*NL*Pi^2)/663390 + (209*CF*lm*NC*NL*Pi^2)/
        162 + (209*CF*lm*NC*NH*Pi^2)/162 - (147012832680156234485*CF^2*NC*
         Pi^3)/(8723683522825128*Sqrt[3]) - (1622368983439539755*CF*NC*NH*
         Pi^3)/(30502389939948*Sqrt[3]) - (14419*CF^2*NC*Pi^4)/45 + 
       (7993411984635910325377457*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (305634252222178359480*Sqrt[3]) + (1545519328474455133153*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5871710063439990*Sqrt[3]) - 
       (96080*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (58805133072062493794*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94237322005827*Sqrt[3]) - (185413598107375972*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) - 
       (29402566536031246897*CF^2*NC*Pi*Log[3]^2)/(2261695728139848*
         Sqrt[3]) - (46353399526843993*CF*NC*NH*Pi*Log[3]^2)/
        (1129718145924*Sqrt[3]) - 
       (CF*NC*(-119*CA*(994213585422448663753469 + 2446008115578627600*lm) + 
          6*(39436998985676937059583517*CF + 
            6006*(11*(-236348620246576643269 + 133509725239800*lm)*NM + 
              19*(5342487150*(17331 + 14468*lm)*NL + (29016675566677 + 
                  77295104086200*lm)*NH))))*Log[x]^2)/2170631159096400 + 
       (CF*NC*(42002435585229305*CA - 364*(230793138578099*CF - 
            330*(284405397466*NM + 329147*NL)))*Log[x]^3)/2432430 - 
       (32198147902919450274643583*CF^2*NC*PolyGamma[2, 1])/274521509459532 + 
       (5428765931675*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (2571171736290471749*CF*NC*NH*PolyGamma[2, 1])/137260754729766 - 
       (29857743796625894370326915851*CF^2*NC*Zeta[3])/137398015484495766 + 
       (4291164729491*CF*NM*NC*Zeta[3])/162 - (658712*CF*NC*NL*Zeta[3])/
        27 + (2822223572192318119*CF*NC*NH*Zeta[3])/68630377364883 + 
       CA*CF*NC*(-167977587111944326422040829173178539537801368603090107/
          11817682423284549596525781511452037056000000 + 
         (29247928812891411107*Pi^2)/6439305600 + 
         (147012832680156234485*Pi^3)/(17447367045650256*Sqrt[3]) + 
         (130607*Pi^4)/810 + lm*(-5392603298165/2318150016 - 
           (2299*Pi^2)/324) - (7993411984635910325377457*
           Im[PolyLog[2, (-1)^(1/3)]])/(611268504444356718960*Sqrt[3]) + 
         (48040*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (29402566536031246897*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (94237322005827*Sqrt[3]) + (29402566536031246897*Pi*Log[3]^2)/
          (4523391456279696*Sqrt[3]) + (32198147902919450274643583*
           PolyGamma[2, 1])/549043018919064 + (14928874135482140069147902511*
           Zeta[3])/137398015484495766) + CF*Log[x]*
        ((226368454669202901424568058677*NM*NC)/23258104155183397500 - 
         (461143633*lm*NM*NC)/442260 - (4579235001297659*NC*NL)/
          134853919200 - (461143633*lm*NC*NL)/442260 - 
         (3214036831793200439984059313851631*NC*NH)/
          8220256779311093942014590000 - (461143633*lm*NC*NH)/442260 + 
         (284404918715*NM*NC*Pi^2)/81 - (329147*NC*NL*Pi^2)/81 + 
         (185413598107375972*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (282429536481*Sqrt[3]) + CF*NC*
          (-1093467783693604668789180729389063129054447/
            36786132631933575454864820520000 - (8400543301852843*Pi^2)/
            972972 + (58805133072062493794*Im[PolyLog[2, (-1)^(1/3)]])/
            (282711966017481*Sqrt[3]) - 29120*Zeta[3]) + 
         CA*NC*(1093469232620697243766483222881959419611257/
            73572265263867150909729641040000 + (5072579963*lm)/884520 + 
           (8400548069409637*Pi^2)/1945944 - (29402566536031246897*
             Im[PolyLog[2, (-1)^(1/3)]])/(282711966017481*Sqrt[3]) + 
           14560*Zeta[3])), 
      (-23210020462760349507446713561659459486101546522966920837*CF^2*NC)/
        1205403607175024058845629714168107779712000000 + 
       (141460258013790846425475764273244249464849*CF*NM*NC)/
        1439004238668890961496228800000 - (7314080183615*CF*lm*NM*NC)/
        15583119552 - (2017626500021269744891*CF*NC*NL)/70194162021984000 - 
       (7314080183615*CF*lm*NC*NL)/15583119552 - 
       (7298455588083604755724998113437109450065949995381*CF*NC*NH)/
        14684609678017813072520511038384605713984000 - 
       (7314080183615*CF*lm*NC*NH)/15583119552 + 
       (57147233012783528532893*CF^2*NC*Pi^2)/9536869165824 - 
       (5053398361138027*CF*NM*NC*Pi^2)/162162 - (25*CF*lm*NM*NC*Pi^2)/18 + 
       (516182855*CF*NC*NL*Pi^2)/648648 - (25*CF*lm*NC*NL*Pi^2)/18 - 
       (25*CF*lm*NC*NH*Pi^2)/18 + (4176178998377742426475*CF^2*NC*Pi^3)/
        (209368404547803072*Sqrt[3]) + (5876919983039132125*CF*NC*NH*Pi^3)/
        (91507169819844*Sqrt[3]) + (480335*CF^2*NC*Pi^4)/1296 - 
       (51917658429413502991480967*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1467044410666456125504*Sqrt[3]) - (7229571112289066165621*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(22899669247415961*Sqrt[3]) + 
       (110225*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (835235799675548485295*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1130847864069924*Sqrt[3]) + (671647998061615100*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (835235799675548485295*CF^2*NC*Pi*Log[3]^2)/(54280697475356352*
         Sqrt[3]) + (167911999515403775*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) + ((3430429466793021366350561*CF^2*NC)/
          47706179320800 + CA*CF*(-312171091083321124238561651/
            8682524636385600 - (481789*lm)/3)*NC + 
         CF*NC*((-500555884719302093327/1338557220 + (87598*lm)/3)*NM + 
           (14*(22432 + 18771*lm)*NL)/9 + (86697877366493*NH)/7763631876 + 
           (87598*lm*NH)/3))*Log[x]^2 + 
       (CF*NC*(-2812774694990522*CA + 5626022955530191*CF - 
          108108*(267727395092*NM + 43799*NL))*Log[x]^3)/243243 + 
       (41397624844402303734980117*CF^2*NC*PolyGamma[2, 1])/823564528378596 - 
       (1055594137279*CF*NM*NC*PolyGamma[2, 1])/3 + 
       (9053866036959809297*CF*NC*NH*PolyGamma[2, 1])/411782264189298 + 
       CA*CF*NC*(11605043388598479762884730447691396570629026602086092231/
          1205403607175024058845629714168107779712000000 - 
         (57147240531414625059443*Pi^2)/19073738331648 - 
         (4176178998377742426475*Pi^3)/(418736809095606144*Sqrt[3]) - 
         (483215*Pi^4)/2592 + lm*(7314080183615/2833294464 + (275*Pi^2)/36) + 
         (51917658429413502991480967*Im[PolyLog[2, (-1)^(1/3)]])/
          (2934088821332912251008*Sqrt[3]) - 
         (110225*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (835235799675548485295*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2261695728139848*Sqrt[3]) - (835235799675548485295*Pi*Log[3]^2)/
          (108561394950712704*Sqrt[3]) - (41397624844402303734980117*
           PolyGamma[2, 1])/1647129056757192 - (20955641874688326883737114583*
           Zeta[3])/471078910232556912) + (20955632811090837433489414627*CF^2*
         NC*Zeta[3])/235539455116278456 - (1932703797818*CF*NM*NC*Zeta[3])/
        3 + 29216*CF*NC*NL*Zeta[3] - (11054376995101810483*CF*NC*NH*
         Zeta[3])/205891132094649 + CF*Log[x]*
        ((-2663018871724587310841868256037*NM*NC)/26876031468211926000 + 
         (131198255*lm*NM*NC)/108108 + (7973966816156087*NC*NL)/
          194788994400 + (131198255*lm*NC*NL)/108108 + 
         (42497745029255655798472749410051611*NC*NH)/
          90069588395391065211052205904 + (131198255*lm*NC*NH)/108108 - 
         (267727333975*NM*NC*Pi^2)/9 + (43799*NC*NL*Pi^2)/9 - 
         (671647998061615100*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CA*NC*
          (-132820436254099047046278988217153132218944877/
            15008742113828898785584846772160000 - (131198255*lm)/19656 - 
           (3214641435128479*Pi^2)/1111968 + (835235799675548485295*
             Im[PolyLog[2, (-1)^(1/3)]])/(6785087184419544*Sqrt[3]) - 
           16800*Zeta[3]) + CF*NC*
          (33205020485322683166425082697586663926946713/
            1876092764228612348198105846520000 + (3214638193949395*Pi^2)/
            555984 - (835235799675548485295*Im[PolyLog[2, (-1)^(1/3)]])/
            (3392543592209772*Sqrt[3]) + 33600*Zeta[3])), 
      (12665349681583579949010459942578618952605186680266217466959*CF^2*NC)/
        54243162322876082648053337137564850087040000000 - 
       (160584886840483926102078808104479393820622357*CF*NM*NC)/
        1748390149982702518217917992000000 + (1813649793170161*CF*lm*NM*NC)/
        3506201899200 + (10640450092691356511179*CF*NC*NL)/
        315873729098928000 + (1813649793170161*CF*lm*NC*NL)/3506201899200 + 
       (862562964477073364733937757374305578356346270017751*CF*NC*NH)/
        1501835080706367246053234083471152857112000000 + 
       (1813649793170161*CF*lm*NC*NH)/3506201899200 - 
       (8956339018935880471898423*CF^2*NC*Pi^2)/119210864572800 + 
       (275541625869737131*CF*NM*NC*Pi^2)/9729720 + (239*CF*lm*NM*NC*Pi^2)/
        162 - (6587589653*CF*NC*NL*Pi^2)/7297290 + (239*CF*lm*NC*NL*Pi^2)/
        162 + (239*CF*lm*NC*NH*Pi^2)/162 - (5407664845848226273765*CF^2*NC*
         Pi^3)/(235539455116278456*Sqrt[3]) - 
       (61393697753688990935*CF*NC*NH*Pi^3)/(823564528378596*Sqrt[3]) - 
       (34225*CF^2*NC*Pi^4)/81 + (1681047976039761641137461569*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41260624049994078529800*Sqrt[3]) + 
       (765822444698560252674457*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2060970232267436490*Sqrt[3]) - 41616*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (2163065938339290509506*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2544407694157329*Sqrt[3]) - 
       (7016422600421598964*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2541865828329*Sqrt[3]) - (1081532969169645254753*CF^2*NC*Pi*
         Log[3]^2)/(61065784659775896*Sqrt[3]) - 
       (1754105650105399741*CF*NC*NH*Pi*Log[3]^2)/(30502389939948*Sqrt[3]) - 
       (CF*NC*(-29*CA*(4892406525382676669739582517 + 2032993447141763106000*
             lm) + 4*(70939852013875132453249205519*CF + 
            5005*(319*(-16748168636066668748107 + 1678481392278600*lm)*NM + 
              2037953367450*(312649 + 262732*lm)*NL + (208059804582719669 + 
                535435564136873400*lm)*NH)))*Log[x]^2)/314741518068978000 + 
       (CF*NC*(345990709519741023*CA + 140*(-4942764882670691*CF + 
            858*(2223364172030*NM + 459781*NL)))*Log[x]^3)/2432430 - 
       (2608049808395766609230241035*CF^2*NC*PolyGamma[2, 1])/
        2470693585135788 + (16286308296269*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (31919266512049895129*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 - 
       (6086911888837540954353010466893*CF^2*NC*Zeta[3])/
        3091455348401154735 + (13321832180357*CF*NM*NC*Zeta[3])/54 - 
       (306680*CF*NC*NL*Zeta[3])/9 + (37891888869798431899*CF*NC*NH*
         Zeta[3])/617673396283947 + CA*CF*NC*
        (-3166338279418004857001297593854332864694300603036254925271/
          27121581161438041324026668568782425043520000000 + 
         (4478169563678466938498929*Pi^2)/119210864572800 + 
         (5407664845848226273765*Pi^3)/(471078910232556912*Sqrt[3]) + 
         (172081*Pi^4)/810 + lm*(-1813649793170161/637491254400 - 
           (2629*Pi^2)/324) - (1681047976039761641137461569*
           Im[PolyLog[2, (-1)^(1/3)]])/(82521248099988157059600*Sqrt[3]) + 
         20808*Im[PolyLog[2, (-1)^(1/3)]]^2 + (1081532969169645254753*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2544407694157329*
           Sqrt[3]) + (1081532969169645254753*Pi*Log[3]^2)/
          (122131569319551792*Sqrt[3]) + (2608049808395766609230241035*
           PolyGamma[2, 1])/4941387170271576 + 
         (3043456013838831554852398305434*Zeta[3])/3091455348401154735) + 
       CF*Log[x]*((109927280167901365638453871640759*NM*NC)/
          1360599093078228753750 - (6656549477*lm*NM*NC)/4864860 - 
         (84047888144262241*NC*NL)/1753100949600 - (6656549477*lm*NC*NL)/
          4864860 - (1941869134919671179747869362874436699089*NC*NH)/
          3546490043068523192685180607470000 - (6656549477*lm*NC*NH)/
          4864860 + (2223363528037*NM*NC*Pi^2)/81 - (459781*NC*NL*Pi^2)/
          81 + (7016422600421598964*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7625597484987*Sqrt[3]) + 
         CF*NC*(-85130315754762267989579467634646909139071084739/
            337696697561150222675659052373600000 - (19221727973825887*Pi^2)/
            270270 + (2163065938339290509506*Im[PolyLog[2, (-1)^(1/3)]])/
            (7633223082471987*Sqrt[3]) - 38080*Zeta[3]) + 
         CA*NC*(21282583615358547314738259228122073133978416991/
            168848348780575111337829526186800000 + (6656549477*lm)/884520 + 
           (115330378939135417*Pi^2)/3243240 - (1081532969169645254753*
             Im[PolyLog[2, (-1)^(1/3)]])/(7633223082471987*Sqrt[3]) + 
           19040*Zeta[3])), 
      (-160077386360478118046842397769686415123828927719107658213*CF^2*NC)/
        1043137736978386204770256483414708655520000000 + 
       (7950149443282243166727731791179197226226057*CF*NM*NC)/
        9934034943083537035329079500000 - (31236425261861*CF*lm*NM*NC)/
        54784404675 - (57558737376631494467*CF*NC*NL)/1435789677722400 - 
       (31236425261861*CF*lm*NC*NL)/54784404675 - 
       (599655943401873022473934644192729116578713088708257289*CF*NC*NH)/
        878844388897423665890876539977821897193677700000 - 
       (31236425261861*CF*lm*NC*NH)/54784404675 + 
       (4550577133359759851685821*CF^2*NC*Pi^2)/94375267786800 - 
       (310925063580479168*CF*NM*NC*Pi^2)/1216215 - (128*CF*lm*NM*NC*Pi^2)/
        81 + (3764614856*CF*NC*NL*Pi^2)/3648645 - (128*CF*lm*NC*NL*Pi^2)/
        81 - (128*CF*lm*NC*NH*Pi^2)/81 + (6328151825799948777455*CF^2*NC*
         Pi^3)/(235539455116278456*Sqrt[3]) + 
       (18299674591199933680*CF*NC*NH*Pi^3)/(205891132094649*Sqrt[3]) + 
       (65329*CF^2*NC*Pi^4)/135 - (2189374363973668788162314839*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41260624049994078529800*Sqrt[3]) - 
       (64901420734878052549696*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (147212159447674035*Sqrt[3]) + 
       (141968*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (2531260730319979510982*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2544407694157329*Sqrt[3]) + (8365565527405683968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) + 
       (1265630365159989755491*CF^2*NC*Pi*Log[3]^2)/(61065784659775896*
         Sqrt[3]) + (522847845462855248*CF*NC*NH*Pi*Log[3]^2)/
        (7625597484987*Sqrt[3]) + 
       (CF*NC*(-81809*CA*(17252229124533241368233999 + 13216767284408688000*
             lm) + 8*(352846512607650388381243024239*CF + 
            20020*(899*(-103943801086779397106557 + 1365368521116600*lm)*
               NM + 175*(206290789848*(40377 + 34001*lm)*NL + 
                (2770225433204731 + 7014093145621848*lm)*NH))))*Log[x]^2)/
        4878493530069159000 + (2*CF*NC*(-56244832104359769*CA + 
          224*(502193706581548*CF - 2145*(1229871927373*NM + 34001*NL)))*
         Log[x]^3)/1216215 + (838301742931165736131254428*CF^2*NC*
         PolyGamma[2, 1])/1853020188851841 - 
       (85503128254888*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (55663141233148540936*CF*NC*NH*PolyGamma[2, 1])/1853020188851841 + 
       CA*CF*NC*(4064466824857298512734775392316357700744713810135541137/
          52971838205933674460989587048403173913125000 - 
         (159669376567308953758711*Pi^2)/6622825809600 - 
         (6328151825799948777455*Pi^3)/(471078910232556912*Sqrt[3]) - 
         (197011*Pi^4)/810 + lm*(31236425261861/9960800850 + (704*Pi^2)/81) + 
         (2189374363973668788162314839*Im[PolyLog[2, (-1)^(1/3)]])/
          (82521248099988157059600*Sqrt[3]) - 
         (70984*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (1265630365159989755491*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2544407694157329*Sqrt[3]) - (1265630365159989755491*Pi*Log[3]^2)/
          (122131569319551792*Sqrt[3]) - (419150871465582868065627214*
           PolyGamma[2, 1])/1853020188851841 - 
         (7533593787080999586283244358649*Zeta[3])/18548732090406928410) + 
       (7533593299860423282448322094934*CF^2*NC*Zeta[3])/
        9274366045203464205 - (157887628218704*CF*NM*NC*Zeta[3])/27 + 
       (362848*CF*NC*NL*Zeta[3])/9 - (144217372029957831280*CF*NC*NH*
         Zeta[3])/1853020188851841 + CF*Log[x]*
        ((-1138682272135453914597124774408609*NM*NC)/
          1360599093078228753750 + (1916262352*lm*NM*NC)/1216215 + 
         (20664601550249*NC*NL)/362210940 + (1916262352*lm*NC*NL)/1216215 + 
         (7942095528122626074516223070626574391997*NC*NH)/
          12172060469245895672037352013495250 + (1916262352*lm*NC*NH)/
          1216215 - (19677950104640*NM*NC*Pi^2)/81 + (544016*NC*NL*Pi^2)/
          81 - (8365565527405683968*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7625597484987*Sqrt[3]) + 
         CA*NC*(-97896501426645860342397697128167877707693833/
            1319127724848243057326793173334375 - (958131176*lm)/110565 - 
           (112489917359987773*Pi^2)/4864860 + (1265630365159989755491*
             Im[PolyLog[2, (-1)^(1/3)]])/(7633223082471987*Sqrt[3]) - 
           21760*Zeta[3]) + CF*NC*
          (12530746644783353853421416872624473372099792649/
            84424174390287555668914763093400000 + (112489897780818163*Pi^2)/
            2432430 - (2531260730319979510982*Im[PolyLog[2, (-1)^(1/3)]])/
            (7633223082471987*Sqrt[3]) + 43520*Zeta[3])), 
      (6137571806110787000192659510616648179333371685797903694990634149*CF^2*
         NC)/3175047566142299471288094814675365909054764544000000 - 
       (1119262706803695824605480607136921837417831348631*CF*NM*NC)/
        1543583253137669926400608213824000000 + 
       (8760871962505661*CF*lm*NM*NC)/14024807596800 + 
       (1680310440609558171727*CF*NC*NL)/36099854754163200 + 
       (8760871962505661*CF*lm*NC*NL)/14024807596800 + 
       (1848375327589684081524109348658293240993581947452825099963*CF*NC*NH)/
        2362333717356274813914676139460385259656605657600000 + 
       (8760871962505661*CF*lm*NC*NH)/14024807596800 - 
       (1133766691032928064072503513*CF^2*NC*Pi^2)/1812005141506560 + 
       (1097789266235413247*CF*NM*NC*Pi^2)/4864860 + (271*CF*lm*NM*NC*Pi^2)/
        162 - (67818452861*CF*NC*NL*Pi^2)/58378320 + (271*CF*lm*NC*NL*Pi^2)/
        162 + (271*CF*lm*NC*NH*Pi^2)/162 - (173357262317197103352035*CF^2*NC*
         Pi^3)/(5652946922790682944*Sqrt[3]) - 
       (63207424713056457995*CF*NC*NH*Pi^3)/(617673396283947*Sqrt[3]) - 
       (354617*CF^2*NC*Pi^4)/648 + (4812042100730049726237546713*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(79220398175988630777216*Sqrt[3]) + 
       (3177505700151853521214651*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (6182910696802309470*Sqrt[3]) - 53210*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (34671452463439420670407*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(30532892329887948*Sqrt[3]) - 
       (28894822725968666512*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7625597484987*Sqrt[3]) - (34671452463439420670407*CF^2*NC*Pi*
         Log[3]^2)/(1465578831834621504*Sqrt[3]) - 
       (1805926420373041657*CF*NC*NH*Pi*Log[3]^2)/(22876792454961*Sqrt[3]) - 
       (CF*NC*(117214482714072097155593715548386*CF - 
          59675*CA*(982107199830447663271299467 + 67029325402029838848*lm) + 
          16016*(527*(-5008421870807237681022047 + 86164805381054400*lm)*
             NM + 65*(1110796560720*(744027 + 628916*lm)*NL + 
              (279864936169502437 + 698597729781779520*lm)*NH)))*Log[x]^2)/
        15611179296221308800 + (CF*NC*(5743996360697864729*CA + 
          20*(-574400453645337481*CF + 24024*(8806757819693*NM + 
              314458*NL)))*Log[x]^3)/4864860 - 
       (211252032303997648256058736061*CF^2*NC*PolyGamma[2, 1])/
        22236242266222092 + (73288394788097*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (777261318141556363189*CF*NC*NH*PolyGamma[2, 1])/22236242266222092 - 
       (793291417353741583114853041025569*CF^2*NC*Zeta[3])/
        44516957016976628184 + (61546057458863*CF*NM*NC*Zeta[3])/27 - 
       (419458*CF*NC*NL*Zeta[3])/9 + (983322537088089940835*CF*NC*NH*
         Zeta[3])/11118121133111046 + CA*CF*NC*
        (-6137572071654625890827638044685391777808593318110294078590317299/
          6350095132284598942576189629350731818109529088000000 + 
         (59671931220991264225882567*Pi^2)/190737383316480 + 
         (173357262317197103352035*Pi^3)/(11305893845581365888*Sqrt[3]) + 
         (21997*Pi^4)/80 + lm*(-8760871962505661/2549965017600 - 
           (2981*Pi^2)/324) - (4812042100730049726237546713*
           Im[PolyLog[2, (-1)^(1/3)]])/(158440796351977261554432*Sqrt[3]) + 
         26605*Im[PolyLog[2, (-1)^(1/3)]]^2 + (34671452463439420670407*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(61065784659775896*
           Sqrt[3]) + (34671452463439420670407*Pi*Log[3]^2)/
          (2931157663669243008*Sqrt[3]) + (211252032303997648256058736061*
           PolyGamma[2, 1])/44472484532444184 + 
         (793291420059576210849283897153033*Zeta[3])/89033914033953256368) + 
       CF*Log[x]*((2890895216649031656172282838118696347*NM*NC)/
          4307816799167210849520000 - (17167422431*lm*NM*NC)/9729720 - 
         (5802358775143267*NC*NL)/87655047480 - (17167422431*lm*NC*NL)/
          9729720 - (1755275043709089625289833296204468051390341*NC*NH)/
          2337035610095211969031171586591088000 - (17167422431*lm*NC*NH)/
          9729720 + (17613514789118*NM*NC*Pi^2)/81 - (628916*NC*NL*Pi^2)/
          81 + (28894822725968666512*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (22876792454961*Sqrt[3]) + 
         CF*NC*(-730186981517021175527406763616627682061809552681163/
            340803507178712804724275115655437120000 - 
           (765866325651123989*Pi^2)/1297296 + (34671452463439420670407*
             Im[PolyLog[2, (-1)^(1/3)]])/(91598676989663844*Sqrt[3]) - 
           48960*Zeta[3]) + CA*NC*
          (1460374015011259737096050605488650879623971418265561/
            1363214028714851218897100462621748480000 + (17167422431*lm)/
            1769040 + (255288779263410323*Pi^2)/864864 - 
           (34671452463439420670407*Im[PolyLog[2, (-1)^(1/3)]])/
            (183197353979327688*Sqrt[3]) + 24480*Zeta[3])), 
      (-22097394706435991747565771304566081696658038329196704496742176917*
         CF^2*NC)/17859642559550434525995533332548933238433050560000000 + 
       (118023807865724801417877337493169872577607941333827*CF*NM*NC)/
        17954310470706581775501811329216000000 - 
       (9599886593613059*CF*lm*NM*NC)/14024807596800 - 
       (138425059712558470854313*CF*NC*NL)/2526989832791424000 - 
       (9599886593613059*CF*lm*NC*NL)/14024807596800 - 
       (19553119919424401402179027361473707709165187993094355190939*CF*NC*
         NH)/21261003456206473325232085255143467336909450918400000 - 
       (9599886593613059*CF*lm*NC*NH)/14024807596800 + 
       (7102889101969074564250842659*CF^2*NC*Pi^2)/18120051415065600 - 
       (6855536798392043353*CF*NM*NC*Pi^2)/3243240 - (289*CF*lm*NM*NC*Pi^2)/
        162 + (76864765889*CF*NC*NL*Pi^2)/58378320 - (289*CF*lm*NC*NL*Pi^2)/
        162 - (289*CF*lm*NC*NH*Pi^2)/162 + (278110344839963758657715*CF^2*NC*
         Pi^3)/(7827157277710176384*Sqrt[3]) + 
       (670778040619327335940*CF*NC*NH*Pi^3)/(5559060566555523*Sqrt[3]) + 
       (4026433*CF^2*NC*Pi^4)/6480 - (42147585299437073903311929061*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(548448910449152059226880*Sqrt[3]) - 
       (16801077005557467704842426*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) + 
       (180115*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (55622068967992751731543*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(42276312456767928*Sqrt[3]) + 
       (306641389997406782144*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (55622068967992751731543*CF^2*NC*Pi*Log[3]^2)/(2029262997924860544*
         Sqrt[3]) + (19165086874837923884*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + 
       (CF*NC*(-279*CA*(1316008030860894513390386114569 + 
            167848548208913155584000*lm) + 
          14*(52452310402371722244498000493753*CF + 
            11440*(4123*(-5996694714473567869349989 + 12894120010886400*lm)*
               NM + 2454860399191200*(25573 + 21656*lm)*NL + 
              5*(4321049190157992613 + 10632491360976925440*lm)*NH)))*
         Log[x]^2)/156111792962213088000 + 
       (CF*NC*(-3640019627397996973*CA + 96*(75833947311631489*CF - 
            5005*(81048994995071*NM + 368152*NL)))*Log[x]^3)/4864860 + 
       (271609756728215195640999922619*CF^2*NC*PolyGamma[2, 1])/
        66708726798666276 - (1539056317385651*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (671983992916780881733*CF*NC*NH*PolyGamma[2, 1])/16677181699666569 + 
       CA*CF*NC*
        (88389585674504547393432221390655188135490486372585707360309754293/
          142877140476403476207964266660391465907464404480000000 - 
         (417817007450403846654181867*Pi^2)/2131770754713600 - 
         (278110344839963758657715*Pi^3)/(15654314555420352768*Sqrt[3]) - 
         (4044929*Pi^4)/12960 + lm*(9599886593613059/2549965017600 + 
           (3179*Pi^2)/324) + (42147585299437073903311929061*
           Im[PolyLog[2, (-1)^(1/3)]])/(1096897820898304118453760*Sqrt[3]) - 
         (180115*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (55622068967992751731543*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (84552624913535856*Sqrt[3]) - (55622068967992751731543*Pi*Log[3]^2)/
          (4058525995849721088*Sqrt[3]) - (271609756728215195640999922619*
           PolyGamma[2, 1])/133417453597332552 - 
         (25651921696881056434288479922477*Zeta[3])/6937707587061292704) + 
       (25651921452457459911901019588581*CF^2*NC*Zeta[3])/
        3468853793530646352 - (1430990998267901*CF*NM*NC*Zeta[3])/27 + 
       (491062*CF*NC*NL*Zeta[3])/9 - (1829169316056710501410*CF*NC*NH*
         Zeta[3])/16677181699666569 + CF*Log[x]*
        ((-27306246314019598527091108996387464523*NM*NC)/
          3854362399254872865360000 + (19585543889*lm*NM*NC)/9729720 + 
         (136544947358781719*NC*NL)/1753100949600 + (19585543889*lm*NC*NL)/
          9729720 + (130330837969748062127283985295002349855841811*NC*NH)/
          147233243435998354048963809955238544000 + (19585543889*lm*NC*NH)/
          9729720 - (162097989029438*NM*NC*Pi^2)/81 + (736304*NC*NL*Pi^2)/
          81 - (306641389997406782144*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CA*NC*(-10926564405585571768870215087959907529771913823454579/
            17527037512048087100105577376565337600000 - (19585543889*lm)/
            1769040 - (37818400021082585*Pi^2)/202176 + 
           (55622068967992751731543*Im[PolyLog[2, (-1)^(1/3)]])/
            (253657874740607568*Sqrt[3]) - 27744*Zeta[3]) + 
         CF*NC*(76485945358496552826145370400186915175124448660743203/
            61344631292168304850369520817978681600000 + 
           (37818398919379073*Pi^2)/101088 - (55622068967992751731543*
             Im[PolyLog[2, (-1)^(1/3)]])/(126828937370303784*Sqrt[3]) + 
           55488*Zeta[3])), (466298213065420520625359414160526368140043238355\
36519012355922794965711*CF^2*NC)/
        2894387966514124452603795158294211069377505010227302400000 - 
       (11766512519345293382824717598161266794762587885877120159*CF*NM*NC)/
        2032532080284715155161102952972960652800000 + 
       (604739727632380679*CF*lm*NM*NC)/810633879095040 + 
       (27193168595142944604733*CF*NC*NL)/431109835700544000 + 
       (604739727632380679*CF*lm*NC*NL)/810633879095040 + 
       (7422479646978369134646659498089289684542995953736637085591*CF*NC*NH)/
        7087001152068824441744028418381155778969816972800000 + 
       (604739727632380679*CF*lm*NC*NH)/810633879095040 - 
       (161460249705296890257491916671*CF^2*NC*Pi^2)/30804087405611520 + 
       (150209003426872937429*CF*NM*NC*Pi^2)/82702620 + 
       (305*CF*lm*NM*NC*Pi^2)/162 - (292293263767*CF*NC*NL*Pi^2)/
        198486288 + (305*CF*lm*NC*NL*Pi^2)/162 + (305*CF*lm*NC*NH*Pi^2)/
        162 - (34819199063392012410720905*CF^2*NC*Pi^3)/
        (864900879186974490432*Sqrt[3]) - (255562717417117394935*CF*NC*NH*
         Pi^3)/(1853020188851841*Sqrt[3]) - (452099*CF^2*NC*Pi^4)/648 + 
       (90112199234108276143222618153319*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1030261278278732143257694080*Sqrt[3]) + 
       (12945463460396832554048903*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (18548732090406928410*Sqrt[3]) - 67070*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (6963839812678402482144181*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) - (116828670819253666256*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (6963839812678402482144181*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) - (7301791926203354141*CF*NC*NH*Pi*Log[3]^2)/
        (68630377364883*Sqrt[3]) - 
       (CF*NC*(-(CA*(1669256848547091200077559077206767 + 
             18261611088177676078379520*lm)) + 
          26*(128404370927101891411195943344249*CF + 
            10472*(11*(-386257479972126858505178729 + 1108614956274745920*lm)*
               NM + 7*(35069434274160*(58461 + 49676*lm)*NL + 
                (717110989529614529 + 1742109217003172160*lm)*NH))))*
         Log[x]^2)/53078009607152449920 - 
       (CF*NC*(-163150057836923646795*CA + 136*(2399266134020488583*CF - 
            12012*(70540236004819*NM + 422246*NL)))*Log[x]^3)/16540524 - 
       (17111414589658232512554915687161*CF^2*NC*PolyGamma[2, 1])/
        200126180395998828 + (659595563435989*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (9301950024715948146457*CF*NC*NH*PolyGamma[2, 1])/
        200126180395998828 - (1097557460895214957876556867488159343*CF^2*NC*
         Zeta[3])/6811094423597424112152 + (565541924024743*CF*NM*NC*
         Zeta[3])/27 - (563198*CF*NC*NL*Zeta[3])/9 + 
       (12405894887227493417135*CF*NC*NH*Zeta[3])/100063090197999414 + 
       CA*CF*NC*(-46629821621955827989468672991655533043199879503151292404817\
754579258011/5788775933028248905207590316588422138755010020454604800000 + 
         (32292049950557622391502904235*Pi^2)/12321634962244608 + 
         (34819199063392012410720905*Pi^3)/(1729801758373948980864*Sqrt[3]) + 
         (454051*Pi^4)/1296 + lm*(-604739727632380679/147387978017280 - 
           (3355*Pi^2)/324) - (90112199234108276143222618153319*
           Im[PolyLog[2, (-1)^(1/3)]])/(2060522556557464286515388160*
           Sqrt[3]) + 33535*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (6963839812678402482144181*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) + (6963839812678402482144181*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) + 
         (17111414589658232512554915687161*PolyGamma[2, 1])/
          400252360791997656 + (1097557461446173593391962181919397347*
           Zeta[3])/13622188847194848224304) + 
       CF*Log[x]*((11231848239529836764661324260811361388263*NM*NC)/
          2010765801371277818531664000 - (74120995453*lm*NM*NC)/33081048 - 
         (60706362480401347*NC*NL)/677334457800 - (74120995453*lm*NC*NL)/
          33081048 - (3818842346974993102163186011946601292951963*NC*NH)/
          3775211370153803949973431024493296000 - (74120995453*lm*NC*NH)/
          33081048 + (141080470905250*NM*NC*Pi^2)/81 - (844492*NC*NL*Pi^2)/
          81 + (116828670819253666256*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (68630377364883*Sqrt[3]) + 
         CF*NC*(-91462394609905264569390076946199767276316636498517842841/
            5010936207100767981702434308016588606496000 - 
           (36255569508985804297*Pi^2)/7351344 + (6963839812678402482144181*
             Im[PolyLog[2, (-1)^(1/3)]])/(14014597579418568132*Sqrt[3]) - 
           62016*Zeta[3]) + CA*NC*
          (52264225786339393200815753948785933977381267898180763077/
            5726784236686591979088496352018958407424000 + (74120995453*lm)/
            6014736 + (108766708803991314035*Pi^2)/44108064 - 
           (6963839812678402482144181*Im[PolyLog[2, (-1)^(1/3)]])/
            (28029195158837136264*Sqrt[3]) + 31008*Zeta[3])), 
      (-182217501825447044898488057922040114191376237622352070466016671160157\
357*CF^2*NC)/18089924790713277828773719739338819183609406313920640000000 + 
       (6142798516293144627304812875124753911048405452014110629*CF*NM*NC)/
        112918448904706397508950164054053369600000 - 
       (10172711317044019*CF*lm*NM*NC)/12509782084800 - 
       (180748022345126978506189*CF*NC*NL)/2458922766588288000 - 
       (10172711317044019*CF*lm*NC*NL)/12509782084800 - 
       (64817357293662705070938300847332694288850092522866078806047*CF*NC*
         NH)/53152508640516183313080213137858668342273627296000000 - 
       (10172711317044019*CF*lm*NC*NH)/12509782084800 + 
       (23573816545284329175798067853*CF^2*NC*Pi^2)/7334306525145600 - 
       (161669448607828507613*CF*NM*NC*Pi^2)/9189180 - 2*CF*lm*NM*NC*Pi^2 + 
       (5074699507*CF*NC*NL*Pi^2)/3063060 - 2*CF*lm*NC*NL*Pi^2 - 
       2*CF*lm*NC*NH*Pi^2 + (39990510045058291660202605*CF^2*NC*Pi^3)/
        (864900879186974490432*Sqrt[3]) + (1790492296460076974485*CF*NC*NH*
         Pi^3)/(11118121133111046*Sqrt[3]) + (169813*CF^2*NC*Pi^4)/216 - 
       (557147038714452881720007555109871*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5151306391393660716288470400*Sqrt[3]) - 
       (22618409548729341528736697*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) + 75158*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 + (7998102009011658332040521*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) + (409255382048017594168*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (7998102009011658332040521*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) + (51156922756002199271*CF*NC*NH*Pi*Log[3]^2)/
        (411782264189298*Sqrt[3]) + 
       ((25590380627622928843888033628310949*CF^2*NC)/663475120089405624000 + 
         CA*CF*(-25590381395622066891558841001665729/1326950240178811248000 - 
           399058*lm)*NC + CF*NC*((-457300400786552337599134051/
              2166053293404 + 72556*lm)*NM + (68*(3761 + 3201*lm)*NL)/3 + 
           (1638088260420093679*NH)/54151332335100 + 72556*lm*NH))*
        Log[x]^2 + (4*CF*NC*(-10527549542756942844*CA + 
          5*(4211021766227217569*CF - 918918*(24906577640365*NM + 
              18139*NL)))*Log[x]^3)/6891885 + 
       (11000195098753056087810631969663*CF^2*NC*PolyGamma[2, 1])/
        300189270593998242 - 256509386454644*CF*NM*NC*PolyGamma[2, 1] + 
       (7981138330152105184090*CF*NC*NH*PolyGamma[2, 1])/
        150094635296999121 + CA*CF*NC*(11388594004420637552141662156997938495\
662332887126127139662268560650327/
          2261240598839159728596714967417352397951175789240080000000 - 
         (7857938852687857006617605591*Pi^2)/4889537683430400 - 
         (39990510045058291660202605*Pi^3)/(1729801758373948980864*Sqrt[3]) - 
         (852521*Pi^4)/2160 + lm*(10172711317044019/2274505833600 + 
           11*Pi^2) + (557147038714452881720007555109871*
           Im[PolyLog[2, (-1)^(1/3)]])/(10302612782787321432576940800*
           Sqrt[3]) - 37579*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (7998102009011658332040521*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) - (7998102009011658332040521*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) - 
         (11000195098753056087810631969663*PolyGamma[2, 1])/
          600378541187996484 - (6863364306444920766488438033085051247*
           Zeta[3])/204332832707922723364560) + 
       (6863364296941098001935236728327714447*CF^2*NC*Zeta[3])/
        102166416353961361682280 - (1439430009275888*CF*NM*NC*Zeta[3])/3 + 
       72580*CF*NC*NL*Zeta[3] - (22653470730366535486216*CF*NC*NH*Zeta[3])/
        150094635296999121 + CF*Log[x]*
        ((-2938348708686792416241926370703592433701*NM*NC)/
          48872779894440780311533500 + (1294372957*lm*NM*NC)/510510 + 
         (427659495974093*NC*NL)/4095748800 + (1294372957*lm*NC*NL)/
          510510 + (9876894967752029903508365878710652726662727*NC*NH)/
          8365525195227179207327489202002190000 + (1294372957*lm*NC*NH)/
          510510 - (49813155234830*NM*NC*Pi^2)/3 + (36278*NC*NL*Pi^2)/3 - 
         (409255382048017594168*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CA*NC*(-3400900186625462335217118945940922096451398617577450071/
            647826271118392757815440763803049593600000 - (1294372957*lm)/
            92820 - (112293868715924754611*Pi^2)/73513440 + 
           (7998102009011658332040521*Im[PolyLog[2, (-1)^(1/3)]])/
            (28029195158837136264*Sqrt[3]) - 34884*Zeta[3]) + 
         CF*NC*(5261192528798841468770662448515663220841340938318867365237/
            501093620710076798170243430801658860649600000 + 
           (336881604548559486673*Pi^2)/110270160 - 
           (7998102009011658332040521*Im[PolyLog[2, (-1)^(1/3)]])/
            (14014597579418568132*Sqrt[3]) + 69768*Zeta[3])), 
      (2293939538913522980349367292848429609899555667593551019125132597705469\
253*CF^2*NC)/16988798933887252221804884624770369320259268538290688000000 - 
       (8622017754825340199822321116905968473731246294962499731*CF*NM*NC)/
        184775643662246832287372995724814604800000 + 
       (325040977793221549*CF*lm*NM*NC)/368469945043200 + 
       (243478396971215984296099*CF*NC*NL)/2898016117764768000 + 
       (325040977793221549*CF*lm*NC*NL)/368469945043200 + 
       (3961165726370143210360274642383224531085366686465410013295601*CF*NC*
         NH)/2870235466587873898906331509444368090482775873984000000 + 
       (325040977793221549*CF*lm*NC*NH)/368469945043200 - 
       (30894389027371908778239152377*CF^2*NC*Pi^2)/700092895582080 + 
       (304852975235892803101*CF*NM*NC*Pi^2)/20675655 + 
       (341*CF*lm*NM*NC*Pi^2)/162 - (55394713559*CF*NC*NL*Pi^2)/30073680 + 
       (341*CF*lm*NC*NL*Pi^2)/162 + (341*CF*lm*NC*NH*Pi^2)/162 - 
       (607658095127806015089084335*CF^2*NC*Pi^3)/(11676161869024155620832*
         Sqrt[3]) - (54893803010682782783245*CF*NC*NH*Pi^3)/
        (300189270593998242*Sqrt[3]) - (284195*CF^2*NC*Pi^4)/324 + 
       (1702526745400888909613693872365353*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(13908527256762883933978870080*
         Sqrt[3]) + (107763775881886565958106201*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(115572869178689323170*Sqrt[3]) - 
       (250420*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (121531619025561203017816867*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(63065689107383556594*
         Sqrt[3]) - (12547154973870350350456*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (121531619025561203017816867*CF^2*NC*Pi*Log[3]^2)/
        (3027153077154410716512*Sqrt[3]) - (1568394371733793793807*CF*NC*NH*
         Pi*Log[3]^2)/(11118121133111046*Sqrt[3]) - 
       (CF*NC*(-805*CA*(65467417441697373765848922114277 + 
            112366695800138911971840*lm) + 
          4*(26350635454558923742649073372858626*CF + 
            51051*(65*(-2653265449599488014248990773 + 1239062461179459840*
                 lm)*NM + 3682290598786800*(25619 + 21872*lm)*NL + 
              (33969358650920574149 + 80539059976664889600*lm)*NH)))*
         Log[x]^2)/199042536026821687200 + 
       (CF*NC*(2283923068088480148741*CA - 340*(13434842110862825161*CF - 
            24024*(190100260010693*NM + 185912*NL)))*Log[x]^3)/27567540 - 
       (1386024581434610493764198379511523*CF^2*NC*PolyGamma[2, 1])/
        1801135623563989452 + (35618160509922829*CF*NM*NC*PolyGamma[2, 1])/
        324 - (27406225862571542585167*CF*NC*NH*PolyGamma[2, 1])/
        450283905890997363 - (11158166807237747235975833733552680527*CF^2*NC*
         Zeta[3])/7662481226547102126171 + (31055754337488433*CF*NM*NC*
         Zeta[3])/162 - (2231626*CF*NC*NL*Zeta[3])/27 + 
       (76432765601444496884278*CF*NC*NH*Zeta[3])/450283905890997363 + 
       CA*CF*NC*(-17645688779206865313845405048908699853428843433177741187716\
5578287304331/2613661374444192649508443788426210664655272082813952000000 + 
         (15447194514370827044093398367*Pi^2)/700092895582080 + 
         (607658095127806015089084335*Pi^3)/(23352323738048311241664*
           Sqrt[3]) + (475477*Pi^4)/1080 + 
         lm*(-325040977793221549/66994535462400 - (3751*Pi^2)/324) - 
         (1702526745400888909613693872365353*Im[PolyLog[2, (-1)^(1/3)]])/
          (27817054513525767867957740160*Sqrt[3]) + 
         (125210*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (121531619025561203017816867*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (126131378214767113188*Sqrt[3]) + (121531619025561203017816867*Pi*
           Log[3]^2)/(6054306154308821433024*Sqrt[3]) + 
         (1386024581434610493764198379511523*PolyGamma[2, 1])/
          3602271247127978904 + (5579083404025148731158880109255097248*
           Zeta[3])/7662481226547102126171) + 
       CF*Log[x]*((656239374911760369100771910548772598911909*NM*NC)/
          14075360609598944729721648000 - (14068604189*lm*NM*NC)/5012280 - 
         (3554356939836460517*NC*NL)/29802716143200 - 
         (14068604189*lm*NC*NL)/5012280 - 
         (1567178181867496859556859396151511922912120487*NC*NH)/
          1169205168462339870388830255526894320000 - (14068604189*lm*NC*NH)/
          5012280 + (126733506516704*NM*NC*Pi^2)/9 - (371824*NC*NL*Pi^2)/
          27 + (12547154973870350350456*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CF*NC*(-18336895032867672449682490763510029682908460533869558664487/
            117648067471061509135622370709954689022080000 - 
           (57098076975571863760*Pi^2)/1378377 + (121531619025561203017816867*
             Im[PolyLog[2, (-1)^(1/3)]])/(189197067322150669782*Sqrt[3]) - 
           77520*Zeta[3]) + CA*NC*
          (2292111881120837280203213556147483708842265386240661647779/
            29412016867765377283905592677488672255520000 + 
           (154754646079*lm)/10024560 + (76130769331249898303*Pi^2)/3675672 - 
           (121531619025561203017816867*Im[PolyLog[2, (-1)^(1/3)]])/
            (378394134644301339564*Sqrt[3]) + 38760*Zeta[3])), 
      (-403829336107980518857146119894464931378362776633822792206529628569172\
41673*CF^2*NC)/488427969349258501376890432962148117957453970475857280000000 + 
       (131554105288882936686405487616537784218287535260215227507*CF*NM*NC)/
        290361725754959307880157564710422950400000 - 
       (3879221127170612539*CF*lm*NM*NC)/4053169395475200 - 
       (267771519001769198580443173*CF*NC*NL)/2758911344112059136000 - 
       (3879221127170612539*CF*lm*NC*NL)/4053169395475200 - 
       (231662386066292127909829511366014183634012730133015244896671955247*CF*
         NC*NH)/
        145386037089075576601302409947885576887224046344911552000000 - 
       (3879221127170612539*CF*lm*NC*NH)/4053169395475200 + 
       (1635580722212005661533377785089*CF^2*NC*Pi^2)/61608174811223040 - 
       (66918005198280503449*CF*NM*NC*Pi^2)/454410 - (361*CF*lm*NM*NC*Pi^2)/
        162 + (681041846699*CF*NC*NL*Pi^2)/330810480 - 
       (361*CF*lm*NC*NL*Pi^2)/162 - (361*CF*lm*NC*NH*Pi^2)/162 + 
       (2769981682739707153825852115*CF^2*NC*Pi^3)/(46704647476096622483328*
         Sqrt[3]) + (127088129052270220677815*CF*NC*NH*Pi^3)/
        (600378541187996484*Sqrt[3]) + (6361751*CF^2*NC*Pi^4)/6480 - 
       (843510570822831283897764647750449*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5676949900719544462848518400*Sqrt[3]) - 
       (27523518802155039044601131081*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (25541604088490340420570*Sqrt[3]) + 92967*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 + (79142333792563061537881489*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(36037536632790603768*
         Sqrt[3]) + (14524357605973739506036*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) + 
       (79142333792563061537881489*CF^2*NC*Pi*Log[3]^2)/
        (1729801758373948980864*Sqrt[3]) + (3631089401493434876509*CF*NC*NH*
         Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) + 
       ((1268208854160176631692969116614344843*CF^2*NC)/
          3980850720536433744000 + CA*CF*
          (-1268208860206480907205740092975280363/7961701441072867488000 - 
           (4704799*lm)/9)*NC + CF*NC*((-344499026822729924586956543851/
              194944796406360 + (855418*lm)/9)*NM + 
           (19*(52659 + 45022*lm)*NL)/9 + (1462396461261701024497*NH)/
            36064787335176600 + (855418*lm*NH)/9))*Log[x]^2 + 
       (CF*NC*(-1386454207099077456187*CA + 8*(346613578539192107909*CF - 
            510510*(3742599352881416*NM + 427709*NL)))*Log[x]^3)/27567540 + 
       (1782031604828189794864615526494145*CF^2*NC*PolyGamma[2, 1])/
        5403406870691968356 - (186995342749848020*CF*NM*NC*PolyGamma[2, 1])/
        81 + (186836663677906176675611*CF*NC*NH*PolyGamma[2, 1])/
        2701703435345984178 + CA*CF*NC*(8076586737677205315763306045151840510\
8356126090490518112034323640271032471/
          1953711877397034005507561731848592471829815881903429120000000 - 
         (86083195913011797995956984483*Pi^2)/6485071032760320 - 
         (2769981682739707153825852115*Pi^3)/(93409294952193244966656*
           Sqrt[3]) - (425657*Pi^4)/864 + 
         lm*(3879221127170612539/736939890086400 + (3971*Pi^2)/324) + 
         (843510570822831283897764647750449*Im[PolyLog[2, (-1)^(1/3)]])/
          (11353899801439088925697036800*Sqrt[3]) - 
         (92967*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
         (79142333792563061537881489*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (72075073265581207536*Sqrt[3]) - (79142333792563061537881489*Pi*
           Log[3]^2)/(3459603516747897961728*Sqrt[3]) - 
         (1782031604828189794864615526494145*PolyGamma[2, 1])/
          10806813741383936712 - (65912039714935359423463429292117386387*
           Zeta[3])/216352411102506412974240) + 
       (65912039701838700599151897964669156747*CF^2*NC*Zeta[3])/
        108176205551253206487120 - (351535089421470100*CF*NM*NC*Zeta[3])/
        81 + (2566976*CF*NC*NL*Zeta[3])/27 - 
       (274861839164337771477025*CF*NC*NH*Zeta[3])/1350851717672992089 + 
       CF*Log[x]*((-211763292538409631964353627624334286863699*NM*NC)/
          413981194399968962638872000 + (173864455979*lm*NM*NC)/55135080 + 
         (39874282474373126033*NC*NL)/289512099676800 + 
         (173864455979*lm*NC*NL)/55135080 + 
         (1918359478430684117223111529713468327600967439767*NC*NH)/
          1236859631164728900161783933494427795880000 + 
         (173864455979*lm*NC*NH)/55135080 - (1247533117451927*NM*NC*Pi^2)/
          9 + (427709*NC*NL*Pi^2)/27 - (14524357605973739506036*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CA*NC*(-239898381776382151236029418189713473300938883378026726969066\
1/54118111036688294202386290526579156950156800000 - (173864455979*lm)/
            10024560 - (326224522527311341597*Pi^2)/25945920 + 
           (79142333792563061537881489*Im[PolyLog[2, (-1)^(1/3)]])/
            (216225219796743622608*Sqrt[3]) - 43320*Zeta[3]) + 
         CF*NC*(2398983813501894481301974807467904078318366226693273654105311/
            27059055518344147101193145263289578475078400000 + 
           (326224522280787103637*Pi^2)/12972960 - 
           (79142333792563061537881489*Im[PolyLog[2, (-1)^(1/3)]])/
            (108112609898371811304*Sqrt[3]) + 86640*Zeta[3])), 
      (1266415675702711096122321344654862448327957019362576132280056357901489\
99868431*CF^2*NC)/
        111361577011630938313931018715369770894299505268495459840000000 - 
       (3853844093796122073128771824032081739736475072163053398347*CF*NM*NC)/
        10162660401423575775805514764864803264000000 + 
       (1512806647537939230121*CF*lm*NM*NC)/1463194151766547200 + 
       (4572784116999304453762522283*CF*NC*NL)/41498624801018889504000 + 
       (1512806647537939230121*CF*lm*NC*NL)/1463194151766547200 + 
       (782072757795801973856123629494392854441135050103801869890864306881*CF*
         NC*NH)/
        436158111267226729803907229843656730661672139034734656000000 + 
       (1512806647537939230121*CF*lm*NC*NH)/1463194151766547200 - 
       (2132718746272330310690763935366*CF^2*NC*Pi^2)/5715602155338075 + 
       (3643962376991486429678*CF*NM*NC*Pi^2)/30218265 + 
       (379*CF*lm*NM*NC*Pi^2)/162 - (14309702922569*CF*NC*NL*Pi^2)/
        6285399120 + (379*CF*lm*NC*NL*Pi^2)/162 + (379*CF*lm*NC*NH*Pi^2)/
        162 - (44165267352981662855357320945*CF^2*NC*Pi^3)/
        (665541226534376870387424*Sqrt[3]) - (215177873578814868754865*CF*NC*
         NH*Pi^3)/(900567811781994726*Sqrt[3]) - (1764409*CF^2*NC*Pi^4)/
        1620 + (359937247484400626461357241157139171*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2151847859867743328642730899520*
         Sqrt[3]) + (13437339336477308477001220111*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10946401752210145894530*Sqrt[3]) - 
       (308140*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (1261864781513761795867352027*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(513534897017266103694*
         Sqrt[3]) - (49183513960871970001112*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (1261864781513761795867352027*CF^2*NC*Pi*Log[3]^2)/
        (24649675056828772977312*Sqrt[3]) - (6147939245108996250139*CF*NC*NH*
         Pi*Log[3]^2)/(33354363399333138*Sqrt[3]) + 
       ((-84668593029268936853922075038946941497*CF^2*NC)/
          18909040922548060284000 + 
         CA*CF*(42334296530911949235187516190953710401/
            18909040922548060284000 + (5323648*lm)/9)*NC + 
         CF*NC*((18317935744569856919850843319/12658753013400 - 
             (967936*lm)/9)*NM - (38*(29709 + 25472*lm)*NL)/9 - 
           (238893231070697380681*NH)/5152112476453800 - (967936*lm*NH)/9))*
        Log[x]^2 + (CF*NC*(366185740876567992497985*CA + 
          152*(-4818233463515492912509*CF + 1021020*(1549242796690195*NM + 
              241984*NL)))*Log[x]^3)/523783260 - 
       (112267991092288918446811573828828127*CF^2*NC*PolyGamma[2, 1])/
        16210220612075905068 + (320563444702004057*CF*NM*NC*PolyGamma[2, 1])/
        324 - (318562634532579380817697*CF*NC*NH*PolyGamma[2, 1])/
        4052555153018976267 - (34466739838263233997977361663485422145471*CF^2*
         NC*Zeta[3])/2620568579479108927150482 + 
       (283381617669350261*CF*NM*NC*Zeta[3])/162 - 
       (2904566*CF*NC*NL*Zeta[3])/27 + (922960171347473666028058*CF*NC*NH*
         Zeta[3])/4052555153018976267 + CA*CF*NC*
        (-1266415675901626236719673896765179472240513328055199725302672882332\
75981424431/222723154023261876627862037430739541788599010536990919680000000 + 
         (34123499940581151409554213465071*Pi^2)/182899268970818400 + 
         (44165267352981662855357320945*Pi^3)/(1331082453068753740774848*
           Sqrt[3]) + (1770473*Pi^4)/3240 + 
         lm*(-1512806647537939230121/266035300321190400 - (4169*Pi^2)/324) - 
         (359937247484400626461357241157139171*Im[PolyLog[2, (-1)^(1/3)]])/
          (4303695719735486657285461799040*Sqrt[3]) + 
         (154070*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1261864781513761795867352027*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1027069794034532207388*Sqrt[3]) + (1261864781513761795867352027*Pi*
           Log[3]^2)/(49299350113657545954624*Sqrt[3]) + 
         (112267991092288918446811573828828127*PolyGamma[2, 1])/
          32420441224151810136 + (8616684959655652594360465693744985751398*
           Zeta[3])/1310284289739554463575241) + 
       CF*Log[x]*((27469434796146187381911694542832780450016663*NM*NC)/
          70376803047994723648608240000 - (3639044854499*lm*NM*NC)/
          1047566520 - (1504266108102762197789*NC*NL)/9626277314253600 - 
         (3639044854499*lm*NC*NL)/1047566520 - 
         (142887018015736023929315848684908181381025197251227*NC*NH)/
          81632735656872107410677739610632234528080000 - 
         (3639044854499*lm*NC*NH)/1047566520 + 
         (1032828530928272*NM*NC*Pi^2)/9 - (483968*NC*NL*Pi^2)/27 + 
         (49183513960871970001112*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*
          (-1028737792658522711501153925683090537705971163593338124978783849/
            771183082272808192384004640003752986539734400000 - 
           (4068730457195841378563*Pi^2)/11639628 + 
           (1261864781513761795867352027*Im[PolyLog[2, (-1)^(1/3)]])/
            (1540604691051798311082*Sqrt[3]) - 95760*Zeta[3]) + 
         CA*NC*
          (257184448199154554944993050127694684084166113283250037239047031/
            385591541136404096192002320001876493269867200000 + 
           (3639044854499*lm)/190466640 + (36618574117024040904355*Pi^2)/
            209513304 - (1261864781513761795867352027*
             Im[PolyLog[2, (-1)^(1/3)]])/(3081209382103596622164*Sqrt[3]) + 
           47880*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["p", 2, 1, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(224*NM - 672*lm*NM + 800*NL - 672*lm*NL + 224*NH - 
         672*lm*NH + 756*NM*Zeta[3] + 756*NH*Zeta[3] + 
         6*CF*(-802 + 1317*Zeta[3]) + CA*(-6770 + 3696*lm + 2961*Zeta[3])))/
       20736, -(CF*NC*(-1798*NM - 672*lm*NM + 128*NL - 672*lm*NL + 
          902*NH - 672*lm*NH + 1701*NM*Zeta[3] - 189*NH*Zeta[3] + 
          6*CF*(-802 + 1317*Zeta[3]) + CA*(-3074 + 3696*lm + 2961*Zeta[3])))/
       20736, (CF*NC*(-1844882*NM - 342528*lm*NM - 221952*NL - 
         342528*lm*NL + 1071118*NH - 342528*lm*NH + 1310715*NM*Zeta[3] - 
         730485*NH*Zeta[3] + 1008*CF*(-152902 + 128721*Zeta[3]) + 
         24*CA*(-1148138 + 78496*lm + 1029339*Zeta[3])))/14929920, 
      -(CF*NC*(-1005002*NM - 100608*lm*NM - 157056*NL - 100608*lm*NL + 
          775750*NH - 100608*lm*NH + 664335*NM*Zeta[3] - 
          628425*NH*Zeta[3] + 576*CF*(-264571 + 220323*Zeta[3]) + 
          96*CA*(-281865 + 5764*lm + 246231*Zeta[3])))/7464960, 
      (CF*NC*(CA*(-15724946258 + 68006400*lm + 13366466235*Zeta[3]) - 
         2*(20134656*NL + 6182400*lm*NL - 135963650*NH + 6182400*lm*NH + 
           25*NM*(5883982 + 247296*lm - 3978261*Zeta[3]) + 
           114869475*NH*Zeta[3] - 165*CF*(-401534614 + 333861921*Zeta[3]))))/
       2090188800, -(CF*NC*(-310046050*NM - 537600*lm*NM - 29487616*NL - 
          537600*lm*NL + 308408490*NH - 537600*lm*NH + 
          222297075*NM*Zeta[3] - 263706975*NH*Zeta[3] + 
          90*CF*(-3234297394 + 2689859211*Zeta[3]) + 
          CA*(-28250554934 + 2956800*lm + 23701909905*Zeta[3])))/2090188800, 
      (CF*NC*(-5277584595430*NM + 119152803840*lm*NM - 259388145664*NL + 
         119152803840*lm*NL + 5062254127770*NH + 119152803840*lm*NH + 
         4035278165625*NM*Zeta[3] - 4339851618375*NH*Zeta[3] + 
         28*CF*(-332524705744838 + 276609364842825*Zeta[3]) + 
         CA*(-731988745532204 - 655340421120*lm + 610475483995650*Zeta[3])))/
       32774160384000, -(CF*NC*(-6003991330750*NM + 193377730560*lm*NM - 
          66676228096*NL + 193377730560*lm*NL + 4972019844750*NH + 
          193377730560*lm*NH - 24*CA*(47407999215634 + 44315729920*lm - 
            39441248602875*Zeta[3]) + 4843249480125*NM*Zeta[3] - 
          4256759611125*NH*Zeta[3] + 112*CF*(-156241617902438 + 
            129978974410425*Zeta[3])))/32774160384000, 
      (CF*NC*(CA*(-20049928345061322922 - 14527765698969600*lm + 
           16667121025913313375*Zeta[3]) + 18*CF*(-20375495209063816742 + 
           16950799254380945625*Zeta[3]) + 
         10*(32768*(3234157013 + 8060949540*lm)*NL + 
           63*NH*(87270926603098 + 4192717373440*lm - 74466847830375*
              Zeta[3]) + 63*NM*(-135873786377102 + 4192717373440*lm + 
             113480104555125*Zeta[3]))))/389357025361920000, 
      -(CF*NC*(CA*(-5731377727229435242 - 2845215571968000*lm + 
            4763863857080930175*Zeta[3]) + 
          2*(4*(204800*(284484919 + 315742140*lm)*NL + 63*NH*(
                19409183883782 + 1026412544000*lm - 16489082003625*
                 Zeta[3])) + 126*NM*(-85469468350174 + 2052825088000*lm + 
              72549661078125*Zeta[3]) + 9*CF*(-6828705317586118502 + 
              5680911088253770425*Zeta[3]))))/77871405072384000, 
      (CF*NC*(-176466272955093649638*NM + 2873509710240153600*lm*NM + 
         3800948296481505280*NL + 2873509710240153600*lm*NL + 
         52676296954935982218*NH + 2873509710240153600*lm*NH - 
         352*CA*(142056552697749364054 + 44898589222502400*lm - 
           118092526890454757025*Zeta[3]) + 150289701337604453625*NM*
          Zeta[3] - 44535376506176931375*NH*Zeta[3] + 
         3520*CF*(-352791852294603569698 + 293491259545989176595*Zeta[3])))/
       489966880715440128000, -(CF*NC*(-58756723115554087998*NM + 
          586435058848235520*lm*NM + 1014826083788849152*NL + 
          586435058848235520*lm*NL + 10905191162062441596*NH + 
          586435058848235520*lm*NH - 55*CA*(307283412322725208630 + 
            58643505884823552*lm - 255495730693740910065*Zeta[3]) + 
          49880580388433920125*NM*Zeta[3] - 9174694762343360250*NH*
           Zeta[3] + 66*CF*(-7285937983006234571174 + 6061222915007143462425*
             Zeta[3])))/122491720178860032000, 
      (CF*NC*(468*CF*(-233688746070864624415916786 + 
           194406962156893977755539275*Zeta[3]) + 
         CA*(-3386040280178244132114779852 - 373394651097719510138880*lm + 
           2815854713483363283533051250*Zeta[3]) + 
         7*(4194304*(5004985190257483 + 2312317458671220*lm)*NL + 
           2145*NM*(-800747862874058890466 + 4521474296584863744*lm + 
             676225289433197178675*Zeta[3]) + 1287*NH*
            (7535790494308106240*lm - 1859*(-79391786358977126 + 
               66477361544141625*Zeta[3])))))/18548186236363701485568000, 
      -(CF*NC*(-4*CA*(1570518690772929439369821566 + 96005918090061781401600*
             lm - 1306220979454052634347500125*Zeta[3]) + 
          104*CF*(-2197065127622738536865663498 + 
            1827750060549266514064779375*Zeta[3]) + 
          5*(8388608*(4438259024359837 + 1664697787372620*lm)*NL + 
            6435*NH*(46425960978969595738 + 2170085031349846016*lm - 
              38701946325802134375*Zeta[3]) + 15015*NM*
             (-312297681020892245386 + 930036442007076864*lm + 
              262432514219891590575*Zeta[3]))))/26497408909091002122240000, 
      (CF*NC*(CA*(-6113244048319832948830767217054 - 
           198125318389966037298708480*lm + 5084913785987834358171745258125*
            Zeta[3]) + CF*(-248644791349353106520522297838788 + 
           206848980157436348606876911659750*Zeta[3]) + 
         7*(805306368*(21071565726259793 + 6390253908898860*lm)*NL + 
           143*NH*(876357948751971623251886 + 35986798363448558223360*lm - 
             727605600818847098473125*Zeta[3]) + 143*NM*
            (-24540949275475889821628818 + 35986798363448558223360*lm + 
             20544312933565147766914875*Zeta[3]))))/
       20180426625163707216297984000, 
      -(CF*NC*(-8*CA*(962468352937900074577116194078 + 
            15645317708245065667706880*lm - 800614368624673117487625778125*
             Zeta[3]) + 16*CF*(-21752722323438367011944758319842 + 
            18096219562069841430834710989875*Zeta[3]) + 
          7*(3221225472*(4217294868255661 + 1009235502595320*lm)*NL + 
            143*NH*(665039313071914957186582 + 22734091665781586657280*lm - 
              550161567112487019314625*Zeta[3]) + 1001*NM*
             (-4855324657391583189441434 + 3247727380825940951040*lm + 
              4054095841484522148690375*Zeta[3]))))/
       20180426625163707216297984000, 
      (CF*NC*(-5*CA*(1261808955457208326792696482086830154 + 
           9480167666719636790347227463680*lm - 
           1049654270637529746361007255654208975*Zeta[3]) + 
         4862*CF*(-64829724456614978956370745955318898 + 
           53932261036891382359509025804948875*Zeta[3]) + 
         840*(805306368*(71368170780627707521 + 12740395612057353240*lm)*
            NL + 9724*NM*(-3823525492792344355706160334 + 
             1055113298768926794055680*lm + 3187376776654662579005143125*
              Zeta[3]) + 2431*NH*(4220453195075707176222720*lm - 
             2431*(-66218704548591125110694 + 54606350232667265657625*
                Zeta[3])))))/13297286711852869958963067617280000, 
      -(CF*NC*(-5*CA*(517072246815238003845136606232069918 + 
            1543549597678117891543243161600*lm - 
            430143625544949971251293663212971725*Zeta[3]) + 
          3366*CF*(-42206303383845344045557660107643438 + 
            35111706422370020817790706502337125*Zeta[3]) + 
          35*(10737418240*(31895789161553260037 + 3733876845081222840*lm)*
             NL + 2431*NH*(956211854172096234509221282 + 
              16492059787037752531353600*lm - 786366725664837393883681875*
               Zeta[3]) + 2431*NM*(-171376658414155375762521054098 + 
              16492059787037752531353600*lm + 142726530001533666205649506875*
               Zeta[3]))))/4432428903950956652987689205760000, 
      (CF*NC*(-16*CA*(3406732322388335599178017932429981938978 + 
           2627981029699554345390815418777600*lm - 
           2834039905669037077999524583219333033875*Zeta[3]) + 
         608*CF*(-5394691483114732360973810017598257025386 + 
           4487881231197269614415271837424518741375*Zeta[3]) + 
         105*(68719476736*(20778030937502399672641 + 1059522969099751196040*
              lm)*NL + 20995*NH*(471978386942879370924018712310 + 
             3467962087464062833039245312*lm - 387243139461330290729255089425*
              Zeta[3]) + 4199*NM*(-806600596478915224105128423459218 + 
             17339810437320314165196226560*lm + 
             671395762983967292071794273154875*Zeta[3]))))/
       76805128047662176882970678557409280000, 
      -(CF*NC*(8*CA*(-821254350797816956251525157667996471698 + 
            178941245674142573972044916981760*lm + 
            683201676733408341696437884481732559675*Zeta[3]) + 
          304*CF*(-1418528956690489624072040057051059679642 + 
            1180084296907820610587164657499309759175*Zeta[3]) - 
          21*(68719476736*(-7268565335291087886101 + 180359330764224371760*
               lm)*NL + 4199*NM*(570101961190318774850320163494822 + 
              2951702508828922556857712640*lm - 
              474403632132495654445958678201625*Zeta[3]) + 
            4199*NH*(-868302144775745710201814383442 + 
              2951702508828922556857712640*lm + 
              711041617249591511086727398875*Zeta[3]))))/
       7680512804766217688297067855740928000, 
      (CF*NC*(CA*(-7945663985910338825380717383500165278177774 + 
           4669928239117608475369419098585825280*lm + 
           6610027891220731352216953477302859016619525*Zeta[3]) + 
         CF*(-566848353193867989037605825015388423712459812 + 
           471565223988069599836290613945480754867368950*Zeta[3]) - 
         462*(412316860416*(-37698747482515335458933 + 4457326502570898836880*
              lm)*NL + 4199*NH*(437682988661362886608599121920*lm + 
             54587*(-538543204846515203224069414 + 
               440318020025768533164833625*Zeta[3])) + 
           4199*NM*(437682988661362886608599121920*lm - 
             493*(-75485792210334336509676834306334 + 
               62805370251553481463949586674125*Zeta[3])))))/
       7772678958423412300556632670009819136000, 
      -(CF*NC*(135*CA*(-10573187342239870705723387095590846731278 + 
            7011620472384175359363732597637120*lm + 
            8795895134631290666288694154965628156725*Zeta[3]) + 
          2*(CF*(-55163788350203366518782153041163193549548702 + 
              45891156212787835005472218069020574289594125*Zeta[3]) - 
            140*(1030792151040*(-2449931428143674217511 + 
                596293870486067886132*lm)*NL + 4199*NM*(
                13247825170022882273199290146917158 + 
                146381291119385826791490846720*lm - 
                11021600958587113575223065355457625*Zeta[3]) + 
              4199*NH*(-5426211676583432161359238580482 + 
                146381291119385826791490846720*lm + 
                4431072044417229391782266539875*Zeta[3])))))/
       1177678630064153378872217071213608960000, 
      (CF*NC*(92*CF*(-851844634156350458752257713682732306834074469586 + 
           708655774775668235859027402290963897543073512475*Zeta[3]) + 
         CA*(-938507815206318077817277756434972960791503446596 + 
           574719355217698824986072642283086492467200*lm + 
           780750999673138983752258303024249516616020538150*Zeta[3]) - 
         1155*(1649267441664*(-127622964580597142002540879 + 
             54855485617405284141450120*lm)*NL + 7429*NM*
            (12178135203318664757814568597585920*lm + 
             23*(62971609895012581644132318118503117782 - 
               52387787919135373634247524350429910625*Zeta[3])) + 
           7429*NH*(12178135203318664757814568597585920*lm + 
             7429*(-41525252202403704470107286762126 + 
               33878028967929655360292927611125*Zeta[3])))))/
       657879547040957617119113389189631091671040000, 
      -(CF*NC*(8*CA*(-137140131347819341349645498848792897584474223862 + 
            71099545356308526661945101873773857996800*lm + 
            114087874369691938052907871318768179983783454225*Zeta[3]) + 
          368*CF*(-268273499972264262031054602979782653029561555334 + 
            223178691704251096395141265188243842122937320425*Zeta[3]) - 
          1155*(2199023255552*(-54041451339526686827718319 + 
              40717613412059257444450680*lm)*NL + 7429*NM*
             (2074286242894449839209587401024863148138 + 
              12052628725763134629403099492515840*lm - 
              1725628555260446995806907373778662373375*Zeta[3]) + 
            111435*NH*(803508581717542308626873299501056*lm + 
              7429*(-2073732755469246803028975340718 + 
                1690680494748514035824294962725*Zeta[3])))))/
       657879547040957617119113389189631091671040000}, 0, 24, 1]
 
CbarSeries["p", 2, 2, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(15*CA*(4665 + 15840*lm^2 - 10732*Pi^2 + 432*Pi^4 - 
            80*lm*(-483 + 44*Pi^2) - 244512*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 34560*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            40752*PolyGamma[2, 1] + 434496*Zeta[3]) + 
          2*(CF*(-194400*lm^2 - 72892*Pi^2 + 1200*Pi^4 + 43200*lm*(-6 + 
                Pi^2) + 15*(-16097 + 244512*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 34560*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                40752*PolyGamma[2, 1] - 396480*Zeta[3])) + 
            60*(NL*(15 - 420*lm - 360*lm^2 + 52*Pi^2 + 80*lm*Pi^2 - 
                960*Zeta[3]) + NM*(15 - 360*lm^2 + 52*Pi^2 + 
                20*lm*(-21 + 4*Pi^2) + 80*PolyGamma[2, 1] - 800*Zeta[3]) + 
              NH*(-10593 - 420*lm - 360*lm^2 + 80*lm*Pi^2 - 68976*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 11496*PolyGamma[2, 1] + 
                132432*Zeta[3])))))/6220800, 
      (CF*NC*(2*(CF*(388800*lm^2 + 335524*Pi^2 + 7320*Pi^4 - 
             43200*lm*(33 + 2*Pi^2) + 15*(158939 + 92064*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 120960*Im[PolyLog[2, 
                   (-1)^(1/3)]]^2 - 15104*PolyGamma[2, 1] - 307744*
                Zeta[3])) - 120*(NH*(-360*lm^2 + 20*lm*(69 + 4*Pi^2) + 3*
                (58211 + 16272*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                 2712*PolyGamma[2, 1] - 77744*Zeta[3])) + 
             NL*(5865 - 360*lm^2 + 108*Pi^2 + 20*lm*(69 + 4*Pi^2) - 960*
                Zeta[3]) + NM*(5865 - 360*lm^2 + 108*Pi^2 + 20*lm*
                (69 + 4*Pi^2) + 80*PolyGamma[2, 1] - 800*Zeta[3]))) - 
         15*CA*(-628455 + 31680*lm^2 - 38396*Pi^2 + 1512*Pi^4 - 
           160*lm*(507 + 44*Pi^2) + 92064*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 120960*Im[PolyLog[2, (-1)^(1/3)]]^
             2 - 15104*PolyGamma[2, 1] - 180832*Zeta[3])))/6220800, 
      -(CF*NC*(CA*(-126720*lm^2 + 160*lm*(1929 + 44*Pi^2) + 
            3*(721235 + 6204*Pi^2 + 408*Pi^4 - 299616*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 213120*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 55072*PolyGamma[2, 1] + 686240*Zeta[3])) - 
          2*(8*(NH*(470151 + 5340*lm - 1440*lm^2 + 80*lm*Pi^2 + 
                379152*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 67024*
                 PolyGamma[2, 1] - 1080608*Zeta[3]) + NM*(27615 - 
                1440*lm^2 - 1084*Pi^2 + 20*lm*(267 + 4*Pi^2) - 
                160*PolyGamma[2, 1] - 1280*Zeta[3]) + NL*(19515 + 5340*lm - 
                1440*lm^2 - 364*Pi^2 + 80*lm*Pi^2 - 960*Zeta[3])) + 
            CF*(-676965 - 103680*lm^2 - 74068*Pi^2 + 2248*Pi^4 + 
              1440*lm*(255 + 4*Pi^2) - 898848*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 639360*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              165216*PolyGamma[2, 1] + 2468640*Zeta[3]))))/414720, 
      (CF*NC*(12441600*(27*CF*(5 + 2*lm) - CA*(76 + 33*lm) + 
           2*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         24883200*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         5*CA*(-174070215 + 29937600*lm^2 - 9555948*Pi^2 + 
           2237200*Sqrt[3]*Pi^3 + 471960*Pi^4 - 12960*lm*(-2291 + 132*Pi^2) - 
           32111136*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           139501440*Im[PolyLog[2, (-1)^(1/3)]]^2 + 82840320*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1725840*Sqrt[3]*Pi*
            Log[3]^2 + 9083904*PolyGamma[2, 1] - 31513056*Zeta[3]) - 
         21600*Log[x]*(CA*(57531 + 29016*lm + 4752*lm^2 + 978*Pi^2 - 
             6392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 10368*Zeta[3]) - 
           2*(24*(3*NM*(-14 + 29*lm + 6*lm^2 + 6*Pi^2) + 3*NL*(58 + 29*lm + 
                 6*lm^2 + 6*Pi^2) + NH*(3296 + 87*lm + 18*lm^2 - 
                 1864*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             CF*(37803 + 19440*lm + 3888*lm^2 + 426*Pi^2 - 6392*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 10368*Zeta[3]))) + 
         2*(CF*(122472000*lm^2 + 14306148*Pi^2 + 11186000*Sqrt[3]*Pi^3 + 
             1115640*Pi^4 - 6998400*lm*(2 + Pi^2) + 8629200*Sqrt[3]*Pi*
              Log[3]^2 + 15*(34419483 - 10703712*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 46500480*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
               27613440*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               3027968*PolyGamma[2, 1] - 37474976*Zeta[3])) - 
           120*(27*NL*(20815 - 4200*lm^2 - 2812*Pi^2 + 20*lm*
                (59 + 12*Pi^2) - 20160*Zeta[3]) + 27*NM*(65815 - 4200*lm^2 - 
               2332*Pi^2 + 20*lm*(59 + 12*Pi^2) - 1040*PolyGamma[2, 1] + 
               12320*Zeta[3]) - NH*(-29044701 + 113400*lm^2 + 652400*Sqrt[3]*
                Pi^3 - 540*lm*(59 + 12*Pi^2) - 7378992*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 24157440*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 503280*Sqrt[3]*Pi*
                Log[3]^2 + 1614168*PolyGamma[2, 1] + 18002736*Zeta[3])))))/
       55987200, -(CF*NC*(2332800*(-10*CA*(76 + 33*lm) + 9*CF*(139 + 60*lm) + 
            4*(28*NM + 15*lm*NM + 25*NL + 15*lm*NL + 15*lm*NH))*
           Log[x]^2 + 46656000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          135*CA*(-13375485 + 1865160*lm^2 - 475020*Pi^2 + 
            205450*Sqrt[3]*Pi^3 + 24372*Pi^4 - 180*lm*(-8359 + 396*Pi^2) + 
            233616*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            9875520*Im[PolyLog[2, (-1)^(1/3)]]^2 + 7607520*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 158490*Sqrt[3]*Pi*
             Log[3]^2 + 253396*PolyGamma[2, 1] - 8488024*Zeta[3]) - 
          2700*Log[x]*(2*(-8*(18*NL*(403 + 201*lm + 45*lm^2 + 45*Pi^2) + 
                9*NM*(-409 + 402*lm + 90*lm^2 + 120*Pi^2) + 
                2*NH*(63222 + 1809*lm + 405*lm^2 - 35680*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 27*CF*(-19511 - 10008*lm - 
                2160*lm^2 + 182*Pi^2 + 4696*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 5760*Zeta[3])) + 9*CA*(93143 + 45456*lm + 
              7920*lm^2 + 342*Pi^2 - 14088*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 17280*Zeta[3])) + 
          2*(54*CF*(3815100*lm^2 + 24342*Pi^2 + 513625*Sqrt[3]*Pi^3 + 
              35010*Pi^4 - 24300*lm*(47 + 6*Pi^2) + 396225*Sqrt[3]*Pi*Log[3]^
                2 + 10*(1204758 + 58404*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                2468880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1901880*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 63349*PolyGamma[2, 
                  1] - 3444790*Zeta[3])) - 5*(243*NL*(98075 - 18840*lm^2 - 
                15036*Pi^2 + 20*lm*(439 + 36*Pi^2) - 95040*Zeta[3]) + 
              243*NM*(316835 - 18840*lm^2 - 19516*Pi^2 + 20*lm*
                 (439 + 36*Pi^2) - 9528*PolyGamma[2, 1] + 87504*Zeta[3]) - 
              NH*(-1086519177 + 4578120*lm^2 + 24976000*Sqrt[3]*Pi^3 - 
                4860*lm*(439 + 36*Pi^2) - 441301104*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 924825600*Sqrt[3]*Im[PolyLog[3, 
                   -((-1)^(5/6)/Sqrt[3])]] + 19267200*Sqrt[3]*Pi*Log[3]^2 + 
                93530112*PolyGamma[2, 1] + 964815744*Zeta[3])))))/41990400, 
      (CF*NC*(-4082400*(65*CA*(587 + 264*lm) - 2*(15*CF*(2189 + 936*lm) + 
             4*(10*(107 + 39*lm)*NM + 5*(121 + 78*lm)*NL + 6*(2 + 65*lm)*
                NH)))*Log[x]^2 + 326592000*(161*CA + 558*CF - 44*NM - 
           26*NL)*Log[x]^3 - 175*CA*(-497865555 + 71850240*lm^2 - 
           26316333*Pi^2 + 13021750*Sqrt[3]*Pi^3 + 1734372*Pi^4 - 
           38880*lm*(-2473 + 66*Pi^2) - 102500172*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 410806080*Im[PolyLog[2, (-1)^(1/3)]]^
             2 + 482176800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           10045350*Sqrt[3]*Pi*Log[3]^2 + 39812448*PolyGamma[2, 1] - 
           149343312*Zeta[3]) - 7560*Log[x]*
          (2*(-12*(225*NM*(-52 + 299*lm + 60*lm^2 + 40*Pi^2) + 225*NL*
                (680 + 299*lm + 60*lm^2 + 72*Pi^2) + NH*(2607591 + 
                 67275*lm + 13500*lm^2 - 1470400*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) + 25*CF*(-626898 - 300348*lm - 58320*
                lm^2 + 7047*Pi^2 + 148820*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] - 155520*Zeta[3])) + 
           25*CA*(986808 + 445932*lm + 71280*lm^2 + 4041*Pi^2 - 
             148820*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 155520*Zeta[3])) + 
         2*(5*CF*(2057529600*lm^2 - 460285443*Pi^2 + 455761250*Sqrt[3]*Pi^3 + 
             47639340*Pi^4 - 36741600*lm*(-13 + 2*Pi^2) + 351587250*Sqrt[3]*
              Pi*Log[3]^2 - 420*(-6551379 + 8541681*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 34233840*Im[PolyLog[2, 
                   (-1)^(1/3)]]^2 - 40181400*Sqrt[3]*Im[PolyLog[3, 
                  -((-1)^(5/6)/Sqrt[3])]] - 3317704*PolyGamma[2, 1] + 
               29960068*Zeta[3])) - 84*(2025*NL*(35085 - 6720*lm^2 - 7096*
                Pi^2 + 40*lm*(-11 + 6*Pi^2) - 54720*Zeta[3]) + 
             2025*NM*(133515 - 6720*lm^2 - 6476*Pi^2 + 40*lm*(-11 + 
                 6*Pi^2) - 3802*PolyGamma[2, 1] + 104716*Zeta[3]) - 
             NH*(-4131422631 + 13608000*lm^2 + 128660000*Sqrt[3]*Pi^3 - 
               81000*lm*(-11 + 6*Pi^2) - 981241200*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 4764096000*Sqrt[3]*Im[PolyLog[3, 
                  -((-1)^(5/6)/Sqrt[3])]] + 99252000*Sqrt[3]*Pi*Log[3]^2 + 
               238548750*PolyGamma[2, 1] + 1367449500*Zeta[3])))))/734832000, 
      -(CF*NC*(2721600*(-12*CA*(6388 + 2717*lm) + 19*CF*(6755 + 2808*lm) + 
            4*(4661*NM + 1482*lm*NM + 2247*NL + 1482*lm*NL + 54*NH + 
              1482*lm*NH))*Log[x]^2 + 21772800*(2789*CA + 11738*CF - 
            808*NM - 494*NL)*Log[x]^3 - 7560*Log[x]*
           (2*(-2*(45*NL*(24529 + 10442*lm + 2160*lm^2 + 2696*Pi^2) + 
                15*NM*(-13529 + 31326*lm + 6480*lm^2 + 7032*Pi^2) + 
                NH*(17534019 + 469890*lm + 97200*lm^2 - 9867520*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 15*CF*(-1138605 - 
                583308*lm - 116640*lm^2 + 9483*Pi^2 + 343172*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 311040*Zeta[3])) + 
            15*CA*(1882170 + 870612*lm + 142560*lm^2 + 13521*Pi^2 - 
              343172*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 311040*Zeta[3])) - 
          105*CA*(130870080*lm^2 - 47605239*Pi^2 + 30027550*Sqrt[3]*Pi^3 + 
            3477492*Pi^4 - 8640*lm*(-18607 + 429*Pi^2) + 23164110*Sqrt[3]*Pi*
             Log[3]^2 - 36*(27050100 + 2643021*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 22842000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              30885480*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              1969402*PolyGamma[2, 1] + 19411480*Zeta[3])) + 
          2*(3*CF*(3747643200*lm^2 - 1146285297*Pi^2 + 1050964250*Sqrt[3]*Pi^
                3 + 102842460*Pi^4 - 1360800*lm*(-337 + 78*Pi^2) + 
              810743850*Sqrt[3]*Pi*Log[3]^2 - 315*(-15174353 + 10572084*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 91368000*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 123541920*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 7877608*PolyGamma[2, 
                  1] + 123577024*Zeta[3])) - 56*(405*NL*(324215 - 
                55080*lm^2 - 64756*Pi^2 + 40*lm*(61 + 39*Pi^2) - 
                504000*Zeta[3]) + 135*NM*(3181715 - 165240*lm^2 - 
                243798*Pi^2 + 120*lm*(61 + 39*Pi^2) - 179802*PolyGamma[2, 
                  1] + 3174156*Zeta[3]) - NH*(-6775913421 + 22307400*lm^2 + 
                215852000*Sqrt[3]*Pi^3 - 16200*lm*(61 + 39*Pi^2) - 
                2068575240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 7992691200*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                166514400*Sqrt[3]*Pi*Log[3]^2 + 491746910*PolyGamma[2, 1] + 
                2969095420*Zeta[3])))))/440899200, 
      (CF*NC*(-29152967767875*CF + 23668448832000*CF*lm + 
         68052791520000*CF*lm^2 - 205902313470000*NM + 
         1369590768000*lm*NM + 7561421280000*lm^2*NM - 56062037682000*NL + 
         1369590768000*lm*NL + 7561421280000*lm^2*NL - 
         2943042727872816*NH + 1369590768000*lm*NH + 7561421280000*lm^2*
          NH - 37517715099900*CF*Pi^2 - 1800338400000*CF*lm*Pi^2 + 
         3712031064000*NM*Pi^2 - 200037600000*lm*NM*Pi^2 + 
         10632665232000*NL*Pi^2 - 200037600000*lm*NL*Pi^2 - 
         200037600000*lm*NH*Pi^2 + 25965866605000*Sqrt[3]*CF*Pi^3 + 
         104706841680000*Sqrt[3]*NH*Pi^3 + 2644997166000*CF*Pi^4 - 
         141966571530000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         669294099936000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         564946189920000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         961478946288000*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         3877144766208000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         20030811381000*Sqrt[3]*CF*Pi*Log[3]^2 + 80773849296000*Sqrt[3]*NH*
          Pi*Log[3]^2 + 114307200*(-105*CA*(73987 + 32780*lm) + 
           35*CF*(379943 + 160920*lm) + 1362760*NM + 625800*lm*NM + 
           913500*NL + 625800*lm*NL + 40284*NH + 625800*lm*NH)*Log[x]^2 + 
         80015040000*(3695*CA + 16280*CF - 2320*NM - 596*NL)*Log[x]^3 + 
         70945227651200*CF*PolyGamma[2, 1] - 4618268071200*NM*
          PolyGamma[2, 1] + 170875286416800*NH*PolyGamma[2, 1] - 
         641494793441600*CF*Zeta[3] - 244480753742400*NM*Zeta[3] + 
         95537957760000*NL*Zeta[3] + 526745345313600*NH*Zeta[3] - 
         15120*Log[x]*(72*(-1225*NM*(25991 + 41709*lm + 8100*lm^2 - 13620*
                Pi^2) - 3675*NL*(36327 + 13903*lm + 2700*lm^2 + 3880*Pi^2) - 
             NH*(2109986972 + 51093525*lm + 9922500*lm^2 - 1187152400*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
           1225*CF*(-56808159 - 27902232*lm - 5248800*lm^2 + 666630*Pi^2 + 
             17303368*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             13996800*Zeta[3]) + 1225*CA*(46708473 + 20599164*lm + 
             3207600*lm^2 + 252585*Pi^2 - 8651684*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 6998400*Zeta[3])) - 
         2450*CA*(16974619200*lm^2 - 8765273655*Pi^2 + 5299156450*Sqrt[3]*
            Pi^3 + 605113740*Pi^4 - 272160*lm*(-90677 + 1650*Pi^2) + 
           4087920690*Sqrt[3]*Pi*Log[3]^2 - 7*(20232113535 + 
             4138967100*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             16470734400*Im[PolyLog[2, (-1)^(1/3)]]^2 - 28031456160*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 2068373984*
              PolyGamma[2, 1] + 10389422672*Zeta[3]))))/648121824000, 
      (10354456121*CF^2*NC)/279936000 - (80627*CF^2*lm*NC)/1728 - 
       (2715*CF^2*lm^2*NC)/16 + (3102895033*CF*NM*NC)/5832000 - 
       (31757*CF*lm*NM*NC)/15552 - (905*CF*lm^2*NM*NC)/48 + 
       (10054807*CF*NC*NL)/62208 - (31757*CF*lm*NC*NL)/15552 - 
       (905*CF*lm^2*NC*NL)/48 + (136448752674239*CF*NC*NH)/18003384000 - 
       (31757*CF*lm*NC*NH)/15552 - (905*CF*lm^2*NC*NH)/48 + 
       (82829881*CF^2*NC*Pi^2)/1088640 + (275*CF^2*lm*NC*Pi^2)/72 - 
       (181969*CF*NM*NC*Pi^2)/7776 + (275*CF*lm*NM*NC*Pi^2)/648 - 
       (224345*CF*NC*NL*Pi^2)/7776 + (275*CF*lm*NC*NL*Pi^2)/648 + 
       (275*CF*lm*NC*NH*Pi^2)/648 - (24230605*CF^2*NC*Pi^3)/
        (104976*Sqrt[3]) - (259372645*CF*NC*NH*Pi^3)/(314928*Sqrt[3]) - 
       (1091*CF^2*NC*Pi^4)/144 + (53789627*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(69984*Sqrt[3]) + 
       (316089167*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(52488*Sqrt[3]) - 
       (4565*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (692303*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) - 
       (7410647*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (243*Sqrt[3]) - (692303*CF^2*NC*Pi*Log[3]^2)/(3888*Sqrt[3]) - 
       (7410647*CF*NC*NH*Pi*Log[3]^2)/(11664*Sqrt[3]) - 
       (CF*NC*(-21*CA*(6228029 + 2444420*lm) + 
          14*CF*(15913837 + 5999940*lm) + 26490632*NM + 9333240*lm*NM + 
          13320930*NL + 9333240*lm*NL + 690768*NH + 9333240*lm*NH)*
         Log[x]^2)/45360 - (CF*NC*(116425*CA + 688445*CF - 85532*NM - 
          22222*NL)*Log[x]^3)/162 - (721213619*CF^2*NC*PolyGamma[2, 1])/
        3149280 + (2791*CF*NM*NC*PolyGamma[2, 1])/1620 - 
       (2390426759*CF*NC*NH*PolyGamma[2, 1])/4723920 + 
       (3728473591*CF^2*NC*Zeta[3])/1574640 + (571651*CF*NM*NC*Zeta[3])/
        810 - (7268*CF*NC*NL*Zeta[3])/27 - (4141922159*CF*NC*NH*Zeta[3])/
        2361960 + (CA*CF*NC*(457203285000*lm^2 - 175799109375*Pi^2 + 
          169614235000*Sqrt[3]*Pi^3 + 18198999000*Pi^4 - 
          141750*lm*(-4454407 + 72600*Pi^2) + 130845267000*Sqrt[3]*Pi*
           Log[3]^2 - 28*(140571088452 + 20171110125*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 119803860000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 224306172000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 18030340475*
             PolyGamma[2, 1] + 125717662550*Zeta[3])))/4408992000 - 
       (CF*NC*Log[x]*(-147*CA*(2627419551 + 1187599500*lm + 187110000*lm^2 + 
            51233400*Pi^2 - 553842400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            408240000*Zeta[3]) + 2*(34624001475*NL + 12688231500*lm*NL + 
            2500470000*lm^2*NL + 517123569192*NH + 12688231500*lm*NH + 
            2500470000*lm^2*NH + 3773460600*NL*Pi^2 + 
            882*NM*(14775409 + 14385750*lm + 2835000*lm^2 - 4146900*Pi^2) - 
            290497362400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            294*CF*(765376413 + 401172750*lm + 76545000*lm^2 + 7231500*Pi^2 - 
              276921200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 204120000*Zeta[
                3]))))/171460800, 
      (CF*NC*(-2057529600*(7*CA*(80075489 + 33858000*lm) - 
           2*(7*CF*(68551859 + 27702000*lm) + 12*(126*(-30641 + 14250*lm)*
                NM + 5*(63*(7957 + 5700*lm)*NL + 4*(8821 + 89775*lm)*
                  NH))))*Log[x]^2 + 1152216576000*(304105*CA + 1743080*CF - 
           108*(3968*NM + 475*NL))*Log[x]^3 - 15120*Log[x]*
          (2*(48*(-47628*NM*(1251746 + 832575*lm + 157500*lm^2 - 
                 1307850*Pi^2) - 5*(59535*NL*(397843 + 133212*lm + 
                   25200*lm^2 + 42600*Pi^2) + 4*NH*(88608902028 + 
                   1982694105*lm + 375070500*lm^2 - 49783774600*Sqrt[3]*
                    Im[PolyLog[2, (-1)^(1/3)]]))) + 49*CF*(-676508146071 - 
               360624052800*lm - 66134880000*lm^2 + 1187735400*Pi^2 + 
               261257692000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 176359680000*
                Zeta[3])) + 49*CA*(1180707428571 + 530167291200*lm + 
             80831520000*lm^2 + 16188514200*Pi^2 - 261257692000*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 176359680000*Zeta[3])) - 
         49*CA*(688199561280000*lm^2 - 447357463488000*Pi^2 + 
           320040672700000*Sqrt[3]*Pi^3 + 33111897336000*Pi^4 - 
           24249456000*lm*(-42743 + 600*Pi^2) + 246888518940000*Sqrt[3]*Pi*
            Log[3]^2 - 7*(948161009734047 + 203032109640000*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 774004844160000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 - 1692949844160000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 129564959641600*
              PolyGamma[2, 1] + 720117491564800*Zeta[3])) + 
         2*(49*CF*(-879969178448829 + 563072368320000*lm^2 - 
             460605431188800*Pi^2 + 320040672700000*Sqrt[3]*Pi^3 + 
             30995581176000*Pi^4 - 19840464000*lm*(-11353 + 600*Pi^2) - 
             1421224767480000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             5418033909120000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             11850648909120000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] + 246888518940000*Sqrt[3]*Pi*Log[3]^2 + 
             906954717491200*PolyGamma[2, 1] - 7852401367417600*Zeta[3]) - 
           96*(1500282*NM*(639395533 - 21285000*lm^2 + 106564500*Pi^2 + 750*
                lm*(-6623 + 600*Pi^2) + 213575400*PolyGamma[2, 1] + 
               1149022800*Zeta[3]) + 5*(18753525*NL*(3768821 - 340560*lm^2 - 
                 594936*Pi^2 + 12*lm*(-6623 + 600*Pi^2) - 6220800*Zeta[3]) - 
               4*NH*(-798102489149181 + 1596675118500*lm^2 + 30492561942500*
                  Sqrt[3]*Pi^3 - 56260575*lm*(-6623 + 600*Pi^2) - 
                 176805319777800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                 1129096007928000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                      Sqrt[3])]] + 23522833498500*Sqrt[3]*Pi*Log[3]^2 + 
                 46085410823760*PolyGamma[2, 1] + 69972649175520*
                  Zeta[3]))))))/186659085312000, 
      (22450157046253697*CF^2*NC)/17283248640000 - (122889*CF^2*lm*NC)/800 - 
       (883*CF^2*lm^2*NC)/2 + (92905615739*CF*NM*NC)/55566000 - 
       (192067*CF*lm*NM*NC)/21600 - (883*CF*lm^2*NM*NC)/18 + 
       (270795229*CF*NC*NL)/432000 - (192067*CF*lm*NC*NL)/21600 - 
       (883*CF*lm^2*NC*NL)/18 + (12487881360026479*CF*NC*NH)/486091368000 - 
       (192067*CF*lm*NC*NH)/21600 - (883*CF*lm^2*NC*NH)/18 - 
       (42874057*CF^2*NC*Pi^2)/907200 + (33*CF^2*lm*NC*Pi^2)/4 + 
       (404597*CF*NM*NC*Pi^2)/2160 + (11*CF*lm*NM*NC*Pi^2)/12 - 
       (66257*CF*NC*NL*Pi^2)/720 + (11*CF*lm*NC*NL*Pi^2)/12 + 
       (11*CF*lm*NC*NH*Pi^2)/12 - (6527391409*CF^2*NC*Pi^3)/
        (7558272*Sqrt[3]) - (12695545765*CF*NC*NH*Pi^3)/(4251528*Sqrt[3]) - 
       (46969*CF^2*NC*Pi^4)/1728 + (88811677043*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(31492800*Sqrt[3]) + 
       (13386788423*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(708588*Sqrt[3]) - 
       (18151*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (932484487*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (29160*Sqrt[3]) - (725459758*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (932484487*CF^2*NC*Pi*Log[3]^2)/(1399680*Sqrt[3]) - 
       (362729879*CF*NC*NH*Pi*Log[3]^2)/(157464*Sqrt[3]) - 
       (CF*NC*(5*CF*(361083679 + 109998000*lm) - 
          CA*(1030339921 + 336105000*lm) + 20*(90*(-28157 + 33950*lm)*NM + 
            21*(199327 + 145500*lm)*NL + 4*(83597 + 763875*lm)*NH))*
         Log[x]^2)/75600 - (CF*NC*(287339*CA + 2911044*CF - 597360*NM - 
          72750*NL)*Log[x]^3)/135 - (18906608117*CF^2*NC*PolyGamma[2, 1])/
        14171760 + (98387*CF*NM*NC*PolyGamma[2, 1])/180 - 
       (2597729696*CF*NC*NH*PolyGamma[2, 1])/1594323 + 
       (CA*CF*NC*(-37714761373679235 + 3357443880806400*lm^2 + 
          487584170879904*Pi^2 + 1791116202629600*Sqrt[3]*Pi^3 + 
          178245743901120*Pi^4 - 288054144*lm*(-16947137 + 217800*Pi^2) - 
          5848781803343808*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          28233742145817600*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          66322474245941760*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          1381718213457120*Sqrt[3]*Pi*Log[3]^2 + 8300757227687680*
           PolyGamma[2, 1] - 35782079329158400*Zeta[3]))/12443939020800 + 
       (115490040323*CF^2*NC*Zeta[3])/14171760 + (273827*CF*NM*NC*Zeta[3])/
        90 - 1006*CF*NC*NL*Zeta[3] - (4786958410*CF*NC*NH*Zeta[3])/
        1594323 - (CF*NC*Log[x]*(-9*CA*(160698062554077 + 68823164894400*lm + 
            10561985280000*lm^2 + 7750678282200*Pi^2 - 36553391890400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 23044331520000*Zeta[3]) + 
          10*(-16*(-4374*NM*(439179737 + 129490830*lm + 24696000*lm^2 - 
                207519900*Pi^2) - 107163*NL*(16532101 + 5285340*lm + 
                1008000*lm^2 + 1791000*Pi^2) - 2*NH*(12668376178641 + 
                283196445210*lm + 54010152000*lm^2 - 7109505628400*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 9*CF*(18635027032311 + 
              9350340390720*lm + 1728324864000*lm^2 + 1064076675480*Pi^2 - 
              7310678378080*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              4608866304000*Zeta[3]))))/185177664000, 
      (CF*NC*(1493766489600*(-440*CA*(127859357 + 49490595*lm) + 
           11*CF*(8826302011 + 3239384400*lm) + 
           60*(198*(-5737339 + 333270*lm)*NM + 693*(128633 + 95220*lm)*NL + 
             20*(429776 + 3299373*lm)*NH))*Log[x]^2 + 18403203151872000*
          (1132979*CA + 8893735*CF - 3919320*NM - 214245*NL)*Log[x]^3 - 
         1331*CA*(1187249000857920000*lm^2 - 674271543023114400*Pi^2 + 
           757507132851140000*Sqrt[3]*Pi^3 + 72425939517288000*Pi^4 - 
           64812182400*lm*(-28088101 + 323400*Pi^2) + 584362645342308000*
            Sqrt[3]*Pi*Log[3]^2 - 3*(4509946381710637383 + 
             1001457876185950400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             3544461593527680000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             9349802325476928000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] - 926008595472128000*PolyGamma[2, 1] + 
             4265919620984672000*Zeta[3])) - 166320*Log[x]*
          (121*CA*(2342680485096891 + 1109264102452800*lm + 
             166351268160000*lm^2 + 78117661931400*Pi^2 - 618373169674400*
              Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 362948221440000*Zeta[3]) - 
           2*(-240*(-4322241*NL*(32176417 + 9517620*lm + 1764000*lm^2 + 
                 3444600*Pi^2) + 176418*NM*(232995647 - 233181690*lm - 
                 43218000*lm^2 + 1134149100*Pi^2) - 10*NH*(199879052666091 + 
                 4113744738642*lm + 762443312400*lm^2 - 112210649375440*
                  Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             121*CF*(1227683059577193 + 757038696523200*lm + 136105583040000*
                lm^2 + 36937893018600*Pi^2 - 618373169674400*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 362948221440000*Zeta[3]))) + 
         10*(1331*CF*(-570544881191291583 + 194277109231296000*lm^2 - 
             156079387832336640*Pi^2 + 151501426570228000*Sqrt[3]*Pi^3 + 
             13875434891438400*Pi^4 - 116661928320*lm*(-711541 + 29400*
                Pi^2) - 600874725711570240*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 2126676956116608000*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 5609881395286156800*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] + 116872529068461600*Sqrt[3]*Pi*
              Log[3]^2 + 555605157283276800*PolyGamma[2, 1] - 
             3722052111974918400*Zeta[3]) - 
           96*(2995313013*NL*(1607877829 - 99918000*lm^2 - 208215000*Pi^2 + 
               60*lm*(-433991 + 29400*Pi^2) - 2501280000*Zeta[3]) + 
             17465382*NM*(-378506148107 - 17135937000*lm^2 + 571006814700*
                Pi^2 + 10290*lm*(-433991 + 29400*Pi^2) + 998962461000*
                PolyGamma[2, 1] + 1762325082000*Zeta[3]) - 
             20*NH*(-9468200566025279523 + 14964284281646700*lm^2 + 
               378009625083513500*Sqrt[3]*Pi^3 - 8985939039*lm*(-433991 + 
                 29400*Pi^2) - 2067392705007121800*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 13997156403092385600*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 291607425064424700*
                Sqrt[3]*Pi*Log[3]^2 + 541510535031262720*PolyGamma[2, 1] + 
               265703187582472640*Zeta[3])))))/3726648638254080000, 
      (2083079028800577359*CF^2*NC)/155549237760000 - (16419763*CF^2*lm*NC)/
        43200 - (15673*CF^2*lm^2*NC)/16 - (25848017431039*CF*NM*NC)/
        15431472000 - (9366913*CF*lm*NM*NC)/388800 - (15673*CF*lm^2*NM*NC)/
        144 + (46701183749*CF*NC*NL)/23328000 - (9366913*CF*lm*NC*NL)/
        388800 - (15673*CF*lm^2*NC*NL)/144 + (4832209923899073703*CF*NC*NH)/
        66547297111680 - (9366913*CF*lm*NC*NH)/388800 - 
       (15673*CF*lm^2*NC*NH)/144 - (40383384523*CF^2*NC*Pi^2)/10886400 + 
       (1127*CF^2*lm*NC*Pi^2)/72 + (127470427*CF*NM*NC*Pi^2)/38880 + 
       (1127*CF*lm*NM*NC*Pi^2)/648 - (3127271*CF*NC*NL*Pi^2)/12960 + 
       (1127*CF*lm*NC*NL*Pi^2)/648 + (1127*CF*lm*NC*NH*Pi^2)/648 - 
       (87404634317*CF^2*NC*Pi^3)/(34012224*Sqrt[3]) - 
       (672981971795*CF*NC*NH*Pi^3)/(76527504*Sqrt[3]) - 
       (497441*CF^2*NC*Pi^4)/6480 + (1182030156439*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(141717600*Sqrt[3]) + 
       (651869979901*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12754584*Sqrt[3]) - 11361*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (12486376331*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (131220*Sqrt[3]) - (19228056337*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (12486376331*CF^2*NC*Pi*Log[3]^2)/(6298560*Sqrt[3]) - 
       (19228056337*CF*NC*NH*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (CF*NC*(-99*CA*(19410009033 + 4193327600*lm) + 
          2*(363*CF*(4854111421 + 935701200*lm) + 
            140*(22*(-164739263 + 12253230*lm)*NM + 1089*(329323 + 
                247540*lm)*NL + 10*(3819241 + 26957106*lm)*NH)))*Log[x]^2)/
        29937600 + (CF*NC*(57159*CA - 148181792*CF + 47453800*NM + 
          2722940*NL)*Log[x]^3)/1620 - (756964969531*CF^2*NC*
         PolyGamma[2, 1])/85030560 + (16262627*CF*NM*NC*PolyGamma[2, 1])/
        2160 - (509777934755*CF*NC*NH*PolyGamma[2, 1])/114791256 + 
       (CA*CF*NC*(-6931595222995875867 + 335214440469216000*lm^2 + 
          1079680461713748720*Pi^2 + 239838316565848000*Sqrt[3]*Pi^3 + 
          22272620065516800*Pi^4 - 720135360*lm*(-695475443 + 7438200*Pi^2) - 
          778437779824467840*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          3180950802344448000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          8880870236266828800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          185018129922225600*Sqrt[3]*Pi*Log[3]^2 + 2492534251671676800*
           PolyGamma[2, 1] - 4089195368003961600*Zeta[3]))/559977255936000 + 
       (891924962051*CF^2*NC*Zeta[3])/42515280 + (15162227*CF*NM*NC*Zeta[3])/
        1080 - (27289*CF*NC*NL*Zeta[3])/9 - (191432729759*CF*NC*NH*Zeta[3])/
        57395628 + CF*Log[x]*((-5199732739*NM*NC)/765450 - 
         (157843*lm*NM*NC)/120 - 245*lm^2*NM*NC - (100546753*NC*NL)/
          21600 - (157843*lm*NC*NL)/120 - 245*lm^2*NC*NL - 
         (154844333352509*NC*NH)/2400696144 - (157843*lm*NC*NH)/120 - 
         245*lm^2*NC*NH + (2074219*NM*NC*Pi^2)/324 - (162607*NC*NL*Pi^2)/
          324 + (19228056337*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (177147*Sqrt[3]) + CF*NC*(-1090526103135169/30862944000 - 
           (488229*lm)/40 - 2205*lm^2 - (16580081*Pi^2)/3240 + 
           (12486376331*Im[PolyLog[2, (-1)^(1/3)]])/(393660*Sqrt[3]) - 
           5880*Zeta[3]) + CA*NC*(332199792409649/12345177600 + 
           (2147873*lm)/240 + (2695*lm^2)/2 + (46617*Pi^2)/16 - 
           (12486376331*Im[PolyLog[2, (-1)^(1/3)]])/(787320*Sqrt[3]) + 
           2940*Zeta[3])), 
      (CF*NC*(2272018830681600*(-429*CA*(1059406763 + 346003350*lm) + 
           429*CF*(1865583241 + 566187300*lm) + 
           5*(143*(-2587195817 + 37745820*lm)*NM + 9009*(789639 + 599140*lm)*
              NL + 2*(430747111 + 2698826130*lm)*NH))*Log[x]^2 + 
         17057181371342112000*(9159411*CA + 121661210*CF - 109417040*NM - 
           2396560*NL)*Log[x]^3 - 2924207*CA*(-65533566073802410701 + 
           4143394211695200000*lm^2 + 1300572872916300900*Pi^2 + 
           3438222080772710000*Sqrt[3]*Pi^3 + 307105234931880000*Pi^4 - 
           48609136800*lm*(-132013339 + 1293600*Pi^2) - 12894827010065170800*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 41606660101829760000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 127312451905183776000*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2652342748024662000*
            Sqrt[3]*Pi*Log[3]^2 + 23776176899264608000*PolyGamma[2, 1] - 
           50969376721310992000*Zeta[3]) - 2162160*Log[x]*
          (20449*CA*(8740674714016857 + 4551621844064400*lm + 
             673722636048000*lm^2 + 735373777855500*Pi^2 - 2806711902671600*
              Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1469940296832000*
              Zeta[3]) - 4*(-90*(-21913761870*NL*(6594885 + 1741026*lm + 
                 317520*lm^2 + 704980*Pi^2) + 3312738*NM*(281667122351 - 
                 11516886990*lm - 2100394800*lm^2 + 173240764200*Pi^2) - NH*
                (2014988410477417899 + 38152429173478620*lm + 
                 6958057668962400*lm^2 - 1130793599335400000*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]])) + 20449*CF*(1969265155085583 + 
               1557181545103800*lm + 275613805656000*lm^2 + 273219564551850*
                Pi^2 - 1403355951335800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               734970148416000*Zeta[3]))) + 
         8*(-90*(-5*NH*(-481618293534363505133673 + 611926381696898268000*
                lm^2 + 19808676876357869500000*Sqrt[3]*Pi^3 - 78968432274732*
                lm*(-2138849 + 117600*Pi^2) - 104475591022231528619520*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 733487006621708539200000*
                Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               15280979304618927900000*Sqrt[3]*Pi*Log[3]^2 + 
               27242149397349096250040*PolyGamma[2, 1] - 
               6356771914504527435920*Zeta[3]) + 13161405379122*NL*
              (5223471089 - 232470000*lm^2 - 562300200*Pi^2 + 30*lm*
                (-2138849 + 117600*Pi^2) - 7656120000*Zeta[3]) + 
             1421164602*NM*(-781575322744493 - 2152904670000*lm^2 + 
               353709007016400*Pi^2 + 277830*lm*(-2138849 + 117600*Pi^2) + 
               633144033704700*PolyGamma[2, 1] + 689879723009400*Zeta[3])) + 
           265837*CF*(9322636976314200000*lm^2 + 1852717839547076775*Pi^2 + 
             9455110722124952500*Sqrt[3]*Pi^3 + 819387084316878000*Pi^4 - 
             1203076135800*lm*(-3430349 + 117600*Pi^2) + 7293942557067820500*
              Sqrt[3]*Pi*Log[3]^2 - 11*(6211486806163479081 + 
               3223706752516292700*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               10401665025457440000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
               31828112976295944000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                    Sqrt[3])]] - 5944044224816152000*PolyGamma[2, 1] + 
               18804697326491692000*Zeta[3])))))/13816316910787110720000, 
      (206941260725997818503519*CF^2*NC)/1630408779236160000 - 
       (211694789*CF^2*lm*NC)/264600 - 1942*CF^2*lm^2*NC - 
       (1329238361326361191*CF*NM*NC)/17971878078000 - 
       (126052589*CF*lm*NM*NC)/2381400 - (1942*CF*lm^2*NM*NC)/9 + 
       (195652954513*CF*NC*NL)/35721000 - (126052589*CF*lm*NC*NL)/2381400 - 
       (1942*CF*lm^2*NC*NL)/9 + (86116764174135503060827*CF*NC*NH)/
        479733226068996900 - (126052589*CF*lm*NC*NH)/2381400 - 
       (1942*CF*lm^2*NC*NH)/9 - (27651522197623*CF^2*NC*Pi^2)/628689600 + 
       (244*CF^2*lm*NC*Pi^2)/9 + (266968502*CF*NM*NC*Pi^2)/8505 + 
       (244*CF*lm*NM*NC*Pi^2)/81 - (3126437*CF*NC*NL*Pi^2)/5670 + 
       (244*CF*lm*NC*NL*Pi^2)/81 + (244*CF*lm*NC*NH*Pi^2)/81 - 
       (249515717651*CF^2*NC*Pi^3)/(38263752*Sqrt[3]) - 
       (320681445035*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) - 
       (149617*CF^2*NC*Pi^4)/810 + (667828946787517*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(31248730800*Sqrt[3]) + 
       (589575072848*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (4782969*Sqrt[3]) - 25096*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (499031435302*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2066715*Sqrt[3]) - (146597232016*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (249515717651*CF^2*NC*Pi*Log[3]^2)/(49601160*Sqrt[3]) - 
       (9162327001*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) - 
       (CF*NC*(-78*CA*(819518259929 + 80253165300*lm) + 
          117*CF*(1051005021041 + 87548907600*lm) + 
          140*(13*(-33841079059 + 625349340*lm)*NM + 
            9009*(1174541 + 902380*lm)*NL + 5*(277468141 + 1625908284*lm)*
             NH))*Log[x]^2)/170270100 + 
       (CF*NC*(354822879*CA + 14*(-160492239*CF + 73941400*NM + 
            1804760*NL))*Log[x]^3)/5670 - 
       (4105618104875*CF^2*NC*PolyGamma[2, 1])/57395628 + 
       (20769307*CF*NM*NC*PolyGamma[2, 1])/270 - 
       (1531771455517*CF*NC*NH*PolyGamma[2, 1])/143489070 + 
       CA*CF*NC*(-24707059498134150624847/326081755847232000 + 
         (10681*lm^2)/9 + (846115054273*Pi^2)/38102400 + 
         (249515717651*Pi^3)/(76527504*Sqrt[3]) + (153521*Pi^4)/1620 + 
         lm*(8580523279/4762800 - (1342*Pi^2)/81) - 
         (667828946787517*Im[PolyLog[2, (-1)^(1/3)]])/(62497461600*Sqrt[3]) + 
         12548*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (249515717651*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2066715*Sqrt[3]) + (249515717651*Pi*Log[3]^2)/(99202320*Sqrt[3]) + 
         (4105618104875*PolyGamma[2, 1])/114791256 - (4545077408681*Zeta[3])/
          2008846980) + (1968291867056*CF^2*NC*Zeta[3])/100442349 + 
       (13458307*CF*NM*NC*Zeta[3])/135 - (70564*CF*NC*NL*Zeta[3])/9 + 
       (18789149603*CF*NC*NH*Zeta[3])/71744535 + 
       CF*Log[x]*((9356621931529*NM*NC)/1296672300 - (2892343*lm*NM*NC)/
          945 - 560*lm^2*NM*NC - (228950737*NC*NL)/18900 - 
         (2892343*lm*NC*NL)/945 - 560*lm^2*NC*NL - 
         (872966500287016229*NC*NH)/5325044134410 - (2892343*lm*NC*NH)/
          945 - 560*lm^2*NC*NH + (3515116*NM*NC*Pi^2)/81 - 
         (105358*NC*NL*Pi^2)/81 + (146597232016*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-6535843633412907733/29408527764000 - (2980543*lm)/105 - 
           5040*lm^2 - (25596388*Pi^2)/567 + 
           (499031435302*Im[PolyLog[2, (-1)^(1/3)]])/(6200145*Sqrt[3]) - 
           13440*Zeta[3]) + CA*NC*(2290187963656243/17147829600 + 
           (39224573*lm)/1890 + 3080*lm^2 + (657597*Pi^2)/28 - 
           (249515717651*Im[PolyLog[2, (-1)^(1/3)]])/(6200145*Sqrt[3]) + 
           6720*Zeta[3])), (-4854787384108951994071*CF^2*NC)/
        73368395065627200 + (35905781*CF^2*lm*NC)/29400 + 2703*CF^2*lm^2*NC + 
       (283048733506158043*CF*NM*NC)/443750076000 + (22661081*CF*lm*NM*NC)/
        264600 + (901*CF*lm^2*NM*NC)/3 - (71983747643*CF*NC*NL)/7938000 + 
       (22661081*CF*lm*NC*NL)/264600 + (901*CF*lm^2*NC*NL)/3 - 
       (166444016607623539688593*CF*NC*NH)/575679871282796280 + 
       (22661081*CF*lm*NC*NH)/264600 + (901*CF*lm^2*NC*NH)/3 + 
       (711339296399*CF^2*NC*Pi^2)/57153600 - 36*CF^2*lm*NC*Pi^2 - 
       (24906254*CF*NM*NC*Pi^2)/105 - 4*CF*lm*NM*NC*Pi^2 + 
       (34721*CF*NC*NL*Pi^2)/42 - 4*CF*lm*NC*NL*Pi^2 - 
       4*CF*lm*NC*NH*Pi^2 + (262751593181*CF^2*NC*Pi^3)/(25509168*Sqrt[3]) + 
       (1569013634405*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) + 
       (152413*CF^2*NC*Pi^4)/540 - (1518579157232651*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(40176939600*Sqrt[3]) - 
       (13482720103804*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (71744535*Sqrt[3]) + 36764*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (37535941883*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (98415*Sqrt[3]) + (717263375728*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) + 
       (37535941883*CF^2*NC*Pi*Log[3]^2)/(4723920*Sqrt[3]) + 
       (44828960983*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) + 
       CF*((607714458359*CF*NC)/1309770 + CA*(-476134187299/1871100 - 
           59818*lm)*NC + 97884*CF*lm*NC - (1955268670*NM*NC)/693 + 
         10876*lm*NM*NC + (210947*NC*NL)/15 + 10876*lm*NC*NL + 
         (30406297*NC*NH)/15015 + 10876*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(5036819*CA + 6*(442081621*CF - 2520*(375693*NM + 2719*NL)))*
         Log[x]^3)/5670 + (132287574862453*CF^2*NC*PolyGamma[2, 1])/
        1937102445 - (80433989*CF*NM*NC*PolyGamma[2, 1])/180 + 
       (928018834163*CF*NC*NH*PolyGamma[2, 1])/57395628 + 
       CA*CF*NC*(747843626844510785093047/14673679013125440000 - 
         (9911*lm^2)/6 - (2752297519667*Pi^2)/419126400 - 
         (262751593181*Pi^3)/(51018336*Sqrt[3]) - (155869*Pi^4)/1080 + 
         lm*(-1361826691/529200 + 22*Pi^2) + 
         (1518579157232651*Im[PolyLog[2, (-1)^(1/3)]])/(80353879200*
           Sqrt[3]) - 18382*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (37535941883*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (196830*Sqrt[3]) - (37535941883*Pi*Log[3]^2)/(9447840*Sqrt[3]) - 
         (132287574862453*PolyGamma[2, 1])/3874204890 - 
         (35118430183727*Zeta[3])/10847773692) - 
       (447328999377887*CF^2*NC*Zeta[3])/27119434230 - 
       (40926869*CF*NM*NC*Zeta[3])/90 + 12604*CF*NC*NL*Zeta[3] - 
       (357031013005*CF*NC*NH*Zeta[3])/28697814 + 
       CF*Log[x]*((-2911796293468*NM*NC)/4002075 + (489917*lm*NM*NC)/105 + 
         840*lm^2*NM*NC + (37072501*NC*NL)/1890 + (489917*lm*NC*NL)/105 + 
         840*lm^2*NC*NL + (8538409132724224603*NC*NH)/31950264806460 + 
         (489917*lm*NC*NH)/105 + 840*lm^2*NC*NH - 247180*NM*NC*Pi^2 + 
         (6278*NC*NL*Pi^2)/3 - (717263375728*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CA*NC*(-124686489942497383/2450710647000 - (6623887*lm)/210 - 
           4620*lm^2 - (286884187*Pi^2)/22680 + 
           (37535941883*Im[PolyLog[2, (-1)^(1/3)]])/(590490*Sqrt[3]) - 
           10080*Zeta[3]) + CF*NC*(78932141203467803/2450710647000 + 
           (1513851*lm)/35 + 7560*lm^2 + (84675167*Pi^2)/3780 - 
           (37535941883*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) + 
           20160*Zeta[3])), (494120984879482718872784317*CF^2*NC)/
        418676270023851840000 - (474081473*CF^2*lm*NC)/313600 - 
       (56631*CF^2*lm^2*NC)/16 - (85604453463333581494567*CF*NM*NC)/
        112310659235174400 - (96362291*CF*lm*NM*NC)/940800 - 
       (18877*CF*lm^2*NM*NC)/48 + (320971086673*CF*NC*NL)/24192000 - 
       (96362291*CF*lm*NC*NL)/940800 - (18877*CF*lm^2*NC*NL)/48 + 
       (884989896104583972994842977*CF*NC*NH)/2210610705725937715200 - 
       (96362291*CF*lm*NC*NH)/940800 - (18877*CF*lm^2*NC*NH)/48 - 
       (721954186178723*CF^2*NC*Pi^2)/1676505600 + (351*CF^2*lm*NC*Pi^2)/8 + 
       (7786649467*CF*NM*NC*Pi^2)/30240 + (39*CF*lm*NM*NC*Pi^2)/8 - 
       (318453*CF*NC*NL*Pi^2)/280 + (39*CF*lm*NC*NL*Pi^2)/8 + 
       (39*CF*lm*NC*NH*Pi^2)/8 - (81046327322455*CF^2*NC*Pi^3)/
        (5509980288*Sqrt[3]) - (17509332093715*CF*NC*NH*Pi^3)/
        (344373768*Sqrt[3]) - (569987*CF^2*NC*Pi^4)/1440 + 
       (22134680027336783*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (449981723520*Sqrt[3]) + (467174619933983*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1721868840*Sqrt[3]) - 
       (100875*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (16209265464491*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (29760696*Sqrt[3]) - (1000533262498*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (16209265464491*CF^2*NC*Pi*Log[3]^2)/(1428513408*Sqrt[3]) - 
       (500266631249*CF*NC*NH*Pi*Log[3]^2)/(12754584*Sqrt[3]) - 
       (CF*NC*(-11*CA*(117477212033899 + 3564093733200*lm) + 
          11*CF*(232140812469299 + 5832153381600*lm) + 
          210*((-6604695169201 + 33943749840*lm)*NM + 
            108108*(401833 + 313980*lm)*NL + (6674000617 + 33943749840*lm)*
             NH))*Log[x]^2)/454053600 + 
       (CF*NC*(2788669577*CA - 8239846803*CF + 2520*(1788601*NM + 
            15699*NL))*Log[x]^3)/3780 - (2628318847046627*CF^2*NC*
         PolyGamma[2, 1])/4132485216 + (28690473*CF*NM*NC*PolyGamma[2, 1])/
        40 - (2163708403833307*CF*NC*NH*PolyGamma[2, 1])/92980917360 - 
       (10970602312645529*CF^2*NC*Zeta[3])/36159245640 + 
       (55615069*CF*NM*NC*Zeta[3])/60 - (36135*CF*NC*NL*Zeta[3])/2 + 
       (649072824043613*CF*NC*NH*Zeta[3])/46490458680 + 
       CA*CF*NC*(-1441516873565606905194241813/2344587112133570304000 + 
         (207647*lm^2)/96 + (9648854101561*Pi^2)/44706816 + 
         (81046327322455*Pi^3)/(11019960576*Sqrt[3]) + (581219*Pi^4)/2880 + 
         lm*(2079944667/627200 - (429*Pi^2)/16) - 
         (22134680027336783*Im[PolyLog[2, (-1)^(1/3)]])/
          (899963447040*Sqrt[3]) + (100875*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (16209265464491*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (59521392*Sqrt[3]) + (16209265464491*Pi*Log[3]^2)/
          (2857026816*Sqrt[3]) + (2628318847046627*PolyGamma[2, 1])/
          8264970432 + (12146722556680223*Zeta[3])/72318491280) + 
       CF*Log[x]*((6360414138782801*NM*NC)/15901142400 - 
         (10754249*lm*NM*NC)/1680 - 1155*lm^2*NM*NC - (403972837*NC*NL)/
          14400 - (10754249*lm*NC*NL)/1680 - 1155*lm^2*NC*NL - 
         (1906368630559235505703*NC*NH)/5112042369033600 - 
         (10754249*lm*NC*NH)/1680 - 1155*lm^2*NC*NH + (879691*NM*NC*Pi^2)/
          3 - (6003*NC*NL*Pi^2)/2 + (1000533262498*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(-126911556505764536742637/65062357424064000 - 
           (33232947*lm)/560 - 10395*lm^2 - (4052285099*Pi^2)/10080 + 
           (16209265464491*Im[PolyLog[2, (-1)^(1/3)]])/(89282088*Sqrt[3]) - 
           27720*Zeta[3]) + CA*NC*(16657795113160987161587/
            16265589356016000 + (145462339*lm)/3360 + (12705*lm^2)/2 + 
           (12283694849*Pi^2)/60480 - (16209265464491*
             Im[PolyLog[2, (-1)^(1/3)]])/(178564176*Sqrt[3]) + 
           13860*Zeta[3])), (-10816781171267581955022203*CF^2*NC)/
        25185994368622337250 + (40777445*CF^2*lm*NC)/18816 + 
       (37905*CF^2*lm^2*NC)/8 + (15780467947510342915721*CF*NM*NC)/
        2674063315123200 + (25918685*CF*lm*NM*NC)/169344 + 
       (12635*CF*lm^2*NM*NC)/24 - (7351232815091*CF*NC*NL)/355622400 + 
       (25918685*CF*lm*NC*NL)/169344 + (12635*CF*lm^2*NC*NL)/24 - 
       (1105105339847368538601275713583*CF*NC*NH)/
        1810121732871921999129600 + (25918685*CF*lm*NC*NH)/169344 + 
       (12635*CF*lm^2*NC*NH)/24 + (2593659617482613*CF^2*NC*Pi^2)/
        26153487360 - (225*CF^2*lm*NC*Pi^2)/4 - (6353778779*CF*NM*NC*Pi^2)/
        3024 - (25*CF*lm*NM*NC*Pi^2)/4 + (272903*CF*NC*NL*Pi^2)/168 - 
       (25*CF*lm*NC*NL*Pi^2)/4 - (25*CF*lm*NC*NH*Pi^2)/4 + 
       (242293176659825*CF^2*NC*Pi^3)/(11019960576*Sqrt[3]) + 
       (4490005827265*CF*NC*NH*Pi^3)/(57395628*Sqrt[3]) + 
       (990539*CF^2*NC*Pi^4)/1728 - (72497618567262251*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(899963447040*Sqrt[3]) - 
       (799041474976231*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2008846980*Sqrt[3]) + (282965*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        4 + (48458635331965*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (59521392*Sqrt[3]) + (513143523116*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) + 
       (48458635331965*CF^2*NC*Pi*Log[3]^2)/(2857026816*Sqrt[3]) + 
       (128285880779*CF*NC*NH*Pi*Log[3]^2)/(2125764*Sqrt[3]) + 
       CF*((2055458303853803*CF*NC)/1089728640 + 
         CA*(-433245162329635/435891456 - 132385*lm)*NC + 216630*CF*lm*NC - 
         (604414863275*NM*NC)/24024 + 24070*lm*NM*NC + (183941*NC*NL)/6 + 
         24070*lm*NC*NL + (10331787509*NC*NH)/2042040 + 24070*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-733477847*CA + 6645209646*CF - 
          30240*(1213203*NM + 2407*NL))*Log[x]^3)/4536 + 
       (6449786544327697*CF^2*NC*PolyGamma[2, 1])/11622614670 - 
       (372086849*CF*NM*NC*PolyGamma[2, 1])/90 + 
       (523182224405299*CF*NC*NH*PolyGamma[2, 1])/15496819560 + 
       CA*CF*NC*(25736552873593865695183638757/103161832933877093376000 - 
         (138985*lm^2)/48 - (67519364053003*Pi^2)/1341204480 - 
         (242293176659825*Pi^3)/(22039921152*Sqrt[3]) - (1007819*Pi^4)/3456 + 
         lm*(-1533241375/338688 + (275*Pi^2)/8) + 
         (72497618567262251*Im[PolyLog[2, (-1)^(1/3)]])/(1799926894080*
           Sqrt[3]) - (282965*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 - 
         (48458635331965*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (119042784*Sqrt[3]) - (48458635331965*Pi*Log[3]^2)/
          (5714053632*Sqrt[3]) - (6449786544327697*PolyGamma[2, 1])/
          23245229340 - (122122379896239299*Zeta[3])/371923669440) + 
       (113297285530587299*CF^2*NC*Zeta[3])/185961834720 - 
       (196335074*CF*NM*NC*Zeta[3])/45 + 27445*CF*NC*NL*Zeta[3] - 
       (309074470064501*CF*NC*NH*Zeta[3])/7748409780 + 
       CF*Log[x]*((-40461513870969769*NM*NC)/5194373184 + 
         (1556099*lm*NM*NC)/168 + 1650*lm^2*NM*NC + (9070526299*NC*NL)/
          211680 + (1556099*lm*NC*NL)/168 + 1650*lm^2*NC*NL + 
         (141213869028017837397673*NC*NH)/246230040775118400 + 
         (1556099*lm*NC*NH)/168 + 1650*lm^2*NC*NH - (6045700*NM*NC*Pi^2)/
          3 + (13685*NC*NL*Pi^2)/3 - (513143523116*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CA*NC*(-4554231363562695545693/81792677904537600 - 
           (20997889*lm)/336 - 9075*lm^2 - (717735299*Pi^2)/10368 + 
           (48458635331965*Im[PolyLog[2, (-1)^(1/3)]])/(357128352*Sqrt[3]) - 
           19800*Zeta[3]) + CF*NC*(-9210848596840412683141/
            286274372665881600 + (4806897*lm)/56 + 14850*lm^2 + 
           (228362809*Pi^2)/1728 - (48458635331965*Im[PolyLog[2, (-1)^
                (1/3)]])/(178564176*Sqrt[3]) + 39600*Zeta[3])), 
      (5097533105856442240125681361543*CF^2*NC)/464228248202446920192000 - 
       (4024954141*CF^2*lm*NC)/1524096 - (12085*CF^2*lm^2*NC)/2 - 
       (49768987351004490990041*CF*NM*NC)/7775353331665920 - 
       (2490062461*CF*lm*NM*NC)/13716864 - (12085*CF*lm^2*NM*NC)/18 + 
       (1400416357844503*CF*NC*NL)/48009024000 - (2490062461*CF*lm*NC*NL)/
        13716864 - (12085*CF*lm^2*NC*NL)/18 + 
       (9279104177483700977748677419631*CF*NC*NH)/
        11278450797125052456115200 - (2490062461*CF*lm*NC*NH)/13716864 - 
       (12085*CF*lm^2*NC*NH)/18 - (319207361438965477*CF^2*NC*Pi^2)/
        78460462080 + (2425*CF^2*lm*NC*Pi^2)/36 + 
       (832601525387*CF*NM*NC*Pi^2)/408240 + (2425*CF*lm*NM*NC*Pi^2)/324 - 
       (44228095*CF*NC*NL*Pi^2)/20412 + (2425*CF*lm*NC*NL*Pi^2)/324 + 
       (2425*CF*lm*NC*NH*Pi^2)/324 - (3004917243091355*CF^2*NC*Pi^3)/
        (99179645184*Sqrt[3]) - (493167971893835*CF*NC*NH*Pi^3)/
        (4649045868*Sqrt[3]) - (4026227*CF^2*NC*Pi^4)/5184 + 
       (842448302245595513*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8099671023360*Sqrt[3]) + (90200849114417269*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(162716605380*Sqrt[3]) - 
       (1129645*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (600983448618271*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (535692528*Sqrt[3]) - (56362053930724*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (600983448618271*CF^2*NC*Pi*Log[3]^2)/(25713241344*Sqrt[3]) - 
       (14090513482681*CF*NC*NH*Pi*Log[3]^2)/(172186884*Sqrt[3]) - 
       (CF*NC*(-153*CA*(18141120550209263 + 134104508778240*lm) + 
          34*CF*(162787937540410211 + 987496837367040*lm) + 
          8736*(255*(-1217429353549 + 1674631728*lm)*NM + 
            706860*(762863 + 604124*lm)*NL + (93910823777 + 427031090640*lm)*
             NH))*Log[x]^2)/111152321280 + 
       (CF*NC*(98169460435*CA + 6*(-36466015217*CF + 
            336*(56995679*NM + 151031*NL)))*Log[x]^3)/13608 - 
       (60463922961510859*CF^2*NC*PolyGamma[2, 1])/10331213040 + 
       (2633301623*CF*NM*NC*PolyGamma[2, 1])/405 - 
       (9813861868629629*CF*NC*NH*PolyGamma[2, 1])/209207064060 - 
       (579089893649262547*CF^2*NC*Zeta[3])/144636982560 + 
       (3634143691*CF*NM*NC*Zeta[3])/405 - (1027411*CF*NC*NL*Zeta[3])/27 + 
       (5112635989513471*CF*NC*NH*Zeta[3])/104603532030 + 
       CA*CF*NC*(-2570485783512886303038062782271/464228248202446920192000 + 
         (132935*lm^2)/36 + (24567233501754529*Pi^2)/12070840320 + 
         (3004917243091355*Pi^3)/(198359290368*Sqrt[3]) + 
         (1362769*Pi^4)/3456 + lm*(156321588191/27433728 - 
           (26675*Pi^2)/648) - (842448302245595513*
           Im[PolyLog[2, (-1)^(1/3)]])/(16199342046720*Sqrt[3]) + 
         (1129645*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (600983448618271*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1071385056*Sqrt[3]) + (600983448618271*Pi*Log[3]^2)/
          (51426482688*Sqrt[3]) + (60463922961510859*PolyGamma[2, 1])/
          20662426080 + (588521881541317387*Zeta[3])/289273965120) + 
       CF*Log[x]*((430985954849598361*NM*NC)/89902612800 - 
         (167791555*lm*NM*NC)/13608 - 2200*lm^2*NM*NC - 
         (565096907341*NC*NL)/9525600 - (167791555*lm*NC*NL)/13608 - 
         2200*lm^2*NC*NL - (170484370460883329599487*NC*NH)/
          219171794536094400 - (167791555*lm*NC*NH)/13608 - 
         2200*lm^2*NC*NH + (6303914*NM*NC*Pi^2)/3 - (170831*NC*NL*Pi^2)/
          27 + (56362053930724*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(-6843366836420497014502571/
            368067050570419200 - (172781155*lm)/1512 - 19800*lm^2 - 
           (400500905437*Pi^2)/108864 + (600983448618271*
             Im[PolyLog[2, (-1)^(1/3)]])/(1607077584*Sqrt[3]) - 
           52800*Zeta[3]) + CA*NC*(48406407165381484497830597/
            5152938707985868800 + (2264833505*lm)/27216 + 12100*lm^2 + 
           (401459124517*Pi^2)/217728 - (600983448618271*
             Im[PolyLog[2, (-1)^(1/3)]])/(3214155168*Sqrt[3]) + 
           26400*Zeta[3])), (-323764341676212535125970962133*CF^2*NC)/
        120520795206404488896000 + (5509058125*CF^2*lm*NC)/1524096 + 
       (62755*CF^2*lm^2*NC)/8 + (26689248905378784346407913*CF*NM*NC)/
        505397966558284800 + (3516461365*CF*lm*NM*NC)/13716864 + 
       (62755*CF*lm^2*NM*NC)/72 - (415801002022099*CF*NC*NL)/9601804800 + 
       (3516461365*CF*lm*NC*NL)/13716864 + (62755*CF*lm^2*NC*NL)/72 - 
       (4424829339170748869420995180495597*CF*NC*NH)/
        3683756857975273085547340800 + (3516461365*CF*lm*NC*NH)/13716864 + 
       (62755*CF*lm^2*NC*NH)/72 + (9563990822950919*CF^2*NC*Pi^2)/
        15692092416 - (3025*CF^2*lm*NC*Pi^2)/36 - 
       (7662523604633*CF*NM*NC*Pi^2)/408240 - (3025*CF*lm*NM*NC*Pi^2)/324 + 
       (121619861*CF*NC*NL*Pi^2)/40824 - (3025*CF*lm*NC*NL*Pi^2)/324 - 
       (3025*CF*lm*NC*NH*Pi^2)/324 + (38714515445051765*CF^2*NC*Pi^3)/
        (892616806656*Sqrt[3]) + (120799266514325*CF*NC*NH*Pi^3)/
        (774840978*Sqrt[3]) + (5594237*CF^2*NC*Pi^4)/5184 - 
       (35114107861455396589*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (218691117630720*Sqrt[3]) - (8529911326063669*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10847773692*Sqrt[3]) + 
       (1530595*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
       (7742903089010353*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4821232752*Sqrt[3]) + (27611260917560*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) + 
       (7742903089010353*CF^2*NC*Pi*Log[3]^2)/(231419172096*Sqrt[3]) + 
       (3451407614695*CF*NC*NH*Pi*Log[3]^2)/(28697814*Sqrt[3]) + 
       CF*((2196083261047481*CF*NC)/251475840 + 
         CA*(-617060744133/137984 - (2431495*lm)/9)*NC + 442090*CF*lm*NC - 
         (48675981937379*NM*NC)/216216 + (442090*lm*NM*NC)/9 + 
         (123607*NC*NL)/2 + (442090*lm*NC*NL)/9 + (550707963643*NC*NH)/
          48349224 + (442090*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(17561676919*CA - 69673775778*CF + 
          2016*(469126739*NM + 221045*NL))*Log[x]^3)/13608 + 
       (755160506027608877*CF^2*NC*PolyGamma[2, 1])/156905298045 - 
       (15355646258*CF*NM*NC*PolyGamma[2, 1])/405 + 
       (9164241874591121*CF*NC*NH*PolyGamma[2, 1])/139471376040 + 
       CA*CF*NC*(678348456667694891242718689649/482083180825617955584000 - 
         (690305*lm^2)/144 - (4368631524264953*Pi^2)/14265538560 - 
         (38714515445051765*Pi^3)/(1785233613312*Sqrt[3]) - 
         (1890559*Pi^4)/3456 + (55*lm*(-3746530961 + 25613280*Pi^2))/
          27433728 + (35114107861455396589*Im[PolyLog[2, (-1)^(1/3)]])/
          (437382235261440*Sqrt[3]) - (1530595*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          24 - (7742903089010353*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9642465504*Sqrt[3]) - (7742903089010353*Pi*Log[3]^2)/
          (462838344192*Sqrt[3]) - (755160506027608877*PolyGamma[2, 1])/
          313810596090 - (271975612520918994491*Zeta[3])/70293573524160) + 
       (268748141345101914131*CF^2*NC*Zeta[3])/35146786762080 - 
       (16752449971*CF*NM*NC*Zeta[3])/405 + (1492645*CF*NC*NL*Zeta[3])/27 - 
       (6908052079769479*CF*NC*NH*Zeta[3])/69735688020 + 
       CF*Log[x]*((-9916027145994623683*NM*NC)/129859329600 + 
         (233117071*lm*NM*NC)/13608 + 3025*lm^2*NM*NC + 
         (82456959203*NC*NL)/952560 + (233117071*lm*NC*NL)/13608 + 
         3025*lm^2*NC*NL + (42191070660663153684774533*NC*NH)/
          36923141652847369920 + (233117071*lm*NC*NH)/13608 + 
         3025*lm^2*NC*NH - (52086461*NM*NC*Pi^2)/3 + (248270*NC*NL*Pi^2)/
          27 - (27611260917560*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CA*NC*(154574038492597313779639/
            509631300789811200 - (3140586581*lm)/27216 - (33275*lm^2)/2 - 
           (83157099811*Pi^2)/217728 + (7742903089010353*
             Im[PolyLog[2, (-1)^(1/3)]])/(28927396512*Sqrt[3]) - 
           36300*Zeta[3]) + CF*NC*(-1573326440981342949212029/
            1783709552764339200 + (239977771*lm)/1512 + 27225*lm^2 + 
           (81778589251*Pi^2)/108864 - (7742903089010353*
             Im[PolyLog[2, (-1)^(1/3)]])/(14463698256*Sqrt[3]) + 
           72600*Zeta[3])), (120693873086920442279929822031383667*CF^2*NC)/
        1172958882901005455435980800 - (13241354759*CF^2*lm*NC)/3048192 - 
       (156629*CF^2*lm^2*NC)/16 - (255237055269697270488036007969*CF*NM*NC)/
        4966040419401706444800 - (8268070751*CF*lm*NM*NC)/27433728 - 
       (156629*CF*lm^2*NM*NC)/144 + (1897754643905569*CF*NC*NL)/
        32006016000 - (8268070751*CF*lm*NC*NL)/27433728 - 
       (156629*CF*lm^2*NC*NL)/144 + (15909360118416401091813122147392031879*
         CF*NC*NH)/10056656222272495523544240384000 - 
       (8268070751*CF*lm*NC*NH)/27433728 - (156629*CF*lm^2*NC*NH)/144 - 
       (7522510453939530067*CF^2*NC*Pi^2)/196151155200 + 
       (7139*CF^2*lm*NC*Pi^2)/72 + (1894720318039*CF*NM*NC*Pi^2)/116640 + 
       (7139*CF*lm*NM*NC*Pi^2)/648 - (79076965*CF*NC*NL*Pi^2)/20412 + 
       (7139*CF*lm*NC*NL*Pi^2)/648 + (7139*CF*lm*NC*NH*Pi^2)/648 - 
       (8636730477466241*CF^2*NC*Pi^3)/(148769467776*Sqrt[3]) - 
       (1919321703704545*CF*NC*NH*Pi^3)/(9298091736*Sqrt[3]) - 
       (3684901*CF^2*NC*Pi^4)/2592 + (37395550398134641889*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(182242598025600*Sqrt[3]) + 
       (346505214619470227*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (325433210760*Sqrt[3]) - (993179*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/6 - (8636730477466241*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4017693960*Sqrt[3]) - 
       (109675525925974*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) - (8636730477466241*CF^2*NC*Pi*Log[3]^2)/
        (192849310080*Sqrt[3]) - (54837762962987*CF*NC*NH*Pi*Log[3]^2)/
        (344373768*Sqrt[3]) - 
       (CF*NC*(-171*CA*(7138913296793339953 + 11302295652648000*lm) + 
          38*CF*(64209146268333179419 + 83225995260408000*lm) + 
          840*(57*(-21478985265500281 + 7339153021200*lm)*NM + 
            384107724*(1360379 + 1089100*lm)*NL + 
            (100768468025317 + 418331722208400*lm)*NH))*Log[x]^2)/
        5279735260800 + (CF*NC*(929697024511*CA + 
          120*(-15898529419*CF + 7252275702*NM + 5031642*NL))*Log[x]^3)/
        13608 - (90905806431631855853*CF^2*NC*PolyGamma[2, 1])/
        1673656512480 + (378904665719*CF*NM*NC*PolyGamma[2, 1])/6480 - 
       (55672738561555153*CF*NC*NH*PolyGamma[2, 1])/627621192180 - 
       (115265891981319260761*CF^2*NC*Zeta[3])/2928898896840 + 
       (276535020179*CF*NM*NC*Zeta[3])/3240 - (4025879*CF*NC*NL*Zeta[3])/
        54 + (38719663991813657*CF*NC*NH*Zeta[3])/313810596090 + 
       CA*CF*NC*(-846239982408928533133107162179696297/
          16421424360614076376103731200 + (1722919*lm^2)/288 + 
         (136787319775595821*Pi^2)/7132769280 + (8636730477466241*Pi^3)/
          (297538935552*Sqrt[3]) + (6217651*Pi^4)/8640 + 
         lm*(508704634933/54867456 - (78529*Pi^2)/1296) - 
         (37395550398134641889*Im[PolyLog[2, (-1)^(1/3)]])/
          (364485196051200*Sqrt[3]) + (993179*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          12 + (8636730477466241*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (8035387920*Sqrt[3]) + (8636730477466241*Pi*Log[3]^2)/
          (385698620160*Sqrt[3]) + (90905806431631855853*PolyGamma[2, 1])/
          3347313024960 + (23125242607411885175*Zeta[3])/1171559558736) + 
       CF*Log[x]*((30943428234009947855569*NM*NC)/675528232579200 - 
         (3026957461*lm*NM*NC)/136080 - (7865*lm^2*NM*NC)/2 - 
         (370316767943*NC*NL)/3175200 - (3026957461*lm*NC*NL)/136080 - 
         (7865*lm^2*NC*NL)/2 - (21789515958546883410318192559*NC*NH)/
          14400025244610474268800 - (3026957461*lm*NC*NH)/136080 - 
         (7865*lm^2*NC*NH)/2 + (47911415*NM*NC*Pi^2)/3 - 
         (334895*NC*NL*Pi^2)/27 + (109675525925974*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(-248786622085640077356735238723/1396124331194921328000 - 
           (3116146561*lm)/15120 - (70785*lm^2)/2 - (9336189373207*Pi^2)/
            272160 + (8636730477466241*Im[PolyLog[2, (-1)^(1/3)]])/
            (12053081880*Sqrt[3]) - 94380*Zeta[3]) + 
         CA*NC*(142454866846833631862504439757/1595570664222767232000 + 
           (40788416471*lm)/272160 + (86515*lm^2)/4 + (9340868270311*Pi^2)/
            544320 - (8636730477466241*Im[PolyLog[2, (-1)^(1/3)]])/
            (24106163760*Sqrt[3]) + 47190*Zeta[3])), 
      (-65306733693547614098238108130039002089*CF^2*NC)/
        4156673041280438082701256960000 + (1214588597*CF^2*lm*NC)/211680 + 
       12397*CF^2*lm^2*NC + (163641850912830399046897269259*CF*NM*NC)/
        344863918014007392000 + (777222437*CF*lm*NM*NC)/1905120 + 
       (12397*CF*lm^2*NM*NC)/9 - (56441719690261*CF*NC*NL)/666792000 + 
       (777222437*CF*lm*NC*NL)/1905120 + (12397*CF*lm^2*NC*NL)/9 - 
       (37828360691004718236042219603001699129*CF*NC*NH)/
        16970607375084836195980905648000 + (777222437*CF*lm*NC*NH)/1905120 + 
       (12397*CF*lm^2*NC*NH)/9 + (302368016558171723*CF^2*NC*Pi^2)/
        98075577600 - 121*CF^2*lm*NC*Pi^2 - (1926423510173*CF*NM*NC*Pi^2)/
        11340 - (121*CF*lm*NM*NC*Pi^2)/9 + (58576463*CF*NC*NL*Pi^2)/11340 - 
       (121*CF*lm*NC*NL*Pi^2)/9 - (121*CF*lm*NC*NH*Pi^2)/9 + 
       (483595823077104637*CF^2*NC*Pi^3)/(6025163444928*Sqrt[3]) + 
       (9174101596169230*CF*NC*NH*Pi^3)/(31381059609*Sqrt[3]) + 
       (12384889*CF^2*NC*Pi^4)/6480 - (2231302994529469375843*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7380825220036800*Sqrt[3]) - 
       (1612966528617762959*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1098337086315*Sqrt[3]) + (654203*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 + (483595823077104637*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(162716605380*Sqrt[3]) + 
       (4193875015391648*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) + (483595823077104637*CF^2*NC*Pi*Log[3]^2)/
        (7810397058240*Sqrt[3]) + (262117188461978*CF*NC*NH*Pi*Log[3]^2)/
        (1162261467*Sqrt[3]) + CF*((551627474353180063*CF*NC)/13894040160 + 
         CA*(-398083135003416257/19848628800 - (1548316*lm)/3)*NC + 
         844536*CF*lm*NC - (3121778694419557*NM*NC)/1531530 + 
         (281512*lm*NM*NC)/3 + (5259727*NC*NL)/45 + (281512*lm*NC*NL)/3 + 
         (49053085162*NC*NH)/2078505 + (281512*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-127732562305*CA + 2*(172388798899*CF - 
            7560*(696371035*NM + 70378*NL)))*Log[x]^3)/17010 + 
       (119985915141586906301*CF^2*NC*PolyGamma[2, 1])/2824295364810 - 
       (74920407769*CF*NM*NC*PolyGamma[2, 1])/216 + 
       (16830979110986267*CF*NC*NH*PolyGamma[2, 1])/139471376040 + 
       CA*CF*NC*(13248251897167263662738999646195947047/
          1662669216512175233080502784000 - (136367*lm^2)/18 - 
         (27536848652549281*Pi^2)/17831923200 - (483595823077104637*Pi^3)/
          (12050326889856*Sqrt[3]) - (12524281*Pi^4)/12960 + 
         lm*(-45288204247/3810240 + (1331*Pi^2)/18) + 
         (2231302994529469375843*Im[PolyLog[2, (-1)^(1/3)]])/
          (14761650440073600*Sqrt[3]) - (654203*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          6 - (483595823077104637*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (325433210760*Sqrt[3]) - (483595823077104637*Pi*Log[3]^2)/
          (15620794116480*Sqrt[3]) - (119985915141586906301*PolyGamma[2, 1])/
          5648590729620 - (862143383115407641291*Zeta[3])/22594362918480) + 
       (860243127946425269431*CF^2*NC*Zeta[3])/11297181459240 - 
       (41553283177*CF*NM*NC*Zeta[3])/108 + (313456*CF*NC*NL*Zeta[3])/3 - 
       (14910288571866373*CF*NC*NH*Zeta[3])/69735688020 + 
       CF*Log[x]*((-2914421028657382942681*NM*NC)/4021001384400 + 
         (28268482*lm*NM*NC)/945 + (15730*lm^2*NM*NC)/3 + 
         (130207056101*NC*NL)/793800 + (28268482*lm*NC*NL)/945 + 
         (15730*lm^2*NC*NL)/3 + (52052817939298686452221792043*NC*NH)/
          24300042600280175328600 + (28268482*lm*NC*NH)/945 + 
         (15730*lm^2*NC*NH)/3 - (464178064*NM*NC*Pi^2)/3 + 
         (52162*NC*NL*Pi^2)/3 - (4193875015391648*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CA*NC*(2476837725396752076178472646307/452344283307154510272000 - 
           (190161301*lm)/945 - (86515*lm^2)/3 - (77425781731*Pi^2)/38880 + 
           (483595823077104637*Im[PolyLog[2, (-1)^(1/3)]])/
            (976299632280*Sqrt[3]) - 62920*Zeta[3]) + 
         CF*NC*(-2589529281605512454848171524163/226172141653577255136000 + 
           (29094307*lm)/105 + 47190*lm^2 + (76961288491*Pi^2)/19440 - 
           (483595823077104637*Im[PolyLog[2, (-1)^(1/3)]])/
            (488149816140*Sqrt[3]) + 125840*Zeta[3])), 
      (113843577493198053095799122128164285022477*CF^2*NC)/
        117327655926512447774682804480000 - (58156490683*CF^2*lm*NC)/
        8537760 - 15193*CF^2*lm^2*NC - (977260159562190665858948504203459*CF*
         NM*NC)/2365421613658076701728000 - (36537459403*CF*lm*NM*NC)/
        76839840 - (15193*CF*lm^2*NM*NC)/9 + (54697941309336497*CF*NC*NL)/
        484090992000 - (36537459403*CF*lm*NC*NL)/76839840 - 
       (15193*CF*lm^2*NC*NL)/9 + (879303363043091050932913759754047429613*CF*
         NC*NH)/305470932751527051527656301664000 - 
       (36537459403*CF*lm*NC*NH)/76839840 - (15193*CF*lm^2*NC*NH)/9 - 
       (130337811022317659911*CF^2*NC*Pi^2)/359610451200 + 
       141*CF^2*lm*NC*Pi^2 + (2340474625897*CF*NM*NC*Pi^2)/17820 + 
       (47*CF*lm*NM*NC*Pi^2)/3 - (273421739*CF*NC*NL*Pi^2)/41580 + 
       (47*CF*lm*NC*NL*Pi^2)/3 + (47*CF*lm*NC*NH*Pi^2)/3 - 
       (257421440628992741*CF^2*NC*Pi^3)/(2454696218304*Sqrt[3]) - 
       (107116131138091810*CF*NC*NH*Pi^3)/(282429536481*Sqrt[3]) - 
       (5313307*CF^2*NC*Pi^4)/2160 + (1404197593584275831861*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3675225726849600*Sqrt[3]) + 
       (3838079138254779361*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1977006755367*Sqrt[3]) - 277121*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (257421440628992741*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(66291950340*Sqrt[3]) - 
       (48967374234556256*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (257421440628992741*CF^2*NC*Pi*Log[3]^2)/
        (3182013616320*Sqrt[3]) - (3060460889659766*CF*NC*NH*Pi*Log[3]^2)/
        (10460353203*Sqrt[3]) - 
       (CF*NC*(-(CA*(21069605210236655750737 + 6607249602560006400*lm)) + 
          2*(CF*(21066911809025303471101 + 5405931493003641600*lm) + 
            55440*(7*(-19652014564182131 + 1547771219280*lm)*NM + 
              21339318*(628499 + 507720*lm)*NL + (2815028227463 + 
                10834398534960*lm)*NH)))*Log[x]^2)/9679514644800 + 
       (CF*NC*(40252710159155*CA - 80952611088514*CF + 
          55440*(568840549*NM + 93082*NL))*Log[x]^3)/62370 - 
       (1900554144510911993509*CF^2*NC*PolyGamma[2, 1])/3765727153080 + 
       (94460377517*CF*NM*NC*PolyGamma[2, 1])/180 - 
       (2694984199300447573*CF*NC*NH*PolyGamma[2, 1])/16945772188860 - 
       (105035258261285884303951*CF^2*NC*Zeta[3])/289960990787160 + 
       (71770849277*CF*NM*NC*Zeta[3])/90 - 137644*CF*NC*NL*Zeta[3] + 
       (2254393843989964187*CF*NC*NH*Zeta[3])/8472886094430 + 
       CA*CF*NC*(-178950629820428593833925617529086787418303/
          368744061483324835863288814080000 + (167123*lm^2)/18 + 
         (130340388043424820103*Pi^2)/719220902400 + 
         (257421440628992741*Pi^3)/(4909392436608*Sqrt[3]) + 
         (5367451*Pi^4)/4320 + lm*(201628243723/13970880 - (517*Pi^2)/6) - 
         (1404197593584275831861*Im[PolyLog[2, (-1)^(1/3)]])/
          (7350451453699200*Sqrt[3]) + (277121*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          2 + (257421440628992741*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (132583900680*Sqrt[3]) + (257421440628992741*Pi*Log[3]^2)/
          (6364027232640*Sqrt[3]) + (1900554144510911993509*PolyGamma[2, 1])/
          7531454306160 + (105099196473621539896963*Zeta[3])/
          579921981574320) + CF*Log[x]*((76500478634944382945957*NM*NC)/
          188167972192200 - (43933873*lm*NM*NC)/1155 - (20020*lm^2*NM*NC)/
          3 - (3771457084057*NC*NL)/17463600 - (43933873*lm*NC*NL)/1155 - 
         (20020*lm^2*NC*NL)/3 - (1215616895799967299841333143037*NC*NH)/
          437400766805043155914800 - (43933873*lm*NC*NH)/1155 - 
         (20020*lm^2*NC*NH)/3 + (1137402446*NM*NC*Pi^2)/9 - 
         (68728*NC*NL*Pi^2)/3 + (48967374234556256*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-8076058246815840910838470625525443/
            4752008330721456508704000 - (135655469*lm)/385 - 60060*lm^2 - 
           (161146124965421*Pi^2)/498960 + (257421440628992741*
             Im[PolyLog[2, (-1)^(1/3)]])/(198875851020*Sqrt[3]) - 
           160160*Zeta[3]) + CA*NC*(56553886688495690899983505403790793/
            66528116630100391121856000 + (53743673*lm)/210 + 
           (110110*lm^2)/3 + (161161920470069*Pi^2)/997920 - 
           (257421440628992741*Im[PolyLog[2, (-1)^(1/3)]])/
            (397751702040*Sqrt[3]) + 80080*Zeta[3])), 
      (-37627789761470569529792233572244833088817863*CF^2*NC)/
        470425236437351659352590704562560000 + (224029998701*CF^2*lm*NC)/
        25613280 + 18850*CF^2*lm^2*NC + (134116592965959708624505762429351*CF*
         NM*NC)/31123968600764167128000 + (143561610701*CF*lm*NM*NC)/
        230519520 + (18850*CF*lm^2*NM*NC)/9 - (37803433318114529*CF*NC*NL)/
        242045496000 + (143561610701*CF*lm*NC*NL)/230519520 + 
       (18850*CF*lm^2*NC*NL)/9 - 
       (4878752851097369742521115431715228422523727*CF*NC*NH)/
        1238888279595943211978998074115296000 + (143561610701*CF*lm*NC*NH)/
        230519520 + (18850*CF*lm^2*NC*NH)/9 + 
       (10116631428356880949*CF^2*NC*Pi^2)/1078831353600 - 
       169*CF^2*lm*NC*Pi^2 - (64587911526511*CF*NM*NC*Pi^2)/41580 - 
       (169*CF*lm*NM*NC*Pi^2)/9 + (1066404313*CF*NC*NL*Pi^2)/124740 - 
       (169*CF*lm*NC*NL*Pi^2)/9 - (169*CF*lm*NC*NH*Pi^2)/9 + 
       (28013566532814192577*CF^2*NC*Pi^3)/(198830393682624*Sqrt[3]) + 
       (98094656567284685*CF*NC*NH*Pi^3)/(188286357654*Sqrt[3]) + 
       (20860957*CF^2*NC*Pi^4)/6480 - (1452120339450731559264773*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2679239554873358400*Sqrt[3]) - 
       (1230373309972598813*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (470715894135*Sqrt[3]) + (1069991*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 + (28013566532814192577*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5369647977540*Sqrt[3]) + 
       (22421635786807928*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) + (28013566532814192577*CF^2*NC*Pi*Log[3]^2)/
        (257743102921920*Sqrt[3]) + (2802704473350991*CF*NC*NH*Pi*Log[3]^2)/
        (6973568802*Sqrt[3]) + CF*((1704759111545037957559*CF*NC)/
          14519271967200 + CA*(-1715645996133489200827/29038543934400 - 
           (2799940*lm)/3)*NC + 1527240*CF*lm*NC - (1585961573689186*NM*NC)/
          85085 + (509080*lm*NM*NC)/3 + (9431851*NC*NL)/45 + 
         (509080*lm*NC*NL)/3 + (91759465236977*NC*NH)/2007835830 + 
         (509080*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(6010378066433*CA + 14*(-995210760671*CF + 
            11880*(6321682429*NM + 127270*NL)))*Log[x]^3)/187110 + 
       (638042889503583882271*CF^2*NC*PolyGamma[2, 1])/1694577218886 - 
       (3424271360299*CF*NM*NC*PolyGamma[2, 1])/1080 + 
       (2384884358214794557*CF*NC*NH*PolyGamma[2, 1])/11297181459240 + 
       CA*CF*NC*(8115627786283229248160549069978423767093/
          201964253058860860514152926720000 - (103675*lm^2)/9 - 
         (778985229909454081*Pi^2)/165974054400 - (28013566532814192577*Pi^3)/
          (397660787365248*Sqrt[3]) - (4211129*Pi^4)/2592 + 
         lm*(-758047482701/41912640 + (1859*Pi^2)/18) + 
         (1452120339450731559264773*Im[PolyLog[2, (-1)^(1/3)]])/
          (5358479109746716800*Sqrt[3]) - (1069991*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/6 - (28013566532814192577*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(10739295955080*Sqrt[3]) - 
         (28013566532814192577*Pi*Log[3]^2)/(515486205843840*Sqrt[3]) - 
         (638042889503583882271*PolyGamma[2, 1])/3389154437772 - 
         (170540310408234582250891*Zeta[3])/474481621288080) + 
       (170470540570160009040751*CF^2*NC*Zeta[3])/237240810644040 - 
       (1907598386059*CF*NM*NC*Zeta[3])/540 + (561808*CF*NC*NL*Zeta[3])/3 - 
       (2372835746377226243*CF*NC*NH*Zeta[3])/5648590729620 + 
       CF*Log[x]*((-3636108228395968315183327*NM*NC)/534793184125200 + 
         (517738208*lm*NM*NC)/10395 + (26026*lm^2*NM*NC)/3 + 
         (2573100660227*NC*NL)/8731800 + (517738208*lm*NC*NL)/10395 + 
         (26026*lm^2*NC*NL)/3 + (2943302356835767380476010846853*NC*NH)/
          771283352132892764929764 + (517738208*lm*NC*NH)/10395 + 
         (26026*lm^2*NC*NH)/3 - (12643011934*NM*NC*Pi^2)/9 + 
         31174*NC*NL*Pi^2 - (22421635786807928*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3486784401*Sqrt[3]) + 
         CA*NC*(374181408310280254076686250283013027/
            5388777447038131680870336000 - (316256434*lm)/945 - 
           (143143*lm^2)/3 - (2242073127409*Pi^2)/272160 + 
           (28013566532814192577*Im[PolyLog[2, (-1)^(1/3)]])/
            (32217887865240*Sqrt[3]) - 104104*Zeta[3]) + 
         CF*NC*(-376493912747255800234884068464398859/
            2694388723519065840435168000 + (532768223*lm)/1155 + 78078*lm^2 + 
           (2236253882929*Pi^2)/136080 - (28013566532814192577*
             Im[PolyLog[2, (-1)^(1/3)]])/(16108943932620*Sqrt[3]) + 
           208208*Zeta[3])), (3455862972039797970824391458316918892683608663*
         CF^2*NC)/376340189149881327482072563650048000 - 
       (18942779393743*CF^2*lm*NC)/1844156160 - (363987*CF^2*lm^2*NC)/16 - 
       (81759115472767293715292959474103189*CF*NM*NC)/
        24330050883340217503488000 - (11950603683223*CF*lm*NM*NC)/
        16597405440 - (40443*CF*lm^2*NM*NC)/16 + 
       (10665822351900824341*CF*NC*NL)/52281827136000 - 
       (11950603683223*CF*lm*NC*NL)/16597405440 - (40443*CF*lm^2*NC*NL)/
        16 + (148648936589602318554362986884229738645817783*CF*NC*NH)/
        29733318710302637087495953778767104000 - 
       (11950603683223*CF*lm*NC*NH)/16597405440 - (40443*CF*lm^2*NC*NH)/
        16 - (616871738754387571643*CF^2*NC*Pi^2)/179805225600 + 
       (14027*CF^2*lm*NC*Pi^2)/72 + (9669202430370883*CF*NM*NC*Pi^2)/
        8981280 + (14027*CF*lm*NM*NC*Pi^2)/648 - 
       (47997314287*CF*NC*NL*Pi^2)/4490640 + (14027*CF*lm*NC*NL*Pi^2)/648 + 
       (14027*CF*lm*NC*NH*Pi^2)/648 - (8965519196741438569*CF^2*NC*Pi^3)/
        (49707598420656*Sqrt[3]) - (3000904723038167435*CF*NC*NH*Pi^3)/
        (4518872583696*Sqrt[3]) - (4387721*CF^2*NC*Pi^4)/1080 + 
       (259263276991981419900797*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (382748507839051200*Sqrt[3]) + (53549095691447802269*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(15816054042936*Sqrt[3]) - 
       (1335698*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (1280788456677348367*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (191773142055*Sqrt[3]) - (85740134943947641*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3486784401*Sqrt[3]) - 
       (1280788456677348367*CF^2*NC*Pi*Log[3]^2)/(9205110818640*Sqrt[3]) - 
       (85740134943947641*CF*NC*NH*Pi*Log[3]^2)/(167365651248*Sqrt[3]) - 
       (CF*NC*(-23*CA*(298927582811472019497823 + 17556915939871908600*lm) + 
          45*(23*CF*(13285349573697989404709 + 638433306904433040*lm) + 
            154*(23*(-27066366431076023773 + 460630091561640*lm)*NM + 
              6380456082*(2039957 + 1660460*lm)*NL + (2934731699426831 + 
                10594492105917720*lm)*NH)))*Log[x]^2)/333943255245600 + 
       (CF*NC*(4569627390020615*CA - 9149468189882168*CF + 
          9240*(332102301658*NM + 11872289*NL))*Log[x]^3)/748440 - 
       (211806723108796405109177*CF^2*NC*PolyGamma[2, 1])/45188725836960 + 
       (3813052617503*CF*NM*NC*PolyGamma[2, 1])/810 - 
       (166283382779433001649*CF*NC*NH*PolyGamma[2, 1])/610047798798960 - 
       (516499176512733487206803*CF^2*NC*Zeta[3])/158160540429360 + 
       (2983308233048*CF*NM*NC*Zeta[3])/405 - (6528743*CF*NC*NL*Zeta[3])/
        27 + (158411873167853312311*CF*NC*NH*Zeta[3])/305023899399480 + 
       CA*CF*NC*(-34560449231386000240909726991597633105895081521/
          7526803782997626549641451273000960000 + (444873*lm^2)/32 + 
         (11862959697692541797*Pi^2)/6915585600 + (8965519196741438569*Pi^3)/
          (99415196841312*Sqrt[3]) + (13275379*Pi^4)/6480 + 
         lm*(65345400018103/3017710080 - (154297*Pi^2)/1296) - 
         (259263276991981419900797*Im[PolyLog[2, (-1)^(1/3)]])/
          (765497015678102400*Sqrt[3]) + (667849*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/3 + (1280788456677348367*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(383546284110*Sqrt[3]) + 
         (1280788456677348367*Pi*Log[3]^2)/(18410221637280*Sqrt[3]) + 
         (211806723108796405109177*PolyGamma[2, 1])/90377451673920 + 
         (516559017313839979072151*Zeta[3])/316321080858720) + 
       CF*Log[x]*((1284764537417003034932800493*NM*NC)/365798537941636800 - 
         (93128063873*lm*NM*NC)/1496880 - (65065*lm^2*NM*NC)/6 - 
         (1434819303372397*NC*NL)/3772137600 - (93128063873*lm*NC*NL)/
          1496880 - (65065*lm^2*NC*NL)/6 - 
         (1125542835333747180385844578470983*NC*NH)/
          231385005639867829478929200 - (93128063873*lm*NC*NH)/1496880 - 
         (65065*lm^2*NC*NH)/6 + (332085662321*NM*NC*Pi^2)/324 - 
         (13043459*NC*NL*Pi^2)/324 + (85740134943947641*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-86974022360817081924841121578415190643/
            5388777447038131680870336000 - (95833466573*lm)/166320 - 
           (195195*lm^2)/2 - (415486511340451*Pi^2)/136080 + 
           (1280788456677348367*Im[PolyLog[2, (-1)^(1/3)]])/
            (575319426165*Sqrt[3]) - 260260*Zeta[3]) + 
         CA*NC*(21744976338195038708803835100135462019/
            2694388723519065840435168000 + (113787502673*lm)/272160 + 
           (715715*lm^2)/12 + (415494062346067*Pi^2)/272160 - 
           (1280788456677348367*Im[PolyLog[2, (-1)^(1/3)]])/
            (1150638852330*Sqrt[3]) + 130130*Zeta[3])), 
      (-5043610939351583776239505274577563601229502647*CF^2*NC)/
        19354638299136753984792303273431040000 + (242558230709*CF^2*lm*NC)/
        18817920 + (221949*CF^2*lm^2*NC)/8 + 
       (134468424319951177475151032317027981*CF*NM*NC)/
        3406207123667630450488320 + (155545344749*CF*lm*NM*NC)/169361280 + 
       (24661*CF*lm^2*NM*NC)/8 - (19731446187396968743*CF*NC*NL)/
        71887512312000 + (155545344749*CF*lm*NC*NL)/169361280 + 
       (24661*CF*lm^2*NC*NL)/8 - 
       (459176231420584359688604348285207631374209769*CF*NC*NH)/
        68827126644219067332166559673072000000 + (155545344749*CF*lm*NC*NH)/
        169361280 + (24661*CF*lm^2*NC*NH)/8 - 
       (66814233680205397259*CF^2*NC*Pi^2)/1164452889600 - 
       (8281*CF^2*lm*NC*Pi^2)/36 - (64215241342772507*CF*NM*NC*Pi^2)/
        4490640 - (8281*CF*lm*NM*NC*Pi^2)/324 + (545465284*CF*NC*NL*Pi^2)/
        40095 - (8281*CF*lm*NC*NL*Pi^2)/324 - (8281*CF*lm*NC*NH*Pi^2)/324 + 
       (1693408510043324412149*CF^2*NC*Pi^3)/(7157894172574464*Sqrt[3]) + 
       (669665970467998105*CF*NC*NH*Pi^3)/(753145430616*Sqrt[3]) + 
       (14974141*CF^2*NC*Pi^4)/2880 - (12832722640911672010931863*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(13778946282205843200*Sqrt[3]) - 
       (71914192696034033353*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (16108943932620*Sqrt[3]) + (6742463*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + (241915501434760630307*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27615332455920*Sqrt[3]) + 
       (38266626883885606*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) + (241915501434760630307*CF^2*NC*Pi*Log[3]^2)/
        (1325535957884160*Sqrt[3]) + (19133313441942803*CF*NC*NH*Pi*
         Log[3]^2)/(27894275208*Sqrt[3]) + 
       (CF*NC*(-23*CA*(-5631924282119644368187 + 26739846958115491200*lm) + 
          6*(23*CF*(-1880927266207741573433 + 7292685534031497600*lm) + 
            528*(115*(-179759235629668098319 + 306931209344760*lm)*NM + 
              2900207310*(14925543 + 12170540*lm)*NL + (10078719131691187 + 
                35297089074647400*lm)*NH)))*Log[x]^2)/381649434566400 + 
       (CF*NC*(-1347397595099*CA + 4715287054994*CF - 
          2640*(2087446249424*NM + 7910851*NL))*Log[x]^3)/106920 + 
       (381973980168555805665572*CF^2*NC*PolyGamma[2, 1])/114383962274805 - 
       (93871818151367*CF*NM*NC*PolyGamma[2, 1])/3240 + 
       (3602341710900751883*CF*NC*NH*PolyGamma[2, 1])/10167463313316 + 
       CA*CF*NC*(5055641553911233595490735429580934995797495211/
          38709276598273507969584606546862080000 - (271271*lm^2)/16 + 
         (100748443968547637*Pi^2)/3512678400 - (1693408510043324412149*Pi^3)/
          (14315788345148928*Sqrt[3]) - (135827237*Pi^4)/51840 + 
         lm*(-820007382989/30792960 + (91091*Pi^2)/648) + 
         (12832722640911672010931863*Im[PolyLog[2, (-1)^(1/3)]])/
          (27557892564411686400*Sqrt[3]) - 
         (6742463*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 - 
         (241915501434760630307*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55230664911840*Sqrt[3]) - (241915501434760630307*Pi*Log[3]^2)/
          (2651071915768320*Sqrt[3]) - (190986990084277902832786*
           PolyGamma[2, 1])/114383962274805 - (268258272593335382767978081*
           Zeta[3])/80526309441462720) + (268238382859969110054286201*CF^2*NC*
         Zeta[3])/40263154720731360 - (52125640602647*CF*NM*NC*Zeta[3])/
        1620 + (8664422*CF*NC*NL*Zeta[3])/27 - 
       (3913810060875753793*CF*NC*NH*Zeta[3])/5083731656658 + 
       CF*Log[x]*((-5806829351840325333202892351*NM*NC)/91449634485409200 + 
         (8518228537*lm*NM*NC)/106920 + (41405*lm^2*NM*NC)/3 + 
         (10498750621326241*NC*NL)/20746756800 + (8518228537*lm*NC*NL)/
          106920 + (41405*lm^2*NC*NL)/3 + 
         (6276847572141606354909935886420529*NC*NH)/
          964104190166115956162205000 + (8518228537*lm*NC*NH)/106920 + 
         (41405*lm^2*NC*NH)/3 - (2087435926813*NM*NC*Pi^2)/162 + 
         (8656141*NC*NL*Pi^2)/162 - (38266626883885606*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3486784401*Sqrt[3]) + 
         CA*NC*(2242385921408154991636365087260208653/
            2771371258476753435876172800 - (10396359337*lm)/19440 - 
           (455455*lm^2)/6 - (6005569335461*Pi^2)/1710720 + 
           (241915501434760630307*Im[PolyLog[2, (-1)^(1/3)]])/
            (165691994735520*Sqrt[3]) - 165620*Zeta[3]) + 
         CF*NC*(-11221758735327219562204166070090868297/
            6928428146191883589690432000 + (8764174237*lm)/11880 + 
           124215*lm^2 + (5942967503861*Pi^2)/855360 - 
           (241915501434760630307*Im[PolyLog[2, (-1)^(1/3)]])/
            (82845997367760*Sqrt[3]) + 331240*Zeta[3])), 
      (12686191140252724210375424000376192956128490486221339*CF^2*NC)/
        145778214019655214977551590526755287040000 - 
       (47680404166061*CF^2*lm*NC)/3180228480 - (66087*CF^2*lm^2*NC)/2 - 
       (4092467087630619442933386016254889608809*CF*NM*NC)/
        148011864548800213182469248000 - (30166090869581*CF*lm*NM*NC)/
        28622056320 - (7343*CF*lm^2*NM*NC)/2 + 
       (65767547626745793107*CF*NC*NL)/186907532011200 - 
       (30166090869581*CF*lm*NC*NL)/28622056320 - (7343*CF*lm^2*NC*NL)/2 + 
       (3987283521490495685488698714444014092775449553*CF*NC*NH)/
        477856907844149524620470685730185600000 - 
       (30166090869581*CF*lm*NC*NH)/28622056320 - (7343*CF*lm^2*NC*NH)/2 - 
       (1475134831977668200204993*CF^2*NC*Pi^2)/45413662694400 + 
       (9457*CF^2*lm*NC*Pi^2)/36 + (74355217985806919*CF*NM*NC*Pi^2)/
        8339760 + (9457*CF*lm*NM*NC*Pi^2)/324 - (13966078441*CF*NC*NL*Pi^2)/
        833976 + (9457*CF*lm*NC*NL*Pi^2)/324 + (9457*CF*lm*NC*NH*Pi^2)/
        324 - (9231191981009806754065*CF^2*NC*Pi^3)/(31017541414489344*
         Sqrt[3]) - (22695288730715726545*CF*NC*NH*Pi^3)/
        (20334926626632*Sqrt[3]) - (55746677*CF^2*NC*Pi^4)/8640 + 
       (35750460633553577873163575*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (31048558955903833344*Sqrt[3]) + (635519907729329772331*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(111842096446476*Sqrt[3]) - 
       (8288525*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (263748342314565907259*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (23933288128464*Sqrt[3]) - (1296873641755184374*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (263748342314565907259*CF^2*NC*Pi*Log[3]^2)/(1148797830166272*
         Sqrt[3]) - (648436820877592187*CF*NC*NH*Pi*Log[3]^2)/
        (753145430616*Sqrt[3]) - 
       (CF*NC*(-11*CA*(17581485468712993857481147 + 185018499264489770880*
             lm) + 6*(CF*(64465165752540309385236995 + 555055497793469312640*
               lm) + 144144*(13*(-9442410811323176341 + 32911977492680*lm)*
               NM + 27621022*(18908179 + 15490220*lm)*NL + 
              (125214113147771 + 427855707404840*lm)*NH)))*Log[x]^2)/
        992288529872640 + (CF*NC*(80342512331793509*CA + 
          26*(-6181516294929763*CF + 1320*(1366947945956*NM + 
              10068643*NL)))*Log[x]^3)/1389960 - 
       (26532467308684603931636689*CF^2*NC*PolyGamma[2, 1])/610047798798960 + 
       (68401133339497*CF*NM*NC*PolyGamma[2, 1])/1620 - 
       (102828795476350951453*CF*NC*NH*PolyGamma[2, 1])/228767924549610 - 
       (5090720836730112664272229769*CF^2*NC*Zeta[3])/174473670456502560 + 
       (54733388235757*CF*NM*NC*Zeta[3])/810 - (10995380*CF*NC*NL*Zeta[3])/
        27 + (107956323639462018317*CF*NC*NH*Zeta[3])/114383962274805 + 
       CA*CF*NC*(-88804133030860246991024285590713279484863929579510959/
          2040894996275173009685722267374574018560000 + (80773*lm^2)/4 + 
         (86772688906699095317117*Pi^2)/5342783846400 + 
         (9231191981009806754065*Pi^3)/(62035082828978688*Sqrt[3]) + 
         (168450527*Pi^4)/51840 + lm*(163911756042701/5204010240 - 
           (104027*Pi^2)/648) - (35750460633553577873163575*
           Im[PolyLog[2, (-1)^(1/3)]])/(62097117911807666688*Sqrt[3]) + 
         (8288525*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (263748342314565907259*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (47866576256928*Sqrt[3]) + (263748342314565907259*Pi*Log[3]^2)/
          (2297595660332544*Sqrt[3]) + (26532467308684603931636689*
           PolyGamma[2, 1])/1220095597597920 + (5090829917194249066153107953*
           Zeta[3])/348947340913005120) + CF*Log[x]*
        ((415061086922960783028150086017*NM*NC)/13821959040794704800 - 
         (136216490557*lm*NM*NC)/1389960 - (50960*lm^2*NM*NC)/3 - 
         (13321108004295127*NC*NL)/20746756800 - (136216490557*lm*NC*NL)/
          1389960 - (50960*lm^2*NC*NL)/3 - 
         (24311194815963747821536290417830213*NC*NH)/
          2974950072512586379014804000 - (136216490557*lm*NC*NH)/1389960 - 
         (50960*lm^2*NC*NH)/3 + (1366934692963*NM*NC*Pi^2)/162 - 
         (10985923*NC*NL*Pi^2)/162 + (1296873641755184374*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(-2426940383505768681471134228693932503226969/
            15882266787120527815433700288000 - (140151621757*lm)/154440 - 
           152880*lm^2 - (321379230026106827*Pi^2)/11119680 + 
           (263748342314565907259*Im[PolyLog[2, (-1)^(1/3)]])/
            (71799864385392*Sqrt[3]) - 407680*Zeta[3]) + 
         CA*NC*(1213484293251180644323143136252472483429639/
            15882266787120527815433700288000 + (166266583357*lm)/252720 + 
           (280280*lm^2)/3 + (64276053446077159*Pi^2)/4447872 - 
           (263748342314565907259*Im[PolyLog[2, (-1)^(1/3)]])/
            (143599728770784*Sqrt[3]) + 203840*Zeta[3])), 
      (6702465829583327746259453271890021262177148069477991*CF^2*NC)/
        5510416489942967126151450121911349850112000 + 
       (1304469025369*CF^2*lm*NC)/70671744 + (317695*CF^2*lm^2*NC)/8 + 
       (2792339876008557807063278927699407215269*CF*NM*NC)/
        7674689272900751794646553600 + (836717781409*CF*lm*NM*NC)/
        636045696 + (317695*CF*lm^2*NM*NC)/72 - 
       (499670706786267745507*CF*NC*NL)/1079910184953600 + 
       (836717781409*CF*lm*NC*NL)/636045696 + (317695*CF*lm^2*NC*NL)/72 - 
       (546932820471529999966275594058069687616395578661*CF*NC*NH)/
        50174975323635700085149422001669488000000 + 
       (836717781409*CF*lm*NC*NH)/636045696 + (317695*CF*lm^2*NC*NH)/72 - 
       (44781197464726597010119*CF^2*NC*Pi^2)/27248197616640 - 
       (1225*CF^2*lm*NC*Pi^2)/4 - (171495729125024119*CF*NM*NC*Pi^2)/
        1297296 - (1225*CF*lm*NM*NC*Pi^2)/36 + (242487077*CF*NC*NL*Pi^2)/
        11583 - (1225*CF*lm*NC*NL*Pi^2)/36 - (1225*CF*lm*NC*NH*Pi^2)/36 + 
       (320329736720550353991005*CF^2*NC*Pi^3)/(837473618191212288*Sqrt[3]) + 
       (89196434062039508155*CF*NC*NH*Pi^3)/(61004779879896*Sqrt[3]) + 
       (42004333*CF^2*NC*Pi^4)/5184 - (1292810689773273073031074291*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(838311091809403500288*Sqrt[3]) - 
       (86392110090725853936197*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (11743420126879980*Sqrt[3]) + (10285555*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + (9152278192015724399743*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(646198779468528*Sqrt[3]) + 
       (5096939089259400466*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) + (9152278192015724399743*CF^2*NC*Pi*Log[3]^2)/
        (31017541414489344*Sqrt[3]) + (2548469544629700233*CF*NC*NH*Pi*
         Log[3]^2)/(2259436291848*Sqrt[3]) + 
       CF*((-150427303961480485011665*CF*NC)/7632988691328 + 
         CA*(279333918674819534180339/28351100853504 - (5348915*lm)/2)*NC + 
         4376385*CF*lm*NC - (2548081984697540486947*NM*NC)/1606268664 + 
         486265*lm*NM*NC + (2370797*NC*NL)/4 + 486265*lm*NC*NL + 
         (17595985709174347*NC*NH)/120470149800 + 486265*lm*NC*NH)*
        Log[x]^2 - (5*CF*NC*(-114526870371785*CA + 227194458921478*CF + 
          185328*(142656955236*NM + 97253*NL))*Log[x]^3)/277992 + 
       (60978565682575281694689791*CF^2*NC*PolyGamma[2, 1])/
        2058911320946490 - (95286100811069*CF*NM*NC*PolyGamma[2, 1])/360 + 
       (87506779992170855969*CF*NC*NH*PolyGamma[2, 1])/152511949699740 + 
       CA*CF*NC*(-6697030485041968696507547851976684456381276302775537/
          11020832979885934252302900243822699700224000 - (3494645*lm^2)/144 + 
         (8956106644319740982759*Pi^2)/10899279046656 - 
         (320329736720550353991005*Pi^3)/(1674947236382424576*Sqrt[3]) - 
         (42286573*Pi^4)/10368 + lm*(-4408636371649/115644672 + 
           (13475*Pi^2)/72) + (1292810689773273073031074291*
           Im[PolyLog[2, (-1)^(1/3)]])/(1676622183618807000576*Sqrt[3]) - 
         (10285555*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 - 
         (9152278192015724399743*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1292397558937056*Sqrt[3]) - (9152278192015724399743*Pi*Log[3]^2)/
          (62035082828978688*Sqrt[3]) - (60978565682575281694689791*
           PolyGamma[2, 1])/4117822641892980 - 
         (288713667237182725759639209281*Zeta[3])/9421578204651138240) + 
       (288709891988027308053972857201*CF^2*NC*Zeta[3])/4710789102325569120 - 
       (52489520148869*CF*NM*NC*Zeta[3])/180 + 529140*CF*NC*NL*Zeta[3] - 
       (101884338451046106331*CF*NC*NH*Zeta[3])/76255974849870 + 
       CF*Log[x]*((-1272638646477104476857778573339*NM*NC)/
          2150082517456954080 + (3803826341*lm*NM*NC)/30888 + 
         (63700*lm^2*NM*NC)/3 + (5010802291155439*NC*NL)/5993507520 + 
         (3803826341*lm*NC*NL)/30888 + (63700*lm^2*NC*NL)/3 + 
         (3342958329627674197125786822583361581*NC*NH)/
          312369757613821569796554420000 + (3803826341*lm*NC*NH)/30888 + 
         (63700*lm^2*NC*NH)/3 - (2139852532915*NM*NC*Pi^2)/18 + 
         (1586195*NC*NL*Pi^2)/18 - (5096939089259400466*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CA*NC*(34936626484392970926174036212822081505937/
            3898374575020493191060999161600 - (4638551141*lm)/5616 - 
           (350350*lm^2)/3 + (2287868570867527*Pi^2)/4447872 + 
           (9152278192015724399743*Im[PolyLog[2, (-1)^(1/3)]])/
            (3877192676811168*Sqrt[3]) - 254800*Zeta[3]) + 
         CF*NC*(-1537405712795651332758043198236356890801019/
            85764240650450850203341981555200 + (3913135541*lm)/3432 + 
           191100*lm^2 - (2288136661818655*Pi^2)/2223936 - 
           (9152278192015724399743*Im[PolyLog[2, (-1)^(1/3)]])/
            (1938596338405584*Sqrt[3]) + 509600*Zeta[3])), 
      (1325422627956413081041454106951092145624441479024261081933*CF^2*NC)/
        1607204809566698745127506285557477039616000000 - 
       (49143054847309*CF^2*lm*NC)/2308610304 - (748145*CF^2*lm^2*NC)/16 - 
       (508152941715479160651244065308541939698071*CF*NM*NC)/
        2213852674875216863840352000000 - (31151645931829*CF*lm*NM*NC)/
        20777492736 - (748145*CF*lm^2*NM*NC)/144 + 
       (40397915932108918243*CF*NC*NL)/69225011856000 - 
       (31151645931829*CF*lm*NC*NL)/20777492736 - (748145*CF*lm^2*NC*NL)/
        144 + (12151935347397593527339536565265884323142858548487*CF*NC*NH)/
        903149555825442601532689596030050784000000 - 
       (31151645931829*CF*lm*NC*NH)/20777492736 - (748145*CF*lm^2*NC*NH)/
        144 - (9769984700634361447928599*CF^2*NC*Pi^2)/31789563886080 + 
       (2775*CF^2*lm*NC*Pi^2)/8 + (192955489064862947*CF*NM*NC*Pi^2)/
        2594592 + (925*CF*lm*NM*NC*Pi^2)/24 - (10994163655*CF*NC*NL*Pi^2)/
        432432 + (925*CF*lm*NC*NL*Pi^2)/24 + (925*CF*lm*NC*NH*Pi^2)/24 - 
       (33075948389182217888315*CF^2*NC*Pi^3)/(69789468182601024*Sqrt[3]) - 
       (1988149465244120718085*CF*NC*NH*Pi^3)/(1098086037838128*Sqrt[3]) - 
       (2140547*CF^2*NC*Pi^4)/216 + (922853601200291482584156127*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(489014803555485375168*Sqrt[3]) + 
       (1949453118237442669603529*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (211381562283839640*Sqrt[3]) - 1039690*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (6615189677836443577663*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(376949288023308*Sqrt[3]) - 
       (56804270435546306231*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (847288609443*Sqrt[3]) - (6615189677836443577663*CF^2*NC*Pi*Log[3]^2)/
        (18093565825118784*Sqrt[3]) - (56804270435546306231*CF*NC*NH*Pi*
         Log[3]^2)/(40669853253264*Sqrt[3]) - 
       (CF*NC*(-91*CA*(58647071301983983761931411 + 106593115420821229200*
             lm) + 4*(8*CF*(333554965280586338870648266 + 
              496021372327571515425*lm) + 3003*(3*(-71673220389844025361707 + 
                48940824343811400*lm)*NM + 43503109650*(4096861 + 
                3374988*lm)*NL + (45069282624159161 + 146822473031434200*lm)*
               NH)))*Log[x]^2)/2894174878795200 + 
       (CF*NC*(354851442737806571*CA + 28*(-25347529099288975*CF + 
            2574*(2524496067854*NM + 3656237*NL)))*Log[x]^3)/648648 - 
       (4427608477251211220169276457*CF^2*NC*PolyGamma[2, 1])/
        10980860378381280 + (272663433602573*CF*NM*NC*PolyGamma[2, 1])/720 - 
       (17711658269996252918693*CF*NC*NH*PolyGamma[2, 1])/
        24706935851357880 - (1425373189528318466239403823437*CF^2*NC*Zeta[3])/
        5495920619379830640 + (222174770691413*CF*NM*NC*Zeta[3])/360 - 
       661402*CF*NC*NL*Zeta[3] + (20055494270106395727007*CF*NC*NH*Zeta[3])/
        12353467925678940 + CA*CF*NC*
        (-1325424589840118375187058416057228823223826583350058745933/
          3214409619133397490255012571114954079232000000 + 
         (8229595*lm^2)/288 + (9769985654622218440258759*Pi^2)/
          63579127772160 + (33075948389182217888315*Pi^3)/
          (139578936365202048*Sqrt[3]) + (2153867*Pi^4)/432 + 
         lm*(168540586740949/3777725952 - (10175*Pi^2)/48) - 
         (922853601200291482584156127*Im[PolyLog[2, (-1)^(1/3)]])/
          (978029607110970750336*Sqrt[3]) + 519845*Im[PolyLog[2, (-1)^(1/3)]]^
           2 + (6615189677836443577663*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (753898576046616*Sqrt[3]) + (6615189677836443577663*Pi*Log[3]^2)/
          (36187131650237568*Sqrt[3]) + (4427608477251211220169276457*
           PolyGamma[2, 1])/21961720756762560 + 
         (1425378683854662873064944618617*Zeta[3])/10991841238759661280) + 
       CF*Log[x]*((34354468723267258936024815061481*NM*NC)/
          134380157341059630000 - (21545429855*lm*NM*NC)/144144 - 
         (77350*lm^2*NM*NC)/3 - (1605911927916283*NC*NL)/1536796800 - 
         (21545429855*lm*NC*NL)/144144 - (77350*lm^2*NC*NL)/3 - 
         (74510430182504794245429319269801831127*NC*NH)/
          5622655637048788256337979560000 - (21545429855*lm*NC*NH)/144144 - 
         (77350*lm^2*NC*NH)/3 + (2524491535573*NM*NC*Pi^2)/36 - 
         (1321879*NC*NL*Pi^2)/12 + (56804270435546306231*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(-14441250345186966287081452209490912697112901493/
            10005828075885932523723231181440000 - (22164848655*lm)/16016 - 
           232050*lm^2 - (354853201852773629*Pi^2)/1297296 + 
           (6615189677836443577663*Im[PolyLog[2, (-1)^(1/3)]])/
            (1130847864069924*Sqrt[3]) - 618800*Zeta[3]) + 
         CA*NC*(1312843482045434619128959591213543529278893013/
            1819241468342896822495132942080000 + (26275537055*lm)/26208 + 
           (425425*lm^2)/3 + (354853398067760597*Pi^2)/2594592 - 
           (6615189677836443577663*Im[PolyLog[2, (-1)^(1/3)]])/
            (2261695728139848*Sqrt[3]) + 309400*Zeta[3])), 
      (1551369372519203835480195231242244494772401794405423001*CF^2*NC)/
        39306639364402958440618360244612210208000000 + 
       (5581400094451*CF^2*lm*NC)/216432216 + 55490*CF^2*lm^2*NC + 
       (4504863526362593323244619073658938471733*CF*NM*NC)/
        1338359596976275075796343750 + (3579762816811*CF*lm*NM*NC)/
        1947889944 + (55490*CF*lm^2*NM*NC)/9 - 
       (5281609710133287660299*CF*NC*NL)/7019416202198400 + 
       (3579762816811*CF*lm*NC*NL)/1947889944 + (55490*CF*lm^2*NC*NL)/9 - 
       (1583860317309673975471964107554105476442193643020789*CF*NC*NH)/
        91778810487611331703253193989903785712400000 + 
       (3579762816811*CF*lm*NC*NH)/1947889944 + (55490*CF*lm^2*NC*NH)/9 - 
       (494154553779649240923551*CF^2*NC*Pi^2)/20590967517120 - 
       400*CF^2*lm*NC*Pi^2 - (33112157162351243*CF*NM*NC*Pi^2)/27027 - 
       (400*CF*lm*NM*NC*Pi^2)/9 + (2537334551*CF*NC*NL*Pi^2)/81081 - 
       (400*CF*lm*NC*NL*Pi^2)/9 - (400*CF*lm*NC*NH*Pi^2)/9 + 
       (903704989375541034535*CF^2*NC*Pi^3)/(1509868302027426*Sqrt[3]) + 
       (53253019974110790400*CF*NC*NH*Pi^3)/(22876792454961*Sqrt[3]) + 
       (991852*CF^2*NC*Pi^4)/81 - (29886937077056684585217703*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12091025362635627408*Sqrt[3]) - 
       (269053043842145304259604*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (22899669247415961*Sqrt[3]) + 
       (3814720*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (206561140428695093608*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9320174703873*Sqrt[3]) + (24344237702450647040*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (25820142553586886701*CF^2*NC*Pi*Log[3]^2)/(55921048223238*Sqrt[3]) + 
       (1521514856403165440*CF*NC*NH*Pi*Log[3]^2)/(847288609443*Sqrt[3]) + 
       CF*((-6794098624286525279063243*CF*NC)/23593816946700 + 
         CA*(6794015003401021168943213/47187633893400 - 4289340*lm)*NC + 
         7018920*CF*lm*NC - (958403338573817292634*NM*NC)/65189475 + 
         779880*lm*NM*NC + 945550*NC*NL + 779880*lm*NC*NL + 
         (1645146159143747*NC*NH)/6718527585 + 779880*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-8774379552308333*CA + 2*(8767450926423107*CF + 
            130378248*(4106327919*NM + 485*NL)))*Log[x]^3)/243243 + 
       (90119488521764396084837846*CF^2*NC*PolyGamma[2, 1])/343151886824415 - 
       (217574875727111*CF*NM*NC*PolyGamma[2, 1])/90 + 
       (1854539510049753604639*CF*NC*NH*PolyGamma[2, 1])/2058911320946490 + 
       CA*CF*NC*(-110807818102899793887794263343962237639020116066719009/
          5615234194914708348659765749230315744000000 - (305195*lm^2)/9 + 
         (26008094162494335622727*Pi^2)/2167470264960 - 
         (903704989375541034535*Pi^3)/(3019736604054852*Sqrt[3]) - 
         (498806*Pi^4)/81 + lm*(-18864992936971/354161808 + (2200*Pi^2)/9) + 
         (29886937077056684585217703*Im[PolyLog[2, (-1)^(1/3)]])/
          (24182050725271254816*Sqrt[3]) - 
         (1907360*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (103280570214347546804*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9320174703873*Sqrt[3]) - (25820142553586886701*Pi*Log[3]^2)/
          (111842096446476*Sqrt[3]) - (45059744260882198042418923*
           PolyGamma[2, 1])/343151886824415 - (96403331290407991234766837506*
           Zeta[3])/343495038711239415) + (192806229413763953697616553747*
         CF^2*NC*Zeta[3])/343495038711239415 - 
       (118530448786631*CF*NM*NC*Zeta[3])/45 + 843880*CF*NC*NL*Zeta[3] - 
       (2283469613505483981761*CF*NC*NH*Zeta[3])/1029455660473245 + 
       CF*Log[x]*((-4809738577585570937389951098451*NM*NC)/
          872598424292595000 + (4994933446*lm*NM*NC)/27027 + 
         (95200*lm^2*NM*NC)/3 + (26017970068560181*NC*NL)/19478899440 + 
         (4994933446*lm*NC*NL)/27027 + (95200*lm^2*NC*NL)/3 + 
         (1386687261537399300813579328369391383*NC*NH)/
          81416208518561138491395330750 + (4994933446*lm*NC*NH)/27027 + 
         (95200*lm^2*NC*NH)/3 - (9904461579328*NM*NC*Pi^2)/9 + 
         (1265020*NC*NL*Pi^2)/9 - (24344237702450647040*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(46838709724824947521742452940074737963151871/
            489415503711811916921245003440000 - (3043248323*lm)/2457 - 
           (523600*lm^2)/3 + (4386720002080699*Pi^2)/486486 + 
           (103280570214347546804*Im[PolyLog[2, (-1)^(1/3)]])/
            (27960524111619*Sqrt[3]) - 380800*Zeta[3]) + 
         CF*NC*(-46839567097545519290917950368464114600109171/
            244707751855905958460622501720000 + (5137876246*lm)/3003 + 
           285600*lm^2 - (4386766721613559*Pi^2)/243243 - 
           (206561140428695093608*Im[PolyLog[2, (-1)^(1/3)]])/
            (27960524111619*Sqrt[3]) + 761600*Zeta[3])), 
      (10084528854070431387217515035227111529047735019975981223017*CF^2*NC)/
        1291503864830382920191746122322972621120000000 - 
       (130656496630637*CF^2*lm*NC)/4427022600 - 64684*CF^2*lm^2*NC - 
       (83822580820621263547196094000535501129092601*CF*NM*NC)/
        43709753749567562955447949800000 - (82930241654237*CF*lm*NM*NC)/
        39843203400 - (64684*CF*lm^2*NM*NC)/9 + 
       (295502370294893956341097*CF*NC*NL)/315873729098928000 - 
       (82930241654237*CF*lm*NC*NL)/39843203400 - (64684*CF*lm^2*NC*NL)/9 + 
       (26085792465132777805646069914514571669846290380512983*CF*NC*NH)/
        1239013941582752977993918118863701107117400000 - 
       (82930241654237*CF*lm*NC*NH)/39843203400 - (64684*CF*lm^2*NC*NH)/9 - 
       (3289346856677270641404565207*CF^2*NC*Pi^2)/1132503213441600 + 
       (4048*CF^2*lm*NC*Pi^2)/9 + (151637334188928691*CF*NM*NC*Pi^2)/
        243243 + (4048*CF*lm*NM*NC*Pi^2)/81 - (12457356167*CF*NC*NL*Pi^2)/
        331695 + (4048*CF*lm*NC*NL*Pi^2)/81 + (4048*CF*lm*NC*NH*Pi^2)/81 - 
       (10447424537607119902285*CF^2*NC*Pi^3)/(14275118491895664*Sqrt[3]) - 
       (1759198204573732362160*CF*NC*NH*Pi^3)/(617673396283947*Sqrt[3]) - 
       (2395541*CF^2*NC*Pi^4)/162 + (3745792441907227059729354937*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1250321940908911470600*Sqrt[3]) + 
       (1283698592251992460641764*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (88327295668604421*Sqrt[3]) - 1524424*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (2089484907521423980457*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(77103263459313*Sqrt[3]) - 
       (804204893519420508416*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (2089484907521423980457*CF^2*NC*Pi*Log[3]^2)/(3700956646047024*
         Sqrt[3]) - (50262805844963781776*CF*NC*NH*Pi*Log[3]^2)/
        (22876792454961*Sqrt[3]) - 
       (CF*NC*(-203*CA*(27019659739466718396886656691 + 
            8221159854724897080000*lm) + 
          8*(8497*CF*(161380199694711296146993921 + 40174765036275870000*
               lm) + 100100*(58*(-50693106528916446855289 + 6533025949399950*
                 lm)*NM + 5822723907*(78613091 + 65075300*lm)*NL + 
              4*(30322445295100862 + 94728876266299275*lm)*NH)))*Log[x]^2)/
        314741518068978000 + (2*CF*NC*(3145595661590132640*CA - 
          6291235265036978287*CF + 120120*(11875060067699*NM + 3253765*NL))*
         Log[x]^3)/1216215 - (1537978257957045776874788345*CF^2*NC*
         PolyGamma[2, 1])/411782264189298 + (458529519825247*CF*NM*NC*
         PolyGamma[2, 1])/135 - (30863021059293838729193*CF*NC*NH*
         PolyGamma[2, 1])/27795302832777615 - 
       (182085579165068285925124178081*CF^2*NC*Zeta[3])/79268085856439865 + 
       (758725651004414*CF*NM*NC*Zeta[3])/135 - (9367544*CF*NC*NL*Zeta[3])/
        9 + (74264468644327932833774*CF*NC*NH*Zeta[3])/27795302832777615 + 
       CA*CF*NC*(-17647929709988236993734112040498076229516591523507800321811/
          4520263526906340220671111428130404173920000000 + (355762*lm^2)/9 + 
         (86561760729518826603246653*Pi^2)/59605432286400 + 
         (10447424537607119902285*Pi^3)/(28550236983791328*Sqrt[3]) + 
         (12042473*Pi^4)/1620 + lm*(447385279655837/7244218800 - 
           (22264*Pi^2)/81) - (3745792441907227059729354937*
           Im[PolyLog[2, (-1)^(1/3)]])/(2500643881817822941200*Sqrt[3]) + 
         762212*Im[PolyLog[2, (-1)^(1/3)]]^2 + (2089484907521423980457*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(154206526918626*Sqrt[3]) + 
         (2089484907521423980457*Pi*Log[3]^2)/(7401913292094048*Sqrt[3]) + 
         (1537978257957045776874788345*PolyGamma[2, 1])/823564528378596 + 
         (364171404548761933444588457809*Zeta[3])/317072343425759460) + 
       CF*Log[x]*((2364155811992050485296525871565609*NM*NC)/
          1088479274462583003000 - (24511659502*lm*NM*NC)/110565 - 
         38080*lm^2*NM*NC - (1444139414699623727*NC*NL)/876550474800 - 
         (24511659502*lm*NC*NL)/110565 - 38080*lm^2*NC*NL - 
         (22170290083083520009402851268071150300793*NC*NH)/
          1063947012920556957805554182241000 - (24511659502*lm*NC*NH)/
          110565 - 38080*lm^2*NC*NH + (47500225038496*NM*NC*Pi^2)/81 - 
         (14043220*NC*NL*Pi^2)/81 + (804204893519420508416*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-765670059156043723209714014920643549476817627999/
            56282782926858370445943175395600000 - (25213378702*lm)/12285 - 
           342720*lm^2 - (322625464809114763*Pi^2)/124740 + 
           (2089484907521423980457*Im[PolyLog[2, (-1)^(1/3)]])/
            (231309790377939*Sqrt[3]) - 913920*Zeta[3]) + 
         CA*NC*(191417574892728582021770727706852724453164610381/
            28141391463429185222971587697800000 + (164286333661*lm)/110565 + 
           209440*lm^2 + (322625494458705041*Pi^2)/249480 - 
           (2089484907521423980457*Im[PolyLog[2, (-1)^(1/3)]])/
            (462619580755878*Sqrt[3]) + 456960*Zeta[3])), 
      (71945326538851851845550392887573098336749961792291831459881*CF^2*NC)/
        122047115226471185958120008559520912695840000000 + 
       (1717311408006451*CF^2*lm*NC)/48697248600 + 75922*CF^2*lm^2*NC + 
       (13642207131718634960880799884207717306358958911*CF*NM*NC)/
        437097537495675629554479498000000 + (1101112656638251*CF*lm*NM*NC)/
        438275237400 + (75922*CF*lm^2*NM*NC)/9 - 
       (53508560093789671418497*CF*NC*NL)/45124818442704000 + 
       (1101112656638251*CF*lm*NC*NL)/438275237400 + (75922*CF*lm^2*NC*NL)/
        9 - (32695993493597493711859757122769755481656857295870140493*CF*NC*
         NH)/1230382144456393132247227155968950656071148780000 + 
       (1101112656638251*CF*lm*NC*NH)/438275237400 + (75922*CF*lm^2*NC*NH)/
        9 - (331618613842521111340212029*CF^2*NC*Pi^2)/1132503213441600 - 
       (4624*CF^2*lm*NC*Pi^2)/9 - (13829214635906342983*CF*NM*NC*Pi^2)/
        1216215 - (4624*CF*lm*NM*NC*Pi^2)/81 + (33281783099*CF*NC*NL*Pi^2)/
        729729 - (4624*CF*lm*NC*NL*Pi^2)/81 - (4624*CF*lm*NC*NH*Pi^2)/81 + 
       (241209884835722624800205*CF^2*NC*Pi^3)/(264981887005813263*Sqrt[3]) + 
       (741708406040928997160*CF*NC*NH*Pi^3)/(205891132094649*Sqrt[3]) + 
       (7296944*CF^2*NC*Pi^4)/405 - (2858959583518514609546223414427*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(742691232899893413536400*Sqrt[3]) - 
       (2687032730989954429736924*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (147212159447674035*Sqrt[3]) + 1840896*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 + (771871631474312399360656*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22899669247415961*Sqrt[3]) + 
       (339066699904424684416*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) + 
       (48241976967144524960041*CF^2*NC*Pi*Log[3]^2)/(68699007742247883*
         Sqrt[3]) + (21191668744026542776*CF*NC*NH*Pi*Log[3]^2)/
        (7625597484987*Sqrt[3]) + CF*((-9533941083809384993225634779*CF*NC)/
          2713288948870500 + CA*(733378923762810754959084673/
            417429069057000 - (180273236*lm)/27)*NC + (32776952*CF*lm*NC)/3 - 
         (18492702084680728909431821*NM*NC)/135528918525 + 
         (32776952*lm*NM*NC)/27 + (65926238*NC*NL)/45 + 
         (32776952*lm*NC*NL)/27 + (9658634080006640842*NC*NH)/
          24368099550795 + (32776952*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-571018743844140435*CA + 1141923321149780278*CF + 
          240240*(206695996576739*NM + 4097119*NL))*Log[x]^3)/1216215 + 
       (194143863203484484876036536962*CF^2*NC*PolyGamma[2, 1])/
        83385908498332845 - (1192081521027655*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (25496067981587626980353*CF*NC*NH*PolyGamma[2, 1])/
        18530201888518410 + CA*CF*NC*
        (-5138931837906749630883379525072958517259593587173448759929/
          17435302175210169422588572651360130385120000000 - (417571*lm^2)/9 + 
         (19506973623070743263522071*Pi^2)/133235672169600 - 
         (241209884835722624800205*Pi^3)/(529963774011626526*Sqrt[3]) - 
         (3666968*Pi^4)/405 + lm*(-5806630394359051/79686406800 + 
           (25432*Pi^2)/81) + (2858959583518514609546223414427*
           Im[PolyLog[2, (-1)^(1/3)]])/(1485382465799786827072800*Sqrt[3]) - 
         920448*Im[PolyLog[2, (-1)^(1/3)]]^2 - (385935815737156199680328*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22899669247415961*
           Sqrt[3]) - (48241976967144524960041*Pi*Log[3]^2)/
          (137398015484495766*Sqrt[3]) - (97071931601742242438018268481*
           PolyGamma[2, 1])/83385908498332845 - 
         (213932003880837459324747002032732*Zeta[3])/83469294406831177845) + 
       (427863846533943317618915380418957*CF^2*NC*Zeta[3])/
        83469294406831177845 - (640892385514087*CF*NM*NC*Zeta[3])/27 + 
       (11764136*CF*NC*NL*Zeta[3])/9 - (32877585502853239323007*CF*NC*NH*
         Zeta[3])/9265100944259205 + CF*Log[x]*
        ((-34893972454602124640918233827503089*NM*NC)/
          680299546539114376875 + (328730483726*lm*NM*NC)/1216215 + 
         46240*lm^2*NM*NC + (1816487372208657569*NC*NL)/876550474800 + 
         (328730483726*lm*NC*NL)/1216215 + 46240*lm^2*NC*NL + 
         (256572950515601530595279773922355640969531*NC*NH)/
          9737648375396716537629881610796200 + (328730483726*lm*NC*NH)/
          1216215 + 46240*lm^2*NC*NH - (826783968239968*NM*NC*Pi^2)/81 + 
         (17636956*NC*NL*Pi^2)/81 - (339066699904424684416*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CA*NC*(137442932536638497215917103702039330088674011541/
            138148649002288727458224157789200000 - (200152921063*lm)/110565 - 
           254320*lm^2 + (95168568314865107*Pi^2)/810810 + 
           (385935815737156199680328*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) - 554880*Zeta[3]) + 
         CF*NC*(-215982324252146325272535080370090271248001343993/
            108545367073226857288604695405800000 + (338103447326*lm)/135135 + 
           416160*lm^2 - (6344579255021545*Pi^2)/27027 - 
           (771871631474312399360656*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) + 1109760*Zeta[3])), 
      (18532818998885465652059962442543455076943122931217756293315901393*CF^2*
         NC)/250991902461841855437794056496076356447016960000000 - 
       (1747142543252461*CF^2*lm*NC)/43589145600 - (1403503*CF^2*lm^2*NC)/
        16 - (111688901590702221546968737109044778392806692627*CF*NM*NC)/
        6939746195924730908776288167936000 - (1109876953491661*CF*lm*NM*NC)/
        392302310400 - (1403503*CF*lm^2*NM*NC)/144 + 
       (919669131899875144244381*CF*NC*NL)/631747458197856000 - 
       (1109876953491661*CF*lm*NC*NL)/392302310400 - 
       (1403503*CF*lm^2*NC*NL)/144 + 
       (181890358003261065668786055089809284698005080410595644461909*CF*NC*
         NH)/5669600921655059553395222734704924623175853578240000 - 
       (1109876953491661*CF*lm*NC*NH)/392302310400 - 
       (1403503*CF*lm^2*NC*NH)/144 - (993365116480132405701484005221*CF^2*NC*
         Pi^2)/36240102830131200 + (41327*CF^2*lm*NC*Pi^2)/72 + 
       (708525847418344058*CF*NM*NC*Pi^2)/135135 + (41327*CF*lm*NM*NC*Pi^2)/
        648 - (88449260951*CF*NC*NL*Pi^2)/1632960 + 
       (41327*CF*lm*NC*NL*Pi^2)/648 + (41327*CF*lm*NC*NH*Pi^2)/648 - 
       (24875870502084695240737375*CF^2*NC*Pi^3)/(22611787691162731776*
         Sqrt[3]) - (32320392336216871341175*CF*NC*NH*Pi^3)/
        (7412080755407364*Sqrt[3]) - (278842177*CF^2*NC*Pi^4)/12960 + 
       (36631047427057003335508017504553*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (7922039817598863077721600*Sqrt[3]) + 
       (127342914736448407982970707*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5707302181663670280*Sqrt[3]) - 
       (4368337*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (4975174100416939048147475*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(122131569319551792*
         Sqrt[3]) - (3693759124139071010420*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (4975174100416939048147475*CF^2*NC*Pi*Log[3]^2)/(5862315327338486016*
         Sqrt[3]) - (923439781034767752605*CF*NC*NH*Pi*Log[3]^2)/
        (274521509459532*Sqrt[3]) + 
       CF*((-72018980219615639499963406391401*CF*NC)/218950621265376000 - 
         (40031498*CF*lm*NC)/3 + CA*(72018981725065188851303569855151/
            437901242530752000 + (220173239*lm)/27)*NC + 
         (1582628651853716259676797811*NM*NC)/25154167278240 - 
         (40031498*lm*NM*NC)/27 - (481544431*NC*NL)/270 - 
         (40031498*lm*NC*NL)/27 - (384059806130352254993*NC*NH)/
          779779185625440 - (40031498*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(86413475282014517445*CA + 4*(-43206789603065849041*CF + 
            10920*(797744029208389*NM + 40031498*NL)))*Log[x]^3)/1769040 - 
       (6149414777551298811486255085051*CF^2*NC*PolyGamma[2, 1])/
        177889938129776736 + (32899617912693533*CF*NM*NC*PolyGamma[2, 1])/
        1080 - (248466290651040181864373*CF*NC*NH*PolyGamma[2, 1])/
        148241615108147280 - (18064634440639043091188512659981059*CF^2*NC*
         Zeta[3])/890339140339532563680 + (27581328963562163*CF*NM*NC*
         Zeta[3])/540 - (28678201*CF*NC*NL*Zeta[3])/18 + 
       (314194383300982772369107*CF*NC*NH*Zeta[3])/74120807554073640 + 
       CA*CF*NC*
        (-18532819698210592351756923295300111803266647025882991126726056893/
          501983804923683710875588112992152712894033920000000 + 
         (15438533*lm^2)/288 + (58433242286366228173460761429*Pi^2)/
          4263541509427200 + (24875870502084695240737375*Pi^3)/
          (45223575382325463552*Sqrt[3]) + (280164641*Pi^4)/25920 + 
         lm*(5976268729846861/71327692800 - (454597*Pi^2)/1296) - 
         (36631047427057003335508017504553*Im[PolyLog[2, (-1)^(1/3)]])/
          (15844079635197726155443200*Sqrt[3]) + 
         (4368337*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (4975174100416939048147475*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (244263138639103584*Sqrt[3]) + (4975174100416939048147475*Pi*
           Log[3]^2)/(11724630654676972032*Sqrt[3]) + 
         (6149414777551298811486255085051*PolyGamma[2, 1])/
          355779876259553472 + (18064636534553375049578558442330731*Zeta[3])/
          1780678280679065127360) + CF*Log[x]*
        ((6169326767975336540869009896375702601*NM*NC)/
          334778905535280386019840 - (87328607249*lm*NM*NC)/272160 - 
         54910*lm^2*NM*NC - (8857282143588523217*NC*NL)/3506201899200 - 
         (87328607249*lm*NC*NL)/272160 - 54910*lm^2*NC*NL - 
         (178873456548745464179643232845822311087686283*NC*NH)/
          5608885464228508725674811807818611200 - (87328607249*lm*NC*NH)/
          272160 - 54910*lm^2*NC*NH + (797743984871675*NM*NC*Pi^2)/162 - 
         (21498319*NC*NL*Pi^2)/81 + (3693759124139071010420*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-37930290853318118499042589591060652106170033566616651/
            296350875807576351934152274482988800000 - (89819324849*lm)/
            30240 - 494190*lm^2 - (633698905016383461517*Pi^2)/25945920 + 
           (4975174100416939048147475*Im[PolyLog[2, (-1)^(1/3)]])/
            (366394707958655376*Sqrt[3]) - 1317840*Zeta[3]) + 
         CA*NC*(75860585480529390877516324657451416779751858627421677/
            1185403503230305407736609097931955200000 + (1169834958139*lm)/
            544320 + 302005*lm^2 + (211232971481776462639*Pi^2)/17297280 - 
           (4975174100416939048147475*Im[PolyLog[2, (-1)^(1/3)]])/
            (732789415917310752*Sqrt[3]) + 658920*Zeta[3])), 
      (4153245155256208420181725310748951190322580108027632999786702235841*
         CF^2*NC)/571508561905613904831857066641565863629857617920000000 + 
       (1820944684963661*CF^2*lm*NC)/38476838400 + (815745*CF^2*lm^2*NC)/8 + 
       (44379016852230469011177593802998521957156112864227*CF*NM*NC)/
        153145633644635265425155741977600000 + 
       (1167042840367661*CF*lm*NM*NC)/346291545600 + (271915*CF*lm^2*NM*NC)/
        24 - (170138680099164089007631*CF*NC*NL)/93592216029312000 + 
       (1167042840367661*CF*lm*NC*NL)/346291545600 + (271915*CF*lm^2*NC*NL)/
        24 - (242534111641196497851416002444514908524577161900462775624537*CF*
         NC*NH)/6074572416058992378637738644326704953402700262400000 + 
       (1167042840367661*CF*lm*NC*NH)/346291545600 + (271915*CF*lm^2*NC*NH)/
        24 - (7218888805270680082640522629*CF^2*NC*Pi^2)/2196369868492800 - 
       (2601*CF^2*lm*NC*Pi^2)/4 - (12685802458514665871*CF*NM*NC*Pi^2)/
        120120 - (289*CF*lm*NM*NC*Pi^2)/4 + (93698424731*CF*NC*NL*Pi^2)/
        1441440 - (289*CF*lm*NC*NL*Pi^2)/4 - (289*CF*lm*NC*NH*Pi^2)/4 + 
       (549535745014599401193727435*CF^2*NC*Pi^3)/(407012178440929171968*
         Sqrt[3]) + (60447037464646938967505*CF*NC*NH*Pi^3)/
        (11118121133111046*Sqrt[3]) + (223734671*CF^2*NC*Pi^4)/8640 - 
       (833222061860228152092854513839873*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (142596716716779535398988800*Sqrt[3]) - 
       (615837255494674786502874557*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (22258478508488314092*Sqrt[3]) + 
       (10433053*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
       (109907149002919880238745487*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2198368247751932256*
         Sqrt[3]) + (13816465706205014621144*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (109907149002919880238745487*CF^2*NC*Pi*Log[3]^2)/
        (105521675892092748288*Sqrt[3]) + (1727058213275626827643*CF*NC*NH*
         Pi*Log[3]^2)/(411782264189298*Sqrt[3]) + 
       CF*((-397236875327584417159072970057251*CF*NC)/10071728578207296000 + 
         CA*(397236789956823748453398708755731/20143457156414592000 - 
           10123058*lm)*NC + 16565004*CF*lm*NC - 
         (39355804226352296665065145*NM*NC)/31054527504 + 
         1840556*lm*NM*NC + (33182113*NC*NL)/15 + 1840556*lm*NC*NL + 
         (2995092348019107709*NC*NH)/4813451763120 + 1840556*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-17657638923871650927*CA + 
          52*(679130590824082267*CF + 83160*(284316928048689*NM + 
              920278*NL)))*Log[x]^3)/3243240 + 
       (30973858325065937278187584242929*CF^2*NC*PolyGamma[2, 1])/
        1500946352969991210 - (36277755847930351*CF*NM*NC*PolyGamma[2, 1])/
        180 + (456184230145429475459063*CF*NC*NH*PolyGamma[2, 1])/
        222362422662220920 + CA*CF*NC*
        (-4153243212413260345121699249211876209128382000476091458908622946341/
          1143017123811227809663714133283131727259715235840000000 - 
         (2991065*lm^2)/48 + (141546835901804128184360471*Pi^2)/
          86132151705600 - (549535745014599401193727435*Pi^3)/
          (814024356881858343936*Sqrt[3]) - (44946691*Pi^4)/3456 + 
         lm*(-6160475108191661/62962099200 + (3179*Pi^2)/8) + 
         (833222061860228152092854513839873*Im[PolyLog[2, (-1)^(1/3)]])/
          (285193433433559070797977600*Sqrt[3]) - 
         (10433053*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 - 
         (109907149002919880238745487*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4396736495503864512*Sqrt[3]) - (109907149002919880238745487*Pi*
           Log[3]^2)/(211043351784185496576*Sqrt[3]) - 
         (30973858325065937278187584242929*PolyGamma[2, 1])/
          3001892705939982420 - (449213573938338855854877176778040097*
           Zeta[3])/19231325431333903375488) + 
       (2246067730815920113977891167494018309*CF^2*NC*Zeta[3])/
        48078313578334758438720 - (19218741116450221*CF*NM*NC*Zeta[3])/90 + 
       1973207*CF*NC*NL*Zeta[3] - (611553797973834086355937*CF*NC*NH*
         Zeta[3])/111181211331110460 + CF*Log[x]*
        ((-172502257130522091241412039279637386353*NM*NC)/
          361643879436259676256000 + (92834880049*lm*NM*NC)/240240 + 
         65892*lm^2*NM*NC + (6357076511788153*NC*NL)/2029052025 + 
         (92834880049*lm*NC*NL)/240240 + 65892*lm^2*NC*NL + 
         (11705431525631964526499510511480304017361222391*NC*NH)/
          294466486871996708097927619910477088000 + (92834880049*lm*NC*NH)/
          240240 + 65892*lm^2*NC*NH - 94772309028569*NM*NC*Pi^2 + 
         (986170*NC*NL*Pi^2)/3 - (13816465706205014621144*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(4974268388315451074369185484176879476457704689117194843/
            490757050337346438802956166543829452800000 - (112982017969*lm)/
            43680 - 362406*lm^2 + (47086957859943517799*Pi^2)/34594560 + 
           (109907149002919880238745487*Im[PolyLog[2, (-1)^(1/3)]])/
            (13190209486511593536*Sqrt[3]) - 790704*Zeta[3]) + 
         CF*NC*(-4974270295412851417313101088894251575702256449792044143/
            245378525168673219401478083271914726400000 + (286419587187*lm)/
            80080 + 593028*lm^2 - (141260896848701730949*Pi^2)/51891840 - 
           (109907149002919880238745487*Im[PolyLog[2, (-1)^(1/3)]])/
            (6595104743255796768*Sqrt[3]) + 1581408*Zeta[3])), 
      (2882804562223770720694571422287427195547714848643184280171504357931099\
5351*CF^2*NC)/41348399521630349322911359404203015276821500146104320000000 - 
       (198140329187055727*CF^2*lm*NC)/3706602099200 - 
       (233769*CF^2*lm^2*NC)/2 - 
       (128827270971897026137629933541585824097335709798073773*CF*NM*NC)/
        950892201302790715864843486770975744000 - 
       (125932940343065327*CF*lm*NM*NC)/33359418892800 - 
       (77923*CF*lm^2*NM*NC)/6 + (42512080983591231764207*CF*NC*NL)/
        19265064410592000 - (125932940343065327*CF*lm*NC*NL)/
        33359418892800 - (77923*CF*lm^2*NC*NL)/6 + 
       (243645731743767186966972368576081094916643416779925427325781*CF*NC*
         NH)/5102640829489553598055700461234432160858268220416000 - 
       (125932940343065327*CF*lm*NC*NH)/33359418892800 - 
       (77923*CF*lm^2*NC*NH)/6 - (35361925519039219759267956884609*CF^2*NC*
         Pi^2)/136907055136051200 + (2889*CF^2*lm*NC*Pi^2)/4 + 
       (406080092049253007189*CF*NM*NC*Pi^2)/9189180 + 
       (321*CF*lm*NM*NC*Pi^2)/4 - (624705690461*CF*NC*NL*Pi^2)/8168160 + 
       (321*CF*lm*NC*NL*Pi^2)/4 + (321*CF*lm*NC*NH*Pi^2)/4 - 
       (11173659587167138366847757185*CF^2*NC*Pi^3)/(6919207033495795923456*
         Sqrt[3]) - (217391854052580804437225*CF*NC*NH*Pi^3)/
        (33354363399333138*Sqrt[3]) - (88179071*CF^2*NC*Pi^4)/2880 + 
       (286852927542722811522995108801833171*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41210451131149285730307763200*
         Sqrt[3]) + (11173253639602770019305743977*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(333877177627324711380*Sqrt[3]) - 
       (12264519*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (2234731917433427673369551437*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37372260211782848352*
         Sqrt[3]) - (49689566640589898157080*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (2234731917433427673369551437*CF^2*NC*Pi*Log[3]^2)/
        (1793868490165576720896*Sqrt[3]) - (6211195830073737269635*CF*NC*NH*
         Pi*Log[3]^2)/(1235346792567894*Sqrt[3]) + 
       CF*((-5483839116868125593715466327981964179*CF*NC)/
          1769266986905081664000 - 20014236*CF*lm*NC + 
         CA*(5483839135200912660696232950615504019/3538533973810163328000 + 
           12230922*lm)*NC + (1209098591922657915122645273*NM*NC)/
          2280056098320 - 2223804*lm*NM*NC - (13325059*NC*NL)/5 - 
         2223804*lm*NC*NL - (33079172140700272541*NC*NH)/43321065868080 - 
         2223804*lm*NC*NH)*Log[x]^2 + 
       ((188114189119352998795*CA*CF*NC)/408408 - 
         (248974712277327697313*CF^2*NC)/270270 + 
         (44*CF*NC*(11308113772771*NM + 101082*NL))/3)*Log[x]^3 - 
       (1279632074901417190952831434087679*CF^2*NC*PolyGamma[2, 1])/
        4002523607919976560 + (1639255288256095*CF*NM*NC*PolyGamma[2, 1])/
        6 - (22268704270068574163752627*CF*NC*NH*PolyGamma[2, 1])/
        9005678117819947260 - (9743080645941760018127404545625321121*CF^2*NC*
         Zeta[3])/54488755388779392897216 + 463492274446552*CF*NM*NC*
        Zeta[3] - 2379807*CF*NC*NL*Zeta[3] + 
       (29356294508158272524496233*CF*NC*NH*Zeta[3])/4502839058909973630 + 
       CA*CF*NC*(-20179632053615916615765429243106597618248756951086053472883\
2310551417644957/
          578877593302824890520759031658842213875501002045460480000000 + 
         (857153*lm^2)/12 + (11787308510641077707202666984251*Pi^2)/
          91271370090700800 + (11173659587167138366847757185*Pi^3)/
          (13838414066991591846912*Sqrt[3]) + (88548863*Pi^4)/5760 + 
         lm*(677334818788082927/6065348889600 - (3531*Pi^2)/8) - 
         (286852927542722811522995108801833171*Im[PolyLog[2, (-1)^(1/3)]])/
          (82420902262298571460615526400*Sqrt[3]) + 
         (12264519*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (2234731917433427673369551437*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74744520423565696704*Sqrt[3]) + (2234731917433427673369551437*Pi*
           Log[3]^2)/(3587736980331153441792*Sqrt[3]) + 
         (1279632074901417190952831434087679*PolyGamma[2, 1])/
          8005047215839953120 + (9743080835618853598758219275380136753*
           Zeta[3])/108977510777558785794432) + 
       CF*Log[x]*((205663993714561919770084535324009869015*NM*NC)/
          1316992805576509448395008 - (1856228154337*lm*NM*NC)/4084080 - 
         77520*lm^2*NM*NC - (35653617125725933*NC*NL)/9434224800 - 
         (1856228154337*lm*NC*NL)/4084080 - 77520*lm^2*NC*NL - 
         (1683773390932709994517416549014697400317508877*NC*NH)/
          35335978424639604971751314389257250560 - (1856228154337*lm*NC*NH)/
          4084080 - 77520*lm^2*NC*NH + 41463083444205*NM*NC*Pi^2 - 
         396474*NC*NL*Pi^2 + (49689566640589898157080*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(-438099907801320845028909243054410072928654918712939316669021/
            364431724152783125941995222401206444108800000 - 
           (5726983403811*lm)/1361360 - 697680*lm^2 - 
           (67721109554247443602387*Pi^2)/294053760 + 
           (2234731917433427673369551437*Im[PolyLog[2, (-1)^(1/3)]])/
            (112116780635348545056*Sqrt[3]) - 1860480*Zeta[3]) + 
         CA*NC*(4819099023021299440734557079252905118813106714522856670142531/
            8017497931361228770723894892826541770393600000 + 
           (2259170912737*lm)/742560 + 426360*lm^2 + 
           (22573703237900665267777*Pi^2)/196035840 - 
           (2234731917433427673369551437*Im[PolyLog[2, (-1)^(1/3)]])/
            (224233561270697090112*Sqrt[3]) + 930240*Zeta[3])), 
      (2375513914075944153067035362274581345758646852807604416200500165968851\
6967*CF^2*NC)/289438796651412445260379515829421106937750501022730240000000 + 
       (694570915883941781*CF^2*lm*NC)/11119806297600 + 
       (1077699*CF^2*lm^2*NC)/8 + 
       (81070017766076996904188530504280001854473061921943976661*CF*NM*NC)/
        30111586374588372669053377081080898560000 + 
       (444908329902332981*CF*lm*NM*NC)/100078256678400 + 
       (359233*CF*lm^2*NM*NC)/24 - (29423365648641817999338007*CF*NC*NL)/
        10819260172988467200 + (444908329902332981*CF*lm*NC*NL)/
        100078256678400 + (359233*CF*lm^2*NC*NL)/24 - 
       (733949340032685096738782126033675618909842690686684752176219*CF*NC*
         NH)/12506472621297925485430638385378510198182029952000000 + 
       (444908329902332981*CF*lm*NC*NH)/100078256678400 + 
       (359233*CF*lm^2*NC*NH)/24 - (2888917167574454655636432199871*CF^2*NC*
         Pi^2)/82144233081630720 - (3249*CF^2*lm*NC*Pi^2)/4 - 
       (1001774032763859062369*CF*NM*NC*Pi^2)/1021020 - 
       (361*CF*lm*NM*NC*Pi^2)/4 + (445137715751*CF*NC*NL*Pi^2)/4900896 - 
       (361*CF*lm*NC*NL*Pi^2)/4 - (361*CF*lm*NC*NH*Pi^2)/4 + 
       (13552118118849558771522821375*CF^2*NC*Pi^3)/(6919207033495795923456*
         Sqrt[3]) + (178419403366645765730455*CF*NC*NH*Pi^3)/
        (22236242266222092*Sqrt[3]) + (314954963*CF^2*NC*Pi^4)/8640 - 
       (357232552311166489901536640390971549*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41210451131149285730307763200*
         Sqrt[3]) - (4565812414704371778429627319*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(111292392542441570460*Sqrt[3]) + 
       (14501161*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
       (2710423623769911754304564275*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37372260211782848352*
         Sqrt[3]) + (20390788956188087512052*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (2710423623769911754304564275*CF^2*NC*Pi*Log[3]^2)/
        (1793868490165576720896*Sqrt[3]) + (5097697239047021878013*CF*NC*NH*
         Pi*Log[3]^2)/(823564528378596*Sqrt[3]) + 
       CF*((-203639077141555958968371406663310107*CF*NC)/
          482527360065022272000 + CA*(320004254507290411144106626515251351/
            1516514560204355712000 - 14993660*lm)*NC + 24535080*CF*lm*NC - 
         (170017899121572994725434857937*NM*NC)/14440355289360 + 
         2726120*lm*NM*NC + (48969061*NC*NL)/15 + 2726120*lm*NC*NL + 
         (754397203407476117*NC*NH)/793426114800 + 2726120*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-3274983348927219544461*CA + 
          4*(1637488447293186029807*CF + 18378360*(2641097100216009*NM + 
              1363060*NL)))*Log[x]^3)/55135080 + 
       (411701641305749106486682374234056*CF^2*NC*PolyGamma[2, 1])/
        2251419529454986815 - (331137585765856499*CF*NM*NC*PolyGamma[2, 1])/
        180 + (3594576412130254461877715*CF*NC*NH*PolyGamma[2, 1])/
        1200757082375992968 + CA*CF*NC*(-237551377147244533531382772573121607\
89022361071544320343721967302518487967/
          578877593302824890520759031658842213875501002045460480000000 - 
         (3951563*lm^2)/48 + (253413785821843941325277484019*Pi^2)/
          14411268961689600 - (13552118118849558771522821375*Pi^3)/
          (13838414066991591846912*Sqrt[3]) - (316202579*Pi^4)/17280 + 
         lm*(-2351422622852800181/18196046668800 + (3971*Pi^2)/8) + 
         (357232552311166489901536640390971549*Im[PolyLog[2, (-1)^(1/3)]])/
          (82420902262298571460615526400*Sqrt[3]) - 
         (14501161*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 - 
         (2710423623769911754304564275*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74744520423565696704*Sqrt[3]) - (2710423623769911754304564275*Pi*
           Log[3]^2)/(3587736980331153441792*Sqrt[3]) - 
         (205850820652874553243341187117028*PolyGamma[2, 1])/
          2251419529454986815 - (1042405198907507118611433876974973861619*
           Zeta[3])/4903987984990145360749440) + 
       (1042405188540862030827371814287021579587*CF^2*NC*Zeta[3])/
        2451993992495072680374720 - (172671761158798109*CF*NM*NC*Zeta[3])/
        90 + 2911313*CF*NC*NL*Zeta[3] - (4981099787677108332344773*CF*NC*NH*
         Zeta[3])/600378541187996484 + CF*Log[x]*
        ((-184879229880636789103703187172578885834293*NM*NC)/
          41704772176589465865841920 + (2211305231777*lm*NM*NC)/4084080 + 
         92055*lm^2*NM*NC + (20437907887240563373*NC*NL)/4415217206400 + 
         (2211305231777*lm*NC*NL)/4084080 + 92055*lm^2*NC*NL + 
         (86346789363990364099471416956726109446154325117*NC*NH)/
          1472332434359983540489638099552385440000 + 
         (2211305231777*lm*NC*NH)/4084080 + 92055*lm^2*NC*NH - 
         (2641097098859732*NM*NC*Pi^2)/3 + (1455115*NC*NL*Pi^2)/3 - 
         (20390788956188087512052*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CA*NC*(815213651826841718370689130065828464928082446969163637788911/
            8017497931361228770723894892826541770393600000 - 
           (2689799757377*lm)/742560 - (1012605*lm^2)/2 + 
           (8733286930161258064651*Pi^2)/588107520 + 
           (2710423623769911754304564275*Im[PolyLog[2, (-1)^(1/3)]])/
            (224233561270697090112*Sqrt[3]) - 1104660*Zeta[3]) + 
         CF*NC*(-116459099534153389678627612707288694714961228644620288507773/
            572678423668659197908849635201895840742400000 + 
           (6821895687531*lm)/1361360 + 828495*lm^2 - 
           (26199861373746484592321*Pi^2)/882161280 - 
           (2710423623769911754304564275*Im[PolyLog[2, (-1)^(1/3)]])/
            (112116780635348545056*Sqrt[3]) + 2209320*Zeta[3])), 
      (5707218185856996340346711632213305106529790351169376189499395281801570\
743061*CF^2*NC)/
        868316389954237335781138547488263320813251503068190720000000 - 
       (126378685481641539439*CF^2*lm*NC)/1801408620211200 - 
       (2453261*CF^2*lm^2*NC)/16 - 
       (49681848614659059783395806651123762800996983976380797873*CF*NM*NC)/
        43476622038175725244087763699956377600000 - 
       (80344044720933740239*CF*lm*NM*NC)/16212677581900800 - 
       (2453261*CF*lm^2*NM*NC)/144 + (32142846445550723598040487*CF*NC*NL)/
        9835691066353152000 - (80344044720933740239*CF*lm*NC*NL)/
        16212677581900800 - (2453261*CF*lm^2*NC*NL)/144 + 
       (1894698365379851427269269761679614087010828761925193838429553*CF*NC*
         NH)/27227530117829633823617374002634321806951233587200000 - 
       (80344044720933740239*CF*lm*NC*NH)/16212677581900800 - 
       (2453261*CF*lm^2*NC*NH)/144 - (1497160900034157057989185976120323*
         CF^2*NC*Pi^2)/616081748112230400 + (64619*CF^2*lm*NC*Pi^2)/72 + 
       (8811665493622401833921*CF*NM*NC*Pi^2)/23629320 + 
       (64619*CF*lm*NM*NC*Pi^2)/648 - (140228015787127*CF*NC*NL*Pi^2)/
        1323241920 + (64619*CF*lm*NC*NL*Pi^2)/648 + 
       (64619*CF*lm*NC*NH*Pi^2)/648 - (2676497180273571190662817115*CF^2*NC*
         Pi^3)/(1153201172249299320576*Sqrt[3]) - 
       (17174490861070375685699105*CF*NC*NH*Pi^3)/(1801135623563989452*
         Sqrt[3]) - (553652723*CF^2*NC*Pi^4)/12960 + 
       (126684946184272692266072885655539029*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12363135339344785719092328960*
         Sqrt[3]) + (886195941698164304145036367141*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(18029367591875534414520*Sqrt[3]) - 
       (25358825*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (535299436054714238132563423*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6228710035297141392*
         Sqrt[3]) - (1962798955550900078365612*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (535299436054714238132563423*CF^2*NC*Pi*Log[3]^2)/
        (298978081694262786816*Sqrt[3]) - (490699738887725019591403*CF*NC*NH*
         Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) + 
       CF*((-21106906383109832928774945517328188573*CF*NC)/
          723791040097533408000 - 29358116*CF*lm*NC + 
         CA*(232175970335738467770461846933052260993/
            15923402882145734976000 + (161469638*lm)/9)*NC + 
         (498495936435540651294507853553*NM*NC)/111397026517920 - 
         (29358116*lm*NM*NC)/9 - (350652353*NC*NL)/90 - 
         (29358116*lm*NC*NL)/9 - (39119642165671011209*NC*NH)/
          33903442853280 - (29358116*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(478193472448263845455631*CA + 
          32*(-29887093015254522341026*CF + 255255*(18883513954510409*NM + 
              29358116*NL)))*Log[x]^3)/110270160 - 
       (23652138240448011333959473806004861*CF^2*NC*PolyGamma[2, 1])/
        8005047215839953120 + (3175581621140297095*CF*NM*NC*PolyGamma[2, 1])/
        1296 - (144840244333793477031341083*CF*NC*NH*PolyGamma[2, 1])/
        40525551530189762670 - (42848418858309507122530334877924407221*CF^2*
         NC*Zeta[3])/27244377694389696448608 + 
       (2722377298275337195*CF*NM*NC*Zeta[3])/648 - 
       (187812245*CF*NC*NL*Zeta[3])/54 + (197806102875060549682058432*CF*NC*
         NH*Zeta[3])/20262775765094881335 + 
       CA*CF*NC*(-57072181909463433395324687615006237697584782592807019614264\
74466949460171561/
          1736632779908474671562277094976526641626503006136381440000000 + 
         (26985871*lm^2)/288 + (78797942111329732382395663968097*Pi^2)/
          64850710327603200 + (2676497180273571190662817115*Pi^3)/
          (2306402344498598641152*Sqrt[3]) + (185240177*Pi^4)/8640 + 
         lm*(431881301439066025039/2947759560345600 - (710809*Pi^2)/1296) - 
         (126684946184272692266072885655539029*Im[PolyLog[2, (-1)^(1/3)]])/
          (24726270678689571438184657920*Sqrt[3]) + 
         (25358825*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (535299436054714238132563423*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (12457420070594282784*Sqrt[3]) + (535299436054714238132563423*Pi*
           Log[3]^2)/(597956163388525573632*Sqrt[3]) + 
         (23652138240448011333959473806004861*PolyGamma[2, 1])/
          16010094431679906240 + (214242094979203641240980084048120336993*
           Zeta[3])/272443776943896964486080) + 
       CF*Log[x]*((74405274193366113659211319650086895148297529*NM*NC)/
          56301442438395778918886592000 - (139282398828841*lm*NM*NC)/
          220540320 - (214795*lm^2*NM*NC)/2 - (10898389201606481503*NC*NL)/
          1970427513600 - (139282398828841*lm*NC*NL)/220540320 - 
         (214795*lm^2*NC*NL)/2 - 
         (11118401603815675617389432621701874078307714079*NC*NH)/
          159543715295195540842355432861194944000 - 
         (139282398828841*lm*NC*NH)/220540320 - (214795*lm^2*NC*NH)/2 + 
         (6294504641736811*NM*NC*Pi^2)/18 - (31291271*NC*NL*Pi^2)/54 + 
         (1962798955550900078365612*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*(-188298060131117159183414557376295344245235568555397899721912\
9/167031206903358932723414476933886286883200000 - (143229978665041*lm)/
            24504480 - (1933155*lm^2)/2 - (106265216460285854341751*Pi^2)/
            49008960 + (535299436054714238132563423*Im[PolyLog[2, (-1)^
                (1/3)]])/(18686130105891424176*Sqrt[3]) - 2577540*Zeta[3]) + 
         CA*NC*(7531922414105612571597079193502147844683823752479539435523491/
            1336249655226871461787315815471090295065600000 + 
           (169427553941641*lm)/40098240 + (2362745*lm^2)/4 + 
           (191277389698363162824515*Pi^2)/176432256 - 
           (535299436054714238132563423*Im[PolyLog[2, (-1)^(1/3)]])/
            (37372260211782848352*Sqrt[3]) + 1288770*Zeta[3])), 
      (3101240186409778653245302419632583939848242085548652486167882644466390\
869443*CF^2*NC)/
        3516681379314661209913611117327466449293668587426172416000000 + 
       (731606821872935693*CF^2*lm*NC)/9007043101056 + 175370*CF^2*lm^2*NC + 
       (1955879555588370226444303312168697964207361683373763227997*CF*NM*NC)/
        78174310780181352121580882806652332800000 + 
       (468345963767570573*CF*lm*NM*NC)/81063387909504 + 
       (175370*CF*lm^2*NM*NC)/9 - (610115313367046019483383*CF*NC*NL)/
        153272852450669952 + (468345963767570573*CF*lm*NC*NL)/
        81063387909504 + (175370*CF*lm^2*NC*NL)/9 - 
       (1537031199516494617222641265754192835065452788539726254363397141153*
         CF*NC*NH)/
        18173254636134447075162801243485697110903005793113944000000 + 
       (468345963767570573*CF*lm*NC*NH)/81063387909504 + 
       (175370*CF*lm^2*NC*NH)/9 - (517055002147205583112628257272931*CF^2*NC*
         Pi^2)/1416988020658129920 - (9025*CF^2*lm*NC*Pi^2)/9 - 
       (37691318531811112939154*CF*NM*NC*Pi^2)/4135131 - 
       (9025*CF*lm*NM*NC*Pi^2)/81 + (4124658520051*CF*NC*NL*Pi^2)/
        33081048 - (9025*CF*lm*NC*NL*Pi^2)/81 - (9025*CF*lm*NC*NH*Pi^2)/
        81 + (1170856104747560843095610703865*CF^2*NC*Pi^3)/
        (420341827284869602349952*Sqrt[3]) + (1742106407635934464881400*CF*NC*
         NH*Pi^3)/(150094635296999121*Sqrt[3]) + (65285501*CF^2*NC*Pi^4)/
        1296 - (6307578328953131238057141199883631451*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(500706981243463821623239322880*
         Sqrt[3]) - (152326943678282496794279064889*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2554160408849034042057*Sqrt[3]) + 
       (14859235*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (234171220949512168619122140773*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2270364807865808037384*
         Sqrt[3]) + (796391500633570041088640*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) + 
       (234171220949512168619122140773*CF^2*NC*Pi*Log[3]^2)/
        (108977510777558785794432*Sqrt[3]) + (49774468789598127568040*CF*NC*
         NH*Pi*Log[3]^2)/(5559060566555523*Sqrt[3]) + 
       CF*((-3486243262549207984317757648120541803*CF*NC)/
          796170144107286748800 + CA*(3486243247898003434178845550005116763/
            1592340288214573497600 - (195738950*lm)/9)*NC + 
         35588900*CF*lm*NC - (10661417619426956445588028898689*NM*NC)/
          97472398203180 + (35588900*lm*NM*NC)/9 + 4720056*NC*NL + 
         (35588900*lm*NC*NL)/9 + (6394774470673810741483*NC*NH)/
          4508098416897075 + (35588900*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-860443540110410332646*CA + 21*(81946980418216691829*CF + 
            97240*(22082681795823754*NM + 1779445*NL)))*Log[x]^3)/1378377 + 
       (196954518705883226690380408514271967*CF^2*NC*PolyGamma[2, 1])/
        121576654590569288010 - (54395609516639069893*CF*NM*NC*
         PolyGamma[2, 1])/3240 + (231506573389804550348314913*CF*NC*NH*
         PolyGamma[2, 1])/54034068706919683560 + 
       CA*CF*NC*(-31012401617353101426356375273435463533211881506578407886458\
93434780329457943/
          7033362758629322419827222234654932898587337174852344832000000 - 
         (964535*lm^2)/9 + (1183192224089791201728682472471*Pi^2)/
          6485071032760320 - (1170856104747560843095610703865*Pi^3)/
          (840683654569739204699904*Sqrt[3]) - (21838847*Pi^4)/864 + 
         lm*(-2478701607481267853/14738797801728 + (99275*Pi^2)/162) + 
         (6307578328953131238057141199883631451*Im[PolyLog[2, (-1)^(1/3)]])/
          (1001413962486927643246478645760*Sqrt[3]) - 
         (14859235*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (234171220949512168619122140773*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4540729615731616074768*Sqrt[3]) - 
         (234171220949512168619122140773*Pi*Log[3]^2)/
          (217955021555117571588864*Sqrt[3]) - 
         (196954518705883226690380408514271967*PolyGamma[2, 1])/
          243153309181138576020 - (63957036665270385461621480559154973177149*
           Zeta[3])/33101918898683481185058720) + 
       (63957036564810905824748538240465923283349*CF^2*NC*Zeta[3])/
        16550959449341740592529360 - (27896391398271035893*CF*NM*NC*Zeta[3])/
        1620 + (113625700*CF*NC*NL*Zeta[3])/27 - 
       (330106766176001455872538687*CF*NC*NH*Zeta[3])/27017034353459841780 + 
       CF*Log[x]*((-289762856379425846019819207559146858816956569*NM*NC)/
          7037680304799472364860824000 + (4108264104013*lm*NM*NC)/5513508 + 
         126350*lm^2*NM*NC + (678894605783380092917*NC*NL)/
          101329234886880 + (4108264104013*lm*NC*NL)/5513508 + 
         126350*lm^2*NC*NL + 
         (18028495062013707429659387605449764719510530848161*NC*NH)/
          212585249106437779715306613569354777416875 + 
         (4108264104013*lm*NC*NH)/5513508 + 126350*lm^2*NC*NH - 
         (73608939313790920*NM*NC*Pi^2)/9 + (18931600*NC*NL*Pi^2)/27 - 
         (796391500633570041088640*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CA*NC*(7551047586808793479454511907931887287104881020621591352789313/
            7493276912772225351099640226757114039252480000 - 
           (4994886313213*lm)/1002456 - 694925*lm^2 + 
           (13767096205719099482081*Pi^2)/88216128 + 
           (234171220949512168619122140773*Im[PolyLog[2, (-1)^(1/3)]])/
            (13622188847194848224304*Sqrt[3]) - 1516200*Zeta[3]) + 
         CF*NC*
          (-98163619400542619129421782057647459043299359640301302089624569/
            48706299933019464782147661473921241255141120000 + 
           (4224369393313*lm)/612612 + 1137150*lm^2 - 
           (13767096247851334587041*Pi^2)/44108064 - 
           (234171220949512168619122140773*Im[PolyLog[2, (-1)^(1/3)]])/
            (6811094423597424112152*Sqrt[3]) + 3032400*Zeta[3])), 
      (2755757400663367504300452237185435195635146694253836345054504052643014\
92730089*CF^2*NC)/
        4454463080465237532557240748614790835771980210739818393600000 - 
       (295111599051957767753*CF^2*lm*NC)/3251542559481216 - 
       198335*CF^2*lm^2*NC - 
       (49030842675703223313492177522041658855800360796472628867071*CF*NM*
         NC)/5081330200711787887902757382432401632000000 - 
       (187629150129506605193*CF*lm*NM*NC)/29263883035330944 - 
       (198335*CF*lm^2*NM*NC)/9 + (5828150605172232363495802807*CF*NC*NL)/
        1229588882993152281600 - (187629150129506605193*CF*lm*NC*NL)/
        29263883035330944 - (198335*CF*lm^2*NC*NL)/9 + 
       (7233923790006949989247903553335715589289861258304004415166424101063*
         CF*NC*NH)/
        72693018544537788300651204973942788443612023172455776000000 - 
       (187629150129506605193*CF*lm*NC*NH)/29263883035330944 - 
       (198335*CF*lm^2*NC*NH)/9 - (614621236864833944010407100249550307*CF^2*
         NC*Pi^2)/26922772392504468480 + (9925*CF^2*lm*NC*Pi^2)/9 + 
       (380547815024260552690279*CF*NM*NC*Pi^2)/120873060 + 
       (9925*CF*lm*NM*NC*Pi^2)/81 - (90747931889845*CF*NC*NL*Pi^2)/
        628539912 + (9925*CF*lm*NC*NL*Pi^2)/81 + (9925*CF*lm*NC*NH*Pi^2)/
        81 - (8713846502143827853261966664165*CF^2*NC*Pi^3)/
        (2662164906137507481549696*Sqrt[3]) - 
       (228216358774668576343850*CF*NC*NH*Pi^3)/(16677181699666569*
         Sqrt[3]) - (75901001*CF^2*NC*Pi^4)/1296 + 
       (18180372067419150743720933949614289077*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1229627348495853330652989085440*
         Sqrt[3]) + (16449495252590192761252134629*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(232196400804457640187*Sqrt[3]) - 
       (17194135*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (248967042918395081521770476119*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2054139588069064414776*
         Sqrt[3]) - (104327478296991349185760*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (248967042918395081521770476119*CF^2*NC*Pi*Log[3]^2)/
        (98598700227315091909248*Sqrt[3]) - (6520467393561959324110*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((-828816738315392547138185581410756228271*CF*NC)/
          3025446547607689645440 - 42214124*CF*lm*NC + 
         CA*(828816738382054217070851383743522883423/6050893095215379290880 + 
           (232177682*lm)/9)*NC + (18412493976793164410458388994329*NM*NC)/
          487361991015900 - (42214124*lm*NM*NC)/9 - (50269288*NC*NL)/9 - 
         (42214124*lm*NC*NL)/9 - (30732323057681618366743*NC*NH)/
          18032393667588300 - (42214124*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(1067627348349030053525464*CA + 
          57*(-37460608912520225665993*CF + 136136*(39847744844990522*NM + 
              10553531*NL)))*Log[x]^3)/26189163 - 
       (4423371379378625094395455852885611731*CF^2*NC*PolyGamma[2, 1])/
        162102206120759050680 + (35600073171778472159*CF*NM*NC*
         PolyGamma[2, 1])/1620 - (1233146581341149984220544861*CF*NC*NH*
         PolyGamma[2, 1])/243153309181138576020 - 
       (1447507144941130035361204532121681937988237*CF^2*NC*Zeta[3])/
        104822743179164357086019280 + (30818343811982711279*CF*NM*NC*
         Zeta[3])/810 - (134582272*CF*NC*NL*Zeta[3])/27 + 
       (1736030357170270250172975539*CF*NC*NH*Zeta[3])/
        121576654590569288010 + CA*CF*NC*
        (-2755757401032306680428543401703232880723160714813398497061324803106\
12917060989/8908926160930475065114481497229581671543960421479636787200000 + 
         (2181685*lm^2)/18 + (26722662472595755931042292730119733*Pi^2)/
          2341110642826475520 + (8713846502143827853261966664165*Pi^3)/
          (5324329812275014963099392*Sqrt[3]) + (25385027*Pi^4)/864 + 
         lm*(1008404214628224573833/5320706006423808 - (109175*Pi^2)/162) - 
         (18180372067419150743720933949614289077*Im[PolyLog[2, (-1)^(1/3)]])/
          (2459254696991706661305978170880*Sqrt[3]) + 
         (17194135*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (248967042918395081521770476119*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4108279176138128829552*Sqrt[3]) + 
         (248967042918395081521770476119*Pi*Log[3]^2)/
          (197197400454630183818496*Sqrt[3]) + 
         (4423371379378625094395455852885611731*PolyGamma[2, 1])/
          324204412241518101360 + 
         (1447507145694448394733632364276048670124837*Zeta[3])/
          209645486358328714172038560) + CF*Log[x]*
        ((1292469481883316076967369668502075662409921*NM*NC)/
          115751320802622900737842500 - (90365269419655*lm*NM*NC)/
          104756652 - 146300*lm^2*NM*NC - (30561991315744713056347*NC*NL)/
          3850510925701440 - (90365269419655*lm*NC*NL)/104756652 - 
         146300*lm^2*NC*NL - 
         (1249080024720478262863145656488408487561351832339*NC*NH)/
          12493531627926554547088726600953816120000 - 
         (90365269419655*lm*NC*NH)/104756652 - 146300*lm^2*NC*NH + 
         (8855054407769882*NM*NC*Pi^2)/3 - (22423762*NC*NL*Pi^2)/27 + 
         (104327478296991349185760*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CF*NC*
          (-383086080305376500881050287898594181836767958176637812745895031/
            3629096857754391493571786541194131701363456000 - 
           (92919585784255*lm)/11639628 - 1316700*lm^2 - 
           (17082037582473728028325705*Pi^2)/838053216 + 
           (248967042918395081521770476119*Im[PolyLog[2, (-1)^(1/3)]])/
            (6162418764207193244328*Sqrt[3]) - 3511200*Zeta[3]) + 
         CA*NC*
          (6512463366339861692409770848525529146526023169330659611501500347/
            123389293163649310781440742400600477846357504000 + 
           (109870958022055*lm)/19046664 + 804650*lm^2 + 
           (17082037583423971723222201*Pi^2)/1676106432 - 
           (248967042918395081521770476119*Im[PolyLog[2, (-1)^(1/3)]])/
            (12324837528414386488656*Sqrt[3]) + 1755600*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["p", 2, 2, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(2366*NM - 182784*lm*NM + 82944*lm^2*NM + 270336*NL - 
         182784*lm*NL + 82944*lm^2*NL + 2366*NH - 182784*lm*NH + 
         82944*lm^2*NH - 6*CA*(2914894 - 70784*lm + 76032*lm^2 - 
           2429433*Zeta[3]) + 169155*NM*Zeta[3] + 169155*NH*Zeta[3] + 
         108*CF*(-768802 - 14080*lm + 6912*lm^2 + 672143*Zeta[3])))/59719680, 
      (CF*NC*(555302*NM + 199680*lm*NM - 165888*lm^2*NM - 357888*NL + 
         199680*lm*NL - 165888*lm^2*NL - 199198*NH + 199680*lm*NH - 
         165888*lm^2*NH + 12*CA*(2879502 + 5248*lm + 76032*lm^2 - 
           2429433*Zeta[3]) - 704025*NM*Zeta[3] + 27405*NH*Zeta[3] - 
         216*CF*(-775842 - 7168*lm + 6912*lm^2 + 672143*Zeta[3])))/59719680, 
      (CF*NC*(-4*CA*(71212195882 + 212259840*lm + 291962880*lm^2 - 
           59449218975*Zeta[3]) + 5*(68640768*NL - 23175168*lm*NL + 
           42467328*lm^2*NL + 139578142*NH - 23175168*lm*NH + 
           42467328*lm^2*NH - 108347085*NH*Zeta[3] + 
           NM*(-282941858 - 23175168*lm + 42467328*lm^2 + 
             301253715*Zeta[3]) + 8*CF*(-66686092382 - 18109440*lm + 
             47775744*lm^2 + 55638737325*Zeta[3]))))/66886041600, 
      (CF*NC*(8*CA*(189458391326 + 239907840*lm + 237219840*lm^2 - 
           157940419725*Zeta[3]) - 5*(79118336*NL - 18038784*lm*NL + 
           69009408*lm^2*NL + 646077222*NH - 18038784*lm*NH + 
           69009408*lm^2*NH - 544116825*NH*Zeta[3] + 
           NM*(-971206462 - 18038784*lm + 69009408*lm^2 + 
             943742205*Zeta[3]) + 48*CF*(-62764681982 - 1225728*lm + 
             12939264*lm^2 + 52251136605*Zeta[3]))))/133772083200, 
      -(CF*NC*(15091919811010*NM + 244787773440*lm*NM - 
          390168576000*lm^2*NM + 39486521344*NL + 244787773440*lm*NL - 
          390168576000*lm^2*NL - 11396038550190*NH + 244787773440*lm*NH - 
          390168576000*lm^2*NH + CA*(7392586764716978 + 1384847278080*lm + 
            2145927168000*lm^2 - 6157978374688875*Zeta[3]) - 
          13432259743875*NM*Zeta[3] + 9502690105125*NH*Zeta[3] - 
          70*CF*(-1384760094685274 - 23111958528*lm + 50164531200*lm^2 + 
            1152067234935015*Zeta[3])))/262193283072000, 
      (CF*NC*(22662882336290*NM + 487635025920*lm*NM - 
         104044953600*lm^2*NM + 928433831936*NL + 487635025920*lm*NL - 
         104044953600*lm^2*NL - 17463691620690*NH + 487635025920*lm*NH - 
         104044953600*lm^2*NH + 12*CA*(1338543054226086 - 162806497280*lm + 
           47687270400*lm^2 - 1114461636118425*Zeta[3]) - 
         18806029081875*NM*Zeta[3] + 14432475526875*NH*Zeta[3] - 
         2520*CF*(-99870885676874 - 1679622144*lm + 371589120*lm^2 + 
           83081120208975*Zeta[3])))/262193283072000, 
      -(CF*NC*(2016*CF*(1743542064068842498 + 18261754675200*lm + 
            2842656768000*lm^2 - 1450431022169563875*Zeta[3]) - 
          16*CA*(-11796175932649812866 + 1648254711398400*lm + 
            218884571136000*lm^2 + 9818032634889955875*Zeta[3]) + 
          5*(1310720*(1490865367 + 607987548*lm + 97161120*lm^2)*NL + 
            63*NM*(618983688956882 + 12649229189120*lm + 2021444812800*lm^
                2 - 494142718174875*Zeta[3]) + 63*NH*(-445005687211078 + 
              12649229189120*lm + 2021444812800*lm^2 + 367287575279625*Zeta[
                3]))))/1557428101447680000, 
      (CF*NC*(1008*CF*(1501687344191178086 + 7524468817920*lm + 
           2374454476800*lm^2 - 1249250130942557625*Zeta[3]) - 
         8*CA*(-8677372738756389862 + 781608471920640*lm + 
           182832994713600*lm^2 + 7220577575355125625*Zeta[3]) + 
         5*(131072*(3621625825 + 1218288204*lm + 405790560*lm^2)*NL + 
           63*NM*(177861146307454 + 2534658277376*lm + 844250480640*lm^2 - 
             140780452722525*Zeta[3]) + 63*NH*(-109073586674962 + 
             2534658277376*lm + 844250480640*lm^2 + 90260958231675*
              Zeta[3]))))/311485620289536000, 
      -(CF*NC*(616*CF*(77561294915171204120702 + 147851373463142400*lm + 
            71034481115136000*lm^2 - 64523535619509311932125*Zeta[3]) - 
          220*CA*(-8610000373833972819382 + 387429460702986240*lm + 
            121547889908121600*lm^2 + 7163536417706122232625*Zeta[3]) + 
          5*(655360*(11043656672107 + 2840968582452*lm + 1483738890480*lm^2)*
             NL + 99*NM*(18806638082785280*lm + 9822051709747200*lm^2 - 
              429*(-6054293268134438 + 4840020828113625*Zeta[3])) + 
            99*NH*(18806638082785280*lm + 9822051709747200*lm^2 + 
              143*(-8633557831863446 + 7169931926474625*Zeta[3])))))/
       4899668807154401280000, 
      (CF*NC*(7392*CF*(24470128963172495518142 + 12166352348774400*lm + 
           11063787356160000*lm^2 - 20356859747908161064125*Zeta[3]) - 
         880*CA*(-7118542757453171442658 + 125271668045905920*lm + 
           56794108428288000*lm^2 + 5922209417179068349875*Zeta[3]) + 
         5*(1048576*(10981833157237 + 1617073282440*lm + 1733218641000*lm^2)*
            NL + 165*NM*(4662507443679105214 + 10276510510350336*lm + 
             11014614967910400*lm^2 - 3784504852079876925*Zeta[3]) + 
           99*NH*(-2612062859243657138 + 17127517517250560*lm + 
             18357691613184000*lm^2 + 2175949344254560875*Zeta[3]))))/
       9799337614308802560000, 
      -(CF*NC*(208*CF*(67812443986509146885228938954 - 1462104196571883110400*
             lm + 13914210984819425280000*lm^2 - 
            56413676609701251027972159375*Zeta[3]) - 
          15400*CA*(-27958463318207319551918630 + 114960084886339190784*lm + 
            114847455747715891200*lm^2 + 23259004433687140938004185*
             Zeta[3]) + 55*(67108864*(419658756145249 - 23675596684740*lm + 
              87123804768000*lm^2)*NL + 195*NM*(-8147909733513166848*lm + 
              29983484950452633600*lm^2 + 65*(365426046688254370942 - 
                300334769868320472285*Zeta[3])) + 1287*NH*
             (-790182896734390626506 - 1234531777805025280*lm + 
              4542952265220096000*lm^2 + 659675416546170399375*Zeta[3]))))/
       423958542545456033955840000, 
      (CF*NC*(33696*CF*(1447090323318786443430987174 - 222230771377635328000*
            lm + 126740404182712320000*lm^2 - 1203845476415402000508953625*
            Zeta[3]) - 176*CA*(-7513201638061974753002787286 - 
           9599639764447789056000*lm + 14828627289377341440000*lm^2 + 
           6250245877978993016524022625*Zeta[3]) + 
         5*(134217728*(1636935069062647 - 1357671648633300*lm + 
             707084049672000*lm^2)*NL + 429*NM*(369344852452768580108482 - 
             424763645803207065600*lm + 221219614573461504000*lm^2 - 
             305876249495822482351875*Zeta[3]) + 1287*NH*
            (-16570264743656835759262 - 141587881934402355200*lm + 
             73739871524487168000*lm^2 + 13850359529993791930125*Zeta[3]))))/
       847917085090912067911680000, 
      (CF*NC*(9*CA*(-417193291557437276162674591831162 - 
           1138690844095189406973952000*lm + 370007502943280242360320000*
            lm^2 + 347062716893934861531285851652375*Zeta[3]) - 
         2*(CF*(77388298571010247991359182779631542 - 
             11398478811896003640164352000*lm + 2724600703491427239198720000*
              lm^2 - 64379912353440983131786258088408625*Zeta[3]) + 
           35*(1610612736*(-10999759533222121 - 23362062061638300*lm + 
               5370332575608000*lm^2)*NL + 715*NM*
              (47266977377194775613551042 - 52625503070904983224320*lm + 
               12097239220741157683200*lm^2 - 39289899067112830835974275*
                Zeta[3]) + 3575*NH*(-742269423978590705712086 - 
               10525100614180996644864*lm + 2419447844148231536640*lm^2 + 
               620695757534559291089505*Zeta[3])))))/
       1614434130013096577303838720000, 
      (CF*NC*(24*CF*(5208498944425775440056975451573138 - 
           556229904721111639130112000*lm + 68189136213604816650240000*lm^2 - 
           4332989331723595605091482989410875*Zeta[3]) - 
         36*CA*(-75818312367405894992809387331962 - 
           195884980049384052883456000*lm + 27780759198135295672320000*lm^2 + 
           63073238677468971849597977652375*Zeta[3]) + 
         35*(25769803776*(-2061936023538173 - 1678139091829200*lm + 
             201606609204000*lm^2)*NL + 715*NM*
            (74402580367337083753775614 - 60482958189193467002880*lm + 
             7266241621163350425600*lm^2 - 61931575038542232398500125*
              Zeta[3]) + 143*NH*(-16392244128792779402274262 - 
             302414790945967335014400*lm + 36331208105816752128000*lm^2 + 
             13705013223935084953526625*Zeta[3]))))/
       807217065006548288651919360000, 
      -(CF*NC*(CA*(511399621604510349055433494982846843486 + 
            1006152500229555763711930112409600*lm - 
            67356793922524432291174809600000*lm^2 - 
            425434126566771862042371769097118046125*Zeta[3]) + 
          2*(17*CF*(761149559915253730898883145246936538498 - 
              52010046892193702451805893427200*lm + 
              3241770830495828292088627200000*lm^2 - 
              633205978056996118970358693084043363875*Zeta[3]) + 
            105*(103079215104*(-15981336550035278743 - 9171102703117435080*
                 lm + 565754894785080000*lm^2)*NL + 2431*NM*(
                757264919756955198490904427986 - 388872919899431485801758720*
                 lm + 23989128134797264158720000*lm^2 - 
                630510611077827572133477310875*Zeta[3]) + 2431*NH*(
                -388872919899431485801758720*lm + 23989128134797264158720000*
                 lm^2 + 2431*(-7466937097130685905153674 + 
                  6239095969007811650115375*Zeta[3]))))))/
       106378293694822959671704540938240000, 
      (CF*NC*(-5*CA*(-47521767337795974769627157025549004466 - 
           63832588326624053142459022049280*lm + 
           1591988436125735006656423526400*lm^2 + 
           39533512881732686812900435204245847275*Zeta[3]) + 
         2*(153*CF*(43205014377922263029742507292049952886 - 
             1753834866875047059993604915200*lm + 
             42566535725287032263540736000*lm^2 - 
             35942571029761769306278331479584716625*Zeta[3]) + 
           70*(21474836480*(-43300662925817117827 - 19914203138111145864*lm + 
               481381418535937920*lm^2)*NL + 19448*NM*
              (74535460043745538236273669814 - 21989626492206896004464640*
                lm + 531550146419668235059200*lm^2 - 
               62051118117405094147517672625*Zeta[3]) + 17017*NH*
              (-25131001705379309719388160*lm + 607485881622477982924800*
                lm^2 + 2431*(-445454686799852612192962 + 
                 371876346924032675599875*Zeta[3]))))))/
       35459431231607653223901513646080000, 
      (CF*NC*(-26*CA*(36144126851557240562189364851998126010446 + 
           30926692728543253328960667254784000*lm + 
           108163290837136386068576206848000*lm^2 - 
           30068466641438767713091866409711625503125*Zeta[3]) + 
         76*CF*(-753124128524891571530378595751205572176142 + 
           17246056153600914914660182917120000*lm + 
           60550741760502187416379981824000*lm^2 + 
           626529518450489630731072971807402734611125*Zeta[3]) + 
         35*(274877906944*(39180565202536834658423 + 15128601757416038741850*
              lm + 53147479241770313400*lm^2)*NL + 
           4199*NM*(-6273840780665872996699235683609894 + 
             990359225069740595183458713600*lm + 3479177864569543197091430400*
              lm^2 + 5221853163199353997692633970337625*Zeta[3]) + 
           4199*NH*(990359225069740595183458713600*lm + 
             3479177864569543197091430400*lm^2 - 
             4199*(-9863676023452568429636066038 + 
               8225790283144830090090020625*Zeta[3])))))/
       102406837396882902510627571409879040000, 
      -(CF*NC*(-44*CA*(28788488866039508704288728955451398842878 + 
            14913930981147386288777004161433600*lm + 
            385614243348173459491607543808000*lm^2 - 
            23949305879108101644373749943556276260125*Zeta[3]) + 
          152*CF*(-553381313341378987140952347599532180530258 + 
            6862461279841943774041111894425600*lm + 
            182659378428082165022340415488000*lm^2 + 
            460361992494093924328060865480446748758875*Zeta[3]) + 
          455*(137438953472*(5591522528942107086521 + 1845137975650214525280*
               lm + 49331215648821506400*lm^2)*NL + 4199*NH*
             (2554757731824101601276729643846 + 60393863392429174347886755840*
               lm + 1614677459460723341210419200*lm^2 - 
              2128133797957344882917723135625*Zeta[3]) + 
            323*NM*(-9857513209057034466410151801719174 + 
              785120224101579266522527825920*lm + 
              20990806972989403435735449600*lm^2 + 
              8203079657802345254768884481051625*Zeta[3]))))/
       102406837396882902510627571409879040000, 
      (CF*NC*(-34*CA*(300579647981982586552706072914102275442108838 + 
           90410552053388123620445296241777049600*lm + 
           4163680629549268738883508007600128000*lm^2 - 
           250054101362501935135346553487060583799257625*Zeta[3]) + 
         4*CF*(-184293599917546582400590787630449676629596634106 + 
           1193473286065671473518824656353414348800*lm + 
           57913012392821647004470611378438144000*lm^2 + 
           153315203429209888352492921371891002629097612375*Zeta[3]) + 
         1155*(412316860416*(3907294714860520290972887 + 
             1104817350969255913549560*lm + 54048115886464616716800*lm^2)*
            NL + 4199*NH*(4825013531770674975594686277920402 + 
             108486501901587419103214216151040*lm + 
             5307203966112699088960172851200*lm^2 - 
             4014706875330546091748086859698875*Zeta[3]) + 
           20995*NM*(-569204798752543472890797036441828422 + 
             21697300380317483820642843230208*lm + 
             1061440793222539817792034570240*lm^2 + 
             473610685647350495756238582511881225*Zeta[3]))))/
       621814316673872984044530613600785530880000, 
      -(CF*NC*(-4*CA*(609252336897524936307488518389488376515330902 + 
            102356910899481074097304725410650521600*lm + 
            6852580291635045396195166912512000000*lm^2 - 
            506841116505861144602534672124027342047966625*Zeta[3]) + 
          5*(40*CF*(-951566420707620300752740541329175522962018106 + 
              3101810458550277310661089930160111616*lm + 
              224266264089874212966387280773120000*lm^2 + 
              791615115638155411696483896332564854131150135*Zeta[3]) + 
            21*(824633720832*(3275605413132875828854501 + 
                786479110582286023582680*lm + 57557383838066712600000*lm^2)*
               NL + 4199*NM*(-8919488285309714339208357289265020198 + 
                154455154874044417655502526218240*lm + 
                11303586471955364175465676800000*lm^2 + 
                7420919776467769981670672160109985625*Zeta[3]) + 
              20995*NH*(30891030974808883531100505243648*lm + 
                2260717294391072835093135360000*lm^2 - 482885*
                 (-3116542854690599656248542222 + 
                  2590311402531666128694944565*Zeta[3]))))))/
       113057148486158724371732838836506460160000, 
      CA*CF*NC*((-12430215206305081*lm)/4937988556838937600 - 
         (1036531*lm^2)/4493059200 + 
         (-96669169591368360897452278009811497111467107614 + 
           80419758196176759863739445516431058194055320525*Zeta[3])/
          3460247453206877670580478049649604689920000) + 
       (CF*NC*(782*CF*(-5282598428399342416071125113664962669301158605626 + 
            8304238266187779309726871437064745779200*lm + 
            846892600427731589149897604247375052800*lm^2 + 
            4394632555613192432903766802406832062237019595575*Zeta[3]) + 
          7315*(3298534883328*(147436320683173219909636687 + 
              29395671806693555594791560*lm + 3049700354181922410889920*lm^2)*
             NL + 7429*NH*(731572205151568295432743564768020958 + 
              13051911276516369144341803743313920*lm + 
              1354091129622671653855368251965440*lm^2 - 
              607425599558443610110106190363238125*Zeta[3]) + 
            37145*NM*(-351460904355142258311835338258380485354 + 
              2610382255303273828868360748662784*lm + 
              270818225924534330771073650393088*lm^2 + 
              292398099627731572144465025444931491775*Zeta[3]))))/
        1754345458775886978984302371172349577789440000, 
      -(CF*NC*(-260*CA*(724995491252407841488054300137209605539283731034 + 
            33363544473125805953242318482722217000960*lm + 
            4171823757075119411230864441642969989120*lm^2 - 
            603128936645643544187470520481579463610604513255*Zeta[3]) + 
          2392*CF*(-7148703045978706804467701426617422661555931686514 + 
            5113503775493584645780111163186479104000*lm + 
            742023988412570646266359288039263436800*lm^2 + 
            5947058745209849498238093347215780099767121704075*Zeta[3]) + 
          1155*(17592186044416*(411539226754358317853177213 + 
              65268388952031551240174220*lm + 9705877774355231352964080*lm^2)*
             NL + 7429*NM*(-52184723006267477786981755419843160121342 + 
              154558304114072538831485924152442880*lm + 
              22983928864022012015094589103800320*lm^2 + 
              43414001699546525626152905992554252484125*Zeta[3]) + 
            22287*NH*(51519434704690846277161974717480960*lm + 
              7661309621340670671698196367933440*lm^2 - 141151*(
                -25175075942888166066282982877062 + 
                20883756269923103622941646395625*Zeta[3])))))/
       5263036376327660936952907113517048733368320000}, 0, 22, 1]
 
CbarSeries["p", 2, 3, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(4*CA*(59400*lm^2 - 24777*Pi^2 + 810*Pi^4 - 
            150*lm*(-1285 + 44*Pi^2) + 10*(16688 + 6294*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 6480*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              1049*PolyGamma[2, 1] - 17506*Zeta[3])) + 
          CF*(-1296625 - 777600*lm^2 - 39668*Pi^2 + 1200*Pi^4 + 
            86400*lm*(-11 + Pi^2) - 503520*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 518400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            83920*PolyGamma[2, 1] + 2015360*Zeta[3]) + 
          20*(NL*(-2365 - 2160*lm^2 - 12*Pi^2 + 60*lm*(-71 + 4*Pi^2) - 
              2880*Zeta[3]) + NM*(-2365 - 2160*lm^2 - 12*Pi^2 + 
              60*lm*(-71 + 4*Pi^2) + 240*PolyGamma[2, 1] - 2400*Zeta[3]) + 
            NH*(-33577 - 2160*lm^2 + 60*lm*(-71 + 4*Pi^2) - 
              598704*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 99784*PolyGamma[2, 
                1] + 1103888*Zeta[3]))))/7776000, 
      (CF*NC*(-3*CA*(712800*lm^2 - 507468*Pi^2 + 19440*Pi^4 - 
           600*lm*(-841 + 132*Pi^2) + 5*(-1417631 - 452736*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 311040*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 76896*PolyGamma[2, 1] + 799776*Zeta[3])) + 
         4*(-5*(NH*(8738277 - 19440*lm^2 + 180*lm*(61 + 12*Pi^2) + 4473264*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 745544*PolyGamma[2, 1] - 
               15297808*Zeta[3]) + 3*NL*(53015 - 6480*lm^2 + 324*Pi^2 + 60*
                lm*(61 + 12*Pi^2) - 8640*Zeta[3]) + 3*NM*(53015 - 6480*
                lm^2 + 324*Pi^2 + 60*lm*(61 + 12*Pi^2) + 720*PolyGamma[2, 
                 1] - 7200*Zeta[3])) + 9*CF*(194400*lm^2 + 26784*Pi^2 + 
             1320*Pi^4 - 3600*lm*(71 + 6*Pi^2) + 5*(57065 - 75456*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 51840*Im[PolyLog[2, (-1)^(1/3)]]^
                 2 + 12816*PolyGamma[2, 1] + 80448*Zeta[3])))))/23328000, 
      -(CF*NC*(CA*(-8019000*lm^2 + 218079*Pi^2 + 86670*Pi^4 + 
            1350*lm*(-4051 + 132*Pi^2) + 10*(6866019 - 555258*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 2624400*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 16589*PolyGamma[2, 1] + 2451514*Zeta[3])) - 
          5*(3*(NH*(27953187 - 97200*lm^2 + 180*lm*(319 + 12*Pi^2) + 
                30775824*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 5328872*
                 PolyGamma[2, 1] - 78896464*Zeta[3]) + 3*NM*(299405 - 
                32400*lm^2 - 18036*Pi^2 + 60*lm*(319 + 12*Pi^2) - 
                720*PolyGamma[2, 1] - 10080*Zeta[3]) + 3*NL*(219485 - 
                32400*lm^2 - 9396*Pi^2 + 60*lm*(319 + 12*Pi^2) - 
                8640*Zeta[3])) + 2*CF*(-4411899 - 2624400*lm^2 - 
              440721*Pi^2 + 22518*Pi^4 + 19440*lm*(181 + 3*Pi^2) - 
              1110516*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              5248800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 33178*PolyGamma[2, 1] + 
              7846244*Zeta[3]))))/17496000, 
      (CF*NC*(74551782375*CF + 29111594400*CF*lm + 44530819200*CF*lm^2 - 
         16158592800*NM + 3472761600*lm*NM + 2473934400*lm^2*NM - 
         2307009600*NL + 3472761600*lm*NL + 2473934400*lm^2*NL - 
         455171935680*NH + 3472761600*lm*NH + 2473934400*lm^2*NH - 
         975005748*CF*Pi^2 - 1175731200*CF*lm*Pi^2 + 1097349120*NM*Pi^2 - 
         65318400*lm*NM*Pi^2 + 1244315520*NL*Pi^2 - 65318400*lm*NL*Pi^2 - 
         65318400*lm*NH*Pi^2 + 746760000*Sqrt[3]*CF*Pi^3 + 
         11975600000*Sqrt[3]*NH*Pi^3 + 102400200*CF*Pi^4 - 
         39979306080*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         180060572160*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         73336233600*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 27651456000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 443439360000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 576072000*Sqrt[3]*CF*Pi*
          Log[3]^2 + 9238320000*Sqrt[3]*NH*Pi*Log[3]^2 + 
         48988800*(-10*CA*(76 + 33*lm) + 9*CF*(227 + 120*lm) + 
           20*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         979776000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
         8416638720*CF*PolyGamma[2, 1] + 400075200*NM*PolyGamma[2, 1] + 
         37108360800*NH*PolyGamma[2, 1] - 84*CA*(161983800*lm^2 - 
           30974643*Pi^2 + 4445000*Sqrt[3]*Pi^3 + 1231605*Pi^4 - 
           32400*lm*(-13381 + 132*Pi^2) + 3429000*Sqrt[3]*Pi*Log[3]^2 - 
           540*(219207 + 440689*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             808380*Im[PolyLog[2, (-1)^(1/3)]]^2 - 304800*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 92776*PolyGamma[2, 1] - 
             439352*Zeta[3])) - 214008480*CF*Zeta[3] - 
         1355356800*NM*Zeta[3] + 6662476800*NL*Zeta[3] + 
         343785758400*NH*Zeta[3] - 37800*Log[x]*
          (16*(-2*(27*NM*(122 + 204*lm + 45*lm^2 + 30*Pi^2) + 27*NL*
                (392 + 204*lm + 45*lm^2 + 30*Pi^2) + NH*(214710 + 5508*lm + 
                 1215*lm^2 - 122200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             3*CF*(-68361 - 55161*lm - 14580*lm^2 + 351*Pi^2 + 5080*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 9720*Zeta[3])) + 
           3*CA*(767505 + 413856*lm + 71280*lm^2 + 4356*Pi^2 - 
             40640*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 77760*Zeta[3]))))/
       2204496000, (-2*CF*NC*(27*CF*(7 + 4*lm) - CA*(76 + 33*lm) + 11*NM + 
          6*lm*NM + 10*NL + 6*lm*NL + 6*lm*NH)*Log[x]^2)/3 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/3 + 
       (CF*NC*Log[x]*(2*(-18*(9*NL*(2917 + 1530*lm + 360*lm^2 + 240*Pi^2) + 
              9*NM*(527 + 1530*lm + 360*lm^2 + 300*Pi^2) + NH*(464871 + 
                13770*lm + 3240*lm^2 - 264400*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) + CF*(-4558719 - 3674160*lm - 
              1049760*lm^2 + 78300*Pi^2 + 575216*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 699840*Zeta[3])) + 
          CA*(6728331 + 3542940*lm + 641520*lm^2 - 19440*Pi^2 - 
            575216*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 699840*Zeta[3])))/
        58320 - (CF*NC*(-28*CA*(1313512200*lm^2 - 198373293*Pi^2 + 
            62914250*Sqrt[3]*Pi^3 + 6790635*Pi^4 - 24300*lm*
             (-136303 + 924*Pi^2) + 48533850*Sqrt[3]*Pi*Log[3]^2 - 
            20*(109156104 + 55393269*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              203522220*Im[PolyLog[2, (-1)^(1/3)]]^2 - 116481240*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 15154420*PolyGamma[2, 
                1] + 26871004*Zeta[3])) - 
          840*(54*NL*(177145 - 147420*lm^2 - 83916*Pi^2 + 30*lm*(-6137 + 
                84*Pi^2) - 419040*Zeta[3]) + 27*NM*(2178005 - 294840*lm^2 - 
              199692*Pi^2 + 60*lm*(-6137 + 84*Pi^2) - 77814*PolyGamma[2, 1] + 
              367092*Zeta[3]) - NH*(-1317371571 + 7960680*lm^2 + 
              34702500*Sqrt[3]*Pi^3 - 1620*lm*(-6137 + 84*Pi^2) - 
              721511952*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1284984000*Sqrt[
                3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 26770500*Sqrt[
                3]*Pi*Log[3]^2 + 146017462*PolyGamma[2, 1] + 1364811884*Zeta[
                3])) + CF*(120365481600*lm^2 - 5046331428*Pi^2 + 
            3523198000*Sqrt[3]*Pi^3 + 197384040*Pi^4 - 12247200*lm*
             (-4903 + 168*Pi^2) + 2717895600*Sqrt[3]*Pi*Log[3]^2 - 
            35*(-4419235737 + 1772584608*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              6512711040*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3727399680*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 484941440*PolyGamma[2, 
                1] + 4114478048*Zeta[3]))))/2204496000, 
      (CF*NC*(307158105240*CF + 269508821400*CF*lm + 332327772000*CF*lm^2 - 
         163972998000*NM + 28819702800*lm*NM + 18462654000*lm^2*NM - 
         16221246300*NL + 28819702800*lm*NL + 18462654000*lm^2*NL - 
         3682273211568*NH + 28819702800*lm*NH + 18462654000*lm^2*NH - 
         37157473359*CF*Pi^2 - 5511240000*CF*lm*Pi^2 + 10486665000*NM*Pi^2 - 
         306180000*lm*NM*Pi^2 + 13012650000*NL*Pi^2 - 
         306180000*lm*NL*Pi^2 - 306180000*lm*NH*Pi^2 + 
         15428789250*Sqrt[3]*CF*Pi^3 + 131245030000*Sqrt[3]*NH*Pi^3 + 
         1915308990*CF*Pi^4 - 315892873800*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] - 1249311252000*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 660356776800*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 571306024800*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 4859815968000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 11902208850*Sqrt[3]*CF*Pi*
          Log[3]^2 + 101246166000*Sqrt[3]*NH*Pi*Log[3]^2 + 
         18370800*(9*CF*(8437 + 4800*lm) - CA*(28513 + 13200*lm) + 
           4*(40*(37 + 15*lm)*NM + 925*NL + 600*lm*NL + 12*NH + 
             600*lm*NH))*Log[x]^2 + 7348320000*(25*CA + 87*CF - 7*NM - 
           4*NL)*Log[x]^3 + 81421803120*CF*PolyGamma[2, 1] + 
         5156377380*NM*PolyGamma[2, 1] + 285940903220*NH*PolyGamma[2, 1] - 
         15*CA*(6769639800*lm^2 - 1534682295*Pi^2 + 514292975*Sqrt[3]*Pi^3 + 
           80173233*Pi^4 - 68040*lm*(-281939 + 1650*Pi^2) + 
           396740295*Sqrt[3]*Pi*Log[3]^2 - 14*(603347625 + 752125890*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 1572278040*Im[PolyLog[2, 
                 (-1)^(1/3)]]^2 - 1360252440*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] - 193861436*PolyGamma[2, 1] - 
             495541972*Zeta[3])) + 1890*Log[x]*
          (2*(41983110*NL + 20377980*lm*NL + 4374000*lm^2*NL + 
             754625238*NH + 20377980*lm*NH + 4374000*lm^2*NH + 
             3402000*NL*Pi^2 + 2430*NM*(8439 + 8386*lm + 1800*lm^2 + 800*
                Pi^2) - 428555200*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
             15*CF*(-26112759 - 20516976*lm - 5248800*lm^2 + 461322*Pi^2 + 
               3358648*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 3499200*
                Zeta[3])) + 15*CA*(-38065389 - 19026252*lm - 3207600*lm^2 + 
             74574*Pi^2 + 3358648*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             3499200*Zeta[3])) - 116427458280*CF*Zeta[3] - 
         107260365240*NM*Zeta[3] + 80831520000*NL*Zeta[3] + 
         1386320606440*NH*Zeta[3]))/1653372000, 
      -(CF*NC*(-12247200*(3*CA*(227979 + 97900*lm) - 
            2*(CF*(861557 + 480600*lm) + (78254 + 26700*lm)*NM + 
              12*(25*(134 + 89*lm)*NL + (54 + 2225*lm)*NH)))*Log[x]^2 + 
          2449440000*(1015*CA + 4288*CF - 302*NM - 178*NL)*Log[x]^3 + 
          3780*Log[x]*(4*(145380825*NL + 69628410*lm*NL + 15309000*lm^
                2*NL + 2382358551*NH + 69628410*lm*NH + 15309000*lm^2*
               NH + 12312000*NL*Pi^2 + 135*NM*(504341 + 515766*lm + 
                113400*lm^2 + 73500*Pi^2) - 1351418800*Sqrt[3]*NH*Im[
                PolyLog[2, (-1)^(1/3)]] - 180*CF*(-7306845 - 5814666*lm - 
                1530900*lm^2 + 119232*Pi^2 + 1199888*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 1020600*Zeta[3])) + 
            45*CA*(-87738519 - 43566156*lm - 7484400*lm^2 + 56844*Pi^2 + 
              9599104*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 8164800*Zeta[
                3])) - 30*CA*(43345902600*lm^2 - 9112426371*Pi^2 + 
            4409588400*Sqrt[3]*Pi^3 + 543842019*Pi^4 - 374220*lm*
             (-317689 + 1500*Pi^2) + 3401682480*Sqrt[3]*Pi*Log[3]^2 - 
            140*(560896731 + 385329321*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              1107837972*Im[PolyLog[2, (-1)^(1/3)]]^2 - 1166291136*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 124385954*PolyGamma[2, 
                1] + 149588684*Zeta[3])) + 
          7*(3*CF*(202656168000*lm^2 - 24623646354*Pi^2 + 12598824000*Sqrt[
                3]*Pi^3 + 1320554340*Pi^4 - 874800*lm*(-166793 + 3000*Pi^2) + 
              9719092800*Sqrt[3]*Pi*Log[3]^2 - 5*(-29758643703 + 
                30826345680*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                88627037760*Im[PolyLog[2, (-1)^(1/3)]]^2 - 93303290880*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                9950876320*PolyGamma[2, 1] + 54491717584*Zeta[3])) - 
            4*(36450*NL*(292561 - 231660*lm^2 - 177580*Pi^2 + 
                lm*(-340538 + 3000*Pi^2) - 1130400*Zeta[3]) + 
              6075*NM*(12619861 - 1389960*lm^2 - 1152948*Pi^2 + 
                12*lm*(-170269 + 1500*Pi^2) - 660006*PolyGamma[2, 1] + 
                10192788*Zeta[3]) - NH*(-1646450875683 + 8444007000*lm^2 + 
                59124572500*Sqrt[3]*Pi^3 - 72900*lm*(-170269 + 1500*Pi^2) - 
                661695942000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                2189298456000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                45610384500*Sqrt[3]*Pi*Log[3]^2 + 149374009190*PolyGamma[2, 
                  1] + 800988194380*Zeta[3])))))/9920232000, 
      (CF*NC*(228020351110965*CF + 677210341613400*CF*lm + 
         785280605004000*CF*lm^2 - 555527269495800*NM + 
         70342821964800*lm*NM + 43626700278000*lm^2*NM - 
         75350763280800*NL + 70342821964800*lm*NL + 43626700278000*lm^2*
          NL - 10572457858689024*NH + 70342821964800*lm*NH + 
         43626700278000*lm^2*NH - 151725027836529*CF*Pi^2 - 
         9721827360000*CF*lm*Pi^2 + 163830794400*NM*Pi^2 - 
         540101520000*lm*NM*Pi^2 + 38824297596000*NL*Pi^2 - 
         540101520000*lm*NL*Pi^2 - 540101520000*lm*NH*Pi^2 + 
         65025190545000*Sqrt[3]*CF*Pi^3 + 422230256000000*Sqrt[3]*NH*Pi^3 + 
         7620224832990*CF*Pi^4 - 841889888758800*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] - 3240490098451200*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 1825321695976800*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 2407789912752000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 15634583193600000*Sqrt[3]*
          NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 50162289849000*Sqrt[3]*
          CF*Pi*Log[3]^2 + 325720483200000*Sqrt[3]*NH*Pi*Log[3]^2 + 
         771573600*(-385*CA*(7117 + 3270*lm) + 7*CF*(1038191 + 588600*lm) + 
           6*(7*(5409 + 5450*lm)*NM + 350*(158 + 109*lm)*NL + 
             (1707 + 38150*lm)*NH))*Log[x]^2 + 270050760000*
          (2763*CA + 12164*CF - 1820*NM - 436*NL)*Log[x]^3 + 
         262372972814400*CF*PolyGamma[2, 1] - 16457703466680*NM*
          PolyGamma[2, 1] + 786667024257520*NH*PolyGamma[2, 1] - 
         735*CA*(326458301400*lm^2 - 98756040780*Pi^2 + 44234823500*Sqrt[3]*
            Pi^3 + 5771692017*Pi^4 - 3674160*lm*(-256349 + 1100*Pi^2) + 
           34124006700*Sqrt[3]*Pi*Log[3]^2 - 280*(2577788001 + 
             2045407893*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             4434697998*Im[PolyLog[2, (-1)^(1/3)]]^2 - 5849829720*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 637446484*
              PolyGamma[2, 1] - 543210248*Zeta[3])) + 
         1890*Log[x]*(2*(8*(119070*NM*(84062 + 68205*lm + 14175*lm^2 - 
                 13620*Pi^2) + 59535*NL*(305647 + 136410*lm + 28350*lm^2 + 
                 25800*Pi^2) + 2*NH*(152051248344 + 4060584675*lm + 
                 843908625*lm^2 - 86169440000*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) - 735*CF*(-1702754817 - 1343080440*lm - 
               330674400*lm^2 + 32200416*Pi^2 + 288880480*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 220449600*Zeta[3])) + 
           735*CA*(-2544043821 - 1229521680*lm - 202078800*lm^2 + 
             4954284*Pi^2 + 288880480*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             220449600*Zeta[3])) - 669874090723320*CF*Zeta[3] - 
         569884338117360*NM*Zeta[3] + 285173602560000*NL*Zeta[3] + 
         2002282675699040*NH*Zeta[3]))/729137052000, 
      (CF*NC*(-2314720800*(-35*CA*(779239 + 307626*lm) + 
           3*(7*CF*(3245843 + 1677960*lm) + 28*(44452 + 23305*lm)*NM + 
             924805*NL + 652540*lm*NL + 34248*NH + 652540*lm*NH))*
          Log[x]^2 - 324060912000*(50095*CA + 294875*CF - 38012*NM - 
           9322*NL)*Log[x]^3 - 49*CF*(356503377384000*lm^2 - 
           54995970475422*Pi^2 + 36077956400500*Sqrt[3]*Pi^3 + 
           3905529203520*Pi^4 - 744017400*lm*(-384423 + 5000*Pi^2) + 
           27831566366100*Sqrt[3]*Pi*Log[3]^2 + 7*(7805291017113 - 
             48880961884200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             127709098675200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             190845026510400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             20302402905800*PolyGamma[2, 1] - 93704336587280*Zeta[3])) + 
         3780*Log[x]*(18*(-15876*NM*(9329807 + 5397915*lm + 1134000*lm^2 - 
               947550*Pi^2) - 19845*NL*(9911539 + 4318332*lm + 907200*lm^2 + 
               861720*Pi^2) - 2*NH*(1537074261489 + 42848649270*lm + 
               9001692000*lm^2 - 870103211600*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]])) + 49*CF*(-617105039109 - 477369437040*lm - 
             119042784000*lm^2 + 4757118660*Pi^2 + 117805571920*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 79361856000*Zeta[3]) + 
           98*CA*(232937148561 + 109718968770*lm + 18187092000*lm^2 + 
             1362665025*Pi^2 - 29451392980*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 19840464000*Zeta[3])) + 
         49*CA*(108931587534000*lm^2 - 23502840345585*Pi^2 + 
           18038978200250*Sqrt[3]*Pi^3 + 2118101801760*Pi^4 - 
           227338650*lm*(-1353633 + 5000*Pi^2) + 13915783183050*Sqrt[3]*Pi*
            Log[3]^2 - 7*(41425339133511 + 24440480942100*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 63854549337600*
              Im[PolyLog[2, (-1)^(1/3)]]^2 - 95422513255200*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 10151201452900*
              PolyGamma[2, 1] + 15674948194600*Zeta[3])) + 
         3*(18753525*NL*(39381181 - 17249760*lm^2 - 16467000*Pi^2 + 
             36*lm*(-743793 + 5000*Pi^2) - 126247680*Zeta[3]) + 
           4500846*NM*(952930737 - 71874000*lm^2 - 28374100*Pi^2 + 
             150*lm*(-743793 + 5000*Pi^2) + 14966520*PolyGamma[2, 1] + 
             1104173040*Zeta[3]) - 2*NH*(-39747201543253809 + 
             161746902702000*lm^2 + 1598814651315000*Sqrt[3]*Pi^3 - 
             337563450*lm*(-743793 + 5000*Pi^2) - 13474444520653200*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 59201822517264000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1233371302443000*
              Sqrt[3]*Pi*Log[3]^2 + 3244963157060800*PolyGamma[2, 1] + 
             9652220713721600*Zeta[3]))))/8749644624000, 
      (CF*NC*(-2645395200*(CA*(56318069 + 25100460*lm) - 
           2*(28*CF*(2642423 + 1466910*lm) + 3*(6*(-665029 + 126770*lm)*NM + 
               105*(10059 + 7244*lm)*NL + 20*(2719 + 38031*lm)*NH)))*
          Log[x]^2 + 740710656000*(67724*CA + 376963*CF - 99240*NM - 
           10866*NL)*Log[x]^3 - 21*CA*(-1692556695914733 + 
           511130033568000*lm^2 - 197230685518800*Pi^2 + 104642277264000*
            Sqrt[3]*Pi^3 + 12255630972480*Pi^4 - 47239200*lm*
            (-31472963 + 107800*Pi^2) - 1028835722505600*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 2224957250073600*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 3874754038118400*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 80724042460800*Sqrt[3]*Pi*
            Log[3]^2 + 389375229021440*PolyGamma[2, 1] - 128573486213120*
            Zeta[3]) - 136080*Log[x]*
          (2*(4*(-486*NM*(7659997 + 26165310*lm + 5292000*lm^2 - 
                 26054700*Pi^2) - 5*(243*NL*(25598377 + 10466124*lm + 
                   2116800*lm^2 + 2226840*Pi^2) + 2*NH*(49560001455 + 
                   1271634066*lm + 257191200*lm^2 - 28039032560*Sqrt[3]*
                    Im[PolyLog[2, (-1)^(1/3)]]))) + 3*CF*(-318961435341 - 
               258897759840*lm - 61725888000*lm^2 + 5366165760*Pi^2 + 
               66439541120*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 41150592000*
                Zeta[3])) + 3*CA*(489531085221 + 234515353680*lm + 
             37721376000*lm^2 + 412426080*Pi^2 - 66439541120*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 41150592000*Zeta[3])) + 
         2*(3*CF*(-1752353076378681 + 5854762202688000*lm^2 - 
             1583452284957936*Pi^2 + 732495940848000*Sqrt[3]*Pi^3 + 
             80604442215360*Pi^4 - 5952139200*lm*(-871543 + 9800*Pi^2) - 
             7201850057539200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             15574700750515200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             27123278266828800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] + 565068297225600*Sqrt[3]*Pi*Log[3]^2 + 
             2725626603150080*PolyGamma[2, 1] - 8761455420273920*Zeta[3]) - 
           8*(1653372*NM*(-73773000*lm^2 + 75*lm*(-1609273 + 9800*Pi^2) + 2*
                (528410624 + 132365825*Pi^2 + 169447830*PolyGamma[2, 1] + 
                 809631660*Zeta[3])) + 5*(688905*NL*(113571223 - 
                 35411040*lm^2 - 37949640*Pi^2 + 36*lm*(-1609273 + 
                   9800*Pi^2) - 324898560*Zeta[3]) - 2*NH*
                (-3659605183254753 + 12197421255600*lm^2 + 154565166987000*
                  Sqrt[3]*Pi^3 - 12400290*lm*(-1609273 + 9800*Pi^2) - 
                 1045913089278960*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                 5723327326147200*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                      Sqrt[3])]] + 119235985961400*Sqrt[3]*Pi*Log[3]^2 + 
                 262561756221632*PolyGamma[2, 1] + 302493665899264*
                  Zeta[3]))))))/8571080448000, 
      (17101921833273966757*CF^2*NC)/3499857849600000 - 
       (11647553*CF^2*lm*NC)/2000 - (69069*CF^2*lm^2*NC)/10 + 
       (2168680198151*CF*NM*NC)/370440000 - (22007903*CF*lm*NM*NC)/36000 - 
       (23023*CF*lm^2*NM*NC)/60 + (29636485481*CF*NC*NL)/19440000 - 
       (22007903*CF*lm*NC*NL)/36000 - (23023*CF*lm^2*NC*NL)/60 + 
       (3536942103897917*CF*NC*NH)/29760696000 - (22007903*CF*lm*NC*NH)/
        36000 - (23023*CF*lm^2*NC*NH)/60 + (3763541983*CF^2*NC*Pi^2)/
        27216000 + (1813*CF^2*lm*NC*Pi^2)/30 + (34752223*CF*NM*NC*Pi^2)/
        32400 + (1813*CF*lm*NM*NC*Pi^2)/540 - (14167337*CF*NC*NL*Pi^2)/
        32400 + (1813*CF*lm*NC*NL*Pi^2)/540 + (1813*CF*lm*NC*NH*Pi^2)/540 - 
       (2314485664477*CF^2*NC*Pi^3)/(765275040*Sqrt[3]) - 
       (193220191241*CF*NC*NH*Pi^3)/(12754584*Sqrt[3]) - 
       (569303*CF^2*NC*Pi^4)/5400 + (76963344961529*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3188646000*Sqrt[3]) + 
       (231373228657*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2125764*Sqrt[3]) - 19586*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (330640809211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2952450*Sqrt[3]) - (55205768926*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(98415*Sqrt[3]) - 
       (330640809211*CF^2*NC*Pi*Log[3]^2)/(141717600*Sqrt[3]) - 
       (27602884463*CF*NC*NH*Pi*Log[3]^2)/(2361960*Sqrt[3]) - 
       (CF*NC*(-30*CA*(579515591 + 187407220*lm) + 
          37*CF*(1136642963 + 497296800*lm) + 
          60*(4*(-13210033 + 4259255*lm)*NM + 
            7*((3318047 + 2433860*lm)*NL + 20*(9836 + 121693*lm)*NH)))*
         Log[x]^2)/378000 - (CF*NC*(5089835*CA + 
          2*(24926952*CF - 65*(82010*NM + 9361*NL)))*Log[x]^3)/675 - 
       (28409919386447*CF^2*NC*PolyGamma[2, 1])/5739562800 + 
       (10364903*CF*NM*NC*PolyGamma[2, 1])/5400 - 
       (1083812679038*CF*NC*NH*PolyGamma[2, 1])/119574225 + 
       (CA*CF*NC*(-6991958720003140143 + 1661905312471404000*lm^2 + 
          71437358826551970*Pi^2 + 396934291457805500*Sqrt[3]*Pi^3 + 
          43625071871917200*Pi^4 - 40102537860*lm*(-118767309 + 
            362600*Pi^2) - 3167811278616533640*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 7711674282254880000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 14697909763694740800*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 306206453410307100*Sqrt[3]*
           Pi*Log[3]^2 + 1948920469910264200*PolyGamma[2, 1] - 
          2970154838488978000*Zeta[3]))/787468016160000 + 
       (10071004274753*CF^2*NC*Zeta[3])/573956280 + 
       (26591303*CF*NM*NC*Zeta[3])/2700 - (176426*CF*NC*NL*Zeta[3])/45 - 
       (1598960458966*CF*NC*NH*Zeta[3])/119574225 - 
       (CF*NC*Log[x]*(-120*(-8748*NM*(12383135392 + 5738636715*lm + 
              1166886000*lm^2 - 5664652350*Pi^2) - 
            49*(2187*NL*(1179436363 + 468460140*lm + 95256000*lm^2 + 
                104767800*Pi^2) + 10*NH*(3906873163023 + 102452232618*lm + 
                20832487200*lm^2 - 2208230757040*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]]))) - 20*CA*(4903149328106523 + 
            2085385188009060*lm + 336861318024000*lm^2 + 101069361396990*
             Pi^2 - 648055986053560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            367485074208000*Zeta[3]) + CF*(133187637473840193 + 
            91898614663531200*lm + 22049104452480000*lm^2 + 
            1884599380944000*Pi^2 - 25922239442142400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 14699402968320000*Zeta[3])))/
        2083248720000, (-20283864332391673061*CF^2*NC)/1749928924800000 + 
       (8420131*CF^2*lm*NC)/750 + (62454*CF^2*lm^2*NC)/5 + 
       (3048620120687*CF*NM*NC)/555660000 + (7723103*CF*lm*NM*NC)/6750 + 
       (10409*CF*lm^2*NM*NC)/15 - (555453829*CF*NC*NL)/151875 + 
       (7723103*CF*lm*NC*NL)/6750 + (10409*CF*lm^2*NC*NL)/15 - 
       (2240976028100923098529*CF*NC*NH)/8734332745908000 + 
       (7723103*CF*lm*NC*NH)/6750 + (10409*CF*lm^2*NC*NH)/15 - 
       (31993946561*CF^2*NC*Pi^2)/7484400 - (1568*CF^2*lm*NC*Pi^2)/15 - 
       (28074556*CF*NM*NC*Pi^2)/2025 - (784*CF*lm*NM*NC*Pi^2)/135 + 
       (1760024*CF*NC*NL*Pi^2)/2025 - (784*CF*lm*NC*NL*Pi^2)/135 - 
       (784*CF*lm*NC*NH*Pi^2)/135 + (4957943539843*CF^2*NC*Pi^3)/
        (765275040*Sqrt[3]) + (481546258571*CF*NC*NH*Pi^3)/
        (14348907*Sqrt[3]) + (1205869*CF^2*NC*Pi^4)/5400 - 
       (169746365295701*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (3188646000*Sqrt[3]) - (5008910830912*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
       (187054*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (708277648549*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2952450*Sqrt[3]) + (1100677162448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(885735*Sqrt[3]) + 
       (708277648549*CF^2*NC*Pi*Log[3]^2)/(141717600*Sqrt[3]) + 
       (68792322653*CF*NC*NH*Pi*Log[3]^2)/(2657205*Sqrt[3]) + 
       (CF*NC*(-55*CA*(5895586861 + 2540408640*lm) + 
          8*(11*CF*(9589004749 + 5196290400*lm) + 
            10*(33*(-241792361 + 9622760*lm)*NM + 462*(925993 + 687340*lm)*
               NL + 5*(6218561 + 63510216*lm)*NH)))*Log[x]^2)/4158000 + 
       (8*CF*NC*(2068475*CA + 14386656*CF - 6999400*NM - 343670*NL)*
         Log[x]^3)/675 + (3087236867372*CF^2*NC*PolyGamma[2, 1])/358722675 - 
       (2204294*CF*NM*NC*PolyGamma[2, 1])/135 + 
       (38405009312171*CF*NC*NH*PolyGamma[2, 1])/2152336050 - 
       (CA*CF*NC*(-34596617169339414846 + 7513691698525320000*lm^2 - 
          3505440470729247225*Pi^2 + 2125718292707686250*Sqrt[3]*Pi^3 + 
          228957237119835000*Pi^4 - 145827410400*lm*(-150530833 + 
            431200*Pi^2) - 17466900988927632900*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 36824760573698160000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 78712311638547468000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1639839825803072250*
           Sqrt[3]*Pi*Log[3]^2 + 8471377964068768000*PolyGamma[2, 1] - 
          7533198444869062000*Zeta[3]))/1968670040400000 - 
       (19750982282833*CF^2*NC*Zeta[3])/717445350 - 
       (3357988*CF*NM*NC*Zeta[3])/135 + (383912*CF*NC*NL*Zeta[3])/45 + 
       (4378712754491*CF*NC*NH*Zeta[3])/1076168025 + 
       CF*Log[x]*((-76320871511*NM*NC)/1984500 + (4011952*lm*NM*NC)/675 + 
         1176*lm^2*NM*NC + (320909147*NC*NL)/20250 + (4011952*lm*NC*NL)/
          675 + 1176*lm^2*NC*NL + (76994667681235067*NC*NH)/315091368900 + 
         (4011952*lm*NC*NH)/675 + 1176*lm^2*NC*NH - (2514476*NM*NC*Pi^2)/
          135 + (190388*NC*NL*Pi^2)/135 - (1100677162448*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) + 
         CA*NC*(-28936550522991773/347208120000 - (27622336*lm)/675 - 
           6468*lm^2 - (1767919*Pi^2)/3600 + 
           (708277648549*Im[PolyLog[2, (-1)^(1/3)]])/(17714700*Sqrt[3]) - 
           7056*Zeta[3]) + CF*NC*(36143187613385917/347208120000 + 
           (6833204*lm)/75 + 21168*lm^2 - (746969*Pi^2)/600 - 
           (708277648549*Im[PolyLog[2, (-1)^(1/3)]])/(8857350*Sqrt[3]) + 
           14112*Zeta[3])), (924665687241999656929*CF^2*NC)/
        15749360323200000 - (229794283*CF^2*lm*NC)/13500 - 
       19642*CF^2*lm^2*NC - (324040942491361*CF*NM*NC)/38578680000 - 
       (428669533*CF*lm*NM*NC)/243000 - (9821*CF*lm^2*NM*NC)/9 + 
       (49871142907*CF*NC*NL)/7290000 - (428669533*CF*lm*NC*NL)/243000 - 
       (9821*CF*lm^2*NC*NL)/9 + (22025171208452682472061*CF*NC*NH)/
        52405996475448000 - (428669533*CF*lm*NC*NH)/243000 - 
       (9821*CF*lm^2*NC*NH)/9 - (70585836731*CF^2*NC*Pi^2)/4158000 + 
       (6664*CF^2*lm*NC*Pi^2)/45 + (223799201*CF*NM*NC*Pi^2)/12150 + 
       (3332*CF*lm*NM*NC*Pi^2)/405 - (5846923*CF*NC*NL*Pi^2)/4050 + 
       (3332*CF*lm*NC*NL*Pi^2)/405 + (3332*CF*lm*NC*NH*Pi^2)/405 - 
       (15915453742363*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (2378046066053*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (6210323*CF^2*NC*Pi^4)/16200 + (470200235747381*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5739562800*Sqrt[3]) + 
       (5156267512106*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (14348907*Sqrt[3]) - (310982*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (2273636248909*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5314410*Sqrt[3]) - (5435533865264*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (2273636248909*CF^2*NC*Pi*Log[3]^2)/(255091680*Sqrt[3]) - 
       (339720866579*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-33*CA*(325616541067 + 67416333600*lm) + 
          8*(66*CF*(46238498207 + 13789704600*lm) + 
            385*(-2416486427 + 131330520*lm)*NM + 67124832390*NL + 
            50562250200*lm*NL + 5446652275*NH + 50562250200*lm*NH))*
         Log[x]^2)/37422000 - (4*CF*NC*(1017417*CA + 203387753*CF - 
          67817600*NM - 3648070*NL)*Log[x]^3)/2025 - 
       (214531920808919*CF^2*NC*PolyGamma[2, 1])/6457008150 + 
       (78061639*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (394028753559703*CF*NC*NH*PolyGamma[2, 1])/12914016300 + 
       (CA*CF*NC*(-873757178311900893174 + 106338696567226200000*lm^2 + 
          162118693584178992675*Pi^2 + 34118753960190681250*Sqrt[3]*Pi^3 + 
          3512747716689519000*Pi^4 - 36456852600*lm*(-8427702863 + 
            21991200*Pi^2) - 241918021292027524500*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 550998851853305520000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 1263368718068774940000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 26320181626432811250*
           Sqrt[3]*Pi*Log[3]^2 + 294337795349836868000*PolyGamma[2, 1] - 
          292850662217567174000*Zeta[3]))/17718030363600000 + 
       (431067069882299*CF^2*NC*Zeta[3])/6457008150 + 
       (67948039*CF*NM*NC*Zeta[3])/1350 - (667252*CF*NC*NL*Zeta[3])/45 - 
       (93013301046823*CF*NC*NH*Zeta[3])/6457008150 + 
       CF*Log[x]*((-320448349*NM*NC)/7654500 - (2222599*lm*NM*NC)/225 - 
         1960*lm^2*NM*NC - (550064287*NC*NL)/20250 - (2222599*lm*NC*NL)/
          225 - 1960*lm^2*NC*NL - (380520910374303029*NC*NH)/945274106700 - 
         (2222599*lm*NC*NH)/225 - 1960*lm^2*NC*NH + (11975348*NM*NC*Pi^2)/
          405 - (994214*NC*NL*Pi^2)/405 + (5435533865264*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-1012541013784499777/3124873080000 - (3783698*lm)/25 - 
           35280*lm^2 - (302671057*Pi^2)/16200 + 
           (2273636248909*Im[PolyLog[2, (-1)^(1/3)]])/(15943230*Sqrt[3]) - 
           23520*Zeta[3]) + CA*NC*(673919164614516277/3124873080000 + 
           (30622589*lm)/450 + 10780*lm^2 + (121849889*Pi^2)/10800 - 
           (2273636248909*Im[PolyLog[2, (-1)^(1/3)]])/(31886460*Sqrt[3]) + 
           11760*Zeta[3])), (-874768377670873972409*CF^2*NC)/
        15749360323200000 + (132689651*CF^2*lm*NC)/4500 + 
       (162666*CF^2*lm^2*NC)/5 + (891940750023733*CF*NM*NC)/3214890000 + 
       (242489201*CF*lm*NM*NC)/81000 + (9037*CF*lm^2*NM*NC)/5 - 
       (8679952631*CF*NC*NL)/607500 + (242489201*CF*lm*NC*NL)/81000 + 
       (9037*CF*lm^2*NC*NL)/5 - (3348617254197941105209493*CF*NC*NH)/
        4111999080591402000 + (242489201*CF*lm*NC*NH)/81000 + 
       (9037*CF*lm^2*NC*NH)/5 - (588995083847*CF^2*NC*Pi^2)/37422000 - 
       (1176*CF^2*lm*NC*Pi^2)/5 - (340485541*CF*NM*NC*Pi^2)/2025 - 
       (196*CF*lm*NM*NC*Pi^2)/15 + (1165477*CF*NC*NL*Pi^2)/450 - 
       (196*CF*lm*NC*NL*Pi^2)/15 - (196*CF*lm*NC*NH*Pi^2)/15 + 
       (151795911169903*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) + 
       (4677438945928*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) + 
       (1288931*CF^2*NC*Pi^4)/1800 - (4603214065851761*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(28697814000*Sqrt[3]) - 
       (46065880641364*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (71744535*Sqrt[3]) + 108318*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (21685130167129*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) + (10691289019264*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) + 
       (21685130167129*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) + 
       (668205563704*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) + 
       (CF*NC*(-2145*CA*(20288486177 + 8945761440*lm) + 
          16*(429*CF*(16567002751 + 9149074200*lm) + 
            35*(143*(-3985585207 + 43567020*lm)*NM + 1287*(6379721 + 
                4840780*lm)*NL + 5*(153189433 + 1246016772*lm)*NH)))*
         Log[x]^2)/162162000 + (CF*NC*(57367903*CA + 473193370*CF - 
          502483800*NM - 9681560*NL)*Log[x]^3)/675 + 
       (24703534226323*CF^2*NC*PolyGamma[2, 1])/645700815 - 
       (516438833*CF*NM*NC*PolyGamma[2, 1])/2700 + 
       (142392376833491*CF*NC*NH*PolyGamma[2, 1])/2582803260 - 
       (107957080617233*CF^2*NC*Zeta[3])/1291401630 - 
       (181614833*CF*NM*NC*Zeta[3])/1350 + (1292732*CF*NC*NL*Zeta[3])/45 - 
       (6049265110025*CF*NC*NH*Zeta[3])/258280326 + 
       CA*CF*NC*(61077770593517878663/984335020200000 - (99407*lm^2)/10 + 
         (94232350691*Pi^2)/14256000 - (151795911169903*Pi^3)/
          (13774950720*Sqrt[3]) - (1326563*Pi^4)/3600 + 
         lm*(-4716972811/162000 + (1078*Pi^2)/15) + 
         (4603214065851761*Im[PolyLog[2, (-1)^(1/3)]])/(57395628000*
           Sqrt[3]) - 54159*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (21685130167129*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (53144100*Sqrt[3]) - (21685130167129*Pi*Log[3]^2)/
          (2550916800*Sqrt[3]) - (24703534226323*PolyGamma[2, 1])/
          1291401630 + (57828019887901*Zeta[3])/5165606520) + 
       CF*Log[x]*((-920391533431*NM*NC)/1275750 + (1361293*lm*NM*NC)/75 + 
         3528*lm^2*NM*NC + (236596051*NC*NL)/4500 + (1361293*lm*NC*NL)/
          75 + 3528*lm^2*NC*NL + (18071873627907696799*NC*NH)/
          22821617718900 + (1361293*lm*NC*NH)/75 + 3528*lm^2*NC*NH - 
         (8069992*NM*NC*Pi^2)/45 + (642838*NC*NL*Pi^2)/135 - 
         (10691289019264*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7971615*Sqrt[3]) + CA*NC*(-689795802228688559/3124873080000 - 
           (18678623*lm)/150 - 19404*lm^2 - (5595317*Pi^2)/2160 + 
           (21685130167129*Im[PolyLog[2, (-1)^(1/3)]])/(159432300*Sqrt[3]) - 
           21168*Zeta[3]) + CF*NC*(757916435724833941/3124873080000 + 
           (6977058*lm)/25 + 63504*lm^2 - (4058047*Pi^2)/1800 - 
           (21685130167129*Im[PolyLog[2, (-1)^(1/3)]])/(79716150*Sqrt[3]) + 
           42336*Zeta[3])), (267599976208214614989844319*CF^2*NC)/
        440210370393763200000 - (9430046417*CF^2*lm*NC)/220500 - 
       (242658*CF^2*lm^2*NC)/5 - (48277715046890672657*CF*NM*NC)/
        119812520520000 - (17455959767*CF*lm*NM*NC)/3969000 - 
       (13481*CF*lm^2*NM*NC)/5 + (2937954295463*CF*NC*NL)/119070000 - 
       (17455959767*CF*lm*NC*NL)/3969000 - (13481*CF*lm^2*NC*NL)/5 + 
       (13304765320492584515956597*CF*NC*NH)/10466906750596296000 - 
       (17455959767*CF*lm*NC*NH)/3969000 - (13481*CF*lm^2*NC*NH)/5 - 
       (23183334580277*CF^2*NC*Pi^2)/87318000 + (1608*CF^2*lm*NC*Pi^2)/5 + 
       (5669949527*CF*NM*NC*Pi^2)/28350 + (268*CF*lm*NM*NC*Pi^2)/15 - 
       (12787277*CF*NC*NL*Pi^2)/3150 + (268*CF*lm*NC*NL*Pi^2)/15 + 
       (268*CF*lm*NC*NH*Pi^2)/15 - (251942871849047*CF^2*NC*Pi^3)/
        (6887475360*Sqrt[3]) - (7330645203119*CF*NC*NH*Pi^3)/
        (43046721*Sqrt[3]) - (691321*CF^2*NC*Pi^4)/600 + 
       (1008482452757197123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (4218578658000*Sqrt[3]) + (74420151271366*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) - 
       (848934*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (251942871849047*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (186004350*Sqrt[3]) - (16755760464272*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (251942871849047*CF^2*NC*Pi*Log[3]^2)/(8928208800*Sqrt[3]) - 
       (1047235029017*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-39*CA*(64031671478741 + 5716272223200*lm) + 
          40*(39*CF*(3390987813901 + 467695000080*lm) + 
            7*(13*(-723421515679 + 11135595240*lm)*NM + 
              11*(1638*(10464293 + 8034340*lm)*NL + 5*(349149901 + 
                  2632049784*lm)*NH))))*Log[x]^2)/1135134000 + 
       (2*CF*NC*(794933799*CA + 28*(-183926261*CF + 86908650*NM + 
            2008585*NL))*Log[x]^3)/4725 - (5371719412386529*CF^2*NC*
         PolyGamma[2, 1])/19371024450 + (857173961*CF*NM*NC*PolyGamma[2, 1])/
        2700 - (3441039436652939*CF*NC*NH*PolyGamma[2, 1])/38742048900 + 
       CA*CF*NC*(-1974957291135237195166577/5502629629922040000 + 
         (148291*lm^2)/10 + (18841253198137*Pi^2)/139708800 + 
         (251942871849047*Pi^3)/(13774950720*Sqrt[3]) + (708473*Pi^4)/1200 + 
         lm*(341832606637/7938000 - (1474*Pi^2)/15) - 
         (1008482452757197123*Im[PolyLog[2, (-1)^(1/3)]])/
          (8437157316000*Sqrt[3]) + (424467*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (251942871849047*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (372008700*Sqrt[3]) + (251942871849047*Pi*Log[3]^2)/
          (17856417600*Sqrt[3]) + (5371719412386529*PolyGamma[2, 1])/
          38742048900 - (6553853799190981*Zeta[3])/108477736920) + 
       (29711332243598359*CF^2*NC*Zeta[3])/135597171150 + 
       (438498761*CF*NM*NC*Zeta[3])/1350 - (2115476*CF*NC*NL*Zeta[3])/45 + 
       (406851853734181*CF*NC*NH*Zeta[3])/19371024450 + 
       CF*Log[x]*((17815785144173*NM*NC)/44104500 - (14951663*lm*NM*NC)/
          525 - 5544*lm^2*NM*NC - (2010817862*NC*NL)/23625 - 
         (14951663*lm*NC*NL)/525 - 5544*lm^2*NC*NL - 
         (18034553268696097963*NC*NH)/14522847639300 - (14951663*lm*NC*NH)/
          525 - 5544*lm^2*NC*NH + (11062636*NM*NC*Pi^2)/45 - 
         (1052914*NC*NL*Pi^2)/135 + (16755760464272*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-6098128089888296580359/2646767498760000 - 
           (76612278*lm)/175 - 99792*lm^2 - (989898437*Pi^2)/4200 + 
           (251942871849047*Im[PolyLog[2, (-1)^(1/3)]])/(558013050*Sqrt[3]) - 
           66528*Zeta[3]) + CA*NC*(496190010999936733201/378109642680000 + 
           (205216693*lm)/1050 + 30492*lm^2 + (9370199159*Pi^2)/75600 - 
           (251942871849047*Im[PolyLog[2, (-1)^(1/3)]])/(1116026100*
             Sqrt[3]) + 33264*Zeta[3])), 
      (-14392834434554843126116199*CF^2*NC)/88042074078752640000 + 
       (302709817*CF^2*lm*NC)/4410 + 75342*CF^2*lm^2*NC + 
       (9114468332920919281*CF*NM*NC)/2396250410400 + 
       (275951741*CF*lm*NM*NC)/39690 + (12557*CF*lm^2*NM*NC)/3 - 
       (110735707651*CF*NC*NL)/2381400 + (275951741*CF*lm*NC*NL)/39690 + 
       (12557*CF*lm^2*NC*NL)/3 - (235173833966218277750993279*CF*NC*NH)/
        103622376830903330400 + (275951741*CF*lm*NC*NH)/39690 + 
       (12557*CF*lm^2*NC*NH)/3 - (270265846921111*CF^2*NC*Pi^2)/2554051500 - 
       480*CF^2*lm*NC*Pi^2 - (5210233514*CF*NM*NC*Pi^2)/2835 - 
       (80*CF*lm*NM*NC*Pi^2)/3 + (425428*CF*NC*NL*Pi^2)/63 - 
       (80*CF*lm*NC*NL*Pi^2)/3 - (80*CF*lm*NC*NH*Pi^2)/3 + 
       (441527225583907*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) + 
       (39633687581915*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) + 
       (10641061*CF^2*NC*Pi^4)/5400 - (1810675055734537523*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4218578658000*Sqrt[3]) - 
       (1127331396310552*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (645700815*Sqrt[3]) + (1380094*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 + (441527225583907*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (186004350*Sqrt[3]) + (18118257180304*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (441527225583907*CF^2*NC*Pi*Log[3]^2)/(8928208800*Sqrt[3]) + 
       (1132391073769*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       (CF*NC*(-13*CA*(118450280051273 + 93374492904000*lm) + 
          16*(13*CF*(22886623229329 + 19099328094000*lm) + 
            525*(13*(-682917753559 + 2021092920*lm)*NM + 18018*(1890359 + 
                1458220*lm)*NL + (3841513759 + 26274207960*lm)*NH)))*
         Log[x]^2)/3405402000 + (2*CF*NC*(2303825767*CA + 
          6*(2682466047*CF - 700*(11701452*NM + 72911*NL)))*Log[x]^3)/
        14175 + (5448481212176396*CF^2*NC*PolyGamma[2, 1])/29056536675 - 
       (2720839687*CF*NM*NC*PolyGamma[2, 1])/1350 + 
       (13081777030662898*CF*NC*NH*PolyGamma[2, 1])/87169610025 + 
       CA*CF*NC*(58959384090045373959667/343914351870127500 - 
         (138127*lm^2)/6 + (103267342894649*Pi^2)/2095632000 - 
         (441527225583907*Pi^3)/(13774950720*Sqrt[3]) - 
         (10871461*Pi^4)/10800 + lm*(-5361276691/79380 + (440*Pi^2)/3) + 
         (1810675055734537523*Im[PolyLog[2, (-1)^(1/3)]])/
          (8437157316000*Sqrt[3]) - (690047*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (441527225583907*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (372008700*Sqrt[3]) - (441527225583907*Pi*Log[3]^2)/
          (17856417600*Sqrt[3]) - (2724240606088198*PolyGamma[2, 1])/
          29056536675 - (103213096945568917*Zeta[3])/1627166053800) - 
       (647631228763723*CF^2*NC*Zeta[3])/16271660538 - 
       (640421887*CF*NM*NC*Zeta[3])/675 + (752488*CF*NC*NL*Zeta[3])/9 - 
       (11877263753584204*CF*NC*NH*Zeta[3])/87169610025 + 
       CF*Log[x]*((-816241773668117*NM*NC)/86444820 + (5064572*lm*NM*NC)/
          105 + 9240*lm^2*NM*NC + (142852177*NC*NL)/945 + 
         (5064572*lm*NC*NL)/105 + 9240*lm^2*NC*NL + 
         (1072552435114098214733*NC*NH)/479253972096900 + 
         (5064572*lm*NC*NH)/105 + 9240*lm^2*NC*NH - (15434612*NM*NC*Pi^2)/
          9 + (374804*NC*NL*Pi^2)/27 - (18118257180304*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CA*NC*(-92408460856580143327/529353499752000 - (34646546*lm)/105 - 
           50820*lm^2 + (1862665463*Pi^2)/226800 + 
           (441527225583907*Im[PolyLog[2, (-1)^(1/3)]])/(1116026100*
             Sqrt[3]) - 55440*Zeta[3]) + CF*NC*(-75339176313347656499/
            378109642680000 + (26021532*lm)/35 + 166320*lm^2 - 
           (57317431*Pi^2)/1512 - (441527225583907*Im[PolyLog[2, (-1)^
                (1/3)]])/(558013050*Sqrt[3]) + 110880*Zeta[3])), 
      (23227573158672520196703562915223*CF^2*NC)/3481711861518351901440000 - 
       (13554476273*CF^2*lm*NC)/141120 - (215631*CF^2*lm^2*NC)/2 - 
       (4110016607119323956546353*CF*NM*NC)/842329944263808000 - 
       (24965668793*CF*lm*NM*NC)/2540160 - (23959*CF*lm^2*NM*NC)/4 + 
       (11514045366577*CF*NC*NL)/152409600 - (24965668793*CF*lm*NC*NL)/
        2540160 - (23959*CF*lm^2*NC*NL)/4 + (5132095780803743010744041017*CF*
         NC*NH)/1507234572085866624000 - (24965668793*CF*lm*NC*NH)/
        2540160 - (23959*CF*lm^2*NC*NH)/4 - (1204411146121121*CF^2*NC*Pi^2)/
        370656000 + (1275*CF^2*lm*NC*Pi^2)/2 + (17042475559*CF*NM*NC*Pi^2)/
        9072 + (425*CF*lm*NM*NC*Pi^2)/12 - (5094953*CF*NC*NL*Pi^2)/504 + 
       (425*CF*lm*NC*NL*Pi^2)/12 + (425*CF*lm*NC*NH*Pi^2)/12 - 
       (12479759231629531*CF^2*NC*Pi^3)/(123974556480*Sqrt[3]) - 
       (238658031374735*CF*NC*NH*Pi^3)/(516560652*Sqrt[3]) - 
       (3615973*CF^2*NC*Pi^4)/1200 + (94453493683671695233*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(151868831688000*Sqrt[3]) + 
       (6948441447428911*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2582803260*Sqrt[3]) - (2065239*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (12479759231629531*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3348078300*Sqrt[3]) - (27275203585684*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (12479759231629531*CF^2*NC*Pi*Log[3]^2)/(160707758400*Sqrt[3]) - 
       (6818800896421*CF*NC*NH*Pi*Log[3]^2)/(19131876*Sqrt[3]) - 
       (CF*NC*(-(CA*(96355802475935627 + 2552329627848000*lm)) + 
          8*(CF*(24514208909897327 + 1044134847756000*lm) + 
            175*(5*(-14467537007431 + 66294276048*lm)*NM + 
              11*(3276*(11810123 + 9198340*lm)*NL + 5*(937434065 + 
                  6026752368*lm)*NH))))*Log[x]^2)/4540536000 + 
       (CF*NC*(95560041063*CA - 281649669202*CF + 
          2800*(54076521*NM + 459917*NL))*Log[x]^3)/18900 - 
       (152605324717065083*CF^2*NC*PolyGamma[2, 1])/55788550416 + 
       (837338549*CF*NM*NC*PolyGamma[2, 1])/270 - 
       (5957028737475667*CF*NC*NH*PolyGamma[2, 1])/25828032600 + 
       CA*CF*NC*(-48372148102278798606451981560961/
          13926847446073407605760000 + (263549*lm^2)/8 + 
         (650795775423809*Pi^2)/399168000 + (12479759231629531*Pi^3)/
          (247949112960*Sqrt[3]) + (1227991*Pi^4)/800 + 
         lm*(487631283763/5080320 - (4675*Pi^2)/24) - 
         (94453493683671695233*Im[PolyLog[2, (-1)^(1/3)]])/
          (303737663376000*Sqrt[3]) + (2065239*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          10 + (12479759231629531*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6696156600*Sqrt[3]) + (12479759231629531*Pi*Log[3]^2)/
          (321415516800*Sqrt[3]) + (152605324717065083*PolyGamma[2, 1])/
          111577100832 - (685948499747150461*Zeta[3])/2440749080700) + 
       (1996907066297732903*CF^2*NC*Zeta[3])/2440749080700 + 
       (377906174*CF*NM*NC*Zeta[3])/135 - (1173139*CF*NC*NL*Zeta[3])/9 + 
       (2260960503224933*CF*NC*NH*Zeta[3])/12914016300 + 
       CF*Log[x]*((6739225382835013171*NM*NC)/1168733966400 - 
         (60726773*lm*NM*NC)/840 - 13860*lm^2*NM*NC - (1413175307*NC*NL)/
          6048 - (60726773*lm*NC*NL)/840 - 13860*lm^2*NC*NL - 
         (2349631754278400837827*NC*NH)/697096686686400 - 
         (60726773*lm*NC*NH)/840 - 13860*lm^2*NC*NH + 
         (17753540*NM*NC*Pi^2)/9 - (584657*NC*NL*Pi^2)/27 + 
         (27275203585684*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CF*NC*(-360670123932706837273108193/
            16102933462455840000 - (155984919*lm)/140 - 249480*lm^2 - 
           (13740402719*Pi^2)/5040 + (12479759231629531*
             Im[PolyLog[2, (-1)^(1/3)]])/(10044234900*Sqrt[3]) - 
           166320*Zeta[3]) + CA*NC*(74844333224588640568819471/
            6441173384982336000 + (830988103*lm)/1680 + 76230*lm^2 + 
           (208644078763*Pi^2)/151200 - (12479759231629531*
             Im[PolyLog[2, (-1)^(1/3)]])/(20088469800*Sqrt[3]) + 
           83160*Zeta[3])), (41114866691849775212167606961*CF^2*NC)/
        57548956388733089280000 + (20542237517*CF^2*lm*NC)/141120 + 
       (318483*CF^2*lm^2*NC)/2 + (7234524718455573418239413*CF*NM*NC)/
        168465988852761600 + (37396357877*CF*lm*NM*NC)/2540160 + 
       (35387*CF*lm^2*NM*NC)/4 - (28093907277869*CF*NC*NL)/213373440 + 
       (37396357877*CF*lm*NC*NL)/2540160 + (35387*CF*lm^2*NC*NL)/4 - 
       (4180474327021776519451285020906893*CF*NC*NH)/
        733099301813128409647488000 + (37396357877*CF*lm*NC*NH)/2540160 + 
       (35387*CF*lm^2*NC*NH)/4 - (1645319445696307*CF^2*NC*Pi^2)/
        1238328000 - (1815*CF^2*lm*NC*Pi^2)/2 - (888144143501*CF*NM*NC*Pi^2)/
        45360 - (605*CF*lm*NM*NC*Pi^2)/12 + (333223*CF*NC*NL*Pi^2)/21 - 
       (605*CF*lm*NC*NL*Pi^2)/12 - (605*CF*lm*NC*NH*Pi^2)/12 + 
       (640559491010423*CF^2*NC*Pi^3)/(3874204890*Sqrt[3]) + 
       (3619369174299865*CF*NC*NH*Pi^3)/(4649045868*Sqrt[3]) + 
       (1085854*CF^2*NC*Pi^4)/225 - (79352108292678175319*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(75934415844000*Sqrt[3]) - 
       (701549495715919811*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (162716605380*Sqrt[3]) + (3182784*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 + (5124475928083384*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(837019575*Sqrt[3]) + 
       (413642191348556*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) + (640559491010423*CF^2*NC*Pi*Log[3]^2)/
        (5022117450*Sqrt[3]) + (103410547837139*CF*NC*NH*Pi*Log[3]^2)/
        (172186884*Sqrt[3]) + 
       (CF*NC*(-187*CA*(-524785930060627 + 98136748710000*lm) + 
          14*(748*CF*(-16323585980761 + 5735264535000*lm) + 
            125*(119*(-21733447736353 + 16022326320*lm)*NM + 
              6738732*(362147 + 282940*lm)*NL + (319661012249 + 
                1906656832080*lm)*NH)))*Log[x]^2)/19297278000 + 
       (CF*NC*(44603746447*CA + 8*(9142144859*CF - 1750*(92847345*NM + 
              155617*NL)))*Log[x]^3)/18900 + 
       (68614858253978753*CF^2*NC*PolyGamma[2, 1])/69735688020 - 
       (27689462563*CF*NM*NC*PolyGamma[2, 1])/1350 + 
       (772634199567955657*CF*NC*NH*PolyGamma[2, 1])/2092070640600 + 
       CA*CF*NC*(-16335068311959366251374991747/115097912777466178560000 - 
         (389257*lm^2)/8 + (540914177250539*Pi^2)/825552000 - 
         (640559491010423*Pi^3)/(7748409780*Sqrt[3]) - (552002*Pi^4)/225 + 
         lm*(-725970183367/5080320 + (6655*Pi^2)/24) + 
         (79352108292678175319*Im[PolyLog[2, (-1)^(1/3)]])/
          (151868831688000*Sqrt[3]) - (1591392*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          5 - (2562237964041692*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (837019575*Sqrt[3]) - (640559491010423*Pi*Log[3]^2)/
          (10044234900*Sqrt[3]) - (68614858253978753*PolyGamma[2, 1])/
          139471376040 - (6746930881470681533*Zeta[3])/4881498161400) + 
       (2871503782168219591*CF^2*NC*Zeta[3])/1220374540350 - 
       (5184049888*CF*NM*NC*Zeta[3])/675 + (1953655*CF*NC*NL*Zeta[3])/9 - 
       (493827959637582143*CF*NC*NH*Zeta[3])/1046035320300 + 
       CF*Log[x]*((-25517061599022204359*NM*NC)/233746793280 + 
         (6444295*lm*NM*NC)/56 + 21780*lm^2*NM*NC + (16448820151*NC*NL)/
          42336 + (6444295*lm*NC*NL)/56 + 21780*lm^2*NC*NL + 
         (113269646897948815637848063*NC*NH)/19944633302784590400 + 
         (6444295*lm*NC*NH)/56 + 21780*lm^2*NC*NH - (154338014*NM*NC*Pi^2)/
          9 + (974105*NC*NL*Pi^2)/27 - (413642191348556*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CA*NC*(122841314225946623897953/26616418946208000 - 
           (87962765*lm)/112 - 119790*lm^2 + (29672388731*Pi^2)/75600 + 
           (2562237964041692*Im[PolyLog[2, (-1)^(1/3)]])/(2511058725*
             Sqrt[3]) - 130680*Zeta[3]) + CF*NC*(-1408580976834228058722097/
            133082094731040000 + (49765815*lm)/28 + 392040*lm^2 - 
           (705953299*Pi^2)/840 - (5124475928083384*Im[PolyLog[2, (-1)^
                (1/3)]])/(2511058725*Sqrt[3]) + 261360*Zeta[3])), 
      (14279217761037051948586074448217519*CF^2*NC)/
        188012440521991002677760000 - (107641770473*CF^2*lm*NC)/544320 - 
       (440671*CF^2*lm^2*NC)/2 - (9209321557794769185816731*CF*NM*NC)/
        194383833291648000 - (197591534993*CF*lm*NM*NC)/9797760 - 
       (440671*CF*lm^2*NM*NC)/36 + (3261566147371601*CF*NC*NL)/
        16003008000 - (197591534993*CF*lm*NC*NL)/9797760 - 
       (440671*CF*lm^2*NC*NL)/36 + (4964506665291772878628534944944417*CF*NC*
         NH)/599808519665286880620672000 - (197591534993*CF*lm*NC*NH)/
        9797760 - (440671*CF*lm^2*NC*NH)/36 - 
       (18377431017613258543*CF^2*NC*Pi^2)/490377888000 + 
       (21175*CF^2*lm*NC*Pi^2)/18 + (6868931380931*CF*NM*NC*Pi^2)/408240 + 
       (21175*CF*lm*NM*NC*Pi^2)/324 - (133459073*CF*NC*NL*Pi^2)/5832 + 
       (21175*CF*lm*NC*NL*Pi^2)/324 + (21175*CF*lm*NC*NH*Pi^2)/324 - 
       (831508677887583887*CF^2*NC*Pi^3)/(3347313024960*Sqrt[3]) - 
       (47416727298429335*CF*NC*NH*Pi^3)/(41841412812*Sqrt[3]) - 
       (229484321*CF^2*NC*Pi^4)/32400 + (6057034758775612535801*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4100458455576000*Sqrt[3]) + 
       (1872702317701745525*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (292889889684*Sqrt[3]) - (13762067*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/15 - (831508677887583887*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(90398114100*Sqrt[3]) - 
       (5419054548391924*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) - (831508677887583887*CF^2*NC*Pi*Log[3]^2)/
        (4339109476800*Sqrt[3]) - (1354763637097981*CF*NC*NH*Pi*Log[3]^2)/
        (1549681956*Sqrt[3]) - 
       (CF*NC*(-153*CA*(1040886515394036737 + 6530531343336000*lm) + 
          2*(17*CF*(9407304779329193567 + 96176916147312000*lm) + 
            2100*(663*(-50217770968187 + 65240073360*lm)*NM + 
              121*(167076*(2716857 + 2139580*lm)*NL + 5*(12618702025 + 
                  71494493616*lm)*NH))))*Log[x]^2)/694702008000 + 
       (CF*NC*(10375719685187*CA + 12*(-1920319980289*CF + 
            2100*(441949109*NM + 1176769*NL)))*Log[x]^3)/170100 - 
       (217898425134121584823*CF^2*NC*PolyGamma[2, 1])/7531454306160 + 
       (117267591539*CF*NM*NC*PolyGamma[2, 1])/4050 - 
       (2056921148967486361*CF*NC*NH*PolyGamma[2, 1])/3765727153080 + 
       CA*CF*NC*(-2879810660228842982732675535266143/
          75204976208796401071104000 + (4847381*lm^2)/72 + 
         (1671884318591075213*Pi^2)/89159616000 + (831508677887583887*Pi^3)/
          (6694626049920*Sqrt[3]) + (77624107*Pi^4)/21600 + 
         lm*(3852569155963/19595520 - (232925*Pi^2)/648) - 
         (6057034758775612535801*Im[PolyLog[2, (-1)^(1/3)]])/
          (8200916911152000*Sqrt[3]) + (13762067*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/30 + (831508677887583887*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(180796228200*Sqrt[3]) + 
         (831508677887583887*Pi*Log[3]^2)/(8678218953600*Sqrt[3]) + 
         (217898425134121584823*PolyGamma[2, 1])/15062908612320 - 
         (185984591005311954367*Zeta[3])/65900225178900) + 
       (206061327648786064603*CF^2*NC*Zeta[3])/32950112589450 + 
       (54153871814*CF*NM*NC*Zeta[3])/2025 - (8780629*CF*NC*NL*Zeta[3])/
        27 + (1191079190612591039*CF*NC*NH*Zeta[3])/1882863576540 + 
       CF*Log[x]*((1091416844615383919*NM*NC)/17980522560 - 
         (1615061591*lm*NM*NC)/9720 - 31460*lm^2*NM*NC - 
         (1835495127887*NC*NL)/3175200 - (1615061591*lm*NC*NL)/9720 - 
         31460*lm^2*NC*NL - (2754086070887864777708827*NC*NH)/
          333027272217182400 - (1615061591*lm*NC*NH)/9720 - 
         31460*lm^2*NC*NH + 16298288*NM*NC*Pi^2 - (1459909*NC*NL*Pi^2)/
          27 + (5419054548391924*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(-26479539124126224461381111269/
            108694800871576920000 - (1385718191*lm)/540 - 566280*lm^2 - 
           (844138520989*Pi^2)/27216 + (831508677887583887*
             Im[PolyLog[2, (-1)^(1/3)]])/(271194342300*Sqrt[3]) - 
           377520*Zeta[3]) + CA*NC*(21357279264657000586937391347/
            173911681394523072000 + (22046754301*lm)/19440 + 173030*lm^2 + 
           (21160096655737*Pi^2)/1360800 - (831508677887583887*
             Im[PolyLog[2, (-1)^(1/3)]])/(542388684600*Sqrt[3]) + 
           188760*Zeta[3])), (150955042667045956598584753335143*CF^2*NC)/
        6267081350733033422592000 + (5687058154*CF^2*lm*NC)/19845 + 
       312807*CF^2*lm^2*NC + (2502513937708466271997763*CF*NM*NC)/
        5399550924768000 + (41371197361*CF*lm*NM*NC)/1428840 + 
       (104269*CF*lm^2*NM*NC)/6 - (95481849420677*CF*NC*NL)/285768000 + 
       (41371197361*CF*lm*NC*NL)/1428840 + (104269*CF*lm^2*NC*NL)/6 - 
       (446901101639513645084223506090570620739*CF*NC*NH)/
        33941214750169672391961811296000 + (41371197361*CF*lm*NC*NH)/
        1428840 + (104269*CF*lm^2*NC*NH)/6 - 
       (422216054737925377*CF^2*NC*Pi^2)/23351328000 - 
       (4840*CF^2*lm*NC*Pi^2)/3 - (1770677868559*CF*NM*NC*Pi^2)/8505 - 
       (2420*CF*lm*NM*NC*Pi^2)/27 + (58349390*CF*NC*NL*Pi^2)/1701 - 
       (2420*CF*lm*NC*NL*Pi^2)/27 - (2420*CF*lm*NC*NH*Pi^2)/27 + 
       (432505840297542859*CF^2*NC*Pi^3)/(1115771008320*Sqrt[3]) + 
       (56813060313531760*CF*NC*NH*Pi^3)/(31381059609*Sqrt[3]) + 
       (116423197*CF^2*NC*Pi^4)/10800 - (3218607760053487454917*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1366819485192000*Sqrt[3]) - 
       (10804123623401697296*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1098337086315*Sqrt[3]) + (6774119*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 + (432505840297542859*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(30132704700*Sqrt[3]) + 
       (25971684714757376*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) + (432505840297542859*CF^2*NC*Pi*Log[3]^2)/
        (1446369825600*Sqrt[3]) + (1623230294672336*CF*NC*NH*Pi*Log[3]^2)/
        (1162261467*Sqrt[3]) + CF*((-1361383012855965581*CF*NC)/6810804000 + 
         CA*(460990708472005253/4540536000 - (20719798*lm)/9)*NC + 
         7534472*CF*lm*NC - (22250953793029*NM*NC)/8910 + 
         (3767236*lm*NM*NC)/9 + (23867602*NC*NL)/45 + (3767236*lm*NC*NL)/
          9 + (978076349333*NC*NH)/12471030 + (3767236*lm*NC*NH)/9)*
        Log[x]^2 - (CF*NC*(-402448483074*CA + 482710293161*CF + 
          4200*(2402994039*NM + 941809*NL))*Log[x]^3)/14175 + 
       (3338957606608366882*CF^2*NC*PolyGamma[2, 1])/784526490225 - 
       (279619752983*CF*NM*NC*PolyGamma[2, 1])/1350 + 
       (23640928220498407673*CF*NC*NH*PolyGamma[2, 1])/28242953648100 + 
       CA*CF*NC*(-90579996211568297642082616148483/
          7833851688416291778240000 - (1146959*lm^2)/12 + 
         (38295657997768307*Pi^2)/4245696000 - (432505840297542859*Pi^3)/
          (2231542016640*Sqrt[3]) - (39323999*Pi^4)/7200 + 
         lm*(-802711846211/2857680 + (13310*Pi^2)/27) + 
         (3218607760053487454917*Im[PolyLog[2, (-1)^(1/3)]])/
          (2733638970384000*Sqrt[3]) - (6774119*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          10 - (432505840297542859*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (60265409400*Sqrt[3]) - (432505840297542859*Pi*Log[3]^2)/
          (2892739651200*Sqrt[3]) - (1669478803304183441*PolyGamma[2, 1])/
          784526490225 - (1452495156566891244193*Zeta[3])/87866966905200) + 
       (282270529085405166407*CF^2*NC*Zeta[3])/8786696690520 - 
       (41052037283*CF*NM*NC*Zeta[3])/675 + (1542112*CF*NC*NL*Zeta[3])/3 - 
       (18562088541376099327*CF*NC*NH*Zeta[3])/14121476824050 + 
       CF*Log[x]*((-1079117426905523567*NM*NC)/899026128 + 
         (714084206*lm*NM*NC)/2835 + 47190*lm^2*NM*NC + 
         (14780321419*NC*NL)/16200 + (714084206*lm*NC*NL)/2835 + 
         47190*lm^2*NC*NL + (128400465974127559383668225957*NC*NH)/
          9720017040112070131440 + (714084206*lm*NC*NH)/2835 + 
         47190*lm^2*NC*NH - (1601093608*NM*NC*Pi^2)/9 + 
         (2308328*NC*NL*Pi^2)/27 - (25971684714757376*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CA*NC*(818936862289744752179858737/11594112092968204800 - 
           (4863948683*lm)/2835 - 259545*lm^2 + (3000428826641*Pi^2)/453600 + 
           (432505840297542859*Im[PolyLog[2, (-1)^(1/3)]])/
            (180796228200*Sqrt[3]) - 283140*Zeta[3]) + 
         CF*NC*(-20916992134626326277946103023/144926401162102560000 + 
           (1227492937*lm)/315 + 849420*lm^2 - (606010561117*Pi^2)/45360 - 
           (432505840297542859*Im[PolyLog[2, (-1)^(1/3)]])/
            (90398114100*Sqrt[3]) + 566280*Zeta[3])), 
      (18090310579004852705249776876560134714729*CF^2*NC)/
        20783365206402190413506284800000 - (602952674567*CF^2*lm*NC)/
        1587600 - (2104707*CF^2*lm^2*NC)/5 - (45081162649357949232914676611*
         CF*NM*NC)/104504217580002240000 - (1104167599547*CF*lm*NM*NC)/
        28576800 - (701569*CF*lm^2*NM*NC)/30 + (4973241595360489*CF*NC*NL)/
        10001880000 - (1104167599547*CF*lm*NC*NL)/28576800 - 
       (701569*CF*lm^2*NC*NL)/30 + (2102267635965238747281801103241862676637*
         CF*NC*NH)/113137382500565574639872704320000 - 
       (1104167599547*CF*lm*NC*NH)/28576800 - (701569*CF*lm^2*NC*NH)/30 - 
       (69221611057984690597*CF^2*NC*Pi^2)/163459296000 + 
       (30734*CF^2*lm*NC*Pi^2)/15 + (12640259987599*CF*NM*NC*Pi^2)/85050 + 
       (15367*CF*lm*NM*NC*Pi^2)/135 - (8158523549*CF*NC*NL*Pi^2)/170100 + 
       (15367*CF*lm*NC*NL*Pi^2)/135 + (15367*CF*lm*NC*NH*Pi^2)/135 - 
       (16922765449834777429*CF^2*NC*Pi^3)/(30125817224640*Sqrt[3]) - 
       (107169653004109591*CF*NC*NH*Pi^3)/(41841412812*Sqrt[3]) - 
       (165188177*CF^2*NC*Pi^4)/10800 + (120168956650671928720243*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(36904126100184000*Sqrt[3]) + 
       (1034757830143180882*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (73222472421*Sqrt[3]) - (9465027*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (16922765449834777429*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(813583026900*Sqrt[3]) - 
       (61239801716634052*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (645700815*Sqrt[3]) - (16922765449834777429*CF^2*NC*Pi*Log[3]^2)/
        (39051985291200*Sqrt[3]) - (15309950429158513*CF*NC*NH*Pi*Log[3]^2)/
        (7748409780*Sqrt[3]) - 
       (CF*NC*(-19*CA*(590746473078481407869 + 778689669396038400*lm) + 
          14*(19*CF*(84466998605968837129 + 182031351287385600*lm) + 
            120*(209*(-22329890398415947 + 7661252158560*lm)*NM + 
              3*(42678636*(15741151 + 12505880*lm)*NL + (104439089187449 + 
                  533733900379680*lm)*NH))))*Log[x]^2)/4399779384000 + 
       (CF*NC*(9895840963971*CA - 20278805723263*CF + 
          18480*(427412559*NM + 312647*NL))*Log[x]^3)/14175 - 
       (13218059135701662758279*CF^2*NC*PolyGamma[2, 1])/42364430472150 + 
       (53091905513*CF*NM*NC*PolyGamma[2, 1])/200 - 
       (67733794993423337821*CF*NC*NH*PolyGamma[2, 1])/56485907296200 + 
       CA*CF*NC*(-9059508024061799706786910459643857915693/
          20783365206402190413506284800000 + (7717259*lm^2)/60 + 
         (6293751107951489759*Pi^2)/29719872000 + (16922765449834777429*Pi^3)/
          (60251634449280*Sqrt[3]) + (167155153*Pi^4)/21600 + 
         lm*(21501855527977/57153600 - (169037*Pi^2)/270) - 
         (120168956650671928720243*Im[PolyLog[2, (-1)^(1/3)]])/
          (73808252200368000*Sqrt[3]) + (9465027*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/10 + (16922765449834777429*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1627166053800*Sqrt[3]) + 
         (16922765449834777429*Pi*Log[3]^2)/(78103970582400*Sqrt[3]) + 
         (13218059135701662758279*PolyGamma[2, 1])/84728860944300 - 
         (3795247453707432450953*Zeta[3])/94896324257616) + 
       (96476813507913306788387*CF^2*NC*Zeta[3])/1186204053220200 + 
       (230422883497*CF*NM*NC*Zeta[3])/900 - (11173448*CF*NC*NL*Zeta[3])/
        15 + (49833088742716339139*CF*NC*NH*Zeta[3])/28242953648100 + 
       CF*Log[x]*((5464784426734851910019*NM*NC)/9595571485500 - 
         (4997900149*lm*NM*NC)/14175 - 66066*lm^2*NM*NC - 
         (5217907637069*NC*NL)/3969000 - (4997900149*lm*NC*NL)/14175 - 
         66066*lm^2*NC*NL - (1514210170258303825802415089189*NC*NH)/
          81000142000933917762000 - (4997900149*lm*NC*NH)/14175 - 
         66066*lm^2*NC*NH + (6261991439*NM*NC*Pi^2)/45 - 
         (16729438*NC*NL*Pi^2)/135 + (61239801716634052*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1937102445*Sqrt[3]) + 
         CF*NC*(-608875313059887382832099238770023/226172141653577255136000 - 
           (8591071973*lm)/1575 - 1189188*lm^2 - (1059270924049*Pi^2)/3024 + 
           (16922765449834777429*Im[PolyLog[2, (-1)^(1/3)]])/
            (2440749080700*Sqrt[3]) - 792792*Zeta[3]) + 
         CA*NC*(3049317818222988373104889784125049/
            2261721416535772551360000 + (68087699339*lm)/28350 + 
           363363*lm^2 + (5299222303637*Pi^2)/30240 - 
           (16922765449834777429*Im[PolyLog[2, (-1)^(1/3)]])/
            (4881498161400*Sqrt[3]) + 396396*Zeta[3])), 
      (44618042279169091606966833308200229053*CF^2*NC)/
        115677357364019612691129600000 + (842878038329*CF^2*lm*NC)/1587600 + 
       (2893319*CF^2*lm^2*NC)/5 + (8563722507038447084978349765413*CF*NM*NC)/
        1724319590070036960000 + (1531893024989*CF*lm*NM*NC)/28576800 + 
       (2893319*CF*lm^2*NM*NC)/90 - (46574796283334953*CF*NC*NL)/
        60011280000 + (1531893024989*CF*lm*NC*NL)/28576800 + 
       (2893319*CF*lm^2*NC*NL)/90 - 
       (129850709744814634439959684103361676852577*CF*NC*NH)/
        4582063991272905772914844524960000 + (1531893024989*CF*lm*NC*NH)/
        28576800 + (2893319*CF*lm^2*NC*NH)/90 - 
       (10341879979955633947*CF^2*NC*Pi^2)/44579808000 - 
       (40898*CF^2*lm*NC*Pi^2)/15 - (376932399401741*CF*NM*NC*Pi^2)/170100 - 
       (20449*CF*lm*NM*NC*Pi^2)/135 + (11779936883*CF*NC*NL*Pi^2)/170100 - 
       (20449*CF*lm*NC*NL*Pi^2)/135 - (20449*CF*lm*NC*NH*Pi^2)/135 + 
       (75995095511975515451*CF^2*NC*Pi^3)/(90377451673920*Sqrt[3]) + 
       (6639619474821860401*CF*NC*NH*Pi^3)/(1694577218886*Sqrt[3]) + 
       (724081787*CF^2*NC*Pi^4)/32400 - (4404836346498450840709*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(885699026404416*Sqrt[3]) - 
       (622859166399932150929*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29655101330505*Sqrt[3]) + (40490593*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + (75995095511975515451*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2440749080700*Sqrt[3]) + 
       (7588136542653554744*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (52301766015*Sqrt[3]) + (75995095511975515451*CF^2*NC*Pi*Log[3]^2)/
        (117155955873600*Sqrt[3]) + (948517067831694343*CF*NC*NH*Pi*
         Log[3]^2)/(313810596090*Sqrt[3]) + 
       (CF*NC*(-1463*CA*(-12418174737798205261 + 46436100850339200*lm) + 
          2*(209*CF*(-86703868465401615793 + 531904427922067200*lm) + 
            5040*(19*(-1832491600654771867 + 64494584514360*lm)*NM + 
              9*(92470378*(1850609 + 1472420*lm)*NL + (27976493455213 + 
                  136155233974760*lm)*NH))))*Log[x]^2)/13199338152000 - 
       (CF*NC*(-15553918661723*CA + 28762542967063*CF + 
          2520*(126833811876*NM + 10527803*NL))*Log[x]^3)/42525 - 
       (50648376343465218289*CF^2*NC*PolyGamma[2, 1])/14121476824050 - 
       (2260365759229*CF*NM*NC*PolyGamma[2, 1])/1080 + 
       (33358519173528704867*CF*NC*NH*PolyGamma[2, 1])/18828635765400 + 
       CA*CF*NC*(-1087415782945293706773571916049814921343/
          5668190510836961021865350400000 - (31826509*lm^2)/180 + 
         (795233658984491911*Pi^2)/6858432000 - (75995095511975515451*Pi^3)/
          (180754903347840*Sqrt[3]) - (731934203*Pi^4)/64800 + 
         lm*(-29712436359199/57153600 + (224939*Pi^2)/270) + 
         (4404836346498450840709*Im[PolyLog[2, (-1)^(1/3)]])/
          (1771398052808832*Sqrt[3]) - (40490593*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/30 - (75995095511975515451*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4881498161400*Sqrt[3]) - 
         (75995095511975515451*Pi*Log[3]^2)/(234311911747200*Sqrt[3]) + 
         (50648376343465218289*PolyGamma[2, 1])/28242953648100 - 
         (5534133070703870694433*Zeta[3])/31632108085872) + 
       (27513050901749516000063*CF^2*NC*Zeta[3])/79080270214680 - 
       (46829671193*CF*NM*NC*Zeta[3])/108 + (16927196*CF*NC*NL*Zeta[3])/
        15 - (30121376370951807373*CF*NC*NH*Zeta[3])/9414317882700 + 
       CF*Log[x]*((-5448233245858195190070877*NM*NC)/422205145362000 + 
         (7283016598*lm*NM*NC)/14175 + (286286*lm^2*NM*NC)/3 + 
         (47362714589623*NC*NL)/23814000 + (7283016598*lm*NC*NL)/14175 + 
         (286286*lm^2*NC*NL)/3 + (93797666936457762878940816821039*NC*NH)/
          3280505751037823669361000 + (7283016598*lm*NC*NH)/14175 + 
         (286286*lm^2*NC*NH)/3 - (28182210736*NM*NC*Pi^2)/15 + 
         (25349896*NC*NL*Pi^2)/135 - (7588136542653554744*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(156905298045*Sqrt[3]) + 
         CA*NC*(527383546113417985962848536654159/616833113600665241280000 - 
           (49525500739*lm)/14175 - (1574573*lm^2)/3 + (24589828320047*Pi^2)/
            272160 + (75995095511975515451*Im[PolyLog[2, (-1)^(1/3)]])/
            (14644494484200*Sqrt[3]) - 572572*Zeta[3]) + 
         CF*NC*(-529369529737306926183507348155677/308416556800332620640000 + 
           (12536981171*lm)/1575 + 1717716*lm^2 - (123143430448219*Pi^2)/
            680400 - (75995095511975515451*Im[PolyLog[2, (-1)^(1/3)]])/
            (7322247242100*Sqrt[3]) + 1145144*Zeta[3])), 
      (1412508534062593585067512930606061783323594481*CF^2*NC)/
        142553101950712624046239607443200000 - (132344572368791*CF^2*lm*NC)/
        192099600 - 760695*CF^2*lm^2*NC - 
       (30386708381590746162419231164709473*CF*NM*NC)/
        7884738712193589005760000 - (241941476285291*CF*lm*NM*NC)/
        3457792800 - (253565*CF*lm^2*NM*NC)/6 + 
       (225458737169624303*CF*NC*NL)/201704580000 - 
       (241941476285291*CF*lm*NC*NL)/3457792800 - (253565*CF*lm^2*NC*NL)/
        6 + (119251019848218965424916275906081226002613*CF*NC*NH)/
        3054709327515270515276563016640000 - (241941476285291*CF*lm*NC*NH)/
        3457792800 - (253565*CF*lm^2*NC*NH)/6 - 
       (8495383824542251160527*CF^2*NC*Pi^2)/1798052256000 + 
       (51038*CF^2*lm*NC*Pi^2)/15 + (609835664642044*CF*NM*NC*Pi^2)/467775 + 
       (25519*CF*lm*NM*NC*Pi^2)/135 - (176514843583*CF*NC*NL*Pi^2)/
        1871100 + (25519*CF*lm*NC*NL*Pi^2)/135 + (25519*CF*lm*NC*NH*Pi^2)/
        135 - (1175504585739620593429*CF^2*NC*Pi^3)/(994151968413120*
         Sqrt[3]) - (6111049078017075479*CF*NC*NH*Pi^3)/
        (1129718145924*Sqrt[3]) - (332898553*CF^2*NC*Pi^4)/10800 + 
       (4301831647391369995617157*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (637914179731752000*Sqrt[3]) + (290372250989131045204*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9885033776835*Sqrt[3]) - 
       (18371899*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (167929226534231513347*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3835462841100*Sqrt[3]) - (3492028044581185988*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(17433922005*Sqrt[3]) - 
       (167929226534231513347*CF^2*NC*Pi*Log[3]^2)/(184102216372800*
         Sqrt[3]) - (873007011145296497*CF*NC*NH*Pi*Log[3]^2)/
        (209207064060*Sqrt[3]) - 
       (CF*NC*(-3*CA*(457690563906545889515287 + 117764824030460006400*lm) + 
          2*(CF*(1373309274389253867636343 + 578118227058621849600*lm) + 
            9240*((-40963082417248861601 + 3475939316129280*lm)*NM + 
              1664466804*(2609899 + 2088320*lm)*NL + 3*(247085835780923 + 
                1158646438709760*lm)*NH)))*Log[x]^2)/48397573224000 + 
       (CF*NC*(1221959490991733*CA + 33*(-74439946372521*CF + 
            6160*(3707173263*NM + 678704*NL)))*Log[x]^3)/155925 - 
       (128564111823531332719094*CF^2*NC*PolyGamma[2, 1])/38127987424935 + 
       (13021245502621*CF*NM*NC*PolyGamma[2, 1])/5400 - 
       (1255901892486205009067*CF*NC*NH*PolyGamma[2, 1])/508373165665800 + 
       CA*CF*NC*(-1554202813440374217302083673577689792550898657/
          313616824291567772901727136375040000 + (2789215*lm^2)/12 + 
         (653507590071150285643*Pi^2)/276623424000 + 
         (1175504585739620593429*Pi^3)/(1988303936826240*Sqrt[3]) + 
         (2490111*Pi^4)/160 + lm*(427924101113291/628689600 - 
           (280709*Pi^2)/270) - (4301831647391369995617157*
           Im[PolyLog[2, (-1)^(1/3)]])/(1275828359463504000*Sqrt[3]) + 
         (18371899*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (167929226534231513347*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (7670925682200*Sqrt[3]) + (167929226534231513347*Pi*Log[3]^2)/
          (368204432745600*Sqrt[3]) + (64282055911765666359547*
           PolyGamma[2, 1])/38127987424935 - (129860914688229033904999963*
           Zeta[3])/234868402537599600) + (26037673708276710469745837*CF^2*NC*
         Zeta[3])/23486840253759960 + (6518591882101*CF*NM*NC*Zeta[3])/
        2700 - (23846576*CF*NC*NL*Zeta[3])/15 + 
       (1082082105379577805013*CF*NC*NH*Zeta[3])/254186582832900 + 
       CF*Log[x]*((384138263492704215834956321*NM*NC)/76208028737841000 - 
         (109246171073*lm*NM*NC)/155925 - 130130*lm^2*NM*NC - 
         (30438422618627*NC*NL)/10914750 - (109246171073*lm*NC*NL)/155925 - 
         130130*lm^2*NC*NL - (7849788404904678734165334832391*NC*NH)/
          198818530365928707234000 - (109246171073*lm*NC*NH)/155925 - 
         130130*lm^2*NC*NH + (54358541633*NM*NC*Pi^2)/45 - 
         (35718826*NC*NL*Pi^2)/135 + (3492028044581185988*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(52301766015*Sqrt[3]) + 
         CF*NC*(-397755860727591010363093765558086459251/
            13471943617595329202175840000 - (188056561771*lm)/17325 - 
           2342340*lm^2 - (9782409708922393*Pi^2)/2494800 + 
           (167929226534231513347*Im[PolyLog[2, (-1)^(1/3)]])/
            (11506388523300*Sqrt[3]) - 1561560*Zeta[3]) + 
         CA*NC*(397876347863882519723980232008346106473/
            26943887235190658404351680000 + (135070469573*lm)/28350 + 
           715715*lm^2 + (9783415170688009*Pi^2)/4989600 - 
           (167929226534231513347*Im[PolyLog[2, (-1)^(1/3)]])/
            (23012777046600*Sqrt[3]) + 780780*Zeta[3])), 
      (806502971974228960173615456619489762964079913*CF^2*NC)/
        155085242781544503083271660844800000 + (229103954957*CF^2*lm*NC)/
        245025 + (5090631*CF^2*lm^2*NC)/5 + 
       (89848427691160599524141003233135031*CF*NM*NC)/
        1689586866898626215520000 + (1664814936293*CF*lm*NM*NC)/17641800 + 
       (1696877*CF*lm^2*NM*NC)/30 - (54325968189225077*CF*NC*NL)/
        32416807500 + (1664814936293*CF*lm*NC*NL)/17641800 + 
       (1696877*CF*lm^2*NC*NL)/30 - 
       (1373302570765467810248569180808707930103576071*CF*NC*NH)/
        23892845392207476231023534286509280000 + (1664814936293*CF*lm*NC*NH)/
        17641800 + (1696877*CF*lm^2*NC*NH)/30 - 
       (947450444303382177619*CF^2*NC*Pi^2)/335899872000 - 
       (66248*CF^2*lm*NC*Pi^2)/15 - (1574169684423007*CF*NM*NC*Pi^2)/66825 - 
       (33124*CF*lm*NM*NC*Pi^2)/135 + (8823827116*CF*NC*NL*Pi^2)/66825 - 
       (33124*CF*lm*NC*NL*Pi^2)/135 - (33124*CF*lm*NC*NH*Pi^2)/135 + 
       (5100257790545321168191*CF^2*NC*Pi^3)/(2982455905239360*Sqrt[3]) + 
       (20290006471156571009*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) + 
       (470406937*CF^2*NC*Pi^4)/10800 - (57063026937444437187334181*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5741227617585768000*Sqrt[3]) - 
       (538726460228990641816*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12709329141645*Sqrt[3]) + (25445147*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + (728608255792188738313*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11506388523300*Sqrt[3]) + 
       (46377157648357876592*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (156905298045*Sqrt[3]) + (728608255792188738313*CF^2*NC*Pi*Log[3]^2)/
        (552306649118400*Sqrt[3]) + (2898572353022367287*CF*NC*NH*Pi*
         Log[3]^2)/(470715894135*Sqrt[3]) + 
       (CF*NC*(-897*CA*(-2994531386436629763491 + 1908917159131382400*lm) + 
          10*(299*CF*(-1795932988090619506279 + 1874209574419902720*lm) + 
            3696*(253*(-4807150002314690909 + 33293875534920*lm)*NM + 
              3*(12760912164*(274701 + 220030*lm)*NL + (623698312192231 + 
                  2807783503444920*lm)*NH))))*Log[x]^2)/159020597736000 - 
       (CF*NC*(-100810695653376*CA + 198848870532469*CF + 
          9240*(192341980473*NM + 3146429*NL))*Log[x]^3)/22275 - 
       (88511555374008657104306*CF^2*NC*PolyGamma[2, 1])/190639937124675 - 
       (57221948488261*CF*NM*NC*PolyGamma[2, 1])/2700 + 
       (809656378613945118653*CF*NC*NH*PolyGamma[2, 1])/228767924549610 + 
       CA*CF*NC*(-1151254918608352723306919967806261930259061/
          443100693661555723095061888128000 - (18665647*lm^2)/60 + 
         (55729047617536919459*Pi^2)/39517632000 - 
         (5100257790545321168191*Pi^3)/(5964911810478720*Sqrt[3]) - 
         (158215603*Pi^4)/7200 + lm*(-2934825558173/3207600 + 
           (182182*Pi^2)/135) + (57063026937444437187334181*
           Im[PolyLog[2, (-1)^(1/3)]])/(11482455235171536000*Sqrt[3]) - 
         (25445147*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
         (728608255792188738313*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (23012777046600*Sqrt[3]) - (728608255792188738313*Pi*Log[3]^2)/
          (1104613298236800*Sqrt[3]) + (44255777687004328552153*
           PolyGamma[2, 1])/190639937124675 - (60040150835087296387210427*
           Zeta[3])/33552628933942800) + (11994589685276773516073221*CF^2*NC*
         Zeta[3])/3355262893394280 - (3382625760301*CF*NM*NC*Zeta[3])/1350 + 
       (11625432*CF*NC*NL*Zeta[3])/5 - (809488406226482412943*CF*NC*NH*
         Zeta[3])/114383962274805 + CF*Log[x]*
        ((-426252285157813768153812073*NM*NC)/3110531785218000 + 
         (22012715504*lm*NM*NC)/22275 + 182182*lm^2*NM*NC + 
         (38108074048361*NC*NL)/9355500 + (22012715504*lm*NC*NL)/22275 + 
         182182*lm^2*NC*NL + (86648764595468996079483617258790733*NC*NH)/
          1487475036256293189507402000 + (22012715504*lm*NC*NH)/22275 + 
         182182*lm^2*NC*NH - (299192721716*NM*NC*Pi^2)/15 + 
         (52248196*NC*NL*Pi^2)/135 - (46377157648357876592*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) + 
         CA*NC*(1740611406129433263244759882025224211/
            177652003748509835633088000 - (13588787602*lm)/2025 - 
           1002001*lm^2 + (804850294170121*Pi^2)/712800 + 
           (728608255792188738313*Im[PolyLog[2, (-1)^(1/3)]])/
            (69038331139800*Sqrt[3]) - 1093092*Zeta[3]) + 
         CF*NC*(-8708723829615609823705090460696650633/
            444130009371274589082720000 + (37938274933*lm)/2475 + 
           3279276*lm^2 - (805059248044393*Pi^2)/356400 - 
           (728608255792188738313*Im[PolyLog[2, (-1)^(1/3)]])/
            (34519165569900*Sqrt[3]) + 2186184*Zeta[3])), 
      (1349196839092773702049835251438301119422313990793*CF^2*NC)/
        12096648936960471240495189545894400000 - (56055210994927*CF^2*lm*NC)/
        47044800 - (13119561*CF^2*lm^2*NC)/10 - 
       (14529929131502251690327659935410135181*CF*NM*NC)/
        425775890458453806311040000 - (102345745244887*CF*lm*NM*NC)/
        846806400 - (1457729*CF*lm^2*NM*NC)/20 + 
       (306861133716385957057*CF*NC*NL)/130704567840000 - 
       (102345745244887*CF*lm*NC*NL)/846806400 - (1457729*CF*lm^2*NC*NL)/
        20 + (1307658650429695685867579904920010837928763593*CF*NC*NH)/
        16865537923911159692487200672830080000 - 
       (102345745244887*CF*lm*NC*NH)/846806400 - (1457729*CF*lm^2*NC*NH)/
        20 - (7586099660832038450513*CF^2*NC*Pi^2)/145556611200 + 
       (488579*CF^2*lm*NC*Pi^2)/90 + (254252192651735581*CF*NM*NC*Pi^2)/
        22453200 + (488579*CF*lm*NM*NC*Pi^2)/1620 - 
       (70529405713*CF*NC*NL*Pi^2)/400950 + (488579*CF*lm*NC*NL*Pi^2)/
        1620 + (488579*CF*lm*NC*NH*Pi^2)/1620 - 
       (2621790271583062194223*CF^2*NC*Pi^3)/(1118420964464760*Sqrt[3]) - 
       (658170694739905502813*CF*NC*NH*Pi^3)/(61004779879896*Sqrt[3]) - 
       (105565369*CF^2*NC*Pi^4)/1800 + (1425526440847324745013451*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(107648017829733150*Sqrt[3]) + 
       (8835789878550336290783*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (152511949699740*Sqrt[3]) - (101615878*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (749082934738017769778*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(8629791392475*Sqrt[3]) - 
       (188048769925687286518*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) - 
       (374541467369008884889*CF^2*NC*Pi*Log[3]^2)/(207114993419400*
         Sqrt[3]) - (94024384962843643259*CF*NC*NH*Pi*Log[3]^2)/
        (11297181459240*Sqrt[3]) - 
       (CF*NC*(-23*CA*(3243522297472389376971269 + 154443014024063965200*
             lm) + 660*(805*CF*(280833448766531412865 + 21880946496915792*
               lm) + 3*(69*(-237234685574323304977 + 4727364983901560*lm)*
               NM + 14399*(443118*(63516449 + 51123020*lm)*NL + 
                83*(62611322321 + 272934100920*lm)*NH))))*Log[x]^2)/
        238530896604000 + (CF*NC*(23219960322107807*CA + 
          20*(-2324368305703705*CF + 726*(773033558186*NM + 33229963*NL)))*
         Log[x]^3)/267300 - (332355769714684750929407351*CF^2*NC*
         PolyGamma[2, 1])/9150716981984400 + 
       (352366787536321*CF*NM*NC*PolyGamma[2, 1])/16200 - 
       (33093925416912936412477*CF*NC*NH*PolyGamma[2, 1])/6863037736488300 + 
       CA*CF*NC*(-24532063801817765972000054220276568094337408047/
          439878143162198954199825074396160000 + (16035019*lm^2)/40 + 
         (19070218226787548453*Pi^2)/731808000 + 
         (2621790271583062194223*Pi^3)/(2236841928929520*Sqrt[3]) + 
         (191581117*Pi^4)/6480 + lm*(180899379123607/153964800 - 
           (5374369*Pi^2)/3240) - (1425526440847324745013451*
           Im[PolyLog[2, (-1)^(1/3)]])/(215296035659466300*Sqrt[3]) + 
         (50807939*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (374541467369008884889*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (8629791392475*Sqrt[3]) + (374541467369008884889*Pi*Log[3]^2)/
          (414229986838800*Sqrt[3]) + (332355769714684750929407351*
           PolyGamma[2, 1])/18301433963968800 - (717403218098884275293599709*
           Zeta[3])/100657886801828400) + (717678909491151105190721693*CF^2*
         NC*Zeta[3])/50328943400914200 + (182434700276041*CF*NM*NC*Zeta[3])/
        8100 - (431603692*CF*NC*NL*Zeta[3])/135 + 
       (31925851836865487804663*CF*NC*NH*Zeta[3])/3431518868244150 + 
       CF*Log[x]*((19580101113039153716910731173*NM*NC)/457248172427046000 - 
         (704475307523*lm*NM*NC)/534600 - (728728*lm^2*NM*NC)/3 - 
         (52611297760110979*NC*NL)/9430344000 - (704475307523*lm*NC*NL)/
          534600 - (728728*lm^2*NC*NL)/3 - 
         (41340189576674025993686987610791387*NC*NH)/
          524991189266927008061436000 - (704475307523*lm*NC*NH)/534600 - 
         (728728*lm^2*NC*NH)/3 + (8502921069137*NM*NC*Pi^2)/810 - 
         (431115113*NC*NL*Pi^2)/810 + (188048769925687286518*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(-5547450525240053304647547763623274437121/
            17321070365479708974226080000 - (607080810323*lm)/29700 - 
           4372368*lm^2 - (23222932907373227*Pi^2)/534600 + 
           (749082934738017769778*Im[PolyLog[2, (-1)^(1/3)]])/
            (25889374177425*Sqrt[3]) - 2914912*Zeta[3]) + 
         CA*NC*(1386937591334559478870025126519940129943/
            8660535182739854487113040000 + (869750817923*lm)/97200 + 
           (4008004*lm^2)/3 + (23223364618139351*Pi^2)/1069200 - 
           (374541467369008884889*Im[PolyLog[2, (-1)^(1/3)]])/
            (25889374177425*Sqrt[3]) + 1457456*Zeta[3])), 
      (4704084036830185314551207736684351227385778952119*CF^2*NC)/
        72579893621762827442971137275366400000 + (989593790837*CF^2*lm*NC)/
        627264 + (3433521*CF^2*lm^2*NC)/2 + 
       (1466160113914973657840307472909179547*CF*NM*NC)/
        2580459942172447310976000 + (1797240334541*CF*lm*NM*NC)/11290752 + 
       (1144507*CF*lm^2*NM*NC)/12 - (163125793335130242733*CF*NC*NL)/
        47925008208000 + (1797240334541*CF*lm*NC*NL)/11290752 + 
       (1144507*CF*lm^2*NC*NL)/12 - 
       (16678227445844953604699934092565436884845192505053*CF*NC*NH)/
        150524925970907100255448266005008464000000 + 
       (1797240334541*CF*lm*NC*NH)/11290752 + (1144507*CF*lm^2*NC*NH)/12 - 
       (4118546555405239188631*CF^2*NC*Pi^2)/124762809600 - 
       (41405*CF^2*lm*NC*Pi^2)/6 - (373530555483697489*CF*NM*NC*Pi^2)/
        1496880 - (41405*CF*lm*NM*NC*Pi^2)/108 + (5128865651*CF*NC*NL*Pi^2)/
        21384 - (41405*CF*lm*NC*NL*Pi^2)/108 - (41405*CF*lm*NC*NH*Pi^2)/
        108 + (88404259033593438802657*CF^2*NC*Pi^3)/(26842103147154240*
         Sqrt[3]) + (2826566009435194479215*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) + (870361583*CF^2*NC*Pi^4)/10800 - 
       (195718059418208635974904003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (10334209711654382400*Sqrt[3]) - (2871005404719287269249063*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(35230260380639940*Sqrt[3]) + 
       (45768541*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (12629179861941919828951*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(103557496709700*Sqrt[3]) + 
       (161518057682011113098*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (12629179861941919828951*CF^2*NC*Pi*Log[3]^2)/(4970759842065600*
         Sqrt[3]) + (80759028841005556549*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((-54755014085588994553729*CF*NC)/
          138278780640 + CA*(1368976255784439087731489/6913939032000 - 
           (127773503*lm)/6)*NC + 69694638*CF*lm*NC - 
         (116181492367388461099*NM*NC)/38798760 + (11615773*lm*NM*NC)/3 + 
         (288424097*NC*NL)/60 + (11615773*lm*NC*NL)/3 + 
         (110773699980039997*NC*NH)/120470149800 + (11615773*lm*NC*NH)/3)*
        Log[x]^2 - (CF*NC*(-4788007686648737*CA + 9552478857520340*CF + 
          75385773358104000*NM + 229992305400*NL)*Log[x]^3)/89100 - 
       (59925261658911476694126251*CF^2*NC*PolyGamma[2, 1])/
        6863037736488300 - (386914801839749*CF*NM*NC*PolyGamma[2, 1])/1800 + 
       (138533300776846306591657*CF*NC*NH*PolyGamma[2, 1])/
        20589113209464900 + CA*CF*NC*
        (-4703527653251813793397046113180090430058080586397/
          145159787243525654885942274550732800000 - (12589577*lm^2)/24 + 
         (443531585025399767957*Pi^2)/26871989760 - 
         (88404259033593438802657*Pi^3)/(53684206294308480*Sqrt[3]) - 
         (876986383*Pi^4)/21600 + lm*(-3167792045069/2052864 + 
           (455455*Pi^2)/216) + (195718059418208635974904003*
           Im[PolyLog[2, (-1)^(1/3)]])/(20668419423308764800*Sqrt[3]) - 
         (45768541*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
         (12629179861941919828951*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (207114993419400*Sqrt[3]) - (12629179861941919828951*Pi*Log[3]^2)/
          (9941519684131200*Sqrt[3]) + (59925261658911476694126251*
           PolyGamma[2, 1])/13726075472976600 - (5471444370816182348659733783*
           Zeta[3])/301973660405485200) + (5470287211580379937906252973*CF^2*
         NC*Zeta[3])/150986830202742600 - (6200322813149*CF*NM*NC*Zeta[3])/
        900 + (40851044*CF*NC*NL*Zeta[3])/9 - 
       (149709346581290764325843*CF*NC*NH*Zeta[3])/10294556604732450 + 
       CF*Log[x]*((-87962289489116387595670071053*NM*NC)/60966422990272800 + 
         (64453967669*lm*NM*NC)/35640 + 331240*lm^2*NM*NC + 
         (54710984784353603*NC*NL)/6915585600 + (64453967669*lm*NC*NL)/
          35640 + 331240*lm^2*NC*NL + 
         (105617129930823675626276408814112684613*NC*NH)/
          937109272841464709389663260000 + (64453967669*lm*NC*NH)/35640 + 
         331240*lm^2*NC*NH - (11422048176263*NM*NC*Pi^2)/54 + 
         (13603213*NC*NL*Pi^2)/18 - (161518057682011113098*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(2845841844912500528901153750341525545939/
            25981605548219563461339120000 - (79479014069*lm)/6480 - 
           1821820*lm^2 + (9572763379331909*Pi^2)/712800 + 
           (12629179861941919828951*Im[PolyLog[2, (-1)^(1/3)]])/
            (621344980258200*Sqrt[3]) - 1987440*Zeta[3]) + 
         CF*NC*(-2276923220807456838793857931631081346539/
            10392642219287825384535648000 + (55599922469*lm)/1980 + 
           5962320*lm^2 - (9573170101156253*Pi^2)/356400 - 
           (12629179861941919828951*Im[PolyLog[2, (-1)^(1/3)]])/
            (310672490129100*Sqrt[3]) + 3974880*Zeta[3])), 
      (13487930161038618626751899827056871143499697837772395587*CF^2*NC)/
        10875822019624277222667335766930295756800000 - 
       (1048934566241293*CF^2*lm*NC)/530038080 - (4348869*CF^2*lm^2*NC)/2 - 
       (421611740741741649767614842483927743153*CF*NM*NC)/
        1409636805226668696975897600 - (1913334381840613*CF*lm*NM*NC)/
        9540685440 - (1449623*CF*lm^2*NM*NC)/12 + 
       (75431202146308617478607*CF*NC*NL)/16198652774304000 - 
       (1913334381840613*CF*lm*NC*NL)/9540685440 - (1449623*CF*lm^2*NC*NL)/
        12 + (7362619601873958835740485175778824780640512858803*CF*NC*NH)/
        50174975323635700085149422001669488000000 - 
       (1913334381840613*CF*lm*NC*NH)/9540685440 - (1449623*CF*lm^2*NC*NH)/
        12 - (922389839928380878953797*CF^2*NC*Pi^2)/1621916524800 + 
       (50225*CF^2*lm*NC*Pi^2)/6 + (269123228473879057*CF*NM*NC*Pi^2)/
        2779920 + (50225*CF*lm*NM*NC*Pi^2)/108 - 
       (43563500599*CF*NC*NL*Pi^2)/138996 + (50225*CF*lm*NC*NL*Pi^2)/108 + 
       (50225*CF*lm*NC*NH*Pi^2)/108 - (630530236416366844847597*CF^2*NC*
         Pi^3)/(142751184918956640*Sqrt[3]) - 
       (1249986698197643266385*CF*NC*NH*Pi^3)/(61004779879896*Sqrt[3]) - 
       (286979987*CF^2*NC*Pi^4)/2700 + (17745588668475801615597700703*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(714469680519377983200*Sqrt[3]) + 
       (1282147396407905248290331*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (11743420126879980*Sqrt[3]) - (59763396*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (90075748059480977835371*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(550737596137950*Sqrt[3]) - 
       (71427811325579615222*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) - (90075748059480977835371*CF^2*NC*Pi*Log[3]^2)/
        (26435404614621600*Sqrt[3]) - (35713905662789807611*CF*NC*NH*Pi*
         Log[3]^2)/(2259436291848*Sqrt[3]) + 
       CF*((-18563671312818951873845087*CF*NC)/2720089171800 - 
         94309254*CF*lm*NC + CA*(92817827832401026319097869/27200891718000 + 
           (57633433*lm)/2)*NC + (1332864099078339649669*NM*NC)/1147334760 - 
         5239403*lm*NM*NC - (1165948433*NC*NL)/180 - 5239403*lm*NC*NL - 
         (154182449186411521*NC*NH)/120470149800 - 5239403*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-1102926584263503369*CA + 
          260*(8485689945464881*CF - 330*(4877042003182*NM + 47154627*NL)))*
         Log[x]^3)/1158300 - (19232077511712009820723984819*CF^2*NC*
         PolyGamma[2, 1])/49413871702715760 + 
       (23379560804257*CF*NM*NC*PolyGamma[2, 1])/120 - 
       (184990990688148373448117*CF*NC*NH*PolyGamma[2, 1])/
        20589113209464900 + CA*CF*NC*
        (-3372010513120469702310176280448838241079937678168305999/
          5437911009812138611333667883465147878400000 + (15945853*lm^2)/24 + 
         (40354584792853771370603*Pi^2)/141917695920 + 
         (630530236416366844847597*Pi^3)/(285502369837913280*Sqrt[3]) + 
         (288988987*Pi^4)/5400 + lm*(3380194674978853/1734670080 - 
           (552475*Pi^2)/216) - (17745588668475801615597700703*
           Im[PolyLog[2, (-1)^(1/3)]])/(1428939361038755966400*Sqrt[3]) + 
         (29881698*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (90075748059480977835371*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1101475192275900*Sqrt[3]) + (90075748059480977835371*Pi*Log[3]^2)/
          (52870809229243200*Sqrt[3]) + (19232077511712009820723984819*
           PolyGamma[2, 1])/98827743405431520 - 
         (3070906417133988449501576393231*Zeta[3])/35330918267441768400) + 
       (3071087898819198272668304179601*CF^2*NC*Zeta[3])/
        17665459133720884200 + (12543637397977*CF*NM*NC*Zeta[3])/60 - 
       (55001732*CF*NC*NL*Zeta[3])/9 + (194340904094548487936983*CF*NC*NH*
         Zeta[3])/10294556604732450 + CF*Log[x]*
        ((50267988580992533097626200336*NM*NC)/143978740008278175 - 
         (1095882223661*lm*NM*NC)/463320 - 433160*lm^2*NM*NC - 
         (954417631372274807*NC*NL)/89902612800 - (1095882223661*lm*NC*NL)/
          463320 - 433160*lm^2*NC*NL - 
         (46711625888456484725867130940043079113*NC*NH)/
          312369757613821569796554420000 - (1095882223661*lm*NC*NH)/463320 - 
         433160*lm^2*NC*NH + (4876989003131*NM*NC*Pi^2)/54 - 
         (2035241*NC*NL*Pi^2)/2 + (71427811325579615222*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(-232777289680899303694226183364427679960816383/
            67708611039829618581585774912000 - (945363455261*lm)/25740 - 
           7796880*lm^2 - (367650570007333651*Pi^2)/772200 + 
           (90075748059480977835371*Im[PolyLog[2, (-1)^(1/3)]])/
            (1652212788413850*Sqrt[3]) - 5197920*Zeta[3]) + 
         CA*NC*(290974316167309326058725603194167337992952969/
            169271527599574046453964437280000 + (1351308012461*lm)/84240 + 
           2382380*lm^2 + (30637646529140249*Pi^2)/128700 - 
           (90075748059480977835371*Im[PolyLog[2, (-1)^(1/3)]])/
            (3304425576827700*Sqrt[3]) + 2598960*Zeta[3])), 
      (2042351475450200915946264249267785620111582651684536529*CF^2*NC)/
        2649238697087964964495889481688148966400000 + 
       (21249578440414*CF^2*lm*NC)/8281845 + 2790956*CF^2*lm^2*NC + 
       (143404085951556331368807225044871237187*CF*NM*NC)/
        23719850087948752112575200 + (38585277185779*CF*lm*NM*NC)/
        149073210 + (1395478*CF*lm^2*NM*NC)/9 - 
       (759258253645866719707*CF*NC*NL)/115704662673600 + 
       (38585277185779*CF*lm*NC*NL)/149073210 + (1395478*CF*lm^2*NC*NL)/9 - 
       (412056585689982876333865448374812679783031053843*CF*NC*NH)/
        2015958829967505806992610705424220500000 + 
       (38585277185779*CF*lm*NC*NH)/149073210 + (1395478*CF*lm^2*NC*NH)/9 - 
       (60803911723248367205094533*CF^2*NC*Pi^2)/161786173348800 - 
       (31360*CF^2*lm*NC*Pi^2)/3 - (8310043795485907*CF*NM*NC*Pi^2)/3159 - 
       (15680*CF*lm*NM*NC*Pi^2)/27 + (14520663736*CF*NC*NL*Pi^2)/34749 - 
       (15680*CF*lm*NC*NL*Pi^2)/27 - (15680*CF*lm*NC*NH*Pi^2)/27 + 
       (3168839870264114105817079*CF^2*NC*Pi^3)/(523421011369507680*
         Sqrt[3]) + (1961484988317731364040*CF*NC*NH*Pi^3)/
        (68630377364883*Sqrt[3]) + (1155323491*CF^2*NC*Pi^4)/8100 - 
       (90686688202508766513698410849*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2619722161904385938400*Sqrt[3]) - (566914173844855336761652*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(3774670755068565*Sqrt[3]) + 
       (237181028*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (452691410037730586545297*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2019371185839150*Sqrt[3]) + 
       (896678851802391480704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) + 
       (452691410037730586545297*CF^2*NC*Pi*Log[3]^2)/(96929816920279200*
         Sqrt[3]) + (56042428237649467544*CF*NC*NH*Pi*Log[3]^2)/
        (2541865828329*Sqrt[3]) + 
       (CF*NC*(CA*(6992078584772132950133055149 - 124449809205681479520000*
             lm) + 320*(4*CF*(-10924989649324026007401053 + 
              318195534900890146500*lm) + 9009*(15*(-2263627054927640703601 + 
                523255402870200*lm)*NM + 31073649750*(312115 + 252588*lm)*
               NL + (1975230130601243 + 7848831043053000*lm)*NH)))*
         Log[x]^2)/3100901655852000 - (7*CF*NC*(-153522791067002857*CA + 
          80*(3836419875800581*CF + 25740*(1077202855039*NM + 586365*NL)))*
         Log[x]^3)/1737450 - (390148606016745126783116584*CF^2*NC*
         PolyGamma[2, 1])/3088366981419735 - 
       (490876879439792*CF*NM*NC*PolyGamma[2, 1])/225 + 
       (567703507680968651078387*CF*NC*NH*PolyGamma[2, 1])/
        46325504721296025 + CA*CF*NC*
        (-1659380406871925822131641635043728598619022435709131431/
          4305012882767943067305820407743242070400000 - (7675129*lm^2)/9 + 
         (6400402341572107825291663*Pi^2)/34060247020800 - 
         (3168839870264114105817079*Pi^3)/(1046842022739015360*Sqrt[3]) - 
         (1162849891*Pi^4)/16200 + lm*(-68003432632459/27104220 + 
           (86240*Pi^2)/27) + (90686688202508766513698410849*
           Im[PolyLog[2, (-1)^(1/3)]])/(5239444323808771876800*Sqrt[3]) - 
         (118590514*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
         (452691410037730586545297*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4038742371678300*Sqrt[3]) - (452691410037730586545297*Pi*Log[3]^2)/
          (193859633840558400*Sqrt[3]) + (195074303008372563391558292*
           PolyGamma[2, 1])/3088366981419735 - 
         (3231022685920948664823464531557*Zeta[3])/17665459133720884200) + 
       (1615449301209492180097067961551*CF^2*NC*Zeta[3])/
        4416364783430221050 + (23625298253216*CF*NM*NC*Zeta[3])/225 + 
       (76131440*CF*NC*NL*Zeta[3])/9 - (1304759448496139388004826*CF*NC*NH*
         Zeta[3])/46325504721296025 + CF*Log[x]*
        ((-17372893605655691089901673875957*NM*NC)/1151829920066225400 + 
         (36732460064*lm*NM*NC)/11583 + (1732640*lm^2*NM*NC)/3 + 
         (4713009466890563*NC*NL)/321080760 + (36732460064*lm*NC*NL)/
          11583 + (1732640*lm^2*NC*NL)/3 + 
         (20939186378706755791824819445849314149*NC*NH)/
          100404564947299790291749635000 + (36732460064*lm*NC*NH)/11583 + 
         (1732640*lm^2*NC*NH)/3 - (60323326336672*NM*NC*Pi^2)/27 + 
         1408680*NC*NL*Pi^2 - (896678851802391480704*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CA*NC*(645077394037300103579216103509077132319227169/
            536026504065317813770887384720000 - (22623326512*lm)/1053 - 
           (9529520*lm^2)/3 + (2149199019113877293*Pi^2)/13899600 + 
           (452691410037730586545297*Im[PolyLog[2, (-1)^(1/3)]])/
            (12116227115034900*Sqrt[3]) - 3465280*Zeta[3]) + 
         CF*NC*(-516071205699581107701059480782170039012535669/
            214410601626127125508354953888000 + (63430335568*lm)/1287 + 
           10395840*lm^2 - (2149213763067293771*Pi^2)/6949800 - 
           (452691410037730586545297*Im[PolyLog[2, (-1)^(1/3)]])/
            (6058113557517450*Sqrt[3]) + 6930560*Zeta[3])), 
      (19281240516645319775206161574989064452192997103993119560761*CF^2*NC)/
        1415039017118506503862260968806039567488000000 - 
       (5152661644474837*CF^2*lm*NC)/1623241620 - 3482292*CF^2*lm^2*NC - 
       (27867507536136996159101242002677900643231893*CF*NM*NC)/
        10792531790016682211221716000000 - (9392112625019617*CF*lm*NM*NC)/
        29218349160 - (580382*CF*lm^2*NM*NC)/3 + 
       (14246103549483313795739*CF*NC*NL)/1619865277430400 - 
       (9392112625019617*CF*lm*NC*NL)/29218349160 - (580382*CF*lm^2*NC*NL)/
        3 + (90199402349439082323265616402785548387307509600817*CF*NC*NH)/
        338681083434540975574758598511269044000000 - 
       (9392112625019617*CF*lm*NC*NH)/29218349160 - (580382*CF*lm^2*NC*NH)/
        3 - (2318848540963579680994241923*CF^2*NC*Pi^2)/377501071147200 + 
       (37600*CF^2*lm*NC*Pi^2)/3 + (196661755359044891*CF*NM*NC*Pi^2)/
        243243 + (18800*CF*lm*NM*NC*Pi^2)/27 - (130604556391*CF*NC*NL*Pi^2)/
        243243 + (18800*CF*lm*NC*NL*Pi^2)/27 + (18800*CF*lm*NC*NH*Pi^2)/
        27 - (112585087504881962928572833*CF^2*NC*Pi^3)/
        (14132367306976707360*Sqrt[3]) - (7679576778469456770140*CF*NC*NH*
         Pi^3)/(205891132094649*Sqrt[3]) - (498861637*CF^2*NC*Pi^4)/2700 + 
       (22159137742657799025183403550593*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (495127488599928942357600*Sqrt[3]) + (15673235112496704979401644*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(79268085856439865*Sqrt[3]) - 
       (101513596*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (112585087504881962928572833*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(381661154123599350*
         Sqrt[3]) - (3510663670157465952064*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (112585087504881962928572833*CF^2*NC*Pi*Log[3]^2)/
        (18319735397932768800*Sqrt[3]) - (219416479384841622004*CF*NC*NH*Pi*
         Log[3]^2)/(7625597484987*Sqrt[3]) + 
       CF*((-144928801542359428285350331*CF*NC)/1966151412225 - 
         174378672*CF*lm*NC + CA*(42469937011434217647471101/1152323172000 + 
           53282372*lm)*NC + (97399797534950758075439*NM*NC)/10039179150 - 
         9687704*lm*NM*NC - (536705078*NC*NL)/45 - 9687704*lm*NC*NL - 
         (75278093002736737*NC*NH)/30117537450 - 9687704*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(41872446498211082449*CA - 
          3360*(24924950876278719*CF - 715*(5146645181192*NM + 
              10898667*NL)))*Log[x]^3)/4054050 - 
       (115245482257777911160011080377*CF^2*NC*PolyGamma[2, 1])/
        27795302832777615 + (779209913776009*CF*NM*NC*PolyGamma[2, 1])/450 - 
       (297938270141056345627181*CF*NC*NH*PolyGamma[2, 1])/
        18530201888518410 + CA*CF*NC*
        (-1205079167197412841435700985585386947515263306987361391461/
          176879877139813312982782621100754945936000000 + (3192101*lm^2)/3 + 
         (244089348600882578078570561*Pi^2)/79473909715200 + 
         (112585087504881962928572833*Pi^3)/(28264734613953414720*Sqrt[3]) + 
         (55763293*Pi^4)/600 + lm*(16586332470792577/5312427120 - 
           (103400*Pi^2)/27) - (22159137742657799025183403550593*
           Im[PolyLog[2, (-1)^(1/3)]])/(990254977199857884715200*Sqrt[3]) + 
         (50756798*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (112585087504881962928572833*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (763322308247198700*Sqrt[3]) + (112585087504881962928572833*Pi*
           Log[3]^2)/(36639470795865537600*Sqrt[3]) + 
         (115245482257777911160011080377*PolyGamma[2, 1])/55590605665555230 - 
         (1133066541097935693062613525162289*Zeta[3])/
          1112923925424415704600) + (566538418578717987783268144538207*CF^2*
         NC*Zeta[3])/278230981356103926150 + 
       (436113781106809*CF*NM*NC*Zeta[3])/225 - 
       (100630616*CF*NC*NL*Zeta[3])/9 + (334586108405179578649219*CF*NC*NH*
         Zeta[3])/9265100944259205 + CF*Log[x]*
        ((83694919607145143247365925617911*NM*NC)/31010805540244530000 - 
         (1653260568046*lm*NM*NC)/405405 - 742560*lm^2*NM*NC - 
         (434827441328508929*NC*NL)/22475653200 - (1653260568046*lm*NC*NL)/
          405405 - 742560*lm^2*NC*NL - 
         (163972924561916528577046252154243297027*NC*NH)/
          602427389683798741750497810000 - (1653260568046*lm*NC*NH)/405405 - 
         742560*lm^2*NC*NH + (20586535727920*NM*NC*Pi^2)/27 - 
         (5586412*NC*NL*Pi^2)/3 + (3510663670157465952064*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(-322031360001564684535863714988083210320781773441/
            8809479066812614504582410061920000 - (2854964830892*lm)/45045 - 
           13366080*lm^2 - (83745220360403306261*Pi^2)/16216200 + 
           (112585087504881962928572833*Im[PolyLog[2, (-1)^(1/3)]])/
            (1144983462370798050*Sqrt[3]) - 8910720*Zeta[3]) + 
         CA*NC*(476378489070180532887730530230228655689078033/
            26063547534948563623024881840000 + (1018199625623*lm)/36855 + 
           4084080*lm^2 + (83745265899185377043*Pi^2)/32432400 - 
           (112585087504881962928572833*Im[PolyLog[2, (-1)^(1/3)]])/
            (2289966924741596100*Sqrt[3]) + 4455360*Zeta[3])), 
      (289077315494173170770445158407706937337049161380934734811721*CF^2*NC)/
        32545897393725649588832002282538910052224000000 + 
       (1312201164914291*CF^2*lm*NC)/324648324 + 4395588*CF^2*lm^2*NC + 
       (345293383462559045524926077393024309434733197*CF*NM*NC)/
        5396265895008341105610858000000 + (2382466372810175*CF*lm*NM*NC)/
        5843669832 + (732598*CF*lm^2*NM*NC)/3 - 
       (50939018802882991504249*CF*NC*NL)/4211649721319040 + 
       (2382466372810175*CF*lm*NC*NL)/5843669832 + (732598*CF*lm^2*NC*NL)/
        3 - (2697303401612187611798445982816368631068613832929671787*CF*NC*
         NH)/7434083649496517867963508713182206642704400000 + 
       (2382466372810175*CF*lm*NC*NH)/5843669832 + (732598*CF*lm^2*NC*NH)/
        3 - (83244977333144570343345103*CF^2*NC*Pi^2)/19868477428800 - 
       (46240*CF^2*lm*NC*Pi^2)/3 - (2580215279448147112*CF*NM*NC*Pi^2)/
        93555 - (23120*CF*lm*NM*NC*Pi^2)/27 + (170792664865*CF*NC*NL*Pi^2)/
        243243 - (23120*CF*lm*NC*NL*Pi^2)/27 - (23120*CF*lm*NC*NH*Pi^2)/
        27 + (151051808733997634880152233*CF^2*NC*Pi^3)/
        (14132367306976707360*Sqrt[3]) + (94266551971976491243360*CF*NC*NH*
         Pi^3)/(1853020188851841*Sqrt[3]) + (655934477*CF^2*NC*Pi^4)/2700 - 
       (6040264949957528023094273398469*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (99025497719985788471520*Sqrt[3]) - (190272109783318218147908128*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(713412772707958785*Sqrt[3]) + 
       (131844316*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (151051808733997634880152233*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(381661154123599350*
         Sqrt[3]) + (43093280901474967425536*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) + 
       (151051808733997634880152233*CF^2*NC*Pi*Log[3]^2)/
        (18319735397932768800*Sqrt[3]) + (2693330056342185464096*CF*NC*NH*Pi*
         Log[3]^2)/(68630377364883*Sqrt[3]) + 
       CF*((-2273604433884748306928788721*CF*NC)/45221482481175 + 
         CA*(13991439522523117911431446097/556572092076000 - 72535804*lm)*
          NC + 237389904*CF*lm*NC - (1661262861721567231194751*NM*NC)/
          5019589575 + 13188328*lm*NM*NC + (730379126*NC*NL)/45 + 
         13188328*lm*NC*NL + (101666897407083469*NC*NH)/29113619535 + 
         13188328*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-28193170097678930011*CA + 40*(1409554869262006879*CF + 
            60060*(158475454037477*NM + 14836869*NL)))*Log[x]^3)/4054050 - 
       (226924098886195046623633462594*CF^2*NC*PolyGamma[2, 1])/
        138976514163888075 - (3320927622655213*CF*NM*NC*PolyGamma[2, 1])/
        150 + (17926254816385739088867689*CF*NC*NH*PolyGamma[2, 1])/
        833859084983328450 + CA*CF*NC*
        (-18067281933301362860975823139131779245055374825192576301261/
          4068237174215706198604000285317363756528000000 - (4029289*lm^2)/3 + 
         (186076966348185287011068373*Pi^2)/88823781446400 - 
         (151051808733997634880152233*Pi^3)/(28264734613953414720*Sqrt[3]) - 
         (659633677*Pi^4)/5400 + lm*(-4198673998330463/1062485424 + 
           (127160*Pi^2)/27) + (6040264949957528023094273398469*
           Im[PolyLog[2, (-1)^(1/3)]])/(198050995439971576943040*Sqrt[3]) - 
         (65922158*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (151051808733997634880152233*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (763322308247198700*Sqrt[3]) - (151051808733997634880152233*Pi*
           Log[3]^2)/(36639470795865537600*Sqrt[3]) + 
         (113462049443097523311816731297*PolyGamma[2, 1])/
          138976514163888075 - (2052538187893039257618615203616719*Zeta[3])/
          1112923925424415704600) + (1026262193626272178041566398746397*CF^2*
         NC*Zeta[3])/278230981356103926150 + 
       (200742933628787*CF*NM*NC*Zeta[3])/75 + (136266152*CF*NC*NL*Zeta[3])/
        9 - (21651738780726331303160311*CF*NC*NH*Zeta[3])/
        416929542491664225 + CF*Log[x]*((-2429193051076629697981884383176019*
           NM*NC)/15505402770122265000 + (2172470940862*lm*NM*NC)/405405 + 
         971040*lm^2*NM*NC + (7646985081624500279*NC*NL)/292183491600 + 
         (2172470940862*lm*NC*NL)/405405 + 971040*lm^2*NC*NL + 
         (8284650127404068338782353153173937798687*NC*NH)/
          22320566704627069044871766061000 + (2172470940862*lm*NC*NH)/
          405405 + 971040*lm^2*NC*NH - (633901760320480*NM*NC*Pi^2)/27 + 
         (7565204*NC*NL*Pi^2)/3 - (43093280901474967425536*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CA*NC*(20318939036569041216549020801985993918827515861/
            1558600142589924104656887934032000 - (1336749224831*lm)/36855 - 
           5340720*lm^2 + (56385831963944826037*Pi^2)/32432400 + 
           (151051808733997634880152233*Im[PolyLog[2, (-1)^(1/3)]])/
            (2289966924741596100*Sqrt[3]) - 5826240*Zeta[3]) + 
         CF*NC*(-5282939392299507210104988829543077500069454364481/
            202618018536690133605395431424160000 + (3754445174924*lm)/45045 + 
           17478720*lm^2 - (56385893410094773219*Pi^2)/16216200 - 
           (151051808733997634880152233*Im[PolyLog[2, (-1)^(1/3)]])/
            (1144983462370798050*Sqrt[3]) + 11652480*Zeta[3])), 
      (43364361346131996182277331233425699576263779172306197102698711*CF^2*
         NC)/292913076543530846299488020542850190470016000000 - 
       (601368065979549719*CF^2*lm*NC)/121743121500 - (27061892*CF^2*lm^2*NC)/
        5 - (1003904015090449811142958388594959272817109621*CF*NM*NC)/
        46010267104807961005734684000000 - (1095557946845931419*CF*lm*NM*NC)/
        2191376187000 - (13530946*CF*lm^2*NM*NC)/45 + 
       (25144180122760937440751357*CF*NC*NL)/1579368645494640000 - 
       (1095557946845931419*CF*lm*NC*NL)/2191376187000 - 
       (13530946*CF*lm^2*NC*NL)/45 + 
       (20783849918979392153248858862344140119147945726584720793*CF*NC*NH)/
        44604501896979107207781052279093239856226400000 - 
       (1095557946845931419*CF*lm*NC*NH)/2191376187000 - 
       (13530946*CF*lm^2*NC*NH)/45 - (372150284042945307889438450037*CF^2*NC*
         Pi^2)/5662516067208000 + (823072*CF^2*lm*NC*Pi^2)/45 + 
       (39694572145077521513*CF*NM*NC*Pi^2)/6081075 + 
       (411536*CF*lm*NM*NC*Pi^2)/405 - (16216596235013*CF*NC*NL*Pi^2)/
        18243225 + (411536*CF*lm*NC*NL*Pi^2)/405 + 
       (411536*CF*lm*NC*NH*Pi^2)/405 - (1759341359961774530128592777*CF^2*NC*
         Pi^3)/(127191305762790366240*Sqrt[3]) - 
       (363713001297220696825900*CF*NC*NH*Pi^3)/(5559060566555523*Sqrt[3]) - 
       (2509124911*CF^2*NC*Pi^4)/8100 + (1734428899262326720113481236780541*
         CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(22280736986996802406092000*
         Sqrt[3]) + (48095621896334382963067318604*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(139115490678051963075*Sqrt[3]) - 
       (166800124*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (1759341359961774530128592777*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3434950387112394150*
         Sqrt[3]) - (166268800593015175691840*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (1759341359961774530128592777*CF^2*NC*Pi*Log[3]^2)/
        (164877618581394919200*Sqrt[3]) - (10391800037063448480740*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) - 
       (CF*NC*(-29*CA*(8559462659295523135431049193777 + 
            2055508265136467764022400*lm) + 
          112*(58*CF*(76423786149170143914998045587 + 30031776601019821227600*
               lm) + 715*(2755*(-223496213046997913468465 + 49125713165697168*
                 lm)*NM + 395945225676*(419305793 + 341818340*lm)*NL + 
              101*(362770594930634507 + 1340013265064313840*lm)*NH)))*
         Log[x]^2)/629483036137956000 + 
       (CF*NC*(1349344112652331932843*CA + 16*(-168669055656169448267*CF + 
            30030*(633473010911242*NM + 290545589*NL)))*Log[x]^3)/
        12162150 - (54909494241925037185628547155629*CF^2*NC*PolyGamma[2, 1])/
        1250788627474992675 + (20590441659375221*CF*NM*NC*PolyGamma[2, 1])/
        1350 - (69469081304555030447612213*CF*NC*NH*PolyGamma[2, 1])/
        2501577254949985350 + CA*CF*NC*
        (-2710273171950996780729969130523015913893594874727867476494171/
          36614134567941355787436002567856273808752000000 + 
         (74420203*lm^2)/45 + (8756477431607967351587329657*Pi^2)/
          266471344339200 + (1759341359961774530128592777*Pi^3)/
          (254382611525580732480*Sqrt[3]) + (2522294063*Pi^4)/16200 + 
         lm*(1934183199225245819/398432034000 - (2263448*Pi^2)/405) - 
         (1734428899262326720113481236780541*Im[PolyLog[2, (-1)^(1/3)]])/
          (44561473973993604812184000*Sqrt[3]) + 
         (83400062*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (1759341359961774530128592777*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6869900774224788300*Sqrt[3]) + (1759341359961774530128592777*Pi*
           Log[3]^2)/(329755237162789838400*Sqrt[3]) + 
         (54909494241925037185628547155629*PolyGamma[2, 1])/
          2501577254949985350 - (16560225181972880752241661897010079*Zeta[3])/
          1430902189831391620200) + (8280124094945117294197360928165953*CF^2*
         NC*Zeta[3])/357725547457847905050 + 
       (12144207222844901*CF*NM*NC*Zeta[3])/675 - 
       (886035512*CF*NC*NL*Zeta[3])/45 + (82314948693752192882974267*CF*NC*
         NH*Zeta[3])/1250788627474992675 + CF*Log[x]*
        ((1000088419814600108549104584388787*NM*NC)/52080348060410670000 - 
         (41285132014474*lm*NM*NC)/6081075 - 1229984*lm^2*NM*NC - 
         (148798092646740317707*NC*NL)/4382752374000 - 
         (41285132014474*lm*NC*NL)/6081075 - 1229984*lm^2*NC*NL - 
         (1306057181442502340070632313333913254432887*NC*NH)/
          2735863747510003605785710754334000 - (41285132014474*lm*NC*NH)/
          6081075 - 1229984*lm^2*NC*NH + (506778188140720*NM*NC*Pi^2)/81 - 
         (1328230196*NC*NL*Pi^2)/405 + (166268800593015175691840*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-702739641116232647581817319127454337268651647630383/
            1823562166830211202448558882817440000 - (71350826599748*lm)/
            675675 - 22139712*lm^2 - (128509046687637087587*Pi^2)/2316600 + 
           (1759341359961774530128592777*Im[PolyLog[2, (-1)^(1/3)]])/
            (10304851161337182450*Sqrt[3]) - 14759808*Zeta[3]) + 
         CA*NC*(13514227260483956869225282303811692876870084233563/
            70137006416546584709559957031440000 + (25402327340837*lm)/
            552825 + 6764912*lm^2 + (42836352706048959143*Pi^2)/1544400 - 
           (1759341359961774530128592777*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) + 7379904*Zeta[3])), 
      (146368805609079594743504973177142423246212934318544944587915529*CF^2*
         NC)/1464565382717654231497440102714250952350080000000 + 
       (6979713153202046*CF^2*lm*NC)/1127251125 + (33664284*CF^2*lm^2*NC)/5 + 
       (875834750840852165072000714239180100490903841*CF*NM*NC)/
        1300885528260939373674046125000 + (12671928454899971*CF*lm*NM*NC)/
        20290520250 + (1870238*CF*lm^2*NM*NC)/5 - 
       (73282168374271861767577*CF*NC*NL)/3418546851720000 + 
       (12671928454899971*CF*lm*NC*NL)/20290520250 + 
       (1870238*CF*lm^2*NC*NL)/5 - 
       (51706195738448661025115293333886511964410648931613921404877*CF*NC*
         NH)/83050794750806536426687833027904169284802542650000 + 
       (12671928454899971*CF*lm*NC*NH)/20290520250 + 
       (1870238*CF*lm^2*NC*NH)/5 - (825683330531697066669157369*CF^2*NC*
         Pi^2)/17976241483200 - (110976*CF^2*lm*NC*Pi^2)/5 - 
       (194270046761856500839*CF*NM*NC*Pi^2)/675675 - 
       (18496*CF*lm*NM*NC*Pi^2)/15 + (772251999808*CF*NC*NL*Pi^2)/675675 - 
       (18496*CF*lm*NC*NL*Pi^2)/15 - (18496*CF*lm*NC*NH*Pi^2)/15 + 
       (2316858594571912746628991077*CF^2*NC*Pi^3)/(127191305762790366240*
         Sqrt[3]) + (486430121690070259931320*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) + (72027487*CF^2*NC*Pi^4)/180 - 
       (2318109723243433363391644493146289*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22280736986996802406092000*Sqrt[3]) - 
       (5796053227847872256462374468*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12646862788913814825*Sqrt[3]) + 
       (213175308*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (2316858594571912746628991077*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3434950387112394150*
         Sqrt[3]) + (222368055629746404540032*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (2316858594571912746628991077*CF^2*NC*Pi*Log[3]^2)/
        (164877618581394919200*Sqrt[3]) + (13898003476859150283752*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((-16616849194753392428061517693*CF*NC)/30147654987450 + 
         CA*(6713880567858431165365753577/24361741404000 - 
           (5687192104*lm)/45)*NC + (2068069856*CF*lm*NC)/5 - 
         (22267010419154898622120502*NM*NC)/6453758025 + 
         (1034034928*lm*NM*NC)/45 + (6340641028*NC*NL)/225 + 
         (1034034928*lm*NC*NL)/45 + (258477146570695418854*NC*NH)/
          40613499251325 + (1034034928*lm*NC*NH)/45)*Log[x]^2 - 
       (CF*NC*(-103735149772330695369*CA + 320*(648336710206027210*CF + 
            1001*(4140210792584889*NM + 64627183*NL)))*Log[x]^3)/1351350 - 
       (990488644846001691343635262216*CF^2*NC*PolyGamma[2, 1])/
        50031545098999707 - (30304417956656051*CF*NM*NC*PolyGamma[2, 1])/
        135 + (15212042512987040701594624*CF*NC*NH*PolyGamma[2, 1])/
        416929542491664225 + CA*CF*NC*
        (-9148046484653384488103665524077504321060958342300021630475219/
          183070672839706778937180012839281369043760000000 - 
         (10286309*lm^2)/5 + (23128383828901120764200461*Pi^2)/
          1007072352000 - (2316858594571912746628991077*Pi^3)/
          (254382611525580732480*Sqrt[3]) - (361913051*Pi^4)/1800 + 
         lm*(-22331445330508571/3689185500 + (101728*Pi^2)/15) + 
         (2318109723243433363391644493146289*Im[PolyLog[2, (-1)^(1/3)]])/
          (44561473973993604812184000*Sqrt[3]) - 
         (106587654*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (2316858594571912746628991077*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6869900774224788300*Sqrt[3]) - (2316858594571912746628991077*Pi*
           Log[3]^2)/(329755237162789838400*Sqrt[3]) + 
         (495244322423000845671817631108*PolyGamma[2, 1])/50031545098999707 - 
         (16922703249794820842774950375920169*Zeta[3])/
          910574120801794667400) + (8461341983730811957711428702316019*CF^2*
         NC*Zeta[3])/227643530200448666850 + 
       (5634517303989146*CF*NM*NC*Zeta[3])/135 + 
       (1177027504*CF*NC*NL*Zeta[3])/45 - (38291715240930882682775872*CF*NC*
         NH*Zeta[3])/416929542491664225 + CF*Log[x]*
        ((-2934754071679371693904150316049521039*NM*NC)/
          1814132124104305005000 + (1974394668824*lm*NM*NC)/225225 + 
         1581408*lm^2*NM*NC + (2992257345714971639*NC*NL)/66405339000 + 
         (1974394668824*lm*NC*NL)/225225 + 1581408*lm^2*NC*NL + 
         (839155265601130205890600589364467645174596429*NC*NH)/
          1314582530678556732580034017457487000 + (1974394668824*lm*NC*NH)/
          225225 + 1581408*lm^2*NC*NH - (2208112392833312*NM*NC*Pi^2)/9 + 
         (588180824*NC*NL*Pi^2)/135 - (222368055629746404540032*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(57829755402737956691281270807412277911855903845991/
            414445947006866182374672473367600000 - (1213852636012*lm)/20475 - 
           8697744*lm^2 + (18860909402265741689*Pi^2)/982800 + 
           (2316858594571912746628991077*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) - 9488448*Zeta[3]) + 
         CF*NC*(-2544510389775710805327124736398080673867748781414289/
            9117810834151056012242794414087200000 + (3414530412448*lm)/
            25025 + 28465344*lm^2 - (18860912613112367039*Pi^2)/491400 - 
           (2316858594571912746628991077*Im[PolyLog[2, (-1)^(1/3)]])/
            (10304851161337182450*Sqrt[3]) + 18976896*Zeta[3])), 
      (6824011629330495105206467805176574751740744496749858605853807383439243*
         CF^2*NC)/4286314214292104286238927999811743977223932134400000000 - 
       (308568184433692223*CF^2*lm*NC)/41225184000 - (16387371*CF^2*lm^2*NC)/
        2 - (1627630267949574609750827369117343881622329923085021*CF*NM*NC)/
        9096850638491334766254251073469440000 - 
       (561907828715416223*CF*lm*NM*NC)/742053312000 - 
       (1820819*CF*lm^2*NM*NC)/4 + (116964823174785078730998239*CF*NC*NL)/
        4211649721319040000 - (561907828715416223*CF*lm*NC*NL)/
        742053312000 - (1820819*CF*lm^2*NC*NL)/4 + 
       (1766299711285505380887724461927728419186403595967618930896553*CF*NC*
         NH)/2238000363811207718445482658436154456516784307200000 - 
       (561907828715416223*CF*lm*NC*NH)/742053312000 - 
       (1820819*CF*lm^2*NC*NH)/4 - (93562370485780494230014131311*CF^2*NC*
         Pi^2)/134222603074560 + (260967*CF^2*lm*NC*Pi^2)/10 + 
       (270806293164961895687*CF*NM*NC*Pi^2)/5405400 + 
       (86989*CF*lm*NM*NC*Pi^2)/60 - (4410810019793*CF*NC*NL*Pi^2)/
        3088800 + (86989*CF*lm*NC*NL*Pi^2)/60 + (86989*CF*lm*NC*NH*Pi^2)/
        60 - (35454055687467501493709476829*CF^2*NC*Pi^3)/
        (1526295669153484394880*Sqrt[3]) - (1234927796685819484493735*CF*NC*
         NH*Pi^3)/(11118121133111046*Sqrt[3]) - (603783611*CF^2*NC*Pi^4)/
        1200 + (2806713519403174331776849280532347*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(21389507507516930309848320*Sqrt[3]) + 
       (29640946249391743871542832977*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (50587451155655259300*Sqrt[3]) - 
       (266173641*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (35454055687467501493709476829*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(41219404645348729800*
         Sqrt[3]) - (282269210671044453598568*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (35454055687467501493709476829*CF^2*NC*Pi*Log[3]^2)/
        (1978531422976739030400*Sqrt[3]) - (35283651333880556699821*CF*NC*NH*
         Pi*Log[3]^2)/(411782264189298*Sqrt[3]) + 
       CF*((-11701145618437874758866218426091187*CF*NC)/1398851191417680000 - 
         (2659904456*CF*lm*NC)/5 + CA*(900088100829915312130748549709439/
            215207875602720000 + (7314737254*lm)/45)*NC + 
         (12602038872660186908216016793*NM*NC)/20961806065200 - 
         (1329952228*lm*NM*NC)/45 - (8131697023*NC*NL)/225 - 
         (1329952228*lm*NC*NL)/45 - (285576146306653814461*NC*NH)/
          34200841474800 - (1329952228*lm*NC*NH)/45)*Log[x]^2 - 
       (CF*NC*(-6384037685615479046205*CA + 4*(3192022208122247460341*CF - 
            40040*(6645973814900847*NM + 664976114*NL)))*Log[x]^3)/
        5405400 - (9245033205891986157982610397172177*CF^2*NC*
         PolyGamma[2, 1])/20012618039599882800 + 
       (358940045906033827*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (1395329798962278280329332479*CF*NC*NH*PolyGamma[2, 1])/
        30018927059399824200 + CA*CF*NC*(-68240118612323662072578409149261354\
39498159361166966795022558205165493/
          8572628428584208572477855999623487954447864268800000000 + 
         (20029009*lm^2)/8 + (137591721687043771537387128163*Pi^2)/
          394772361984000 + (35454055687467501493709476829*Pi^3)/
          (3052591338306968789760*Sqrt[3]) + (606567259*Pi^4)/2400 + 
         lm*(991817528102584223/134918784000 - (956879*Pi^2)/120) - 
         (2806713519403174331776849280532347*Im[PolyLog[2, (-1)^(1/3)]])/
          (42779015015033860619696640*Sqrt[3]) + 
         (266173641*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (35454055687467501493709476829*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(82438809290697459600*Sqrt[3]) + 
         (35454055687467501493709476829*Pi*Log[3]^2)/(3957062845953478060800*
           Sqrt[3]) + (9245033205891986157982610397172177*PolyGamma[2, 1])/
          40025236079199765600 - (5150950670172989876469990981148759169*
           Zeta[3])/40065261315278965365600) + 
       (5150951755054780938126635574702876269*CF^2*NC*Zeta[3])/
        20032630657639482682800 + (226020818424976297*CF*NM*NC*Zeta[3])/
        1350 - (1508643529*CF*NC*NL*Zeta[3])/45 + 
       (1727930107506609171347294441*CF*NC*NH*Zeta[3])/
        15009463529699912100 + CF*Log[x]*
        ((227534151884944462507355047273265486173*NM*NC)/
          1952876948955802251782400 - (5642289794747*lm*NM*NC)/514800 - 
         1976760*lm^2*NM*NC - (42097132113209380729*NC*NL)/730458729000 - 
         (5642289794747*lm*NC*NL)/514800 - 1976760*lm^2*NC*NL - 
         (12558502810439962862604339798160039329672539537*NC*NH)/
          15498236151157721478838295784761952000 - (5642289794747*lm*NC*NH)/
          514800 - 1976760*lm^2*NC*NH + (443064882274115*NM*NC*Pi^2)/9 - 
         (753930314*NC*NL*Pi^2)/135 + (282269210671044453598568*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-1854653458242389964355640339719746966870404055984557808641/
            460084734691262286377771406134840112000000 - (4879062758747*lm)/
            28600 - 35581680*lm^2 - (4256025572177875752341*Pi^2)/7207200 + 
           (35454055687467501493709476829*Im[PolyLog[2, (-1)^(1/3)]])/
            (123658213936046189400*Sqrt[3]) - 23721120*Zeta[3]) + 
         CA*NC*(3709307063959308177898125694911079209365553888545441911807/
            1840338938765049145511085624539360448000000 + (6937462946747*lm)/
            93600 + 10872180*lm^2 + (12768076897836320192387*Pi^2)/43243200 - 
           (35454055687467501493709476829*Im[PolyLog[2, (-1)^(1/3)]])/
            (247316427872092378800*Sqrt[3]) + 11860560*Zeta[3])), 
      (4731158337388589996925020386797718711412704553712254295747530390623769*
         CF^2*NC)/4286314214292104286238927999811743977223932134400000000 + 
       (2670472227620774261*CF^2*lm*NC)/288576288000 + 
       (100623867*CF^2*lm^2*NC)/10 + 
       (320272582736619643183721438829374380782354547991753461*CF*NM*NC)/
        45484253192456673831271255367347200000 + 
       (4848296879350701461*CF*lm*NM*NC)/5194373184000 + 
       (33541289*CF*lm^2*NM*NC)/60 - (638863824375535048408537*CF*NC*NL)/
        17403511245120000 + (4848296879350701461*CF*lm*NC*NL)/
        5194373184000 + (33541289*CF*lm^2*NC*NL)/60 - 
       (1983514231720546119623649255468195890899705782151281377139455393*CF*
         NC*NH)/1913490311058582599270887672962912060321850582656000000 + 
       (4848296879350701461*CF*lm*NC*NH)/5194373184000 + 
       (33541289*CF*lm^2*NC*NH)/60 - (149978980220602908644367192511*CF^2*NC*
         Pi^2)/302000856917760 - (312987*CF^2*lm*NC*Pi^2)/10 - 
       (8055927341588710626941*CF*NM*NC*Pi^2)/2702700 - 
       (104329*CF*lm*NM*NC*Pi^2)/60 + (39111636972311*CF*NC*NL*Pi^2)/
        21621600 - (104329*CF*lm*NC*NL*Pi^2)/60 - (104329*CF*lm*NC*NH*Pi^2)/
        60 + (22964597956994432898706394867*CF^2*NC*Pi^3)/
        (763147834576742197440*Sqrt[3]) + (14609725569424144231381085*CF*NC*
         NH*Pi^3)/(100063090197999414*Sqrt[3]) + (3455681069*CF^2*NC*Pi^4)/
        5400 - (46088092084515419670299819755837787*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(267368843843961628873104000*Sqrt[3]) - 
       (547150783923248758795579299239*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (715451094915695810100*Sqrt[3]) + 
       (335370254*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (22964597956994432898706394867*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(20609702322674364900*
         Sqrt[3]) + (3339365844439804395744248*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) + 
       (22964597956994432898706394867*CF^2*NC*Pi*Log[3]^2)/
        (989265711488369515200*Sqrt[3]) + (417420730554975549468031*CF*NC*NH*
         Pi*Log[3]^2)/(3706040377703682*Sqrt[3]) + 
       CF*((-487188086270280355659603706387871*CF*NC)/81751043654280000 + 
         CA*(9378371119319233315289868226108093/3147415180689780000 - 
           (9593519254*lm)/45)*NC + (3488552456*CF*lm*NC)/5 - 
         (57674560047377967388541017921*NM*NC)/1612446620400 + 
         (1744276228*lm*NM*NC)/45 + (10663228393*NC*NL)/225 + 
         (1744276228*lm*NC*NL)/45 + (1037391326783802295543*NC*NH)/
          92830855431600 + (1744276228*lm*NC*NH)/45)*Log[x]^2 - 
       (CF*NC*(-13536280074421403872125*CA + 8*(3384063194251240672027*CF + 
            60060*(344187456806889387*NM + 872138114*NL)))*Log[x]^3)/
        16216200 - (10366789587709638628685430140533957*CF^2*NC*
         PolyGamma[2, 1])/45028390589099736300 - 
       (6136624648952049919*CF*NM*NC*PolyGamma[2, 1])/2700 + 
       (3249024459864679149841214809*CF*NC*NH*PolyGamma[2, 1])/
        54034068706919683560 + CA*CF*NC*(-47311580368528009451526899800385074\
07874351577669220368399612002637769/
          8572628428584208572477855999623487954447864268800000000 - 
         (368954179*lm^2)/120 + (3869426715009463199776441463*Pi^2)/
          15583119552000 - (22964597956994432898706394867*Pi^3)/
          (1526295669153484394880*Sqrt[3]) - (694140889*Pi^4)/2160 + 
         lm*(-8543999318649971861/944431488000 + (1147619*Pi^2)/120) + 
         (46088092084515419670299819755837787*Im[PolyLog[2, (-1)^(1/3)]])/
          (534737687687923257746208000*Sqrt[3]) - 
         (167685127*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (22964597956994432898706394867*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(41219404645348729800*Sqrt[3]) - 
         (22964597956994432898706394867*Pi*Log[3]^2)/(1978531422976739030400*
           Sqrt[3]) + (10366789587709638628685430140533957*PolyGamma[2, 1])/
          90056781178199472600 - (2410024434532977544168800503186323193*
           Zeta[3])/12878119708482524581800) + 
       (602505995603815928473009974284760941*CF^2*NC*Zeta[3])/
        1609764963560315572725 + (747124158692712611*CF*NM*NC*Zeta[3])/
        1350 + (1970565829*CF*NC*NL*Zeta[3])/45 - 
       (4233291364040506612385377727*CF*NC*NH*Zeta[3])/
        27017034353459841780 + CF*Log[x]*
        ((-162209300240631891703673663543772138727829*NM*NC)/
          9764384744779011258912000 + (50219103120089*lm*NM*NC)/3603600 + 
         2503896*lm^2*NM*NC + (19978745977628657111*NC*NL)/265621356000 + 
         (50219103120089*lm*NC*NL)/3603600 + 2503896*lm^2*NC*NL + 
         (83503061244784182089904687602054290470589448113*NC*NH)/
          78408236149348235884063567431783840000 + (50219103120089*lm*NC*NH)/
          3603600 + 2503896*lm^2*NC*NH - (22945830407327267*NM*NC*Pi^2)/9 + 
         (984813434*NC*NL*Pi^2)/135 - (3339365844439804395744248*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CA*NC*(1360022159449219140080034656428795009210510462043721720653/
            920169469382524572755542812269680224000000 - (61702971734489*lm)/
            655200 - 13771428*lm^2 + (322292311170550622477*Pi^2)/1544400 + 
           (22964597956994432898706394867*Im[PolyLog[2, (-1)^(1/3)]])/
            (123658213936046189400*Sqrt[3]) - 15023376*Zeta[3]) + 
         CF*NC*(-2720044508532903299108536882476232927199963086164562865581/
            920169469382524572755542812269680224000000 + (43451823400889*lm)/
            200200 + 45070128*lm^2 - (966876958813799916323*Pi^2)/2316600 - 
           (22964597956994432898706394867*Im[PolyLog[2, (-1)^(1/3)]])/
            (61829106968023094700*Sqrt[3]) + 30046752*Zeta[3])), 
      (3012352632563840971690518528411478918035844071529542381816220847145461\
0824037*CF^2*NC)/
        1776101706724576368643237938044174974390741710821299200000000 - 
       (923868393529662923957*CF^2*lm*NC)/83398547232000 - 
       (121181031*CF^2*lm^2*NC)/10 - 
       (1903673559928686775225701919646989461477683316031883055139*CF*NM*NC)/
        1355021386856476770107401968648640435200000 - 
       (1681842538840359638357*CF*lm*NM*NC)/1501173850176000 - 
       (13464559*CF*lm^2*NM*NC)/20 + (57071523750713393507285171933*CF*NC*
         NL)/1217166769461202560000 - (1681842538840359638357*CF*lm*NC*NL)/
        1501173850176000 - (13464559*CF*lm^2*NC*NL)/20 + 
       (2485178794856440219955952254309412084820686009004889389183467191*CF*
         NC*NH)/1913490311058582599270887672962912060321850582656000000 - 
       (1681842538840359638357*CF*lm*NC*NH)/1501173850176000 - 
       (13464559*CF*lm^2*NC*NH)/20 - (59769853133696350591084646281547*CF^2*
         NC*Pi^2)/8149229472384000 + (364971*CF^2*lm*NC*Pi^2)/10 + 
       (32511350961040041837997*CF*NM*NC*Pi^2)/91891800 + 
       (121657*CF*lm*NM*NC*Pi^2)/60 - (821008560725491*CF*NC*NL*Pi^2)/
        367567200 + (121657*CF*lm*NC*NL*Pi^2)/60 + 
       (121657*CF*lm*NC*NH*Pi^2)/60 - (8844402495276170936415166162567*CF^2*
         NC*Pi^3)/(233523237380483112416640*Sqrt[3]) - 
       (18327699814079874430660175*CF*NC*NH*Pi^3)/(100063090197999414*
         Sqrt[3]) - (38146129*CF^2*NC*Pi^4)/48 + 
       (299137192103598201029045534146612565201*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1390852725676288393397887008000*
         Sqrt[3]) + (4836416845021436239238554452179*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5008157664409870670700*Sqrt[3]) - 
       (413859843*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (8844402495276170936415166162567*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6306568910738355659400*
         Sqrt[3]) - (4189188528932542727008040*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (8844402495276170936415166162567*CF^2*NC*Pi*Log[3]^2)/
        (302715307715441071651200*Sqrt[3]) - (523648566116567840876005*CF*NC*
         NH*Pi*Log[3]^2)/(3706040377703682*Sqrt[3]) - 
       (CF*NC*(-(CA*(194648150935468544857194212988376492601 + 
             1196758742904951488227982016000*lm)) + 
          CF*(389296303491312559681648431155286226702 + 
            3916664976779841234200668416000*lm) + 
          6806800*((-2758861418604323533908264692059 + 
              31966929939177172779840*lm)*NM + 932846951692656*
             (41790173 + 34268140*lm)*NL + (9382853082670296083551 + 
              31966929939177172779840*lm)*NH))*Log[x]^2)/
        4423167467262704160000 + (CF*NC*(1145771407885155504686193*CA - 
          1496*(1531780225820714849207*CF - 1820*(48963735790764291*NM + 
              1106860922*NL)))*Log[x]^3)/91891800 - 
       (10744644940465404976283820952224587*CF^2*NC*PolyGamma[2, 1])/
        2223624226622209200 + (3089607664500836641*CF*NM*NC*PolyGamma[2, 1])/
        2700 - (6813315960217495738593784187*CF*NC*NH*PolyGamma[2, 1])/
        90056781178199472600 + CA*CF*NC*(-25489137793468520074348254786464784\
801926954359541173791020983216265404580839/
          3005710580610821546934710356690142264353562895236044800000000 + 
         (148110149*lm^2)/40 + (629156349039149981985153692869*Pi^2)/
          171562725734400 + (8844402495276170936415166162567*Pi^3)/
          (467046474760966224833280*Sqrt[3]) + (319182083*Pi^4)/800 + 
         lm*(2968101694519117699157/272940700032000 - (1338227*Pi^2)/120) - 
         (299137192103598201029045534146612565201*Im[PolyLog[2, (-1)^(1/3)]])/
          (2781705451352576786795774016000*Sqrt[3]) + 
         (413859843*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (8844402495276170936415166162567*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(12613137821476711318800*Sqrt[3]) + 
         (8844402495276170936415166162567*Pi*Log[3]^2)/
          (605430615430882143302400*Sqrt[3]) + 
         (10744644940465404976283820952224587*PolyGamma[2, 1])/
          4447248453244418400 - (106125116631750221276795779339608282047*
           Zeta[3])/75678826928860267912800) + 
       (106125119986743069466069470368268425159*CF^2*NC*Zeta[3])/
        37839413464430133956400 + (2110333363205515951*CF*NM*NC*Zeta[3])/
        1350 - (2493191077*CF*NC*NL*Zeta[3])/45 + 
       (8754726477826611799757624893*CF*NC*NH*Zeta[3])/
        45028390589099736300 + CF*Log[x]*
        ((4132199673195435501130225892091771386204861*NM*NC)/
          9383573739732629819814432000 - (1054820385490009*lm*NM*NC)/
          61261200 - 3093048*lm^2*NM*NC - (2358956167671232245373*NC*NL)/
          24835596786000 - (1054820385490009*lm*NC*NL)/61261200 - 
         3093048*lm^2*NC*NL - 
         (2529065459110496467693121593400540188105367300377*NC*NH)/
          1892998844177121694915248985138781280000 - 
         (1054820385490009*lm*NC*NH)/61261200 - 3093048*lm^2*NC*NH + 
         (3264248993366111*NM*NC*Pi^2)/9 - (1246048082*NC*NL*Pi^2)/135 + 
         (4189188528932542727008040*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1853020188851841*Sqrt[3]) + 
         CF*NC*
          (-2832428420077642533623467680819911223184243230399263979925327639/
            67647638795860367752982863158223946187696000000 - 
           (912707511386809*lm)/3403400 - 55674864*lm^2 - 
           (152769523599388630739891*Pi^2)/24504480 + 
           (8844402495276170936415166162567*Im[PolyLog[2, (-1)^(1/3)]])/
            (18919706732215066978200*Sqrt[3]) - 37116576*Zeta[3]) + 
         CA*NC*
          (514986988644415841930513664071273899297802443118714247303062023/
            24599141380312861001084677512081434977344000000 + 
           (1295981626392409*lm)/11138400 + 17011764*lm^2 + 
           (2291542859075938469709997*Pi^2)/735134400 - 
           (8844402495276170936415166162567*Im[PolyLog[2, (-1)^(1/3)]])/
            (37839413464430133956400*Sqrt[3]) + 18558288*Zeta[3])), 
      (8377973659797094412260008909181473134592461168273412927017078694137432\
782163*CF^2*NC)/
        697754241927512144824129189945925882796362814965510400000000 + 
       (564192478860462589*CF^2*lm*NC)/41699273616 + 14712669*CF^2*lm^2*NC + 
       (24800056882415796735675299426111569047924318380844353161849*CF*NM*
         NC)/338755346714119192526850492162160108800000 + 
       (1024323186549943417*CF*lm*NM*NC)/750586925088 + 
       (1634741*CF*lm^2*NM*NC)/2 - (296862884098475731144722359*CF*NC*NL)/
        4868667077844810240 + (1024323186549943417*CF*lm*NC*NL)/
        750586925088 + (1634741*CF*lm^2*NC*NL)/2 - 
       (1446623068361614572702081599383446921298414329095748649886897933*CF*
         NC*NH)/861070639976362169671899452833310427144832762195200000 + 
       (1024323186549943417*CF*lm*NC*NH)/750586925088 + 
       (1634741*CF*lm^2*NC*NH)/2 - (321356446135213827216021429035083*CF^2*
         NC*Pi^2)/60555043617868800 - 43320*CF^2*lm*NC*Pi^2 - 
       (47069998839163161374879*CF*NM*NC*Pi^2)/1531530 - 
       (7220*CF*lm*NM*NC*Pi^2)/3 + (2565845067427*CF*NC*NL*Pi^2)/918918 - 
       (7220*CF*lm*NC*NL*Pi^2)/3 - (7220*CF*lm*NC*NH*Pi^2)/3 + 
       (11291962795300961848996444522057*CF^2*NC*Pi^3)/
        (233523237380483112416640*Sqrt[3]) + (106761972237103713516712985*CF*
         NC*NH*Pi^3)/(450283905890997363*Sqrt[3]) + 
       (3589065173*CF^2*NC*Pi^4)/3600 - 
       (386978478948616918202039782133434568591*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1390852725676288393397887008000*
         Sqrt[3]) - (2801316239629009717573960253894*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2253670948984441801815*Sqrt[3]) + 
       (514887213*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (11291962795300961848996444522057*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6306568910738355659400*
         Sqrt[3]) + (48805473022675983321925936*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) + 
       (11291962795300961848996444522057*CF^2*NC*Pi*Log[3]^2)/
        (302715307715441071651200*Sqrt[3]) + (3050342063917248957620371*CF*NC*
         NH*Pi*Log[3]^2)/(16677181699666569*Sqrt[3]) + 
       CF*((-140838473849433123457707363727918662467*CF*NC)/
          2211583733631352080000 + 
         CA*(140838474905406927795551744879820518327/4423167467262704160000 - 
           (3144753194*lm)/9)*NC + 1143546616*CF*lm*NC - 
         (11982855493939233303354064166873*NM*NC)/32490799401060 + 
         (571773308*lm*NM*NC)/9 + (3486040808*NC*NL)/45 + 
         (571773308*lm*NC*NL)/9 + (123383407327026950017*NC*NH)/
          6498159880212 + (571773308*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-102960524828536927338453*CA + 4*(51480245717709747616409*CF + 
            850850*(355710586042648827*NM + 142943327*NL)))*Log[x]^3)/
        11486475 - (87777662773404707704328521584472426*CF^2*NC*
         PolyGamma[2, 1])/33771292941824802225 - 
       (31010314556004281819*CF*NM*NC*PolyGamma[2, 1])/1350 + 
       (39115920100479786780566544253*CF*NC*NH*PolyGamma[2, 1])/
        405255515301897626700 + CA*CF*NC*
        (-8624384568316792552433178445069003810091849227279737492420405337514\
74343287/143655285102723088640261892047690622928662932492899200000000 - 
         (17982151*lm^2)/4 + (408538578568932345113634369619*Pi^2)/
          153966548736000 - (11291962795300961848996444522057*Pi^3)/
          (467046474760966224833280*Sqrt[3]) - (3602927573*Pi^4)/7200 + 
         lm*(-1805151054144213913/136470350016 + (39710*Pi^2)/3) + 
         (386978478948616918202039782133434568591*Im[PolyLog[2, (-1)^(1/3)]])/
          (2781705451352576786795774016000*Sqrt[3]) - 
         (514887213*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
         (11291962795300961848996444522057*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(12613137821476711318800*Sqrt[3]) - 
         (11291962795300961848996444522057*Pi*Log[3]^2)/
          (605430615430882143302400*Sqrt[3]) + 
         (43888831386702353852164260792236213*PolyGamma[2, 1])/
          33771292941824802225 - (34621581109881814099700481789746734968769*
           Zeta[3])/18389954943713045102810400) + 
       (6924316013506652017273898528105115324617*CF^2*NC*Zeta[3])/
        1838995494371304510281040 + (4560743779027553281*CF*NM*NC*Zeta[3])/
        675 + (641626808*CF*NC*NL*Zeta[3])/9 - 
       (52492717279562889676289840747*CF*NC*NH*Zeta[3])/
        202627757650948813350 + CF*Log[x]*
        ((-398134608826131276728184664032053061152946731*NM*NC)/
          2345893434933157454953608000 + (16537802871797*lm*NM*NC)/765765 + 
         3866310*lm^2*NM*NC + (1213252916142075058819*NC*NL)/
          9934238714400 + (16537802871797*lm*NC*NL)/765765 + 
         3866310*lm^2*NC*NL + 
         (937353912034256013678198243313400571857575978517*NC*NH)/
          542086032650721212634821300289741912000 + 
         (16537802871797*lm*NC*NH)/765765 + 3866310*lm^2*NC*NH - 
         (237140390624873204*NM*NC*Pi^2)/9 + (320683444*NC*NL*Pi^2)/27 - 
         (48805473022675983321925936*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CA*NC*
          (4197814031859051987969650118211157158983070783258901498528388031/
            270590555183441471011931452632895784750784000000 - 
           (20305947260897*lm)/139230 - 21264705*lm^2 + 
           (1647368341302872003544419*Pi^2)/735134400 + 
           (11291962795300961848996444522057*Im[PolyLog[2, (-1)^(1/3)]])/
            (37839413464430133956400*Sqrt[3]) - 23197860*Zeta[3]) + 
         CF*NC*
          (-322908775089605129150979732240148425723642834951877493482168087/
            10407329045516979654305055870495991721184000000 + 
           (28634578427869*lm)/85085 + 69593580*lm^2 - 
           (1647368347829839197699827*Pi^2)/367567200 - 
           (11291962795300961848996444522057*Im[PolyLog[2, (-1)^(1/3)]])/
            (18919706732215066978200*Sqrt[3]) + 46395720*Zeta[3])), 
      (1181234738012829410793661107781148910200991815719611571285512473463922\
2227111549*CF^2*NC)/
        65937775862149897685880208449889995924256286014240732800000000 - 
       (361505701977171068857*CF^2*lm*NC)/22517607752640 - 
       17552561*CF^2*lm^2*NC - 
       (104756751140517694469443832838442423973330096059447912507163*CF*NM*
         NC)/10162660401423575775805514764864803264000000 - 
       (657936964716385952137*CF*lm*NM*NC)/405316939547520 - 
       (17552561*CF*lm^2*NM*NC)/18 + (936023298223295243695969913*CF*NC*NL)/
        12171667694612025600 - (657936964716385952137*CF*lm*NC*NL)/
        405316939547520 - (17552561*CF*lm^2*NC*NL)/18 + 
       (161404242099199649987498875939542286776343469432254529212939603217*CF*
         NC*NH)/77496357597872595270470950754997938443034948597568000000 - 
       (657936964716385952137*CF*lm*NC*NH)/405316939547520 - 
       (17552561*CF*lm^2*NC*NH)/18 - (542754534788296484541172190432935717*
         CF^2*NC*Pi^2)/7084940103290649600 + (451250*CF^2*lm*NC*Pi^2)/9 + 
       (70117416044982426287395*CF*NM*NC*Pi^2)/33081048 + 
       (225625*CF*lm*NM*NC*Pi^2)/81 - (112856426114155*CF*NC*NL*Pi^2)/
        33081048 + (225625*CF*lm*NC*NL*Pi^2)/81 + (225625*CF*lm*NC*NH*Pi^2)/
        81 - (379240249721587025943809650017439*CF^2*NC*Pi^3)/
        (6305127409273044035249280*Sqrt[3]) - 
       (4770275756742875921391355415*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) - (39668588417*CF^2*NC*Pi^4)/32400 + 
       (1844055648400875639105896241308548344671*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5364717656179969517391849888000*
         Sqrt[3]) + (62964480662977367648884194803503*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40566077081719952432670*Sqrt[3]) - 
       (1886155859*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (54177178531655289420544235716777*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(24325337227133657543400*
         Sqrt[3]) - (545174372199185819587583476*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (54177178531655289420544235716777*CF^2*NC*Pi*Log[3]^2)/
        (1167616186902415562083200*Sqrt[3]) - 
       (136293593049796454896895869*CF*NC*NH*Pi*Log[3]^2)/
        (600378541187996484*Sqrt[3]) + 
       CF*((-18297612317486289063310712169179236115417*CF*NC)/
          19904253602682168720000 - 1434008888*CF*lm*NC + 
         CA*(18297612305670223067765366320245012513677/
            39808507205364337440000 + (3943524442*lm)/9)*NC + 
         (24791884421262422603170798101877*NM*NC)/974723982031800 - 
         (717004444*lm*NM*NC)/9 - (484597546*NC*NL)/5 - 
         (717004444*lm*NC*NL)/9 - (23588906472255942379349*NC*NH)/
          974723982031800 - (717004444*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-9003429356306622887720927*CA + 
          24*(750285801109884138442171*CF - 850850*(32055854814093860*NM + 
              179251111*NL)))*Log[x]^3)/68918850 - 
       (9163768328360368257878840045444794288*CF^2*NC*PolyGamma[2, 1])/
        182364981885853932015 + (31428035011496631247*CF*NM*NC*
         PolyGamma[2, 1])/3240 - (876019497811025371851174316109*CF*NC*NH*
         PolyGamma[2, 1])/7294599275434157280600 + 
       CA*CF*NC*(-82230054921576803213577789906750542986709316270997611977454\
74325272173326701/
          91803377462095228243480972432843711694056785261734400000000 + 
         (193078171*lm^2)/36 + (6210006119241968126467897913699653*Pi^2)/
          162126775819008000 + (379240249721587025943809650017439*Pi^3)/
          (12610254818546088070498560*Sqrt[3]) + (13270996139*Pi^4)/21600 + 
         lm*(1160971834819296057097/73693989008640 - (2481875*Pi^2)/162) - 
         (1844055648400875639105896241308548344671*
           Im[PolyLog[2, (-1)^(1/3)]])/(10729435312359939034783699776000*
           Sqrt[3]) + (1886155859*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (54177178531655289420544235716777*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(48650674454267315086800*Sqrt[3]) + 
         (54177178531655289420544235716777*Pi*Log[3]^2)/
          (2335232373804831124166400*Sqrt[3]) + 
         (4581884164180184128939420022722397144*PolyGamma[2, 1])/
          182364981885853932015 - 
         (7482419583437141109005807228785988345924129*Zeta[3])/
          496528783480252217775880800) + 
       (7482419618574316299141113478442919087938637*CF^2*NC*Zeta[3])/
        248264391740126108887940400 + (23734630662056208967*CF*NM*NC*
         Zeta[3])/1620 - (2407092292*CF*NC*NL*Zeta[3])/27 + 
       (1161481253036949242120890935091*CF*NC*NH*Zeta[3])/
        3647299637717078640300 + CF*Log[x]*
        ((-43749483187036879529735153614363456471159937*NM*NC)/
          17594200761998680912152060000 - (727813175333861*lm*NM*NC)/
          27567540 - 4725490*lm^2*NM*NC - (4543943086352811948791*NC*NL)/
          29802716143200 - (727813175333861*lm*NC*NL)/27567540 - 
         4725490*lm^2*NC*NL - 
         (71984814162977967700616714574559400385964780573423*NC*NH)/
          33541573270263375031779567955427780805000 - 
         (727813175333861*lm*NC*NH)/27567540 - 4725490*lm^2*NC*NH + 
         (21370569787513523*NM*NC*Pi^2)/9 - (401031632*NC*NL*Pi^2)/27 + 
         (545174372199185819587583476*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*
          (
           -15784526334138010937576648994466704741868525599146233375581761719\
43/3652972494976459858661074610544093094135584000000 - (630110574387911*lm)/
            1531530 - 85058820*lm^2 - (72027435036783588680753179*Pi^2)/
            1102701600 + (54177178531655289420544235716777*
             Im[PolyLog[2, (-1)^(1/3)]])/(72976011681400972630200*Sqrt[3]) - 
           56705880*Zeta[3]) + CA*NC*(157845263489602031577710851052006880739\
7331295713202695018783507143/
            7305944989952919717322149221088186188271168000000 + 
           (893611528454261*lm)/5012280 + 25990195*lm^2 + 
           (72027435061295586752418283*Pi^2)/2205403200 - 
           (54177178531655289420544235716777*Im[PolyLog[2, (-1)^(1/3)]])/
            (145952023362801945260400*Sqrt[3]) + 28352940*Zeta[3])), 
      (2024640366755464680019722496246715531824769273911531536253691409439473\
46232483*CF^2*NC)/
        1569947044336902325854290677378333236291816333672398400000000 + 
       (2971189068573484157*CF^2*lm*NC)/153181005120 + 
       21093933*CF^2*lm^2*NC + 
       (61043572065406728974439203654129716574728162565076748137161*CF*NM*
         NC)/80656034931933141077821545752895264000000 + 
       (5394581462728936877*CF*lm*NM*NC)/2757258092160 + 
       (7031311*CF*lm^2*NM*NC)/6 - (11653803780450721889803353409*CF*NC*NL)/
        118239057604802534400 + (5394581462728936877*CF*lm*NC*NL)/
        2757258092160 + (7031311*CF*lm^2*NC*NL)/6 - 
       (223550714798225812651990743200004305828393507180828419043281983058297\
1*CF*NC*NH)/841162071729651550336106800412766551990367696709845408000000 + 
       (5394581462728936877*CF*lm*NC*NH)/2757258092160 + 
       (7031311*CF*lm^2*NC*NH)/6 - (36075553961539240028184812620403*CF^2*NC*
         Pi^2)/642624952679424 - (176890*CF^2*lm*NC*Pi^2)/3 - 
       (620794094162877555220583*CF*NM*NC*Pi^2)/1969110 - 
       (88445*CF*lm*NM*NC*Pi^2)/27 + (6639164045153*CF*NC*NL*Pi^2)/
        1575288 - (88445*CF*lm*NC*NL*Pi^2)/27 - (88445*CF*lm*NC*NH*Pi^2)/
        27 + (159311600034144802741294196063413*CF^2*NC*Pi^3)/
        (2101709136424348011749760*Sqrt[3]) + 
       (9136428153460690210601086565*CF*NC*NH*Pi^3)/(24315330918113857602*
         Sqrt[3]) + (16386081859*CF^2*NC*Pi^4)/10800 - 
       (784343868759675084081523390967420496797*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1788239218726656505797283296000*
         Sqrt[3]) - (291542586781735763380665259722098*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(147776423654836969576155*Sqrt[3]) + 
       (773371193*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (22758800004877828963042028009059*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(8108445742377885847800*
         Sqrt[3]) + (2088326435076729190994534072*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) + (22758800004877828963042028009059*CF^2*NC*Pi*Log[3]^2)/
        (389205395634138520694400*Sqrt[3]) + (261040804384591148874316759*CF*
         NC*NH*Pi*Log[3]^2)/(900567811781994726*Sqrt[3]) + 
       CF*((-638503480442887110242561753657400874403*CF*NC)/
          947821600127722320000 + CA*(91214783023651255708453742499477724649/
            270806171465063520000 - (5023093460*lm)/9)*NC + 
         1826579440*CF*lm*NC - (29266443624244633181290854933889*NM*NC)/
          7735904619300 + (913289720*lm*NM*NC)/9 + (1111003264*NC*NL)/9 + 
         (913289720*lm*NC*NL)/9 + (332142145474258725167*NC*NH)/
          10601054478300 + (913289720*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-312508190167478164696933*CA + 
          28*(22322012439345897051067*CF + 1215500*(104482850088527463*NM + 
              6523498*NL)))*Log[x]^3)/3281850 - 
       (3488718905985026634398052348373390267*CF^2*NC*PolyGamma[2, 1])/
        121576654590569288010 - (417001150436569058473*CF*NM*NC*
         PolyGamma[2, 1])/1800 + (3311381504590593290076333343747*CF*NC*NH*
         PolyGamma[2, 1])/21883797826302471841800 + 
       CA*CF*NC*(-47638596798618365945285026736084448122428294808324236602613\
724770001502057121/
          738798609099718741578489730530980346490266509963481600000000 - 
         (77344421*lm^2)/12 + (553791398474768290625334691573289*Pi^2)/
          19729713459456000 - (159311600034144802741294196063413*Pi^3)/
          (4203418272848696023499520*Sqrt[3]) - (5480895553*Pi^4)/7200 + 
         lm*(-9507004919477583917/501319653120 + (972895*Pi^2)/54) + 
         (784343868759675084081523390967420496797*Im[PolyLog[2, (-1)^(1/3)]])/
          (3576478437453313011594566592000*Sqrt[3]) - 
         (773371193*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
         (22758800004877828963042028009059*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(16216891484755771695600*Sqrt[3]) - 
         (22758800004877828963042028009059*Pi*Log[3]^2)/
          (778410791268277041388800*Sqrt[3]) + 
         (3488718905985026634398052348373390267*PolyGamma[2, 1])/
          243153309181138576020 - (40659382152584443273631003817562980597401*
           Zeta[3])/2149475253161265012016800) + 
       (40659381960534445441557213333753272471573*CF^2*NC*Zeta[3])/
        1074737626580632506008400 + (70585482736584710327*CF*NM*NC*Zeta[3])/
        900 + (1018716160*CF*NC*NL*Zeta[3])/9 - 
       (4558406278629862521103791399053*CF*NC*NH*Zeta[3])/
        10941898913151235920900 + CF*Log[x]*
        ((-963785922334263204660939970280485118431009519*NM*NC)/
          558546055936466060703240000 + (8588797578143*lm*NM*NC)/262548 + 
         5837370*lm^2*NM*NC + (373366980725909125547*NC*NL)/1930080664512 + 
         (8588797578143*lm*NC*NL)/262548 + 5837370*lm^2*NC*NL + 
         (215675794514148784555327687295639811190710047922911291*NC*NH)/
          78717280811983817860296391767395369009220000 + 
         (8588797578143*lm*NC*NH)/262548 + 5837370*lm^2*NC*NH - 
         (2437933168628871508*NM*NC*Pi^2)/9 + (509181190*NC*NL*Pi^2)/27 - 
         (2088326435076729190994534072*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CA*NC*
          (56194516178608332713865185270750566915546310515763395791561988837/
            347902142378710462729626153385151723251008000000 - 
           (10539366438383*lm)/47736 - 32105535*lm^2 + 
           (75759560865044499196129*Pi^2)/3182400 + 
           (22758800004877828963042028009059*Im[PolyLog[2, (-1)^(1/3)]])/
            (48650674454267315086800*Sqrt[3]) - 35024220*Zeta[3]) + 
         CF*NC*
          (-56194516267031948131253923729203482697727255989567194061556959037/
            173951071189355231364813076692575861625504000000 + 
           (7439355214073*lm)/14586 + 105072660*lm^2 - 
           (227278682729556243492691*Pi^2)/4773600 - 
           (22758800004877828963042028009059*Im[PolyLog[2, (-1)^(1/3)]])/
            (24325337227133657543400*Sqrt[3]) + 70048440*Zeta[3])), 
      (3024181538839573872527508974409786428931846242853868259471068426069710\
358944243817*CF^2*NC)/
        1610765667489661786326502234990169900435403558347880758400000000 - 
       (1262583583722840776531*CF^2*lm*NC)/55298342848320 - 
       24952641*CF^2*lm^2*NC - 
       (1162430483135273305523172245785534616472055235973851105953*CF*NM*NC)/
        17372069062262522693684640623700518400000 - 
       (2297463356464625586371*CF*lm*NM*NC)/995370171269760 - 
       (8317547*CF*lm^2*NM*NC)/6 + (282460888837952688704643281797*CF*NC*
         NL)/2298385373594892341760 - (2297463356464625586371*CF*lm*NC*NL)/
        995370171269760 - (8317547*CF*lm^2*NC*NL)/6 + 
       (182982714663492860783409418235039000485994413057473401069701921695033\
7*CF*NC*NH)/560774714486434366890737866941844367993578464473230272000000 - 
       (2297463356464625586371*CF*lm*NC*NH)/995370171269760 - 
       (8317547*CF*lm^2*NC*NH)/6 - (5094633048256196997124943536104326987*
         CF^2*NC*Pi^2)/6410183902977254400 + (203350*CF^2*lm*NC*Pi^2)/3 + 
       (7988821338278143720461161*CF*NM*NC*Pi^2)/1047566520 + 
       (101675*CF*lm*NM*NC*Pi^2)/27 - (152651773123973*CF*NC*NL*Pi^2)/
        29930472 + (101675*CF*lm*NC*NL*Pi^2)/27 + (101675*CF*lm*NC*NH*Pi^2)/
        27 - (9144257898716638078405917863657239*CF^2*NC*Pi^3)/
        (98016071544153684547966080*Sqrt[3]) - 
       (7486628569133892643352023885*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) - (19921755539*CF^2*NC*Pi^4)/10800 + 
       (121552952189417480406876614273736186134387*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(226363216427645726779300263456000*
         Sqrt[3]) + (240250006347120417942482757768847*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(98517615769891313050770*Sqrt[3]) - 
       (935379753*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (1306322556959519725486559694808177*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(378148424167259585447400*
         Sqrt[3]) - (855614693615302016383088444*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (1306322556959519725486559694808177*CF^2*NC*Pi*Log[3]^2)/
        (18151124360028460101475200*Sqrt[3]) - 
       (213903673403825504095772111*CF*NC*NH*Pi*Log[3]^2)/
        (600378541187996484*Sqrt[3]) + 
       CF*((-171752816729886229728174837763168660588343*CF*NC)/
          18008610402426724080000 - 2265823720*CF*lm*NC + 
         CA*(171752816712984586078940099580967130317283/
            36017220804853448160000 + (6231015230*lm)/9)*NC + 
         (1982218300366749914193896722283*NM*NC)/21660532934040 - 
         (1132911860*lm*NM*NC)/9 - (6876431246*NC*NL)/45 - 
         (1132911860*lm*NC*NL)/9 - (278776672433675948149*NC*NH)/
          7067369652200 - (1132911860*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(84753563242137343136830493*CA - 
          304*(557589234394209951684119*CF - 1154725*(8330849708806986*NM + 
              14906735*NL)))*Log[x]^3)/62355150 - 
       (1705827699291467851507405521442832749993*CF^2*NC*PolyGamma[2, 1])/
        3282569673945370776270 + (435546014241260862199*CF*NM*NC*
         PolyGamma[2, 1])/5400 - (815668406034335806044637201493*CF*NC*NH*
         PolyGamma[2, 1])/4376759565260494368360 + 
       CA*CF*NC*(-60483630783941377908159595039597968358838688288713202872727\
82249095198387745748009/
          6443062669958647145306008939960679601741614233391523033600000000 + 
         (91493017*lm^2)/12 + (25473165241508529096155837854940629159*Pi^2)/
          64101839029772544000 + (9144257898716638078405917863657239*Pi^3)/
          (196032143088307369095932160*Sqrt[3]) + (19986827539*Pi^4)/21600 + 
         lm*(4053622970814321021251/180976394776320 - (1118425*Pi^2)/54) - 
         (121552952189417480406876614273736186134387*
           Im[PolyLog[2, (-1)^(1/3)]])/(452726432855291453558600526912000*
           Sqrt[3]) + (935379753*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (1306322556959519725486559694808177*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(756296848334519170894800*
           Sqrt[3]) + (1306322556959519725486559694808177*Pi*Log[3]^2)/
          (36302248720056920202950400*Sqrt[3]) + 
         (1705827699291467851507405521442832749993*PolyGamma[2, 1])/
          6565139347890741552540 - 
         (1940005706036588246158504046577085969019808757*Zeta[3])/
          12129488853589018462810802400) + 
       (1940005707375767985035702668850536995024927601*CF^2*NC*Zeta[3])/
        6064744426794509231405401200 + (372231558577115274799*CF*NM*NC*
         Zeta[3])/2700 - (1260511780*CF*NC*NL*Zeta[3])/9 + 
       (1111000097857141086810097263307*CF*NC*NH*Zeta[3])/
        2188379782630247184180 + CF*Log[x]*
        ((-4387926805222358706825935870250157768367207*NM*NC)/
          48872779894440780311533500 - (987910830257251*lm*NM*NC)/24942060 - 
         7066290*lm^2*NM*NC - (14748238296874628709577*NC*NL)/
          61706905860600 - (987910830257251*lm*NC*NL)/24942060 - 
         7066290*lm^2*NC*NL - 
         (44181931708300274479276179757901383925370897467629663*NC*NH)/
          13119546801997302976716065294565894834870000 - 
         (987910830257251*lm*NC*NH)/24942060 - 7066290*lm^2*NC*NH + 
         (105524096182643557*NM*NC*Pi^2)/9 - (630052540*NC*NL*Pi^2)/27 + 
         (855614693615302016383088444*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*(-395586236129507318767758887252528429399870350640373266688835\
787088019/89236899520139233690149108343291417013883552000000 - 
           (855724958389201*lm)/1385670 - 127193220*lm^2 - 
           (25112166896454451967778143*Pi^2)/36951200 + 
           (1306322556959519725486559694808177*Im[PolyLog[2, (-1)^(1/3)]])/
            (1134445272501778756342200*Sqrt[3]) - 84795480*Zeta[3]) + 
         CA*NC*(3955862361851509251769889686054322143172431079821742927523850\
58751619/178473799040278467380298216686582834027767104000000 + 
           (1212226249184851*lm)/4534920 + 38864595*lm^2 + 
           (678028506239066879260607957*Pi^2)/1995364800 - 
           (1306322556959519725486559694808177*Im[PolyLog[2, (-1)^(1/3)]])/
            (2268890545003557512684400*Sqrt[3]) + 42397740*Zeta[3]))}, 0, 39, 
     1]
 
CbarSeries["p", 2, 3, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-224725550*NM - 42639360*lm*NM + 132710400*lm^2*NM + 
         349876224*NL - 42639360*lm*NL + 132710400*lm^2*NL - 
         224725550*NH - 42639360*lm*NH + 132710400*lm^2*NH - 
         10*CA*(10595581994 + 69445632*lm + 72990720*lm^2 - 
           8820968607*Zeta[3]) + 237313125*NM*Zeta[3] + 
         237313125*NH*Zeta[3] + 20*CF*(-44800916438 - 127954944*lm + 
           119439360*lm^2 + 37472842593*Zeta[3])))/334430208000, 
      -(CF*NC*(-460444030*NM + 91668480*lm*NM + 265420800*lm^2*NM + 
          671326208*NL + 91668480*lm*NL + 265420800*lm^2*NL - 
          495310650*NH + 91668480*lm*NH + 265420800*lm^2*NH - 
          60*CA*(3539576846 + 39368704*lm + 24330240*lm^2 - 
            2940322869*Zeta[3]) + 577324125*NM*Zeta[3] + 
          371928375*NH*Zeta[3] + 40*CF*(-44843568086 - 48328704*lm + 
            119439360*lm^2 + 37472842593*Zeta[3])))/222953472000, 
      (CF*NC*(-3310567461250*NM + 1506202091520*lm*NM + 
         1734082560000*lm^2*NM + 4604797386752*NL + 1506202091520*lm*NL + 
         1734082560000*lm^2*NL - 3788937487650*NH + 1506202091520*lm*NH + 
         1734082560000*lm^2*NH - 8*CA*(798102055564022 + 2552836177920*lm + 
           1192181760000*lm^2 - 663351189591825*Zeta[3]) + 
         5155926307875*NM*Zeta[3] + 2337896617875*NH*Zeta[3] + 
         560*CF*(-163314166868590 + 6609862656*lm + 55738368000*lm^2 + 
           135933257456325*Zeta[3])))/873977610240000, 
      -(CF*NC*(-20332680515630*NM + 7841411235840*lm*NM + 
          6242697216000*lm^2*NM + 18157840236544*NL + 7841411235840*lm*
           NL + 6242697216000*lm^2*NL - 12924254251650*NH + 
          7841411235840*lm*NH + 6242697216000*lm^2*NH - 
          96*CA*(676490160678702 + 904444190720*lm + 357654528000*lm^2 - 
            562498115185125*Zeta[3]) + 31043405665125*NM*Zeta[3] + 
          6787492243875*NH*Zeta[3] + 2240*CF*(-445982195425298 + 
            25387941888*lm + 50164531200*lm^2 + 371076386627835*Zeta[3])))/
       2621932830720000, 
      (CF*NC*(-(CA*(76637191727766917218 + 35356755469271040*lm + 
            12772558503936000*lm^2 - 63743703356304450675*Zeta[3])) + 
         2*(3708301609140224*NL + 1736433810800640*lm*NL + 
           1161141682176000*lm^2*NL - 850360646486610*NH + 
           1736433810800640*lm*NH + 1161141682176000*lm^2*NH - 
           79062579721125*NH*Zeta[3] + 315*NM*(-29067235624706 + 
             5512488288256*lm + 3686164070400*lm^2 + 36474598296675*
              Zeta[3]) + 63*CF*(-11528684169698314466 + 247307871191040*lm + 
             331754766336000*lm^2 + 9591160118703239475*Zeta[3]))))/
       1038285400965120000, -(CF*NC*(-7755299574655878*NM + 
          525672429649920*lm*NM + 344596886323200*lm^2*NM + 
          1162434973007872*NL + 525672429649920*lm*NL + 
          344596886323200*lm^2*NL + 1574990926647894*NH + 
          525672429649920*lm*NH + 344596886323200*lm^2*NH - 
          CA*(39450391143800510434 + 5303376567336960*lm + 1895282874777600*
             lm^2 - 32818019978981414835*Zeta[3]) + 8052284638715625*NM*
           Zeta[3] - 1514082937838625*NH*Zeta[3] + 
          126*CF*(-6911965129729388642 + 38174966415360*lm + 
            49228126617600*lm^2 + 5750153266598589555*Zeta[3])))/
       207657080193024000, 
      (CF*NC*(-44*CA*(978573243194012825784886 + 25062387989151744000*lm + 
           10786631665582080000*lm^2 - 814095923158792248368625*Zeta[3]) + 
         5*(616*CF*(-357064964231168234730158 + 151666313999155200*lm + 
             504310051897344000*lm^2 + 297044862907752405663525*Zeta[3]) + 
           5*(1048576*(9932492285537 + 3458846340180*lm + 3291818745600*lm^2)*
              NL + 693*NH*(130274218836471358 + 5233568917749760*lm + 
               4980840018739200*lm^2 - 109649856711520125*Zeta[3]) + 
             693*NM*(-403910091598919114 + 5233568917749760*lm + 
               4980840018739200*lm^2 + 368710118184783375*Zeta[3])))))/
       97993376143088025600000, 
      (CF*NC*(44*CA*(693542061620468356934482 - 2741566045342924800*lm + 
           509872295116800000*lm^2 - 576976684016938550758875*Zeta[3]) - 
         5*(-5463908531887407104*NL - 5424791073513799680*lm*NL + 
           815795672186880000*lm^2*NL + 283369258425869693154*NH - 
           5424791073513799680*lm*NH + 815795672186880000*lm^2*NH - 
           232900538489677933875*NH*Zeta[3] + 231*NM*
            (-3611349129708816886 - 23483944041185280*lm + 3531582996480000*
              lm^2 + 3069081411695924625*Zeta[3]) + 
           616*CF*(-289662029310988057521274 - 176395261197680640*lm + 
             23838185226240000*lm^2 + 240971683434541342442775*Zeta[3]))))/
       32664458714362675200000, 
      -(CF*NC*(104*CF*(2926585347831341673952653815878 + 
            1575484955963800997068800*lm + 394349101569760296960000*lm^2 - 
            2434645920731552450726274095625*Zeta[3]) - 
          44*CA*(-208577198678338062476487250582 + 1713938516827660143820800*
             lm + 284807684467049103360000*lm^2 + 
            173520137628054531714289514625*Zeta[3]) + 
          35*(67108864*(8351338981681673 + 4603031735161860*lm + 
              970049192112000*lm^2)*NL + 429*NM*(73132060484376553028122 + 
              720056481824385269760*lm + 151745686029729792000*lm^2 - 
              60297433131304196202375*Zeta[3]) + 1287*NH*
             (-7234093193515623277986 + 240018827274795089920*lm + 
              50581895343243264000*lm^2 + 5928121661300373409875*Zeta[3]))))/
       4946182996363653729484800000, 
      (CF*NC*(208*CF*(2649826327252435339125884063954 + 
           825865581033156929126400*lm + 300682705671951482880000*lm^2 - 
           2204409153980413070600905870875*Zeta[3]) - 
         88*CA*(-167792378479662394024339470274 + 1035713387390673774182400*
            lm + 217159731874187182080000*lm^2 + 
           139589321669271086924211775875*Zeta[3]) + 
         5*(134217728*(38371534230568433 + 18103796818167060*lm + 
             5177491471152000*lm^2)*NL + 429*NM*(760465784115910344571514 + 
             5663987126125901905920*lm + 1619839491835428864000*lm^2 - 
             622836440811766786980375*Zeta[3]) + 1287*NH*
            (-57605608981398622875302 + 1887995708708633968640*lm + 
             539946497278476288000*lm^2 + 47322873929844689801625*Zeta[3]))))/
       4239585425454560339558400000, 
      -(CF*NC*(72*CF*(9719805559568299769864774348416462 + 
            1443053640005588694859776000*lm + 648949750438654535270400000*
             lm^2 - 8085976561134311413780885649095125*Zeta[3]) - 
          1716*CA*(-9774516708354431364185805088522 + 
            35329512805736059502592000*lm + 8319868595367365836800000*lm^2 + 
            8131542632036836435501899195375*Zeta[3]) + 
          2275*(2147483648*(3801520454641379 + 1579986457669620*lm + 
              531324441648000*lm^2)*NL + 77*NM*
             (10311814045233332702886494 + 44064871193596793978880*lm + 
              14818318834049482752000*lm^2 - 8471062838343522946654125*Zeta[
                3]) + 143*NH*(-870557622191938601988166 + 
              23727238335013658296320*lm + 7979094756795875328000*lm^2 + 
              717733129067079195695625*Zeta[3]))))/
       2690723550021827628839731200000, 
      (CF*NC*(576*CF*(2319466086726791537547067653167662 + 
           139636131827235415916544000*lm + 79608894935367942144000000*lm^2 - 
           1929580838100436033326199534273125*Zeta[3]) - 
         3168*CA*(-9098225920604921267625082837686 + 
           16703511931371344887808000*lm + 4422716385298219008000000*lm^2 + 
           7568903117446298699724804776625*Zeta[3]) + 
         175*(42949672960*(2346292720791101 + 848696925932856*lm + 
             338932850256000*lm^2)*NL + 143*NM*
            (126810740902168377799510294 + 254903883992821735096320*lm + 
             101797587929341624320000*lm^2 - 104680091207130736426754625*
              Zeta[3]) + 1001*NH*(-1804925287774725902285786 + 
             36414840570403105013760*lm + 14542512561334517760000*lm^2 + 
             1493063865128108296398375*Zeta[3]))))/
       2690723550021827628839731200000, 
      -(CF*NC*(374*CF*(1294269041270088681495879120913078926698 + 
            25317902143706458850478312652800*lm + 
            21166080374960550531248947200000*lm^2 - 
            1076711949858627142162239501865090965375*Zeta[3]) - 
          CA*(-9451761850902676467539976091528711676818 + 
            7785871868317849804351552566067200*lm + 
            2418812629516325135709949132800000*lm^2 + 
            7862999282837303040031364545874152930875*Zeta[3]) + 
          210*(77309411328*(175495581687126648273 + 52718760434909649080*lm + 
              27088682126425920000*lm^2)*NL + 2431*NH*
             (1676534897229420909601751040*lm + 861460332721227127848960000*
               lm^2 + 508079*(-253125154715482895987458 + 
                209957602356267349003875*Zeta[3])) + 2431*NM*
             (1676534897229420909601751040*lm + 861460332721227127848960000*
               lm^2 - 323*(-6704558255713980307267305386 + 
                5555234969100033308013297375*Zeta[3])))))/
       531891468474114798358522704691200000, 
      (CF*NC*(34*CF*(2797519844022951848523737126112695644174 + 
           9520559677111491418882100428800*lm + 
           20630134966740781903915253760000*lm^2 - 
           2327277397513991646960759988933938595125*Zeta[3]) - 
         3*CA*(-563077532621245109509088595122732958982 + 
           177475800199806475009016620646400*lm + 
           71441393310750485482076897280000*lm^2 + 
           468428488433100611212513867499183459625*Zeta[3]) + 
         35*(17179869184*(364901955626325512411 + 78512661568680098760*lm + 
             64806800992485552000*lm^2)*NL + 153153*NM*
            (40362365454014124668800016906 + 8807122648838666746593280*lm + 
             7269673877001581101056000*lm^2 - 33517651119211009916978187375*
              Zeta[3]) + 2431*NH*(-85643312791791030794876471542 + 
             554848726876836005035376640*lm + 457989454251099609366528000*
              lm^2 + 71181943176838206582593348625*Zeta[3]))))/
       59099052052679422039835856076800000, 
      -(CF*NC*(304*CF*(1548164344803249103558174648720168167062558 - 
            2767970065017995633393816253235200*lm + 
            4895632527828615342213939855360000*lm^2 - 
            1287929342210707255038036241949374655170125*Zeta[3]) - 
          936*CA*(-8158355223917467414775642153264278505966 + 
            708035568637600212982732895027200*lm + 
            485843873844340269004137431040000*lm^2 + 
            6786995516351889626846642344283923525125*Zeta[3]) + 
          35*(274877906944*(35218761135422549851631 + 1586512836743694219360*
               lm + 8594131816823805252000*lm^2)*NL + 37791*NM*
             (11539713897591877526607626240*lm + 
              62510570395315381802631168000*lm^2 + 1083*(
                765861920021805671908223216366 - 
                636696455495722540356574261125*Zeta[3])) + 
            4199*NH*(103857425078326897739468636160*lm + 
              562595133557838436223680512000*lm^2 + 79781*(
                -1718359257973104523218555598 + 1430226701408222080413175125*
                 Zeta[3])))))/170678062328138170851045952349798400000, 
      (CF*NC*(684*CF*(859532792155003404444494945821173398344958 - 
           2313901981411692606599467106304000*lm + 
           1100411283241755570217030778880000*lm^2 - 
           715051670841825339097748354559576225652125*Zeta[3]) - 
         6*CA*(-1458337287986534423485952915152587992060786 - 
           3067774020765264578339810574336000*lm + 
           38330993032921152362559905464320000*lm^2 + 
           1213201353016728132365014518038555666212875*Zeta[3]) + 
         175*(29393*NM*(279584490321106116940962347583926 - 
             10997089437476228120319098880*lm + 8129365837966612394252697600*
              lm^2 - 232544436324601464157352866232625*Zeta[3]) + 
           10*(137438953472*(232755812549633615134 - 235186198432157669697*
                lm + 173856424280786186940*lm^2)*NL + 4199*NH*
              (-7697962606233359684223369216*lm + 
               5690556086576628675976888320*lm^2 + 4199*
                (-452202133083961351816005254 + 376719867360935719649253225*
                  Zeta[3]))))))/128008546746103628138284464262348800000, 
      -(CF*NC*(8*CF*(966143995858606873723574894820458799209054952854 - 
            2158828045563409215860388622994767872000*lm + 
            461409556972481997853452214279864320000*lm^2 - 
            803742315955775551722365730986517015984945338625*Zeta[3]) - 
          68*CA*(-1557453487238462987765743437912079139138454986 - 
            44054725027973127196813604853645312000*lm + 
            16586618061102294040483576330321920000*lm^2 + 
            1295656832658747996824900433195132434817615375*Zeta[3]) + 
          98175*(137438953472*(-60115849921909448577083 - 
              59710354282756358901720*lm + 15198240689521236547200*lm^2)*
             NL + 2223*NM*(92767775850620694704281251784628782 - 
              3691645795800444058931906478080*lm + 
              939644757077537754280938700800*lm^2 - 
              77173331881936617109980605059777125*Zeta[3]) + 
            20995*NH*(-49056218478343857718393646471866 - 
              390880143084752900357495980032*lm + 
              99491797808209879865040568320*lm^2 + 
              40888525957921667490309992121975*Zeta[3]))))/
       1036357194456454973407551022667975884800000, 
      (CF*NC*(16*CF*(139390754947807405504287241503347901697268568854 - 
           214887753394184206396724298383779430400*lm + 
           21383191438541903619398170784563200000*lm^2 - 
           115960196932740171370087834767038768106309218625*Zeta[3]) - 
         8*CA*(-3528758047813845142089654652412568115801566442 - 
           104888293212692717490686554570280140800*lm + 
           13067505879108941100743326590566400000*lm^2 + 
           2935599459962400556595707661358902169696669375*Zeta[3]) + 
         105*(274877906944*(-10614195713268700992893053 - 
             6124134559073372673872040*lm + 658553204498627758320000*lm^2)*
            NL + 188955*NM*(320931132240602461954677695275698430 - 
             8908942814117144318577603510272*lm + 
             958015011319344834099019776000*lm^2 - 
             266994670501898085486849355562240925*Zeta[3]) + 
           20995*NH*(-7267577755769982467122911141449926 - 
             80180485327054298867198431592448*lm + 
             8622135101874103506891177984000*lm^2 + 
             6058789628213233379893488404366025*Zeta[3]))))/
       188428580810264540619554731394177433600000, 
      -(CF*NC*(368*CF*(877035838140843753938966578470728132594975010874394 - 
            848255260098540630425066633336462298316800*lm + 
            28381100063056290615755740690331467776000*lm^2 - 
            729612580445190566214435705857013231843574617546375*Zeta[3]) - 
          40*CA*(-94640077476309150395277938378488133809871451966754 - 
            2223161698307352475276987310398309253775360*lm + 
            79782425732813794730957804385042903859200*lm^2 + 
            78731770915899107227569361075113003399941653033875*Zeta[3]) + 
          385*(277076930199552*(-347535324124159506499606063 - 
              158490660374878296110457240*lm + 5439305372731866184348800*lm^
                2)*NL + 37145*NM*
             (71334993936021739741539734595312528434362 - 
              1182234638362392130005226725021057024*lm + 
              40573590929989916846670316704890880*lm^2 - 
              59346336086766137466077834345363058201975*Zeta[3]) + 
            37145*NH*(-1182234638362392130005226725021057024*lm + 
              40573590929989916846670316704890880*lm^2 + 
              7429*(-11956093255229404252872895313348846 + 
                9967267110853745576866936654625925*Zeta[3])))))/
       17543454587758869789843023711723495777894400000, 
      -(CF*NC*(-224*CA*(23951641760364871074330434302359222111303315938722 + 
            392878094283144773501502120249389167411200*lm + 
            4583115258759048558327231309850607616000*lm^2 - 
            19925546122136216870337279155148615279262818337875*Zeta[3]) + 
          19136*CF*(-25722215128832641421345823487246089681834422260918 + 
            14695825618411444855850397901779684556800*lm + 
            175576929949419312359145985114374144000*lm^2 + 
            21398500413120569567830555853395469553952227080625*Zeta[3]) + 
          1155*(8796093022208*(3982199535329451626924298443 + 
              1551583082589905243330492040*lm + 18372756123222116587171200*lm^
                2)*NL + 111435*NH*(8239137199901255080088970070481570282 + 
              122473810976309458246325242190364672*lm + 
              1450248772236760130498651656028160*lm^2 - 
              6867352432060760737048751107468134975*Zeta[3]) + 
            37145*NM*(-40714796399345441930528050541520498437390 + 
              367421432928928374738975726571094016*lm + 
              4350746316710280391495954968084480*lm^2 + 
              33871857658550634261846612266924791353525*Zeta[3]))))/
       17543454587758869789843023711723495777894400000}, 0, 20, 1]
 
CbarSeries["p", 2, 4, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(CF*(-1157360400*lm^2 + 16218036*Pi^2 + 793800*Pi^4 + 
            7144200*lm*(-221 + 12*Pi^2) + 35*(-35804493 + 124743552*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] - 9797760*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 20790592*PolyGamma[2, 1] - 
              207349952*Zeta[3])) + 35*CA*(21043251 + 6735960*lm^2 - 
            2241432*Pi^2 + 61236*Pi^4 - 15120*lm*(-1645 + 33*Pi^2) - 
            62371776*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            4898880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 10395296*PolyGamma[2, 1] + 
            109713040*Zeta[3]) + 70*(9*NL*(-131005 - 68040*lm^2 - 
              4932*Pi^2 + 1680*lm*(-98 + 3*Pi^2) - 60480*Zeta[3]) + 
            9*NM*(-131005 - 68040*lm^2 - 4932*Pi^2 + 1680*lm*(-98 + 
                3*Pi^2) + 5040*PolyGamma[2, 1] - 50400*Zeta[3]) + 
            NH*(3319767 - 612360*lm^2 + 15120*lm*(-98 + 3*Pi^2) - 
              257432016*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              42905336*PolyGamma[2, 1] + 459939952*Zeta[3]))))/10287648000, 
      (CF*NC*(2*(-280*(NL*(-34020*lm^2 - 1476*Pi^2 + 105*lm*(-217 + 
                 24*Pi^2) + 35*(4805 - 864*Zeta[3])) + 
             NM*(-34020*lm^2 - 1476*Pi^2 + 105*lm*(-217 + 24*Pi^2) + 35*
                (4805 + 72*PolyGamma[2, 1] - 720*Zeta[3])) + 
             NH*(16189219 - 34020*lm^2 + 105*lm*(-217 + 24*Pi^2) + 13397568*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 2232928*PolyGamma[2, 
                 1] - 37508096*Zeta[3])) + CF*(257191200*lm^2 + 
             3186909*Pi^2 + 1014300*Pi^4 - 793800*lm*(125 + 24*Pi^2) + 
             70*(2849936 + 2038602*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               2449440*Im[PolyLog[2, (-1)^(1/3)]]^2 - 321497*PolyGamma[2, 
                 1] - 6323074*Zeta[3]))) - 35*CA*(-17097414 + 2993760*lm^2 - 
           1655433*Pi^2 + 61236*Pi^4 - 840*lm*(-6923 + 264*Pi^2) + 
           4077204*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           4898880*Im[PolyLog[2, (-1)^(1/3)]]^2 - 642994*PolyGamma[2, 1] - 
           7797380*Zeta[3])))/1143072000, 
      -(CF*NC*(CA*(2405879496 - 484989120*lm^2 - 1424061*Pi^2 + 
            5422788*Pi^4 + 22680*lm*(-39899 + 264*Pi^2) - 1671330492*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1308000960*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 256446454*PolyGamma[2, 1] + 
            3797078732*Zeta[3]) + 2*(CF*(1190427840*lm^2 + 77632101*Pi^2 - 
              6293700*Pi^4 - 612360*lm*(899 + 24*Pi^2) + 2*(510576777 + 
                835665246*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 654000480*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 128223227*PolyGamma[2, 1] - 
                2230030246*Zeta[3])) - 4*(NH*(3244859811 - 11022480*lm^2 + 
                5670*lm*(-1153 + 24*Pi^2) + 4827213792*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 825988300*PolyGamma[2, 1] - 
                11405102360*Zeta[3]) + 27*NL*(1650005 - 408240*lm^2 - 
                124272*Pi^2 + 210*lm*(-1153 + 24*Pi^2) - 60480*Zeta[3]) + 
              27*NM*(-408240*lm^2 - 199872*Pi^2 + 210*lm*(-1153 + 24*Pi^2) - 
                35*(-64405 + 72*PolyGamma[2, 1] + 1872*Zeta[3]))))))/
       881798400, (CF*NC*(32648738035725*CF + 27990375487200*CF*lm + 
         27998862796800*CF*lm^2 - 3248486791200*NM + 2131286320800*lm*NM + 
         1036994918400*lm^2*NM + 718773199200*NL + 2131286320800*lm*NL + 
         1036994918400*lm^2*NL - 169478939095200*NH + 
         2131286320800*lm*NH + 1036994918400*lm^2*NH - 
         1084816726452*CF*Pi^2 - 462944160000*CF*lm*Pi^2 + 
         422773344000*NM*Pi^2 - 17146080000*lm*NM*Pi^2 + 
         463923936000*NL*Pi^2 - 17146080000*lm*NL*Pi^2 - 
         17146080000*lm*NH*Pi^2 + 111125140000*Sqrt[3]*CF*Pi^3 + 
         5185034960000*Sqrt[3]*NH*Pi^3 + 28402481520*CF*Pi^4 - 
         11634520099440*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         97860111014400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         23165725766400*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         4114805184000*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         191994437376000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         85725108000*Sqrt[3]*CF*Pi*Log[3]^2 + 3999884112000*Sqrt[3]*NH*Pi*
          Log[3]^2 + 61725888000*(-2*CA*(76 + 33*lm) + 9*CF*(61 + 36*lm) + 
           4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         246903552000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
         2311015559720*CF*PolyGamma[2, 1] + 133053580800*NM*
          PolyGamma[2, 1] + 19381750366720*NH*PolyGamma[2, 1] + 
         3503558028880*CF*Zeta[3] + 101504793600*NM*Zeta[3] + 
         2057529600000*NL*Zeta[3] + 161282529981440*NH*Zeta[3] - 
         529200*Log[x]*(-4*(243*NM*(4859 + 4800*lm + 1080*lm^2 + 600*Pi^2) + 
             243*NL*(9179 + 4800*lm + 1080*lm^2 + 600*Pi^2) + 
             NH*(53023659 + 1166400*lm + 262440*lm^2 - 30233440*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) + CF*(-97433481 - 96053040*lm - 
             28343520*lm^2 + 1102248*Pi^2 + 2591840*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 8398080*Zeta[3]) + 
           4*CA*(14923374 + 8252280*lm + 1443420*lm^2 + 2187*Pi^2 - 
             323980*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1049760*Zeta[3])) - 
         70*CA*(81478172160*lm^2 - 13023613431*Pi^2 + 793751000*Sqrt[3]*
            Pi^3 + 398830068*Pi^4 - 204120*lm*(-1328423 + 6600*Pi^2) + 
           612322200*Sqrt[3]*Pi*Log[3]^2 + 2*(51785280306 - 
             41551857498*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             82734734880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 14695732800*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 8253626999*
              PolyGamma[2, 1] + 55661727358*Zeta[3]))))/555532992000, 
      -(CF*NC*(-35*CA*(76 + 33*lm) + 18*CF*(494 + 315*lm) + 
           10*(38*NM + 21*lm*NM + 35*NL + 21*lm*NL + 21*lm*NH))*
          Log[x]^2)/45 - (14*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + (CF*NC*Log[x]*(-4*(729*NL*(19945 + 10564*lm + 2520*lm^2 + 
              1400*Pi^2) + 243*NM*(26629 + 31692*lm + 7560*lm^2 + 
              5040*Pi^2) + NH*(290567235 + 7701156*lm + 1837080*lm^2 - 
              165690560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          CF*(-627831201 - 622297728*lm - 198404640*lm^2 + 12264696*Pi^2 + 
            42001184*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 58786560*Zeta[3]) - 
          4*CA*(-101875011 - 55215918*lm - 10103940*lm^2 + 652455*Pi^2 + 
            5250148*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 7348320*Zeta[3])))/
        2099520 - (CF*NC*(-140*CA*(126030814317 + 257892964560*lm^2 - 
            32807724273*Pi^2 + 6431431300*Sqrt[3]*Pi^3 + 653633064*Pi^4 - 
            204120*lm*(-4018123 + 13200*Pi^2) - 168399010236*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 608176356480*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 238146713280*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 4961389860*Sqrt[3]*Pi*
             Log[3]^2 + 40815749084*PolyGamma[2, 1] + 33936702328*Zeta[3]) + 
          CF*(177242801097600*lm^2 - 7686265218552*Pi^2 + 1800800764000*
             Sqrt[3]*Pi^3 + 73282345920*Pi^4 - 3086294400*lm*
             (-48931 + 600*Pi^2) + 1389189160800*Sqrt[3]*Pi*Log[3]^2 - 
            35*(-4691485754883 + 1347192081888*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 4865410851840*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              1905173706240*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              326525992672*PolyGamma[2, 1] + 2031584923072*Zeta[3])) - 
          1120*(486*NM*(46721780 - 12060090*lm^2 - 6768360*Pi^2 + 
              105*lm*(-219101 + 1200*Pi^2) - 2281617*PolyGamma[2, 1] + 
              3450366*Zeta[3]) - 2*NH*(-423603070650 + 2930601870*lm^2 + 
              12685683500*Sqrt[3]*Pi^3 - 25515*lm*(-219101 + 1200*Pi^2) - 
              306161347200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              469732737600*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              9786098700*Sqrt[3]*Pi*Log[3]^2 + 60012832399*PolyGamma[2, 1] + 
              524942591198*Zeta[3]) + 1215*NL*(-4824036*lm^2 + 
              42*lm*(-219101 + 1200*Pi^2) - 5*(384587 + 475092*Pi^2 + 
                2026080*Zeta[3])))))/1111065984000, 
      (CF*NC*(-111106598400*(CA*(26369 + 12540*lm) - 
           2*(CF*(48417 + 30780*lm) + 2*(1255*NM + 570*lm*NM + 875*NL + 
               570*lm*NL + 8*NH + 570*lm*NH)))*Log[x]^2 + 
         4444263936000*(239*CA + 834*CF - 68*NM - 38*NL)*Log[x]^3 - 
         35*CA*(25171071707763 + 27970292528640*lm^2 - 5309387335800*Pi^2 + 
           1092795687200*Sqrt[3]*Pi^3 + 215895111264*Pi^4 - 
           132269760*lm*(-720917 + 2200*Pi^2) - 36538853050464*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 67702012116480*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 40464663160320*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 843013815840*Sqrt[3]*Pi*
            Log[3]^2 + 8263661420816*PolyGamma[2, 1] + 45685834515232*
            Zeta[3]) + 105840*Log[x]*(5*CA*(-16302512721 - 8486889696*lm - 
             1454967360*lm^2 + 87602472*Pi^2 + 892078112*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 1058158080*Zeta[3]) + 
           2*(16*(3645*NM*(72005 + 51714*lm + 11340*lm^2 + 4320*Pi^2) + 3645*
                NL*(103433 + 51714*lm + 11340*lm^2 + 7200*Pi^2) + 2*NH*
                (3852250233 + 94248765*lm + 20667150*lm^2 - 2193650800*
                  Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             5*CF*(12801277839 + 12516498432*lm + 3571283520*lm^2 - 248145768*
                Pi^2 - 892078112*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               1058158080*Zeta[3]))) + 
         2*(CF*(2402902403596800*lm^2 - 191330058199464*Pi^2 + 
             38247849052000*Sqrt[3]*Pi^3 + 6074907582240*Pi^4 - 
             124994923200*lm*(-20779 + 200*Pi^2) + 29505483554400*Sqrt[3]*Pi*
              Log[3]^2 - 35*(-56218719686517 + 36538853050464*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 67702012116480*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 40464663160320*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 8263661420816*
                PolyGamma[2, 1] - 13487751999520*Zeta[3])) - 
           448*(492075*NL*(-315777 - 403704*lm^2 - 236540*Pi^2 + 21*lm*
                (-41071 + 200*Pi^2) - 1260000*Zeta[3]) + 
             98415*NM*(9462985 - 2018520*lm^2 - 908860*Pi^2 + 105*lm*
                (-41071 + 200*Pi^2) - 387936*PolyGamma[2, 1] + 5927328*
                Zeta[3]) - NH*(-33147865822581 + 198652645800*lm^2 + 
               1343611115000*Sqrt[3]*Pi^3 - 10333575*lm*(-41071 + 200*Pi^2) - 
               15367705677600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               49752000144000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               1036500003000*Sqrt[3]*Pi*Log[3]^2 + 3360941064320*
                PolyGamma[2, 1] + 14968901664640*Zeta[3])))))/6666395904000, 
      -(CF*NC*(-3*CA*(368211 + 159830*lm) + 2*(CF*(1875193 + 1176930*lm) + 
             118167*NM + 43590*lm*NM + 65325*NL + 43590*lm*NL + 756*NH + 
             43590*lm*NH))*Log[x]^2)/810 - 
       (2*CF*NC*(16703*CA + 70598*CF - 5056*NM - 2906*NL)*Log[x]^3)/81 + 
       (CF*NC*Log[x]*(2*(-8*(3645*NM*(3493823 + 2428932*lm + 544320*lm^2 + 
                279240*Pi^2) + 3645*NL*(4881557 + 2428932*lm + 544320*lm^2 + 
                355800*Pi^2) + NH*(324568696983 + 8853457140*lm + 
                1984046400*lm^2 - 184726151200*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) + 5*CF*(-300037298151 - 291996832608*lm - 
              85710804480*lm^2 + 5576867496*Pi^2 + 28765360544*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 25395793920*Zeta[3])) - 
          5*CA*(-392413457523 - 200263485024*lm - 34919216640*lm^2 + 
            1821036168*Pi^2 + 28765360544*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 25395793920*Zeta[3])))/566870400 - 
       (CF*NC*(-35*CA*(231351191259057 + 616289254479360*lm^2 - 
            105668055277272*Pi^2 + 35237566666400*Sqrt[3]*Pi^3 + 
            4823124209568*Pi^4 - 132269760*lm*(-15477217 + 37400*Pi^2) - 
            702326580457056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            1644533205557760*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            1304796754275840*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
            27183265714080*Sqrt[3]*Pi*Log[3]^2 + 186166370101936*
             PolyGamma[2, 1] + 435555947081312*Zeta[3]) + 
          2*(CF*(52944849589363200*lm^2 - 4232632601388168*Pi^2 + 
              1233314833324000*Sqrt[3]*Pi^3 + 143625185030880*Pi^4 - 
              624974616000*lm*(-84163 + 680*Pi^2) + 951414299992800*Sqrt[
                3]*Pi*Log[3]^2 - 35*(-1017984488576805 + 702326580457056*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1644533205557760*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 1304796754275840*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 186166370101936*
                 PolyGamma[2, 1] + 324087212819872*Zeta[3])) - 
            224*(164025*NL*(-25199699 - 53370576*lm^2 - 33512280*Pi^2 + 
                126*lm*(-867923 + 3400*Pi^2) - 184464000*Zeta[3]) + 
              98415*NM*(445461275 - 88950960*lm^2 - 55469080*Pi^2 + 
                210*lm*(-867923 + 3400*Pi^2) - 26857452*PolyGamma[2, 1] + 
                339001896*Zeta[3]) - NH*(-1407496518654903 + 8754108728400*
                 lm^2 + 56572383805000*Sqrt[3]*Pi^3 - 20667150*lm*
                 (-867923 + 3400*Pi^2) - 727178785420800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 2094794554608000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 43641553221000*
                 Sqrt[3]*Pi*Log[3]^2 + 157852657198280*PolyGamma[2, 1] + 
                790679409068560*Zeta[3])))))/59997563136000, 
      (CF*NC*(74071065600*(-21*CA*(1451889 + 692230*lm) + 
           35*CF*(3205415 + 2038932*lm) + 6*(35*(-1753 + 12586*lm)*NM + 
             245*(2595 + 1798*lm)*NL + 2*(7263 + 220255*lm)*NH))*Log[x]^2 + 
         145179288576000*(5792*CA + 25427*CF - 3934*NM - 899*NL)*Log[x]^3 - 
         245*CA*(255339794244087 + 1827025793429760*lm^2 - 
           444770335024344*Pi^2 + 137496192652000*Sqrt[3]*Pi^3 + 
           21283672578336*Pi^4 - 1454967360*lm*(-4309243 + 9800*Pi^2) - 
           2787567106681056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           5113992289835520*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           5091287590771200*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           106068491474400*Sqrt[3]*Pi*Log[3]^2 + 729408379634864*
            PolyGamma[2, 1] + 2991435462733408*Zeta[3]) + 
         2*(49*CF*(22422589283001600*lm^2 - 2609449372195128*Pi^2 + 
             687480963260000*Sqrt[3]*Pi^3 + 96048413707680*Pi^4 - 
             17856417600*lm*(-1385581 + 9800*Pi^2) + 530342457372000*Sqrt[3]*
              Pi*Log[3]^2 + 5*(2166125633092323 - 2787567106681056*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 5113992289835520*
                Im[PolyLog[2, (-1)^(1/3)]]^2 + 5091287590771200*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 729408379634864*
                PolyGamma[2, 1] + 554851252555360*Zeta[3])) - 
           64*(56260575*NL*(-3554213 - 11301444*lm^2 - 8070360*Pi^2 + 9*lm*
                (-2711059 + 9800*Pi^2) - 51105600*Zeta[3]) + 
             33756345*NM*(139919575 - 18835740*lm^2 + 1770560*Pi^2 + 15*lm*
                (-2711059 + 9800*Pi^2) + 4673904*PolyGamma[2, 1] + 135952608*
                Zeta[3]) - NH*(-124170852931356249 + 635825737770300*lm^2 + 
               5535436285172500*Sqrt[3]*Pi^3 - 506345175*lm*(-2711059 + 
                 9800*Pi^2) - 49667348872318800*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 204969297873816000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 4270193705704500*
                Sqrt[3]*Pi*Log[3]^2 + 11555660431121240*PolyGamma[2, 1] + 
               26977853633770480*Zeta[3]))) + 15120*Log[x]*
          (245*CA*(-1454765722629 - 731055033504*lm - 122217258240*lm^2 + 
             8418952728*Pi^2 + 112241789920*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 88885278720*Zeta[3]) + 
           2*(-8*(-178605*NM*(11364967 + 8970972*lm + 1905120*lm^2 - 
                 1289400*Pi^2) - 178605*NL*(19015753 + 8970972*lm + 
                 1905120*lm^2 + 1390200*Pi^2) - NH*(63581079406503 + 
                 1602260454060*lm + 340263957600*lm^2 - 36149787984800*
                  Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             245*CF*(1095951329568*lm + 299987815680*lm^2 + 5*(224689442061 - 
                 4619381400*Pi^2 - 22448357984*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]] + 17777055744*Zeta[3]))))))/419982941952000, 
      (-1679903687718349*CF^2*NC)/408146688000 - (3661537*CF^2*lm*NC)/320 - 
       (875637*CF^2*lm^2*NC)/80 + (6013233661*CF*NM*NC)/1944000 - 
       (7358671*CF*lm*NM*NC)/8640 - (32431*CF*lm^2*NM*NC)/80 + 
       (24738733*CF*NC*NL)/933120 - (7358671*CF*lm*NC*NL)/8640 - 
       (32431*CF*lm^2*NC*NL)/80 + (12385617938440589*CF*NC*NH)/
        156243654000 - (7358671*CF*lm*NC*NH)/8640 - (32431*CF*lm^2*NC*NH)/
        80 + (84978993349*CF^2*NC*Pi^2)/81648000 + (1715*CF^2*lm*NC*Pi^2)/
        24 - (2699101*CF*NM*NC*Pi^2)/38880 + (1715*CF*lm*NM*NC*Pi^2)/648 - 
       (2390873*CF*NC*NL*Pi^2)/7776 + (1715*CF*lm*NC*NL*Pi^2)/648 + 
       (1715*CF*lm*NC*NH*Pi^2)/648 - (97996643675*CF^2*NC*Pi^3)/
        (76527504*Sqrt[3]) - (808023769735*CF*NC*NH*Pi^3)/
        (76527504*Sqrt[3]) - (841561*CF^2*NC*Pi^4)/16200 + 
       (6137369681251*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (318864600*Sqrt[3]) + (6443399022097*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(63772920*Sqrt[3]) - 
       (67298*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (2799904105*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (59049*Sqrt[3]) - (23086393421*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (2799904105*CF^2*NC*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (23086393421*CF*NC*NH*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (CF*NC*(-35*CA*(2868755 + 1144308*lm) + 
          2*(140*CF*(1191376 + 702189*lm) + 3648864*NM + 3640980*lm*NM + 
            5138595*NL + 3640980*lm*NL + 142992*NH + 3640980*lm*NH))*
         Log[x]^2)/6480 - (7*CF*NC*(95141*CA + 555471*CF - 73508*NM - 
          17338*NL)*Log[x]^3)/162 - (1984959892189*CF^2*NC*PolyGamma[2, 1])/
        956593800 + (14545073*CF*NM*NC*PolyGamma[2, 1])/226800 - 
       (6534928824292*CF*NC*NH*PolyGamma[2, 1])/837019575 + 
       (CF*NC*Log[x]*(2*(4*(-61236*NM*(181978952 + 99979275*lm + 
                21432600*lm^2 - 12567450*Pi^2) - 76545*NL*(172020769 + 
                79983420*lm + 17146080*lm^2 + 12997320*Pi^2) - 
              2*NH*(113774994441489 + 3061165441950*lm + 656223346800*lm^2 - 
                64641901578800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            7*CF*(-78257474240817 - 73084687484400*lm - 20249177558400*lm^2 + 
              1035451771200*Pi^2 + 8959693136000*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 5999756313600*Zeta[3])) - 
          7*CA*(-102203792095377 - 48982796247600*lm - 8249664931200*lm^2 + 
            23460036480*Pi^2 + 8959693136000*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 5999756313600*Zeta[3])))/23808556800 + 
       (2767792136029*CF^2*NC*Zeta[3])/956593800 + 
       (395275073*CF*NM*NC*Zeta[3])/113400 - (55013*CF*NC*NL*Zeta[3])/27 - 
       (17949506100059*CF*NC*NH*Zeta[3])/837019575 + 
       (CA*CF*NC*(-4408161941327769 + 16380298982678400*lm^2 - 
          2898008099033040*Pi^2 + 1567946298800000*Sqrt[3]*Pi^3 + 
          206377332053760*Pi^4 - 141717600*lm*(-389943159 + 754600*Pi^2) - 
          23567499576003840*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          49441420456243200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          58058811521280000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          1209558573360000*Sqrt[3]*Pi*Log[3]^2 + 7622245986005760*
           PolyGamma[2, 1] + 12756640637752320*Zeta[3]))/7346640384000, 
      (CF*NC*(-1374944155200*(7*CA*(265476437 + 125331360*lm) - 
           6*(147*CF*(7727927 + 4883040*lm) + 4*(7*(-7769367 + 949480*lm)*
                NM + 490*(18785 + 13564*lm)*NL + (362377 + 6646360*lm)*
                NH)))*Log[x]^2 + 5389781088384000*(175711*CA + 953114*CF - 
           8*(32930*NM + 3391*NL))*Log[x]^3 + 83160*Log[x]*
          (2*(-8*(-38578680*NL*(15629045 + 6918708*lm + 1428840*lm^2 + 
                 1188390*Pi^2) + 964467*NM*(187488211 - 276748320*lm - 
                 57153600*lm^2 + 209672400*Pi^2) - NH*(10682089032942141 + 
                 266914621945440*lm + 55122761131200*lm^2 - 6064723502286400*
                  Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
             245*CF*(-185555659991313 - 184022729805312*lm - 48598026140160*
                lm^2 + 3859464842424*Pi^2 + 23357880903776*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 14399415152640*Zeta[3])) + 
           245*CA*(-244167067338483 - 121070350930176*lm - 19799195834880*
              lm^2 + 1217455748280*Pi^2 + 23357880903776*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 14399415152640*Zeta[3])) - 
         2695*CA*(-95714844158026359 + 122002644734530560*lm^2 - 
           38086918947707868*Pi^2 + 14306702053562800*Sqrt[3]*Pi^3 + 
           1938076282997568*Pi^4 - 1785641760*lm*(-235109851 + 431200*Pi^2) - 
           213600461136965616*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           387023880618869760*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           529756738897639680*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           11036598727034160*Sqrt[3]*Pi*Log[3]^2 + 64907035961126768*
            PolyGamma[2, 1] + 190310321946419296*Zeta[3]) + 
         4*(49*CF*(8235178519580812800*lm^2 - 1285083339920114202*Pi^2 + 
             393434306472977000*Sqrt[3]*Pi^3 + 50217222874785120*Pi^4 - 
             1325839006800*lm*(-6911969 + 39200*Pi^2) + 303506464993439400*
              Sqrt[3]*Pi*Log[3]^2 - 55*(-20291819092324731 + 
               106800230568482808*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               193511940309434880*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
               264878369448819840*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                    Sqrt[3])]] - 32453517980563384*PolyGamma[2, 1] + 
               61413134265424*Zeta[3])) - 
           44*(3038071050*NL*(58091555 - 111803328*lm^2 - 94002960*Pi^2 + 18*
                lm*(-13468337 + 39200*Pi^2) - 692979840*Zeta[3]) + 
             26040609*NM*(124164659689 - 13043721600*lm^2 + 38125645600*
                Pi^2 + 2100*lm*(-13468337 + 39200*Pi^2) + 36104171520*
                PolyGamma[2, 1] + 158559671040*Zeta[3]) - 
             NH*(-79948430487250901757 + 339666454090454400*lm^2 + 
               3714643145150420000*Sqrt[3]*Pi^3 - 54685278900*lm*
                (-13468337 + 39200*Pi^2) - 28798179428973292800*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 137547929031855552000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2865581854830324000*
                Sqrt[3]*Pi*Log[3]^2 + 6971970860120190400*PolyGamma[2, 1] + 
               7156247409569148800*Zeta[3])))))/62367466879872000, 
      (2562305716269758411*CF^2*NC)/7874680161600000 - 
       (312296113*CF^2*lm*NC)/6000 - (242928*CF^2*lm^2*NC)/5 + 
       (222363310409*CF*NM*NC)/13720000 - (620004913*CF*lm*NM*NC)/162000 - 
       (26992*CF*lm^2*NM*NC)/15 + (13149834793*CF*NC*NL)/7290000 - 
       (620004913*CF*lm*NC*NL)/162000 - (26992*CF*lm^2*NC*NL)/15 + 
       (5676310585734496283*CF*NC*NH)/13124466936000 - 
       (620004913*CF*lm*NC*NH)/162000 - (26992*CF*lm^2*NC*NH)/15 + 
       (246562105213*CF^2*NC*Pi^2)/128304000 + (4018*CF^2*lm*NC*Pi^2)/15 + 
       (50145149*CF*NM*NC*Pi^2)/12150 + (4018*CF*lm*NM*NC*Pi^2)/405 - 
       (19405981*CF*NC*NL*Pi^2)/12150 + (4018*CF*lm*NC*NL*Pi^2)/405 + 
       (4018*CF*lm*NC*NH*Pi^2)/405 - (57237630728159*CF^2*NC*Pi^3)/
        (6887475360*Sqrt[3]) - (1726143453643*CF*NC*NH*Pi^3)/
        (28697814*Sqrt[3]) - (5271763*CF^2*NC*Pi^4)/16200 + 
       (5832580234770791*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (57395628000*Sqrt[3]) + (2320106820328*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) - 
       (334278*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (8176804389737*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) - (1972735375592*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(885735*Sqrt[3]) - 
       (8176804389737*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) - 
       (246591921949*CF*NC*NH*Pi*Log[3]^2)/(5314410*Sqrt[3]) - 
       (CF*NC*(-15*CA*(9662216057 + 3124758560*lm) + 
          CF*(448551149194 + 230095857600*lm) + 120*(-373644729*NM + 
            71017240*lm*NM + 96602058*NL + 71017240*lm*NL + 4428595*NH + 
            71017240*lm*NH))*Log[x]^2)/1134000 - 
       (CF*NC*(44508995*CA + 421557366*CF - 40*(2321870*NM + 253633*NL))*
         Log[x]^3)/2025 - (2172169062159391*CF^2*NC*PolyGamma[2, 1])/
        144636982560 + (14987534*CF*NM*NC*PolyGamma[2, 1])/2835 - 
       (392530645591507*CF*NC*NH*PolyGamma[2, 1])/10044234900 + 
       (7273447029814513*CF^2*NC*Zeta[3])/361592456400 + 
       (73475728*CF*NM*NC*Zeta[3])/2835 - (1665644*CF*NC*NL*Zeta[3])/135 - 
       (259220782333747*CF*NC*NH*Zeta[3])/5022117450 + 
       (CA*CF*NC*(-71711143264366016499 + 56114088867383500800*lm^2 - 
          789191056211642028*Pi^2 + 7853002935903414800*Sqrt[3]*Pi^3 + 
          967520828126059200*Pi^4 - 17499289248*lm*(-10901244443 + 
            17679200*Pi^2) - 96027600985266303024*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 189527928124271385600*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 290785480140880730880*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6058030836268348560*
           Sqrt[3]*Pi*Log[3]^2 + 42574513618324063600*PolyGamma[2, 1] + 
          36878712336152163680*Zeta[3]))/5669769716352000 - 
       (CF*NC*Log[x]*(-5*CA*(694080773337400599 + 295606367711182080*lm + 
            48508029795456000*lm^2 + 6823738008755640*Pi^2 - 
            64106146415538080*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            35278567123968000*Zeta[3]) + 
          2*(-120*(-6561*NM*(177246479111 + 135020111520*lm + 28005264000*
                 lm^2 - 99498478800*Pi^2) - 642978*NL*(3174251353 + 
                1377756240*lm + 285768000*lm^2 + 247435800*Pi^2) - 
              5*NH*(6815209727789535 + 177173390336544*lm + 36748507420800*
                 lm^2 - 3866561336160320*Sqrt[3]*Im[PolyLog[2, (-1)^
                    (1/3)]])) + CF*(2712437603655791523 + 2241809446556332800*
               lm + 595325820216960000*lm^2 + 765130381759800*Pi^2 - 
              320530732077690400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              176392835619840000*Zeta[3]))))/18749238480000, 
      (-381779474233964493917*CF^2*NC)/15749360323200000 + 
       (222159391*CF^2*lm*NC)/2000 + (993951*CF^2*lm^2*NC)/10 - 
       (621941530993*CF*NM*NC)/370440000 + (431993491*CF*lm*NM*NC)/54000 + 
       (36813*CF*lm^2*NM*NC)/10 - (10067936299*CF*NC*NL)/1620000 + 
       (431993491*CF*lm*NC*NL)/54000 + (36813*CF*lm^2*NC*NL)/10 - 
       (7831739077067892860333*CF*NC*NH)/7486570925064000 + 
       (431993491*CF*lm*NC*NH)/54000 + (36813*CF*lm^2*NC*NH)/10 - 
       (19334465836771*CF^2*NC*Pi^2)/898128000 - (2646*CF^2*lm*NC*Pi^2)/5 - 
       (4144267*CF*NM*NC*Pi^2)/75 - (98*CF*lm*NM*NC*Pi^2)/5 + 
       (2403757*CF*NC*NL*Pi^2)/675 - (98*CF*lm*NC*NL*Pi^2)/5 - 
       (98*CF*lm*NC*NH*Pi^2)/5 + (8608862382659*CF^2*NC*Pi^3)/
        (430467210*Sqrt[3]) + (12811510764689*CF*NC*NH*Pi^3)/
        (86093442*Sqrt[3]) + (532252*CF^2*NC*Pi^4)/675 - 
       (13918978029139381*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (57395628000*Sqrt[3]) - (75104778595342*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) + 
       (717248*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (9838699865896*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (13286025*Sqrt[3]) + (14641726588216*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) + 
       (1229837483237*CF^2*NC*Pi*Log[3]^2)/(79716150*Sqrt[3]) + 
       (1830215823527*CF*NC*NH*Pi*Log[3]^2)/(15943230*Sqrt[3]) + 
       (CF*NC*(-55*CA*(24484628011 + 11969551440*lm) + 
          11*CF*(457023926287 + 293798080800*lm) + 
          180*(11*(-1970033083 + 60452280*lm)*NM + 
            21*(22*(1938173 + 1439340*lm)*NL + 5*(484849 + 6333096*lm)*
               NH)))*Log[x]^2)/6237000 + 
       (CF*NC*(57202675*CA + 362217482*CF - 360*(526740*NM + 23989*NL))*
         Log[x]^3)/675 + (62053852997321767*CF^2*NC*PolyGamma[2, 1])/
        2169554738400 - (230942281*CF*NM*NC*PolyGamma[2, 1])/4725 + 
       (5874861806443321*CF*NC*NH*PolyGamma[2, 1])/67798585575 + 
       CA*CF*NC*((-404943*lm^2)/20 + (27942135367*Pi^2)/3168000 - 
         (8608862382659*Pi^3)/(860934420*Sqrt[3]) - (55342*Pi^4)/135 + 
         lm*(-7534991201/108000 + (539*Pi^2)/5) - (1229837483237*Pi*Log[3]^2)/
          (159432300*Sqrt[3]) + (3219322201312111431129 + 
           3437430814076261531760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
           6099946484271058944000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
           10496586177568841011200*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                Sqrt[3])]] - 1216255518747506633200*PolyGamma[2, 1] - 
           2590908381020652677600*Zeta[3])/85046545745280000) - 
       (14407462651446773*CF^2*NC*Zeta[3])/1084777369200 - 
       (300799862*CF*NM*NC*Zeta[3])/4725 + (150052*CF*NC*NL*Zeta[3])/5 + 
       (888064770560882*CF*NC*NH*Zeta[3])/67798585575 + 
       CF*Log[x]*((-86539129109*NM*NC)/330750 + (5900176*lm*NM*NC)/225 + 
         5292*lm^2*NM*NC + (1706895629*NC*NL)/27000 + (5900176*lm*NC*NL)/
          225 + 5292*lm^2*NC*NL + (72898936935191537*NC*NH)/67519579050 + 
         (5900176*lm*NC*NH)/225 + 5292*lm^2*NC*NH - (317882*NM*NC*Pi^2)/
          5 + (74438*NC*NL*Pi^2)/15 - (14641726588216*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CA*NC*(-441640613980949407/1249949232000 - (40785868*lm)/225 - 
           29106*lm^2 + (14929981*Pi^2)/8100 + 
           (4919349932948*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) - 
           21168*Zeta[3]) + CF*NC*(407314238120068799/781218270000 + 
           (13929978*lm)/25 + 142884*lm^2 - (99402149*Pi^2)/8100 - 
           (9838699865896*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) + 
           42336*Zeta[3])), (36155924948822851722121*CF^2*NC)/
        283488485817600000 - (1684529747*CF^2*lm*NC)/9000 - 
       (3446037*CF^2*lm^2*NC)/20 - (255443454353639*CF*NM*NC)/11022480000 - 
       (1660698661*CF*lm*NM*NC)/121500 - (127631*CF*lm^2*NM*NC)/20 + 
       (213367706251*CF*NC*NL)/14580000 - (1660698661*CF*lm*NC*NL)/121500 - 
       (127631*CF*lm^2*NC*NL)/20 + (252189129138748741373737*CF*NC*NH)/
        134758276651152000 - (1660698661*CF*lm*NC*NH)/121500 - 
       (127631*CF*lm^2*NC*NH)/20 - (1490373331781*CF^2*NC*Pi^2)/25660800 + 
       (4116*CF^2*lm*NC*Pi^2)/5 + (471617302*CF*NM*NC*Pi^2)/6075 + 
       (1372*CF*lm*NM*NC*Pi^2)/45 - (13132046*CF*NC*NL*Pi^2)/2025 + 
       (1372*CF*lm*NC*NL*Pi^2)/45 + (1372*CF*lm*NC*NH*Pi^2)/45 - 
       (183190176665671*CF^2*NC*Pi^3)/(4591650240*Sqrt[3]) - 
       (68660539590307*CF*NC*NH*Pi^3)/(258280326*Sqrt[3]) - 
       (16027907*CF^2*NC*Pi^4)/10800 + (108315978531233267*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(258280326000*Sqrt[3]) + 
       (1239631438549276*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (645700815*Sqrt[3]) - (1312633*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (26170025237953*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (17714700*Sqrt[3]) - (78469188103208*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) - 
       (26170025237953*CF^2*NC*Pi*Log[3]^2)/(850305600*Sqrt[3]) - 
       (9808648512901*CF*NC*NH*Pi*Log[3]^2)/(47829690*Sqrt[3]) - 
       (CF*NC*(-495*CA*(154439452879 + 31101852320*lm) + 
          4*(33*CF*(1559131977521 + 572556826800*lm) + 
            70*(11*(-20900564611 + 908820360*lm)*NM + 198*(67032829 + 
                50490020*lm)*NL + 5*(169941355 + 1999404792*lm)*NH)))*
         Log[x]^2)/74844000 - (CF*NC*(28919095*CA + 2854691782*CF - 
          140*(7004490*NM + 360643*NL))*Log[x]^3)/2025 - 
       (17085641889542167*CF^2*NC*PolyGamma[2, 1])/154968195600 + 
       (10284637249*CF*NM*NC*PolyGamma[2, 1])/113400 - 
       (17222480031583619*CF*NC*NH*PolyGamma[2, 1])/108477736920 + 
       (CA*CF*NC*(6567018286409578166400*lm^2 + 6136214191164452011176*Pi^2 + 
          1244117765807238029400*Sqrt[3]*Pi^3 + 143399740856513248800*Pi^4 - 
          769968726912*lm*(-29122701821 + 40748400*Pi^2) + 
          959747990765583622680*Sqrt[3]*Pi*Log[3]^2 - 
          11*(1932826541835463093677 + 1188876180358816338592*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2232698049625282444800*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 4187991232431637626240*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 937660026898074124960*
             PolyGamma[2, 1] - 146770047943915948160*Zeta[3])))/
        187102400639616000 + (1869077078022877*CF^2*NC*Zeta[3])/15496819560 + 
       (8313661249*CF*NM*NC*Zeta[3])/56700 - (7717934*CF*NC*NL*Zeta[3])/
        135 - (3152440251017171*CF*NC*NH*Zeta[3])/54238868460 + 
       CF*Log[x]*((578961282953*NM*NC)/4374000 - (64773481*lm*NM*NC)/1350 - 
         9702*lm^2*NM*NC - (19162966889*NC*NL)/162000 - 
         (64773481*lm*NC*NL)/1350 - 9702*lm^2*NC*NL - 
         (3127485309138701051*NC*NH)/1620469897200 - (64773481*lm*NC*NH)/
          1350 - 9702*lm^2*NC*NH + (14512414*NM*NC*Pi^2)/135 - 
         (3834271*NC*NL*Pi^2)/405 + (78469188103208*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
         CF*NC*(-3712408877094984673/2083248720000 - (50948131*lm)/50 - 
           261954*lm^2 - (1707849451*Pi^2)/32400 + 
           (26170025237953*Im[PolyLog[2, (-1)^(1/3)]])/(53144100*Sqrt[3]) - 
           77616*Zeta[3]) + CA*NC*(55654373068085873/52081218000 + 
           (895876091*lm)/2700 + 53361*lm^2 + (745035319*Pi^2)/21600 - 
           (26170025237953*Im[PolyLog[2, (-1)^(1/3)]])/(106288200*Sqrt[3]) + 
           38808*Zeta[3])), 
      (CF*NC*(3067225421420160*(-2574*CA*(62053557637 + 43141021000*lm) + 
           429*CF*(1665874657921 + 1270699164000*lm) + 
           100*(143*(-159694459397 + 1411887960*lm)*NM + 
             7*(2574*(14793223 + 11205460*lm)*NL + 5*(565279661 + 
                 5768570808*lm)*NH)))*Log[x]^2 + 184217558810494809600*
          (1731501247*CA + 2*(5260330001*CF - 200*(31856304*NM + 560273*
                NL)))*Log[x]^3 + 648648*Log[x]*
          (-4*(100*(134165889*NM*(105500045616541 - 2100305100600*lm - 
                 415878170400*lm^2 + 16310064128400*Pi^2) - 49*
                (72449580060*NL*(204086807 + 79376610*lm + 15717240*lm^2 + 
                   16444540*Pi^2) + NH*(246201876917681230707 + 
                   5750802061086396600*lm + 1138707437702234400*lm^2 - 
                   139478789448089291200*Sqrt[3]*Im[PolyLog[2, (-1)^
                       (1/3)]]))) + 61347*CF*(-6165938333435536857 - 
               9809943746338260000*lm - 2455719008394960000*lm^2 + 
               355106604171627000*Pi^2 + 1628699104543380800*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 727620446931840000*Zeta[3])) + 
           306735*CA*(-3822177321868028979 - 2530415905057656000*lm - 
             400191245812512000*lm^2 + 77202048617023680*Pi^2 + 
             651479641817352320*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             291048178772736000*Zeta[3])) - 265837*CA*
          (182034591791491520928000*lm^2 - 166116168668487395192940*Pi^2 + 
           39504096780699701304000*Sqrt[3]*Pi^3 + 4490953436712478982400*
            Pi^4 - 1804614203700000*lm*(-347857681 + 465696*Pi^2) + 
           30474588945111198148800*Sqrt[3]*Pi*Log[3]^2 + 
           11*(-50605960308771631060683 - 37522173640223473368720*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 64719536828082329088000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 132980024487757955558400*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 14732398368408655992400*
              PolyGamma[2, 1] + 30086029498796640471200*Zeta[3])) + 
         5*(-16*(245*(-(NH*(-152942611911950201362593309 + 
                  448901018349487304721120*lm^2 + 7329959082470712475788000*
                   Sqrt[3]*Pi^3 - 1958094800281620*lm*(-498807851 + 
                    1058400*Pi^2) - 48160361104802710068264960*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]] + 271417913453772667674892800*
                   Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                  5654539863620263909893600*Sqrt[3]*Pi*Log[3]^2 + 
                  12147127665305254624498496*PolyGamma[2, 1] - 
                  5699626526208403090510208*Zeta[3])) + 65269826676054*NL*
                (21903091211 - 6877619280*lm^2 - 7524572400*Pi^2 + 
                 30*lm*(-498807851 + 1058400*Pi^2) - 71421436800*Zeta[3])) + 
             172671499143*NM*(-43778465981609533 - 636936321520800*lm^2 + 
               43111506084141600*Pi^2 + 2778300*lm*(-498807851 + 
                 1058400*Pi^2) + 35918843797166400*PolyGamma[2, 1] + 
               13222902085948800*Zeta[3])) + 20449*CF*
            (2323423335229582685299200*lm^2 - 976625770955876525981448*Pi^2 + 
             205421303259638446780800*Sqrt[3]*Pi^3 + 22717308648465235284480*
              Pi^4 - 10134713367979200*lm*(-256817543 + 1058400*Pi^2) + 
             158467862514578230373760*Sqrt[3]*Pi*Log[3]^2 - 
             143*(10399518913609204839333 + 15008869456089389347488*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 25887814731232931635200*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 53192009795103182223360*
                Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
               5892959347363462396960*PolyGamma[2, 1] + 
               2174914516478960616640*Zeta[3])))))/746081113182503978880000, 
      (97708729569774589334443643*CF^2*NC)/56598476193483840000 - 
       (20068572803*CF^2*lm*NC)/35280 - (2595564*CF^2*lm^2*NC)/5 - 
       (22719430684919027791*CF*NM*NC)/14377502462400 - 
       (7880066695*CF*lm*NM*NC)/190512 - (96132*CF*lm^2*NM*NC)/5 + 
       (7545569878417*CF*NC*NL)/100018800 - (7880066695*CF*lm*NC*NL)/
        190512 - (96132*CF*lm^2*NC*NL)/5 + (21135850105406737102604054197*CF*
         NC*NH)/3108671304927099912000 - (7880066695*CF*lm*NC*NH)/190512 - 
       (96132*CF*lm^2*NC*NH)/5 - (99223777911620407*CF^2*NC*Pi^2)/
        81729648000 + 2190*CF^2*lm*NC*Pi^2 + (1171409119*CF*NM*NC*Pi^2)/
        1215 + (730*CF*lm*NM*NC*Pi^2)/9 - (4159133*CF*NC*NL*Pi^2)/189 + 
       (730*CF*lm*NC*NL*Pi^2)/9 + (730*CF*lm*NC*NH*Pi^2)/9 - 
       (9593622122380787*CF^2*NC*Pi^3)/(61987278240*Sqrt[3]) - 
       (756744330356945*CF*NC*NH*Pi^3)/(774840978*Sqrt[3]) - 
       (29458969*CF^2*NC*Pi^4)/5400 + (110374918258475113661*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(75934415844000*Sqrt[3]) + 
       (88649713775770802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (13559717115*Sqrt[3]) - (4339126*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (9593622122380787*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1674039150*Sqrt[3]) - 
       (172970132653016*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4782969*Sqrt[3]) - (9593622122380787*CF^2*NC*Pi*Log[3]^2)/
        (80353879200*Sqrt[3]) - (21621266581627*CF*NC*NH*Pi*Log[3]^2)/
        (28697814*Sqrt[3]) - 
       (CF*NC*(-13*CA*(2601898370106067 + 216764975196000*lm) + 
          26*CF*(2978633728124713 + 532059484572000*lm) + 
          1400*(65*(-420361896113 + 5630259096*lm)*NM + 
            2574*(185599699 + 142178260*lm)*NL + 
            (38980540783 + 365966841240*lm)*NH))*Log[x]^2)/3405402000 + 
       (CF*NC*(39945578203*CA - 264930092002*CF + 
          2800*(45537168*NM + 1015559*NL))*Log[x]^3)/28350 - 
       (19841418138633796081*CF^2*NC*PolyGamma[2, 1])/19525992645600 + 
       (62756144551*CF*NM*NC*PolyGamma[2, 1])/56700 - 
       (47873283845864812*CF*NC*NH*PolyGamma[2, 1])/87169610025 + 
       CA*CF*NC*(-821959148266155077248166069/792378666708773760000 + 
         (528726*lm^2)/5 + (867204032985691*Pi^2)/1397088000 + 
         (9593622122380787*Pi^3)/(123974556480*Sqrt[3]) + 
         (30159769*Pi^4)/10800 + lm*(689803862401/1905120 - (4015*Pi^2)/9) - 
         (110374918258475113661*Im[PolyLog[2, (-1)^(1/3)]])/
          (151868831688000*Sqrt[3]) + (2169563*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          5 + (9593622122380787*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3348078300*Sqrt[3]) + (9593622122380787*Pi*Log[3]^2)/
          (160707758400*Sqrt[3]) + (19841418138633796081*PolyGamma[2, 1])/
          39051985291200 - (3075442754026724531*Zeta[3])/19525992645600) + 
       (7818539020361897507*CF^2*NC*Zeta[3])/9762996322800 + 
       (23973096751*CF*NM*NC*Zeta[3])/28350 - (5884772*CF*NC*NL*Zeta[3])/
        27 + (14713367418189976*CF*NC*NH*Zeta[3])/87169610025 + 
       CF*Log[x]*((441643978644821*NM*NC)/129667230 - (52875521*lm*NM*NC)/
          315 - 33264*lm^2*NM*NC - (70157234657*NC*NL)/158760 - 
         (52875521*lm*NC*NL)/315 - 33264*lm^2*NC*NL - 
         (5101620903674995759457*NC*NH)/718880958145350 - 
         (52875521*lm*NC*NH)/315 - 33264*lm^2*NC*NH + 
         (29058466*NM*NC*Pi^2)/27 - (2929246*NC*NL*Pi^2)/81 + 
         (172970132653016*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CF*NC*(-347987579922298173955877/
            23820907488840000 - (125445723*lm)/35 - 898128*lm^2 - 
           (621391355*Pi^2)/648 + (9593622122380787*Im[PolyLog[2, (-1)^
                (1/3)]])/(5022117450*Sqrt[3]) - 266112*Zeta[3]) + 
         CA*NC*(10818895781047212639379/1361194713648000 + 
           (728324971*lm)/630 + 182952*lm^2 + (115699243193*Pi^2)/226800 - 
           (9593622122380787*Im[PolyLog[2, (-1)^(1/3)]])/(10044234900*
             Sqrt[3]) + 133056*Zeta[3])), 
      (CF*NC*(-41407543189172160*(13*CA*(-805923574432217 + 
             433942537644000*lm) - 2*(13*CF*(-30764587327253 + 
               1065131683308000*lm) + 700*(91*(-3319709059741 + 8050881960*
                  lm)*NM + 12870*(74073519 + 56925428*lm)*NL + 
               (86704279267 + 732630258360*lm)*NH)))*Log[x]^2 + 
         4973874087883359859200*(80071252063*CA + 
           14*(16889689757*CF - 200*(363434574*NM + 2033051*NL)))*
          Log[x]^3 + 648648*Log[x]*
          (-2*(1400*(-489034665405*NL*(135978249671 + 49673960952*lm + 
                 9681819840*lm^2 + 11196833200*Pi^2) + 239502744*NM*
                (23214464789593433 - 101428019018865*lm - 19769065885800*
                  lm^2 + 2882176313766750*Pi^2) - 2*NH*
                (543772598648360130997791 + 12146144436751177632780*lm + 
                 2367372762982945317600*lm^2 - 307829846723332577644000*
                  Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             169*CF*(3509121494684298887211219 - 4315574987765384572152000*
                lm - 1059014088056276130240000*lm^2 + 
               572385648862269368973000*Pi^2 + 788675910206098006954400*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 313781952016674408960000*
                Zeta[3])) + 845*CA*(392779162904798824454541 - 
             552547054391559440875200*lm - 86290036804585462464000*lm^2 + 
             99210597066403429095720*Pi^2 + 157735182041219601390880*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 62756390403334881792000*
              Zeta[3])) - 169*CA*(151156328431475664649287936000*lm^2 - 
           554749387970494341412496029860*Pi^2 + 
           41446890771105965510471106000*Sqrt[3]*Pi^3 + 
           4403272911705710428131345600*Pi^4 - 4817608390278684000*lm*
            (-108250057451 + 128066400*Pi^2) + 31973315737710316250934853200*
            Sqrt[3]*Pi*Log[3]^2 + 13*(-35251717519597562878328272089 - 
             29845386540846371414605722960*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 49743586138544179879181184000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 118055319646930398464990227200*
              Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             6546168864603021094867302800*PolyGamma[2, 1] + 
             48952971626279768011749584800*Zeta[3])) + 
         4*(169*CF*(185510039438629224796853376000*lm^2 - 
             288045194308035250179900813930*Pi^2 + 
             20723445385552982755235553000*Sqrt[3]*Pi^3 + 
             2156765636714470773584392800*Pi^4 - 5912519388069294000*lm*
              (-35198315723 + 128066400*Pi^2) + 15986657868855158125467426600*
              Sqrt[3]*Pi*Log[3]^2 - 13*(7410875347454588648107630083 + 
               14922693270423185707302861480*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] - 24871793069272089939590592000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 59027659823465199232495113600*
                Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
               3273084432301510547433651400*PolyGamma[2, 1] - 
               9931310642148540298575429200*Zeta[3])) - 
           140*(-(NH*(-3355811603027742495536044113663 + 
                8293967371727073807055084800*lm^2 + 
                161772280199279352866363100000*Sqrt[3]*Pi^3 - 
                1321713990190093500*lm*(-13663443631 + 25613280*Pi^2) - 
                1011378038586869525075987683200*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 5990196432521886894708759360000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                124795759010872643639765820000*Sqrt[3]*Pi*Log[3]^2 + 
                257308037767813590795881163520*PolyGamma[2, 1] - 
                238880039398352431332734440960*Zeta[3])) + 1258775228752470*
              NL*(32998820810657 - 6588918483840*lm^2 - 8044820784000*Pi^2 + 
               1050*lm*(-13663443631 + 25613280*Pi^2) - 84970786320000*
                Zeta[3]) + 3502727631*NM*(-1047239525917100582747 - 
               2367859635537580800*lm^2 + 748462571017608585600*Pi^2 + 
               377338500*lm*(-13663443631 + 25613280*Pi^2) + 
               582042993618592820160*PolyGamma[2, 1] + 6214540681349320320*
                Zeta[3])))))/141009330391493252008320000, 
      (46443763993337019947484821287597*CF^2*NC)/1989549635153343943680000 - 
       (859099234267*CF^2*lm*NC)/564480 - (110468259*CF^2*lm^2*NC)/80 - 
       (23137146895638998978677291*CF*NM*NC)/1010795933116569600 - 
       (1681866827299*CF*lm*NM*NC)/15240960 - (4091417*CF*lm^2*NM*NC)/80 + 
       (1928049778766807*CF*NC*NL)/6401203200 - (1681866827299*CF*lm*NC*NL)/
        15240960 - (4091417*CF*lm^2*NC*NL)/80 + 
       (250485229249474776727876730809*CF*NC*NH)/11627238127519542528000 - 
       (1681866827299*CF*lm*NC*NH)/15240960 - (4091417*CF*lm^2*NC*NH)/80 - 
       (5982327930346498231*CF^2*NC*Pi^2)/326918592000 + 
       (41745*CF^2*lm*NC*Pi^2)/8 + (2805293845771*CF*NM*NC*Pi^2)/272160 + 
       (13915*CF*lm*NM*NC*Pi^2)/72 - (36909004*CF*NC*NL*Pi^2)/567 + 
       (13915*CF*lm*NC*NL*Pi^2)/72 + (13915*CF*lm*NC*NH*Pi^2)/72 - 
       (126862478288815361*CF^2*NC*Pi^3)/(247949112960*Sqrt[3]) - 
       (86850870921950135*CF*NC*NH*Pi^3)/(27894275208*Sqrt[3]) - 
       (369643087*CF^2*NC*Pi^4)/21600 + (1340671913564942917033*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(303737663376000*Sqrt[3]) + 
       (3854524955351420333*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (195259926456*Sqrt[3]) - (25132349*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/10 - (126862478288815361*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6696156600*Sqrt[3]) - 
       (4962906909825722*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) - (126862478288815361*CF^2*NC*Pi*Log[3]^2)/
        (321415516800*Sqrt[3]) - (2481453454912861*CF*NC*NH*Pi*Log[3]^2)/
        (1033121304*Sqrt[3]) - 
       (CF*NC*(-3*CA*(1078019073344965447 + 25723059514152000*lm) + 
          2*(9*CF*(374375750235896641 + 21046139602488000*lm) + 
            700*(5*(-476547800185229 + 2004394247856*lm)*NM + 
              11*(2340*(502055599 + 389353972*lm)*NL + 7*(16487763593 + 
                  130155470640*lm)*NH))))*Log[x]^2)/27243216000 + 
       (CF*NC*(2987851381009*CA - 8797751753036*CF + 
          2800*(1660658055*NM + 13905499*NL))*Log[x]^3)/113400 - 
       (171122391738446509513*CF^2*NC*PolyGamma[2, 1])/14644494484200 + 
       (666021302969*CF*NM*NC*PolyGamma[2, 1])/56700 - 
       (146945778709353811781*CF*NC*NH*PolyGamma[2, 1])/87866966905200 + 
       CA*CF*NC*(-340231908233376456696096655421593/
          27853694892146815211520000 + (45005587*lm^2)/160 + 
         (60708292726891189*Pi^2)/6604416000 + (126862478288815361*Pi^3)/
          (495898225920*Sqrt[3]) + (376322287*Pi^4)/43200 + 
         lm*(5882606319469/6096384 - (153065*Pi^2)/144) - 
         (1340671913564942917033*Im[PolyLog[2, (-1)^(1/3)]])/
          (607475326752000*Sqrt[3]) + (25132349*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          20 + (126862478288815361*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (13392313200*Sqrt[3]) + (126862478288815361*Pi*Log[3]^2)/
          (642831033600*Sqrt[3]) + (171122391738446509513*PolyGamma[2, 1])/
          29288988968400 - (37130717770813465993*Zeta[3])/11715595587360) + 
       (229676463770872222031*CF^2*NC*Zeta[3])/29288988968400 + 
       (86737257247*CF*NM*NC*Zeta[3])/14175 - (38638925*CF*NC*NL*Zeta[3])/
        54 + (58985322394883851219*CF*NC*NH*Zeta[3])/43933483452600 + 
       CF*Log[x]*((63092567138504875729*NM*NC)/1402480759680 - 
         (7686300149*lm*NM*NC)/15120 - 99099*lm^2*NM*NC - 
         (1810438636133*NC*NL)/1270080 - (7686300149*lm*NC*NL)/15120 - 
         99099*lm^2*NC*NL - (24348733602434857992863*NC*NH)/
          1075520602316160 - (7686300149*lm*NC*NH)/15120 - 
         99099*lm^2*NC*NH + (272835833*NM*NC*Pi^2)/27 - 
         (19256845*NC*NL*Pi^2)/162 + (4962906909825722*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(129140163*Sqrt[3]) + 
         CF*NC*(-94002936735784680067305893/575104766516280000 - 
           (6104680109*lm)/560 - 2675673*lm^2 - (1277293531531*Pi^2)/90720 + 
           (126862478288815361*Im[PolyLog[2, (-1)^(1/3)]])/
            (20088469800*Sqrt[3]) - 792792*Zeta[3]) + 
         CA*NC*(215765687208999109410021811/2576469353992934400 + 
           (105526577959*lm)/30240 + (1090089*lm^2)/2 + (2158979337733*Pi^2)/
            302400 - (126862478288815361*Im[PolyLog[2, (-1)^(1/3)]])/
            (40176939600*Sqrt[3]) + 396396*Zeta[3])), 
      (2133392144583252424727480067365941*CF^2*NC)/
        188012440521991002677760000 + (39272445013*CF^2*lm*NC)/15680 + 
       (44613261*CF^2*lm^2*NC)/20 + (729672273619640202189329*CF*NM*NC)/
        3599700616512000 + (15238479401*CF*lm*NM*NC)/84672 + 
       (1652343*CF*lm^2*NM*NC)/20 - (2629371232373*CF*NC*NL)/4445280 + 
       (15238479401*CF*lm*NC*NL)/84672 + (1652343*CF*lm^2*NC*NL)/20 - 
       (129659483699699357396325729516500771*CF*NC*NH)/
        3298946858159077843413696000 + (15238479401*CF*lm*NC*NH)/84672 + 
       (1652343*CF*lm^2*NC*NH)/20 - (6279714519950948653*CF^2*NC*Pi^2)/
        326918592000 - (16335*CF^2*lm*NC*Pi^2)/2 - 
       (49726747463*CF*NM*NC*Pi^2)/378 - (605*CF*lm*NM*NC*Pi^2)/2 + 
       (168391399*CF*NC*NL*Pi^2)/1512 - (605*CF*lm*NC*NL*Pi^2)/2 - 
       (605*CF*lm*NC*NH*Pi^2)/2 + (6132345066698736409*CF^2*NC*Pi^3)/
        (6694626049920*Sqrt[3]) + (119300115116845705*CF*NC*NH*Pi^3)/
        (20920706406*Sqrt[3]) + (649351769*CF^2*NC*Pi^4)/21600 - 
       (64751049833970681467617*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8200916911152000*Sqrt[3]) - (359387752567705484*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
       (42209563*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
       (6132345066698736409*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (180796228200*Sqrt[3]) + (27268597740993304*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) + 
       (6132345066698736409*CF^2*NC*Pi*Log[3]^2)/(8678218953600*Sqrt[3]) + 
       (3408574717624163*CF*NC*NH*Pi*Log[3]^2)/(774840978*Sqrt[3]) + 
       CF*((-49816279826967893*CF*NC)/277992000 + 
         CA*(2696889496136097533/27243216000 - 5239146*lm)*NC + 
         25719444*CF*lm*NC - (7281969622009*NM*NC)/4620 + 952572*lm*NM*NC + 
         (77244553*NC*NL)/63 + 952572*lm*NC*NL + (26735641021*NC*NH)/
          204204 + 952572*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-579078566867*CA + 6*(39019281703*CF + 
            25200*(53546675*NM + 79381*NL)))*Log[x]^3)/18900 - 
       (1508921687392716445847*CF^2*NC*PolyGamma[2, 1])/351467867620800 - 
       (902514601133*CF*NM*NC*PolyGamma[2, 1])/9450 + 
       (16059481806037934669*CF*NC*NH*PolyGamma[2, 1])/5491685431575 + 
       CA*CF*NC*(-1778420750298749733178325511711541/
          376024881043982005355520000 - (18175773*lm^2)/40 + 
         (188832356307746701*Pi^2)/19813248000 - (6132345066698736409*Pi^3)/
          (13389252099840*Sqrt[3]) - (659806169*Pi^4)/43200 + 
         lm*(-1327791519791/846720 + (6655*Pi^2)/4) + 
         (64751049833970681467617*Im[PolyLog[2, (-1)^(1/3)]])/
          (16401833822304000*Sqrt[3]) - (42209563*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/20 - (6132345066698736409*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(361592456400*Sqrt[3]) - 
         (6132345066698736409*Pi*Log[3]^2)/(17356437907200*Sqrt[3]) + 
         (1508921687392716445847*PolyGamma[2, 1])/702935735241600 - 
         (2860280725601831179699*Zeta[3])/351467867620800) + 
       (2397465656260825207987*CF^2*NC*Zeta[3])/175733933810400 + 
       (81257945617*CF*NM*NC*Zeta[3])/4725 + 1295970*CF*NC*NL*Zeta[3] - 
       (20554141803524669762*CF*NC*NH*Zeta[3])/5491685431575 + 
       CF*Log[x]*((-4714456561950826763*NM*NC)/4994589600 + 
         (1112894497*lm*NM*NC)/1260 + 169884*lm^2*NM*NC + 
         (5663665138*NC*NL)/2205 + (1112894497*lm*NC*NL)/1260 + 
         169884*lm^2*NC*NL + (3721775814650252660535906277*NC*NH)/
          89750849862530656800 + (1112894497*lm*NC*NH)/1260 + 
         169884*lm^2*NC*NH - 106859988*NM*NC*Pi^2 + 215390*NC*NL*Pi^2 - 
         (27268597740993304*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CA*NC*(734272547322859527665311471/
            9937810365401318400 - (15238593227*lm)/2520 - 934362*lm^2 + 
           (6013182088357*Pi^2)/907200 + (6132345066698736409*
             Im[PolyLog[2, (-1)^(1/3)]])/(1084777369200*Sqrt[3]) - 
           679536*Zeta[3]) + CF*NC*(-134618918327320153873819393813/
            869558406972615360000 + (2660846331*lm)/140 + 4586868*lm^2 - 
           (176457355751*Pi^2)/12960 - (6132345066698736409*
             Im[PolyLog[2, (-1)^(1/3)]])/(542388684600*Sqrt[3]) + 
           1359072*Zeta[3])), (1690059990466060744456616550085972859*CF^2*NC)/
        5076335894093757072299520000 - (4678058632013*CF^2*lm*NC)/1270080 - 
       (33283503*CF^2*lm^2*NC)/10 - (932377306019920361627149*CF*NM*NC)/
        3599700616512000 - (1828035635641*CF*lm*NM*NC)/6858432 - 
       (3698167*CF*lm^2*NM*NC)/30 + (12114788745119777*CF*NC*NL)/
        12002256000 - (1828035635641*CF*lm*NC*NL)/6858432 - 
       (3698167*CF*lm^2*NC*NL)/30 + (777988350844707755982803924861737433*CF*
         NC*NH)/12724509310042157396024256000 - (1828035635641*CF*lm*NC*NH)/
        6858432 - (3698167*CF*lm^2*NC*NH)/30 - 
       (19113589724886991813*CF^2*NC*Pi^2)/75442752000 + 
       (68365*CF^2*lm*NC*Pi^2)/6 + (2107184623013*CF*NM*NC*Pi^2)/20412 + 
       (68365*CF*lm*NM*NC*Pi^2)/162 - (7050435271*CF*NC*NL*Pi^2)/40824 + 
       (68365*CF*lm*NC*NL*Pi^2)/162 + (68365*CF*lm*NC*NH*Pi^2)/162 - 
       (269818478753387787787*CF^2*NC*Pi^3)/(180754903347840*Sqrt[3]) - 
       (5008642943491956055*CF*NC*NH*Pi^3)/(564859072962*Sqrt[3]) - 
       (3077638883*CF^2*NC*Pi^4)/64800 + (2672843910120711947065291*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(221424756601104000*Sqrt[3]) + 
       (533957642815575369961*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) - (196551641*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - (269818478753387787787*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4881498161400*Sqrt[3]) - 
       (1144832672798161384*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (269818478753387787787*CF^2*NC*Pi*Log[3]^2)/
        (234311911747200*Sqrt[3]) - (143104084099770173*CF*NC*NH*Pi*
         Log[3]^2)/(20920706406*Sqrt[3]) - 
       (CF*NC*(-51*CA*(42135506102165807083 + 232642145447712000*lm) + 
          34*CF*(127639350692357951561 + 1713092161933152000*lm) + 
          16800*(221*(-462124124924537 + 581024339280*lm)*NM + 
            3*(29172*(1874503591 + 1467233180*lm)*NL + 35*(177872325451 + 
                1222917895056*lm)*NH)))*Log[x]^2)/1389404016000 + 
       (CF*NC*(65327922809353*CA + 42*(-3445811421891*CF + 
            400*(3861883599*NM + 10480237*NL)))*Log[x]^3)/170100 - 
       (602828641028882607760079*CF^2*NC*PolyGamma[2, 1])/4066985325326400 + 
       (6642378753589*CF*NM*NC*PolyGamma[2, 1])/56700 - 
       (16339550137357955145587*CF*NC*NH*PolyGamma[2, 1])/3558612159660600 + 
       CA*CF*NC*(-341132695674671230347156979449188287/
          2030534357637502828919808000 + (40679837*lm^2)/60 + 
         (22609589250750242339*Pi^2)/178319232000 + 
         (269818478753387787787*Pi^3)/(361509806695680*Sqrt[3]) + 
         (115607129*Pi^4)/4800 + lm*(159723756046591/68584320 - 
           (752015*Pi^2)/324) - (2672843910120711947065291*
           Im[PolyLog[2, (-1)^(1/3)]])/(442849513202208000*Sqrt[3]) + 
         (196551641*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (269818478753387787787*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9762996322800*Sqrt[3]) + (269818478753387787787*Pi*Log[3]^2)/
          (468623823494400*Sqrt[3]) + (602828641028882607760079*
           PolyGamma[2, 1])/8133970650652800 - (1395782816932266863255773*
           Zeta[3])/28468897277284800) + (1455373546795865650970941*CF^2*NC*
         Zeta[3])/14234448638642400 + (1510183820689*CF*NM*NC*Zeta[3])/
        28350 - (18775978*CF*NC*NL*Zeta[3])/9 + 
       (9639871149602672833213*CF*NC*NH*Zeta[3])/1779306079830300 + 
       CF*Log[x]*((12963253462577804249*NM*NC)/26970783840 - 
         (9349844911*lm*NM*NC)/6804 - 264264*lm^2*NM*NC - 
         (9747542931239*NC*NL)/2381400 - (9349844911*lm*NC*NL)/6804 - 
         264264*lm^2*NC*NL - (22330250344606191329970086191*NC*NH)/
          346181849469761104800 - (9349844911*lm*NC*NH)/6804 - 
         264264*lm^2*NC*NH + (2564037760*NM*NC*Pi^2)/27 - 
         (28095602*NC*NL*Pi^2)/81 + (1144832672798161384*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-48525566568101406216864930217661/23478076988260614720000 - 
           (7451900863*lm)/252 - 7135128*lm^2 - (10605401644681*Pi^2)/54432 + 
           (269818478753387787787*Im[PolyLog[2, (-1)^(1/3)]])/
            (14644494484200*Sqrt[3]) - 2114112*Zeta[3]) + 
         CA*NC*(9758073733294728039502838364133/9391230795304245888000 + 
           (128021025605*lm)/13608 + 1453452*lm^2 + (265920080135761*Pi^2)/
            2721600 - (269818478753387787787*Im[PolyLog[2, (-1)^(1/3)]])/
            (29288988968400*Sqrt[3]) + 1057056*Zeta[3])), 
      (239016447699583066019835480540338389*CF^2*NC)/
        846055982348959512049920000 + (7319470401877*CF^2*lm*NC)/1270080 + 
       (51298533*CF^2*lm^2*NC)/10 + (371394961255296908339291993*CF*NM*NC)/
        140388324043968000 + (14196756929989*CF*lm*NM*NC)/34292160 + 
       (5699837*CF*lm^2*NM*NC)/30 - (14654365417324547*CF*NC*NL)/
        8001504000 + (14196756929989*CF*lm*NC*NL)/34292160 + 
       (5699837*CF*lm^2*NC*NL)/30 - 
       (21435660512451659769357634416098204484319*CF*NC*NH)/
        203647288501018034351770867776000 + (14196756929989*CF*lm*NC*NH)/
        34292160 + (5699837*CF*lm^2*NC*NH)/30 - 
       (38665635365051261731*CF^2*NC*Pi^2)/140107968000 - 
       (102245*CF^2*lm*NC*Pi^2)/6 - (83824855215919*CF*NM*NC*Pi^2)/51030 - 
       (102245*CF*lm*NM*NC*Pi^2)/162 + (1634623133*CF*NC*NL*Pi^2)/5832 - 
       (102245*CF*lm*NC*NL*Pi^2)/162 - (102245*CF*lm*NC*NH*Pi^2)/162 + 
       (151938115775710859663*CF^2*NC*Pi^3)/(60251634449280*Sqrt[3]) + 
       (5761351864258368595*CF*NC*NH*Pi^3)/(376572715308*Sqrt[3]) + 
       (5095574341*CF^2*NC*Pi^4)/64800 - (1506746410582686414680459*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(73808252200368000*Sqrt[3]) - 
       (295364495179865226662*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3295011258945*Sqrt[3]) + (104716469*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + (151938115775710859663*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1627166053800*Sqrt[3]) + 
       (658440213058099268*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) + (151938115775710859663*CF^2*NC*Pi*Log[3]^2)/
        (78103970582400*Sqrt[3]) + (164610053264524817*CF*NC*NH*Pi*Log[3]^2)/
        (13947137604*Sqrt[3]) + CF*((-129425392727658757073*CF*NC)/
          40864824000 + CA*(43868786351796984359/27243216000 - 
           (400520120*lm)/27)*NC + 72821840*CF*lm*NC - 
         (95861497722850273*NM*NC)/4864860 + (72821840*lm*NM*NC)/27 + 
         (3253141489*NC*NL)/945 + (72821840*lm*NC*NL)/27 + 
         (73113803607787*NC*NH)/174594420 + (72821840*lm*NC*NH)/27)*
        Log[x]^2 - (CF*NC*(-71298773840459*CA + 116802487382606*CF + 
          117600*(7596839541*NM + 2600780*NL))*Log[x]^3)/170100 - 
       (957189169223543021823503*CF^2*NC*PolyGamma[2, 1])/9489632425761600 - 
       (15931420153574*CF*NM*NC*PolyGamma[2, 1])/14175 + 
       (32323764769797179056*CF*NC*NH*PolyGamma[2, 1])/4236443047215 + 
       CA*CF*NC*(-469380908548171587852597857547440057/
          3384223929395838048199680000 - (62698207*lm^2)/60 + 
         (1890099627855028739*Pi^2)/13716864000 - 
         (151938115775710859663*Pi^3)/(120503268898560*Sqrt[3]) - 
         (1720337047*Pi^4)/43200 + (55*lm*(-899559503053 + 865728864*Pi^2))/
          13716864 + (1506746410582686414680459*Im[PolyLog[2, (-1)^(1/3)]])/
          (147616504400736000*Sqrt[3]) - 
         (104716469*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 - 
         (151938115775710859663*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3254332107600*Sqrt[3]) - (151938115775710859663*Pi*Log[3]^2)/
          (156207941164800*Sqrt[3]) + (957189169223543021823503*
           PolyGamma[2, 1])/18979264851523200 - 
         (950405789630222821795843*Zeta[3])/9489632425761600) + 
       (917339579393728507591051*CF^2*NC*Zeta[3])/4744816212880800 + 
       (5116926268352*CF*NM*NC*Zeta[3])/14175 + (32071832*CF*NC*NL*Zeta[3])/
        9 - (50305908171248189848*CF*NC*NH*Zeta[3])/4236443047215 + 
       CF*Log[x]*((-10424989693791058477099*NM*NC)/876550474800 + 
         (76815810643*lm*NM*NC)/34020 + 429429*lm^2*NM*NC + 
         (22096480722223*NC*NL)/3175200 + (76815810643*lm*NC*NL)/34020 + 
         429429*lm^2*NC*NL + (3245597283105281105160200380709*NC*NH)/
          29160051120336210394320 + (76815810643*lm*NC*NH)/34020 + 
         429429*lm^2*NC*NH - (35435988971*NM*NC*Pi^2)/27 + 
         (48005503*NC*NL*Pi^2)/81 - (658440213058099268*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3486784401*Sqrt[3]) + 
         CA*NC*(3604839605542983181618359979519/3130410265101415296000 - 
           (1049502361193*lm)/68040 - (4723719*lm^2)/2 + 
           (13197026352613*Pi^2)/129600 + (151938115775710859663*
             Im[PolyLog[2, (-1)^(1/3)]])/(9762996322800*Sqrt[3]) - 
           1717716*Zeta[3]) + CF*NC*(-18170102131506479992256710868711/
            7826025662753538240000 + (61395015253*lm)/1260 + 11594583*lm^2 - 
           (18564744679783*Pi^2)/90720 - (151938115775710859663*
             Im[PolyLog[2, (-1)^(1/3)]])/(4881498161400*Sqrt[3]) + 
           3435432*Zeta[3])), (1182800257824806986427807050984154037054671*
         CF^2*NC)/249400382476826284962075417600000 - 
       (1043816720809*CF^2*lm*NC)/127008 - (59239323*CF^2*lm^2*NC)/8 - 
       (187388229029975011322718712627*CF*NM*NC)/69669478386668160000 - 
       (2036549295643*CF*lm*NM*NC)/3429216 - (2194049*CF*lm^2*NM*NC)/8 + 
       (712295687145879743*CF*NC*NL)/240045120000 - 
       (2036549295643*CF*lm*NC*NL)/3429216 - (2194049*CF*lm^2*NC*NL)/8 + 
       (968235520032682986981542778890757467992679*CF*NC*NH)/
        6109418655030541030553126033280000 - (2036549295643*CF*lm*NC*NH)/
        3429216 - (2194049*CF*lm^2*NC*NH)/8 - 
       (1657416019444454504849*CF^2*NC*Pi^2)/490377888000 + 
       (347633*CF^2*lm*NC*Pi^2)/15 + (507159184876117*CF*NM*NC*Pi^2)/
        510300 + (347633*CF*lm*NM*NC*Pi^2)/405 - 
       (428010252527*CF*NC*NL*Pi^2)/1020600 + (347633*CF*lm*NC*NL*Pi^2)/
        405 + (347633*CF*lm*NC*NH*Pi^2)/405 - 
       (44489500568536826579*CF^2*NC*Pi^3)/(11297181459240*Sqrt[3]) - 
       (26016158680527656921*CF*NC*NH*Pi^3)/(1129718145924*Sqrt[3]) - 
       (242033077*CF^2*NC*Pi^4)/2025 + (19173895776003108585889*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(632642161717440*Sqrt[3]) + 
       (1345880014938185692939*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) - (235130896*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (12711285876724807594*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(87169610025*Sqrt[3]) - 
       (14866376388872946812*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (17433922005*Sqrt[3]) - (6355642938362403797*CF^2*NC*Pi*Log[3]^2)/
        (2092070640600*Sqrt[3]) - (3716594097218236703*CF*NC*NH*Pi*Log[3]^2)/
        (209207064060*Sqrt[3]) - 
       (CF*NC*(-19*CA*(14137642011761609096383 + 16137430506791193600*lm) + 
          8*(152*CF*(442697531667060267421 + 1237814271827733600*lm) + 
            105*(209*(-895849226532371941 + 317540938740480*lm)*NM + 
              21616452*(3894329767 + 3070164160*lm)*NL + 
              3*(3603235792382617 + 22122018732253440*lm)*NH)))*Log[x]^2)/
        13199338152000 + (CF*NC*(887632370340035*CA - 1817093634871236*CF + 
          1680*(363300718809*NM + 285086672*NL))*Log[x]^3)/170100 - 
       (82010874994817773570278533*CF^2*NC*PolyGamma[2, 1])/
        42703345915927200 + (10261164152537*CF*NM*NC*PolyGamma[2, 1])/9072 - 
       (247033926403620151304177*CF*NC*NH*PolyGamma[2, 1])/
        21351672957963600 + CA*CF*NC*
        (-118479654523417475799360012192931138422503/
          49880076495365256992415083520000 + (24134539*lm^2)/16 + 
         (11592313563577520917*Pi^2)/6858432000 + (44489500568536826579*Pi^3)/
          (22594362918480*Sqrt[3]) + (244814141*Pi^4)/4050 + 
         lm*(35568811139345/6858432 - (3823963*Pi^2)/810) - 
         (19173895776003108585889*Im[PolyLog[2, (-1)^(1/3)]])/
          (1265284323434880*Sqrt[3]) + (117565448*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/15 + (6355642938362403797*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(87169610025*Sqrt[3]) + 
         (6355642938362403797*Pi*Log[3]^2)/(4184141281200*Sqrt[3]) + 
         (82010874994817773570278533*PolyGamma[2, 1])/85406691831854400 - 
         (30028903431212674111932523*Zeta[3])/42703345915927200) + 
       (1210286102519683074649117*CF^2*NC*Zeta[3])/854066918318544 + 
       (11224928168173*CF*NM*NC*Zeta[3])/22680 - 
       (248494207*CF*NC*NL*Zeta[3])/45 + (182189663580696778738063*CF*NC*NH*
         Zeta[3])/10675836478981800 + CF*Log[x]*
        ((2101626093829567900984141*NM*NC)/460587431304000 - 
         (576318245789*lm*NM*NC)/170100 - (1288287*lm^2*NM*NC)/2 - 
         (145496378180809*NC*NL)/13608000 - (576318245789*lm*NC*NL)/
          170100 - (1288287*lm^2*NC*NL)/2 - 
         (1466038438661541774678334477904401*NC*NH)/
          8748015336100863118296000 - (576318245789*lm*NC*NH)/170100 - 
         (1288287*lm^2*NC*NH)/2 + (120972563041*NM*NC*Pi^2)/135 - 
         (744092089*NC*NL*Pi^2)/810 + (14866376388872946812*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(52301766015*Sqrt[3]) + 
         CF*NC*(-89892702293566824472958038413244349/
            3392582124803658827040000 - (115165570091*lm)/1575 - 
           (34783749*lm^2)/2 - (890290046458501*Pi^2)/340200 + 
           (12711285876724807594*Im[PolyLog[2, (-1)^(1/3)]])/
            (261508830075*Sqrt[3]) - 5153148*Zeta[3]) + 
         CA*NC*(719921186020891955446636513364353/54281313996858541232640 + 
           (7873464034579*lm)/340200 + (14171157*lm^2)/4 + 
           (890806097335321*Pi^2)/680400 - (6355642938362403797*
             Im[PolyLog[2, (-1)^(1/3)]])/(261508830075*Sqrt[3]) + 
           2576574*Zeta[3])), (185278285422951224439587960936599922708503*
         CF^2*NC)/38478916153567483965577350144000 + 
       (1599454651121*CF^2*lm*NC)/129600 + 10981971*CF^2*lm^2*NC + 
       (16677202905296199990831980770747*CF*NM*NC)/492662740020010560000 + 
       (3101788283921*CF*lm*NM*NC)/3499200 + (1220219*CF*lm^2*NM*NC)/3 - 
       (5426283040306397*CF*NC*NL)/1071630000 + (3101788283921*CF*lm*NC*NL)/
        3499200 + (1220219*CF*lm^2*NC*NL)/3 - 
       (21451349829715734181271963792119283128012499*CF*NC*NH)/
        82477151842912303912467201449280000 + (3101788283921*CF*lm*NC*NH)/
        3499200 + (1220219*CF*lm^2*NC*NH)/3 - 
       (9114214115413055895251*CF^2*NC*Pi^2)/2381835456000 - 
       (1002001*CF^2*lm*NC*Pi^2)/30 - (740496521544893*CF*NM*NC*Pi^2)/
        36450 - (1002001*CF*lm*NM*NC*Pi^2)/810 + 
       (95035105451*CF*NC*NL*Pi^2)/145800 - (1002001*CF*lm*NC*NL*Pi^2)/
        810 - (1002001*CF*lm*NC*NH*Pi^2)/810 + 
       (30965883928180569973703*CF^2*NC*Pi^3)/(4880382390391680*Sqrt[3]) + 
       (288561141382676514058*CF*NC*NH*Pi^3)/(7625597484987*Sqrt[3]) + 
       (12226983769*CF^2*NC*Pi^4)/64800 - (1672481179740892281400601*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(34162676732741760*Sqrt[3]) - 
       (57928026581501921002352*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (266895911974545*Sqrt[3]) + (240529289*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + (4423697704025795710529*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(18828635765400*Sqrt[3]) + 
       (659568323160403460704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) + 
       (4423697704025795710529*CF^2*NC*Pi*Log[3]^2)/(903774516739200*
         Sqrt[3]) + (41223020197525216294*CF*NC*NH*Pi*Log[3]^2)/
        (1412147682405*Sqrt[3]) + 
       (CF*NC*(-57*CA*(-1511311145801380430449 + 2537051016214915200*lm) + 
          10*(19*CF*(-904039757951557998107 + 3736384223880147840*lm) + 
            48*(133*(-14400103626576502369 + 411858931203720*lm)*NM + 
              302630328*(229492314 + 181003795*lm)*NL + 
              3*(3137846439805331 + 18259079283364920*lm)*NH)))*Log[x]^2)/
        3771239472000 - (CF*NC*(-141973221750995*CA + 
          14*(19541987099569*CF + 120*(937094007072*NM + 67229981*NL)))*
         Log[x]^3)/24300 - (253881918603098843719612703*CF^2*NC*
         PolyGamma[2, 1])/153732045297337920 - 
       (26882814405953*CF*NM*NC*PolyGamma[2, 1])/2025 + 
       (221292944540216285546293*CF*NC*NH*PolyGamma[2, 1])/
        12010316038854525 + CA*CF*NC*
        (-923926754717705653850466101464368154073549/
          384789161535674839655773501440000 - (13422409*lm^2)/6 + 
         (3748271308396385093*Pi^2)/1959552000 - 
         (30965883928180569973703*Pi^3)/(9760764780783360*Sqrt[3]) - 
         (1372804433*Pi^4)/14400 + (11*lm*(-4913214482321 + 4328644320*Pi^2))/
          6998400 + (1672481179740892281400601*Im[PolyLog[2, (-1)^(1/3)]])/
          (68325353465483520*Sqrt[3]) - (240529289*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/20 - (4423697704025795710529*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(37657271530800*Sqrt[3]) - 
         (4423697704025795710529*Pi*Log[3]^2)/(1807549033478400*Sqrt[3]) + 
         (253881918603098843719612703*PolyGamma[2, 1])/307464090594675840 - 
         (958479107544118489541643047*Zeta[3])/768660226486689600) + 
       (951925227782422673637148943*CF^2*NC*Zeta[3])/384330113243344800 + 
       (11739267278504*CF*NM*NC*Zeta[3])/2025 + 
       (404588002*CF*NC*NL*Zeta[3])/45 - (393589291208751578841934*CF*NC*NH*
         Zeta[3])/12010316038854525 + CF*Log[x]*
        ((-52874645598802564541355469*NM*NC)/361890124596000 + 
         (129271555127*lm*NM*NC)/24300 + 1002001*lm^2*NM*NC + 
         (1228595059372*NC*NL)/70875 + (129271555127*lm*NC*NL)/24300 + 
         1002001*lm^2*NC*NL + (32521615606064459701508147358462721*NC*NH)/
          118098207037361652096996000 + (129271555127*lm*NC*NH)/24300 + 
         1002001*lm^2*NC*NH - (2186368854796*NM*NC*Pi^2)/135 + 
         (605880002*NC*NL*Pi^2)/405 - (659568323160403460704*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CA*NC*(23220801219207604677676481099615749/
            1495505589709367972736000 - (1762867846597*lm)/48600 - 
           (11022011*lm^2)/2 + (188295067370861*Pi^2)/129600 + 
           (4423697704025795710529*Im[PolyLog[2, (-1)^(1/3)]])/
            (112971814592400*Sqrt[3]) - 4008004*Zeta[3]) + 
         CF*NC*(-813917193535322098459024376671616819/
            26171347819913939522880000 + (103570229477*lm)/900 + 
           27054027*lm^2 - (188454350711053*Pi^2)/64800 - 
           (4423697704025795710529*Im[PolyLog[2, (-1)^(1/3)]])/
            (56485907296200*Sqrt[3]) + 8016008*Zeta[3])), 
      (62054882907787664413597463041363732519671920221*CF^2*NC)/
        942596021061854901856768016563200000 - (268867713630097*CF^2*lm*NC)/
        15681600 - (30829617*CF^2*lm^2*NC)/2 - 
       (90493758555098457792972654941059273*CF*NM*NC)/
        3379173733797252431040000 - (524025955768897*CF*lm*NM*NC)/
        423403200 - (3425513*CF*lm^2*NM*NC)/6 + 
       (5442099903853475339*CF*NC*NL)/691558560000 - 
       (524025955768897*CF*lm*NC*NL)/423403200 - (3425513*CF*lm^2*NC*NL)/
        6 + (236106856390471619008709600928374200825133*CF*NC*NH)/
        620128961224904540695242116160000 - (524025955768897*CF*lm*NC*NH)/
        423403200 - (3425513*CF*lm^2*NC*NH)/6 - 
       (1150953472005326130269593*CF^2*NC*Pi^2)/26200190016000 + 
       (1333241*CF^2*lm*NC*Pi^2)/30 + (7364594153261431*CF*NM*NC*Pi^2)/
        801900 + (1333241*CF*lm*NM*NC*Pi^2)/810 - 
       (1517422574681*CF*NC*NL*Pi^2)/1603800 + (1333241*CF*lm*NC*NL*Pi^2)/
        810 + (1333241*CF*lm*NC*NH*Pi^2)/810 - 
       (513369858264443061299663*CF^2*NC*Pi^3)/(53684206294308480*Sqrt[3]) - 
       (1689370614376473686707*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) - 
       (17988371219*CF^2*NC*Pi^4)/64800 + (1464388800385130362800227963*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(20668419423308764800*Sqrt[3]) + 
       (12205155653612445967193*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (38127987424935*Sqrt[3]) - (1047587177*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - (73338551180634723042809*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(207114993419400*Sqrt[3]) - 
       (965354636786556392404*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) - 
       (73338551180634723042809*CF^2*NC*Pi*Log[3]^2)/(9941519684131200*
         Sqrt[3]) - (241338659196639098101*CF*NC*NH*Pi*Log[3]^2)/
        (5648590729620*Sqrt[3]) - 
       (CF*NC*(-3*CA*(3647131706693734772524889 + 802595119128071068800*lm) + 
          10*(CF*(2189139255353102587261687 + 1182003720897704664960*lm) + 
            3696*((-123665515007936678681 + 11844674131169880*lm)*NM + 
              57*(758472*(345546659 + 273973595*lm)*NL + (37208608717487 + 
                  207801300546840*lm)*NH))))*Log[x]^2)/41483634192000 + 
       (CF*NC*(18327545981566895*CA + 66*(-558080690449993*CF + 
            280*(481747796592*NM + 101761621*NL)))*Log[x]^3)/267300 - 
       (2714951490817126524522400753*CF^2*NC*PolyGamma[2, 1])/
        109808603783812800 + (1207428021823853*CF*NM*NC*PolyGamma[2, 1])/
        113400 - (260585397335386583768627*CF*NC*NH*PolyGamma[2, 1])/
        9608252831083620 + CA*CF*NC*
        (-191185351022237823308878062511667496900607899221/
          5806391489741026195437690982029312000 + (37680643*lm^2)/12 + 
         (5208092587947831181757*Pi^2)/237105792000 + 
         (513369858264443061299663*Pi^3)/(107368412588616960*Sqrt[3]) + 
         (224185507*Pi^4)/1600 + lm*(831680869735297/76982400 - 
           (14665651*Pi^2)/1620) - (1464388800385130362800227963*
           Im[PolyLog[2, (-1)^(1/3)]])/(41336838846617529600*Sqrt[3]) + 
         (1047587177*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (73338551180634723042809*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (414229986838800*Sqrt[3]) + (73338551180634723042809*Pi*Log[3]^2)/
          (19883039368262400*Sqrt[3]) + (2714951490817126524522400753*
           PolyGamma[2, 1])/219617207567625600 - 
         (11590006928845093470466537351*Zeta[3])/1207894641621940800) + 
       (11605330170799454883187772167*CF^2*NC*Zeta[3])/603947320810970400 + 
       (267060255531773*CF*NM*NC*Zeta[3])/56700 - 
       (606947432*CF*NC*NL*Zeta[3])/45 + (222958304832813459776821*CF*NC*NH*
         Zeta[3])/4804126415541810 + CF*Log[x]*
        ((1275114722374063785551798441*NM*NC)/32660583744789000 - 
         (2069259793757*lm*NM*NC)/267300 - 1457456*lm^2*NM*NC - 
         (1932109913708537*NC*NL)/74844000 - (2069259793757*lm*NC*NL)/
          267300 - 1457456*lm^2*NC*NL - (89494044584984760254281154681803*NC*
           NH)/221989110972484308453000 - (2069259793757*lm*NC*NH)/267300 - 
         1457456*lm^2*NC*NH + (1123794168581*NM*NC*Pi^2)/135 - 
         (909087907*NC*NL*Pi^2)/405 + (965354636786556392404*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(-34764814461048626683147746270500430914749/
            103926422192878253845356480000 - (1658038583357*lm)/9900 - 
           39351312*lm^2 - (14670529155689149*Pi^2)/427680 + 
           (73338551180634723042809*Im[PolyLog[2, (-1)^(1/3)]])/
            (621344980258200*Sqrt[3]) - 11659648*Zeta[3]) + 
         CA*NC*(993481529002497298259534568694645679531/
            5938652696735900219734656000 + (2565086324957*lm)/48600 + 
           8016008*lm^2 + (73360524836398577*Pi^2)/4276800 - 
           (73338551180634723042809*Im[PolyLog[2, (-1)^(1/3)]])/
            (1242689960516400*Sqrt[3]) + 5829824*Zeta[3])), 
      (15752599436528854326821965766275709393456720679451*CF^2*NC)/
        217739680865288482328913411826099200000 + (8671474963837*CF^2*lm*NC)/
        348480 + (442768599*CF^2*lm^2*NC)/20 + 
       (96346951316563930097438259929888953*CF*NM*NC)/
        225278248919816828736000 + (3362975007329*CF*lm*NM*NC)/1881792 + 
       (16398837*CF*lm^2*NM*NC)/20 - (1767960032129970689*CF*NC*NL)/
        138311712000 + (3362975007329*CF*lm*NC*NL)/1881792 + 
       (16398837*CF*lm^2*NC*NL)/20 - 
       (361407961509042239729108130640042228454716314013*CF*NC*NH)/
        602099703883628401021793064020033856000 + 
       (3362975007329*CF*lm*NC*NH)/1881792 + (16398837*CF*lm^2*NC*NH)/20 - 
       (89180158151926591577173*CF^2*NC*Pi^2)/1746679334400 - 
       (124215*CF^2*lm*NC*Pi^2)/2 - (2213640042968963*CF*NM*NC*Pi^2)/8910 - 
       (41405*CF*lm*NM*NC*Pi^2)/18 + (10110795799*CF*NC*NL*Pi^2)/7128 - 
       (41405*CF*lm*NC*NL*Pi^2)/18 - (41405*CF*lm*NC*NH*Pi^2)/18 + 
       (2385457788542961127093721*CF^2*NC*Pi^3)/(161052618882925440*
         Sqrt[3]) + (7995565181542755273905*CF*NC*NH*Pi^3)/
        (91507169819844*Sqrt[3]) + (3034051111*CF^2*NC*Pi^4)/7200 - 
       (6829561115723014338357107789*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (62005258269926294400*Sqrt[3]) - (394786547427331814314942*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(800687735923635*Sqrt[3]) + 
       (517817391*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
       (340779684077565875299103*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(621344980258200*Sqrt[3]) + 
       (913778877890600602732*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (340779684077565875299103*CF^2*NC*Pi*Log[3]^2)/(29824559052393600*
         Sqrt[3]) + (228444719472650150683*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) + CF*((-281994680996582453771933*CF*NC)/
          460929268800 + CA*(1410739544488280515230793/4609292688000 - 
           (275536261*lm)/3)*NC + 450877518*CF*lm*NC - 
         (6759956289131758417*NM*NC)/2267460 + (50097502*lm*NM*NC)/3 + 
         (947663548*NC*NL)/45 + (50097502*lm*NC*NL)/3 + 
         (2511794957086183*NC*NH)/803134332 + (50097502*lm*NC*NH)/3)*
        Log[x]^2 - (CF*NC*(-7035602122795231*CA + 
          90*(155254429273157*CF + 3080*(255404710794*NM + 3578393*NL)))*
         Log[x]^3)/89100 - (55418472375202542554222395411*CF^2*NC*
         PolyGamma[2, 1])/2305980679460068800 - 
       (148414947270332*CF*NM*NC*PolyGamma[2, 1])/945 + 
       (3002327424389006523589547*CF*NC*NH*PolyGamma[2, 1])/
        72061896233127150 + CA*CF*NC*
        (-15746065354303868424165750430973218744582630041223/
          435479361730576964657826823652198400000 - (180387207*lm^2)/40 + 
         (6859741609158500081753*Pi^2)/268719897600 - 
         (2385457788542961127093721*Pi^3)/(322105237765850880*Sqrt[3]) - 
         (1020183437*Pi^4)/4800 + lm*(-26633711488069/1710720 + 
           (455455*Pi^2)/36) + (6829561115723014338357107789*
           Im[PolyLog[2, (-1)^(1/3)]])/(124010516539852588800*Sqrt[3]) - 
         (517817391*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 - 
         (340779684077565875299103*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1242689960516400*Sqrt[3]) - (340779684077565875299103*Pi*Log[3]^2)/
          (59649118104787200*Sqrt[3]) + (55418472375202542554222395411*
           PolyGamma[2, 1])/4611961358920137600 - 
         (390454200806653737462357549133*Zeta[3])/25365787474060756800) + 
       (389959054167260055048188724493*CF^2*NC*Zeta[3])/
        12682893737030378400 + (78511440290876*CF*NM*NC*Zeta[3])/945 + 
       (63297416*CF*NC*NL*Zeta[3])/3 - (2943257970233858151394753*CF*NC*NH*
         Zeta[3])/36030948116563575 + CF*Log[x]*
        ((-2558881038132429330428264407*NM*NC)/1451581499768400 + 
         (13905215857*lm*NM*NC)/1188 + 2186184*lm^2*NM*NC + 
         (66909152064637*NC*NL)/1663200 + (13905215857*lm*NC*NL)/1188 + 
         2186184*lm^2*NC*NL + (5959968300807645755019922481033007493*NC*NH)/
          9371092728414647093896632600 + (13905215857*lm*NC*NH)/1188 + 
         2186184*lm^2*NC*NH - (595935594737*NM*NC*Pi^2)/3 + 
         (31607303*NC*NL*Pi^2)/9 - (913778877890600602732*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(124335708285984084026874182670825362260553/
            623558533157269523072138880000 - (17210726065*lm)/216 - 
           12024012*lm^2 + (9371921822657203*Pi^2)/475200 + 
           (340779684077565875299103*Im[PolyLog[2, (-1)^(1/3)]])/
            (3728069881549200*Sqrt[3]) - 8744736*Zeta[3]) + 
         CF*NC*(-24873582091635609034881422379441303265921/
            62355853315726952307213888000 + (11163741121*lm)/44 + 
           59026968*lm^2 - (28119857075773913*Pi^2)/712800 - 
           (340779684077565875299103*Im[PolyLog[2, (-1)^(1/3)]])/
            (1864034940774600*Sqrt[3]) + 17489472*Zeta[3])), 
      (3474428503803212258527097657193949665422092499938171*CF^2*NC)/
        3919314255575192681920441412869785600000 - 
       (84803549022091*CF^2*lm*NC)/2509056 - (2427040161*CF^2*lm^2*NC)/80 - 
       (43801989867389836687925303234260452661*CF*NM*NC)/
        170310356183381522524416000 - (825760848880463*CF*lm*NM*NC)/
        338722560 - (269671129*CF*lm^2*NM*NC)/240 + 
       (125424393291345753361*CF*NC*NL)/6535228392000 - 
       (825760848880463*CF*lm*NC*NL)/338722560 - (269671129*CF*lm^2*NC*NL)/
        240 + (18585217730788357462594104553252951004846224987633*CF*NC*NH)/
        21675589339810622436784550304721218816000 - 
       (825760848880463*CF*lm*NC*NH)/338722560 - (269671129*CF*lm^2*NC*NH)/
        240 - (731261333240450860498927*CF^2*NC*Pi^2)/1310009500800 + 
       (1946035*CF^2*lm*NC*Pi^2)/24 + (719040184108819403*CF*NM*NC*Pi^2)/
        8981280 + (1946035*CF*lm*NM*NC*Pi^2)/648 - 
       (257381570173*CF*NC*NL*Pi^2)/128304 + (1946035*CF*lm*NC*NL*Pi^2)/
        648 + (1946035*CF*lm*NC*NH*Pi^2)/648 - 
       (1962243130614208713784037*CF^2*NC*Pi^3)/(90592098121645560*Sqrt[3]) - 
       (411127938127705678607315*CF*NC*NH*Pi^3)/(3294258113514384*Sqrt[3]) - 
       (2441819107*CF^2*NC*Pi^4)/4050 + (5436592474828323399237156509*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(34877957776833540600*Sqrt[3]) + 
       (40870569871486294142661929*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (57649516986501720*Sqrt[3]) - (366142504*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (560640894461202489652582*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(699013102790475*Sqrt[3]) - 
       (11746512517934447960209*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (280320447230601244826291*CF^2*NC*Pi*Log[3]^2)/(16776314466971400*
         Sqrt[3]) - (11746512517934447960209*CF*NC*NH*Pi*Log[3]^2)/
        (122009559759792*Sqrt[3]) - 
       (CF*NC*(-46*CA*(8684787295702147884498119 + 350076671623755326250*
             lm) + 5*(46*CF*(3474166176123548568286171 + 
              343711641230596138500*lm) + 165*(69*(-2012702791745283695983 + 
                51434589035629800*lm)*NM + 1740124386*(2560470271 + 
                2039501700*lm)*NL + (688805669995659871 + 
                3548986643458456200*lm)*NH)))*Log[x]^2)/119265448302000 + 
       (CF*NC*(469945941129579267*CA + 40*(-23519657584421932*CF + 
            3969716755982010*NM + 218736557325*NL))*Log[x]^3)/534600 - 
       (101737533819664613266370277997*CF^2*NC*PolyGamma[2, 1])/
        324278533049072175 + (7358715960048737*CF*NM*NC*PolyGamma[2, 1])/
        75600 - (155057852465187778672869643*CF*NC*NH*PolyGamma[2, 1])/
        2594228264392577400 + CA*CF*NC*
        (-3474601539767254733147743794029168326478332374961033/
          7838628511150385363840882825739571200000 + (2966382419*lm^2)/480 + 
         (351569758661165697313*Pi^2)/1259624520 + 
         (1962243130614208713784037*Pi^3)/(181184196243291120*Sqrt[3]) + 
         (2461279457*Pi^4)/8100 + lm*(1310159232373487/61585920 - 
           (21406385*Pi^2)/1296) - (5436592474828323399237156509*
           Im[PolyLog[2, (-1)^(1/3)]])/(69755915553667081200*Sqrt[3]) + 
         (183071252*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (280320447230601244826291*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (699013102790475*Sqrt[3]) + (280320447230601244826291*Pi*Log[3]^2)/
          (33552628933942800*Sqrt[3]) + (101737533819664613266370277997*
           PolyGamma[2, 1])/648557066098144350 - 
         (7184479458194990928318902615971*Zeta[3])/57073021816636702800) + 
       (898261720293909475693092565892*CF^2*NC*Zeta[3])/3567063863539793925 + 
       (1751024327892137*CF*NM*NC*Zeta[3])/37800 - 
       (831054146*CF*NC*NL*Zeta[3])/27 + (147608438091871576433519657*CF*NC*
         NH*Zeta[3])/1297114132196288700 + CF*Log[x]*
        ((5278995844132953812414708879*NM*NC)/18289926897081840 - 
         (3547560142399*lm*NM*NC)/213840 - 3097094*lm^2*NM*NC - 
         (219980628007161419*NC*NL)/3772137600 - (3547560142399*lm*NC*NL)/
          213840 - 3097094*lm^2*NC*NL - 
         (613037793695177984465629794200325386543*NC*NH)/
          674718676445854590760557547200 - (3547560142399*lm*NC*NH)/213840 - 
         3097094*lm^2*NC*NH + (24057477862777*NM*NC*Pi^2)/324 - 
         (61487491*NC*NL*Pi^2)/12 + (11746512517934447960209*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(-1161939693575920296695379990009373156697959/
            280601339920771285382462496000 - (2848484084719*lm)/7920 - 
           83621538*lm^2 - (156665336839406963*Pi^2)/356400 + 
           (560640894461202489652582*Im[PolyLog[2, (-1)^(1/3)]])/
            (2097039308371425*Sqrt[3]) - 24776752*Zeta[3]) + 
         CA*NC*(1659973849701202367434065061179379107243457/
            801718114059346529664178560000 + (4390465245439*lm)/38880 + 
           17034017*lm^2 + (156668319656926139*Pi^2)/712800 - 
           (280320447230601244826291*Im[PolyLog[2, (-1)^(1/3)]])/
            (2097039308371425*Sqrt[3]) + 12388376*Zeta[3])), 
      (142095358528222776680562288390264508626236288639857*CF^2*NC)/
        139975509127685452925730050459635200000 + (37371239587423*CF^2*lm*NC)/
        784080 + (212001426*CF^2*lm^2*NC)/5 + 
       (322364872427036435391851142971831101*CF*NM*NC)/
        60479529894666733851000 + (72463411630351*CF*lm*NM*NC)/21170160 + 
       (23555714*CF*lm^2*NM*NC)/15 - (4918414799135762497*CF*NC*NL)/
        164314313856 + (72463411630351*CF*lm*NC*NL)/21170160 + 
       (23555714*CF*lm^2*NC*NL)/15 - 
       (24460484380879058727321874886537810576056842251*CF*NC*NH)/
        18724075820131632882284309957500500000 + 
       (72463411630351*CF*lm*NC*NH)/21170160 + (23555714*CF*lm^2*NC*NH)/
        15 - (2345647062749228997823699*CF^2*NC*Pi^2)/3555740073600 - 
       (331240*CF^2*lm*NC*Pi^2)/3 - (1684363797697963021*CF*NM*NC*Pi^2)/
        561330 - (331240*CF*lm*NM*NC*Pi^2)/81 + (23390529227*CF*NC*NL*Pi^2)/
        8019 - (331240*CF*lm*NC*NL*Pi^2)/81 - (331240*CF*lm*NC*NH*Pi^2)/
        81 + (734907776697226333940557*CF^2*NC*Pi^3)/(22648024530411390*
         Sqrt[3]) + (39162760928649905985340*CF*NC*NH*Pi^3)/
        (205891132094649*Sqrt[3]) + (1793432914*CF^2*NC*Pi^4)/2025 - 
       (32724463765417225069176663151*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (139511831107334162400*Sqrt[3]) - (12003821478050345195151514*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(11324012265205695*Sqrt[3]) + 
       (1582174048*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (839894601939687238789208*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(699013102790475*Sqrt[3]) + 
       (17902976424525671307584*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) + 
       (104986825242460904848651*CF^2*NC*Pi*Log[3]^2)/(4194078616742850*
         Sqrt[3]) + (1118936026532854456724*CF*NC*NH*Pi*Log[3]^2)/
        (7625597484987*Sqrt[3]) + CF*((-2931322895326799828747*CF*NC)/
          370389591 + CA*(20521200200065358229588583/5185454274000 - 
           (618525908*lm)/3)*NC + 1012133304*CF*lm*NC - 
         (1571694395423077786853*NM*NC)/43648605 + (112459256*lm*NM*NC)/3 + 
         (1270779770*NC*NL)/27 + (112459256*lm*NC*NL)/3 + 
         (151037784647297*NC*NH)/19980675 + (112459256*lm*NC*NH)/3)*
        Log[x]^2 - (2*CF*NC*(-34497553158658087*CA + 68906167572399285*CF + 
          322142784435021000*NM + 835009975800*NL)*Log[x]^3)/66825 - 
       (1702361938567042869722506703143*CF^2*NC*PolyGamma[2, 1])/
        5188456528785154800 - (973461276005228*CF*NM*NC*PolyGamma[2, 1])/
        525 + (28869578366495299753515142*CF*NC*NH*PolyGamma[2, 1])/
        324278533049072175 + CA*CF*NC*
        (-497301273931932215035547507043489228694768233392351/
          979828563893798170480110353217446400000 - (129556427*lm^2)/15 + 
         (66475404727602415057489*Pi^2)/201539923200 - 
         (734907776697226333940557*Pi^3)/(45296049060822780*Sqrt[3]) - 
         (903341257*Pi^4)/2025 + (7*lm*(-3279300121061 + 2473511040*Pi^2))/
          769824 + (32724463765417225069176663151*Im[PolyLog[2, (-1)^(1/3)]])/
          (279023662214668324800*Sqrt[3]) - 
         (791087024*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
         (419947300969843619394604*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (699013102790475*Sqrt[3]) - (104986825242460904848651*Pi*Log[3]^2)/
          (8388157233485700*Sqrt[3]) + (1702361938567042869722506703143*
           PolyGamma[2, 1])/10376913057570309600 - 
         (2145985534245351048786664483127*Zeta[3])/11414604363327340560) + 
       (429100769825831709821082359431*CF^2*NC*Zeta[3])/1141460436332734056 + 
       (1751432450827832*CF*NM*NC*Zeta[3])/1575 + 
       (1256720920*CF*NC*NL*Zeta[3])/27 - (60976282674280941274116916*CF*NC*
         NH*Zeta[3])/324278533049072175 + CF*Log[x]*
        ((-1915899718339996643093195313851*NM*NC)/91449634485409200 + 
         (324724874552*lm*NM*NC)/13365 + 4504864*lm^2*NM*NC + 
         (2604712829364607*NC*NL)/29638224 + (324724874552*lm*NC*NL)/
          13365 + 4504864*lm^2*NC*NL + 
         (2582625833919602942918307840455336411*NC*NH)/
          1865100277658819633902470000 + (324724874552*lm*NC*NH)/13365 + 
         4504864*lm^2*NC*NH - (195237579691184*NM*NC*Pi^2)/81 + 
         (69744220*NC*NL*Pi^2)/9 - (17902976424525671307584*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CA*NC*(39676663238096660615686388481454567203997/
            15943257950043823033094460000 - (200676305596*lm)/1215 - 
           24776752*lm^2 + (34491906712514657*Pi^2)/133650 + 
           (419947300969843619394604*Im[PolyLog[2, (-1)^(1/3)]])/
            (2097039308371425*Sqrt[3]) - 18019456*Zeta[3]) + 
         CF*NC*(-99762902409726185868735080633290304924111/
            20042952851483663241604464000 + (261172505672*lm)/495 + 
           121631328*lm^2 - (68985498866522533*Pi^2)/133650 - 
           (839894601939687238789208*Im[PolyLog[2, (-1)^(1/3)]])/
            (2097039308371425*Sqrt[3]) + 36038912*Zeta[3])), 
      (2696448056769930244644905160113529576228908634960055108237*CF^2*NC)/
        232470695669468925634514302018135071801600000 - 
       (8411710670438599*CF^2*lm*NC)/132509520 - (284544036*CF^2*lm^2*NC)/5 - 
       (1679456487373492507641759139474180978619*CF*NM*NC)/
        711595502638462563377256000 - (16371611547718951*CF*lm*NM*NC)/
        3577757040 - (10538668*CF*lm^2*NM*NC)/5 + 
       (30304113744450721420573*CF*NC*NL)/694227976041600 - 
       (16371611547718951*CF*lm*NC*NL)/3577757040 - 
       (10538668*CF*lm^2*NC*NL)/5 + 
       (3012418664364313184006287418478069374113502889439*CF*NC*NH)/
        1649420860882504751175772395347089500000 - 
       (16371611547718951*CF*lm*NC*NH)/3577757040 - 
       (10538668*CF*lm^2*NC*NH)/5 - (2248761887876259342670449871*CF^2*NC*
         Pi^2)/323572346697600 + (425320*CF^2*lm*NC*Pi^2)/3 + 
       (660782060621611531*CF*NM*NC*Pi^2)/1042470 + 
       (425320*CF*lm*NM*NC*Pi^2)/81 - (420417646535*CF*NC*NL*Pi^2)/104247 + 
       (425320*CF*lm*NC*NL*Pi^2)/81 + (425320*CF*lm*NC*NH*Pi^2)/81 - 
       (29702467004317524624787727*CF^2*NC*Pi^3)/(642380332135304880*
         Sqrt[3]) - (164248177388294240929940*CF*NC*NH*Pi^3)/
        (617673396283947*Sqrt[3]) - (5009748919*CF^2*NC*Pi^4)/4050 + 
       (2092568024183927226327883793221*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6430227124674401848800*Sqrt[3]) + (50642364042151287521507738*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(33972036795617085*Sqrt[3]) - 
       (729050168*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (4243209572045360660683961*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2478319182620775*Sqrt[3]) - 
       (75084881091791652996544*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (4243209572045360660683961*CF^2*NC*Pi*Log[3]^2)/(118959320765797200*
         Sqrt[3]) - (4692805068236978312284*CF*NC*NH*Pi*Log[3]^2)/
        (22876792454961*Sqrt[3]) - 
       (CF*NC*(-243*CA*(266062887151521760879238733 + 1885538914336669592000*
             lm) + 10*(CF*(12930821379196836934334077871 + 
              224927651217507076238400*lm) + 24024*
             (45*(-1090858454464091441171 + 7705862423499240*lm)*NM + 
              6214729950*(69784405 + 55797084*lm)*NL + (72147840170420101 + 
                346763809057465800*lm)*NH)))*Log[x]^2)/1550450827926000 + 
       (CF*NC*(9584044132262274479*CA + 130*(-147473086887160751*CF + 
            9240*(1779790844911*NM + 25905789*NL)))*Log[x]^3)/868725 - 
       (322529811671834210227540160291*CF^2*NC*PolyGamma[2, 1])/
        82356452837859600 + (4037064787802138*CF*NM*NC*PolyGamma[2, 1])/
        4725 - (26998188649622288163709099*CF*NC*NH*PolyGamma[2, 1])/
        216185688699381450 + CA*CF*NC*
        (-2696470172088780441309052745603203700956706091431328409291/
          464941391338937851269028604036270143603200000 + (57962674*lm^2)/5 + 
         (118355988401669817114749437*Pi^2)/34060247020800 + 
         (29702467004317524624787727*Pi^3)/(1284760664270609760*Sqrt[3]) + 
         (560419391*Pi^4)/900 + lm*(25969195380612007/650501280 - 
           (2339260*Pi^2)/81) - (2092568024183927226327883793221*
           Im[PolyLog[2, (-1)^(1/3)]])/(12860454249348803697600*Sqrt[3]) + 
         (364525084*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (4243209572045360660683961*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4956638365241550*Sqrt[3]) + (4243209572045360660683961*Pi*
           Log[3]^2)/(237918641531594400*Sqrt[3]) + 
         (322529811671834210227540160291*PolyGamma[2, 1])/
          164712905675719200 - (18844106508899904136096610451383*Zeta[3])/
          11776972755813922800) + (18844810144627562570996413600343*CF^2*NC*
         Zeta[3])/5888486377906961400 + (2261815301068276*CF*NM*NC*Zeta[3])/
        4725 - (1789250680*CF*NC*NL*Zeta[3])/27 + 
       (27858080018558681906583701*CF*NC*NH*Zeta[3])/108092844349690725 + 
       CF*Log[x]*((10550756671153125514087941257789*NM*NC)/
          6910979520397352400 - (5847994329896*lm*NM*NC)/173745 - 
         6237504*lm^2*NM*NC - (239725882887539927*NC*NL)/1926484560 - 
         (5847994329896*lm*NC*NL)/173745 - 6237504*lm^2*NC*NL - 
         (3499124187078269970178057946373020158169*NC*NH)/
          1807282169051396225251493430000 - (5847994329896*lm*NC*NH)/
          173745 - 6237504*lm^2*NC*NH + (49833456816080*NM*NC*Pi^2)/81 - 
         (99308300*NC*NL*Pi^2)/9 + (75084881091791652996544*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-9101796728551554466752005878625916649695547427/
            180908945122044762147674492343000 - (4704051690056*lm)/6435 - 
           168412608*lm^2 - (6389482797575654357*Pi^2)/1158300 + 
           (4243209572045360660683961*Im[PolyLog[2, (-1)^(1/3)]])/
            (7434957547862325*Sqrt[3]) - 49900032*Zeta[3]) + 
         CA*NC*(52010590528297794390900978373995641067344847473/
            2067530801394797281687708483920000 + (3613646794708*lm)/15795 + 
           34306272*lm^2 + (709944842986764529*Pi^2)/257400 - 
           (4243209572045360660683961*Im[PolyLog[2, (-1)^(1/3)]])/
            (14869915095724650*Sqrt[3]) + 24950016*Zeta[3])), 
      (113808301792508032036652907438980315999982561290496866453681*CF^2*NC)/
        8368945044100881322842514872652862584857600000 + 
       (11573664452855047*CF^2*lm*NC)/132509520 + (388484901*CF^2*lm^2*NC)/
        5 + (4238658379086509914085356408177686023501849*CF*NM*NC)/
        64755190740100093267330296000 + (22441231201926079*CF*lm*NM*NC)/
        3577757040 + (43164989*CF*lm^2*NM*NC)/15 - 
       (45677406165494387864263*CF*NC*NL)/694227976041600 + 
       (22441231201926079*CF*lm*NC*NL)/3577757040 + 
       (43164989*CF*lm^2*NC*NL)/15 - 
       (16969618109746560378843072083003183105913740279599*CF*NC*NH)/
        6280487124129537321784671813052379250000 + 
       (22441231201926079*CF*lm*NC*NH)/3577757040 + 
       (43164989*CF*lm^2*NC*NH)/15 - (537134692447436985867974339*CF^2*NC*
         Pi^2)/64714469339520 - (566440*CF^2*lm*NC*Pi^2)/3 - 
       (52219729636261692347*CF*NM*NC*Pi^2)/1459458 - 
       (566440*CF*lm*NM*NC*Pi^2)/81 + (595472776562*CF*NC*NL*Pi^2)/104247 - 
       (566440*CF*lm*NC*NL*Pi^2)/81 - (566440*CF*lm*NC*NH*Pi^2)/81 + 
       (8562228355164832321029052577*CF^2*NC*Pi^3)/(127191305762790366240*
         Sqrt[3]) + (2187230130678346248131840*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) + (14311912111*CF^2*NC*Pi^4)/8100 - 
       (18946103808291691319483770589387*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (39787030333922861439450*Sqrt[3]) - (60368753871135327780356614*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(27795302832777615*Sqrt[3]) + 
       (3072467188*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (1223175479309261760147007511*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(490707198158913450*
         Sqrt[3]) + (999876631167243999145984*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (1223175479309261760147007511*CF^2*NC*Pi*Log[3]^2)/
        (23553945511627845600*Sqrt[3]) + (62492289447952749946624*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((-308839399915542220322899141*CF*NC)/3100901655852 + 
         CA*(154422168734448475571359506139/3100901655852000 - 
           (1313099788*lm)/3)*NC + 2148708744*CF*lm*NC - 
         (1293133968938189993482331*NM*NC)/3011753745 + 
         (238745416*lm*NM*NC)/3 + (2687923550*NC*NL)/27 + 
         (238745416*lm*NC*NL)/3 + (8495864600479963*NC*NH)/496442925 + 
         (238745416*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-22801177930027884619*CA + 300*(151972845983169925*CF + 
            1144*(584956733180611*NM + 268588593*NL)))*Log[x]^3)/1737450 - 
       (601094308049977037255944074620591*CF^2*NC*PolyGamma[2, 1])/
        140088326277199179600 - (102926307513315646*CF*NM*NC*
         PolyGamma[2, 1])/4725 + (226520324746785576163933334*CF*NC*NH*
         PolyGamma[2, 1])/1250788627474992675 + 
       CA*CF*NC*(-4064540616656101039581985754220418333230802754155691344061/
          597781788864348665917322490903775898918400000 - 
         (474814879*lm^2)/30 + (2821082745200439330330301*Pi^2)/
          679773837600 - (8562228355164832321029052577*Pi^3)/
          (254382611525580732480*Sqrt[3]) - (14402542511*Pi^4)/16200 + 
         lm*(-7108941762649235/130100256 + (3115420*Pi^2)/81) + 
         (18946103808291691319483770589387*Im[PolyLog[2, (-1)^(1/3)]])/
          (79574060667845722878900*Sqrt[3]) - 
         (1536233594*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
         (1223175479309261760147007511*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (981414396317826900*Sqrt[3]) - (1223175479309261760147007511*Pi*
           Log[3]^2)/(47107891023255691200*Sqrt[3]) + 
         (601094308049977037255944074620591*PolyGamma[2, 1])/
          280176652554398359200 - (9097136295516672118975756946722249*
           Zeta[3])/4006526131527896536560) + 
       (9096788598638316111323695632071323*CF^2*NC*Zeta[3])/
        2003263065763948268280 + (67124689089657508*CF*NM*NC*Zeta[3])/4725 + 
       (2628143560*CF*NC*NL*Zeta[3])/27 - (507375998465185993746981332*CF*NC*
         NH*Zeta[3])/1250788627474992675 + CF*Log[x]*
        ((-11883177530034261503193139366252421*NM*NC)/48376856642781466800 + 
         (8334305396336*lm*NM*NC)/173745 + 8836464*lm^2*NM*NC + 
         (351024368522435807*NC*NL)/1926484560 + (8334305396336*lm*NC*NL)/
          173745 + 8836464*lm^2*NC*NL + 
         (3584111990853023981167998381171330986153*NC*NH)/
          1251195347804812771327956990000 + (8334305396336*lm*NC*NH)/
          173745 + 8836464*lm^2*NC*NH - (2339826042832352*NM*NC*Pi^2)/81 + 
         (145882100*NC*NL*Pi^2)/9 - (999876631167243999145984*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(989290666912558350529521197363309337100221843223/
            32563610121968057186581408621740000 - (5144156340328*lm)/15795 - 
           48600552*lm^2 + (45601101997698869593*Pi^2)/13899600 + 
           (1223175479309261760147007511*Im[PolyLog[2, (-1)^(1/3)]])/
            (2944243188953480700*Sqrt[3]) - 35345856*Zeta[3]) + 
         CF*NC*(-3165753600906083518733668366275047637857476676153/
            52101776195148891498530253794784000 + (6713719989896*lm)/6435 + 
           238584528*lm^2 - (45601284643614997411*Pi^2)/6949800 - 
           (1223175479309261760147007511*Im[PolyLog[2, (-1)^(1/3)]])/
            (1472121594476740350*Sqrt[3]) + 70691712*Zeta[3])), 
      (7877616170160578005075757937006679250657560256487737329973057*CF^2*NC)/
        53256923007914699327179640098700034630912000000 - 
       (74238966241273025*CF^2*lm*NC)/649296648 - (1024027317*CF^2*lm^2*NC)/
        10 - (1311940633159923428656955583410665203577173733*CF*NM*NC)/
        64755190740100093267330296000000 - (722112958522535539*CF*lm*NM*NC)/
        87655047480 - (113780813*CF*lm^2*NM*NC)/30 + 
       (129928694189985190873297*CF*NC*NL)/1388455952083200 - 
       (722112958522535539*CF*lm*NC*NL)/87655047480 - 
       (113780813*CF*lm^2*NC*NL)/30 + 
       (22593360051327959445310416951571724184320155496851001*CF*NC*NH)/
        6096259501821737560345654773202842792000000 - 
       (722112958522535539*CF*lm*NC*NH)/87655047480 - 
       (113780813*CF*lm^2*NC*NH)/30 - (48096234681109624675674952123*CF^2*NC*
         Pi^2)/566251606720800 + (716720*CF^2*lm*NC*Pi^2)/3 + 
       (30129480196736630921*CF*NM*NC*Pi^2)/7297290 + 
       (716720*CF*lm*NM*NC*Pi^2)/81 - (807138579235*CF*NC*NL*Pi^2)/104247 + 
       (716720*CF*lm*NC*NL*Pi^2)/81 + (716720*CF*lm*NC*NH*Pi^2)/81 - 
       (23857321249919921623052432521*CF^2*NC*Pi^3)/(254382611525580732480*
         Sqrt[3]) - (1000050785251275132795560*CF*NC*NH*Pi^3)/
        (1853020188851841*Sqrt[3]) - (39145939423*CF^2*NC*Pi^4)/16200 + 
       (5784481715847120730156779189636091*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8912294794798720962436800*Sqrt[3]) + 
       (305247628727485097858395022*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (101916110386851255*Sqrt[3]) - (1387848414*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (23857321249919921623052432521*
         CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6869900774224788300*Sqrt[3]) - (457166073257725774992256*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (23857321249919921623052432521*CF^2*NC*Pi*Log[3]^2)/
        (329755237162789838400*Sqrt[3]) - (28572879578607860937016*CF*NC*NH*
         Pi*Log[3]^2)/(68630377364883*Sqrt[3]) - 
       (CF*NC*(-(CA*(3160621084383377222111870550083 + 
             3805400121321215328912000*lm)) + 
          80*(CF*(79015699060189006765417978123 + 233513189262892758819600*
               lm) + 429*(9*(-994802952473291790682673 + 2239999129595026800*
                 lm)*NM + 11*(3841833060*(594741853 + 477044820*lm)*NL + 
                (405178992552097117 + 1832726560577749200*lm)*NH))))*
         Log[x]^2)/6201803311704000 + (CF*NC*(3303704974059314831331*CA - 
          440*(15017322426086851333*CF - 5460*(179639076790120*NM + 
              753049323*NL)))*Log[x]^3)/24324300 - 
       (3368465799872211385820042590821587*CF^2*NC*PolyGamma[2, 1])/
        70044163138599589800 + (44404404818383549*CF*NM*NC*PolyGamma[2, 1])/
        6300 - (2907616427143951775532029779*CF*NC*NH*PolyGamma[2, 1])/
        11674027189766598300 + CA*CF*NC*
        (-10831736537058467278299651026318976757539077923675631709694649/
          146456538271765423149744010271425095235008000000 + 
         (1251588943*lm^2)/60 + (22633525222815416585561970379*Pi^2)/
          532942688678400 + (23857321249919921623052432521*Pi^3)/
          (508765223051161464960*Sqrt[3]) + (39375289823*Pi^4)/32400 + 
         lm*(1145229552224329531/15937281360 - (3941960*Pi^2)/81) - 
         (5784481715847120730156779189636091*Im[PolyLog[2, (-1)^(1/3)]])/
          (17824589589597441924873600*Sqrt[3]) + 
         (693924207*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (23857321249919921623052432521*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(13739801548449576600*Sqrt[3]) + 
         (23857321249919921623052432521*Pi*Log[3]^2)/(659510474325579676800*
           Sqrt[3]) + (3368465799872211385820042590821587*PolyGamma[2, 1])/
          140088326277199179600 - (397033926682453076041265966702450311*
           Zeta[3])/20032630657639482682800) + 
       (49629542283889432801778666957967332*CF^2*NC*Zeta[3])/
        1252039416102467667675 + (16462874484147149*CF*NM*NC*Zeta[3])/3150 - 
       (3662650748*CF*NC*NL*Zeta[3])/27 + (3195533510453256015903833021*CF*
         NC*NH*Zeta[3])/5837013594883299150 + 
       CF*Log[x]*((-4106629637065991701898532317896717*NM*NC)/
          2418842832139073340000 - (15843145724381*lm*NM*NC)/243243 - 
         11992344*lm^2*NM*NC - (34078742448418080799*NC*NL)/134853919200 - 
         (15843145724381*lm*NC*NL)/243243 - 11992344*lm^2*NC*NL - 
         (298286979729838146319716361155445416197617*NC*NH)/
          75905851100158641460562724060000 - (15843145724381*lm*NC*NH)/
          243243 - 11992344*lm^2*NC*NH + (359276887731136*NM*NC*Pi^2)/81 - 
         (203321326*NC*NL*Pi^2)/9 + (457166073257725774992256*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-2192093028224752003192181135179563671916156811209727/
            3647124333660422404897117765634880000 - (12764033452145*lm)/
            9009 - 323793288*lm^2 - (104879858375914601873*Pi^2)/1544400 + 
           (23857321249919921623052432521*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) - 95938752*Zeta[3]) + 
         CA*NC*(137005956407904836797647480981501312943461687727549/
            455890541707552800612139720704360000 + (19555759564589*lm)/
            44226 + 65957892*lm^2 + (2202478213476826892219*Pi^2)/64864800 - 
           (23857321249919921623052432521*Im[PolyLog[2, (-1)^(1/3)]])/
            (41219404645348729800*Sqrt[3]) + 47969376*Zeta[3])), 
      (10304389925020425978809426348714747939644843565643431424257239*CF^2*
         NC)/58582615308706169259897604108570038094003200000 + 
       (12344828045540247*CF^2*lm*NC)/80160080 + (684992781*CF^2*lm^2*NC)/5 + 
       (79139538505515269954904552572319537759612397*CF*NM*NC)/
        99930849907561872326127000000 + (531927647027627*CF*lm*NM*NC)/
        48096048 + (25370103*CF*lm^2*NM*NC)/5 - 
       (320551435292856188475823*CF*NC*NL)/2339805400732800 + 
       (531927647027627*CF*lm*NC*NL)/48096048 + (25370103*CF*lm^2*NC*NL)/
        5 - (21284373174618964704892985944365981293301798713132214431*CF*NC*
         NH)/3982544812230277429266165382061896415734500000 + 
       (531927647027627*CF*lm*NC*NH)/48096048 + (25370103*CF*lm^2*NC*NH)/
        5 - (77102208217391303661263290039*CF^2*NC*Pi^2)/755002142294400 - 
       312120*CF^2*lm*NC*Pi^2 - (37957589111489443157*CF*NM*NC*Pi^2)/90090 - 
       11560*CF*lm*NM*NC*Pi^2 + (289710942397*CF*NC*NL*Pi^2)/27027 - 
       11560*CF*lm*NC*NL*Pi^2 - 11560*CF*lm*NC*NH*Pi^2 + 
       (16941890821179182468458530841*CF^2*NC*Pi^3)/(127191305762790366240*
         Sqrt[3]) + (4326413392448645395985500*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) + (9097286381*CF^2*NC*Pi^4)/2700 - 
       (1032556431661423252210137368540533*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1114036849349840120304600*Sqrt[3]) - 
       (23734748658578296954636798394*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5564619627122078523*Sqrt[3]) + (1907584348*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + (16941890821179182468458530841*
         CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3434950387112394150*Sqrt[3]) + (1977788979405095038164800*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (16941890821179182468458530841*CF^2*NC*Pi*Log[3]^2)/
        (164877618581394919200*Sqrt[3]) + (123611811212818439885300*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((-55416828134618724665552588381*CF*NC)/45221482481175 + 
         CA*(4433357926361965239913365671683/7235437196988000 - 885170484*lm)*
          NC + 4345382376*CF*lm*NC - (8459607220275359992505093*NM*NC)/
          1673196525 + 160940088*lm*NM*NC + (7024715146*NC*NL)/35 + 
         160940088*lm*NC*NL + (592312376470053787*NC*NH)/16174233075 + 
         160940088*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-660317812247372007193*CA + 2080*(634895594744306878*CF + 
            31185*(85467127247335*NM + 6705837*NL)))*Log[x]^3)/4054050 - 
       (22834027656910282924966465306190941*CF^2*NC*PolyGamma[2, 1])/
        420264978831597538800 - (171559330117014746*CF*NM*NC*
         PolyGamma[2, 1])/675 + (1853528954647497684619471454*CF*NC*NH*
         PolyGamma[2, 1])/5253312235394969235 + 
       CA*CF*NC*(-52573334562736241255195976200940483747209002007136757757221/
          597781788864348665917322490903775898918400000 - 
         (279071133*lm^2)/10 + (1133855828502287267015526619*Pi^2)/
          22205945361600 - (16941890821179182468458530841*Pi^3)/
          (254382611525580732480*Sqrt[3]) - (9147225581*Pi^4)/5400 + 
         lm*(-4212622206332791/43723680 + 63580*Pi^2) + 
         (1032556431661423252210137368540533*Im[PolyLog[2, (-1)^(1/3)]])/
          (2228073698699680240609200*Sqrt[3]) - 
         (953792174*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (16941890821179182468458530841*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(6869900774224788300*Sqrt[3]) - 
         (16941890821179182468458530841*Pi*Log[3]^2)/(329755237162789838400*
           Sqrt[3]) + (22834027656910282924966465306190941*PolyGamma[2, 1])/
          840529957663195077600 - (1629029132969067414179318942874695239*
           Zeta[3])/60097891972918448048400) + 
       (1629018867827981340834784216865429749*CF^2*NC*Zeta[3])/
        30048945986459224024200 + (118403099662805708*CF*NM*NC*Zeta[3])/
        675 + 194288376*CF*NC*NL*Zeta[3] - (4353675152704488281927744132*CF*
         NC*NH*Zeta[3])/5253312235394969235 + 
       CF*Log[x]*((-4719127654825462083909056367780707*NM*NC)/
          1659014288161230000 + (4083734764442*lm*NM*NC)/45045 + 
         16604784*lm^2*NM*NC + (3905691030011207999*NC*NL)/10821610800 + 
         (4083734764442*lm*NC*NL)/45045 + 16604784*lm^2*NC*NL + 
         (542591770055837650841652047081158416443736553*NC*NH)/
          95755231162850126202499876401690000 + (4083734764442*lm*NC*NH)/
          45045 + 16604784*lm^2*NC*NH - 341868489296880*NM*NC*Pi^2 + 
         32358276*NC*NL*Pi^2 - (1977788979405095038164800*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(75527187342647903273106018722719285330158931813/
            207505936143628948844851943880000 - (2517843515581*lm)/4095 - 
           91326312*lm^2 + (440209893144563225407*Pi^2)/10810800 + 
           (16941890821179182468458530841*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) - 66419136*Zeta[3]) + 
         CF*NC*(-265493488761880470834282084709601440064730847855687/
            364712433366042240489711776563488000 + (9882656391606*lm)/5005 + 
           448329168*lm^2 - (1320630527546682955487*Pi^2)/16216200 - 
           (16941890821179182468458530841*Im[PolyLog[2, (-1)^(1/3)]])/
            (10304851161337182450*Sqrt[3]) + 132838272*Zeta[3])), 
      (45687670895458463435802351310039278243766341957828266623445447*CF^2*
         NC)/24776482038456556547889024294038080020960000000 - 
       (3580905053506506871*CF^2*lm*NC)/18036018000 - 
       (888416532*CF^2*lm^2*NC)/5 - 
       (33990307716724725648043869528010508217512837207*CF*NM*NC)/
        218548768747837814777239749000000 - (6963643216732528471*CF*lm*NM*
         NC)/486972486000 - (32904316*CF*lm^2*NM*NC)/5 + 
       (301099317411548037595946791*CF*NC*NL)/1579368645494640000 - 
       (6963643216732528471*CF*lm*NC*NL)/486972486000 - 
       (32904316*CF*lm^2*NC*NL)/5 + 
       (1808229317506121495542124843995630790527273011810981925553*CF*NC*NH)/
        250900323170507478043768419069899474191273500000 - 
       (6963643216732528471*CF*lm*NC*NH)/486972486000 - 
       (32904316*CF*lm^2*NC*NH)/5 - (1284531673518517539623625655949*CF^2*NC*
         Pi^2)/1258336903824000 + (1949016*CF^2*lm*NC*Pi^2)/5 + 
       (54412209317181846701*CF*NM*NC*Pi^2)/4054050 + 
       (649672*CF*lm*NM*NC*Pi^2)/45 - (9646691813812*CF*NC*NL*Pi^2)/
        675675 + (649672*CF*lm*NC*NL*Pi^2)/45 + (649672*CF*lm*NC*NH*Pi^2)/
        45 - (9466463714010419155852874863*CF^2*NC*Pi^3)/
        (52032806902959695280*Sqrt[3]) - (52511195989179206974491160*CF*NC*
         NH*Pi^3)/(50031545098999707*Sqrt[3]) - (6106428917*CF^2*NC*Pi^4)/
        1350 + (22666022330781088565817307472162167*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(18229693898451929241348000*Sqrt[3]) + 
       (7237258000777296189079822598798*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1252039416102467667675*Sqrt[3]) - 
       (2539940216*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (9466463714010419155852874863*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1405206976545979425*
         Sqrt[3]) - (24005118166481923188338816*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (9466463714010419155852874863*CF^2*NC*Pi*Log[3]^2)/
        (67449934874207012400*Sqrt[3]) - (1500319885405120199271176*CF*NC*NH*
         Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) - 
       (CF*NC*(-14877*CA*(129580026115255271333529281633 + 
            25742622115954691147200*lm) + 
          2*(1653*CF*(1166220655065038739590793207997 + 
              568677924925180904433600*lm) + 40040*
             (203*(-3118322229946144224707009 + 4283367653607676920*lm)*NM + 
              11*(2571072894*(38227690873 + 30744987140*lm)*NL + 
                (18436375233102301079 + 79047603062032583160*lm)*NH))))*
         Log[x]^2)/314741518068978000 + 
       (4*CF*NC*(832705925568936081790*CA - 1665421164016703802201*CF + 
          20020*(2260165890086001*NM + 3733319867*NL))*Log[x]^3)/2027025 - 
       (732968721591380239179310906488760727*CF^2*NC*PolyGamma[2, 1])/
        1260794936494792616400 + (296083913157628291*CF*NM*NC*
         PolyGamma[2, 1])/5670 - (37570791969395444584892262094*CF*NC*NH*
         PolyGamma[2, 1])/78799683530924538525 + 
       CA*CF*NC*
        (-319813762906710150998108194734810813526093198325903921666092679/
          346870748538391791670446340116533120293440000000 + 
         (180973738*lm^2)/5 + (226682064710348870915341852783*Pi^2)/
          444118907232000 + (9466463714010419155852874863*Pi^3)/
          (104065613805919390560*Sqrt[3]) + (6137613173*Pi^4)/2700 + 
         lm*(11042351432679693271/88540452000 - (3573196*Pi^2)/45) - 
         (22666022330781088565817307472162167*Im[PolyLog[2, (-1)^(1/3)]])/
          (36459387796903858482696000*Sqrt[3]) + 
         (1269970108*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (9466463714010419155852874863*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2810413953091958850*Sqrt[3]) + (9466463714010419155852874863*Pi*
           Log[3]^2)/(134899869748414024800*Sqrt[3]) + 
         (732968721591380239179310906488760727*PolyGamma[2, 1])/
          2521589872989585232800 - (8663124500382035251169726316812200159*
           Zeta[3])/36058735183751068829040) + 
       (43315664450826014924799121369123103099*CF^2*NC*Zeta[3])/
        90146837959377672072600 + (169518796928066659*CF*NM*NC*Zeta[3])/
        2835 - (35867669368*CF*NC*NL*Zeta[3])/135 + 
       (86877342761944591912165180132*CF*NC*NH*Zeta[3])/
        78799683530924538525 + CF*Log[x]*
        ((-2392619696699186254582777459670642249*NM*NC)/
          10884792744625830030000 - (81714868421218*lm*NM*NC)/675675 - 
         22139712*lm^2*NM*NC - (2153877864923604863831*NC*NL)/
          4382752374000 - (81714868421218*lm*NC*NL)/675675 - 
         22139712*lm^2*NC*NL - 
         (6586263102718859931526112404053178214069968627*NC*NH)/
          861797080465651135822498887615210000 - (81714868421218*lm*NC*NH)/
          675675 - 22139712*lm^2*NC*NH + (602710163393984*NM*NC*Pi^2)/27 - 
         (17922140588*NC*NL*Pi^2)/405 + (24005118166481923188338816*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*(-3818095945312270322188393834982306572514457031758127/
            539870378337891474409112827149900000 - (65924549076418*lm)/
            25025 - 597772224*lm^2 - (740183435897292091403*Pi^2)/900900 + 
           (9466463714010419155852874863*Im[PolyLog[2, (-1)^(1/3)]])/
            (4215620929637938275*Sqrt[3]) - 177117696*Zeta[3]) + 
         CA*NC*(1090884739589028365773274679726439802203902997138247/
            308497359050223699662350186942800000 + (50376956877809*lm)/
            61425 + 121768416*lm^2 + (6661651502892059465791*Pi^2)/16216200 - 
           (9466463714010419155852874863*Im[PolyLog[2, (-1)^(1/3)]])/
            (8431241859275876550*Sqrt[3]) + 88558848*Zeta[3])), 
      (2915744153771720190349800238120364221927077474608129430242405989*CF^2*
         NC)/1318108844445888808347696092442825857115072000000 + 
       (4734206433606036071*CF^2*lm*NC)/18036018000 + 
       (1167584922*CF^2*lm^2*NC)/5 + 
       (2064090520354875336770766670524703567705146413377*CF*NM*NC)/
        218548768747837814777239749000000 + (9179907219435939671*CF*lm*NM*
         NC)/486972486000 + (43243886*CF*lm^2*NM*NC)/5 - 
       (429849858871276366991913371*CF*NC*NL)/1579368645494640000 + 
       (9179907219435939671*CF*lm*NC*NL)/486972486000 + 
       (43243886*CF*lm^2*NC*NL)/5 - 
       (151913669892268282068721134216497216781476296776038552438494621*CF*NC*
         NH)/14949143055145176556803809945022750471264457677000000 + 
       (9179907219435939671*CF*lm*NC*NH)/486972486000 + 
       (43243886*CF*lm^2*NC*NH)/5 - (4652869481388833203135356134917*CF^2*NC*
         Pi^2)/3775010711472000 - (2503896*CF^2*lm*NC*Pi^2)/5 - 
       (19874424552666942588791*CF*NM*NC*Pi^2)/4054050 - 
       (834632*CF*lm*NM*NC*Pi^2)/45 + (13091375777972*CF*NC*NL*Pi^2)/
        675675 - (834632*CF*lm*NC*NL*Pi^2)/45 - (834632*CF*lm*NC*NH*Pi^2)/
        45 + (36180323617856924060802232157*CF^2*NC*Pi^3)/
        (143090218983139162020*Sqrt[3]) + (74037350235004472368926160*CF*NC*
         NH*Pi^3)/(50031545098999707*Sqrt[3]) + (1389579592*CF^2*NC*Pi^4)/
        225 - (348500433646266623248514722453939907*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(200526632882971221654828000*Sqrt[3]) - 
       (1442868834359154173085901772474*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (178862773728923952525*Sqrt[3]) + 
       (3424895616*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (144721294471427696243208928628*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(15457276742005773675*
         Sqrt[3]) + (33845645821716330225794816*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) + 
       (36180323617856924060802232157*CF^2*NC*Pi*Log[3]^2)/
        (185487320904069284100*Sqrt[3]) + (2115352863857270639112176*CF*NC*
         NH*Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) + 
       (CF*NC*(-13485*CA*(-5350796228038470462905591776951 + 
            1241147001934506360133440*lm) + 
          52*(8091*CF*(-342999612869356491929285469853 + 
              195285367437247504216800*lm) + 
            1540*(899*(-7972943297706871021252729513 + 42269560051352273640*
                 lm)*NM + 16657981280226*(2837375707 + 2281208860*lm)*NL + 
              (9090853229087223381629 + 38000334486165694002360*lm)*NH)))*
         Log[x]^2)/9756987060138318000 - 
       (CF*NC*(-803020467055477068529*CA + 1606030077695590982276*CF + 
          16016*(404699233175397621*NM + 5263074727*NL))*Log[x]^3)/405405 - 
       (845431662549960594506516430289967957*CF^2*NC*PolyGamma[2, 1])/
        1260794936494792616400 - (41702923619348994794*CF*NM*NC*
         PolyGamma[2, 1])/14175 + (52135501333795537678886730884*CF*NC*NH*
         PolyGamma[2, 1])/78799683530924538525 + 
       CA*CF*NC*
        (-29752484132375566375644433545538288002266757408284103240074693/
          26900180498895689966279512090669915451328000000 - 
         (237841373*lm^2)/5 + (14405168338170805837638019253*Pi^2)/
          23374679328000 - (36180323617856924060802232157*Pi^3)/
          (286180437966278324040*Sqrt[3]) - (698128324*Pi^4)/225 + 
         lm*(-14540273717183000471/88540452000 + (4590476*Pi^2)/45) + 
         (348500433646266623248514722453939907*Im[PolyLog[2, (-1)^(1/3)]])/
          (401053265765942443309656000*Sqrt[3]) - 
         (1712447808*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (72360647235713848121604464314*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(15457276742005773675*Sqrt[3]) - 
         (36180323617856924060802232157*Pi*Log[3]^2)/(370974641808138568200*
           Sqrt[3]) + (845431662549960594506516430289967957*PolyGamma[2, 1])/
          2521589872989585232800 - (57664650227809358935927246454366155733*
           Zeta[3])/180293675918755344145200) + 
       (11532918385301571481552470189697734373*CF^2*NC*Zeta[3])/
        18029367591875534414520 + (29909908337964522572*CF*NM*NC*Zeta[3])/
        14175 + (50247267608*CF*NC*NL*Zeta[3])/135 - 
       (127356689851907934929995850552*CF*NC*NH*Zeta[3])/
        78799683530924538525 + CF*Log[x]*
        ((-354471950655954223019390978983828153361*NM*NC)/
          10884792744625830030000 + (111415862729978*lm*NM*NC)/675675 + 
         30046752*lm^2*NM*NC + (3009627449816817901111*NC*NL)/
          4382752374000 + (111415862729978*lm*NC*NL)/675675 + 
         30046752*lm^2*NC*NL + 
         (8923294817129104297922630005043240812048073114347*NC*NH)/
          828186994327490741525421430998216810000 + 
         (111415862729978*lm*NC*NH)/675675 + 30046752*lm^2*NC*NH - 
         (107919794603905216*NM*NC*Pi^2)/27 + (25108610428*NC*NL*Pi^2)/
          405 - (33845645821716330225794816*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CA*NC*(17601092881639361565578109739405180128210027759161413/
            4103014875367975205509257486339240000 - (68627283556189*lm)/
            61425 - 165257136*lm^2 + (1003774860863025080498*Pi^2)/2027025 + 
           (72360647235713848121604464314*Im[PolyLog[2, (-1)^(1/3)]])/
            (46371830226017321025*Sqrt[3]) - 120187008*Zeta[3]) + 
         CF*NC*(-6400398636201179268245206083718129390015737412292387/
            746002704612359128274410452061680000 + (89986143619178*lm)/
            25025 + 811262304*lm^2 - (803019969719932007807*Pi^2)/810810 - 
           (144721294471427696243208928628*Im[PolyLog[2, (-1)^(1/3)]])/
            (46371830226017321025*Sqrt[3]) + 240374016*Zeta[3])), 
      (3160748337767625865266931207068073332348831462158915945619911676534645\
1*CF^2*NC)/1402793742859234130041830981756570756182377789440000000 - 
       (385326677908196502539*CF^2*lm*NC)/1154305152000 - 
       (23885484687*CF^2*lm^2*NC)/80 - 
       (67369873430481818352343199798839227053560264233808397*CF*NM*NC)/
        71817241882826327102007245316864000000 - 
       (749112526944448544939*CF*lm*NM*NC)/31166239104000 - 
       (884647581*CF*lm^2*NM*NC)/80 + (4694514913511468628555760573*CF*NC*
         NL)/12634949163957120000 - (749112526944448544939*CF*lm*NC*NL)/
        31166239104000 - (884647581*CF*lm^2*NC*NL)/80 + 
       (154945799600352818508090436586866678286008152601372235954611950893*CF*
         NC*NH)/11480941866351495595625326037777472361931103495936000000 - 
       (749112526944448544939*CF*lm*NC*NH)/31166239104000 - 
       (884647581*CF*lm^2*NC*NH)/80 - (243285449617658582320516671553481*
         CF^2*NC*Pi^2)/20133390461184000 + (24725973*CF^2*lm*NC*Pi^2)/40 - 
       (3305088902894912468431*CF*NM*NC*Pi^2)/16216200 + 
       (8241991*CF*lm*NM*NC*Pi^2)/360 - (3295952443585289*CF*NC*NL*Pi^2)/
        129729600 + (8241991*CF*lm*NC*NL*Pi^2)/360 + 
       (8241991*CF*lm*NC*NH*Pi^2)/360 - (9323225945689617939509072170489*
         CF^2*NC*Pi^3)/(27473322044762719107840*Sqrt[3]) - 
       (1180045851259100948672643695*CF*NC*NH*Pi^3)/(600378541187996484*
         Sqrt[3]) - (176161405727*CF^2*NC*Pi^4)/21600 + 
       (22119601888404549166295593326197189491*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(9625278378382618639431744000*Sqrt[3]) + 
       (323423826297210824782502443369547*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(30048945986459224024200*Sqrt[3]) - 
       (8978908717*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (9323225945689617939509072170489*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(741949283616277136400*
         Sqrt[3]) - (134862383001040108419730708*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (9323225945689617939509072170489*CF^2*NC*Pi*Log[3]^2)/
        (35613565613581302547200*Sqrt[3]) - (33715595750260027104932677*CF*NC*
         NH*Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) - 
       (CF*NC*(-31*CA*(730221346173217765484265876539561519 + 
            23338239027018490317155212800*lm) + 
          26*(31*CF*(56170876046097868997146197668813381 + 
              4406520655451043626316019200*lm) + 
            3080*(4123*(2312830395553836671169887537 + 398409502783929848640*
                 lm)*NM + 133263850241808*(15291048253 + 12326241340*lm)*
               NL + (401781047876548075965373 + 1642642379978142765942720*
                 lm)*NH)))*Log[x]^2)/312223585924426176000 + 
       (CF*NC*(634678558987212910428895*CA - 1672*(759185598703746756349*CF + 
            1820*(2047165481784753*NM - 2993515754*NL)))*Log[x]^3)/
        32432400 - (654858745594983251870614135033896877*CF^2*NC*
         PolyGamma[2, 1])/94559620237109446230 + 
       (34572771185049248287*CF*NM*NC*PolyGamma[2, 1])/113400 - 
       (665788210869029578962107798647*CF*NC*NH*PolyGamma[2, 1])/
        756476961896875569840 + CA*CF*NC*
        (-2674479449082894556645026730306334323035541446361020258797854383648\
1397/2373958641761780835455406276818812048924023951360000000 + 
         (9731123391*lm^2)/160 + (2259617186167848686979463801897*Pi^2)/
          373994869248000 + (9323225945689617939509072170489*Pi^3)/
          (54946644089525438215680*Sqrt[3]) + (176952636863*Pi^4)/43200 + 
         lm*(1187744268366149572139/5666588928000 - (90661901*Pi^2)/720) - 
         (22119601888404549166295593326197189491*Im[PolyLog[2, (-1)^(1/3)]])/
          (19250556756765237278863488000*Sqrt[3]) + 
         (8978908717*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (9323225945689617939509072170489*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1483898567232554272800*Sqrt[3]) + 
         (9323225945689617939509072170489*Pi*Log[3]^2)/
          (71227131227162605094400*Sqrt[3]) + 
         (654858745594983251870614135033896877*PolyGamma[2, 1])/
          189119240474218892460 - (883733500903418813984835928591273984051*
           Zeta[3])/309074873003580589963200) + 
       (6186135443936117321594710527120719212249*CF^2*NC*Zeta[3])/
        1081762055512532064871200 + (40018391009675153197*CF*NM*NC*Zeta[3])/
        56700 - (135123412051*CF*NC*NL*Zeta[3])/270 + 
       (802499781532065208970732507969*CF*NC*NH*Zeta[3])/
        378238480948437784920 + CF*Log[x]*
        ((-6375812688287236903597964201859606158377*NM*NC)/
          1401586327001771951040000 - (4681689142256471*lm*NM*NC)/21621600 - 
         39436362*lm^2*NM*NC - (16125437467139419352509*NC*NL)/
          17531009496000 - (4681689142256471*lm*NC*NL)/21621600 - 
         39436362*lm^2*NC*NL - 
         (1137877537204776972145470928814865934848270610283797*NC*NH)/
          79505951455439111186440457375828813760000 - 
         (4681689142256471*lm*NC*NH)/21621600 - 39436362*lm^2*NC*NH - 
         (2593078764115339*NM*NC*Pi^2)/54 - (33762308533*NC*NL*Pi^2)/405 + 
         (134862383001040108419730708*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CF*NC*(-4855642159172446938303542690395214715511594503427178193449/
            59153751603162293962856323645908014400000 - (3781640939602871*lm)/
            800800 - 1064781774*lm^2 - (60445582184612327585809*Pi^2)/
            6177600 + (9323225945689617939509072170489*
             Im[PolyLog[2, (-1)^(1/3)]])/(2225847850848831409200*Sqrt[3]) - 
           315490896*Zeta[3]) + CA*NC*
          (38845138311520295849900257790995968156222159526303774763557/
            946460025650596703405701178334528230400000 + 
           (5766914726317271*lm)/3931200 + 216899991*lm^2 + 
           (1269357243308089082383541*Pi^2)/259459200 - 
           (9323225945689617939509072170489*Im[PolyLog[2, (-1)^(1/3)]])/
            (4451695701697662818400*Sqrt[3]) + 157745448*Zeta[3])), 
      (9435613175613595117269890475207829913729111046604292204568644901877209\
959*CF^2*NC)/347191451357660447185353167984751262155138502886400000000 + 
       (5011367267592510509*CF^2*lm*NC)/11543051520 + 
       (7725210057*CF^2*lm^2*NC)/20 + 
       (3445895777426351846260420198701412710936553550589169447*CF*NM*NC)/
        31011990813038641248594037750464000000 + 
       (1943538706921107433*CF*lm*NM*NC)/62332478208 + 
       (286118891*CF*lm^2*NM*NC)/20 - (7492626320739277499497277*CF*NC*NL)/
        14439941901665280 + (1943538706921107433*CF*lm*NC*NL)/62332478208 + 
       (286118891*CF*lm^2*NC*NL)/20 - 
       (96380617057346145472957899997313469725053657406754864034278332231*CF*
         NC*NH)/5166423839858173018031396716999862562868996573171200000 + 
       (1943538706921107433*CF*lm*NC*NH)/62332478208 + 
       (286118891*CF*lm^2*NC*NH)/20 - (4064280582019128844097222412530731*
         CF^2*NC*Pi^2)/277840788364339200 - (1564935*CF^2*lm*NC*Pi^2)/2 - 
       (2903607612678422268689*CF*NM*NC*Pi^2)/51480 - 
       (521645*CF*lm*NM*NC*Pi^2)/18 + (43946128286821*CF*NC*NL*Pi^2)/
        1297296 - (521645*CF*lm*NC*NL*Pi^2)/18 - (521645*CF*lm*NC*NH*Pi^2)/
        18 + (8800402395041112109382806412963*CF^2*NC*Pi^3)/
        (19019992184835728613120*Sqrt[3]) + (3669721822404560083056691180*CF*
         NC*NH*Pi^3)/(1350851717672992089*Sqrt[3]) + 
       (78705901283*CF^2*NC*Pi^4)/7200 - 
       (21002278447981500192519571813864477217*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(6663654261957197519606592000*Sqrt[3]) - 
       (99737263339418722558650711591082*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(6761012846953325405445*Sqrt[3]) + 
       (11903648523*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
       (8800402395041112109382806412963*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(513657196349730325200*
         Sqrt[3]) + (1677587118813513180825915968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) + 
       (8800402395041112109382806412963*CF^2*NC*Pi*Log[3]^2)/
        (24655545424787055609600*Sqrt[3]) + (104849194925844573801619748*CF*
         NC*NH*Pi*Log[3]^2)/(50031545098999707*Sqrt[3]) + 
       CF*((-4419904362301440749400341471502297473*CF*NC)/
          25179321445518240000 + CA*(4419904657339228041609326525965296713/
            50358642891036480000 - (86429155252*lm)/27)*NC + 
         15714391864*CF*lm*NC - (21281419420332499680358561984693*NM*NC)/
          31442709097800 + (15714391864*lm*NM*NC)/27 + (75838474274*NC*NL)/
          105 + (15714391864*lm*NC*NL)/27 + (28385516484510448517123*NC*NH)/
          194944796406360 + (15714391864*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-191885607874714240471829*CA + 4*(95942696788023324586117*CF + 
            200200*(1870973043126380937*NM + 3928597966*NL)))*Log[x]^3)/
        8108100 - (1103229405492437219774373468188296301837*CF^2*NC*
         PolyGamma[2, 1])/136165853141437602571200 - 
       (38292491349371491819*CF*NM*NC*PolyGamma[2, 1])/1134 + 
       (364457561886377118764237565896*CF*NC*NH*PolyGamma[2, 1])/
        303941636476423220025 + CA*CF*NC*
        (-9435612828623623843446926375883822892315066694473217063876570261781\
420959/694382902715320894370706335969502524310277005772800000000 - 
         (3147307801*lm^2)/40 + (2735415646798964192162441155691*Pi^2)/
          373994869248000 - (8800402395041112109382806412963*Pi^3)/
          (38039984369671457226240*Sqrt[3]) - (79039754083*Pi^4)/14400 + 
         lm*(-15392307024018373133/56665889280 + (5738095*Pi^2)/36) + 
         (21002278447981500192519571813864477217*Im[PolyLog[2, (-1)^(1/3)]])/
          (13327308523914395039213184000*Sqrt[3]) - 
         (11903648523*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 - 
         (8800402395041112109382806412963*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1027314392699460650400*Sqrt[3]) - 
         (8800402395041112109382806412963*Pi*Log[3]^2)/
          (49311090849574111219200*Sqrt[3]) + 
         (1103229405492437219774373468188296301837*PolyGamma[2, 1])/
          272331706282875205142400 - (454038483698079119656392537992467375703*
           Zeta[3])/121698231245159857298010) + 
       (2270192058669090387471340205376470694631*CF^2*NC*Zeta[3])/
        304245578112899643245025 + (14094751633352222939*CF*NM*NC*Zeta[3])/
        567 + (18563199538*CF*NC*NL*Zeta[3])/27 - 
       (920078178454600824932699363108*CF*NC*NH*Zeta[3])/
        303941636476423220025 + CF*Log[x]*
        ((-2078208433566028722755262301917348145458241*NM*NC)/
          5633298891218660341680000 + (20894030846323*lm*NM*NC)/72072 + 
         52581816*lm^2*NM*NC + (2210112487215688117627*NC*NL)/
          1753100949600 + (20894030846323*lm*NC*NL)/72072 + 
         52581816*lm^2*NC*NL + 
         (707655096026027315446654615562815361427179403823399*NC*NH)/
          35777678154947600033898205819122966192000 + 
         (20894030846323*lm*NC*NH)/72072 + 52581816*lm^2*NC*NH - 
         (1247315360593938418*NM*NC*Pi^2)/27 + (9276904964*NC*NL*Pi^2)/81 - 
         (1677587118813513180825915968*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CA*NC*(1485649003014720584401067321281454867296340202768261590158300\
7/298134908079937961572795871175376392576000000 - (25717255664371*lm)/13104 - 
           289199988*lm^2 + (1535084689723015408638211*Pi^2)/259459200 + 
           (8800402395041112109382806412963*Im[PolyLog[2, (-1)^(1/3)]])/
            (3081943178098381951200*Sqrt[3]) - 210327264*Zeta[3]) + 
         CF*NC*(-135059004296947462151927604896660195828088022537973270596533\
7/13551586730906270980581630507971654208000000 + (50681449836921*lm)/8008 + 
           1419709032*lm^2 - (1535084713618255571269763*Pi^2)/129729600 - 
           (8800402395041112109382806412963*Im[PolyLog[2, (-1)^(1/3)]])/
            (1540971589049190975600*Sqrt[3]) + 420654528*Zeta[3])), 
      (1585246149867650867214868859029875858914814900743595173083467620793755\
7122536807*CF^2*NC)/
        58611356321911020165226851955457774154894476457102873600000000 - 
       (363888755366343839945*CF^2*lm*NC)/667188377856 - 
       (4875853131*CF^2*lm^2*NC)/10 - 
       (17173670047758595319185581036951105599479447790754462123067*CF*NM*
         NC)/10162660401423575775805514764864803264000000 - 
       (3536364284653490996269*CF*lm*NM*NC)/90070431010560 - 
       (180587153*CF*lm^2*NM*NC)/10 + (101718171802225950344926193189*CF*NC*
         NL)/146060012335344307200 - (3536364284653490996269*CF*lm*NC*NL)/
        90070431010560 - (180587153*CF*lm^2*NC*NL)/10 + 
       (631242874203156435504546149731965742681659850819414159797800120873*CF*
         NC*NH)/25832119199290865090156983584999312814344982865856000000 - 
       (3536364284653490996269*CF*lm*NC*NH)/90070431010560 - 
       (180587153*CF*lm^2*NC*NH)/10 - (74040846552747461679553627425527029*
         CF^2*NC*Pi^2)/524810378021529600 + (1911495*CF^2*lm*NC*Pi^2)/2 - 
       (331510751395670163923327*CF*NM*NC*Pi^2)/55135080 + 
       (637165*CF*lm*NM*NC*Pi^2)/18 - (138003488360407*CF*NC*NL*Pi^2)/
        3150576 + (637165*CF*lm*NC*NL*Pi^2)/18 + (637165*CF*lm*NC*NH*Pi^2)/
        18 - (856595110964188578036665323675613*CF^2*NC*Pi^3)/
        (1401139424282898674499840*Sqrt[3]) - 
       (4807596558372070253851571210*CF*NC*NH*Pi^3)/(1350851717672992089*
         Sqrt[3]) - (307252227017*CF^2*NC*Pi^4)/21600 + 
       (4903943702240123077092520308572675197897*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1192159479151104337198188864000*
         Sqrt[3]) + (10093675860770601708048062878733*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(520077911304101954265*Sqrt[3]) - 
       (15386586859*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (122370730137741225433809331953659*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5405630494918590565200*
         Sqrt[3]) - (2197758426684374973189289696*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (122370730137741225433809331953659*CF^2*NC*Pi*Log[3]^2)/
        (259470263756092347129600*Sqrt[3]) - (137359901667773435824330606*CF*
         NC*NH*Pi*Log[3]^2)/(50031545098999707*Sqrt[3]) - 
       (CF*NC*(-219*CA*(102579537388802671353119554087191531883 + 
            515883283491883599671258880000*lm) + 
          14*(CF*(3209274127719042341177830400611242627831 + 
              39615816302435165257872126720000*lm) + 
            1944800*((70328688258281160230814415812037 + 
                754449020796866958763200*lm)*NM + 666319251209040*(
                1401821419 + 1132263580*lm)*NL + (192566082102544861090613 + 
                754449020796866958763200*lm)*NH)))*Log[x]^2)/
        26539004803576224960000 + (CF*NC*(31667533335085942785702971*CA - 
          68*(931398185217443945329299*CF + 200200*(150206522635560807*NM - 
              5224587662*NL)))*Log[x]^3)/137837700 - 
       (3693757475680812646000593424812392807593*CF^2*NC*PolyGamma[2, 1])/
        45388617713812534190400 + (29573477129528956837*CF*NM*NC*
         PolyGamma[2, 1])/56700 - (26768298507452947517670097518629*CF*NC*NH*
         PolyGamma[2, 1])/17020731642679700321400 + 
       CA*CF*NC*(-15852461576703172355611415595988080491125638772131023787380\
108413522272646669807/
          117222712643822040330453703910915548309788952914205747200000000 + 
         (1986458683*lm^2)/20 + (7624343470065857405874549904663213*Pi^2)/
          108084517212672000 + (856595110964188578036665323675613*Pi^3)/
          (2802278848565797348999680*Sqrt[3]) + (308475583817*Pi^4)/43200 + 
         lm*(5606526810830938329901/16376442001920 - (7008815*Pi^2)/36) - 
         (4903943702240123077092520308572675197897*
           Im[PolyLog[2, (-1)^(1/3)]])/(2384318958302208674396377728000*
           Sqrt[3]) + (15386586859*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (122370730137741225433809331953659*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(10811260989837181130400*Sqrt[3]) + 
         (122370730137741225433809331953659*Pi*Log[3]^2)/
          (518940527512184694259200*Sqrt[3]) + 
         (3693757475680812646000593424812392807593*PolyGamma[2, 1])/
          90777235427625068380800 - (9238702163443112300609730402282399673763*
           Zeta[3])/275849324155695676542156) + 
       (230967559471764415687535782030894028133431*CF^2*NC*Zeta[3])/
        3448116551946195956776950 + (239862755971188117337*CF*NM*NC*Zeta[3])/
        28350 - (24584360642*CF*NC*NL*Zeta[3])/27 + 
       (33406970059912789899785346546571*CF*NC*NH*Zeta[3])/
        8510365821339850160700 + CF*Log[x]*
        ((-5072311947476436923826393180199049095025950507*NM*NC)/
          70376803047994723648608240000 - (2299389643609391*lm*NM*NC)/
          6126120 - 68047056*lm^2*NM*NC - (49589973150057383270641*NC*NL)/
          29802716143200 - (2299389643609391*lm*NC*NL)/6126120 - 
         68047056*lm^2*NC*NL - 
         (4635651803243708544094484039043691226215106077916617*NC*NH)/
          178888390774738000169491029095614830960000 - 
         (2299389643609391*lm*NC*NH)/6126120 - 68047056*lm^2*NC*NH - 
         (100137683761187062*NM*NC*Pi^2)/27 - (12286445836*NC*NL*Pi^2)/81 + 
         (2197758426684374973189289696*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CF*NC*
          (-76388632604221577939567114418089634683067849638530017161876651733\
1/811771665550324413035794357898687354252352000000 - (5578098233602893*lm)/
            680680 - 1837270512*lm^2 - (84446756689741908574417559*Pi^2)/
            735134400 + (122370730137741225433809331953659*
             Im[PolyLog[2, (-1)^(1/3)]])/(16216891484755771695600*Sqrt[3]) - 
           544376448*Zeta[3]) + CA*NC*
          (763886329214667051859670775684515794989964344975534129508794625231/
            1623543331100648826071588715797374708504704000000 + 
           (2829944373594671*lm)/1113840 + 374258808*lm^2 + 
           (253340270607207213311171909*Pi^2)/4410806400 - 
           (122370730137741225433809331953659*Im[PolyLog[2, (-1)^(1/3)]])/
            (32433782969511543391200*Sqrt[3]) + 272188224*Zeta[3])), 
      (8505491616462740490668891324563319227423956981272975915095631462804759\
29769261*CF^2*NC)/
        2598533038902459022103653534971034322138178759181900800000000 + 
       (5288048286763752909*CF^2*lm*NC)/7564494080 + 
       (3110068143*CF^2*lm^2*NC)/5 + 
       (69410125188156618187728500452110240694245487398978674647813*CF*NM*
         NC)/53770689954622094051881030501930176000000 + 
       (1139407524537061157*CF*lm*NM*NC)/22693482240 + 
       (115187709*CF*lm^2*NM*NC)/5 - (1474326695190842760570657859*CF*NC*
         NL)/1545608596141209600 + (1139407524537061157*CF*lm*NC*NL)/
        22693482240 + (115187709*CF*lm^2*NC*NL)/5 - 
       (514345237895932670074527665710535451017326253964161713881438161171*CF*
         NC*NH)/15499271519574519054094190150999587688606989719513600000 + 
       (1139407524537061157*CF*lm*NC*NH)/22693482240 + 
       (115187709*CF*lm^2*NC*NH)/5 - (16487910998435756074777781700633169*
         CF^2*NC*Pi^2)/96393742901913600 - (2388015*CF^2*lm*NC*Pi^2)/2 - 
       (210737758177714346110567*CF*NM*NC*Pi^2)/328185 - 
       (88445*CF*lm*NM*NC*Pi^2)/2 + (60378576615397*CF*NC*NL*Pi^2)/
        1050192 - (88445*CF*lm*NC*NL*Pi^2)/2 - (88445*CF*lm*NC*NH*Pi^2)/2 + 
       (10333792468592826112182295518158143*CF^2*NC*Pi^3)/
        (12610254818546088070498560*Sqrt[3]) + 
       (78336428389344930496716733345*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) + (405128963323*CF^2*NC*Pi^4)/21600 - 
       (8501976384792115309269941987500548013421*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1532776473194277004969099968000*
         Sqrt[3]) - (1061688438449189535368956112943029*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40566077081719952432670*Sqrt[3]) + 
       (20092181921*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
       (1476256066941832301740327931165449*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(48650674454267315086800*
         Sqrt[3]) + (8952734673067992056767626668*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) + 
       (1476256066941832301740327931165449*CF^2*NC*Pi*Log[3]^2)/
        (2335232373804831124166400*Sqrt[3]) + 
       (2238183668266998014191906667*CF*NC*NH*Pi*Log[3]^2)/
        (600378541187996484*Sqrt[3]) + 
       CF*((-134170372144956290021131507509881461399*CF*NC)/
          65367006905360160000 + CA*(134170373529412837858968865971822078919/
            130734013810720320000 - 5775891814*lm)*NC + 
         28354377996*CF*lm*NC - (39739712575069940231565090252947*NM*NC)/
          5157269746200 + 1050162148*lm*NM*NC + (11706030986*NC*NL)/9 + 
         1050162148*lm*NC*NL + (658282865835457911067*NC*NH)/
          2406725881560 + 1050162148*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-5481609756159014279062723*CA + 
          4*(2740804382884364660072659*CF + 1562160600*
             (6657959795650815*NM + 2206223*NL)))*Log[x]^3)/19691100 - 
       (4364030453986155017946679683307354639877*CF^2*NC*PolyGamma[2, 1])/
        45388617713812534190400 - (259375210930579157303*CF*NM*NC*
         PolyGamma[2, 1])/675 + (498287208681972686782621078979*CF*NC*NH*
         PolyGamma[2, 1])/236399050592773615575 + 
       CA*CF*NC*(-85054915697311468680894567623661761473266976226079043000500\
0765087483750765761/
          5197066077804918044207307069942068644276357518363801600000000 - 
         (1267064799*lm^2)/10 + (30372467613425466965501374146843457*Pi^2)/
          355134842270208000 - (10333792468592826112182295518158143*Pi^3)/
          (25220509637092176140997120*Sqrt[3]) - (406657292923*Pi^4)/43200 + 
         lm*(-360958389265263265/825217536 + (972895*Pi^2)/4) + 
         (8501976384792115309269941987500548013421*
           Im[PolyLog[2, (-1)^(1/3)]])/(3065552946388554009938199936000*
           Sqrt[3]) - (20092181921*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 - 
         (1476256066941832301740327931165449*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(97301348908534630173600*
           Sqrt[3]) - (1476256066941832301740327931165449*Pi*Log[3]^2)/
          (4670464747609662248332800*Sqrt[3]) + 
         (4364030453986155017946679683307354639877*PolyGamma[2, 1])/
          90777235427625068380800 - 
         (148413508534011147057403380007611511625783*Zeta[3])/
          3448116551946195956776950) + 
       (593654019678469527145736941177906579727279*CF^2*NC*Zeta[3])/
        6896233103892391913553900 + (194317067462125326794*CF*NM*NC*Zeta[3])/
        675 + 1229316340*CF*NC*NL*Zeta[3] - (1293633386090462520582185358242*
         CF*NC*NH*Zeta[3])/236399050592773615575 + 
       CF*Log[x]*((-70048443119365654439954602246702991446995491*NM*NC)/
          16925638058680789718280000 + (432744275567089*lm*NM*NC)/875160 + 
         89311761*lm^2*NM*NC + (8079601436271940847*NC*NL)/3604258944 + 
         (432744275567089*lm*NC*NL)/875160 + 89311761*lm^2*NC*NL + 
         (472049262187877511013425003996743686872173938321073*NC*NH)/
          13416629308105350012711827182171112322000 + 
         (432744275567089*lm*NC*NH)/875160 + 89311761*lm^2*NC*NH - 
         528198143701441675*NM*NC*Pi^2 + (614392835*NC*NL*Pi^2)/3 - 
         (8952734673067992056767626668*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CA*NC*
          (41130085125663221141718240307001145117323699498692483129684735913/
            71979753595595268150957135183134839293312000000 - 
           (532223287439329*lm)/159120 - (982429371*lm^2)/2 + 
           (14617625762593577500789789*Pi^2)/210038400 + 
           (1476256066941832301740327931165449*Im[PolyLog[2, (-1)^(1/3)]])/
            (291904046725603890520800*Sqrt[3]) - 357247044*Zeta[3]) + 
         CF*NC*
          (-3739098664814116369729862904496460496034205651995813957788038383/
            3271806981617966734134415235597038149696000000 + 
           (1050719570971527*lm)/97240 + 2411417547*lm^2 - 
           (43852877391342490726998071*Pi^2)/315057600 - 
           (1476256066941832301740327931165449*Im[PolyLog[2, (-1)^(1/3)]])/
            (145952023362801945260400*Sqrt[3]) + 714494088*Zeta[3])), 
      (6501969528836853366954191817282506337174165477173664006915456488378277\
086939812801*CF^2*NC)/
        2034651369460625414307160717882319874234193968439428326400000000 - 
       (266093876035480573469*CF^2*lm*NC)/306362010240 - 
       (31047543009*CF^2*lm^2*NC)/40 + 
       (72907621786991283222949386654465885728380037293138006017983*CF*NM*
         NC)/967872419183197692933858549034743168000000 - 
       (517099384501802614901*CF*lm*NM*NC)/8271774276480 - 
       (3449727001*CF*lm^2*NM*NC)/120 + (105240867828298676709361095689*CF*
         NC*NL)/83462864191625318400 - (517099384501802614901*CF*lm*NC*NL)/
        8271774276480 - (3449727001*CF*lm^2*NC*NL)/120 + 
       (97071288389323731340541022227745994951891213923872281138221469*CF*NC*
         NH)/2261206363169036575235482529952201024979203609600000 - 
       (517099384501802614901*CF*lm*NC*NH)/8271774276480 - 
       (3449727001*CF*lm^2*NC*NH)/120 - 
       (126646817725827029933420461119619949*CF^2*NC*Pi^2)/
        77856484651545600 + (4333805*CF^2*lm*NC*Pi^2)/3 - 
       (499426070667222048299291*CF*NM*NC*Pi^2)/4725864 + 
       (4333805*CF*lm*NM*NC*Pi^2)/81 - (86731505447705*CF*NC*NL*Pi^2)/
        1181466 + (4333805*CF*lm*NC*NL*Pi^2)/81 + 
       (4333805*CF*lm*NC*NH*Pi^2)/81 - (16523700685013942848110622116781289*
         CF^2*NC*Pi^3)/(15476221822761108086520960*Sqrt[3]) - 
       (2736551615851261636270048465595*CF*NC*NH*Pi^3)/
        (437675956526049436836*Sqrt[3]) - (780379490611*CF^2*NC*Pi^4)/32400 + 
       (94197258111833430375308335530911396942311*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(13167943337896288815416358816000*
         Sqrt[3]) + (5319505195452477923960787855436927*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(156469154458062673668870*Sqrt[3]) - 
       (38468003497*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (2360528669287706121158660302397327*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59707645921146250333800*
         Sqrt[3]) - (312748756097287044145148396068*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (2360528669287706121158660302397327*CF^2*NC*Pi*Log[3]^2)/
        (2865967004215020016022400*Sqrt[3]) - 
       (78187189024321761036287099017*CF*NC*NH*Pi*Log[3]^2)/
        (16210220612075905068*Sqrt[3]) + 
       CF*((-55504551158927204660426989776534347742313*CF*NC)/
          2843464800383166960000 - 37180575866*CF*lm*NC + 
         CA*(55504551080260770578415296585121907932703/
            5686929600766333920000 + (204493167263*lm)/27)*NC - 
         (117723614933088065436670341834547*NM*NC)/92830855431600 - 
         (37180575866*lm*NM*NC)/27 - (45952654117*NC*NL)/27 - 
         (37180575866*lm*NC*NL)/27 - (44209543328101973*NC*NH)/121041360 - 
         (37180575866*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-13106411461269267556250439*CA + 26212823586911331192164623*
           CF + 1701700*(861742945283344449*NM - 2655755419*NL))*Log[x]^3)/
        4922775 - (743971065203597667084940389718320322529119*CF^2*NC*
         PolyGamma[2, 1])/787816721746888986304800 - 
       (1782631489012659209431*CF*NM*NC*PolyGamma[2, 1])/75600 - 
       (7525787561882678203955571773283913*CF*NC*NH*PolyGamma[2, 1])/
        2757358526114111452066800 + CA*CF*NC*
        (-6501969533642802993305508000153895612723601768824744488775949557707\
808324935403051/
          4069302738921250828614321435764639748468387936878856652800000000 + 
         (37946997011*lm^2)/240 + (33328109930106614752854750549863947*Pi^2)/
          40977097185024000 + (16523700685013942848110622116781289*Pi^3)/
          (30952443645522216173041920*Sqrt[3]) + (87017013979*Pi^4)/7200 + 
         lm*(819747174614305746197/1503958959360 - (47671855*Pi^2)/162) - 
         (94197258111833430375308335530911396942311*
           Im[PolyLog[2, (-1)^(1/3)]])/(26335886675792577630832717632000*
           Sqrt[3]) + (38468003497*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (2360528669287706121158660302397327*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(119415291842292500667600*
           Sqrt[3]) + (2360528669287706121158660302397327*Pi*Log[3]^2)/
          (5731934008430040032044800*Sqrt[3]) + 
         (743971065203597667084940389718320322529119*PolyGamma[2, 1])/
          1575633443493777972609600 - 
         (185225051188868653003756672186487974041486827*Zeta[3])/
          478795612641671781426742200) + 
       (370450103685914902164327644841899182486821961*CF^2*NC*Zeta[3])/
        478795612641671781426742200 + (3847422770217202003769*CF*NM*NC*
         Zeta[3])/37800 - (43360422595*CF*NC*NL*Zeta[3])/27 + 
       (9673244948952005264997681186819287*CF*NC*NH*Zeta[3])/
        1378679263057055726033400 + CF*Log[x]*
        ((-6804959102861394915629648800368712240221825457*NM*NC)/
          6702552671237592728438880000 - (622339928863957*lm*NM*NC)/984555 - 
         (228241167*lm^2*NM*NC)/2 - (3977598002900413855585*NC*NL)/
          1362409880832 - (622339928863957*lm*NC*NL)/984555 - 
         (228241167*lm^2*NC*NL)/2 - 
         (86255225826197505563599028555353387938653175470111*NC*NH)/
          1894731566231288396695491775971860256000 - 
         (622339928863957*lm*NC*NH)/984555 - (228241167*lm^2*NC*NH)/2 - 
         (2010733542101518493*NM*NC*Pi^2)/27 - (43343087375*NC*NL*Pi^2)/
          162 + (312748756097287044145148396068*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CF*NC*
          (-44466810150719845506290030849950583805681776795209825007728262338\
3/41686499308691638285650471041711966839248000000 - (2014959308640493*lm)/
            145860 - (6162511509*lm^2)/2 - (209702583812958397895830201*Pi^2)/
            157528800 + (2360528669287706121158660302397327*
             Im[PolyLog[2, (-1)^(1/3)]])/(179122937763438751001400*Sqrt[3]) - 
           912964668*Zeta[3]) + CA*NC*(37574454601168863846373695726819828815\
000979084911501269113824687201/
            7045018383168886870274929606049322395832912000000 + 
           (382670504215151*lm)/89505 + (2510652837*lm^2)/4 + 
           (209702583880606336896493937*Pi^2)/315057600 - 
           (2360528669287706121158660302397327*Im[PolyLog[2, (-1)^(1/3)]])/
            (358245875526877502002800*Sqrt[3]) + 456482334*Zeta[3])), 
      (4875763520702897561586567632623072828227853584785950496321538924430618\
051292359*CF^2*NC)/
        1258287798058519118309932416748497139291400104167859200000000 + 
       (5564316477637076909*CF^2*lm*NC)/5063834880 + 
       (9778248711*CF^2*lm^2*NC)/10 + 
       (7172838729471411127695725645335124434349564718671692926881761*CF*NM*
         NC)/483936209591598846466929274517371584000000 + 
       (10790945926934076653*CF*lm*NM*NC)/136723541760 + 
       (1086472079*CF*lm^2*NM*NC)/30 - (46320261732906938767012396601*CF*NC*
         NL)/27285936370339046400 + (10790945926934076653*CF*lm*NC*NL)/
        136723541760 + (1086472079*CF*lm^2*NC*NL)/30 - 
       (202717473144441896062364038228228544668804030337374787225127940828064\
8547*CF*NC*NH)/
        35328807012645365114116485617336195183595443261813507136000000 + 
       (10790945926934076653*CF*lm*NC*NH)/136723541760 + 
       (1086472079*CF*lm^2*NC*NH)/30 - (51887051294866436486573435269175869*
         CF^2*NC*Pi^2)/26289202609612800 - (10701845*CF^2*lm*NC*Pi^2)/6 - 
       (171057576939410179802550139*CF*NM*NC*Pi^2)/23629320 - 
       (10701845*CF*lm*NM*NC*Pi^2)/162 + (81634243292635*CF*NC*NL*Pi^2)/
        859248 - (10701845*CF*lm*NC*NL*Pi^2)/162 - 
       (10701845*CF*lm*NC*NH*Pi^2)/162 + 
       (14542408058563354031201496321279217*CF^2*NC*Pi^3)/
        (10317481215174072057680640*Sqrt[3]) + 
       (609551918745517080644168422075*CF*NC*NH*Pi^3)/(72945992754341572806*
         Sqrt[3]) + (2028041151829*CF^2*NC*Pi^4)/64800 - 
       (83399902145924815088539390375013599308413*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8778628891930859210277572544000*
         Sqrt[3]) - (2156948208835532200048523131807289*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(47743152257716559401527*Sqrt[3]) + 
       (33036510661*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
       (2077486865509050575885928045897031*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(39805097280764166889200*
         Sqrt[3]) + (139326152856118189861524210760*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) + (2077486865509050575885928045897031*CF^2*NC*Pi*Log[3]^2)/
        (1910644669476680010681600*Sqrt[3]) + 
       (17415769107014773732690526345*CF*NC*NH*Pi*Log[3]^2)/
        (2701703435345984178*Sqrt[3]) + 
       CF*((-12244695467596041626851438732759114442023*CF*NC)/
          516993600069666720000 + 
         CA*(1749242212399583832327645963329005597009/147712457162761920000 - 
           (273018682783*lm)/27)*NC + 49639760506*CF*lm*NC - 
         (237184210044378902282315997431497*NM*NC)/2730319277400 + 
         (49639760506*lm*NM*NC)/27 + (61375000933*NC*NL)/27 + 
         (49639760506*lm*NC*NL)/27 + (663327355258412645458187*NC*NH)/
          1335732864265800 + (49639760506*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-5781023650289460666934093*CA + 
          52*(222347057095790652440603*CF + 11900*(69181763278937221968*NM + 
              3545697179*NL)))*Log[x]^3)/1790100 - 
       (4129946193015475286364098729312043924841297*CF^2*NC*PolyGamma[2, 1])/
        3676478034818815269422400 - (20486340305129583387668*CF*NM*NC*
         PolyGamma[2, 1])/4725 + (207058399119821760465464088404734*CF*NC*NH*
         PolyGamma[2, 1])/57444969294043988584725 + 
       CA*CF*NC*(-23891241232066010144571204875297051804829534110816599901618\
2312435282316194347091/
          123312204209734873594373376841352719650557210208450201600000000 - 
         (11951192869*lm^2)/60 + (95581410273102942544168562760739181*Pi^2)/
          96854956982784000 - (14542408058563354031201496321279217*Pi^3)/
          (20634962430348144115361280*Sqrt[3]) - (678296777543*Pi^4)/43200 + 
         lm*(-37604403367916483747/54689416704 + (117720295*Pi^2)/324) + 
         (83399902145924815088539390375013599308413*
           Im[PolyLog[2, (-1)^(1/3)]])/(17557257783861718420555145088000*
           Sqrt[3]) - (33036510661*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 - 
         (2077486865509050575885928045897031*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(79610194561528333778400*
           Sqrt[3]) - (2077486865509050575885928045897031*Pi*Log[3]^2)/
          (3821289338953360021363200*Sqrt[3]) + 
         (4129946193015475286364098729312043924841297*PolyGamma[2, 1])/
          7352956069637630538844800 - 
         (24952828016727508107501782686854776767053601*Zeta[3])/
          50781352855934885908896900) + 
       (49905655849964902431294786075985299645672239*CF^2*NC*Zeta[3])/
        50781352855934885908896900 + (15525759342044040543614*CF*NM*NC*
         Zeta[3])/4725 + (57636179090*CF*NC*NL*Zeta[3])/27 - 
       (550658113696770670282544195321932*CF*NC*NH*Zeta[3])/
        57444969294043988584725 + CF*Log[x]*
        ((-154195123095511571272718080946058704062791075419*NM*NC)/
          3351276335618796364219440000 + (587703821805551*lm*NM*NC)/716040 + 
         147685461*lm^2*NM*NC + (123220894377654559865*NC*NL)/31814516448 + 
         (587703821805551*lm*NC*NL)/716040 + 147685461*lm^2*NC*NL + 
         (402258910379682713591273842495590004762530267195882408349*NC*NH)/
          6612251588206640700264896908461210996774480000 + 
         (587703821805551*lm*NC*NH)/716040 + 147685461*lm^2*NC*NH - 
         (161424114313970874506*NM*NC*Pi^2)/27 + (28807387700*NC*NL*Pi^2)/
          81 - (139326152856118189861524210760*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1350851717672992089*Sqrt[3]) + 
         CA*NC*
          (110611208221312314125581036634868499446837573135618835796696463868\
03/1707883244404578635218164752981653914141312000000 - (7945223804783221*lm)/
            1432080 - (1624540071*lm^2)/2 + (46248189080820561881979217*Pi^2)/
            57283200 + (2077486865509050575885928045897031*
             Im[PolyLog[2, (-1)^(1/3)]])/(238830583684585001335200*Sqrt[3]) - 
           590741844*Zeta[3]) + CF*NC*(-1580160118529643853976015375291914566\
535617944859726017445167227729/
            121991660314612759658440339498689565295808000000 + 
           (476080196672531*lm)/26520 + 3987507447*lm^2 - 
           (46248189097141360969427761*Pi^2)/28641600 - 
           (2077486865509050575885928045897031*Im[PolyLog[2, (-1)^(1/3)]])/
            (119415291842292500667600*Sqrt[3]) + 1181483688*Zeta[3])), 
      (6229632269465434747406704423623172200265296221881529479360396276343858\
529215940067*CF^2*NC)/
        167352277141783042735221011427550119525756213854325273600000000 - 
       (494172288150140172601*CF^2*lm*NC)/365608878336 - 
       (12075328881*CF^2*lm^2*NC)/10 + 
       (6186705876554578098139433809544121859580704726201345432664249*CF*NM*
         NC)/3387553467141191925268504921621601088000000 - 
       (4800919815936634319069*CF*lm*NM*NC)/49357198575360 - 
       (447234403*CF*lm^2*NM*NC)/10 + (3968321613169108991879166355930387*CF*
         NC*NL)/1792740591404016026572800 - (4800919815936634319069*CF*lm*NC*
         NL)/49357198575360 - (447234403*CF*lm^2*NC*NL)/10 + 
       (707096346047518453711561710098690786160263038972815498877194620981581\
061*CF*NC*NH)/
        9635129185266917758395405168364416868253302707767320128000000 - 
       (4800919815936634319069*CF*lm*NC*NH)/49357198575360 - 
       (447234403*CF*lm^2*NC*NH)/10 - 
       (64833332529611756874410591204795385401*CF^2*NC*Pi^2)/
        3496463947078502400 + (12836285*CF^2*lm*NC*Pi^2)/6 - 
       (123176570634703628751301430*CF*NM*NC*Pi^2)/78567489 + 
       (12836285*CF*lm*NM*NC*Pi^2)/162 - (1957963156018177*CF*NC*NL*Pi^2)/
        16325712 + (12836285*CF*lm*NC*NL*Pi^2)/162 + 
       (12836285*CF*lm*NC*NH*Pi^2)/162 - 
       (355462075217490831252266991178183357*CF^2*NC*Pi^3)/
        (196032143088307369095932160*Sqrt[3]) - 
       (4678415786085669363042694217215*CF*NC*NH*Pi^3)/
        (437675956526049436836*Sqrt[3]) - (2573381920571*CF^2*NC*Pi^4)/
        64800 + (38406882488653181748539542390442637673581187*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3169085029987040174910203688384000*
         Sqrt[3]) + (98194787477214328435842108863435351*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1692711761864496196963230*Sqrt[3]) - 
       (125064171617*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
       (50780296459641547321752427311169051*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(756296848334519170894800*
         Sqrt[3]) - (534676089838362212919165053396*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (50780296459641547321752427311169051*CF^2*NC*Pi*Log[3]^2)/
        (36302248720056920202950400*Sqrt[3]) - 
       (133669022459590553229791263349*CF*NC*NH*Pi*Log[3]^2)/
        (16210220612075905068*Sqrt[3]) + 
       CF*((-312241960589914742033947604094959298043651*CF*NC)/
          1403268343046238240000 - 64266491746*CF*lm*NC + 
         CA*(2185693723658718984238987377001023558433117/
            19645756802647335360000 + (353465704603*lm)/27)*NC - 
         (6112612684169076790272310400788531*NM*NC)/324907994010600 - 
         (64266491746*lm*NM*NC)/27 - (396542615753*NC*NL)/135 - 
         (64266491746*lm*NC*NL)/27 - (8819780591904567337153*NC*NH)/
          13492251154200 - (64266491746*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(1037025255667527645692844737*CA - 
          76*(27290138416744173278196949*CF + 22100*(94586450588397374592*
               NM - 32133245873*NL)))*Log[x]^3)/34011900 - 
       (358402576677539503147992188412500813176615237*CF^2*NC*
         PolyGamma[2, 1])/33088302313369337424801600 - 
       (7031061643332912327701*CF*NM*NC*PolyGamma[2, 1])/12600 - 
       (9540327267307821504035921582894159*CF*NC*NH*PolyGamma[2, 1])/
        2068018894585583589050100 + CA*CF*NC*
        (-4360742589103262221407467390399244563719080273889392861579470337061\
7330242852911469/
          2342931879984962598293094159985701673360586993960553830400000000 + 
         (4919578433*lm^2)/20 + (324166662651218661874633720886657850781*
           Pi^2)/34964639470785024000 + (355462075217490831252266991178183357*
           Pi^3)/(392064286176614738191864320*Sqrt[3]) + 
         (2581597142971*Pi^4)/129600 + lm*(83714050109347989663871/
            98714397150720 - (141199135*Pi^2)/324) - 
         (38406882488653181748539542390442637673581187*
           Im[PolyLog[2, (-1)^(1/3)]])/(6338170059974080349820407376768000*
           Sqrt[3]) + (125064171617*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (50780296459641547321752427311169051*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1512593696669038341789600*
           Sqrt[3]) + (50780296459641547321752427311169051*Pi*Log[3]^2)/
          (72604497440113840405900800*Sqrt[3]) + 
         (358402576677539503147992188412500813176615237*PolyGamma[2, 1])/
          66176604626738674849603200 - 
         (471676162883604948106719032223235073905987471*Zeta[3])/
          106875216472182959882109168) + 
       (11791904078305777425463020656785039880343095983*CF^2*NC*Zeta[3])/
        1335940205902286998526364600 + (7682386327045482991499*CF*NM*NC*
         Zeta[3])/6300 - (74365867340*CF*NC*NL*Zeta[3])/27 + 
       (12576719366479883632248084652158841*CF*NC*NH*Zeta[3])/
        1034009447292791794525050 + CF*Log[x]*
        ((-6027171427364364499172621252233150843991189623*NM*NC)/
          451133352871761049029540000 - (2822142463753921*lm*NM*NC)/
          2720952 - 186550056*lm^2*NM*NC - (191891955469205423414113223*NC*
           NL)/38505109257014400 - (2822142463753921*lm*NC*NL)/2720952 - 
         186550056*lm^2*NC*NL - 
         (70170309108320265986372707063249003643282545398830329931*NC*NH)/
          901670671119087368217940487517437863196520000 - 
         (2822142463753921*lm*NC*NH)/2720952 - 186550056*lm^2*NC*NH - 
         (31528816867438878865*NM*NC*Pi^2)/27 - (37170097385*NC*NL*Pi^2)/
          81 + (534676089838362212919165053396*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CF*NC*(-194183687139726250810924337504109278452164829761831406752851\
6902987877/16224890821843497034572565153325712184342464000000 - 
           (2286349063115425*lm)/100776 - 5036851512*lm^2 - 
           (638169388302631538234386943*Pi^2)/41860800 + 
           (50780296459641547321752427311169051*Im[PolyLog[2, (-1)^(1/3)]])/
            (2268890545003557512684400*Sqrt[3]) - 1492400448*Zeta[3]) + 
         CA*NC*
          (213388667206810960718486777044957483832623469630846265600962515299\
47/356591007073483451309287146226938729326208000000 + (38149879572919499*lm)/
            5441904 + 1026025308*lm^2 + (638169388333411121484617951*Pi^2)/
            83721600 - (50780296459641547321752427311169051*
             Im[PolyLog[2, (-1)^(1/3)]])/(4537781090007115025368800*
             Sqrt[3]) + 746200224*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["p", 2, 4, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-3*CA*(1159077970103966 + 3376313794560*lm + 
           1907490816000*lm^2 - 963789424282125*Zeta[3]) + 
         2*(35*CF*(-660472099990178 - 224036388864*lm + 401316249600*lm^2 + 
             549808396646355*Zeta[3]) + 3*(131072*(3728303 + 657930*lm + 
               1323000*lm^2)*NL + 35*NH*(-16417085090 + 2463891456*lm + 
               4954521600*lm^2 + 12911454675*Zeta[3]) + 
             35*NM*(2463891456*lm + 4954521600*lm^2 + 35*(-469059574 + 
                 368898705*Zeta[3]))))))/10487731322880000, 
      -(CF*NC*(-3*CA*(1159922048552606 + 4330059202560*lm + 
            1907490816000*lm^2 - 963789424282125*Zeta[3]) + 
          2*(35*CF*(-660528109087394 - 23378264064*lm + 401316249600*lm^2 + 
              549808396646355*Zeta[3]) + 6*(32768*(7785571 + 2638860*lm + 
                2646000*lm^2)*NL + 210*NM*(-931776646 + 411762688*lm + 
                412876800*lm^2 + 930962025*Zeta[3]) + 35*NH*(-10210452350 + 
                2470576128*lm + 2477260800*lm^2 + 7325682525*Zeta[3])))))/
       2621932830720000, 
      (CF*NC*(-(CA*(277110434866356473806 + 318934159542190080*lm + 
            118661188681728000*lm^2 - 230410888998572071125*Zeta[3])) + 
         126*CF*(-44719860681621611342 + 1661974735749120*lm + 
           4623163195392000*lm^2 + 37206245731735739925*Zeta[3]) + 
         16*(131072*(32831856983 + 14557476780*lm + 10287648000*lm^2)*NL + 
           315*NM*(-6131458406266 + 6057389195264*lm + 4280706662400*lm^2 + 
             9675791623575*Zeta[3]) + 315*NH*(-22596398783602 + 
             6057389195264*lm + 4280706662400*lm^2 + 15876832200075*
              Zeta[3]))))/24918849623162880000, 
      -(CF*NC*(-(CA*(227481233531624805358 + 112321250721792000*lm + 
             37081621463040000*lm^2 - 189191542900874149125*Zeta[3])) + 
          2*(11875767088578560*NL + 5920587251712000*lm*NL + 
            3371056496640000*lm^2*NL - 22233380116416462*NH + 
            5920587251712000*lm*NH + 3371056496640000*lm^2*NH + 
            15769876398247125*NH*Zeta[3] + 63*NM*(-68483590095086 + 
              93977575424000*lm + 53508833280000*lm^2 + 158237128405125*Zeta[
                3]) + 63*CF*(-39488350012426989422 + 1012392787968000*lm + 
              1444738498560000*lm^2 + 32851763230296608325*Zeta[3]))))/
       4983769924632576000, 
      (CF*NC*(-11*CA*(11318889940123221421756814 + 2163450914075049984000*
            lm + 656715516110438400000*lm^2 - 9415125083261572491403125*
            Zeta[3]) + 154*CF*(-20910163260659432984968574 + 
           222462977674051584000*lm + 230276869285478400000*lm^2 + 
           17395502833073661634540125*Zeta[3]) + 
         25*(4194304*(48889725430879 + 25322554899180*lm + 12525854418000*
              lm^2)*NL + 693*NM*(-196830123022626566 + 153261895099351040*
              lm + 75811314991104000*lm^2 + 378597702749891625*Zeta[3]) + 
           693*NH*(-605147368032694102 + 153261895099351040*lm + 
             75811314991104000*lm^2 + 437728842564638625*Zeta[3]))))/
       783947009144704204800000, 
      -(CF*NC*(-11*CA*(16846238478465467884097662 + 1171332249405515366400*
             lm + 336923612613181440000*lm^2 - 14013840714747753958588125*
             Zeta[3]) + 2*(231*CF*(-11839763020746333951979514 + 
              45219598564117708800*lm + 39380681993748480000*lm^2 + 
              9849617328128089520460375*Zeta[3]) + 
            5*(4194304*(69095738714921 + 35406130733820*lm + 16065769797000*
                 lm^2)*NL + 1848*NM*(-268125313158975178 + 
                80359348355727360*lm + 36463594438656000*lm^2 + 
                365295716842431375*Zeta[3]) + 693*NH*(-884694121093223298 + 
                214291595615272960*lm + 97236251836416000*lm^2 + 
                652029976959235875*Zeta[3])))))/391973504572352102400000, 
      (CF*NC*(-88*CA*(241265332822974111103417955218 + 
           5556768431202183728332800*lm + 1564726555626197483520000*lm^2 - 
           200707218698505638726999266875*Zeta[3]) + 
         5*(23422887184113914932625408*NL + 11408954462387565452328960*lm*
            NL + 5007124978003831947264000*lm^2*NL - 
           45542161431160721021332638*NH + 11408954462387565452328960*lm*
            NH + 5007124978003831947264000*lm^2*NH + 
           33911339074100413482682125*NH*Zeta[3] + 
           3003*NM*(-35990741133905192475386 + 3799185635160694456320*lm + 
             1667374285049561088000*lm^2 + 38523731663432789148375*Zeta[3]) + 
           624*CF*(-227886248758851999070473480382 + 264965879184863872942080*
              lm + 216654446163627343872000*lm^2 + 
             189580400865005940476397035325*Zeta[3]))))/
       16958341701818241358233600000, 
      -(CF*NC*(-880*CA*(116459583130169166256621753286 + 
            748094334486562933309440*lm + 217649934429207920640000*lm^2 - 
            96883228994646277042274039625*Zeta[3]) + 
          416*CF*(-9285223687775846248728159260366 + 
            2506261807157759233228800*lm + 2260210857534082252800000*lm^2 + 
            7724446888184996649612774967125*Zeta[3]) + 
          5*(2147483648*(16088447277872393 + 7019718394148460*lm + 
              3243236756760000*lm^2)*NL + 429*NM*
             (-1118169485888507084481346 + 35139231853143675371520*lm + 
              16234960143903621120000*lm^2 + 1040357494105028039815875*Zeta[
                3]) + 1287*NH*(11713077284381225123840*lm + 
              5411653381301207040000*lm^2 + 429*(-63765908208328322858 + 
                45236535125720313375*Zeta[3])))))/
       33916683403636482716467200000, 
      (CF*NC*(-11*CA*(39689807181693957496377467369677898 + 
           42782034331263795839631360000*lm + 15819879601556317462855680000*
            lm^2 - 33018251008656097566191671606119375*Zeta[3]) + 
         2*(3*CF*(-3065382526252359269388945303554691142 + 
             53539922785125873903206400000*lm + 
             142378916414006857165701120000*lm^2 + 
             2550114211753083051560964202489391625*Zeta[3]) + 
           175*(4294967296*(101848890179799311 + 30131800514115300*lm + 
               21047730000897600*lm^2)*NL + 429*NH*
              (3954971348610039070542086 + 301666894586762703667200*lm + 
               210721007013737162342400*lm^2 - 3311720193693060688163625*
                Zeta[3]) + 2145*NM*(-12544650360849557227688002 + 
               60333378917352540733440*lm + 42144201402747432468480*lm^2 + 
               10856664524858060061828675*Zeta[3])))))/
       64577365200523863092153548800000, 
      CA*CF*NC*((-80726687*lm)/17708090400 - (8*lm^2)/69615 + 
         (2084117531978448687930773621882434 - 
           1733794568309668666852815193303875*Zeta[3])/
          146766739092099688845803520000) + 
       (CF*NC*(24*CF*(7152651194048413833182224768213822 + 
            226729161956221127686619136*lm + 6071797868063594108682240*lm^2 - 
            5950342952197573168003163017744125*Zeta[3]) + 
          77*(34359738368*(62145645724399 + 78328623725352*lm + 
              2039972014080*lm^2)*NL + 273*NM*(3574025529286494169582538 + 
              9858428637101143621632*lm + 256750566600112865280*lm^2 - 
              2996636837624061150293775*Zeta[3]) + 3003*NH*
             (-31813742472460990356094 + 896220785191013056512*lm + 
              23340960600010260480*lm^2 + 25979424172838220008925*Zeta[3]))))/
        258309460802095452368614195200, 
      -(CF*NC*(-55*CA*(-729027106423910909210598680231052389398 + 
            357098988814496342293003747983360*lm + 
            60570543622125724675986161664000*lm^2 + 
            606483579454693691979490406325666309825*Zeta[3]) + 
          2*(153*CF*(6775384707813967482763266792016733011766 + 
              190653204881775029850201076531200*lm + 
              53444597313640345302340730880000*lm^2 - 
              5636492303883346177320429920357658464625*Zeta[3]) + 
            70*(274877906944*(122250813975257089931 + 72761968378654264710*
                 lm + 15739596716522679000*lm^2)*NL + 51051*NM*(
                391777978355957719357194240*lm + 84747946202433035698176000*
                 lm^2 + 187*(608185894147335382717815374 - 
                  504597318100698005273215125*Zeta[3])) + 7293*NH*(
                -69959195248120302324637925774 + 2742445848491704035500359680*
                 lm + 593235623417031249887232000*lm^2 + 
                57171400076478390168480139125*Zeta[3])))))/
       1418377249264306128956060545843200000, 
      (CF*NC*(306*CF*(14161067380426194851116919688595223937478 + 
           240310749218820802410045033676800*lm + 
           86648824810143470145503232000000*lm^2 - 
           11780696158630995673369968218745689111625*Zeta[3]) - 
         11*CA*(-6929526138884105470526341082337789119038 + 
           2504971080652601340812323926835200*lm + 
           491010007257479664157851648000000*lm^2 + 
           5764727339205164465773331799415817632125*Zeta[3]) + 
         35*(137438953472*(1543587000488160811957 + 781666210234726837020*
              lm + 204146742911161050000*lm^2)*NL + 
           2431*NM*(18745679967189071521232918797178 + 
             44192260756513859297335050240*lm + 11541635006346116569497600000*
              lm^2 - 15528009108203325497612061588375*Zeta[3]) + 
           21879*NH*(4910251195168206588592783360*lm + 
             1282403889594012952166400000*lm^2 + 
             2431*(-54983332779974145044922038 + 45091962818191972850792625*
                Zeta[3])))))/1418377249264306128956060545843200000, 
      -(CF*NC*(76*CF*(987468266422492666931154228048493791195669826 + 
            8547104301782517772557218311097548800*lm + 
            3567523636738372695053566539202560000*lm^2 - 
            821482124992312674043037314008516382722151875*Zeta[3]) - 
          2*CA*(-603033890138158924713361771186260277978905626 + 
            130457090365220654930729309883177369600*lm + 
            27615275558456292343192422470123520000*lm^2 + 
            501668509908415948192015206968830768832586375*Zeta[3]) + 
          105*(274877906944*(2639790351370035201544247 + 
              1200821222683185824841120*lm + 347926535874153280044000*lm^2)*
             NL + 4199*NM*(61292490593286531390107749533130774 + 
              78609007931671601608510899486720*lm + 
              22776212896252389380025483264000*lm^2 - 
              50827105431868865948911902257042625*Zeta[3]) + 
            37791*NH*(8734334214630177956501211054080*lm + 
              2530690321805821042225053696000*lm^2 + 340119*(
                -832270665789539945124455366 + 685015473354476351021559625*
                 Zeta[3])))))/12288820487625948301275308569185484800000, 
      (CF*NC*(76*CF*(948898995271721590847717124413055614421448142 + 
           3723351181687712313900812998803456000*lm + 
           1801976530319194598025897632071680000*lm^2 - 
           789396067890398064331499230187985234505159125*Zeta[3]) - 
         2*CA*(-531552879195717162389894658110145473476428214 + 
           61297859206944442816880032635420672000*lm + 
           13948633142100432258793059448258560000*lm^2 + 
           442202835907619459201319101080152553265720625*Zeta[3]) + 
         525*(274877906944*(265955074671910773694619 + 
             109725355072207302508080*lm + 35147935417391142746400*lm^2)*
            NL + 4199*NM*(11925296115378300120656847699178582 + 
             7182918776121828363775487508480*lm + 
             2300878999984606890948978278400*lm^2 - 
             9902257054789537647870487280078625*Zeta[3]) + 
           37791*NH*(798102086235758707086165278720*lm + 
             255653222220511876772108697600*lm^2 + 
             4199*(-7835840204315408218544074726 + 
               6469554915083214210100469625*Zeta[3])))))/
       6144410243812974150637654284592742400000, 
      -(CF*NC*(2*CF*(67722119432312440048538481199198241159871571330514 + 
            106906328061776760050132569779439927296000*lm + 
            63125709600525710205045425993668362240000*lm^2 - 
            56338530403741529692241613243912066227122000702875*Zeta[3]) - 
          CA*(-1838272683724181435032557235385871484401503795758 + 
            103432932267642285791053889299197984768000*lm + 
            25717881689103067120574062441864888320000*lm^2 + 
            1529272719809417209805654552896548149740907713125*Zeta[3]) + 
          5775*(4398046511104*(1362377777578266563595983 + 
              506117750942703610570860*lm + 184102929059915355890400*lm^2)*
             NL + 12597*NM*(706681237037332294447931700188358382 + 
              176703136361146369887776035307520*lm + 
              64276672607445260423222054092800*lm^2 - 
              587339190197719604828760635674741125*Zeta[3]) + 
            29393*NH*(75729915583348444237618300846080*lm + 
              27547145403190825895666594611200*lm^2 + 54587*(
                -77626730116923017665088295022 + 
                64253609766760589660489437125*Zeta[3])))))/
       6218143166738729840445306136007855308800000, 
      (CF*NC*(8*CF*(3691221572256475767741220110455359632383381029486 + 
           1967063194496644974888527124881001676800*lm + 
           1606648979572031940099070200077352960000*lm^2 - 
           3070754439847774682894498188338076624154666941125*Zeta[3]) - 
         4*CA*(-92559477916139397131865310083064715334815366546 + 
           2325398543401321871221398627494028902400*lm + 
           654560695381198197818139711142625280000*lm^2 + 
           77000914477225156506964505877560297054918722875*Zeta[3]) + 
         35*(2199023255552*(43262523924451281288667267 + 
             14101385048351177514897960*lm + 6185137500654580580112000*lm^2)*
            NL + 20995*NH*(1476983741691712470044466443452416*lm + 
             647833350927658791059728839475200*lm^2 + 
             4199*(-29195214767795928410693299882622 + 
               24213482576266825904640261608925*Zeta[3])) + 
           1322685*NM*(23444186376058928095943911800832*lm + 
             10283069062343790334281410150400*lm^2 - 
             459*(-562189448958495198130801406917946 + 
               467490198646971902656304776901175*Zeta[3])))))/
       753714323241058162478218925576709734400000, 
      CA*CF*NC*((11180641739227344781*lm)/1407326738699097216000 + 
         (4065617*lm^2)/1497686400 + 
         (-55856515728639144552785619940958141389713442353288506 + 
           46467447647472481931713991419981637936713758028920375*Zeta[3])/
          70173818351035479159372094846893983111577600000) - 
       (CF*NC*(207*CF*(331791936225530053664175950938032617646410149486814 + 
            38615242465352608949537894314325217116160*lm + 
            64537683825368908897458119954221812940800*lm^2 - 
            276020157962707038549342951351884802987482620457325*Zeta[3]) + 
          22*(2199023255552*(63578945525124737296036086823 + 
              16915100255545382034373068840*lm + 
              10227452080219673452764811200*lm^2)*NL + 
            37145*NH*(1001391811332288952550993097532637184*lm + 
              605475971717505477975965099486085120*lm^2 + 
              854335*(-169804908199751513366634755176946 + 
                141042596209838683044628775786955*Zeta[3])) + 
            111435*NM*(333797270444096317516997699177545728*lm + 
              201825323905835159325321699828695040*lm^2 - 
              529*(-23289525438563422321494206010927161566 + 
                19371378795264149925513624391165481325*Zeta[3])))))/
        1002483119300506845133887069241342615879680000, 
      (CF*NC*(92*CF*(133612287887337946104505349182012103492504280933246394 - 
           3147563178981372635867078905679716338892800*lm + 
           11086142888385640089449920964647282802688000*lm^2 - 
           111153047381451052146862304756475869125699654472304375*Zeta[3]) - 
         2*CA*(-66360011466093973893744075120537888687089868131474506 + 
           212371132363110639680450277061089941048524800*lm + 
           103881264843020997875215926076139353669632000*lm^2 + 
           55205382763659541988775563927493481088786376792039375*Zeta[3]) + 
         1155*(193514046488576*(815996296158974624162530903 + 
             130413642184969601713458840*lm + 169009087310289358854321600*
              lm^2)*NL + 37145*NM*
            (139335779976127305380325575579742498280946 + 
             679415038808095939123533743696904192*lm + 
             880485459113074036999801620481966080*lm^2 - 
             115907362724869374264295117372027440432075*Zeta[3]) + 
           334305*NH*(75490559867566215458170415966322688*lm + 
             97831717679230448555533513386885120*lm^2 + 
             126293*(-243498140331145646315638113979322 + 
               202479119460507067138123079491575*Zeta[3])))))/
       105260727526553218739058142270340974667366400000}, 0, 18, 1]

CbarTable["p", 2, -1] = {{0., 0.000925925925925926*CF*NC*
       (CF*(-6538.21369593866 - 4967.885821649447*lm - 2430.*lm^2 - 
          2160.*lm^3) - 1.*CA*(8942.848749338787 + 8518.557089175276*lm + 
          4560.*lm^2 + 660.*lm^3) + 
        30.*((83.46582090110702 + 45.*lm + 20.*lm^2 + 4.*lm^3)*NM + 
          (83.46582090110702 + 45.*lm + 20.*lm^2 + 4.*lm^3)*NL + 
          (-9.63037315387456 + 117.*lm + 20.*lm^2 + 4.*lm^3)*NH))}, 
     {0.005, CF*NC*(CF*(-6.024116887226836 - 4.577099533730961*lm - 
          2.238814157936368*lm^2 - 1.99005*lm^3) + 
        CA*(-8.239380247378715 - 7.848349019351166*lm - 4.201219082980557*
           lm^2 - 0.6080708333333333*lm^3) + 2.3069610202051134*NM + 
        1.2438373698500598*lm*NM + 0.5527921059964649*lm^2*NM + 
        0.11055833333333333*lm^3*NM + 2.3069863627162004*NL + 
        1.2437873698500599*lm*NL + 0.5527921059964649*lm^2*NL + 
        0.11055833333333333*lm^3*NL - 0.2617584366081661*NH + 
        3.2437873698500597*lm*NH + 0.5527921059964649*lm^2*NH + 
        0.11055833333333333*lm^3*NH)}, 
     {0.01, CF*NC*(CF*(-5.995746031978208 - 4.554900304900597*lm - 
          2.2277797148932987*lm^2 - 1.9802*lm^3) + 
        CA*(-8.19933869309349 - 7.809697075695543*lm - 4.180438940661841*
           lm^2 - 0.6050611111111112*lm^3) + 2.2955913852107313*NM + 
        1.2378631292093534*lm*NM + 0.55005859527185*lm^2*NM + 
        0.11001111111111112*lm^3*NM + 2.2956859380076393*NL + 
        1.2376631292093534*lm*NL + 0.55005859527185*lm^2*NL + 
        0.11001111111111112*lm^3*NL - 0.25607009487151744*NH + 
        3.2376631292093534*lm*NH + 0.55005859527185*lm^2*NH + 
        0.11001111111111112*lm^3*NH)}, 
     {0.015, CF*NC*(CF*(-5.969052265119674 - 4.533464048602967*lm - 
          2.216923824439068*lm^2 - 1.97045*lm^3) + 
        CA*(-8.160487275630786 - 7.77168018986765*lm - 4.159890092189715*
           lm^2 - 0.6020819444444444*lm^3) + 2.2844234272121455*NM + 
        1.232090478217162*lm*NM + 0.5473565319132816*lm^2*NM + 
        0.10946944444444444*lm^3*NM + 2.284623432083808*NL + 
        1.231640478217162*lm*NL + 0.5473565319132816*lm^2*NL + 
        0.10946944444444444*lm^3*NL - 0.2504494822298865*NH + 
        3.231640478217162*lm*NH + 0.5473565319132816*lm^2*NH + 
        0.10946944444444444*lm^3*NH)}, 
     {0.02, CF*NC*(CF*(-5.9441206598829535 - 4.512893232865401*lm - 
          2.206268190400511*lm^2 - 1.9608*lm^3) + 
        CA*(-8.122926213441213 - 7.7343552438755125*lm - 4.139579169289045*
           lm^2 - 0.5991333333333333*lm^3) + 2.2734773649719804*NM + 
        1.2265282244427438*lm*NM + 0.5446871216889173*lm^2*NM + 
        0.10893333333333333*lm^3*NM + 2.2738133534067764*NL + 
        1.2257282244427439*lm*NL + 0.5446871216889173*lm^2*NL + 
        0.10893333333333333*lm^3*NL - 0.24489997769517227*NH + 
        3.2257282244427437*lm*NH + 0.5446871216889173*lm^2*NH + 
        0.10893333333333333*lm^3*NH)}, 
     {0.025, CF*NC*(CF*(-5.920965308008219 - 4.493256427499036*lm - 
          2.195831045022094*lm^2 - 1.95125*lm^3) + 
        CA*(-8.086711849458249 - 7.697764671579093*lm - 4.119511742923418*
           lm^2 - 0.5962152777777778*lm^3) + 2.2627654285804057*NM + 
        1.2211827939847664*lm*NM + 0.5420513775012274*lm^2*NM + 
        0.10840277777777778*lm^3*NM + 2.263263445964135*NL + 
        1.2199327939847664*lm*NL + 0.5420513775012274*lm^2*NL + 
        0.10840277777777778*lm^3*NL - 0.23942446782117305*NH + 
        3.2199327939847664*lm*NH + 0.5420513775012274*lm^2*NH + 
        0.10840277777777778*lm^3*NH)}, 
     {0.03, CF*NC*(CF*(-5.899563357696897 - 4.474600334475511*lm - 
          2.1856280337463416*lm^2 - 1.9418*lm^3) + 
        CA*(-8.051874703854327 - 7.6619411771230705*lm - 4.099692593644716*
           lm^2 - 0.5933277777777778*lm^3) + 2.252295027125534*NM + 
        1.216059026807942*lm*NM + 0.5394501685414634*lm^2*NM + 
        0.10787777777777778*lm^3*NM + 2.2529775425839342*NL + 
        1.2142590268079423*lm*NL + 0.5394501685414634*lm^2*NL + 
        0.10787777777777778*lm^3*NL - 0.2340254675349686*NH + 
        3.2142590268079423*lm*NH + 0.5394501685414634*lm^2*NH + 
        0.10787777777777778*lm^3*NH)}, 
     {0.035, CF*NC*(CF*(-5.879870753631652 - 4.456956197535866*lm - 
          2.175672736486377*lm^2 - 1.93245*lm^3) + 
        CA*(-8.01842839235401 - 7.6269103076129925*lm - 4.0801258708708374*
           lm^2 - 0.5904708333333333*lm^3) + 2.242070328677318*NM + 
        1.2111606076446755*lm*NM + 0.5368842492492432*lm^2*NM + 
        0.10735833333333333*lm^3*NM + 2.2429569576710304*NL + 
        1.2087106076446754*lm*NL + 0.5368842492492432*lm^2*NL + 
        0.10735833333333333*lm^3*NL - 0.22870519130646086*NH + 
        3.2087106076446754*lm*NH + 0.5368842492492432*lm^2*NH + 
        0.10735833333333333*lm^3*NH)}, 
     {0.04, CF*NC*(CF*(-5.861830772253352 - 4.440343739610248*lm - 
          2.165977015993749*lm^2 - 1.9232*lm^3) + 
        CA*(-7.986374776281615 - 7.592692066676909*lm - 4.060815199331423*
           lm^2 - 0.5876444444444444*lm^3) + 2.232093182155457*NM + 
        1.2064903347378353*lm*NM + 0.5343542786663193*lm^2*NM + 
        0.10684444444444445*lm^3*NM + 2.233201282925585*NL + 
        1.2032903347378354*lm*NL + 0.5343542786663193*lm^2*NL + 
        0.10684444444444445*lm^3*NL - 0.22346560075498584*NH + 
        3.203290334737835*lm*NH + 0.5343542786663193*lm^2*NH + 
        0.10684444444444445*lm^3*NH)}, 
     {0.045, CF*NC*(CF*(-5.845379101386744 - 4.42477379767725*lm - 
          2.156551269105266*lm^2 - 1.91405*lm^3) + 
        CA*(-7.955707227338949 - 7.559302015590539*lm - 4.04176375583772*
           lm^2 - 0.5848486111111111*lm^3) + 2.2223637082445578*NM + 
        1.2020503022804043*lm*NM + 0.531860834394737*lm^2*NM + 
        0.10633611111111112*lm^3*NM + 2.223708886740159*NL + 
        1.1980003022804044*lm*NL + 0.531860834394737*lm^2*NL + 
        0.10633611111111112*lm^3*NL - 0.21830843905297237*NH + 
        3.198000302280404*lm*NH + 0.531860834394737*lm^2*NH + 
        0.10633611111111112*lm^3*NH)}, 
     {0.05, CF*NC*(CF*(-5.830447052135855 - 4.410250190916328*lm - 
          2.1474046175336485*lm^2 - 1.905*lm^3) + 
        CA*(-7.9264128314039 - 7.526752068898934*lm - 4.022974327579726*
           lm^2 - 0.5820833333333333*lm^3) + 2.2128807030308617*NM + 
        1.1978420315837148*lm*NM + 0.5294044231963138*lm^2*NM + 
        0.10583333333333333*lm^3*NM + 2.2144772480493065*NL + 
        1.1928420315837147*lm*NL + 0.5294044231963138*lm^2*NL + 
        0.10583333333333333*lm^3*NL - 0.21323525712993502*NH + 
        3.192842031583715*lm*NH + 0.5294044231963138*lm^2*NH + 
        0.10583333333333333*lm^3*NH)}, 
     {0.055, CF*NC*(CF*(-5.816963675767762 - 4.396771101798846*lm - 
          2.1385450582560863*lm^2 - 1.89605*lm^3) + 
        CA*(-7.8984739450076855 - 7.49505109361045*lm - 4.004449358078249*
           lm^2 - 0.5793486111111111*lm^3) + 2.2036419267052976*NM + 
        1.1938665693882726*lm*NM + 0.5269854893475604*lm^2*NM + 
        0.10533611111111112*lm^3*NM + 2.205503189872127*NL + 
        1.1878165693882725*lm*NL + 0.5269854893475604*lm^2*NL + 
        0.10533611111111112*lm^3*NL - 0.20824743440814117*NH + 
        3.1878165693882727*lm*NH + 0.5269854893475604*lm^2*NH + 
        0.10533611111111112*lm^3*NH)}, 
     {0.06, CF*NC*(CF*(-5.8048571995125915 - 4.384330129908598*lm - 
          2.129979585450794*lm^2 - 1.8872*lm^3) + 
        CA*(-7.871869332734898 - 7.464205374868079*lm - 3.986190984443298*
           lm^2 - 0.5766444444444444*lm^3) + 2.194644317393206*NM + 
        1.190124563909495*lm*NM + 0.524604421413933*lm^2*NM + 
        0.10484444444444445*lm^3*NM + 2.1967830483477293*NL + 
        1.182924563909495*lm*NL + 0.524604421413933*lm^2*NL + 
        0.10484444444444445*lm^3*NL - 0.20334619569425025*NH + 
        3.182924563909495*lm*NH + 0.524604421413933*lm^2*NH + 
        0.10484444444444445*lm^3*NH)}, 
     {0.065, CF*NC*(CF*(-5.794056019324418 - 4.372917116162762*lm - 
          2.121714291571779*lm^2 - 1.87845*lm^3) + 
        CA*(-7.846575020668512 - 7.434218986885146*lm - 3.9682010682580438*
           lm^2 - 0.5739708333333333*lm^3) + 2.185884153915973*NM + 
        1.1866163251338655*lm*NM + 0.5222615578650989*lm^2*NM + 
        0.10435833333333333*lm^3*NM + 2.1883127983466184*NL + 
        1.1781663251338654*lm*NL + 0.5222615578650989*lm^2*NL + 
        0.10435833333333333*lm^3*NL - 0.1985326252564634*NH + 
        3.1781663251338657*lm*NH + 0.5222615578650989*lm^2*NH + 
        0.10435833333333333*lm^3*NH)}, 
     {0.07, CF*NC*(CF*(-5.784489394209543 - 4.362518800340274*lm - 
          2.1137544526280516*lm^2 - 1.8698*lm^3) + 
        CA*(-7.822564950359701 - 7.405094094336202*lm - 3.950481221636349*
           lm^2 - 0.5713277777777778*lm^3) + 2.1773571824267006*NM + 
        1.1833418735874328*lm*NM + 0.5199571918126695*lm^2*NM + 
        0.10387777777777778*lm^3*NM + 2.1800881487728794*NL + 
        1.1735418735874328*lm*NL + 0.5199571918126695*lm^2*NL + 
        0.10387777777777778*lm^3*NL - 0.19380767877290686*NH + 
        3.173541873587433*lm*NH + 0.5199571918126695*lm^2*NH + 
        0.10387777777777778*lm^3*NH)}, 
     {0.075, CF*NC*(CF*(-5.77608793388244 - 4.353119354167761*lm - 
          2.1061046011861113*lm^2 - 1.86125*lm^3) + 
        CA*(-7.799811488497553 - 7.376831201258893*lm - 3.9330328295290897*
           lm^2 - 0.5687152777777778*lm^3) + 2.169058716719294*NM + 
        1.180300980428905*lm*NM + 0.517691575065895*lm^2*NM + 
        0.10340277777777777*lm^3*NM + 2.1721046160806328*NL + 
        1.169050980428905*lm*NL + 0.517691575065895*lm^2*NL + 
        0.10340277777777777*lm^3*NL - 0.1891721936265175*NH + 
        3.169050980428905*lm*NH + 0.517691575065895*lm^2*NH + 
        0.10340277777777777*lm^3*NH)}, 
     {0.08, CF*NC*(CF*(-5.768783940080281 - 4.3447008193318135*lm - 
          2.0987685896209536*lm^2 - 1.8528*lm^3) + 
        CA*(-7.7782858296272 - 7.349429359415958*lm - 3.9158570690508467*
           lm^2 - 0.5661333333333334*lm^3) + 2.16098371887303*NM + 
        1.1774932008613566*lm*NM + 0.5154649216456085*lm^2*NM + 
        0.10293333333333334*lm^3*NM + 2.1643575817465828*NL + 
        1.1646932008613566*lm*NL + 0.5154649216456085*lm^2*NL + 
        0.10293333333333334*lm^3*NL - 0.18462689788678652*NH + 
        3.1646932008613566*lm*NH + 0.5154649216456085*lm^2*NH + 
        0.10293333333333334*lm^3*NH)}, 
     {0.085, CF*NC*(CF*(-5.7625116423865315 - 4.337243471427219*lm - 
          2.0917496454781137*lm^2 - 1.84445*lm^3) + 
        CA*(-7.757958317964916 - 7.322886344731445*lm - 3.8989549263960903*
           lm^2 - 0.5635819444444444*lm^3) + 2.1531268649001207*NM + 
        1.174917902297051*lm*NM + 0.5132774108598952*lm^2*NM + 
        0.10246944444444445*lm^3*NM + 2.1568423376842327*NL + 
        1.160467902297051*lm*NL + 0.5132774108598952*lm^2*NL + 
        0.10246944444444445*lm^3*NL - 0.18017241822887994*NH + 
        3.160467902297051*lm*NH + 0.5132774108598952*lm^2*NH + 
        0.10246944444444445*lm^3*NH)}, 
     {0.09, CF*NC*(CF*(-5.757207356915193 - 4.330726125241979*lm - 
          2.08505042035274*lm^2 - 1.8362*lm^3) + 
        CA*(-7.7387987069437685 - 7.2971988081635635*lm - 
          3.8823272117744483*lm^2 - 0.5610611111111111*lm^3) + 
        2.1454825987509647*NM + 1.1725742883327739*lm*NM + 
        0.5111291900195967*lm^2*NM + 0.10201111111111111*lm^3*NM + 
        2.1495541224373578*NL + 1.156374288332774*lm*NL + 
        0.5111291900195967*lm^2*NL + 0.10201111111111111*lm^3*NL - 
        0.17580928697888268*NH + 3.156374288332774*lm*NH + 
        0.5111291900195967*lm^2*NH + 0.10201111111111111*lm^3*NH)}, 
     {0.095, CF*NC*(CF*(-5.752809587948998 - 4.325126392907532*lm - 
          2.0786730333685624*lm^2 - 1.82805*lm^3) + 
        CA*(-7.720776370112527 - 7.272362405812612*lm - 3.8659745726959494*
           lm^2 - 0.5585708333333333*lm^3) + 2.1380451771417692*NM + 
        1.1704614193315477*lm*NM + 0.509020376853809*lm^2*NM + 
        0.10155833333333333*lm^3*NM + 2.142488150217505*NL + 
        1.1524114193315478*lm*NL + 0.509020376853809*lm^2*NL + 
        0.10155833333333333*lm^3*NL - 0.17153794843026643*NH + 
        3.1524114193315476*lm*NH + 0.509020376853809*lm^2*NH + 
        0.10155833333333333*lm^3*NH)}, 
     {0.1, CF*NC*(CF*(-5.7492590870292 - 4.320420903702525*lm - 
          2.0726191101053897*lm^2 - 1.82*lm^3) + 
        CA*(-7.703860473536884 - 7.248371911949202*lm - 3.8498975058655356*
           lm^2 - 0.5561111111111111*lm^3) + 2.130808707050237*NM + 
        1.16857823022077*lm*NM + 0.5069510616725217*lm^2*NM + 
        0.10111111111111111*lm^3*NM + 2.135639634316571*NL + 
        1.1485782302207699*lm*NL + 0.5069510616725217*lm^2*NL + 
        0.10111111111111111*lm^3*NL - 0.1673587645451035*NH + 
        3.1485782302207697*lm*NH + 0.5069510616725217*lm^2*NH + 
        0.10111111111111111*lm^3*NH)}, 
     {0.105, CF*NC*(CF*(-5.746498880119307 - 4.316585492317471*lm - 
          2.066889817650468*lm^2 - 1.81205*lm^3) + 
        CA*(-7.688020117390255 - 7.225221317838509*lm - 3.8340963678931987*
           lm^2 - 0.5536819444444444*lm^3) + 2.1237671772848383*NM + 
        1.1669235459818794*lm*NM + 0.5049213093139149*lm^2*NM + 
        0.10066944444444445*lm^3*NM + 2.129003806048658*NL + 
        1.1448735459818793*lm*NL + 0.5049213093139149*lm^2*NL + 
        0.10066944444444445*lm^3*NL - 0.1632720201302267*NH + 
        3.1448735459818793*lm*NH + 0.5049213093139149*lm^2*NH + 
        0.10066944444444445*lm^3*NH)}, 
     {0.11, CF*NC*(CF*(-5.744474270729429 - 4.313595360928125*lm - 
          2.061485896318438*lm^2 - 1.8042*lm^3) + 
        CA*(-7.67322445264229 - 7.202903918636439*lm - 3.8185713849861895*
           lm^2 - 0.5512833333333333*lm^3) + 2.1169144852139254*NM + 
        1.1654960952068338*lm*NM + 0.5029311609065799*lm^2*NM + 
        0.10023333333333333*lm^3*NM + 2.1225759301040834*NL + 
        1.1412960952068338*lm*NL + 0.5029311609065799*lm^2*NL + 
        0.10023333333333333*lm^3*NL - 0.15927792756099504*NH + 
        3.141296095206834*lm*NH + 0.5029311609065799*lm^2*NH + 
        0.10023333333333333*lm^3*NH)}, 
     {0.115, CF*NC*(CF*(-5.743132824923998 - 4.3114252193318165*lm - 
          2.056407688484637*lm^2 - 1.79645*lm^3) + 
        CA*(-7.659442777445078 - 7.181412390181636*lm - 3.8033226617591946*
           lm^2 - 0.5489152777777778*lm^3) + 2.11024445950539*NM + 
        1.1642945220215752*lm*NM + 0.5009806354713687*lm^2*NM + 
        0.09980277777777778*lm^3*NM + 2.1163513169996424*NL + 
        1.1378445220215754*lm*NL + 0.5009806354713687*lm^2*NL + 
        0.09980277777777778*lm^3*NL - 0.1553766311119189*NH + 
        3.137844522021575*lm*NH + 0.5009806354713687*lm^2*NH + 
        0.09980277777777778*lm^3*NH)}, 
     {0.12, CF*NC*(CF*(-5.742424342704587 - 4.3100494065693775*lm - 
          2.0516551648987904*lm^2 - 1.7888*lm^3) + 
        CA*(-7.6466446168402005 - 7.1607388571616015*lm - 
          3.7883501892746305*lm^2 - 0.5465777777777778*lm^3) + 
        2.1037508795509585*NM + 1.1633173966193049*lm*NM + 
        0.4990697313832661*lm^2*NM + 0.09937777777777777*lm^3*NM + 
        2.1103253331613554*NL + 1.134517396619305*lm*NL + 
        0.4990697313832661*lm^2*NL + 0.09937777777777777*lm^3*NL - 
        0.15156821094300088*NH + 3.1345173966193047*lm*NH + 
        0.4990697313832661*lm^2*NH + 0.09937777777777777*lm^3*NH)}, 
     {0.125, CF*NC*(CF*(-5.742300819202952 - 4.309441996814128*lm - 
          2.0472279487849967*lm^2 - 1.78125*lm^3) + 
        CA*(-7.634799788670198 - 7.140874953863244*lm - 3.7736538524065266*
           lm^2 - 0.5442708333333334*lm^3) + 2.097427492115018*NM + 
        1.162563224601999*lm*NM + 0.4971984277102776*lm^2*NM + 
        0.09895833333333333*lm^3*NM + 2.1044934090643626*NL + 
        1.131313224601999*lm*NL + 0.4971984277102776*lm^2*NL + 
        0.09895833333333333*lm^3*NL - 0.14785268678248098*NH + 
        3.131313224601999*lm*NH + 0.4971984277102776*lm^2*NH + 
        0.09895833333333333*lm^3*NH)}, 
     {0.13, CF*NC*(CF*(-5.742716398329949 - 4.309576891809153*lm - 
          2.0431253379851984*lm^2 - 1.7738*lm^3) + 
        CA*(-7.623878458010991 - 7.12181187850794*lm - 3.7592334366065883*
           lm^2 - 0.5419944444444444*lm^3) + 2.091268025644537*NM + 
        1.1620304552938114*lm*NM + 0.4953666854436221*lm^2*NM + 
        0.09854444444444445*lm^3*NM + 2.0988510457694454*NL + 
        1.1282304552938114*lm*NL + 0.4953666854436221*lm^2*NL + 
        0.09854444444444445*lm^3*NL - 0.14423002134018148*NH + 
        3.1282304552938114*lm*NH + 0.4953666854436221*lm^2*NH + 
        0.09854444444444445*lm^3*NH)}, 
     {0.135, CF*NC*(CF*(-5.74362732092998 - 4.310427901739403*lm - 
          2.0393463253641433*lm^2 - 1.76645*lm^3) + 
        CA*(-7.613851182002102 - 7.10354044200442*lm - 3.745088634139044*
           lm^2 - 0.5397486111111112*lm^3) + 2.0852662025962077*NM + 
        1.161717489162458*lm*NM + 0.4935744486313413*lm^2*NM + 
        0.0981361111111111*lm^3*NM + 2.0933938201298057*NL + 
        1.125267489162458*lm*NL + 0.4935744486313413*lm^2*NL + 
        0.0981361111111111*lm^3*NL - 0.14070012348042835*NH + 
        3.125267489162458*lm*NH + 0.4935744486313413*lm^2*NH + 
        0.0981361111111111*lm^3*NH)}, 
     {0.14, CF*NC*(CF*(-5.744991869036223 - 4.311968816110583*lm - 
          2.035889617661969*lm^2 - 1.7592*lm^3) + 
        CA*(-7.604688946607072 - 7.086051111819078*lm - 3.7312190498411573*
           lm^2 - 0.5375333333333333*lm^3) + 2.079415750073632*NM + 
        1.161622684462627*lm*NM + 0.4918216454256649*lm^2*NM + 
        0.09773333333333334*lm^3*NM + 2.0881173888903795*NL + 
        1.122422684462627*lm*NL + 0.4918216454256649*lm^2*NL + 
        0.09773333333333334*lm^3*NL - 0.13726285117929288*NH + 
        3.122422684462627*lm*NH + 0.4918216454256649*lm^2*NH + 
        0.09773333333333334*lm^3*NH)}, 
     {0.145, CF*NC*(CF*(-5.746770307472755 - 4.314173465953775*lm - 
          2.0327536529544106*lm^2 - 1.75205*lm^3) + 
        CA*(-7.596363196563983 - 7.069334051555276*lm - 3.717624206458292*
           lm^2 - 0.5353486111111111*lm^3) + 2.073710409017083*NM + 
        1.1617443631976556*lm*NM + 0.4901081890530228*lm^2*NM + 
        0.09733611111111111*lm^3*NM + 2.08301749186145*NL + 
        1.1196943631976557*lm*NL + 0.4901081890530228*lm^2*NL + 
        0.09733611111111111*lm^3*NL - 0.1339180142874287*NH + 
        3.1196943631976555*lm*NH + 0.4901081890530228*lm^2*NH + 
        0.09733611111111111*lm^3*NH)}, 
     {0.15, CF*NC*(CF*(-5.748924823779136 - 4.317015778469507*lm - 
          2.0299366168590245*lm^2 - 1.745*lm^3) + 
        CA*(-7.588845859568651 - 7.053379156744972*lm - 3.704303549595813*
           lm^2 - 0.5331944444444444*lm^3) + 2.0681439421480787*NM + 
        1.1620808164812038*lm*NM + 0.48843397871439026*lm^2*NM + 
        0.09694444444444444*lm^3*NM + 2.0780899543161833*NL + 
        1.1170808164812038*lm*NL + 0.48843397871439026*lm^2*NL + 
        0.09694444444444444*lm^3*NL - 0.13066537711691759*NH + 
        3.117080816481204*lm*NH + 0.48843397871439026*lm^2*NH + 
        0.09694444444444444*lm^3*NH)}, 
     {0.155, CF*NC*(CF*(-5.751419467222136 - 4.320469825057131*lm - 
          2.0274364576078123*lm^2 - 1.73805*lm^3) + 
        CA*(-7.582109365558253 - 7.038176087283544*lm - 3.6912564523246094*
           lm^2 - 0.5310708333333334*lm^3) + 2.062710140838427*NM + 
        1.1626303093687544*lm*NM + 0.4867989004226562*lm^2*NM + 
        0.09655833333333333*lm^3*NM + 2.0733306887359024*NL + 
        1.1145803093687545*lm*NL + 0.4867989004226562*lm^2*NL + 
        0.09655833333333333*lm^3*NL - 0.12750466086815404*NH + 
        3.1145803093687543*lm*NH + 0.4867989004226562*lm^2*NH + 
        0.09655833333333333*lm^3*NH)}, 
     {0.16, CF*NC*(CF*(-5.754220087493843 - 4.324509863537245*lm - 
          2.0252509000915144*lm^2 - 1.7312*lm^3) + 
        CA*(-7.576126661821528 - 7.0237142968786435*lm - 3.678482219472407*
           lm^2 - 0.5289777777777778*lm^3) + 2.0574028310469044*NM + 
        1.163391085218919*lm*NM + 0.48520282778286195*lm^2*NM + 
        0.09617777777777778*lm^3*NM + 2.06873569600615*NL + 
        1.1121910852189192*lm*NL + 0.48520282778286195*lm^2*NL + 
        0.09617777777777778*lm^3*NL - 0.12443554591080336*NH + 
        3.112191085218919*lm*NH + 0.48520282778286195*lm^2*NH + 
        0.09617777777777778*lm^3*NH)}, 
     {0.165, CF*NC*(CF*(-5.7572942735649235 - 4.329110375260271*lm - 
          2.0233774589680893*lm^2 - 1.72445*lm^3) + 
        CA*(-7.570871224546212 - 7.009983059833875*lm - 3.6659800916291383*
           lm^2 - 0.5269152777777778*lm^3) + 2.05221587844498*NM + 
        1.1643613696363357*lm*NM + 0.4836456227204494*lm^2*NM + 
        0.09580277777777778*lm^3*NM + 2.064301066149657*NL + 
        1.1099113696363356*lm*NL + 0.4836456227204494*lm^2*NL + 
        0.09580277777777778*lm^3*NL - 0.12145767393118234*NH + 
        3.1099113696363356*lm*NH + 0.4836456227204494*lm^2*NH + 
        0.09580277777777778*lm^3*NH)}, 
     {0.17, CF*NC*(CF*(-5.760611293058414 - 4.334246097698773*lm - 
          2.021813450917039*lm^2 - 1.7178*lm^3) + 
        CA*(-7.566317067319525 - 6.9969714954461*lm - 3.6537492488913177*
           lm^2 - 0.5248833333333334*lm^3) + 2.047143192835085*NM + 
        1.1655393740410753*lm*NM + 0.4821271361620577*lm^2*NM + 
        0.09543333333333333*lm^3*NM + 2.0600229786685573*NL + 
        1.1077393740410753*lm*NL + 0.4821271361620577*lm^2*NL + 
        0.09543333333333333*lm^3*NL - 0.11857064995698313*NH + 
        3.1077393740410755*lm*NH + 0.4821271361620577*lm^2*NH + 
        0.09543333333333333*lm^3*NH)}, 
     {0.175, CF*NC*(CF*(-5.764142032427245 - 4.339892053040905*lm - 
          2.020556006111985*lm^2 - 1.71125*lm^3) + 
        CA*(-7.562438747019276 - 6.984668590259788*lm - 3.641788814367551*
           lm^2 - 0.5228819444444445*lm^3) + 2.042178731950018*NM + 
        1.1669232989036937*lm*NM + 0.48064720867288807*lm^2*NM + 
        0.09506944444444444*lm^3*NM + 2.0558977025567957*NL + 
        1.105673298903694*lm*NL + 0.48064720867288807*lm^2*NL + 
        0.09506944444444444*lm^3*NL - 0.11577404426903866*NH + 
        3.1056732989036937*lm*NH + 0.48064720867288807*lm^2*NH + 
        0.09506944444444444*lm^3*NH)}, 
     {0.18, CF*NC*(CF*(-5.767858938153048 - 4.346023573234736*lm - 
          2.01960207897592*lm^2 - 1.7048*lm^3) + 
        CA*(-7.559211367468164 - 6.973063218391715*lm - 3.6300978574648646*
           lm^2 - 0.5209111111111111*lm^3) + 2.0373165047096755*NM + 
        1.1685113366801616*lm*NM + 0.47920567105421774*lm^2*NM + 
        0.09471111111111111*lm^3*NM + 2.05192159603431*NL + 
        1.1037113366801616*lm*NL + 0.47920567105421774*lm^2*NL + 
        0.09471111111111111*lm^3*NL - 0.11306739420878081*NH + 
        3.1037113366801616*lm*NH + 0.47920567105421774*lm^2*NH + 
        0.09471111111111111*lm^3*NH)}, 
     {0.185, CF*NC*(CF*(-5.771735959131293 - 4.3526163218758365*lm - 
          2.018948458276696*lm^2 - 1.69845*lm^3) + 
        CA*(-7.556610581169608 - 6.962144160113763*lm - 3.6186753969734347*
           lm^2 - 0.5189708333333334*lm^3) + 2.032550574000842*NM + 
        1.17030167447673*lm*NM + 0.4778023449042609*lm^2*NM + 
        0.09435833333333334*lm^3*NM + 2.0480911060467513*NL + 
        1.1018516744767302*lm*NL + 0.4778023449042609*lm^2*NL + 
        0.09435833333333334*lm^3*NL - 0.11045020588913734*NH + 
        3.10185167447673*lm*NH + 0.4778023449042609*lm^2*NH + 
        0.09435833333333334*lm^3*NH)}, 
     {0.19, CF*NC*(CF*(-5.775748490365716 - 4.359646313281685*lm - 
          2.01859177661435*lm^2 - 1.6922*lm^3) + 
        CA*(-7.554612589398025 - 6.951900118859554*lm - 3.607520403965496*
           lm^2 - 0.5170611111111111*lm^3) + 2.0278750590370134*NM + 
        1.1722924964712274*lm*NM + 0.47643704314524166*lm^2*NM + 
        0.09401111111111111*lm^3*NM + 2.0444027675680077*NL + 
        1.1000924964712273*lm*NL + 0.47643704314524166*lm^2*NL + 
        0.09401111111111111*lm^3*NL - 0.10792195581582957*NH + 
        3.1000924964712273*lm*NH + 0.47643704314524166*lm^2*NH + 
        0.09401111111111111*lm^3*NH)}, 
     {0.195, CF*NC*(CF*(-5.779873318061149 - 4.367089929054614*lm - 
          2.018528519346651*lm^2 - 1.68605*lm^3) + 
        CA*(-7.553194140878156 - 6.942319736801804*lm - 3.5966318045225876*
           lm^2 - 0.5151819444444444*lm^3) + 2.0232841373477384*NM + 
        1.1744819861142033*lm*NM + 0.4751095705192584*lm^2*NM + 
        0.09366944444444444*lm^3*NM + 2.040853202737315*NL + 
        1.0984319861142033*lm*NL + 0.4751095705192584*lm^2*NL + 
        0.09366944444444444*lm^3*NL - 0.10548209242534966*NH + 
        3.0984319861142033*lm*NH + 0.4751095705192584*lm^2*NH + 
        0.09366944444444444*lm^3*NH)}, 
     {0.2, NC*(CF^2*(-5.784088566176716 - 4.3749239323991205*lm - 
          2.018755032994728*lm^2 - 1.68*lm^3) + 
        CA*CF*(-7.552332529255685 - 6.9333916091309025*lm - 
          3.586008482303945*lm^2 - 0.5133333333333333*lm^3) + 
        CF*((2.0187720464406564 + 1.1768683281307*lm + 0.4738197240552627*
             lm^2 + 0.09333333333333334*lm^3)*NM + 
          (2.037439119858169 + 1.0968683281307*lm + 0.4738197240552627*lm^2 + 
            0.09333333333333334*lm^3)*NL + (-0.10313003754529822 + 
            3.0968683281306997*lm + 0.4738197240552627*lm^2 + 
            0.09333333333333334*lm^3)*NH))}, 
     {0.205, NC*(CF^2*(-5.788373644479509 - 4.383125480428372*lm - 
          2.0192675331666345*lm^2 - 1.67405*lm^3) + 
        CA*CF*(-7.552005589533955 - 6.925104297151102*lm - 
          3.575649280967583*lm^2 - 0.5115152777777778*lm^3) + 
        CF*((2.0143330851739734 + 1.1794497103411226*lm + 0.47256729350925747*
             lm^2 + 0.09300277777777778*lm^3)*NM + 
          (2.0341573122823458 + 1.0953997103411226*lm + 0.47256729350925747*
             lm^2 + 0.09300277777777778*lm^3)*NL + 
          (-0.1008651877822386 + 3.095399710341123*lm + 0.47256729350925747*
             lm^2 + 0.09300277777777778*lm^3)*NH))}, 
     {0.21, NC*(CF^2*(-5.792709198121334 - 4.391672134667912*lm - 
          2.020062112033181*lm^2 - 1.6682*lm^3) + 
        CA*CF*(-7.552191693628107 - 6.917446340298316*lm - 
          3.565553006454583*lm^2 - 0.5097277777777778*lm^3) + 
        CF*((2.0099616148724775 + 1.1822243253177014*lm + 0.4713520617796212*
             lm^2 + 0.09267777777777778*lm^3)*NM + 
          (2.0310046571990616 + 1.0940243253177016*lm + 0.4713520617796212*
             lm^2 + 0.09267777777777778*lm^3)*NL + 
          (-0.09868691584176102 + 3.0940243253177013*lm + 0.4713520617796212*
             lm^2 + 0.09267777777777778*lm^3)*NH))}, 
     {0.215, NC*(CF^2*(-5.797077058747078 - 4.400541869941258*lm - 
          2.0211347453872675*lm^2 - 1.66245*lm^3) + 
        CA*CF*(-7.552869745168028 - 6.9104062671727515*lm - 
          3.5557184291461095*lm^2 - 0.5079708333333334*lm^3) + 
        CF*((2.0056520602161982 + 1.1851903718912795*lm + 0.47017380529929265*
             lm^2 + 0.09235833333333333*lm^3)*NM + 
          (2.0279781143464906 + 1.0927403718912794*lm + 0.47017380529929265*
             lm^2 + 0.09235833333333333*lm^3)*NL + 
          (-0.09659457178503963 + 3.0927403718912796*lm + 0.47017380529929265*
             lm^2 + 0.09235833333333333*lm^3)*NH))}, 
     {0.22, NC*(CF^2*(-5.80146019713202 - 4.409713081801784*lm - 
          2.0224812993151655*lm^2 - 1.6568*lm^3) + 
        CA*CF*(-7.554019173664292 - 6.903972605670146*lm - 
          3.5461442859018564*lm^2 - 0.5062444444444445*lm^3) + 
        CF*((2.001398909927358 + 1.188346056521648*lm + 0.4690322944063981*
             lm^2 + 0.09204444444444444*lm^3)*NM + 
          (2.025074724660476 + 1.091546056521648*lm + 0.4690322944063981*
             lm^2 + 0.09204444444444444*lm^3)*NL + 
          (-0.09458748422580285 + 3.091546056521648*lm + 0.4690322944063981*
             lm^2 + 0.09204444444444444*lm^3)*NH))}, 
     {0.225, NC*(CF^2*(-5.805842677336481 - 4.41916459265749*lm - 
          2.0240975365057583*lm^2 - 1.65125*lm^3) + 
        CA*CF*(-7.555619928136522 - 6.89813389228702*lm - 
          3.536829281987871*lm^2 - 0.5045486111111112*lm^3) + 
        CF*((1.9971967172782616 + 1.191689594543304*lm + 0.4679272936947644*
             lm^2 + 0.09173611111111112*lm^3)*NM + 
          (2.022291608873221 + 1.090439594543304*lm + 0.4679272936947644*
             lm^2 + 0.09173611111111112*lm^3)*NL + 
          (-0.09266496147131173 + 3.090439594543304*lm + 0.4679272936947644*
             lm^2 + 0.09173611111111112*lm^3)*NH))}, 
     {0.23, NC*(CF^2*(-5.810209612359218 - 4.428875656719696*lm - 
          2.0259791222215333*lm^2 - 1.6458*lm^3) + 
        CA*CF*(-7.557652470290884 - 6.892878680668051*lm - 
          3.527772092901024*lm^2 - 0.5028833333333333*lm^3) + 
        CF*((1.9930401004401896 + 1.1952192112973261*lm + 0.4668585623456407*
             lm^2 + 0.09143333333333334*lm^3)*NM + 
          (2.019625966072986 + 1.089419211297326*lm + 0.4668585623456407*
             lm^2 + 0.09143333333333334*lm^3)*NL + 
          (-0.09082629261065285 + 3.089419211297326*lm + 0.4668585623456407*
             lm^2 + 0.09143333333333334*lm^3)*NH))}, 
     {0.235, NC*(CF^2*(-5.814547121265352 - 4.438825963893003*lm - 
          2.028121629953166*lm^2 - 1.64045*lm^3) + 
        CA*CF*(-7.560097767322374 - 6.888195549457132*lm - 
          3.518971366096801*lm^2 - 0.5012486111111111*lm^3) + 
        CF*((1.9889237426910613 + 1.1989331431590204*lm + 0.46582585444184255*
             lm^2 + 0.09113611111111111*lm^3)*NM + 
          (2.0170750722343276 + 1.0884831431590205*lm + 0.46582585444184255*
             lm^2 + 0.09113611111111111*lm^3)*NL + 
          (-0.08907074855339134 + 3.0884831431590207*lm + 0.46582585444184255*
             lm^2 + 0.09113611111111111*lm^3)*NH))}, 
     {0.24, NC*(CF^2*(-5.818842287760461 - 4.448995642711755*lm - 
          2.030520546777768*lm^2 - 1.6352*lm^3) + 
        CA*CF*(-7.562937284408076 - 6.884073109507925*lm - 
          3.51042572262654*lm^2 - 0.49964444444444445*lm^3) + 
        CF*((1.9848423924976821 + 1.2028296384700659*lm + 0.4648289192654316*
             lm^2 + 0.09084444444444445*lm^3)*NM + 
          (2.0146362787270795 + 1.0876296384700659*lm + 0.4648289192654316*
             lm^2 + 0.09084444444444445*lm^3)*NL + 
          (-0.0873975830213967 + 3.087629638470066*lm + 0.4648289192654316*
             lm^2 + 0.09084444444444445*lm^3)*NH))}, 
     {0.245, NC*(CF^2*(-5.823083120179142 - 4.459365262417589*lm - 
          2.0331712784392684*lm^2 - 1.63005*lm^3) + 
        CA*CF*(-7.566152976949174 - 6.88050001050459*lm - 
          3.5021337586897765*lm^2 - 0.49807083333333335*lm^3) + 
        CF*((1.980790863486627 + 1.2069069583830614*lm + 0.4638675015799594*
             lm^2 + 0.09055833333333334*lm^3)*NM + 
          (2.0123070108111887 + 1.0868569583830614*lm + 0.4638675015799594*
             lm^2 + 0.09055833333333334*lm^3)*NL + 
          (-0.08580603349644368 + 3.0868569583830614*lm + 0.4638675015799594*
             lm^2 + 0.09055833333333334*lm^3)*NH))}, 
     {0.25, NC*(CF^2*(-5.8272585128539625 - 4.469915834263177*lm - 
          2.0360691541679836*lm^2 - 1.625*lm^3) + 
        CA*CF*(-7.569727282612369 - 6.877464947038755*lm - 
          3.4940940471068838*lm^2 - 0.4965277777777778*lm^3) + 
        CF*((1.9767640343162984 + 1.2111633776256547*lm + 0.46294134189822134*
             lm^2 + 0.09027777777777778*lm^3)*NM + 
          (2.0100847661235197 + 1.0861633776256547*lm + 0.46294134189822134*
             lm^2 + 0.09027777777777778*lm^3)*NL + 
          (-0.08429532212599959 + 3.0861633776256547*lm + 0.46294134189822134*
             lm^2 + 0.09027777777777778*lm^3)*NH))}, 
     {0.255, NC*(CF^2*(-5.831358208829006 - 4.480628812118866*lm - 
          2.0392094312551183*lm^2 - 1.62005*lm^3) + 
        CA*CF*(-7.573643113214994 - 6.8749566641847455*lm - 
          3.486305138716842*lm^2 - 0.49501527777777776*lm^3) + 
        CF*((1.9727568484613502 + 1.2155971851907696*lm + 0.4620501767363955*
             lm^2 + 0.09000277777777778*lm^3)*NM + 
          (2.0079671131619024 + 1.0855471851907696*lm + 0.4620501767363955*
             lm^2 + 0.09000277777777778*lm^3)*NL + 
          (-0.08286465658943806 + 3.0855471851907694*lm + 0.4620501767363955*
             lm^2 + 0.09000277777777778*lm^3)*NH))}, 
     {0.26, NC*(CF^2*(-5.8353727638810104 - 4.4914860924514315*lm - 
          2.0425872993967724*lm^2 - 1.6152*lm^3) + 
        CA*CF*(-7.577883846492594 - 6.872963962611379*lm - 
          3.4787655637045694*lm^2 - 0.4935333333333333*lm^3) + 
        CF*((1.9687643139194733 + 1.2202066849588709*lm + 0.46119373885537623*
             lm^2 + 0.08973333333333333*lm^3)*NM + 
          (2.0059516897709764 + 1.0850066849588709*lm + 0.46119373885537623*
             lm^2 + 0.08973333333333333*lm^3)*NL + 
          (-0.08151323092676152 + 3.085006684958871*lm + 0.46119373885537623*
             lm^2 + 0.08973333333333333*lm^3)*NH))}, 
     {0.265, NC*(CF^2*(-5.839293511810401 - 4.502470013737526*lm - 
          2.046197884820956*lm^2 - 1.61045*lm^3) + 
        CA*CF*(-7.582433317782946 - 6.87147570326536*lm - 
          3.4714738328619585*lm^2 - 0.4920819444444444*lm^3) + 
        CF*((1.9647815028495028 + 1.224990196257681*lm + 0.4603717574900531*
             lm^2 + 0.08946944444444445*lm^3)*NM + 
          (2.0040362016337263 + 1.084540196257681*lm + 0.4603717574900531*
             lm^2 + 0.08946944444444445*lm^3)*NL + 
          (-0.08024022633177325 + 3.084540196257681*lm + 0.4603717574900531*
             lm^2 + 0.08946944444444445*lm^3)*NH))}, 
     {0.27, NC*(CF^2*(-5.843112530964171 - 4.5135633553683885*lm - 
          2.0500362542101453*lm^2 - 1.6058*lm^3) + 
        CA*CF*(-7.587275811656227 - 6.870480811658315*lm - 
          3.4644284387864333*lm^2 - 0.4906611111111111*lm^3) + 
        CF*((1.960803551148865 + 1.2299460543642913*lm + 0.4595839585672303*
             lm^2 + 0.08921111111111112*lm^3)*NM + 
          (2.0022184207720684 + 1.0841460543642913*lm + 0.4595839585672303*
             lm^2 + 0.08921111111111112*lm^3)*NL + 
          (-0.07904481191150896 + 3.0841460543642913*lm + 0.4595839585672303*
             lm^2 + 0.08921111111111112*lm^3)*NH))}, 
     {0.275, NC*(CF^2*(-5.846822611952489 - 4.524749336097094*lm - 
          2.054097418431032*lm^2 - 1.60125*lm^3) + 
        CA*CF*(-7.59239605351733 - 6.869968281786895*lm - 
          3.457627857020593*lm^2 - 0.4892708333333333*lm^3) + 
        CF*((1.95682565797756 + 1.2350726109541847*lm + 0.4588300649128351*
             lm^2 + 0.08895833333333333*lm^3)*NM + 
          (2.000496184059346 + 1.0838226109541849*lm + 0.4588300649128351*
             lm^2 + 0.08895833333333333*lm^3)*NL + 
          (-0.07792614541361982 + 3.0838226109541846*lm + 0.4588300649128351*
             lm^2 + 0.08895833333333333*lm^3)*NH))}, 
     {0.28, NC*(CF^2*(-5.850417226521129 - 4.536011612074825*lm - 
          2.058376336082292*lm^2 - 1.5968*lm^3) + 
        CA*CF*(-7.597779201203025 - 6.869927179712862*lm - 
          3.451070547136256*lm^2 - 0.48791111111111113*lm^3) + 
        CF*((1.9528430852351397 + 1.2403682345013112*lm + 0.4581097964490162*
             lm^2 + 0.08871111111111112*lm^3)*NM + 
          (1.9988673917471775 + 1.0835682345013111*lm + 0.4581097964490162*
             lm^2 + 0.08871111111111112*lm^3)*NL + 
          (-0.07688337392328921 + 3.083568234501311*lm + 0.4581097964490162*
             lm^2 + 0.08871111111111112*lm^3)*NH))}, 
     {0.285, NC*(CF^2*(-5.8538904975421895 - 4.547334274518319*lm - 
          2.0628679168704824*lm^2 - 1.59245*lm^3) + 
        CA*CF*(-7.60341083659381 - 6.870346646827992*lm - 
          3.444754953765981*lm^2 - 0.48658194444444447*lm^3) + 
        CF*((1.9488511569964895 + 1.2458313106330041*lm + 0.4574228703816935*
             lm^2 + 0.08846944444444445*lm^3)*NM + 
          (1.9973300060087311 + 1.0833813106330041*lm + 0.4574228703816935*
             lm^2 + 0.08846944444444445*lm^3)*NL + 
          (-0.07591563453116625 + 3.083381310633004*lm + 0.4574228703816935*
             lm^2 + 0.08846944444444445*lm^3)*NH))}, 
     {0.29, NC*(CF^2*(-5.857237170086095 - 4.558701847046836*lm - 
          2.067567024823474*lm^2 - 1.5882*lm^3) + 
        CA*CF*(-7.609276957257723 - 6.871215902826564*lm - 
          3.4386795075849506*lm^2 - 0.48528333333333334*lm^3) + 
        CF*((1.9448452589116316 + 1.2514602424432226*lm + 0.4567690013790819*
             lm^2 + 0.08823333333333333*lm^3)*NM + 
          (1.995882049500171 + 1.0832602424432227*lm + 0.4567690013790819*
             lm^2 + 0.08823333333333333*lm^3)*NL + 
          (-0.07502205497370679 + 3.083260242443223*lm + 0.4567690013790819*
             lm^2 + 0.08823333333333333*lm^3)*NH))}, 
     {0.295, NC*(CF^2*(-5.860452583538566 - 4.570099282723451*lm - 
          2.07246848135022*lm^2 - 1.58405*lm^3) + 
        CA*CF*(-7.615363968141148 - 6.872524248406455*lm - 
          3.4328426262459004*lm^2 - 0.48401527777777775*lm^3) + 
        CF*((1.9408208375742493 + 1.2572534507673114*lm + 0.4561479017416789*
             lm^2 + 0.08800277777777778*lm^3)*NM + 
          (1.9945216039417415 + 1.0832034507673116*lm + 0.4561479017416789*
             lm^2 + 0.08800277777777778*lm^3)*NL + 
          (-0.0742017542472285 + 3.0832034507673116*lm + 0.4561479017416789*
             lm^2 + 0.08800277777777778*lm^3)*NH))}, 
     {0.3, NC*(CF^2*(-5.863532644726956 - 4.581511960832359*lm - 
          2.0775670681550795*lm^2 - 1.58*lm^3) + 
        CA*CF*(-7.621658673319656 - 6.874261067718204*lm - 
          3.4272427152696077*lm^2 - 0.48277777777777775*lm^3) + 
        CF*((1.9367733998631615 + 1.263209374421222*lm + 0.4555592815641711*
             lm^2 + 0.08777777777777777*lm^3)*NM + 
          (1.9932468087197055 + 1.0832093744212221*lm + 0.4555592815641711*
             lm^2 + 0.08777777777777777*lm^3)*NL + 
          (-0.07345384319690793 + 3.083209374421222*lm + 0.4555592815641711*
             lm^2 + 0.08777777777777777*lm^3)*NH))}, 
     {0.305, NC*(CF^2*(-5.866473802021196 - 4.592925683421064*lm - 
          2.082857530014388*lm^2 - 1.57605*lm^3) + 
        CA*CF*(-7.628148267820164 - 6.8764158305799254*lm - 
          3.421878168893285*lm^2 - 0.48157083333333334*lm^3) + 
        CF*((1.9326985122605593 + 1.2693264704079006*lm + 0.4550028488896882*
             lm^2 + 0.08755833333333334*lm^3)*NM + 
          (1.9920558595101379 + 1.0832764704079005*lm + 0.4550028488896882*
             lm^2 + 0.08755833333333334*lm^3)*NL + 
          (-0.07277742508187601 + 3.0832764704079003*lm + 0.4550028488896882*
             lm^2 + 0.08755833333333334*lm^3)*NH))}, 
     {0.31, NC*(CF^2*(-5.869273020375485 - 4.604326671633673*lm - 
          2.0883345774224815*lm^2 - 1.5722*lm^3) + 
        CA*CF*(-7.6348203295241435 - 6.878978094474579*lm - 
          3.4167473708790914*lm^2 - 0.48039444444444446*lm^3) + 
        CF*((1.9285918001504392 + 1.2756032140933364*lm + 0.45447830985680454*
             lm^2 + 0.08734444444444445*lm^3)*NM + 
          (1.9909470069253823 + 1.0834032140933365*lm + 0.45447830985680454*
             lm^2 + 0.08734444444444445*lm^3)*NL + 
          (-0.0721715961175014 + 3.0834032140933365*lm + 0.45447830985680454*
             lm^2 + 0.08734444444444445*lm^3)*NH))}, 
     {0.315, NC*(CF^2*(-5.871927757277736 - 4.6157015618592965*lm - 
          2.0939928891139314*lm^2 - 1.56845*lm^3) + 
        CA*CF*(-7.641662811160224 - 6.8819375063448955*lm - 
          3.4118486952848124*lm^2 - 0.4792486111111111*lm^3) + 
        CF*((1.9244489471003252 + 1.2820380993545715*lm + 0.45398536883966284*
             lm^2 + 0.08713611111111111*lm^3)*NM + 
          (1.9899185551838154 + 1.0835880993545715*lm + 0.45398536883966284*
             lm^2 + 0.08713611111111111*lm^3)*NL + 
          (-0.07163544599588903 + 3.0835880993545715*lm + 0.45398536883966284*
             lm^2 + 0.08713611111111111*lm^3)*NH))}, 
     {0.32, NC*(CF^2*(-5.874435939574768 - 4.627037401717348*lm - 
          2.0998271144683303*lm^2 - 1.5648*lm^3) + 
        CA*CF*(-7.648664032393308 - 6.8852838042000775*lm - 
          3.4071805071986563*lm^2 - 0.47813333333333335*lm^3) + 
        CF*((1.9202656941290743 + 1.2886296387017926*lm + 0.4535237285815739*
             lm^2 + 0.08693333333333333*lm^3)*NM + 
          (1.988968860803414 + 1.0838296387017927*lm + 0.4535237285815739*
             lm^2 + 0.08693333333333333*lm^3)*NL + 
          (-0.07116805838556411 + 3.0838296387017925*lm + 0.4535237285815739*
             lm^2 + 0.08693333333333333*lm^3)*NH))}, 
     {0.325, NC*(CF^2*(-5.876795941142164 - 4.638321645899681*lm - 
          2.105831875803583*lm^2 - 1.56125*lm^3) + 
        CA*CF*(-7.655812672016253 - 6.889006818547388*lm - 
          3.4027411634399836*lm^2 - 0.47704861111111113*lm^3) + 
        CF*((1.916037838963282 + 1.2953763633764688*lm + 0.4530930903224213*
             lm^2 + 0.08673611111111111*lm^3)*NM + 
          (1.9880963313194975 + 1.0841263633764688*lm + 0.4530930903224213*
             lm^2 + 0.08673611111111111*lm^3)*NL + 
          (-0.07076851141125852 + 3.084126363376469*lm + 0.4530930903224213*
             lm^2 + 0.08673611111111111*lm^3)*NH))}, 
     {0.33, NC*(CF^2*(-5.879006561368686 - 4.649542151887715*lm - 
          2.1120017705633067*lm^2 - 1.5578*lm^3) + 
        CA*CF*(-7.663097760249191 - 6.893096473660783*lm - 
          3.398529013227677*lm^2 - 0.47599444444444444*lm^3) + 
        CF*((1.9117612352845519 + 1.3022768234273459*lm + 0.4526931539201837*
             lm^2 + 0.08654444444444444*lm^3)*NM + 
          (1.9872994240269006 + 1.0844768234273459*lm + 0.4526931539201837*
             lm^2 + 0.08654444444444444*lm^3)*NL + 
          (-0.07043587811466626 + 3.084476823427346*lm + 0.4526931539201837*
             lm^2 + 0.08654444444444444*lm^3)*NH))}, 
     {0.335, NC*(CF^2*(-5.881067004426101 - 4.660687175561167*lm - 
          2.118331373403598*lm^2 - 1.55445*lm^3) + 
        CA*CF*(-7.670508671150712 - 6.897542788697845*lm - 
          3.394542398817766*lm^2 - 0.47497083333333334*lm^3) + 
        CF*((1.9074317919696822 + 1.3093295877659776*lm + 0.45232361796686654*
             lm^2 + 0.08635833333333333*lm^3)*NM + 
          (1.9865766447467383 + 1.0848795877659776*lm + 0.45232361796686654*
             lm^2 + 0.08635833333333333*lm^3)*NL + 
          (-0.07016922689698918 + 3.0848795877659776*lm + 0.45232361796686654*
             lm^2 + 0.08635833333333333*lm^3)*NH))}, 
     {0.34, NC*(CF^2*(-5.882976859296215 - 4.671745366713486*lm - 
          2.1248152381841403*lm^2 - 1.5512*lm^3) + 
        CA*CF*(-7.678035115144391 - 6.902335878675506*lm - 
          3.3907796561118206*lm^2 - 0.4739777777777778*lm^3) + 
        CF*((1.9030454723256063 + 1.316533244203344*lm + 0.45198417989911893*
             lm^2 + 0.08617777777777778*lm^3)*NM + 
          (1.9859265466178364 + 1.0853332442033439*lm + 0.45198417989911893*
             lm^2 + 0.08617777777777778*lm^3)*NL + 
          (-0.06996762194405026 + 3.0853332442033437*lm + 0.45198417989911893*
             lm^2 + 0.08617777777777778*lm^3)*NH))}, 
     {0.345, NC*(CF^2*(-5.884736080527863 - 4.682705764487859*lm - 
          2.1314478998683137*lm^2 - 1.54805*lm^3) + 
        CA*CF*(-7.685667131663449 - 6.907465955314275*lm - 
          3.38723911523754*lm^2 - 0.4730152777777778*lm^3) + 
        CF*((1.898598293320754 + 1.3238863994689953*lm + 0.4516745361037952*
             lm^2 + 0.08600277777777778*lm^3)*NM + 
          (1.9853477289128323 + 1.0858363994689952*lm + 0.4516745361037952*
             lm^2 + 0.08600277777777778*lm^3)*NL + 
          (-0.06983012363471187 + 3.0858363994689952*lm + 0.4516745361037952*
             lm^2 + 0.08600277777777778*lm^3)*NH))}, 
     {0.35, NC*(CF^2*(-5.886344969697525 - 4.69355779274638*lm - 
          2.1382238763367183*lm^2 - 1.545*lm^3) + 
        CA*CF*(-7.693395081915752 - 6.912923327760039*lm - 
          3.383919101102886*lm^2 - 0.47208333333333335*lm^3) + 
        CF*((1.894086324814323 + 1.3313876792140604*lm + 0.4513943820187066*
             lm^2 + 0.08583333333333333*lm^3)*NM + 
          (1.9848388358788764 + 1.0863876792140605*lm + 0.4513943820187066*
             lm^2 + 0.08583333333333333*lm^3)*NL + 
          (-0.06975578893329838 + 3.0863876792140603*lm + 0.4513943820187066*
             lm^2 + 0.08583333333333333*lm^3)*NH))}, 
     {0.355, NC*(CF^2*(-5.887804157548166 - 4.704291255383908*lm - 
          2.1451376701182734*lm^2 - 1.54205*lm^3) + 
        CA*CF*(-7.701209641770847 - 6.9186984031918275*lm - 
          3.380817933925028*lm^2 - 0.47118194444444444*lm^3) + 
        CF*((1.8895056887848138 + 1.3390357279993488*lm + 0.45114341222879295*
             lm^2 + 0.08566944444444445*lm^3)*NM + 
          (1.9843985556028214 + 1.0869857279993487*lm + 0.45114341222879295*
             lm^2 + 0.08566944444444445*lm^3)*NL + 
          (-0.06974367176668733 + 3.0869857279993487*lm + 0.45114341222879295*
             lm^2 + 0.08566944444444445*lm^3)*NH))}, 
     {0.36, NC*(CF^2*(-5.889114586781743 - 4.714896331597159*lm - 
          2.152183770042813*lm^2 - 1.5392*lm^3) + 
        CA*CF*(-7.709101794770209 - 6.924781687323418*lm - 
          3.377933929735304*lm^2 - 0.4703111111111111*lm^3) + 
        CF*((1.8848525585590328 + 1.3468292092696998*lm + 0.45092132055793405*
             lm^2 + 0.08551111111111111*lm^3)*NM + 
          (1.984025618900725 + 1.0876292092696997*lm + 0.45092132055793405*
             lm^2 + 0.08551111111111111*lm^3)*NL + 
          (-0.0697928233867002 + 3.0876292092697*lm + 0.45092132055793405*
             lm^2 + 0.08551111111111111*lm^3)*NH))}, 
     {0.365, NC*(CF^2*(-5.890277495481764 - 4.725363571118593*lm - 
          2.1593566528188943*lm^2 - 1.53645*lm^3) + 
        CA*CF*(-7.717062825261533 - 6.931163784806062*lm - 
          3.3752654008613288*lm^2 - 0.46947083333333334*lm^3) + 
        CF*((1.8801231580426525 + 1.3547668053156456*lm + 0.45072780015660524*
             lm^2 + 0.08535833333333333*lm^3)*NM + 
          (1.9837187982314617 + 1.0883168053156456*lm + 0.45072780015660524*
             lm^2 + 0.08535833333333333*lm^3)*NL + 
          (-0.06990229271839278 + 3.0883168053156456*lm + 0.45072780015660524*
             lm^2 + 0.08535833333333333*lm^3)*NH))}, 
     {0.37, NC*(CF^2*(-5.891294401143047 - 4.735683889423907*lm - 
          2.166650784540323*lm^2 - 1.5338*lm^3) + 
        CA*CF*(-7.725084311657487 - 6.937835399539155*lm - 
          3.372810656387321*lm^2 - 0.4686611111111111*lm^3) + 
        CF*((1.8753137609533066 + 1.3628472172233723*lm + 0.4505625435855735*
             lm^2 + 0.08521111111111111*lm^3)*NM + 
          (1.9834769066341917 + 1.0890472172233725*lm + 0.4505625435855735*
             lm^2 + 0.08521111111111111*lm^3)*NL + 
          (-0.07007112669481579 + 3.0890472172233725*lm + 0.4505625435855735*
             lm^2 + 0.08521111111111111*lm^3)*NH))}, 
     {0.375, NC*(CF^2*(-5.892167085286722 - 4.745848562921084*lm - 
          2.1740606221247147*lm^2 - 1.53125*lm^3) + 
        CA*CF*(-7.733158119819026 - 6.944787334895198*lm - 
          3.370568002593663*lm^2 - 0.4678819444444444*lm^3) + 
        CF*((1.8704206900570899 + 1.3710691648139077*lm + 0.4504252428958175*
             lm^2 + 0.08506944444444445*lm^3)*NM + 
          (1.9832987966894184 + 1.0898191648139077*lm + 0.4504252428958175*
             lm^2 + 0.08506944444444445*lm^3)*NL + 
          (-0.07029837057878931 + 3.0898191648139077*lm + 0.4504252428958175*
             lm^2 + 0.08506944444444445*lm^3)*NH))}, 
     {0.38, NC*(CF^2*(-5.892897578639274 - 4.755849224128316*lm - 
          2.1815806146872374*lm^2 - 1.5288*lm^3) + 
        CA*CF*(-7.74127639656312 - 6.9520104938649805*lm - 
          3.368535743376656*lm^2 - 0.46713333333333334*lm^3) + 
        CF*((1.865440316409248 + 1.3794313865723835*lm + 0.45031558970484653*
             lm^2 + 0.08493333333333333*lm^3)*NM + 
          (1.9831833595033235 + 1.0906313865723836*lm + 0.45031558970484653*
             lm^2 + 0.08493333333333333*lm^3)*NL + 
          (-0.0705830682722084 + 3.0906313865723836*lm + 0.45031558970484653*
             lm^2 + 0.08493333333333333*lm^3)*NH))}, 
     {0.385, NC*(CF^2*(-5.893488146855201 - 4.765677856847437*lm - 
          2.189205204852506*lm^2 - 1.52645*lm^3) + 
        CA*CF*(-7.749431563294437 - 6.95949587912853*lm - 
          3.366712180649377*lm^2 - 0.4664152777777778*lm^3) + 
        CF*((1.860369058599754 + 1.387932639568175*lm + 0.4502332752695837*
             lm^2 + 0.08480277777777778*lm^3)*NM + 
          (1.9831295237150615 + 1.0914826395681752*lm + 0.4502332752695837*
             lm^2 + 0.08480277777777778*lm^3)*NL + 
          (-0.07092426261337317 + 3.091482639568175*lm + 0.4502332752695837*
             lm^2 + 0.08480277777777778*lm^3)*NH))}, 
     {0.39, NC*(CF^2*(-5.893941276763646 - 4.775326791338894*lm - 
          2.196928830007451*lm^2 - 1.5242*lm^3) + 
        CA*CF*(-7.757616309760369 - 6.967234593056974*lm - 
          3.365095614724499*lm^2 - 0.4657277777777778*lm^3) + 
        CF*((1.8552033820043938 + 1.396571699366654*lm + 0.4501779905559695*
             lm^2 + 0.08467777777777778*lm^3)*NM + 
          (1.9831362545266678 + 1.092371699366654*lm + 0.4501779905559695*
             lm^2 + 0.08467777777777778*lm^3)*NL + 
          (-0.07132099566281379 + 3.092371699366654*lm + 0.4501779905559695*
             lm^2 + 0.08467777777777778*lm^3)*NH))}, 
     {0.395, NC*(CF^2*(-5.894259663120034 - 4.784788699503801*lm - 
          2.204745923497838*lm^2 - 1.52205*lm^3) + 
        CA*CF*(-7.765823587928535 - 6.975217837650175*lm - 
          3.363684344679895*lm^2 - 0.4650708333333333*lm^3) + 
        CF*((1.849939798041911 + 1.405347359933246*lm + 0.4501494263054355*
             lm^2 + 0.08455833333333333*lm^3)*NM + 
          (1.9832025527552217 + 1.093297359933246*lm + 0.4501494263054355*
             lm^2 + 0.08455833333333333*lm^3)*NL + 
          (-0.07177230897805886 + 3.093297359933246*lm + 0.4501494263054355*
             lm^2 + 0.08455833333333333*lm^3)*NH))}, 
     {0.4, NC*(CF^2*(-5.894446195844498 - 4.794056590078041*lm - 
          2.212650915770965*lm^2 - 1.52*lm^3) + 
        CA*CF*(-7.774046605985773 - 6.98343691441464*lm - 
          3.362476668707795*lm^2 - 0.46444444444444444*lm^3) + 
        CF*((1.8445748634377048 + 1.4142584335304371*lm + 0.4501472730983869*
             lm^2 + 0.08444444444444445*lm^3)*NM + 
          (1.983327453906897 + 1.094258433530437*lm + 0.4501472730983869*
             lm^2 + 0.08444444444444445*lm^3)*NL + 
          (-0.0722772438777758 + 3.0942584335304373*lm + 0.4501472730983869*
             lm^2 + 0.08444444444444445*lm^3)*NH))}, 
     {0.405, NC*(CF^2*(-5.894503947729497 - 4.803123803842982*lm - 
          2.220638235466953*lm^2 - 1.51805*lm^3) + 
        CA*CF*(-7.7822788224574575 - 6.9918832241859326*lm - 
          3.3614708844482357*lm^2 - 0.4638486111111111*lm^3) + 
        CF*((1.8391051794945072 + 1.4233037506083204*lm + 0.45017122141483074*
             lm^2 + 0.08433611111111111*lm^3)*NM + 
          (1.9835100272725164 + 1.0952537506083204*lm + 0.45017122141483074*
             lm^2 + 0.08433611111111111*lm^3)*NL + 
          (-0.07283484169569203 + 3.0952537506083204*lm + 0.45017122141483074*
             lm^2 + 0.08433611111111111*lm^3)*NH))}, 
     {0.41, NC*(CF^2*(-5.89443616259975 - 4.811984008856929*lm - 
          2.2287023104609163*lm^2 - 1.5162*lm^3) + 
        CA*CF*(-7.790513940445876 - 7.000548266899536*lm - 
          3.360665289307502*lm^2 - 0.4632833333333333*lm^3) + 
        CF*((1.833527391370426 + 1.4324821596892487*lm + 0.4502209616922731*
             lm^2 + 0.08423333333333333*lm^3)*NM + 
          (1.9837493750442237 + 1.0962821596892487*lm + 0.4502209616922731*
             lm^2 + 0.08423333333333333*lm^3)*NL + 
          (-0.07344414402468798 + 3.0962821596892485*lm + 0.4502209616922731*
             lm^2 + 0.08423333333333333*lm^3)*NH))}, 
     {0.415, NC*(CF^2*(-5.89424624390817 - 4.820631195711045*lm - 
          2.236837568858172*lm^2 - 1.51445*lm^3) + 
        CA*CF*(-7.798745901986256 - 7.009423641313876*lm - 
          3.3600581807622194*lm^2 - 0.4627486111111111*lm^3) + 
        CF*((1.8278381873646776 + 1.4417925272471053*lm + 0.45029618438100955*
             lm^2 + 0.0841361111111111*lm^3)*NM + 
          (1.9840446314528795 + 1.0973425272471053*lm + 0.45029618438100955*
             lm^2 + 0.0841361111111111*lm^3)*NL + 
          (-0.07410419295143529 + 3.0973425272471053*lm + 0.45029618438100955*
             lm^2 + 0.0841361111111111*lm^3)*NH))}, 
     {0.42, NC*(CF^2*(-5.893937743752137 - 4.829059672813108*lm - 
          2.2450384399445706*lm^2 - 1.5128*lm^3) + 
        CA*CF*(-7.80696888251898 - 7.018501044688963*lm - 
          3.35964785664973*lm^2 - 0.46224444444444446*lm^3) + 
        CF*((1.8220342982113067 + 1.4512337375816804*lm + 0.45039657999692057*
             lm^2 + 0.08404444444444445*lm^3)*NM + 
          (1.984394961925783 + 1.0984337375816804*lm + 0.45039657999692057*
             lm^2 + 0.08404444444444445*lm^3)*NL + 
          (-0.07481403128193775 + 3.0984337375816806*lm + 0.45039657999692057*
             lm^2 + 0.08404444444444445*lm^3)*NH))}, 
     {0.425, NC*(CF^2*(-5.893514352295013 - 4.837264061702172*lm - 
          2.2532993550938922*lm^2 - 1.51125*lm^3) + 
        CA*CF*(-7.815177285476408 - 7.027772272423893*lm - 
          3.359432615445356*lm^2 - 0.46177083333333335*lm^3) + 
        CF*((1.8161124963811361 + 1.460804692688603*lm + 0.4505218391718829*
             lm^2 + 0.08395833333333333*lm^3)*NM + 
          (1.9847995622643202 + 1.0995546926886028*lm + 0.4505218391718829*
             lm^2 + 0.08395833333333333*lm^3)*NL + 
          (-0.07557270275831633 + 3.099554692688603*lm + 0.4505218391718829*
             lm^2 + 0.08395833333333333*lm^3)*NH))}, 
     {0.43, NC*(CF^2*(-5.892979887578362 - 4.845239292396861*lm - 
          2.2616147486341855*lm^2 - 1.5098*lm^3) + 
        CA*CF*(-7.8233657369826926 - 7.037229217656247*lm - 
          3.359410756527112*lm^2 - 0.4613277777777778*lm^3) + 
        CF*((1.8100695953921622 + 1.470504312125248*lm + 0.4506716527018992*
             lm^2 + 0.08387777777777777*lm^3)*NM + 
          (1.985257657841136 + 1.100704312125248*lm + 0.4506716527018992*
             lm^2 + 0.08387777777777777*lm^3)*NL + 
          (-0.07637925226716603 + 3.1007043121252478*lm + 0.4506716527018992*
             lm^2 + 0.08387777777777777*lm^3)*NH))}, 
     {0.435, NC*(CF^2*(-5.8923382857109 - 4.852980598779786*lm - 
          2.2699790586748247*lm^2 - 1.50845*lm^3) + 
        CA*CF*(-7.83152908066489 - 7.046863870826248*lm - 
          3.359580580428419*lm^2 - 0.4609152777777778*lm^3) + 
        CF*((1.8039024491285789 + 1.4803315328730131*lm + 0.4508457115930458*
             lm^2 + 0.08380277777777778*lm^3)*NM + 
          (1.98576850281643 + 1.1018815328730132*lm + 0.4508457115930458*
             lm^2 + 0.08380277777777778*lm^3)*NL + 
          (-0.07723272603979715 + 3.101881532873013*lm + 0.4508457115930458*
             lm^2 + 0.08380277777777778*lm^3)*NH))}, 
     {0.44, NC*(CF^2*(-5.891593591420685 - 4.860483514020266*lm - 
          2.27838672789597*lm^2 - 1.5072*lm^3) + 
        CA*CF*(-7.839662372573633 - 7.0566683192083195*lm - 
          3.3599403890793242*lm^2 - 0.46053333333333335*lm^3) + 
        CF*((1.7976079511685759 + 1.4902853091963282*lm + 0.45104370710533165*
             lm^2 + 0.08373333333333334*lm^3)*NM + 
          (1.986331379372975 + 1.1030853091963282*lm + 0.45104370710533165*
             lm^2 + 0.08373333333333334*lm^3)*NL + 
          (-0.07813217184466138 + 3.103085309196328*lm + 0.45104370710533165*
             lm^2 + 0.08373333333333334*lm^3)*NH))}, 
     {0.445, NC*(CF^2*(-5.890749948957602 - 4.867743866037362*lm - 
          2.2868322043020477*lm^2 - 1.50605*lm^3) + 
        CA*CF*(-7.847760876211615 - 7.066634746412577*lm - 
          3.3604884860367368*lm^2 - 0.46018194444444444*lm^3) + 
        CF*((1.7911830341210422 + 1.500364612498739*lm + 0.4512653307945582*
             lm^2 + 0.08366944444444445*lm^3)*NM + 
          (1.9869455969694618 + 1.104314612498739*lm + 0.4512653307945582*
             lm^2 + 0.08366944444444445*lm^3)*NL + 
          (-0.07907663917225018 + 3.1043146124987393*lm + 0.4512653307945582*
             lm^2 + 0.08366944444444445*lm^3)*NH))}, 
     {0.45, NC*(CF^2*(-5.889811593333648 - 4.874757773004964*lm - 
          2.2953099419407814*lm^2 - 1.505*lm^3) + 
        CA*CF*(-7.855820057668062 - 7.076755431858568*lm - 
          3.3612231767041276*lm^2 - 0.4598611111111111*lm^3) + 
        CF*((1.7846246689712668 + 1.5105684311763854*lm + 0.45151027455226567*
             lm^2 + 0.08361111111111111*lm^3)*NM + 
          (1.9876104916117714 + 1.1055684311763854*lm + 0.45151027455226567*
             lm^2 + 0.08361111111111111*lm^3)*NL + 
          (-0.08006517941274068 + 3.1055684311763856*lm + 0.45151027455226567*
             lm^2 + 0.08361111111111111*lm^3)*NH))}, 
     {0.455, NC*(CF^2*(-5.888782841888993 - 4.881521638900496*lm - 
          2.3038144015892383*lm^2 - 1.50405*lm^3) + 
        CA*CF*(-7.863835580857386 - 7.087022750223484*lm - 
          3.362142768541156*lm^2 - 0.4595708333333333*lm^3) + 
        CF*((1.77792986443572 + 1.520895770469166*lm + 0.4517782306438466*
             lm^2 + 0.08355833333333333*lm^3)*NM + 
          (1.988325425141786 + 1.1068457704691659*lm + 0.4517782306438466*
             lm^2 + 0.08355833333333333*lm^3)*NL + 
          (-0.08109684602665371 + 3.106845770469166*lm + 0.4517782306438466*
             lm^2 + 0.08355833333333333*lm^3)*NH))}, 
     {0.46, NC*(CF^2*(-5.887668086172261 - 4.888032149098618*lm - 
          2.312340051408282*lm^2 - 1.5032*lm^3) + 
        CA*CF*(-7.871803302860186 - 7.0974291708668975*lm - 
          3.3632455712636418*lm^2 - 0.4593111111111111*lm^3) + 
        CF*((1.7710956663259674 + 1.5313456523098707*lm + 0.45206889174490456*
             lm^2 + 0.0835111111111111*lm^3)*NM + 
          (1.989089784543347 + 1.108145652309871*lm + 0.45206889174490456*
             lm^2 + 0.0835111111111111*lm^3)*NL + 
          (-0.08217069470877719 + 3.108145652309871*lm + 0.45206889174490456*
             lm^2 + 0.0835111111111111*lm^3)*NH))}, 
     {0.465, NC*(CF^2*(-5.88647178412386 - 4.8942862660111155*lm - 
          2.3208813675667637*lm^2 - 1.50245*lm^3) + 
        CA*CF*(-7.87971926936474 - 7.107967257233948*lm - 
          3.3645298970342887*lm^2 - 0.45908194444444445*lm^3) + 
        CF*((1.7641191569217578 + 1.5419171151715365*lm + 0.4523819509759313*
             lm^2 + 0.08346944444444444*lm^3)*NM + 
          (1.9899029812649816 + 1.1094671151715365*lm + 0.4523819509759313*
             lm^2 + 0.08346944444444444*lm^3)*NL + 
          (-0.08328578354559805 + 3.1094671151715363*lm + 0.4523819509759313*
             lm^2 + 0.08346944444444444*lm^3)*NH))}, 
     {0.47, NC*(CF^2*(-5.8851984525516645 - 4.9002812247740595*lm - 
          2.32943283483672*lm^2 - 1.5018*lm^3) + 
        CA*CF*(-7.887579710207155 - 7.118629666238823*lm - 
          3.3659940606445535*lm^2 - 0.4588833333333333*lm^3) + 
        CF*((1.7569974543533036 + 1.5526092139132646*lm + 0.45271710193537334*
             lm^2 + 0.08343333333333333*lm^3)*NM + 
          (1.99076445055901 + 1.1108092139132646*lm + 0.45271710193537334*
             lm^2 + 0.08343333333333333*lm^3)*NL + 
          (-0.08444117316647613 + 3.1108092139132646*lm + 0.45271710193537334*
             lm^2 + 0.08343333333333333*lm^3)*NH))}, 
     {0.475, NC*(CF^2*(-5.883852659888679 - 4.906014528983099*lm - 
          2.337988947160789*lm^2 - 1.50125*lm^3) + 
        CA*CF*(-7.895381035008299 - 7.129409147630198*lm - 
          3.367636379688019*lm^2 - 0.45871527777777776*lm^3) + 
        CF*((1.7497277119927646 + 1.5634210196247291*lm + 0.4530740387311549*
             lm^2 + 0.08340277777777778*lm^3)*NM + 
          (1.9916736508366724 + 1.112171019624729*lm + 0.4530740387311549*
             lm^2 + 0.08340277777777778*lm^3)*NL + 
          (-0.08563592688878419 + 3.112171019624729*lm + 0.4530740387311549*
             lm^2 + 0.08340277777777778*lm^3)*NH))}, 
     {0.48, NC*(CF^2*(-5.882439019222757 - 4.911483946477702*lm - 
          2.3465442081929964*lm^2 - 1.5008*lm^3) + 
        CA*CF*(-7.903119828905697 - 7.140298543340268*lm - 
          3.369455174725638*lm^2 - 0.45857777777777775*lm^3) + 
        CF*((1.7423071178549212 + 1.57435161946958*lm + 0.453452456010722*
             lm^2 + 0.08337777777777777*lm^3)*NM + 
          (1.9926300630388936 + 1.1135516194695798*lm + 0.453452456010722*
             lm^2 + 0.08337777777777777*lm^3)*NL + 
          (-0.08686911085722916 + 3.11355161946958*lm + 0.453452456010722*
             lm^2 + 0.08337777777777777*lm^3)*NH))}, 
     {0.485, NC*(CF^2*(-5.880962181588783 - 4.916687505174966*lm - 
          2.3550931318140185*lm^2 - 1.50045*lm^3) + 
        CA*CF*(-7.9107928483785255 - 7.151290786818854*lm - 
          3.3714487694431723*lm^2 - 0.4584708333333333*lm^3) + 
        CF*((1.7347328940070246 + 1.585400116527938*lm + 0.4538520489896677*
             lm^2 + 0.08335833333333334*lm^3)*NM + 
          (1.993633190022336 + 1.1149501165279383*lm + 0.4538520489896677*
             lm^2 + 0.08335833333333334*lm^3)*NL + 
          (-0.08813979417756146 + 3.1149501165279383*lm + 0.4538520489896677*
             lm^2 + 0.08335833333333334*lm^3)*NH))}, 
     {0.49, NC*(CF^2*(-5.879426829514077 - 4.921623488953559*lm - 
          2.36363024262198*lm^2 - 1.5002*lm^3) + 
        CA*CF*(-7.9183970171638896 - 7.162378902353985*lm - 
          3.3736154908011606*lm^2 - 0.45839444444444444*lm^3) + 
        CF*((1.7270022959877858 + 1.5965656296381645*lm + 0.4542725134789989*
             lm^2 + 0.08334444444444444*lm^3)*NM + 
          (1.9946825559603751 + 1.1163656296381645*lm + 0.4542725134789989*
             lm^2 + 0.08334444444444444*lm^3)*NL + 
          (-0.0894470490448709 + 3.1163656296381643*lm + 0.4542725134789989*
             lm^2 + 0.08334444444444444*lm^3)*NH))}, 
     {0.495, NC*(CF^2*(-5.877837670808123 - 4.926290433588216*lm - 
          2.3721500763997834*lm^2 - 1.50005*lm^3) + 
        CA*CF*(-7.925929422262571 - 7.173556004380296*lm - 
          3.3759536691777114*lm^2 - 0.45834861111111114*lm^3) + 
        CF*((1.719112612235468 + 1.607847293238068*lm + 0.4547135459110991*
             lm^2 + 0.08333611111111111*lm^3)*NM + 
          (1.9957777057586523 + 1.117797293238068*lm + 0.4547135459110991*
             lm^2 + 0.08333611111111111*lm^3)*NL + 
          (-0.0907899508666604 + 3.117797293238068*lm + 0.4547135459110991*
             lm^2 + 0.08333611111111111*lm^3)*NH))}, 
     {0.5, CF*NC*(CF*(-5.876199432591634 - 4.930687122739416*lm - 
          2.3806471805604446*lm^2 - 1.5*lm^3) + 
        CA*(-7.93338731003634 - 7.184815296778363*lm - 3.3784616385045805*
           lm^2 - 0.4583333333333333*lm^3) + 1.7110611635257806*NM + 
        1.6192442572060248*lm*NM + 0.4551748433644692*lm^2*NM + 
        0.08333333333333333*lm^3*NM + 1.9969182044854206*NL + 
        1.1192442572060248*lm*NL + 0.4551748433644692*lm^2*NL + 
        0.08333333333333333*lm^3*NL - 0.09216757838094586*NH + 
        3.119244257206025*lm*NH + 0.4551748433644692*lm^2*NH + 
        0.08333333333333333*lm^3*NH)}, 
     {0.505, CF*NC*(CF*(-5.87451685553445 - 4.9348125839717545*lm - 
          2.38911611456822*lm^2 - 1.50005*lm^3) + 
        CA*(-7.940768082370563 - 7.19615007215428*lm - 3.381137736395845*
           lm^2 - 0.45834861111111114*lm^3) + 1.7028453024148142*NM + 
        1.6307556867002162*lm*NM + 0.45565610358712333*lm^2*NM + 
        0.08333611111111111*lm^3*NM + 1.998103636812844*NL + 
        1.120705686700216*lm*NL + 0.45565610358712333*lm^2*NL + 
        0.08333611111111111*lm^3*NL - 0.09357901376915201*NH + 
        3.1207056867002163*lm*NH + 0.45565610358712333*lm^2*NH + 
        0.08333611111111111*lm^3*NH)}, 
     {0.51, CF*NC*(CF*(-5.872794688352373 - 4.938666084871064*lm - 
          2.3975514503445794*lm^2 - 1.5002*lm^3) + 
        CA*(-7.948069292964395 - 7.207553711131562*lm - 3.383980304271955*
           lm^2 - 0.45839444444444444*lm^3) + 1.6944624126992414*NM + 
        1.6423807620011768*lm*NM + 0.4561570250191433*lm^2*NM + 
        0.08334444444444444*lm^3*NM + 1.9993336064780698*NL + 
        1.1221807620011768*lm*NL + 0.4561570250191433*lm^2*NL + 
        0.08334444444444444*lm^3*NL - 0.09502334276503749*NH + 
        3.1221807620011766*lm*NH + 0.4561570250191433*lm^2*NH + 
        0.08334444444444444*lm^3*NH)}, 
     {0.515, CF*NC*(CF*(-5.871037682474166 - 4.942247129162728*lm - 
          2.4059477726484504*lm^2 - 1.50045*lm^3) + 
        CA*(-7.955288643657265 - 7.219019681613092*lm - 3.3869876874759153*
           lm^2 - 0.4584708333333333*lm^3) + 1.6859099088765352*NM + 
        1.6541186783507185*lm*NM + 0.4566773068138028*lm^2*NM + 
        0.08335833333333334*lm^3*NM + 2.0006077357509624*NL + 
        1.1236686783507184*lm*NL + 0.4566773068138028*lm^2*NL + 
        0.08335833333333334*lm^3*NL - 0.09649965475832635*NH + 
        3.1236686783507186*lm*NH + 0.4566773068138028*lm^2*NH + 
        0.08335833333333334*lm^3*NH)}, 
     {0.52, CF*NC*(CF*(-5.869250586935285 - 4.945555452908235*lm - 
          2.4142996794405396*lm^2 - 1.5008*lm^3) + 
        CA*(-7.962423980860553 - 7.230541538048208*lm - 3.390158235384609*
           lm^2 - 0.45857777777777775*lm^3) + 1.6771852356186698*NM + 
        1.6659686457929144*lm*NM + 0.4572166488578078*lm^2*NM + 
        0.08337777777777777*lm^3*NM + 2.001925664918264*NL + 
        1.1251686457929142*lm*NL + 0.4572166488578078*lm^2*NL + 
        0.08337777777777777*lm^3*NL - 0.0980070428943751*NH + 
        3.125168645792914*lm*NH + 0.4572166488578078*lm^2*NH + 
        0.08337777777777777*lm^3*NH)}, 
     {0.525, CF*NC*(CF*(-5.867438143464233 - 4.94859102074745*lm - 
          2.4226017822287003*lm^2 - 1.50125*lm^3) + 
        CA*(-7.969473292062964 - 7.24211292069145*lm - 3.393490301514325*
           lm^2 - 0.45871527777777776*lm^3) + 1.6682858672535053*NM + 
        1.6779298890149024*lm*NM + 0.4577747517904833*lm^2*NM + 
        0.08340277777777778*lm^3*NM + 2.003287051779618*NL + 
        1.1266798890149023*lm*NL + 0.4577747517904833*lm^2*NL + 
        0.08340277777777778*lm^3*NL - 0.09954460416953223*NH + 
        3.1266798890149023*lm*NH + 0.4577747517904833*lm^2*NH + 
        0.08340277777777778*lm^3*NH)}, 
     {0.53, CF*NC*(CF*(-5.865605081759434 - 4.951354022192244*lm - 
          2.4308487063957642*lm^2 - 1.5018*lm^3) + 
        CA*(-7.976434702413171 - 7.253727554856309*lm - 3.396982243620928*
           lm^2 - 0.4588833333333333*lm^3) + 1.6592093072547764*NM + 
        1.6900016471880266*lm*NM + 0.4583513170219869*lm^2*NM + 
        0.08343333333333333*lm^3*NM + 2.0046915711558984*NL + 
        1.1282016471880265*lm*NL + 0.4583513170219869*lm^2*NL + 
        0.08343333333333333*lm^3*NL - 0.10111143952242312*NH + 
        3.1282016471880265*lm*NH + 0.4583513170219869*lm^2*NH + 
        0.08343333333333333*lm^3*NH)}, 
     {0.535, CF*NC*(CF*(-5.86375611495003 - 4.953844867971369*lm - 
          2.439035091510536*lm^2 - 1.50245*lm^3) + 
        CA*(-7.983306471378098 - 7.265379250164814*lm - 3.400632423794886*
           lm^2 - 0.45908194444444445*lm^3) + 1.6499530877405955*NM + 
        1.7021831738094069*lm*NM + 0.45894604675058537*lm^2*NM + 
        0.08346944444444444*lm^3*NM + 2.0061389144095476*NL + 
        1.1297331738094067*lm*NL + 0.45894604675058537*lm^2*NL + 
        0.08346944444444444*lm^3*NL - 0.1027066539213008*NH + 
        3.1297331738094067*lm*NH + 0.45894604675058537*lm^2*NH + 
        0.08346944444444444*lm^3*NH)}, 
     {0.54, CF*NC*(CF*(-5.861895935234216 - 4.956064186426391*lm - 
          2.447155591622628*lm^2 - 1.5032*lm^3) + 
        CA*(-7.990086989475207 - 7.277061899793676*lm - 3.404439208551359*
           lm^2 - 0.4593111111111111*lm^3) + 1.6405147689803712*NM + 
        1.7144737365440283*lm*NM + 0.4595586439790349*lm^2*NM + 
        0.0835111111111111*lm^3*NM + 2.0076287889766387*NL + 
        1.1312737365440284*lm*NL + 0.4595586439790349*lm^2*NL + 
        0.0835111111111111*lm^3*NL - 0.1043293564475979*NH + 
        3.131273736544028*lm*NH + 0.4595586439790349*lm^2*NH + 
        0.0835111111111111*lm^3*NH)}, 
     {0.545, CF*NC*(CF*(-5.860029209688961 - 4.95801281995846*lm - 
          2.455204875541789*lm^2 - 1.50405*lm^3) + 
        CA*(-7.996774775077212 - 7.288769479717696*lm - 3.408400968915547*
           lm^2 - 0.4595708333333333*lm^3) + 1.6308919389100496*NM + 
        1.7268726170674282*lm*NM + 0.4601888125300994*lm^2*NM + 
        0.08355833333333333*lm^3*NM + 2.0091609179103656*NL + 
        1.1328226170674283*lm*NL + 0.4601888125300994*lm^2*NL + 
        0.08355833333333333*lm^3*NL - 0.10597866037580982*NH + 
        3.1328226170674283*lm*NH + 0.4601888125300994*lm^2*NH + 
        0.08355833333333333*lm^3*NH)}, 
     {0.55, CF*NC*(CF*(-5.858160576245212 - 4.959691821525647*lm - 
          2.463177627102342*lm^2 - 1.505*lm^3) + 
        CA*(-8.003368471287626 - 7.300496047951078*lm - 3.4125160805034933*
           lm^2 - 0.4598611111111111*lm^3) + 1.621082212655569*NM + 
        1.7393791109090546*lm*NM + 0.4608362570612412*lm^2*NM + 
        0.08361111111111111*lm^3*NM + 2.0107350394356915*NL + 
        1.1343791109090546*lm*NL + 0.4608362570612412*lm^2*NL + 
        0.08361111111111111*lm^3*NL - 0.10765368324983471*NH + 
        3.134379110909055*lm*NH + 0.4608362570612412*lm^2*NH + 
        0.08361111111111111*lm^3*NH)}, 
     {0.555, CF*NC*(CF*(-5.856294639822837 - 4.961102451190565*lm - 
          2.47106854541333*lm^2 - 1.50605*lm^3) + 
        CA*(-8.009866842885629 - 7.312235743787266*lm - 3.4167829235985177*
           lm^2 - 0.46018194444444444*lm^3) + 1.6110832320644326*NM + 
        1.7519925272963697*lm*NM + 0.4615006830785183*lm^2*NM + 
        0.08366944444444445*lm^3*NM + 2.012350906514882*NL + 
        1.1359425272963697*lm*NL + 0.4615006830785183*lm^2*NL + 
        0.08366944444444445*lm^3*NL - 0.10935354695589138*NH + 
        3.1359425272963697*lm*NH + 0.4615006830785183*lm^2*NH + 
        0.08366944444444445*lm^3*NH)}, 
     {0.56, CF*NC*(CF*(-5.854435968619819 - 4.9622461727179425*lm - 
          2.4788723450949397*lm^2 - 1.5072*lm^3) + 
        CA*(-8.016268773338723 - 7.323982787037877*lm - 3.4211998832234536*
           lm^2 - 0.46053333333333335*lm^3) + 1.6008926652452875*NM + 
        1.764712188999755*lm*NM + 0.4621817969497189*lm^2*NM + 
        0.08373333333333334*lm^3*NM + 2.014008286423652*NL + 
        1.1375121889997548*lm*NL + 0.4621817969497189*lm^2*NL + 
        0.08373333333333334*lm^3*NL - 0.11107737779213157*NH + 
        3.137512188999755*lm*NH + 0.4621817969497189*lm^2*NH + 
        0.08373333333333334*lm^3*NH)}, 
     {0.565, CF*NC*(CF*(-5.852589090550381 - 4.96312465022177*lm - 
          2.4865837565017483*lm^2 - 1.50845*lm^3) + 
        CA*(-8.022573261881696 - 7.335731477271262*lm - 3.4257653492088673*
           lm^2 - 0.4609152777777778*lm^3) + 1.5905082061154086*NM + 
        1.7775374321782837*lm*NM + 0.4628793059167638*lm^2*NM + 
        0.08380277777777778*lm^3*NM + 2.015706960337674*NL + 
        1.1390874321782838*lm*NL + 0.4628793059167638*lm^2*NL + 
        0.08380277777777778*lm^3*NL - 0.11282430653505915*NH + 
        3.139087432178284*lm*NH + 0.4628793059167638*lm^2*NH + 
        0.08380277777777778*lm^3*NH)}, 
     {0.57, CF*NC*(CF*(-5.850758489826907 - 4.963739744861674*lm - 
          2.494197525933321*lm^2 - 1.5098*lm^3) + 
        CA*(-8.02877942066043 - 7.34747619305119*lm - 3.430477716257404*
           lm^2 - 0.4613277777777778*lm^3) + 1.5799275739559735*NM + 
        1.7904676062264098*lm*NM + 0.4635929181074067*lm^2*NM + 
        0.08387777777777777*lm^3*NM + 2.017446722929189*NL + 
        1.1406676062264098*lm*NL + 0.4635929181074067*lm^2*NL + 
        0.08387777777777777*lm^3*NL - 0.11459346850286452*NH + 
        3.1406676062264096*lm*NH + 0.4635929181074067*lm^2*NH + 
        0.08387777777777777*lm^3*NH)}, 
     {0.575, CF*NC*(CF*(-5.848948603680732 - 4.964093511588069*lm - 
          2.501708415832659*lm^2 - 1.51125*lm^3) + 
        CA*(-8.034886471939142 - 7.35921139117614*lm - 3.4353353840044236*
           lm^2 - 0.46177083333333335*lm^3) + 1.5691485129750233*NM + 
        1.8035020736216238*lm*NM + 0.4643223425462588*lm^2*NM + 
        0.08395833333333333*lm^3*NM + 2.0192273819734723*NL + 
        1.142252073621624*lm*NL + 0.4643223425462588*lm^2*NL + 
        0.08395833333333333*lm^3*NL - 0.116384003615779*NH + 
        3.142252073621624*lm*NH + 0.4643223425462588*lm^2*NH + 
        0.08395833333333333*lm^3*NH)}, 
     {0.58, CF*NC*(CF*(-5.847163819217015 - 4.964188195935692*lm - 
          2.5091112049729816*lm^2 - 1.5128*lm^3) + 
        CA*(-8.040893745369639 - 7.370931605919616*lm - 3.4403367570750776*
           lm^2 - 0.46224444444444446*lm^3) + 1.5581687918779983*NM + 
        1.8166402097731236*lm*NM + 0.46506728916516565*lm^2*NM + 
        0.08404444444444445*lm^3*NM + 2.0210487579649166*NL + 
        1.1438402097731237*lm*NL + 0.46506728916516565*lm^2*NL + 
        0.08404444444444445*lm^3*NL - 0.11819505645354993*NH + 
        3.1438402097731237*lm*NH + 0.46506728916516565*lm^2*NH + 
        0.08404444444444445*lm^3*NH)}, 
     {0.585, CF*NC*(CF*(-5.845408470399102 - 4.964026230865044*lm - 
          2.51640068863331*lm^2 - 1.51445*lm^3) + 
        CA*(-8.046800675321203 - 7.3826314482719155*lm - 3.445480245137956*
           lm^2 - 0.4627486111111111*lm^3) + 1.5469862034457365*NM + 
        1.829881402871537*lm*NM + 0.46582746881296166*lm^2*NM + 
        0.0841361111111111*lm^3*NM + 2.0229106837424937*NL + 
        1.145431402871537*lm*NL + 0.46582746881296166*lm^2*NL + 
        0.0841361111111111*lm^3*NL - 0.12002577631013384*NH + 
        3.145431402871537*lm*NH + 0.46582746881296166*lm^2*NH + 
        0.0841361111111111*lm^3*NH)}, 
     {0.59, CF*NC*(CF*(-5.843686835157937 - 4.9636102336512975*lm - 
          2.523571678763288*lm^2 - 1.5162*lm^3) + 
        CA*(-8.052606798269792 - 7.394305605183711*lm - 3.450764262955449*
           lm^2 - 0.4632833333333333*lm^3) + 1.5355985641198258*NM + 
        1.8432250537397392*lm*NM + 0.4666025932646271*lm^2*NM + 
        0.08423333333333333*lm^3*NM + 2.024813004124362*NL + 
        1.147025053739739*lm*NL + 0.4666025932646271*lm^2*NL + 
        0.08423333333333333*lm^3*NL - 0.12187531724570169*NH + 
        3.147025053739739*lm*NH + 0.4666025932646271*lm^2*NH + 
        0.08423333333333333*lm^3*NH)}, 
     {0.595, CF*NC*(CF*(-5.842003132622246 - 4.96294300282017*lm - 
          2.530619004137673*lm^2 - 1.51805*lm^3) + 
        CA*(-8.058311750245215 - 7.405948838811825*lm - 3.4561872304309555*
           lm^2 - 0.4638486111111111*lm^3) + 1.5240037135951987*NM + 
        1.8566705756847952*lm*NM + 0.4673923752298707*lm^2*NM + 
        0.08433611111111111*lm^3*NM + 2.026755575551399*NL + 
        1.1486205756847951*lm*NL + 0.4673923752298707*lm^2*NL + 
        0.08433611111111111*lm^3*NL - 0.12374283813604674*NH + 
        3.148620575684795*lm*NH + 0.4673923752298707*lm^2*NH + 
        0.08433611111111111*lm^3*NH)}, 
     {0.6, CF*NC*(CF*(-5.840361520465331 - 4.962027515130277*lm - 
          2.5375375105009055*lm^2 - 1.52*lm^3) + 
        CA*(-8.063915264334966 - 7.417555985767499*lm - 3.4617475726530547*
           lm^2 - 0.46444444444444444*lm^3) + 1.5121995144198561*NM + 
        1.870217394351062*lm*NM + 0.46819652836116143*lm^2*NM + 
        0.08444444444444445*lm^3*NM + 2.028738265739439*NL + 
        1.150217394351062*lm*NL + 0.46819652836116143*lm^2*NL + 
        0.08444444444444445*lm^3*NL - 0.1256275027194825*NH + 
        3.150217394351062*lm*NH + 0.46819652836116143*lm^2*NH + 
        0.08444444444444445*lm^3*NH)}, 
     {0.605, CF*NC*(CF*(-5.838766092364534 - 4.9608669226014666*lm - 
          2.5443220607021484*lm^2 - 1.52205*lm^3) + 
        CA*(-8.069417168243515 - 7.429121956367502*lm - 3.4674437199367674*
           lm^2 - 0.4650708333333333*lm^3) + 1.5001838516016124*NM + 
        1.8838649475744758*lm*NM + 0.4690147672612305*lm^2*NM + 
        0.08455833333333333*lm^3*NM + 2.0307609533400015*NL + 
        1.1518149475744757*lm*NL + 0.4690147672612305*lm^2*NL + 
        0.08455833333333333*lm^3*NL - 0.12752847964131553*NH + 
        3.1518149475744757*lm*NH + 0.4690147672612305*lm^2*NH + 
        0.08455833333333333*lm^3*NH)}, 
     {0.61, CF*NC*(CF*(-5.837220875569463 - 4.959464549588603*lm - 
          2.5509675348211727*lm^2 - 1.5242*lm^3) + 
        CA*(-8.074817381905746 - 7.440641733888329*lm - 3.473274107862025*
           lm^2 - 0.4657277777777778*lm^3) + 1.48795463222175*NM + 
        1.8976126852380515*lm*NM + 0.46984680749006513*lm^2*NM + 
        0.08467777777777778*lm^3*NM + 2.0328235276092967*NL + 
        1.1534126852380513*lm*NL + 0.46984680749006513*lm^2*NL + 
        0.08467777777777778*lm^3*NL - 0.12944494249597416*NH + 
        3.1534126852380515*lm*NH + 0.46984680749006513*lm^2*NH + 
        0.08467777777777778*lm^3*NH)}, 
     {0.615, CF*NC*(CF*(-5.835729828575306 - 4.957823889900297*lm - 
          2.557468830285456*lm^2 - 1.52645*lm^3) + 
        CA*(-8.080115915153376 - 7.452110373823783*lm - 3.479237177309445*
           lm^2 - 0.4664152777777778*lm^3) + 1.4755097850554728*NM + 
        1.9114600691286185*lm*NM + 0.47069236557141425*lm^2*NM + 
        0.08480277777777778*lm^3*NM + 2.0349258880853163*NL + 
        1.1550100691286185*lm*NL + 0.47069236557141425*lm^2*NL + 
        0.08480277777777778*lm^3*NL - 0.1313760698668723*NH + 
        3.1550100691286187*lm*NH + 0.47069236557141425*lm^2*NH + 
        0.08480277777777778*lm^3*NH)}, 
     {0.62, CF*NC*(CF*(-5.834296838897626 - 4.955948603962028*lm - 
          2.563820861978839*lm^2 - 1.5288*lm^3) + 
        CA*(-8.085312865433153 - 7.4635230031461735*lm - 3.4853313744935344*
           lm^2 - 0.46713333333333334*lm^3) + 1.462847260199049*NM + 
        1.9254065727948104*lm*NM + 0.4715511589988244*lm^2*NM + 
        0.08493333333333333*lm^3*NM + 2.0370679442727977*NL + 
        1.1566065727948105*lm*NL + 0.4715511589988244*lm^2*NL + 
        0.08493333333333333*lm^3*NL - 0.13332104536408435*NH + 
        3.1566065727948103*lm*NH + 0.4715511589988244*lm^2*NH + 
        0.08493333333333333*lm^3*NH)}, 
     {0.625, CF*NC*(CF*(-5.832925720945179 - 4.953842516023142*lm - 
          2.5700185623420713*lm^2 - 1.53125*lm^3) + 
        CA*(-8.090408415575652 - 7.47487481957137*lm - 3.4915551509934106*
           lm^2 - 0.4678819444444444*lm^3) + 1.4499650287035348*NM + 
        1.9394516814063278*lm*NM + 0.4724229062412262*lm^2*NM + 
        0.08506944444444445*lm^3*NM + 2.0392496153358777*NL + 
        1.1582016814063278*lm*NL + 0.4724229062412262*lm^2*NL + 
        0.08506944444444445*lm^3*NL - 0.13527905765990442*NH + 
        3.158201681406328*lm*NH + 0.4724229062412262*lm^2*NH + 
        0.08506944444444445*lm^3*NH)}, 
     {0.63, CF*NC*(CF*(-5.831620213987397 - 4.951509611407166*lm - 
          2.576056881465576*lm^2 - 1.5338*lm^3) + 
        CA*(-8.095402831613582 - 7.486161090827914*lm - 3.497906963781148*
           lm^2 - 0.4686611111111111*lm^3) + 1.4368610822149714*NM + 
        1.9535948916144925*lm*NM + 0.47330732674808756*lm^2*NM + 
        0.08521111111111111*lm^3*NM + 2.041470829798242*NL + 
        1.1597948916144925*lm*NL + 0.47330732674808756*lm^2*NL + 
        0.08521111111111111*lm^3*NL - 0.13724930052236128*NH + 
        3.1597948916144927*lm*NH + 0.47330732674808756*lm^2*NH + 
        0.08521111111111111*lm^3*NH)}, 
     {0.635, CF*NC*(CF*(-5.830383980213332 - 4.9489540338049*lm - 
          2.5819307871747323*lm^2 - 1.53645*lm^3) + 
        CA*(-8.100296460648428 - 7.4973771539304*lm - 3.504385275247835*
           lm^2 - 0.46947083333333334*lm^3) + 1.4235334326209454*NM + 
        1.9678357114141023*lm*NM + 0.4742041409541518*lm^2*NM + 
        0.08535833333333333*lm^3*NM + 2.043731525250588*NL + 
        1.1613857114141024*lm*NL + 0.4742041409541518*lm^2*NL + 
        0.08535833333333333*lm^3*NL - 0.1392309728467571*NH + 
        3.1613857114141024*lm*NH + 0.4742041409541518*lm^2*NH + 
        0.08535833333333333*lm^3*NH)}, 
     {0.64, CF*NC*(CF*(-5.829220602878916 - 4.946180082609735*lm - 
          2.5876352651079837*lm^2 - 1.5392*lm^3) + 
        CA*(-8.105089728764398 - 7.508518414457288*lm - 3.510988553227439*
           lm^2 - 0.4703111111111111*lm^3) + 1.4099801117034103*NM + 
        1.9821736600066036*lm*NM + 0.47511307028377686*lm^2*NM + 
        0.08551111111111111*lm^3*NM + 2.04603164806522*NL + 
        1.1629736600066036*lm*NL + 0.47511307028377686*lm^2*NL + 
        0.08551111111111111*lm^3*NL - 0.14122327868529674*NH + 
        3.1629736600066036*lm*NH + 0.47511307028377686*lm^2*NH + 
        0.08551111111111111*lm^3*NH)}, 
     {0.645, CF*NC*(CF*(-5.828133584539545 - 4.943192210294648*lm - 
          2.593165318788041*lm^2 - 1.54205*lm^3) + 
        CA*(-8.109783138988574 - 7.51958034583333*lm - 3.517715271018568*
           lm^2 - 0.47118194444444444*lm^3) + 1.3961991707976598*NM + 
        1.996608267664588*lm*NM + 0.47603383715489117*lm^2*NM + 
        0.08566944444444445*lm^3*NM + 2.0483711531176056*NL + 
        1.1645582676645878*lm*NL + 0.47603383715489117*lm^2*NL + 
        0.08566944444444445*lm^3*NL - 0.1432254272748716*NH + 
        3.164558267664588*lm*NH + 0.47603383715489117*lm^2*NH + 
        0.08566944444444445*lm^3*NH)}, 
     {0.65, CF*NC*(CF*(-5.827126345365063 - 4.93999501983031*lm - 
          2.5985159696864746*lm^2 - 1.545*lm^3) + 
        CA*(-8.114377269296241 - 7.530558488616763*lm - 3.524563907404201*
           lm^2 - 0.47208333333333335*lm^3) + 1.3821886804573489*NM + 
        2.0111390755976237*lm*NM + 0.47696616498258193*lm^2*NM + 
        0.08583333333333333*lm^3*NM + 2.0507500035147177*NL + 
        1.1661390755976235*lm*NL + 0.47696616498258193*lm^2*NL + 
        0.08583333333333333*lm^3*NL - 0.14523663306305917*NH + 
        3.1661390755976235*lm*NH + 0.47696616498258193*lm^2*NH + 
        0.08583333333333333*lm^3*NH)}, 
     {0.655, CF*NC*(CF*(-5.8262022215343485 - 4.936593262143767*lm - 
          2.6036822572819416*lm^2 - 1.54805*lm^3) + 
        CA*(-8.118872770660385 - 7.541448449791397*lm - 3.5315329466694823*
           lm^2 - 0.4730152777777778*lm^3) + 1.3679467301254642*NM + 
        2.0257656358194276*lm*NM + 0.4779097781823301*lm^2*NM + 
        0.08600277777777778*lm^3*NM + 2.0531681703299975*NL + 
        1.1677156358194276*lm*NL + 0.4779097781823301*lm^2*NL + 
        0.08600277777777778*lm^3*NL - 0.14725611573239963*NH + 
        3.1677156358194276*lm*NH + 0.4779097781823301*lm^2*NH + 
        0.08600277777777778*lm^3*NH)}, 
     {0.66, CF*NC*(CF*(-5.82536446370679 - 4.932991833617127*lm - 
          2.6086592391123116*lm^2 - 1.5512*lm^3) + 
        CA*(-8.123270365144343 - 7.552245902063746*lm - 3.5386208786176505*
           lm^2 - 0.4739777777777778*lm^3) + 1.3534714278111333*NM + 
        2.0404875110163854*lm*NM + 0.4788644021729062*lm^2*NM + 
        0.08617777777777778*lm^3*NM + 2.0556256323447806*NL + 
        1.1692875110163854*lm*NL + 0.4788644021729062*lm^2*NL + 
        0.08617777777777778*lm^3*NL - 0.14928310022300562*NH + 
        3.1692875110163854*lm*NH + 0.4788644021729062*lm^2*NH + 
        0.08617777777777778*lm^3*NH)}, 
     {0.665, CF*NC*(CF*(-5.824616235568012 - 4.929195773625702*lm - 
          2.613441990820929*lm^2 - 1.55445*lm^3) + 
        CA*(-8.127570844036656 - 7.562946583165299*lm - 3.5458261985841726*
           lm^2 - 0.47497083333333334*lm^3) + 1.3387608997721787*NM + 
        2.055304274417421*lm*NM + 0.4798297633789405*lm^2*NM + 
        0.08635833333333333*lm^3*NM + 2.0581223757960174*NL + 
        1.1708542744174206*lm*NL + 0.4798297633789405*lm^2*NL + 
        0.08635833333333333*lm^3*NL - 0.1513168167535625*NH + 
        3.1708542744174206*lm*NH + 0.4798297633789405*lm^2*NH + 
        0.08635833333333333*lm^3*NH)}, 
     {0.67, CF*NC*(CF*(-5.823960612447346 - 4.9252102621150655*lm - 
          2.618025606197254*lm^2 - 1.5578*lm^3) + 
        CA*(-8.131775066027172 - 7.573546295160065*lm - 3.553147407449161*
           lm^2 - 0.47599444444444444*lm^3) + 1.3238132902033153*NM + 
        2.070215509665219*lm*NM + 0.4808055892331808*lm^2*NM + 
        0.08654444444444444*lm^3*NM + 2.060658394130149*NL + 
        1.172415509665219*lm*NL + 0.4808055892331808*lm^2*NL + 
        0.08654444444444444*lm^3*NL - 0.15335650084077249*NH + 
        3.172415509665219*lm*NH + 0.4808055892331808*lm^2*NH + 
        0.08654444444444444*lm^3*NH)}, 
     {0.675, CF*NC*(CF*(-5.823400580004572 - 4.921040617216448*lm - 
          2.622405197212097*lm^2 - 1.56125*lm^3) + 
        CA*(-8.13588395542345 - 7.58404090375745*lm - 3.5605830116481405*
           lm^2 - 0.47704861111111113*lm^3) + 1.3086267609298883*NM + 
        2.0852208106888073*lm*NM + 0.48179160817844985*lm^2*NM + 
        0.08673611111111111*lm^3*NM + 2.063233687762973*NL + 
        1.1739708106888074*lm*NL + 0.48179160817844985*lm^2*NL + 
        0.08673611111111111*lm^3*NL - 0.15540139331729505*NH + 
        3.1739708106888074*lm*NH + 0.48179160817844985*lm^2*NH + 
        0.08673611111111111*lm^3*NH)}, 
     {0.68, CF*NC*(CF*(-5.822939032983593 - 4.916692292899947*lm - 
          2.6265758940476713*lm^2 - 1.5648*lm^3) + 
        CA*(-8.139898500406588 - 7.594426337630604*lm - 3.5681315231812327*
           lm^2 - 0.47813333333333335*lm^3) + 1.2931994911070621*NM + 
        2.1003197815774906*lm*NM + 0.4827875496693151*lm^2*NM + 
        0.08693333333333333*lm^3*NM + 2.0658482638453624*NL + 
        1.1755197815774907*lm*NL + 0.4827875496693151*lm^2*NL + 
        0.08693333333333333*lm^3*NL - 0.15745074034823442*NH + 
        3.1755197815774907*lm*NH + 0.4827875496693151*lm^2*NH + 
        0.08693333333333333*lm^3*NH)}, 
     {0.685, CF*NC*(CF*(-5.822578774030733 - 4.912170876664993*lm - 
          2.630532845122671*lm^2 - 1.56845*lm^3) + 
        CA*(-8.143819751325555 - 7.604698587740267*lm - 3.5757914596208162*
           lm^2 - 0.4792486111111111*lm^3) + 1.2775296769243556*NM + 
        2.1155120364561424*lm*NM + 0.48379314417348174*lm^2*NM + 
        0.08713611111111111*lm^3*NM + 2.068502136034693*NL + 
        1.1770620364561424*lm*NL + 0.48379314417348174*lm^2*NL + 
        0.08713611111111111*lm^3*NL - 0.1595037934462228*NH + 
        3.1770620364561424*lm*NH + 0.48379314417348174*lm^2*NH + 
        0.08713611111111111*lm^3*NH)}, 
     {0.69, CF*NC*(CF*(-5.82232251257547 - 4.9074820872675256*lm - 
          2.6342712171125737*lm^2 - 1.5722*lm^3) + 
        CA*(-8.14764881902921 - 7.6148537066642215*lm - 3.5835613441177308*
           lm^2 - 0.48039444444444446*lm^3) + 1.2616155313154376*NM + 
        2.130797199361851*lm*NM + 0.48480812317292077*lm^2*NM + 
        0.08734444444444445*lm^3*NM + 2.071195324271838*NL + 
        1.1785971993618507*lm*NL + 0.48480812317292077*lm^2*NL + 
        0.08734444444444445*lm^3*NL - 0.16155980948514703*NH + 
        3.178597199361851*lm*NH + 0.48480812317292077*lm^2*NH + 
        0.08734444444444445*lm^3*NH)}, 
     {0.695, CF*NC*(CF*(-5.822172863771461 - 4.902631772483353*lm - 
          2.6377861949653596*lm^2 - 1.57605*lm^3) + 
        CA*(-8.151386873235088 - 7.624887807932394*lm - 3.5914397054060823*
           lm^2 - 0.48157083333333334*lm^3) + 1.2454552836730812*NM + 
        2.146174904121917*lm*NM + 0.48583221916474223*lm^2*NM + 
        0.08755833333333334*lm^3*NM + 2.0739278545635944*NL + 
        1.180124904121917*lm*NL + 0.48583221916474223*lm^2*NL + 
        0.08755833333333334*lm^3*NL - 0.16361805071256397*NH + 
        3.180124904121917*lm*NH + 0.48583221916474223*lm^2*NH + 
        0.08755833333333334*lm^3*NH)}, 
     {0.7, CF*NC*(CF*(-5.822132347495799 - 4.897625906907142*lm - 
          2.6410729819128367*lm^2 - 1.58*lm^3) + 
        CA*(-8.155035140934212 - 7.634797065367671*lm - 3.5994250778067003*
           lm^2 - 0.48277777777777775*lm^3) + 1.229047179569191*NM + 
        2.161644794233203*lm*NM + 0.48686516566182425*lm^2*NM + 
        0.08777777777777777*lm^3*NM + 2.0766997587704124*NL + 
        1.181644794233203*lm*NL + 0.48686516566182425*lm^2*NL + 
        0.08777777777777777*lm^3*NL - 0.16567778476084938*NH + 
        3.181644794233203*lm*NH + 0.48686516566182425*lm^2*NH + 
        0.08777777777777777*lm^3*NH)}, 
     {0.705, CF*NC*(CF*(-5.822203387404515 - 4.892470589786516*lm - 
          2.644126799477749*lm^2 - 1.58405*lm^3) + 
        CA*(-8.158594904831038 - 7.644577712432467*lm - 3.607516001229312*
           lm^2 - 0.48401527777777775*lm^3) + 1.2123894804798099*NM + 
        2.177206522742822*lm*NM + 0.4879066971932083*lm^2*NM + 
        0.08800277777777778*lm^3*NM + 2.0795110743992935*NL + 
        1.1831565227428218*lm*NL + 0.4879066971932083*lm^2*NL + 
        0.08800277777777778*lm^3*NL - 0.167738284657123*NH + 
        3.183156522742822*lm*NH + 0.4879066971932083*lm^2*NH + 
        0.08800277777777778*lm^3*NH)}, 
     {0.71, CF*NC*(CF*(-5.822388310042382 - 4.887172042890735*lm - 
          2.646942887476839*lm^2 - 1.5882*lm^3) + 
        CA*(-8.162067501817814 - 7.6542260415810945*lm - 3.6157110211734786*
           lm^2 - 0.48528333333333334*lm^3) + 1.1954804635150158*NM + 
        2.1928597521301723*lm*NM + 0.4889565493042688*lm^2*NM + 
        0.08823333333333333*lm^3*NM + 2.082361844401739*NL + 
        1.1846597521301723*lm*NL + 0.4889565493042688*lm^2*NL + 
        0.08823333333333333*lm^3*NL - 0.16979882883199138*NH + 
        3.1846597521301723*lm*NH + 0.4889565493042688*lm^2*NH + 
        0.08823333333333333*lm^3*NH)}, 
     {0.715, CF*NC*(CF*(-5.822689344005181 - 4.881736608413427*lm - 
          2.649516504020031*lm^2 - 1.59245*lm^3) + 
        CA*(-8.165454321482539 - 7.663738403617979*lm - 3.6240086887283427*
           lm^2 - 0.48658194444444447*lm^3) + 1.1783184211536215*NM + 
        2.2086041541903065*lm*NM + 0.49001445855666836*lm^2*NM + 
        0.08846944444444445*lm^3*NM + 2.0852521169766156*NL + 
        1.1861541541903065*lm*NL + 0.49001445855666836*lm^2*NL + 
        0.08846944444444445*lm^3*NL - 0.17185870112714818*NH + 
        3.1861541541903065*lm*NH + 0.49001445855666836*lm^2*NH + 
        0.08846944444444445*lm^3*NH)}, 
     {0.72, CF*NC*(CF*(-5.823108619152615 - 4.876170746908857*lm - 
          2.6518429255058966*lm^2 - 1.5968*lm^3) + 
        CA*(-8.16875680464978 - 7.67311120706172*lm - 3.632407560571246*
           lm^2 - 0.48791111111111113*lm^3) + 1.1609016609825908*NM + 
        2.2244394099186264*lm*NM + 0.4910801625281054*lm^2*NM + 
        0.08871111111111112*lm^3*NM + 2.0881819453778325*NL + 
        1.1876394099186265*lm*NL + 0.4910801625281054*lm^2*NL + 
        0.08871111111111112*lm^3*NL - 0.17391719080187168*NH + 
        3.1876394099186265*lm*NH + 0.4910801625281054*lm^2*NH + 
        0.08871111111111112*lm^3*NH)}, 
     {0.725, CF*NC*(CF*(-5.8236481658701305 - 4.870481035261216*lm - 
          2.653917446613552*lm^2 - 1.60125*lm^3) + 
        CA*(-8.171976441953614 - 7.6823409175150585*lm - 3.640906198965252*
           lm^2 - 0.4892708333333333*lm^3) + 1.143228505441085*NM + 
        2.240365209396905*lm*NM + 0.492153399811864*lm^2*NM + 
        0.08895833333333333*lm^3*NM + 2.0911513877267*NL + 
        1.189115209396905*lm*NL + 0.492153399811864*lm^2*NL + 
        0.08895833333333333*lm^3*NL - 0.17597359253845624*NH + 
        3.189115209396905*lm*NH + 0.492153399811864*lm^2*NH + 
        0.08895833333333333*lm^3*NH)}, 
     {0.73, CF*NC*(CF*(-5.82430991437797 - 4.864674164686431*lm - 
          2.6557353802911376*lm^2 - 1.6058*lm^3) + 
        CA*(-8.175114772441969 - 7.691424057040739*lm - 3.6495031717556254*
           lm^2 - 0.4906611111111111*lm^3) + 1.1252972915690562*NM + 
        2.2563812516806214*lm*NM + 0.49323391001617434*lm^2*NM + 
        0.08921111111111112*lm^3*NM + 2.0941605068288665*NL + 
        1.1905812516806213*lm*NL + 0.49323391001617434*lm^2*NL + 
        0.08921111111111112*lm^3*NL - 0.17802720644661466*NH + 
        3.190581251680621*lm*NH + 0.49323391001617434*lm^2*NH + 
        0.08921111111111112*lm^3*NH)}, 
     {0.735, CF*NC*(CF*(-5.825095694085827 - 4.858756938765977*lm - 
          2.6572920577410235*lm^2 - 1.61045*lm^3) + 
        CA*(-8.178173382211677 - 7.7003572035433*lm - 3.658197052365313*
           lm^2 - 0.4920819444444444*lm^3) + 1.1071063707603064*NM + 
        2.2724872446876048*lm*NM + 0.4943214337633902*lm^2*NM + 
        0.08946944444444445*lm^3*NM + 2.097209369995717*NL + 
        1.1920372446876046*lm*NL + 0.4943214337633902*lm^2*NL + 
        0.08946944444444445*lm^3*NL - 0.1800773380668863*NH + 
        3.192037244687605*lm*NH + 0.4943214337633902*lm^2*NH + 
        0.08946944444444445*lm^3*NH)}, 
     {0.74, CF*NC*(CF*(-5.826007232991524 - 4.852736271512206*lm - 
          2.6585828284018747*lm^2 - 1.6152*lm^3) + 
        CA*(-8.181153903073524 - 7.709136990156795*lm - 3.666986419789462*
           lm^2 - 0.4935333333333333*lm^3) + 1.088654108519927*NM + 
        2.2886829050879793*lm*NM + 0.49541571268899304*lm^2*NM + 
        0.08973333333333333*lm^3*NM + 2.1002980488701306*NL + 
        1.1934829050879794*lm*NL + 0.49541571268899304*lm^2*NL + 
        0.08973333333333333*lm^3*NL - 0.1821232983730857*NH + 
        3.1934829050879796*lm*NH + 0.49541571268899304*lm^2*NH + 
        0.08973333333333333*lm^3*NH)}, 
     {0.745, CF*NC*(CF*(-5.827046157122201 - 4.846619185464698*lm - 
          2.6596030599277096*lm^2 - 1.62005*lm^3) + 
        CA*(-8.184058011246654 - 7.7177601046384465*lm - 3.6758698585890226*
           lm^2 - 0.49501527777777776*lm^3) + 1.0699388842260456*NM + 
        2.304967958195401*lm*NM + 0.4965164894404283*lm^2*NM + 
        0.09000277777777778*lm^3*NM + 2.103426619256485*NL + 
        1.1949179581954008*lm*NL + 0.4965164894404283*lm^2*NL + 
        0.09000277777777778*lm^3*NL - 0.18416440377382376*NH + 
        3.1949179581954006*lm*NH + 0.4965164894404283*lm^2*NH + 
        0.09000277777777778*lm^3*NH)}, 
     {0.75, CF*NC*(CF*(-5.828213990016542 - 4.840412809817144*lm - 
          2.6603481381640806*lm^2 - 1.625*lm^3) + 
        CA*(-8.186887426081661 - 7.726223288768238*lm - 3.684845958883469*
           lm^2 - 0.4965277777777778*lm^3) + 1.050959090895793*NM + 
        2.3213421378595744*lm*NM + 0.49762350767578223*lm^2*NM + 
        0.09027777777777778*lm^3*NM + 2.106595160954812*NL + 
        1.1963421378595742*lm*NL + 0.49762350767578223*lm^2*NL + 
        0.09027777777777778*lm^3*NL - 0.1861999761131347*NH + 
        3.1963421378595744*lm*NH + 0.49762350767578223*lm^2*NH + 
        0.09027777777777778*lm^3*NH)}, 
     {0.755, CF*NC*(CF*(-5.82951215224661 - 4.834124378574276*lm - 
          2.660813467121495*lm^2 - 1.63005*lm^3) + 
        CA*(-8.189643908811727 - 7.734523337754442*lm - 3.693913316342679*
           lm^2 - 0.49807083333333335*lm^3) + 1.031713134955423*NM + 
        2.3378051863600486*lm*NM + 0.4987365120623053*lm^2*NM + 
        0.09055833333333334*lm^3*NM + 2.109803757599003*NL + 
        1.1977551863600486*lm*NL + 0.4987365120623053*lm^2*NL + 
        0.09055833333333334*lm^3*NL - 0.18822934267023855*NH + 
        3.1977551863600486*lm*NH + 0.4987365120623053*lm^2*NH + 
        0.09055833333333334*lm^3*NH)}, 
     {0.76, CF*NC*(CF*(-5.830941960977917 - 4.827761228738388*lm - 
          2.6609944689461993*lm^2 - 1.6352*lm^3) + 
        CA*(-8.192329261331178 - 7.742657099645072*lm - 3.7030705321780055*
           lm^2 - 0.49964444444444445*lm^3) + 1.0121994360144988*NM + 
        2.3543568543012743*lm*NM + 0.4998552482747889*lm^2*NM + 
        0.09084444444444445*lm^3*NM + 2.113052496498961*NL + 
        1.199156854301274*lm*NL + 0.4998552482747889*lm^2*NL + 
        0.09084444444444445*lm^3*NL - 0.19025183615847008*NH + 
        3.199156854301274*lm*NH + 0.4998552482747889*lm^2*NH + 
        0.09084444444444445*lm^3*NH)}, 
     {0.765, CF*NC*(CF*(-5.832504629566409 - 4.821330798524956*lm - 
          2.6608865838884386*lm^2 - 1.64045*lm^3) + 
        CA*(-8.194945325000864 - 7.750621474745261*lm - 3.7123162131325786*
           lm^2 - 0.5012486111111111*lm^3) + 0.9924164266440811*NM + 
        2.3709969005089135*lm*NM + 0.5009794629938021*lm^2*NM + 
        0.09113611111111111*lm^3*NM + 2.116341468486617*NL + 
        1.2005469005089136*lm*NL + 0.5009794629938021*lm^2*NL + 
        0.09113611111111111*lm^3*NL - 0.19226679472340288*NH + 
        3.2005469005089133*lm*NH + 0.5009794629938021*lm^2*NH + 
        0.09113611111111111*lm^3*NH)}, 
     {0.77, CF*NC*(CF*(-5.834201267191061 - 4.814840625606901*lm - 
          2.660485270268295*lm^2 - 1.6458*lm^3) + 
        CA*(-8.197493979479745 - 7.758413415040534*lm - 3.721648971470868*
           lm^2 - 0.5028833333333333*lm^3) + 0.9723625521588377*NM + 
        2.3877250919274005*lm*NM + 0.5021089039037941*lm^2*NM + 
        0.09143333333333334*lm^3*NM + 2.1196707677656996*NL + 
        1.2019250919274005*lm*NL + 0.5021089039037941*lm^2*NL + 
        0.09143333333333334*lm^3*NL - 0.19427356194019654*NH + 
        3.2019250919274005*lm*NH + 0.5021089039037941*lm^2*NH + 
        0.09143333333333334*lm^3*NH)}, 
     {0.775, CF*NC*(CF*(-5.836032878520852 - 4.808298345387046*lm - 
          2.65978600443922*lm^2 - 1.65125*lm^3) + 
        CA*(-8.199977141582123 - 7.766029923625987*lm - 3.7310674249675393*
           lm^2 - 0.5045486111111112*lm^3) + 0.9520362704030045*NM + 
        2.40454120351873*lm*NM + 0.5032433196910678*lm^2*NM + 
        0.09173611111111112*lm^3*NM + 2.123040491765189*NL + 
        1.2032912035187298*lm*NL + 0.5032433196910678*lm^2*NL + 
        0.09173611111111112*lm^3*NL - 0.19627148681019466*NH + 
        3.20329120351873*lm*NH + 0.5032433196910678*lm^2*NH + 
        0.09173611111111112*lm^3*NH)}, 
     {0.78, CF*NC*(CF*(-5.838000363414906 - 4.801711689298309*lm - 
          2.658784280749359*lm^2 - 1.6568*lm^3) + 
        CA*(-8.202396764159918 - 7.773468054141317*lm - 3.7405701968956375*
           lm^2 - 0.5062444444444445*lm^3) + 0.9314360515401304*NM + 
        2.4214450181624736*lm*NM + 0.504382460041631*lm^2*NM + 
        0.09204444444444444*lm^3*NM + 2.1264507409963525*NL + 
        1.2046450181624735*lm*NL + 0.504382460041631*lm^2*NL + 
        0.09204444444444444*lm^3*NL - 0.19825992375679946*NH + 
        3.2046450181624735*lm*NH + 0.504382460041631*lm^2*NH + 
        0.09204444444444444*lm^3*NH)}, 
     {0.785, CF*NC*(CF*(-5.840104516654638 - 4.795088483131187*lm - 
          2.6574756115007574*lm^2 - 1.66245*lm^3) + 
        CA*(-8.204754835009478 - 7.780724910211726*lm - 3.7501559160141205*
           lm^2 - 0.5079708333333334*lm^3) + 0.9105603778465308*NM + 
        2.438436326557008*lm*NM + 0.5055260756389309*lm^2*NM + 
        0.09235833333333333*lm^3*NM + 2.129901618913275*NL + 
        1.2059863265570079*lm*NL + 0.5055260756389309*lm^2*NL + 
        0.09235833333333333*lm^3*NL - 0.20023823262064938*NH + 
        3.205986326557008*lm*NH + 0.5055260756389309*lm^2*NH + 
        0.09235833333333333*lm^3*NH)}, 
     {0.79, CF*NC*(CF*(-5.8423460277067765 - 4.788436645388083*lm - 
          2.655855526906557*lm^2 - 1.6682*lm^3) + 
        CA*(-8.207053375802339 - 7.7877976448946375*lm - 3.759823216554781*
           lm^2 - 0.5097277777777778*lm^3) + 0.8894077435083864*NM + 
        2.4555149271219454*lm*NM + 0.5066739181614754*lm^2*NM + 
        0.09267777777777778*lm^3*NM + 2.133393231776817*NL + 
        1.2073149271219454*lm*NL + 0.5066739181614754*lm^2*NL + 
        0.09267777777777778*lm^3*NL - 0.20220577865412354*NH + 
        3.2073149271219457*lm*NH + 0.5066739181614754*lm^2*NH + 
        0.09267777777777778*lm^3*NH)}, 
     {0.795, CF*NC*(CF*(-5.844725480516176 - 4.781764185664071*lm - 
          2.6539195750462623*lm^2 - 1.67405*lm^3) + 
        CA*(-8.209294441039416 - 7.79468346013222*lm - 3.7695707382085804*
           lm^2 - 0.5115152777777778*lm^3) + 0.867976654422418*NM + 
        2.472680625901756*lm*NM + 0.5078257402803479*lm^2*NM + 
        0.09300277777777778*lm^3*NM + 2.1369256885218975*NL + 
        1.208630625901756*lm*NL + 0.5078257402803479*lm^2*NL + 
        0.09300277777777778*lm^3*NL - 0.2041619325151977*NH + 
        3.208630625901756*lm*NH + 0.5078257402803479*lm^2*NH + 
        0.09300277777777778*lm^3*NH)}, 
     {0.8, CF*NC*(CF*(-5.847243353327352 - 4.775079203053628*lm - 
          2.651663321819169*lm^2 - 1.68*lm^3) + 
        CA*(-8.211480117028133 - 7.801379606209689*lm - 3.7793971261114128*
           lm^2 - 0.5133333333333333*lm^3) + 0.8462656280000714*NM + 
        2.489933236470569*lm*NM + 0.5089812956566205*lm^2*NM + 
        0.09333333333333334*lm^3*NM + 2.1404991006280376*NL + 
        1.2099332364705693*lm*NL + 0.5089812956566205*lm^2*NL + 
        0.09333333333333334*lm^3*NL - 0.20610607026067487*NH + 
        3.2099332364705693*lm*NH + 0.5089812956566205*lm^2*NH + 
        0.09333333333333334*lm^3*NH)}, 
     {0.805, CF*NC*(CF*(-5.849900018533741 - 4.768389884582966*lm - 
          2.649082350896038*lm^2 - 1.68605*lm^3) + 
        CA*(-8.213612520881941 - 7.8078833812193515*lm - 3.789301030829345*
           lm^2 - 0.5151819444444444*lm^3) + 0.8242731929751487*NM + 
        2.507272579838144*lm*NM + 0.5101403389386687*lm^2*NM + 
        0.09366944444444444*lm^3*NM + 2.1441135819930817*NL + 
        1.2112225798381442*lm*NL + 0.5101403389386687*lm^2*NL + 
        0.09366944444444444*lm^3*NL - 0.20803757333881265*NH + 
        3.2112225798381444*lm*NH + 0.5101403389386687*lm^2*NH + 
        0.09366944444444444*lm^3*NH)}, 
     {0.81, CF*NC*(CF*(-5.85269574255367 - 4.76170450366749*lm - 
          2.6461722636690945*lm^2 - 1.6922*lm^3) + 
        CA*(-8.215693799541766 - 7.814192130530367*lm - 3.7992811083433344*
           lm^2 - 0.5170611111111111*lm^3) + 0.801997889214821*NM + 
        2.5246984843569993*lm*NM + 0.5113026257593941*lm^2*NM + 
        0.09401111111111111*lm^3*NM + 2.1477692488100186*NL + 
        1.2124984843569993*lm*NL + 0.5113026257593941*lm^2*NL + 
        0.09401111111111111*lm^3*NL - 0.20995582858136982*NH + 
        3.212498484356999*lm*NH + 0.5113026257593941*lm^2*NH + 
        0.09401111111111111*lm^3*NH)}, 
     {0.815, CF*NC*(CF*(-5.855630685732099 - 4.755031418594026*lm - 
          2.6429286792004354*lm^2 - 1.69845*lm^3) + 
        CA*(-8.217726128818882 - 7.820303246264189*lm - 3.8093360200334665*
           lm^2 - 0.5189708333333334*lm^3) + 0.7794382675339626*NM + 
        2.542210785630685*lm*NM + 0.5124679127333576*lm^2*NM + 
        0.09435833333333334*lm^3*NM + 2.1514662194468355*NL + 
        1.2137607856306847*lm*NL + 0.5124679127333576*lm^2*NL + 
        0.09435833333333334*lm^3*NL - 0.21186022819509284*NH + 
        3.2137607856306847*lm*NH + 0.5124679127333576*lm^2*NH + 
        0.09435833333333334*lm^3*NH)}, 
     {0.82, CF*NC*(CF*(-5.858704902267208 - 4.74837907102738*lm - 
          2.639347234168914*lm^2 - 1.7048*lm^3) + 
        CA*(-8.21971171245876 - 7.826214166775657*lm - 3.819464432662724*
           lm^2 - 0.5209111111111111*lm^3) + 0.7565928895127432*NM + 
        2.559809326423192*lm*NM + 0.5136359574538285*lm^2*NM + 
        0.09471111111111111*lm^3*NM + 2.155204614329326*NL + 
        1.2150093264231918*lm*NL + 0.5136359574538285*lm^2*NL + 
        0.09471111111111111*lm^3*NL - 0.21375016975266267*NH + 
        3.215009326423192*lm*NH + 0.5136359574538285*lm^2*NH + 
        0.09471111111111111*lm^3*NH)}, 
     {0.825, CF*NC*(CF*(-5.8619183401609245 - 4.741755984540848*lm - 
          2.6354235828155783*lm^2 - 1.71125*lm^3) + 
        CA*(-8.2216527812254 - 7.8319223761396985*lm - 3.829665018360316*
           lm^2 - 0.5228819444444445*lm^3) + 0.7334603273174183*NM + 
        2.577493956569484*lm*NM + 0.5148065184897543*lm^2*NM + 
        0.09506944444444444*lm^3*NM + 2.1589845558267853*NL + 
        1.216243956569484*lm*NL + 0.5148065184897543*lm^2*NL + 
        0.09506944444444444*lm^3*NL - 0.21562505618312247*NH + 
        3.216243956569484*lm*NH + 0.5148065184897543*lm^2*NH + 
        0.09506944444444444*lm^3*NH)}, 
     {0.83, CF*NC*(CF*(-5.865270841192544 - 4.735170763170284*lm - 
          2.631153396887734*lm^2 - 1.7178*lm^3) + 
        CA*(-8.223551592005728 - 7.837425403643608*lm - 3.8399364546045853*
           lm^2 - 0.5248833333333334*lm^3) + 0.7100391635242612*NM + 
        2.5952645328871387*lm*NM + 0.5159793553826519*lm^2*NM + 
        0.09543333333333333*lm^3*NM + 2.1628061681405235*NL + 
        1.2174645328871387*lm*NL + 0.5159793553826519*lm^2*NL + 
        0.09543333333333333*lm^3*NL - 0.21748429576180434*NH + 
        3.2174645328871385*lm*NH + 0.5159793553826519*lm^2*NH + 
        0.09543333333333333*lm^3*NH)}, 
     {0.835, CF*NC*(CF*(-5.86876214091458 - 4.728632089991332*lm - 
          2.6265323655816957*lm^2 - 1.72445*lm^3) + 
        CA*(-8.225410426933594 - 7.84272082328486*lm - 3.850277424205518*
           lm^2 - 0.5269152777777778*lm^3) + 0.6863279909465747*NM + 
        2.6131209190890883*lm*NM + 0.5171542286434275*lm^2*NM + 
        0.09580277777777778*lm^3*NM + 2.166669577195134*NL + 
        1.2186709190890883*lm*NL + 0.5171542286434275*lm^2*NL + 
        0.09580277777777778*lm^3*NL - 0.2193273020997747*NH + 
        3.2186709190890883*lm*NH + 0.5171542286434275*lm^2*NH + 
        0.09580277777777778*lm^3*NH)}, 
     {0.84, CF*NC*(CF*(-5.872391868670061 - 4.722148725719455*lm - 
          2.6215561954842936*lm^2 - 1.7312*lm^3) + 
        CA*(-8.227231592532963 - 7.847806253274422*lm - 3.8606866152868675*
           lm^2 - 0.5289777777777778*lm^3) + 0.6623254124647301*NM + 
        2.63106298569745*lm*NM + 0.5183308997491274*lm^2*NM + 
        0.09617777777777778*lm^3*NM + 2.1705749105324452*NL + 
        1.21986298569745*lm*NL + 0.5183308997491274*lm^2*NL + 
        0.09617777777777778*lm^3*NL - 0.22115349413281604*NH + 
        3.21986298569745*lm*NH + 0.5183308997491274*lm^2*NH + 
        0.09617777777777778*lm^3*NH)}, 
     {0.845, CF*NC*(CF*(-5.8761595476304604 - 4.715729507332383*lm - 
          2.6162206105132007*lm^2 - 1.73805*lm^3) + 
        CA*(-8.229017418879847 - 7.852679355545525*lm - 3.8711627212679223*
           lm^2 - 0.5310708333333334*lm^3) + 0.6380300408591741*NM + 
        2.6490906099584306*lm*NM + 0.5195091311396223*lm^2*NM + 
        0.09655833333333333*lm^3*NM + 2.1745222972080955*NL + 
        1.2210406099584308*lm*NL + 0.5195091311396223*lm^2*NL + 
        0.09655833333333333*lm^3*NL - 0.22296229610996227*NH + 
        3.221040609958431*lm*NH + 0.5195091311396223*lm^2*NH + 
        0.09655833333333333*lm^3*NH)}, 
     {0.85, CF*NC*(CF*(-5.880064594853532 - 4.709383346714601*lm - 
          2.6105213518561365*lm^2 - 1.745*lm^3) + 
        CA*(-8.230770258782613 - 7.857337835267848*lm - 3.8817044408449304*
           lm^2 - 0.5331944444444444*lm^3) + 0.6134404986463511*NM + 
        2.6672036757582944*lm*NM + 0.5206886862142298*lm^2*NM + 
        0.09694444444444444*lm^3*NM + 2.1785118676906747*NL + 
        1.2222036757582946*lm*NL + 0.5206886862142298*lm^2*NL + 
        0.09694444444444444*lm^3*NL - 0.22475313758160495*NH + 
        3.2222036757582946*lm*NH + 0.5206886862142298*lm^2*NH + 
        0.09694444444444444*lm^3*NH)}, 
     {0.855, CF*NC*(CF*(-5.884106321360281 - 4.703119229323541*lm - 
          2.604454177909006*lm^2 - 1.75205*lm^3) + 
        CA*(-8.23249248698022 - 7.861779440367077*lm - 3.892310477972196*
           lm^2 - 0.5353486111111111*lm^3) + 0.5885554179174864*NM + 
        2.6854020735403856*lm*NM + 0.5218693293282781*lm^2*NM + 
        0.09733611111111111*lm^3*NM + 2.1825437537633605*NL + 
        1.2233520735403853*lm*NL + 0.5218693293282781*lm^2*NL + 
        0.09733611111111111*lm^3*NL - 0.22652545338718702*NH + 
        3.2233520735403856*lm*NH + 0.5218693293282781*lm^2*NH + 
        0.09733611111111111*lm^3*NH)}, 
     {0.86, CF*NC*(CF*(-5.888283932230387 - 4.696946212877087*lm - 
          2.5980148642130345*lm^2 - 1.7592*lm^3) + 
        CA*(-8.234186499358026 - 7.866001961049798*lm - 3.9029795418428717*
           lm^2 - 0.5375333333333333*lm^3) + 0.5633734401801778*NM + 
        2.7036857002231875*lm*NM + 0.523050825789613*lm^2*NM + 
        0.09773333333333334*lm^3*NM + 2.1866180884280007*NL + 
        1.2244857002231875*lm*NL + 0.523050825789613*lm^2*NL + 
        0.09773333333333334*lm^3*NL - 0.2282786836424995*NH + 
        3.2244857002231875*lm*NH + 0.523050825789613*lm^2*NH + 
        0.09773333333333334*lm^3*NH)}, 
     {0.865, CF*NC*(CF*(-5.892596526715378 - 4.690873426062078*lm - 
          2.5911992033909472*lm^2 - 1.76645*lm^3) + 
        CA*(-8.235854712180767 - 7.870003229333671*lm - 3.9137103468694563*
           lm^2 - 0.5397486111111112*lm^3) + 0.5378932162027437*NM + 
        2.7220544591194162*lm*NM + 0.5242329418550526*lm^2*NM + 
        0.0981361111111111*lm^3*NM + 2.1907350058115824*NL + 
        1.2256044591194164*lm*NL + 0.5242329418550526*lm^2*NL + 
        0.0981361111111111*lm^3*NL - 0.2300122737265969*NH + 
        3.2256044591194164*lm*NH + 0.5242329418550526*lm^2*NH + 
        0.0981361111111111*lm^3*NH)}, 
     {0.87, CF*NC*(CF*(-5.897043098368893 - 4.6849100672634325*lm - 
          2.5840030050822467*lm^2 - 1.7738*lm^3) + 
        CA*(-8.237499561342341 - 7.873781118582854*lm - 3.9245016126640198*
           lm^2 - 0.5419944444444444*lm^3) + 0.5121134058612772*NM + 
        2.7405082598561257*lm*NM + 0.5254154447267915*lm^2*NM + 
        0.09854444444444445*lm^3*NM + 2.194894641075026*NL + 
        1.2267082598561256*lm*NL + 0.5254154447267915*lm^2*NL + 
        0.09854444444444445*lm^3*NL - 0.2317256742683462*NH + 
        3.2267082598561254*lm*NH + 0.5254154447267915*lm^2*NH + 
        0.09854444444444445*lm^3*NH)}, 
     {0.875, CF*NC*(CF*(-5.901622535193372 - 4.679065403313581*lm - 
          2.576422095877641*lm^2 - 1.78125*lm^3) + 
        CA*(-8.239123501632024 - 7.877333543048622*lm - 3.935352064018168*
           lm^2 - 0.5442708333333334*lm^3) + 0.4860326779893567*NM + 
        2.75904701829582*lm*NM + 0.5265981025487578*lm^2*NM + 
        0.09895833333333333*lm^3*NM + 2.1990971303242572*NL + 
        1.2277970182958202*lm*NL + 0.5265981025487578*lm^2*NL + 
        0.09895833333333333*lm^3*NL - 0.23341834113262422*NH + 
        3.22779701829582*lm*NH + 0.5265981025487578*lm^2*NH + 
        0.09895833333333333*lm^3*NH)}, 
     {0.88, CF*NC*(CF*(-5.906333619802586 - 4.673348768261849*lm - 
          2.568452319252666*lm^2 - 1.7888*lm^3) + 
        CA*(-8.240729006016767 - 7.880658457415141*lm - 3.946260430882759*
           lm^2 - 0.5465777777777778*lm^3) + 0.45964971023036316*NM + 
        2.777670656458563*lm*NM + 0.5277806844029259*lm^2*NM + 
        0.09937777777777777*lm^3*NM + 2.203342610523498*NL + 
        1.2288706564585632*lm*NL + 0.5277806844029259*lm^2*NL + 
        0.09937777777777777*lm^3*NL - 0.23508973540617686*NH + 
        3.228870656458563*lm*NH + 0.5277806844029259*lm^2*NH + 
        0.09937777777777777*lm^3*NH)}, 
     {0.885, CF*NC*(CF*(-5.9111750295993595 - 4.667769562163479*lm - 
          2.5600895355005546*lm^2 - 1.79645*lm^3) + 
        CA*(-8.242318564939234 - 7.883753856350344*lm - 3.9572254483473914*
           lm^2 - 0.5489152777777778*lm^3) + 0.43296318889235763*NM + 
        2.796379102445063*lm*NM + 0.5289629603055863*lm^2*NM + 
        0.09980277777777778*lm^3*NM + 2.2076312194107293*NL + 
        1.2299291024450631*lm*NL + 0.5289629603055863*lm^2*NL + 
        0.09980277777777778*lm^3*NL - 0.23673932338315454*NH + 
        3.2299291024450634*lm*NH + 0.5289629603055863*lm^2*NH + 
        0.09980277777777778*lm^3*NH)}, 
     {0.89, CF*NC*(CF*(-5.916145336967926 - 4.662337249887962*lm - 
          2.551329621664393*lm^2 - 1.8042*lm^3) + 
        CA*(-8.243894685631211 - 7.886617774061878*lm - 3.9682458566196757*
           lm^2 - 0.5512833333333333*lm^3) + 0.40597180880547057*NM + 
        2.815172290360735*lm*NM + 0.5301447012035774*lm^2*NM + 
        0.10023333333333333*lm^3*NM + 2.2119630954152685*NL + 
        1.230972290360735*lm*NL + 0.5301447012035774*lm^2*NL + 
        0.10023333333333333*lm^3*NL - 0.23836657655033636*NH + 
        3.230972290360735*lm*NH + 0.5301447012035774*lm^2*NH + 
        0.10023333333333333*lm^3*NH)}, 
     {0.895, CF*NC*(CF*(-5.921243009480349 - 4.657061359946355*lm - 
          2.542168471468607*lm^2 - 1.81205*lm^3) + 
        CA*(-8.245459891442088 - 7.889248283858058*lm - 3.9793204010042964*
           lm^2 - 0.5536819444444444*lm^3) + 0.3786742731817579*NM + 
        2.834050160240717*lm*NM + 0.5313256789704782*lm^2*NM + 
        0.10066944444444445*lm^3*NM + 2.2163383775774212*NL + 
        1.232000160240717*lm*NL + 0.5313256789704782*lm^2*NL + 
        0.10066944444444445*lm^3*NL - 0.23997097157205635*NH + 
        3.232000160240717*lm*NH + 0.5313256789704782*lm^2*NH + 
        0.10066944444444445*lm^3*NH)}, 
     {0.9, CF*NC*(CF*(-5.9264664101164515 - 4.651951483337281*lm - 
          2.5326019952498235*lm^2 - 1.82*lm^3) + 
        CA*(-8.247016721182076 - 7.891643497713797*lm - 3.9904478318818906*
           lm^2 - 0.5561111111111111*lm^3) + 0.3510692934774781*NM + 
        2.853012657975837*lm*NM + 0.532505666402768*lm^2*NM + 
        0.10111111111111111*lm^3*NM + 2.2207572054701497*NL + 
        1.2330126579758371*lm*NL + 0.532505666402768*lm^2*NL + 
        0.10111111111111111*lm^3*NL - 0.24155199027484403*NH + 
        3.233012657975837*lm*NH + 0.532505666402768*lm^2*NH + 
        0.10111111111111111*lm^3*NH)}, 
     {0.905, CF*NC*(CF*(-5.9318137974967255 - 4.647017272411293*lm - 
          2.522626119887144*lm^2 - 1.82805*lm^3) + 
        CA*(-8.248567728479813 - 7.893801565841442*lm - 4.001626904687739*
           lm^2 - 0.5585708333333333*lm^3) + 0.323155589257746*NM + 
        2.872059735239516*lm*NM + 0.5336844372159525*lm^2*NM + 
        0.10155833333333333*lm^3*NM + 2.2252197191227148*NL + 
        1.234009735239516*lm*NL + 0.5336844372159525*lm^2*NL + 
        0.10155833333333333*lm^3*NL - 0.24310911963179113*NH + 
        3.234009735239516*lm*NH + 0.5336844372159525*lm^2*NH + 
        0.10155833333333333*lm^3*NH)}, 
     {0.91, CF*NC*(CF*(-5.937283326127715 - 4.642268439753308*lm - 
          2.512236788731871*lm^2 - 1.8362*lm^3) + 
        CA*(-8.250115481154104 - 7.895720676266511*lm - 4.012856379890294*
           lm^2 - 0.5610611111111111*lm^3) + 0.29493188806352*NM + 
        2.8911913494155934*lm*NM + 0.5348617660406595*lm^2*NM + 
        0.10201111111111111*lm^3*NM + 2.2297260589462504*NL + 
        1.2349913494155933*lm*NL + 0.5348617660406595*lm^2*NL + 
        0.10201111111111111*lm^3*NL - 0.24464185174665654*NH + 
        3.2349913494155933*lm*NH + 0.5348617660406595*lm^2*NH + 
        0.10201111111111111*lm^3*NH)}, 
     {0.915, CF*NC*(CF*(-5.942873046659364 - 4.63771475708281*lm - 
          2.501429961536723*lm^2 - 1.84445*lm^3) + 
        CA*(-8.251662560599444 - 7.897399054408227*lm - 4.0241350229695545*
           lm^2 - 0.5635819444444444*lm^3) + 0.26639692528087927*NM + 
        2.9104074635270694*lm*NM + 0.5360374284187068*lm^2*NM + 
        0.10246944444444445*lm^3*NM + 2.234276365661214*NL + 
        1.2359574635270694*lm*NL + 0.5360374284187068*lm^2*NL + 
        0.10246944444444445*lm^3*NL - 0.2461496838377203*NH + 
        3.2359574635270696*lm*NH + 0.5360374284187068*lm^2*NH + 
        0.10246944444444445*lm^3*NH)}, 
     {0.92, CF*NC*(CF*(-5.948580906153864 - 4.633366054171523*lm - 
          2.4902016143845738*lm^2 - 1.8528*lm^3) + 
        CA*(-8.253211561185038 - 7.898834962664856*lm - 4.0354616043952865*
           lm^2 - 0.5661333333333334*lm^3) + 0.2375494440125505*NM + 
        2.9297080461657488*lm*NM + 0.537211200799143*lm^2*NM + 
        0.10293333333333334*lm^3*NM + 2.238870780226684*NL + 
        1.236908046165749*lm*NL + 0.537211200799143*lm^2*NL + 
        0.10293333333333334*lm^3*NL - 0.24763211822139802*NH + 
        3.2369080461657487*lm*NH + 0.537211200799143*lm^2*NH + 
        0.10293333333333334*lm^3*NH)}, 
     {0.925, CF*NC*(CF*(-5.954404748365511 - 4.629232217778276*lm - 
          2.4785477396167512*lm^2 - 1.86125*lm^3) + 
        CA*(-8.254765089667051 - 7.900026700003763*lm - 4.046834899605119*
           lm^2 - 0.5687152777777778*lm^3) + 0.2083881949516413*NM + 
        2.9490930714227757*lm*NM + 0.538382860534264*lm^2*NM + 
        0.10340277777777777*lm^3*NM + 2.243509443771445*NL + 
        1.2378430714227757*lm*NL + 0.538382860534264*lm^2*NL + 
        0.10340277777777777*lm^3*NL - 0.24908866229562623*NH + 
        3.2378430714227755*lm*NH + 0.538382860534264*lm^2*NH + 
        0.10340277777777777*lm^3*NH)}, 
     {0.93, CF*NC*(CF*(-5.960342314031153 - 4.625323190600769*lm - 
          2.4664643457609308*lm^2 - 1.8698*lm^3) + 
        CA*(-8.256325764613766 - 7.900972601556157*lm - 4.058253688982506*
           lm^2 - 0.5713277777777778*lm^3) + 0.17891193625754137*NM + 
        2.9685625188200495*lm*NM + 0.5395521858756073*lm^2*NM + 
        0.10387777777777778*lm^3*NM + 2.248192497526835*NL + 
        1.2387625188200493*lm*NL + 0.5395521858756073*lm^2*NL + 
        0.10387777777777778*lm^3*NL - 0.2505188285230288*NH + 
        3.2387625188200495*lm*NH + 0.5395521858756073*lm^2*NH + 
        0.10387777777777778*lm^3*NH)}, 
     {0.935, CF*NC*(CF*(-5.966391241170759 - 4.621648970243962*lm - 
          2.4539474574586495*lm^2 - 1.87845*lm^3) + 
        CA*(-8.257896215843411 - 7.901671038216477*lm - 4.069716757834588*
           lm^2 - 0.5739708333333333*lm^3) + 0.14911943343395134*NM + 
        2.988116373242511*lm*NM + 0.5407189559699249*lm^2*NM + 
        0.10435833333333333*lm^3*NM + 2.252920082761304*NL + 
        1.2396663732425108*lm*NL + 0.5407189559699249*lm^2*NL + 
        0.10435833333333333*lm^3*NL - 0.25192213441387457*NH + 
        3.239666373242511*lm*NH + 0.5407189559699249*lm^2*NH + 
        0.10435833333333333*lm^3*NH)}, 
     {0.94, CF*NC*(CF*(-5.9725490653977085 - 4.618219608204818*lm - 
          2.440993115392478*lm^2 - 1.8872*lm^3) + 
        CA*(-8.259479083874359 - 7.902120416246361*lm - 4.0812228963699235*
           lm^2 - 0.5766444444444444*lm^3) + 0.11900945920900033*NM + 
        3.007754624871286*lm*NM + 0.5418829508551377*lm^2*NM + 
        0.10484444444444445*lm^3*NM + 2.2576923407166465*NL + 
        1.240554624871286*lm*NL + 0.5418829508551377*lm^2*NL + 
        0.10484444444444445*lm^3*NL - 0.25329810250883583*NH + 
        3.2405546248712858*lm*NH + 0.5418829508551377*lm^2*NH + 
        0.10484444444444445*lm^3*NH)}, 
     {0.945, CF*NC*(CF*(-5.978813220238389 - 4.6150452088731235*lm - 
          2.4275973762128795*lm^2 - 1.89605*lm^3) + 
        CA*(-8.261077019387432 - 7.9023191768831635*lm - 4.092770899676157*
           lm^2 - 0.5793486111111111*lm^3) + 0.08858079341741462*NM + 
        3.0274772691176794*lm*NM + 0.543043951456271*lm^2*NM + 
        0.10533611111111112*lm^3*NM + 2.2625094125458687*NL + 
        1.2414272691176795*lm*NL + 0.543043951456271*lm^2*NL + 
        0.10533611111111112*lm^3*NL - 0.2546462603615571*NH + 
        3.2414272691176795*lm*NH + 0.543043951456271*lm^2*NH + 
        0.10533611111111112*lm^3*NH)}, 
     {0.95, CF*NC*(CF*(-5.985181037460698 - 4.612135928548127*lm - 
          2.413756312464776*lm^2 - 1.905*lm^3) + 
        CA*(-8.262692682700093 - 7.902265795952965*lm - 4.10435956769757*
           lm^2 - 0.5820833333333333*lm^3) + 0.05783222288469972*NM + 
        3.047284306558004*lm*NM + 0.5442017395813764*lm^2*NM + 
        0.10583333333333333*lm^3*NM + 2.2673714392526563*NL + 
        1.2422843065580043*lm*NL + 0.5442017395813764*lm^2*NL + 
        0.10583333333333333*lm^3*NL - 0.255966140521043*NH + 
        3.2422843065580045*lm*NH + 0.5442017395813764*lm^2*NH + 
        0.10583333333333333*lm^3*NH)}, 
     {0.955, CF*NC*(CF*(-5.9916497474110715 - 4.609501974470726*lm - 
          2.399466012513864*lm^2 - 1.91405*lm^3) + 
        CA*(-8.264328743252204 - 7.901958783488028*lm - 4.11598770521257*
           lm^2 - 0.5848486111111111*lm^3) + 0.026762541313299585*NM + 
        3.0671757428692388*lm*NM + 0.5453560979174369*lm^2*NM + 
        0.10633611111111112*lm^3*NM + 2.272278561632403*NL + 
        1.2431257428692388*lm*NL + 0.5453560979174369*lm^2*NL + 
        0.10633611111111112*lm^3*NL - 0.2572572805138746*NH + 
        3.2431257428692386*lm*NH + 0.5453560979174369*lm^2*NH + 
        0.10633611111111112*lm^3*NH)}, 
     {0.96, CF*NC*(CF*(-5.998216479359665 - 4.607153603870968*lm - 
          2.3847225804726886*lm^2 - 1.9232*lm^3) + 
        CA*(-8.265987879103164 - 7.901396683348658*lm - 4.1276541218111*
           lm^2 - 0.5876444444444444*lm^3) - 0.004629450829303224*NM + 
        3.0871515887655008*lm*NM + 0.5465068100262604*lm^2*NM + 
        0.10684444444444445*lm^3*NM + 2.2772309202147585*NL + 
        1.2439515887655008*lm*NL + 0.5465068100262604*lm^2*NL + 
        0.10684444444444445*lm^3*NL - 0.25851922282626205*NH + 
        3.243951588765501*lm*NH + 0.5465068100262604*lm^2*NH + 
        0.10684444444444445*lm^3*NH)}, 
     {0.965, CF*NC*(CF*(-6.004878261853341 - 4.60510112303058*lm - 
          2.3695221361265184*lm^2 - 1.93245*lm^3) + 
        CA*(-8.267672776440165 - 7.900578072849414*lm - 4.139357631871992*
           lm^2 - 0.5904708333333333*lm^3) - 0.03634494642058148*NM + 
        3.107211859935328*lm*NM + 0.5476536603403621*lm^2*NM + 
        0.10735833333333333*lm^3*NM + 2.282228655207675*NL + 
        1.244761859935328*lm*NL + 0.5476536603403621*lm^2*NL + 
        0.10735833333333333*lm^3*NL - 0.25975151488594256*NH + 
        3.244761859935328*lm*NH + 0.5476536603403621*lm^2*NH + 
        0.10735833333333333*lm^3*NH)}, 
     {0.97, CF*NC*(CF*(-6.0116320230760945 - 4.603354886360309*lm - 
          2.353860814859034*lm^2 - 1.9418*lm^3) + 
        CA*(-8.269386129097295 - 7.89950156238963*lm - 4.15109705454026*
           lm^2 - 0.5933277777777778*lm^3) - 0.06838513179108592*NM + 
        3.1273565769797527*lm*NM + 0.5487964341588352*lm^2*NM + 
        0.10787777777777778*lm^3*NM + 2.2872719064429026*NL + 
        1.2455565769797525*lm*NL + 0.5487964341588352*lm^2*NL + 
        0.10787777777777778*lm^3*NL - 0.2609537090439307*NH + 
        3.2455565769797525*lm*NH + 0.5487964341588352*lm^2*NH + 
        0.10787777777777778*lm^3*NH)}, 
     {0.975, CF*NC*(CF*(-6.018474591216589 - 4.601925295491817*lm - 
          2.3377347675778566*lm^2 - 1.95125*lm^3) + 
        CA*(-8.271130638085335 - 7.898165795088191*lm - 4.162871213704345*
           lm^2 - 0.5962152777777778*lm^3) - 0.10075118683073046*NM + 
        3.1475857653511645*lm*NM + 0.5499349176432142*lm^2*NM + 
        0.10840277777777778*lm^3*NM + 2.292360813322906*NL + 
        1.2463357653511646*lm*NL + 0.5499349176432142*lm^2*NL + 
        0.10840277777777778*lm^3*NL - 0.26212536255613034*NH + 
        3.246335765351165*lm*NH + 0.5499349176432142*lm^2*NH + 
        0.10840277777777778*lm^3*NH)}, 
     {0.98, CF*NC*(CF*(-6.025402694842491 - 4.600822798383889*lm - 
          2.321140160639944*lm^2 - 1.9608*lm^3) + 
        CA*(-8.272909011131926 - 7.896569446422531*lm - 4.174678937973316*
           lm^2 - 0.5991333333333333*lm^3) - 0.1334442850932732*NM + 
        3.167899455292949*lm*NM + 0.5510688978133302*lm^2*NM + 
        0.10893333333333333*lm^3*NM + 2.2974955147691762*NL + 
        1.2470994552929489*lm*NL + 0.5510688978133302*lm^2*NL + 
        0.10893333333333333*lm^3*NL - 0.2632660375648138*NH + 
        3.2470994552929486*lm*NH + 0.5510688978133302*lm^2*NH + 
        0.10893333333333333*lm^3*NH)}, 
     {0.985, CF*NC*(CF*(-6.032412963281267 - 4.600057888442719*lm - 
          2.3040731757768675*lm^2 - 1.97045*lm^3) + 
        CA*(-8.274723962231977 - 7.894711223871787*lm - 4.186519060654043*
           lm^2 - 0.6020819444444444*lm^3) - 0.16646559389902585*NM + 
        3.188297681779888*lm*NM + 0.5521981625431593*lm^2*NM + 
        0.10946944444444444*lm^3*NM + 2.302676149171894*NL + 
        1.2478476817798878*lm*NL + 0.5521981625431593*lm^2*NL + 
        0.10946944444444444*lm^3*NL - 0.2643753010799777*NH + 
        3.247847681779888*lm*NH + 0.5521981625431593*lm^2*NH + 
        0.10946944444444444*lm^3*NH)}, 
     {0.99, CF*NC*(CF*(-6.039501927007147 - 4.5996411036560625*lm - 
          2.2865300100199994*lm^2 - 1.9802*lm^3) + 
        CA*(-8.27657821120804 - 7.892589866564089*lm - 4.198390419728333*
           lm^2 - 0.6050611111111112*lm^3) - 0.1998162744358236*NM + 
        3.2087804844593224*lm*NM + 0.5533225005566667*lm^2*NM + 
        0.11001111111111112*lm^3*NM + 2.307902854340922*NL + 
        1.2485804844593225*lm*NL + 0.5533225005566667*lm^2*NL + 
        0.11001111111111112*lm^3*NL - 0.26545272496058026*NH + 
        3.2485804844593225*lm*NH + 0.5533225005566667*lm^2*NH + 
        0.11001111111111112*lm^3*NH)}, 
     {0.995, CF*NC*(CF*(-6.046666018033964 - 4.599583025740988*lm - 
          2.268506875625625*lm^2 - 1.99005*lm^3) + 
        CA*(-8.278474483280444 - 7.890204144927915*lm - 4.210291857830052*
           lm^2 - 0.6080708333333333*lm^3) - 0.23349748185828664*NM + 
        3.2293479075930565*lm*NM + 0.5544417014236458*lm^2*NM + 
        0.11055833333333333*lm^3*NM + 2.3131757674580906*NL + 
        1.2492979075930566*lm*NL + 0.5544417014236458*lm^2*NL + 
        0.11055833333333333*lm^3*NL - 0.2664978858956691*NH + 
        3.2492979075930566*lm*NH + 0.5544417014236458*lm^2*NH + 
        0.11055833333333333*lm^3*NH)}, 
     {1., -2.0049093698225087*(CA - 2.*CF)*CF*NC + 0.000925925925925926*CF*NC*
        (CF*(-10868.817934755278 - 4967.885821649447*lm - 2430.*lm^2 - 
           2160.*lm^3) - 1.*CA*(6777.546629930479 + 8518.557089175276*lm + 
           4560.*lm^2 + 660.*lm^3) + 30.*((-9.63037315387456 + 117.*lm + 
             20.*lm^2 + 4.*lm^3)*NM + (83.46582090110702 + 45.*lm + 
             20.*lm^2 + 4.*lm^3)*NL + (-9.63037315387456 + 117.*lm + 
             20.*lm^2 + 4.*lm^3)*NH))}}
 
CbarTable["p", 2, 0] = {{0., -0.000038580246913580246*CF*NC*
       (-3.*CA*(5160.430157209292 + 198.04533104651125*lm + 7140.*lm^2 + 
          1320.*lm^3) + 2.*(CF*(-135.93938964079425 + 116.1865557539944*lm + 
            5670.*lm^2 - 3240.*lm^3) - 
          15.*((-288.8434648794611 - 83.04316479128514*lm - 84.*lm^2 - 
              24.*lm^3)*NM + (-288.8434648794611 - 83.04316479128514*lm - 
              84.*lm^2 - 24.*lm^3)*NL - 1.*(-114.9438057198067 + 
              83.04316479128514*lm + 84.*lm^2 + 24.*lm^3)*NH)))}, 
     {0.005, CF*NC*(CA*(0.6219310927376351 + 0.04213188554421318*lm + 
          0.8286566044434652*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.03640969813240417 + 0.004758816925722289*lm - 
          0.4337891927288752*lm^2 + 0.25*lm^3) - 0.33788253190594697*NM - 
        0.0990827356631779*lm*NM - 0.09763453414123609*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.33790572360523774*NL - 
        0.0990827356631779*lm*NL - 0.09763453414123609*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13501303227366604*NH - 
        0.0990827356631779*lm*NH - 0.09763453414123609*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.01, CF*NC*(CA*(0.6456294770716834 + 0.06089666287136164*lm + 
          0.8308735937792704*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.06104141869704785 + 0.0181503126979492*lm - 
          0.43016139199755754*lm^2 + 0.25*lm^3) - 0.3412580312618772*NM - 
        0.1019814910333822*lm*NM - 0.0980376231113825*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.34135518586282976*NL - 
        0.1019814910333822*lm*NL - 0.0980376231113825*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13695467957697205*NH - 
        0.1019814910333822*lm*NH - 0.0980376231113825*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.015, CF*NC*(CA*(0.6682100107923219 + 0.07916002799231264*lm + 
          0.8330367702160877*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.08418576509680241 + 0.031141590062874272*lm - 
          0.426621648737311*lm^2 + 0.25*lm^3) - 0.344408762225758*NM - 
        0.10480153311958085*lm*NM - 0.09843092791807656*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.34463476977681834*NL - 
        0.10480153311958085*lm*NL - 0.09843092791807656*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13885957342796895*NH - 
        0.10480153311958085*lm*NH - 0.09843092791807656*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.02, CF*NC*(CA*(0.6896066529977783 + 0.0968883200148942*lm + 
          0.835143880600311*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.10579847901774726 + 0.04369516450403265*lm - 
          0.4231736499267638*lm^2 + 0.25*lm^3) - 0.34732327546018077*NM - 
        0.1075372631504779*lm*NM - 0.09881403889702624*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3477354317240002*NL - 
        0.1075372631504779*lm*NL - 0.09881403889702624*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1407260872427732*NH - 
        0.1075372631504779*lm*NH - 0.09881403889702624*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.025, CF*NC*(CA*(0.7097935083829028 + 0.11405982994143121*lm + 
          0.8371931953804654*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1258933039542076 + 0.05578901986112636*lm - 
          0.4198202257410565*lm^2 + 0.25*lm^3) - 0.3499971728311856*NM - 
        0.1101851342623745*lm*NM - 0.09918664158432705*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3506541697972158*NL - 
        0.1101851342623745*lm*NL - 0.09918664158432705*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14255294622694986*NH - 
        0.1101851342623745*lm*NH - 0.09918664158432705*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.03, CF*NC*(CA*(0.7287673835523452 + 0.13066060997009005*lm + 
          0.8391833681627123*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.14451216363729505 + 0.06741084768303644*lm - 
          0.416563579370107*lm^2 + 0.25*lm^3) - 0.35243007615439403*NM - 
        0.11274292205351154*lm*NM - 0.09954849118109922*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.35339131129288365*NL - 
        0.11274292205351154*lm*NL - 0.09954849118109922*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14433913568006232*NH - 
        0.11274292205351154*lm*NH - 0.09954849118109922*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.035, CF*NC*(CA*(0.7465392487212967 + 0.14668220706885096*lm + 
          0.8411133521481317*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.16171171599374995 + 0.07855499114860179*lm - 
          0.4134054237576027*lm^2 + 0.25*lm^3) - 0.35462413423896294*NM - 
        0.11520933184343715*lm*NM - 0.09989939736026637*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3559492071535026*NL - 
        0.11520933184343715*lm*NL - 0.09989939736026637*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14608384633557128*NH - 
        0.11520933184343715*lm*NH - 0.09989939736026637*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.04, CF*NC*(CA*(0.7631293645076271 + 0.16212025425282808*lm + 
          0.8429823438729283*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17755627423593176 + 0.08922057926839307*lm - 
          0.4103470736624811*lm^2 + 0.25*lm^3) - 0.35658316560491704*NM - 
        0.11758375556040569*lm*NM - 0.1002392140375021*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.358331498395805*NL - 
        0.11758375556040569*lm*NL - 0.1002392140375021*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1477864374464225*NH - 
        0.11758375556040569*lm*NH - 0.1002392140375021*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.045, CF*NC*(CA*(0.7785642373472251 + 0.1769735191852009*lm + 
          0.8447897424250285*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1921137413981714 + 0.0994102885648818*lm - 0.40738951239540805*
           lm^2 + 0.25*lm^3) - 0.35831211972966986*NM - 
        0.11986610819721062*lm*NM - 0.10056783195606578*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.36054266477036334*NL - 
        0.11986610819721062*lm*NL - 0.10056783195606578*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14944640991682895*NH - 
        0.11986610819721062*lm*NH - 0.10056783195606578*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.05, CF*NC*(CA*(0.7928746004550505 + 0.1912432249198666*lm + 
          0.8465351183820412*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.20545314934913114 + 0.10912947415237512*lm - 
          0.40453344264756885*lm^2 + 0.25*lm^3) - 0.35981671773362905*NM - 
        0.12205671149775844*lm*NM - 0.10088517303915902*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.36258773003463857*NL - 
        0.12205671149775844*lm*NL - 0.10088517303915902*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1510633857399864*NH - 
        0.12205671149775844*lm*NH - 0.10088517303915902*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.055, CF*NC*(CA*(0.8060940177398593 + 0.20493254527104993*lm + 
          0.8482181893036543*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.2176431223408996 + 0.11838553538055596*lm - 
          0.4017793265940201*lm^2 + 0.25*lm^3) - 0.36110320255706174*NM - 
        0.12415620787726973*lm*NM - 0.10119118593399777*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3644720613724058*NL - 
        0.12415620787726973*lm*NL - 0.10119118593399777*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15263709168697728*NH - 
        0.12415620787726973*lm*NH - 0.10119118593399777*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.06, CF*NC*(CA*(0.8182578887946645 + 0.2180462186043524*lm + 
          0.8498387998792837*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.22875090411598806 + 0.1271874389014169*lm - 
          0.39912741837935395*lm^2 + 0.25*lm^3) - 0.36217815994952435*NM - 
        0.12616549479640224*lm*NM - 0.10148584240229401*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.36620122879964817*NL - 
        0.12616549479640224*lm*NL - 0.10148584240229401*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15416734601661056*NH - 
        0.12616549479640224*lm*NH - 0.10148584240229401*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.065, CF*NC*(CA*(0.8294027237950791 + 0.23059024540426765*lm + 
          0.8513969055166859*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.23884174301776231 + 0.13554535195131867*lm - 
          0.39657779097269574*lm^2 + 0.25*lm^3) - 0.3630483873267028*NM - 
        0.12808567357120285*lm*NM - 0.10176913433636714*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3677809045165293*NL - 
        0.12808567357120285*lm*NL - 0.10176913433636714*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15565404742072939*NH - 
        0.12808567357120285*lm*NH - 0.10176913433636714*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.07, CF*NC*(CA*(0.839565606441523 + 0.24257164712181234*lm + 
          0.8528925585554789*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.24797851160806736 + 0.1434703554092902*lm - 
          0.39413035872739827*lm^2 + 0.25*lm^3) - 0.3637207961231809*NM - 
        0.12991800871748202*lm*NM - 0.1020410712525113*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3692167897927636*NL - 
        0.12991800871748202*lm*NL - 0.1020410712525113*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15709716567775975*NH - 
        0.12991800871748202*lm*NH - 0.1020410712525113*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.075, CF*NC*(CA*(0.848783791595267 + 0.25399827107333206*lm + 
          0.8543258965347847*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.256221483401442 + 0.15097421616926407*lm - 0.39178489657944315*
           lm^2 + 0.25*lm^3) - 0.364202338241487*NM - 0.13166389519279498*lm*
         NM - 0.10230167815783965*lm^2*NM - 0.027777777777777776*lm^3*NM - 
        0.37051456135873206*NL - 0.13166389519279498*lm*NL - 
        0.10230167815783965*lm^2*NL - 0.027777777777777776*lm^3*NL + 
        0.15849673364608477*NH - 0.13166389519279498*lm*NH - 
        0.10230167815783965*lm^2*NH - 0.027777777777777776*lm^3*NH)}, 
     {0.08, CF*NC*(CA*(0.8570944015926238 + 0.2648786307236636*lm + 
          0.8556971321024553*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.2636282165522344 + 0.15806920459337093*lm - 
          0.38954105655961857*lm^2 + 0.25*lm^3) - 0.364499950228767*NM - 
        0.133324831692072*lm*NM - 0.10255099371559794*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3716798319246976*NL - 
        0.133324831692072*lm*NL - 0.10255099371559794*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15985284033114278*NH - 
        0.133324831692072*lm*NH - 0.10255099371559794*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.085, CF*NC*(CA*(0.8645341962012983 + 0.275221773666825*lm + 
          0.8570065442594214*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.27025351107672685 + 0.16476794686124713*lm - 
          0.3873983821209468*lm^2 + 0.25*lm^3) - 0.3646205107378581*NM - 
        0.13490239867020837*lm*NM - 0.10278906865322814*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3727181211191149*NL - 
        0.13490239867020837*lm*NL - 0.10278906865322814*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.16116562482863747*NH - 
        0.13490239867020837*lm*NH - 0.10278906865322814*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.09, CF*NC*(CA*(0.8711393983809816 + 0.28503717162999637*lm + 
          0.858254470706161*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.2761494168457694 + 0.17108330474999958*lm - 
          0.3853563206626457*lm^2 + 0.25*lm^3) - 0.36457080809556075*NM - 
        0.1363982401138535*lm*NM - 0.10301596437081714*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.37363483422447796*NL - 
        0.1363982401138535*lm*NL - 0.10301596437081714*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.16243527099360835*NH - 
        0.1363982401138535*lm*NH - 0.10301596437081714*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.095, CF*NC*(CA*(0.8769455628692825 + 0.29433462822501283*lm + 
          0.859441301110556*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.28136527655634685 + 0.17702827725958573*lm - 
          0.38341423454636286*lm^2 + 0.25*lm^3) - 0.36435751565810426*NM - 
        0.1378140483268064*lm*NM - 0.10323175171707079*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.37443524681884577*NL - 
        0.1378140483268064*lm*NL - 0.10323175171707079*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.16366200271877315*NH - 
        0.1378140483268064*lm*NH - 0.10323175171707079*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.1, CF*NC*(CA*(0.8819874779777193 + 0.3031242011674436*lm + 
          0.8605674711545092*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.2859477925659652 + 0.18261591983037603*lm - 
          0.381571410838076*lm^2 + 0.25*lm^3) - 0.36398717322900853*NM - 
        0.13915155116567243*lm*NM - 0.10343650990688044*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3751244939332578*NL - 
        0.13915155116567243*lm*NL - 0.10343650990688044*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1648460797300634*NH - 
        0.13915155116567243*lm*NH - 0.10343650990688044*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.105, CF*NC*(CA*(0.8862990933624407 + 0.31141613640781346*lm + 
          0.8616334572450445*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.2899411096740464 + 0.1878592778637421*lm - 0.3798270699626545*
           lm^2 + 0.25*lm^3) - 0.3634661732369756*NM - 
        0.14041250128759927*lm*NM - 0.10363032555970506*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3757075626883163*NL - 
        0.14041250128759927*lm*NL - 0.10363032555970506*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.16598779382549594*NH - 
        0.14041250128759927*lm*NH - 0.10363032555970506*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.11, CF*NC*(CA*(0.8899134682508535 + 0.31922081215658543*lm + 
          0.8626397717971099*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.2933869081642181 + 0.1927713319675022*lm - 0.37818037342291094*
           lm^2 + 0.25*lm^3) - 0.36280075067705586*NM - 
        0.141598667064584*lm*NM - 0.10381329184189879*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3761892876262595*NL - 
        0.141598667064584*lm*NL - 0.10381329184189879*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.16708746549732406*NH - 
        0.141598667064584*lm*NH - 0.10381329184189879*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.115, CF*NC*(CA*(0.8928627358644555 + 0.32654869118932606*lm + 
          0.8635869590118488*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.296324502998637 + 0.1973649528811756*lm - 0.3766304307078838*
           lm^2 + 0.25*lm^3) - 0.3619969760431949*NM - 
        0.14271182488861378*lm*NM - 0.10398550769912401*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3765743481392831*NL - 
        0.14271182488861378*lm*NL - 0.10398550769912401*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1681454408880361*NH - 
        0.14271182488861378*lm*NH - 0.10398550769912401*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.12, CF*NC*(CA*(0.8951780807157349 + 0.3334102801281592*lm + 
          0.8644755910870516*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.2987909461858546 + 0.20165286444168978*lm - 
          0.37517630549391545*lm^2 + 0.25*lm^3) - 0.36106075064821397*NM - 
        0.14375375264521417*lm*NM - 0.10414707716734273*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3768672675313011*NL - 
        0.14375375264521417*lm*NL - 0.10414707716734273*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.16916208903907182*NH - 
        0.14375375264521417*lm*NH - 0.10414707716734273*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.125, CF*NC*(CA*(0.8968897261645354 + 0.3398160946356954*lm + 
          0.8653062648067456*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.3008211301628888 + 0.2056476132630241*lm - 0.37381702122532545*
           lm^2 + 0.25*lm^3) - 0.3599978038543963*NM - 
        0.14472622417425854*lm*NM - 0.10429810875274162*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3770724133526057*NL - 
        0.14472622417425854*lm*NL - 0.10429810875274162*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.17013779939769963*NH - 
        0.14472622417425854*lm*NH - 0.10429810875274162*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.13, CF*NC*(CA*(0.8980269301596634 + 0.3457766296459937*lm + 
          0.8660795984650851*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.30244789063138167 + 0.20936154404738985*lm - 
          0.3725515661480427*lm^2 + 0.25*lm^3) - 0.3588136918352291*NM - 
        0.1456310045692425*lm*NM - 0.1044387148724397*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3771939987244523*NL - 
        0.1456310045692425*lm*NL - 0.1044387148724397*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1710729795527659*NH - 
        0.1456310045692425*lm*NH - 0.1044387148724397*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.135, CF*NC*(CA*(0.8986179875086955 + 0.35130233390651966*lm + 
          0.8667962290863637*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.30370210772946254 + 0.21280677963809963*lm - 
          0.3713788978586777*lm^2 + 0.25*lm^3) - 0.3575137975642457*NM - 
        0.14646984619185216*lm*NM - 0.1045690113490358*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.37723608443005363*NL - 
        0.14646984619185216*lm*NL - 0.1045690113490358*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.17196805317429506*NH - 
        0.14646984619185216*lm*NH - 0.1045690113490358*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.14, CF*NC*(CA*(0.898690237344163 + 0.3564035882247391*lm + 
          0.8674568099083984*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.30461280474861596 + 0.21599520507764178*lm - 
          0.37029794742262084*lm^2 + 0.25*lm^3) - 0.3561033317858538*NM - 
        0.14724448529915676*lm*NM - 0.10468911695304213*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.377202581594477*NL - 
        0.14724448529915676*lm*NL - 0.10468911695304213*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1728234581354119*NH - 
        0.14724448529915676*lm*NH - 0.10468911695304213*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.145, CF*NC*(CA*(0.8982700747100386 + 0.36109068690971247*lm + 
          0.8680620081010294*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.30520724384906 + 0.21893845505771115*lm - 0.3693076231074064*
           lm^2 + 0.25*lm^3) - 0.35458733476952164*NM - 
        0.1479566391973034*lm*NM - 0.10479915298806596*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3770972548118456*NL - 
        0.1479566391973034*lm*NL - 0.10479915298806596*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.17363964479794114*NH - 
        0.1479566391973034*lm*NH - 0.10479915298806596*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.15, CF*NC*(CA*(0.8973829653951875 + 0.36537382197787743*lm + 
          0.8686125026952078*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.30551101840970807 + 0.22164790424777792*lm - 
          0.3684068137714781*lm^2 + 0.25*lm^3) - 0.352970678685637*NM - 
        0.1486080038490607*lm*NM - 0.10489924291428021*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3769237256064841*NL - 
        0.1486080038490607*lm*NL - 0.10489924291428021*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1744170744454421*NH - 
        0.1486080038490607*lm*NH - 0.10489924291428021*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.155, CF*NC*(CA*(0.8960534633023013 + 0.3692630697569222*lm + 
          0.869108982701274*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.3055481417854744 + 0.22413466007024296*lm - 
          0.36759439194336974*lm^2 + 0.25*lm^3) - 0.3512580704709352*NM - 
        0.14920025187359898*lm*NM - 0.10498951200629225*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.37668547613701137*NL - 
        0.14920025187359898*lm*NL - 0.10498951200629225*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.17515621784945115*NH - 
        0.14920025187359898*lm*NH - 0.10498951200629225*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.16, CF*NC*(CA*(0.8943052297709099 + 0.3727683795751576*lm + 
          0.8695521453976689*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.30534113234697535 + 0.22640955755716424*lm - 
          0.36686921662199634*lm^2 + 0.25*lm^3) - 0.3494540550752211*NM - 
        0.14973503088601323*lm*NM - 0.10507008704200041*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.37638585307019895*NL - 
        0.14973503088601323*lm*NL - 0.10507008704200041*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1758575539564096*NH - 
        0.14973503088601323*lm*NH - 0.10507008704200041*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.165, CF*NC*(CA*(0.8921610543782111 + 0.37589956426831345*lm + 
          0.8699426947735611*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.3049110947540417 + 0.22848315597887225*lm - 
          0.36623013582508174*lm^2 + 0.25*lm^3) - 0.3475630190004241*NM - 
        0.1502139621316698*lm*NM - 0.10514109601943536*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.37602807156569096*NL - 
        0.1502139621316698*lm*NL - 0.10514109601943536*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.17652156868420424*NH - 
        0.1502139621316698*lm*NH - 0.10514109601943536*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.17, CF*NC*(CA*(0.8896428768269103 + 0.37866629227294324*lm + 
          0.8702813401107918*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.3042777974711663 + 0.23036573698080356*lm - 
          0.36567598890961334*lm^2 + 0.25*lm^3) - 0.34558919405875965*NM - 
        0.15063863937678876*lm*NM - 0.10520266789893186*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.37561521932417197*NL - 
        0.15063863937678876*lm*NL - 0.10520266789893186*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.17714875381848885*NH - 
        0.15063863937678876*lm*NH - 0.10520266789893186*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.175, CF*NC*(CA*(0.8867718095990463 + 0.3810780811069767*lm + 
          0.8705687946921806*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.30345974657476815 + 0.23206730400333467*lm - 
          0.36520560868552265*lm^2 + 0.25*lm^3) - 0.3435366612896534*NM - 
        0.15101062802199416*lm*NM - 0.10525493236827527*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3751502606608661*NL - 
        0.15101062802199416*lm*NL - 0.10525493236827527*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1777396060000242*NH - 
        0.15101062802199416*lm*NH - 0.10525493236827527*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.18, CF*NC*(CA*(0.8835681611120093 + 0.38314429206447725*lm + 
          0.8708057746246601*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.3024742559324966 + 0.2335975827916983*lm - 0.3648178233414653*
           lm^2 + 0.25*lm^3) - 0.34140935498567027*NM - 
        0.15133146441005685*lm*NM - 0.10529801962872608*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.374636040573794*NL - 
        0.15133146441005685*lm*NL - 0.10529801962872608*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.17829462579519903*NH - 
        0.15133146441005685*lm*NH - 0.10529801962872608*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.185, CF*NC*(CA*(0.8800514591600843 + 0.38487412597419457*lm + 
          0.8709929977669373*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.30133751385641167 + 0.2349660228303103*lm - 
          0.3645114581995571*lm^2 + 0.25*lm^3) - 0.33921106678643487*NM - 
        0.15160265530286693*lm*NM - 0.1053320602000492*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.37407528878235874*NL - 
        0.15160265530286693*lm*NL - 0.1053320602000492*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1788143168426991*NH - 
        0.15160265530286693*lm*NH - 0.1053320602000492*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.19, CF*NC*(CA*(0.8762404744637838 + 0.3862766198907353*lm + 
          0.871131182752454*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.30006464634680435 + 0.2361817995589194*lm - 
          0.364285337314166*lm^2 + 0.25*lm^3) - 0.33694544980676294*NM - 
        0.15182567750592002*lm*NM - 0.10535718474287044*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3734706237168521*NL - 
        0.15182567750592002*lm*NL - 0.10535718474287044*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.17929918506999507*NH - 
        0.15182567750592002*lm*NH - 0.10535718474287044*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.195, CF*NC*(CA*(0.8721532441815025 + 0.38736064460365294*lm + 
          0.8712210480993589*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.2986697770532316 + 0.23725381724761946*lm - 
          0.3641382849283219*lm^2 + 0.25*lm^3) - 0.33461602277123814*NM - 
        0.15200197762138165*lm*NM - 0.10537352389685313*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.37282455644358004*NL - 
        0.15200197762138165*lm*NL - 0.10537352389685313*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.17974973797393615*NH - 
        0.15200197762138165*lm*NH - 0.10537352389685313*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.2, NC*(CA*CF*(0.8678070952648383 + 0.3881349028639311*lm + 
          0.8712633114000264*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.29716608408523965 + 0.23819071242451384*lm - 
          0.3640691267999568*lm^2 + 0.25*lm^3) + 
        CF*((-0.33222617413247113 - 0.15213297191317857*lm - 
            0.10538120813333814*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.372139494513676 - 0.15213297191317857*lm - 0.10538120813333814*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18016648396028137 - 0.15213297191317857*lm - 0.10538120813333814*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.205, NC*(CA*CF*(0.8632186675612544 + 0.38860792823957063*lm + 
          0.8712586885833906*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.29556585380816525 + 0.23900085776416252*lm - 
          0.36407669140899723*lm^2 + 0.25*lm^3) + 
        CF*((-0.3297791661544743 - 0.1522200462696238*lm - 
            0.10538036762122253*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.371417745726438 - 0.1522200462696238*lm - 0.10538036762122253*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18054993173748016 - 0.1522200462696238*lm - 0.10538036762122253*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.21, NC*(CA*CF*(0.8584039365863896 + 0.38878808452258495*lm + 
          0.8712078932439965*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.29388053176006734 + 0.23969236635725572*lm - 
          0.3641598110552785*lm^2 + 0.25*lm^3) + 
        CF*((-0.32727813894604046 - 0.1522645562508581*lm - 
            0.10537113210496905*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3706615218003003 - 0.1522645562508581*lm - 0.10537113210496905*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1809005897604414 - 0.1522645562508581*lm - 0.10537113210496905*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.215, NC*(CA*CF*(0.8533782359038973 + 0.38868356561890943*lm + 
          0.8711116360322507*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2921207708247956 + 0.24027309629256105*lm - 
          0.36431732285631696*lm^2 + 0.25*lm^3) + 
        CF*((-0.32472611443199 - 0.15226782720993262*lm - 0.10535363079374256*
             lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.36987294194641945 - 0.15226782720993262*lm - 
            0.10535363079374256*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1812189657204097 - 0.15226782720993262*lm - 0.10535363079374256*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.22, NC*(CA*CF*(0.8481562790637215 + 0.3883023958607501*lm + 
          0.8709706241008556*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2902964767939007 + 0.2407506554913454*lm - 
          0.3645480696531454*lm^2 + 0.25*lm^3) + 
        CF*((-0.32212600025258525 - 0.15223115447769758*lm - 
            0.10532799226076162*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3690540363413907 - 0.15223115447769758*lm - 0.10532799226076162*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18150556607740725 - 0.15223115447769758*lm - 0.10532799226076162*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.225, NC*(CA*CF*(0.8427521810606255 + 0.3876524306878969*lm + 
          0.8707855606028645*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.28841685144686124 + 0.2411324067423922*lm - 
          0.3648509008316763*lm^2 + 0.25*lm^3) + 
        CF*((-0.31948059358345515 - 0.15215580360282965*lm - 
            0.10529434435203597*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.36820674949687376 - 0.15215580360282965*lm - 
            0.10529434435203597*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18176089563200343 - 0.15215580360282965*lm - 0.10529434435203597*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.23, NC*(CA*CF*(0.8371794792839289 + 0.38674135765065837*lm + 
          0.8705571442372043*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.286490433275203 + 0.24142547289260394*lm - 
          0.36522467306639295*lm^2 + 0.25*lm^3) + 
        CF*((-0.31679258487012346 - 0.15204301063935227*lm - 
            0.10525281410373412*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3673329435249378 - 0.15204301063935227*lm - 0.10525281410373412*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1819854571334476 - 0.15204301063935227*lm - 0.10525281410373412*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.235, NC*(CA*CF*(0.8314511539370477 + 0.38557669769245656*lm + 
          0.8702860688378704*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.28452513597176404 + 0.24163674215414607*lm - 
          0.3656682509925757*lm^2 + 0.25*lm^3) + 
        CF*((-0.3140645614727086 - 0.151893982474897*lm - 0.10520352766749158*
             lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.36643440129878213 - 0.151893982474897*lm - 0.10520352766749158*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1821797509214461 - 0.151893982474897*lm - 0.10520352766749158*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.24, NC*(CA*CF*(0.8255796479118597 + 0.3841658066748528*lm + 
          0.8699730230033283*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.28252828480167086 + 0.2417728734942837*lm - 
          0.3661805078127354*lm^2 + 0.25*lm^3) + 
        CF*((-0.3112990112175042 - 0.1517098971937391*lm - 0.1051466102430294*
             lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3655128295091771 - 0.1517098971937391*lm - 0.1051466102430294*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18234427459908628 - 0.1517098971937391*lm - 0.1051466102430294*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.245, NC*(CA*CF*(0.8195768861082366 + 0.38251587711194696*lm + 
          0.8696186897629512*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2805066509668319 + 0.24184030207858984*lm - 
          0.36676032584244345*lm^2 + 0.25*lm^3) + 
        CF*((-0.308498325853278 - 0.15149190446933108*lm - 
            0.10508218601750628*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.36456986161752386 - 0.15149190446933108*lm - 
            0.10508218601750628*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18247952273461168 - 0.15149190446933108*lm - 0.10508218601750628*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.25, NC*(CA*CF*(0.8134542941935802 + 0.38063394008477697*lm + 
          0.8692237462775846*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.27846648407082003 + 0.2418452447421582*lm - 
          0.3674065970003161*lm^2 + 0.25*lm^3) + 
        CF*((-0.3056648044108965 - 0.15124112598166597*lm - 
            0.105010378111076*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.36360706070688387 - 0.15124112598166597*lm - 0.105010378111076*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1825859865899334 - 0.15124112598166597*lm - 0.105010378111076*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.255, NC*(CA*CF*(0.8072228168008962 + 0.3785268673096023*lm + 
          0.8687888635715747*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.27641354278614244 + 0.24179370546690865*lm - 
          0.36811822324651416*lm^2 + 0.25*lm^3) + 
        CF*((-0.3028006564656407 - 0.150958655855339*lm - 0.1049313085281651*
             lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3626259222326832 - 0.150958655855339*lm - 0.1049313085281651*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18266415387392906 - 0.150958655855339*lm - 0.1049313085281651*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.26, NC*(CA*CF*(0.8008929351670331 + 0.37620137333684417*lm + 
          0.8683147062938094*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.274353123821052 + 0.24169148084609987*lm - 
          0.3688941169737665*lm^2 + 0.25*lm^3) + 
        CF*((-0.29990800530216544 - 0.150645561114651*lm - 
            0.10484509811402594*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.36162787667508056 - 0.150645561114651*lm - 0.10484509811402594*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18271450851872997 - 0.150645561114651*lm - 0.10484509811402594*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.265, NC*(CA*CF*(0.7944746842152475 + 0.3736640178600163*lm + 
          0.8678019325055225*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.27229008927830917 + 0.24154416551981217*lm - 
          0.3697332013545996*lm^2 + 0.25*lm^3) + 
        CF*((-0.2969888909825453 - 0.15030288215251728*lm - 
            0.1047518665161556*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3606142920952057 - 0.15030288215251728*lm - 0.1047518665161556*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18273753047733546 - 0.15030288215251728*lm - 0.1047518665161556*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.27, NC*(CA*CF*(0.7879776690883523 + 0.3709212081162567*lm + 
          0.8672511934927889*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2702288924936846 + 0.241357157567488*lm - 
          0.37063441064816355*lm^2 + 0.25*lm^3) + 
        CF*((-0.29404527331826324 - 0.1499316332103175*lm - 
            0.10465173215020405*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.35958647659764076 - 0.1499316332103175*lm - 0.10465173215020405*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1827336955410172 - 0.1499316332103175*lm - 0.10465173215020405*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.275, NC*(CA*CF*(0.7814110811403953 + 0.3679792013620989*lm + 
          0.8666631336018031*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2681736024375275 + 0.24113566384565605*lm - 
          0.37159669046977667*lm^2 + 0.25*lm^3) + 
        CF*((-0.29107903474733376 - 0.14953280286615328*lm - 
            0.10454481217002481*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.35854568070164056 - 0.14953280286615328*lm - 
            0.10454481217002481*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18270347517509203 - 0.14953280286615328*lm - 0.10454481217002481*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.28, NC*(CA*CF*(0.7747837133961882 + 0.3648441074099245*lm + 
          0.8660383900951816*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2661279267584158 + 0.24088470526075403*lm - 
          0.3726189980260665*lm^2 + 0.25*lm^3) + 
        CF*((-0.2880919831180217 - 0.14910735452927368*lm - 
            0.10443122244154816*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3574930996236714 - 0.14910735452927368*lm - 0.10443122244154816*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18264733637174546 - 0.14910735452927368*lm - 0.10443122244154816*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.285, NC*(CA*CF*(0.7681039754891007 + 0.3615218912121507*lm + 
          0.8653775930276671*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.26409523354376313 + 0.24060912196853823*lm - 
          0.37370030231836276*lm^2 + 0.25*lm^3) + 
        CF*((-0.2850858543808444 - 0.14865622693869004*lm - 
            0.10431107752018191*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3564298754739047 - 0.14865622693869004*lm - 0.10431107752018191*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18256574151868513 - 0.14865622693869004*lm - 0.10431107752018191*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.29, NC*(CA*CF*(0.7613799080883954 + 0.35801837548164295*lm + 
          0.8646813651397371*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2620785718682759 + 0.24031357849294652*lm - 
          0.3748395843167938*lm^2 + 0.25*lm^3) + 
        CF*((-0.28206231519071523 - 0.14818033466423444*lm - 
            0.10418449063146736*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.35535709936933146 - 0.14818033466423444*lm - 
            0.10418449063146736*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18245914828249152 - 0.14818033466423444*lm - 0.10418449063146736*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.295, NC*(CA*CF*(0.7546191968280727 + 0.3543392433381297*lm + 
          0.8639503217677296*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.26008069119730115 + 0.2400025687584965*lm - 
          0.3760358371073517*lm^2 + 0.25*lm^3) + 
        CF*((-0.27902296542122834 - 0.14768056860852305*lm - 
            0.1040515736547387*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.35427581346617254 - 0.14768056860852305*lm - 0.1040515736547387*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18232800950561415 - 0.14768056860852305*lm - 0.1040515736547387*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.3, NC*(CA*CF*(0.7478291729027294 + 0.3504900409715447*lm + 
          0.8631850707692101*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.25810408540239194 + 0.23968042103136383*lm - 
          0.3772880660140197*lm^2 + 0.25*lm^3) + 
        CF*((-0.27596934059318523 - 0.14715779650847075*lm - 
            0.10391243710955336*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3531870129142517 - 0.14715779650847075*lm - 0.10391243710955336*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18217277311603644 - 0.14715779650847075*lm - 0.10391243710955336*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.305, NC*(CA*CF*(0.7410168800293527 + 0.3464761803142508*lm + 
          0.8623862124623942*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2561509020768358 + 0.2393513027652224*lm - 
          0.3785952886979004*lm^2 + 0.25*lm^3) + 
        CF*((-0.2729029142195461 - 0.1466128634351681*lm - 
            0.10376719014467774*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.35209164773597795 - 0.1466128634351681*lm - 0.10376719014467774*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18199388204870162 - 0.1466128634351681*lm - 0.10376719014467774*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.31, NC*(CA*CF*(0.7341890017450433 + 0.34230294171502385*lm + 
          0.861554339578528*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.25422312929392243 + 0.2390192253487479*lm - 
          0.3799565352351359*lm^2 + 0.25*lm^3) + 
        CF*((-0.2698251000690381 - 0.14604659229107933*lm - 
            0.10361594052942934*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.350990624632548 - 0.14604659229107933*lm - 0.10361594052942934*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18179177417785516 - 0.14604659229107933*lm - 0.10361594052942934*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.315, NC*(CA*CF*(0.7273519334262023 + 0.33797547660849797*lm + 
          0.860690037226216*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2523224911167923 + 0.2386880487524071*lm - 
          0.3813708481752829*lm^2 + 0.25*lm^3) + 
        CF*((-0.2667372543506908 - 0.14545978430365097*lm - 
            0.1034587946471908*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.34988480871993966 - 0.14545978430365097*lm - 0.1034587946471908*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18156688225951823 - 0.14545978430365097*lm - 0.1034587946471908*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.32, NC*(CA*CF*(0.7205117780317168 + 0.3334988101745187*lm + 
          0.8597938828667517*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2504504939318317 + 0.23836148607278568*lm - 
          0.38283728258167893*lm^2 + 0.25*lm^3) + 
        CF*((-0.2636406778215851 - 0.14485321951453903*lm - 
            0.10329585749092457*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.34877502519721615 - 0.14485321951453903*lm - 
            0.10329585749092457*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18131963388336086 - 0.14485321951453903*lm - 0.10329585749092457*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.325, NC*(CA*CF*(0.7136743573172444 + 0.32887784398251235*lm + 
          0.858866446299583*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.24860844018559516 + 0.238043107973259*lm - 
          0.3843549060552279*lm^2 + 0.25*lm^3) + 
        CF*((-0.26053661782010545 - 0.14422765726376705*lm - 
            0.10312723266053024*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.34766206094960495 - 0.14422765726376705*lm - 
            0.10312723266053024*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18105045143329393 - 0.14422765726376705*lm - 0.10312723266053024*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.33, NC*(CA*CF*(0.7068452226423908 + 0.3241173586165792*lm + 
          0.8579082896571004*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2467974413530168 + 0.23773634702029364*lm - 
          0.3859227987429265*lm^2 + 0.25*lm^3) + 
        CF*((-0.2574262702269778 - 0.14358383666822142*lm - 
            0.10295302236189706*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.34654666608875784 - 0.14358383666822142*lm - 
            0.10295302236189706*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.180759752056145 - 0.14358383666822142*lm - 0.10295302236189706*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.335, NC*(CA*CF*(0.7000296653838471 + 0.3192220162775531*lm + 
          0.8569199674080029*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.24501843017934977 + 0.23744450191508717*lm - 
          0.38754005333235886*lm^2 + 0.25*lm^3) + 
        CF*((-0.25431078135635793 - 0.14292247709397476*lm - 
            0.10277332740751569*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3454295554325315 - 0.14292247709397476*lm - 0.10277332740751569*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18044794763782715 - 0.14292247709397476*lm - 0.10277332740751569*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.34, NC*(CA*CF*(0.6932327269673629 + 0.31419636335875195*lm + 
          0.8559020263685403*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2432721722359105 + 0.23717074162062088*lm - 
          0.3892057750332978*lm^2 + 0.25*lm^3) + 
        CF*((-0.25119124977920837 - 0.14224427862200228*lm - 
            0.10258824721852247*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.34431140992656645 - 0.14224427862200228*lm - 
            0.10258824721852247*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.18011544478644922 - 0.14224427862200228*lm - 0.10258824721852247*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.345, NC*(CA*CF*(0.68645920853122 + 0.3090448329925761*lm + 
          0.8548550057209907*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.24155927682747425 + 0.23691810938451732*lm - 
          0.3909190815474697*lm^2 + 0.25*lm^3) + 
        CF*((-0.24806872808116906 - 0.14154992250692391*lm - 
            0.10239787982805892*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3431928780098721 - 0.14154992250692391*lm - 0.10239787982805892*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1797626448218527 - 0.14154992250692391*lm - 0.10239787982805892*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.35, NC*(CA*CF*(0.6797136802336224 + 0.30377174756549924*lm + 
          0.8537794370387712*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2398802072870599 + 0.23668952665837023*lm - 
          0.3926791030274652*lm^2 + 0.25*lm^3) + 
        CF*((-0.2449442245570906 - 0.14084007162846487*lm - 
            0.1022023218858372*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.34207457692655924 - 0.14084007162846487*lm - 0.1022023218858372*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17938994377109638 - 0.14084007162846487*lm - 0.1022023218858372*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.355, NC*(CA*CF*(0.6730004902161557 + 0.2983813211993469*lm + 
          0.8526758443176241*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.23823529069184915 + 0.23648779691445168*lm - 
          0.394484982025706*lm^2 + 0.25*lm^3) + 
        CF*((-0.24181870484435414 - 0.14011537093538032*lm - 
            0.10200166866381045*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3409570939857923 - 0.14011537093538032*lm - 0.10200166866381045*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17899773236944017 - 0.14011537093538032*lm - 0.10200166866381045*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.36, NC*(CA*CF*(0.6663237732351847 + 0.292877662197069*lm + 
          0.851544744012363*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.23662472703210521 + 0.23631560936090387*lm - 
          0.39633587343431503*lm^2 + 0.25*lm^3) + 
        CF*((-0.23869309349705758 - 0.13937644788163814*lm - 
            0.10179601406285389*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3398409877719652 - 0.13937644788163814*lm - 0.10179601406285389*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17858639606641077 - 0.13937644788163814*lm - 0.10179601406285389*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.365, NC*(CA*CF*(0.6596874589727678 + 0.28726477545149626*lm + 
          0.8503866450786968*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.235048597863179 + 0.23617554255669893*lm - 
          0.398230944416678*lm^2 + 0.25*lm^3) + 
        CF*((-0.23556827550309883 - 0.13862391285469644*lm - 
            0.10158545062036911*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.33872678930703665 - 0.13862391285469644*lm - 
            0.10158545062036911*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1781563150365588 - 0.13862391285469644*lm - 0.10158545062036911*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.37, NC*(CA*CF*(0.6530952800383603 + 0.28154656481581997*lm + 
          0.8492020490196847*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.233506874469015 + 0.23607006792779495*lm - 
          0.4001693743314252*lm^2 + 0.25*lm^3) + 
        CF*((-0.23244509774613503 - 0.13785835959574985*lm - 
            0.10137006951873054*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.33761500316689463 - 0.13785835959574985*lm - 
            0.10137006951873054*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17770786419454293 - 0.13785835959574985*lm - 0.10137006951873054*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.375, NC*(CA*CF*(0.6465507796722695 + 0.275726835434765*lm + 
          0.8479914499364074*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.23199942556398606 + 0.23600155318604338*lm - 
          0.40215035464951515*lm^2 + 0.25*lm^3) + 
        CF*((-0.22932437041434658 - 0.13708036561185358*lm - 
            0.10114996059449832*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3365061085535516 - 0.13708036561185358*lm - 0.10114996059449832*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17724141321420137 - 0.13708036561185358*lm - 0.10114996059449832*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.38, NC*(CA*CF*(0.640057319161516 + 0.26980929603562415*lm + 
          0.8467553345824692*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2305260245583938 + 0.23597226565250357*lm - 
          0.4041730888650503*lm^2 + 0.25*lm^3) + 
        CF*((-0.226206868357879 - 0.13629049257986325*lm - 
            0.10092521234832774*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.33540056032490945 - 0.13629049257986325*lm - 
            0.10092521234832774*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.176757326551292 - 0.13629049257986325*lm - 0.10092521234832774*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.385, NC*(CA*CF*(0.633618084978435 + 0.26379756117850856*lm + 
          0.8454941824219699*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2290863564115618 + 0.2359843754869078*lm - 
          0.40623679240041277*lm^2 + 0.25*lm^3) + 
        CF*((-0.22309333239678453 - 0.13548928674215613*lm - 
            0.1006959119555097*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.33429878998376683 - 0.13548928674215613*lm - 0.1006959119555097*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1762559634696054 - 0.13548928674215613*lm - 0.1006959119555097*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.39, NC*(CA*CF*(0.6272360956520403 + 0.25769515346532773*lm + 
          0.844208465690616*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2276800240951202 + 0.23603995882508738*lm - 
          0.40834069250626476*lm^2 + 0.25*lm^3) + 
        CF*((-0.21998447058122886 - 0.13467727929412251*lm - 
            0.1004621452770817*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3332012066276828 - 0.13467727929412251*lm - 0.1004621452770817*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17573767807017238 - 0.13467727929412251*lm - 0.1004621452770817*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.395, NC*(CA*CF*(0.6209142083818635 + 0.25150550570716074*lm + 
          0.8428986494596585*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.226306554687825 + 0.2361410008262257*lm - 
          0.4104840281569224*lm^2 + 0.25*lm^3) + 
        CF*((-0.21688095940567698 - 0.13385498676343768*lm - 
            0.10022399687145306*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3321081978612465 - 0.13385498676343768*lm - 0.10022399687145306*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17520281932330797 - 0.13385498676343768*lm - 0.10022399687145306*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.4, NC*(CA*CF*(0.6146551254036643 + 0.24523196304980988*lm + 
          0.8415651917023722*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2249654051220741 + 0.23628939863184614*lm - 
          0.41266604994157274*lm^2 + 0.25*lm^3) + 
        CF*((-0.213783444978716 - 0.1330229113811426*lm - 0.09998155000649192*
             lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3310201306722467 - 0.1330229113811426*lm - 0.09998155000649192*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17465173110324894 - 0.1330229113811426*lm - 0.09998155000649192*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.405, NC*(CA*CF*(0.6084614001161083 + 0.23887778505744195*lm + 
          0.8402085433628054*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.22365596760116338 + 0.2364869642384732*lm - 
          0.4148860199517731*lm^2 + 0.25*lm^3) + 
        CF*((-0.21069254415012173 - 0.1321815414445788*lm - 
            0.09973488667202521*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3299373522731765 - 0.1321815414445788*lm - 0.09973488667202521*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17408475222515912 - 0.1321815414445788*lm - 0.09973488667202521*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.41, NC*(CA*CF*(0.6023354429772041 + 0.23244614775432873*lm + 
          0.8388291484265532*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.222377574705276 + 0.23673542728592636*lm - 
          0.4171432116656402*lm^2 + 0.25*lm^3) + 
        CF*((-0.2076088455967225 - 0.1313313516722364*lm - 
            0.09948408759270665*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.32886019090945257 - 0.1313313516722364*lm - 0.09948408759270665*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17350221648429168 - 0.1313313516722364*lm - 0.09948408759270665*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.415, NC*(CA*CF*(0.5962795271789967 + 0.2259401456247871*lm + 
          0.8374274439933239*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2211295042032019 + 0.23703643776321906*lm - 
          0.4194369098291063*lm^2 + 0.25*lm^3) + 
        CF*((-0.20453291086856162 - 0.13047280355058766*lm - 
            0.09922923224121041*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.32778895663567686 - 0.13047280355058766*lm - 
            0.09922923224121041*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17290445269710983 - 0.13047280355058766*lm - 0.09922923224121041*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.42, NC*(CA*CF*(0.5902957941087236 + 0.2193627935715022*lm + 
          0.836003860351081*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.21991098358584904 + 0.23739156863403885*lm - 
          0.4217664103345948*lm^2 + 0.25*lm^3) + 
        CF*((-0.20146527539681078 - 0.1296063456729888*lm - 
            0.09897039885171169*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3267239420612135 - 0.1296063456729888*lm - 0.09897039885171169*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1722917847441829 - 0.1296063456729888*lm - 0.09897039885171169*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.425, NC*(CA*CF*(0.5843862586043571 + 0.21271702883248853*lm + 
          0.8345588210515635*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.21872119433672332 + 0.23780231838378457*lm - 
          0.4241310200974414*lm^2 + 0.25*lm^3) + 
        CF*((-0.1984064494648352 - 0.1287324140707424*lm - 
            0.09870766443361761*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3256654230663067 - 0.1287324140707424*lm - 0.09870766443361761*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17166453161468476 - 0.1287324140707424*lm - 0.09870766443361761*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.43, NC*(CA*CF*(0.5785528140121812 + 0.20600571285700683*lm + 
          0.8330927429869998*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.21755927595371816 + 0.2382701134901272*lm - 
          0.4265300569303641*lm^2 + 0.25*lm^3) + 
        CF*((-0.19535691914376493 - 0.12785143253642164*lm - 
            0.0984411047855151*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.32461365948991483 - 0.12785143253642164*lm - 0.0984411047855151*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1710230074523339 - 0.12785143253642164*lm - 0.0984411047855151*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.435, NC*(CA*CF*(0.5727972370537764 + 0.19923163314081116*lm + 
          0.8316060364678396*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2164243297357702 + 0.23879631081904965*lm - 
          0.42896284941626256*lm^2 + 0.25*lm^3) + 
        CF*((-0.1923171471938771 - 0.12696381293956363*lm - 
            0.09817079450930416*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3235688957903903 - 0.12696381293956363*lm - 0.09817079450930416*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.17036752160262514 - 0.12696381293956363*lm - 0.09817079450930416*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.44, NC*(CA*CF*(0.5671211925095322 + 0.192397505021149*lm + 
          0.8300991053013498*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.21531542234719162 + 0.23938219994830334*lm - 
          0.4314287367796094*lm^2 + 0.25*lm^3) + 
        CF*((-0.18928757393305018 - 0.12606995553484582*lm - 
            0.09789680702448784*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3225313616800892 - 0.12606995553484582*lm - 0.09789680702448784*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.16969837866121298 - 0.12606995553484582*lm - 0.09789680702448784*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.445, NC*(CA*CF*(0.561526237725542 + 0.18550597343197925*lm + 
          0.8285723468709213*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.21423158917179055 + 0.24002900542019856*lm - 
          0.4339270687566742*lm^2 + 0.25*lm^3) + 
        CF*((-0.18626861807350484 - 0.12517024926286452*lm - 
            0.09761921458259175*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3215012727349517 - 0.12517024926286452*lm - 0.09761921458259175*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.16901587852331493 - 0.12517024926286452*lm - 0.09761921458259175*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.45, NC*(CA*CF*(0.5560138269504955 + 0.178559614619911*lm + 
          0.8270261522159522*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.21317183746822765 + 0.24073788892562212*lm - 
          0.43645720546480543*lm^2 + 0.25*lm^3) + 
        CF*((-0.18326067752800282 - 0.12426507204363835*lm - 
            0.09733808828168829*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3204788309800523 - 0.12426507204363835*lm - 0.09733808828168829*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.16832031643401368 - 0.12426507204363835*lm - 0.09733808828168829*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.455, NC*(CA*CF*(0.5505853155089386 + 0.17156093782139636*lm + 
          0.8254609061121803*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.21213514933743416 + 0.24150995142114845*lm - 
          0.43901851727097785*lm^2 + 0.25*lm^3) + 
        CF*((-0.1802641301866334 - 0.1233547910629631*lm - 
            0.09705349808100246*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3194642254520787 - 0.1233547910629631*lm - 0.09705349808100246*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.16761198303934366 - 0.1233547910629631*lm - 0.09705349808100246*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.46, NC*(CA*CF*(0.5452419638170397 + 0.16451238690173903*lm + 
          0.8238769871523451*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.21112048451232393 + 0.24234623518108225*lm - 
          0.44161038465979885*lm^2 + 0.25*lm^3) + 
        CF*((-0.17727933466527587 - 0.12243976305174757*lm - 
            0.09676551281557791*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.31845763273966005 - 0.12243976305174757*lm - 
            0.09676551281557791*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.16689116443805563 - 0.12243976305174757*lm - 0.09676551281557791*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.465, NC*(CA*CF*(0.5399849412467758 + 0.15741634195650195*lm + 
          0.8222747678270743*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2101267829794789 + 0.243247725786239*lm - 
          0.44423219810115105*lm^2 + 0.25*lm^3) + 
        CF*((-0.17430663102678576 - 0.12152033455846134*lm - 
            0.09647420021098321*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3174592175024269 - 0.12152033455846134*lm - 0.09647420021098321*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1661581422339608 - 0.12152033455846134*lm - 0.09647420021098321*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.47, NC*(CA*CF*(0.534815329844233 + 0.15027512087591752*lm + 
          0.8206546146058886*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.2091529674419589 + 0.2442153540512371*lm - 
          0.4468833579176368*lm^2 + 0.25*lm^3) + 
        CF*((-0.17134634147591582 - 0.1205968422148278*lm - 
            0.09617962689804035*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3164691329696512 - 0.1205968422148278*lm - 0.09617962689804035*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1654131935887619 - 0.1205968422148278*lm - 0.09617962689804035*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.475, NC*(CA*CF*(0.5297341279075048 + 0.14309098087291933*lm + 
          0.8190168880182367*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.20819794563189176 + 0.24524999789204258*lm - 
          0.44956327415197633*lm^2 + 0.25*lm^3) + 
        CF*((-0.1683987710289438 - 0.11966961299489635*lm - 
            0.09588185842755818*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3154875214192784 - 0.11966961299489635*lm - 0.09588185842755818*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.16465659127528454 - 0.11966961299489635*lm - 0.09588185842755818*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.48, NC*(CA*CF*(0.5247422534294693 + 0.13586611997542677*lm + 
          0.8173619427344713*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.20726061248103 + 0.24635248413547078*lm - 
          0.4522713664345016*lm^2 + 0.25*lm^3) + 
        CF*((-0.1654642081589445 - 0.11873896446762856*lm - 
            0.09558095928505538*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.31451451463813324 - 0.11873896446762856*lm - 
            0.09558095928505538*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.16388860373103065 - 0.11873896446762856*lm - 0.09558095928505538*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.485, NC*(CA*CF*(0.5198405474105263 + 0.1286026784835243*lm + 
          0.8156901276466884*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.20633985215701897 + 0.24752359027231485*lm - 
          0.4550070638508736*lm^2 + 0.25*lm^3) + 
        CF*((-0.16254292541760762 - 0.11780520504313324*lm - 
            0.09527699290545849*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3135502343640461 - 0.11780520504313324*lm - 0.09527699290545849*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.16310949511197745 - 0.11780520504313324*lm - 0.09527699290545849*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.49, NC*(CA*CF*(0.5150297770461877 + 0.12130274039218406*lm + 
          0.8140017859493559*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.20543453997270122 + 0.24876404615573433*lm - 
          0.45776980481014484*lm^2 + 0.25*lm^3) + 
        CF*((-0.1596351800344702 - 0.1168686342126855*lm - 
            0.09497002168776168*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.3125947927106194 - 0.1168686342126855*lm - 0.09497002168776168*
             lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.1623195253465541 - 0.1168686342126855*lm - 0.09497002168776168*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.495, NC*(CA*CF*(0.5103106387942316 + 0.1139683347801866*lm + 
          0.8122972552196648*lm^2 + 0.1527777777777778*lm^3) + 
        CF^2*(0.20454354417538867 + 0.2500745356464996*lm - 
          0.4605590369132757*lm^2 + 0.25*lm^3) + 
        CF*((-0.15674121449439987 - 0.11592954278266406*lm - 
            0.09466010700963604*lm^2 - 0.027777777777777776*lm^3)*NM + 
          (-0.31164829257532267 - 0.11592954278266406*lm - 
            0.09466010700963604*lm^2 - 0.027777777777777776*lm^3)*NL + 
          (0.16151895018973114 - 0.11592954278266406*lm - 0.09466010700963604*
             lm^2 - 0.027777777777777776*lm^3)*NH))}, 
     {0.5, CF*NC*(CA*(0.505683761286181 + 0.1066014371438954*lm + 
          0.8105768674963459*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.20366572761934804 + 0.2514556981799762*lm - 
          0.46337421682416113*lm^2 + 0.25*lm^3) - 0.15386125708628784*NM - 
        0.11498821309881713*lm*NM - 0.09434730924175988*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.31071082802665745*NL - 
        0.11498821309881713*lm*NL - 0.09434730924175988*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.16070802127642253*NH - 
        0.11498821309881713*lm*NH - 0.09434730924175988*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.505, CF*NC*(CA*(0.5011497083354621 + 0.09920397081373936*lm + 
          0.8088409493643434*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.20279994934843867 + 0.2529081304227167*lm - 
          0.4662148101310745*lm^2 + 0.25*lm^3) - 0.1509955224726524*NM - 
        0.11404491928421086*lm*NM - 0.09403168776321394*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30978248470170655*NL - 
        0.11404491928421086*lm*NL - 0.09403168776321394*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15988698617876176*NH - 
        0.11404491928421086*lm*NH - 0.09403168776321394*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.51, CF*NC*(CA*(0.49670898140084346 + 0.09177780809691963*lm + 
          0.8070898220259074*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.20194506604055254 + 0.25443238758711023*lm - 
          0.4690802912303333*lm^2 + 0.25*lm^3) - 0.14814421215352533*NM - 
        0.11309992743054285*lm*NM - 0.09371330097440742*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30886334013480077*NL - 
        0.11309992743054285*lm*NL - 0.09371330097440742*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15905608845518307*NH - 
        0.11309992743054285*lm*NH - 0.09371330097440742*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.515, CF*NC*(CA*(0.49236202240749466 + 0.08432477164391206*lm + 
          0.8053238013850292*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.20109993339523777 + 0.2560289850080559*lm - 
          0.471970143188134*lm^2 + 0.25*lm^3) - 0.1453075150025774*NM - 
        0.11215349582705875*lm*NM - 0.09339220631242956*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3079534641290385*NL - 
        0.11215349582705875*lm*NL - 0.09339220631242956*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15821556770797957*NH - 
        0.11215349582705875*lm*NH - 0.09339220631242956*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.52, CF*NC*(CA*(0.4881092162247121 + 0.07684663564954743*lm + 
          0.8035431981240135*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.2002634074099331 + 0.25769839951033374*lm - 
          0.4748838576152506*lm^2 + 0.25*lm^3) - 0.14248560773709945*NM - 
        0.11120587516121096*lm*NM - 0.09306846026497216*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3070529190839956*NL - 
        0.11120587516121096*lm*NL - 0.09306846026497216*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15736565963617735*NH - 
        0.11120587516121096*lm*NH - 0.09306846026497216*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.525, CF*NC*(CA*(0.4839508930998704 + 0.0693451270529387*lm + 
          0.8017483177810314*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1994343455750635 + 0.2594410707664464*lm - 0.4778209345401305*
           lm^2 + 0.25*lm^3) - 0.13967865538087593*NM - 
        0.11025730871888127*lm*NM - 0.09274211838442994*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3061617603167744*NL - 
        0.11025730871888127*lm*NL - 0.09274211838442994*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15650659608918915*NH - 
        0.11025730871888127*lm*NH - 0.09274211838442994*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.53, CF*NC*(CA*(0.479887331000278 + 0.06182192670818726*lm + 
          0.7999394608270562*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.19861160798823882 + 0.2612574026114519*lm - 
          0.4807808822829988*lm^2 + 0.25*lm^3) - 0.13688681171034567*NM - 
        0.1093080325794331*lm*NM - 0.09241323530188902*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3052800363704814*NL - 
        0.1093080325794331*lm*NL - 0.09241323530188902*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15563860512024388*NH - 
        0.1093080325794331*lm*NH - 0.09241323530188902*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.535, CF*NC*(CA*(0.47591875786639554 + 0.05427867052650848*lm + 
          0.7981169227421528*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1977940583920144 + 0.26314776431609094*lm - 
          0.48376321733102257*lm^2 + 0.25*lm^3) - 0.13411021968466472*NM - 
        0.10835827580571708*lm*NM - 0.09208186474099748*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3044077893106293*NL - 
        0.10835827580571708*lm*NL - 0.09208186474099748*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1547619110395578*NH - 
        0.10835827580571708*lm*NH - 0.09208186474099748*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.54, CF*NC*(CA*(0.47204535377974727 + 0.04671695059041027*lm + 
          0.7962809940910873*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.19698056513943568 + 0.265112491819475*lm - 0.48676746421458433*
           lm^2 + 0.25*lm^3) - 0.1313490118602637*NM - 
        0.10740826062915242*lm*NM - 0.09174805953171285*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3035450550099357*NL - 
        0.10740826062915242*lm*NL - 0.09174805953171285*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15387673446721492*NH - 
        0.10740826062915242*lm*NH - 0.09174805953171285*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.545, CF*NC*(CA*(0.4682672530487262 + 0.03913831624055092*lm + 
          0.7944319605982336*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.19617000209136257 + 0.26715188892257064*lm - 
          0.4897931553847085*lm^2 + 0.25*lm^3) - 0.12860331079047002*NM - 
        0.10645820263000363*lm*NM - 0.09141187162392127*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3026918634219775*NL - 
        0.10645820263000363*lm*NL - 0.09141187162392127*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15298329238572766*NH - 
        0.10645820263000363*lm*NH - 0.09141187162392127*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.55, CF*NC*(CA*(0.4645845462153743 + 0.03154427513589468*lm + 
          0.7925701032217515*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.19536124944935715 + 0.2692662284436758*lm - 
          0.4928398310916794*lm^2 + 0.25*lm^3) - 0.12587322941074225*NM - 
        0.1055083109129711*lm*NM - 0.09107335210092452*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3018482388441346*NL - 
        0.1055083109129711*lm*NL - 0.09107335210092452*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15208179819225046*NH - 
        0.1055083109129711*lm*NH - 0.09107335210092452*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.555, CF*NC*(CA*(0.4609972819861001 + 0.023936294287775054*lm + 
          0.7906956982270144*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.19455319452771666 + 0.2714557533370552*lm - 
          0.4959070392648856*lm^2 + 0.25*lm^3) - 0.12315887141004561*NM - 
        0.10455878827821083*lm*NM - 0.09073255119279049*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.30101420017024516*NL - 
        0.10455878827821083*lm*NL - 0.09073255119279049*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1511724617504221*NH - 
        0.10455878827821083*lm*NH - 0.09073255119279049*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.56, CF*NC*(CA*(0.45750546908918405 + 0.016315801068467053*lm + 
          0.7888090172592693*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1937447324680434 + 0.27372067777586606*lm - 
          0.498994335393923*lm^2 + 0.25*lm^3) - 0.12046033158887497*NM - 
        0.10360983138789749*lm*NM - 0.09038951828956411*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.3001897611333739*NL - 
        0.10360983138789749*lm*NL - 0.09038951828956411*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.15025548944181383*NH - 
        0.10360983138789749*lm*NH - 0.09038951828956411*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.565, CF*NC*(CA*(0.4541090780618138 + 0.008684184194860336*lm + 
          0.7869103274155109*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.19293476689956246 + 0.27606118820047376*lm - 
          0.5021012824109822*lm^2 + 0.25*lm^3) - 0.11777769620441489*NM - 
        0.10266163092844201*lm*NM - 0.09004430195433531*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29937493053907954*NL - 
        0.10266163092844201*lm*NL - 0.09004430195433531*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.149331084216963*NH - 
        0.10266163092844201*lm*NH - 0.09004430195433531*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.57, CF*NC*(CA*(0.45080804296928645 + 0.0010427946878157357*lm + 
          0.7849998913155555*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.19212221054822817 + 0.27847744433322597*lm - 
          0.5052274505745455*lm^2 + 0.25*lm^3) - 0.11511104330330624*NM - 
        0.10171437176847317*lm*NM - 0.0896969499361616*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2985697124895527*NL - 
        0.10171437176847317*lm*NL - 0.0896969499361616*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14839944564597332*NH - 
        0.10171437176847317*lm*NH - 0.0896969499361616*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.575, CF*NC*(CA*(0.4476022630589157 - 0.006607053192222032*lm + 
          0.7830779671723022*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.19130598579749833 + 0.28096958016072165*lm - 
          0.5083724173544147*lm^2 + 0.25*lm^3) - 0.11246044304247196*NM - 
        0.10076823311269023*lm*NM - 0.0893475091828428*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29777410659898046*NL - 
        0.10076823311269023*lm*NL - 0.0893475091828428*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1474607699686649*NH - 
        0.10076823311269023*lm*NH - 0.0893475091828428*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.58, CF*NC*(CA*(0.44449160435108387 - 0.014264081032792777*lm + 
          0.7811448088611697*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.19048502520350263 + 0.28353770488458235*lm - 
          0.511535767318086*lm^2 + 0.25*lm^3) - 0.10982595799843717*NM - 
        0.09982338865169148*lm*NM - 0.088996025853546*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2969881082004782*NL - 
        0.09982338865169148*lm*NL - 0.088996025853546*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14651525014425892*NH - 
        0.09982338865169148*lm*NH - 0.088996025853546*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.585, CF*NC*(CA*(0.4414759011697869 - 0.021927045379617656*lm + 
          0.779200665988701*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.18965827196718718 + 0.28618190384170283*lm - 
          0.5147170920184893*lm^2 + 0.25*lm^3) - 0.10720764346556262*NM - 
        0.09888000670788136*lm*NM - 0.08864254533127897*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2962117085449179*NL - 
        0.09888000670788136*lm*NL - 0.08864254533127897*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14556307590058296*NH - 
        0.09888000670788136*lm*NH - 0.08864254533127897*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.59, CF*NC*(CA*(0.4385549576149325 - 0.029594736868882*lm + 
          0.7772457839603256*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.18882468036587996 + 0.288902239394929*lm - 0.5179159898831035*
           lm^2 + 0.25*lm^3) - 0.1046055477435947*NM - 
        0.09793825037755652*lm*NM - 0.08828711223521073*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29544489499196674*NL - 
        0.09793825037755652*lm*NL - 0.08828711223521073*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14460443378278465*NH - 
        0.09793825037755652*lm*NH - 0.08828711223521073*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.595, CF*NC*(CA*(0.435728548978562 - 0.03726597938107208*lm + 
          0.7752804040472755*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1879832161465924 + 0.2916987517950839*lm - 0.5211320661044583*
           lm^2 + 0.25*lm^3) - 0.10201971241491975*NM - 
        0.0969982776692691*lm*NM - 0.08792977043283798*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29468765119363904*NL - 
        0.0969982776692691*lm*NL - 0.08792977043283798*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.143639507201543*NH - 
        0.0969982776692691*lm*NH - 0.08792977043283798*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.6, CF*NC*(CA*(0.4329964231070889 - 0.044939629215844115*lm + 
          0.773304763452648*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.18713285688325015 + 0.29457146001523427*lm - 
          0.5243649325320306*lm^2 + 0.25*lm^3) - 0.09945017261189625*NM - 
        0.0960602416385632*lm*NM - 0.08757056305199659*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2939399572706506*NL - 
        0.0960602416385632*lm*NL - 0.08757056305199659*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14266847648076728*NH - 
        0.0960602416385632*lm*NH - 0.08757056305199659*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.605, CF*NC*(CA*(0.43035830171156425 - 0.05261457428741427*lm + 
          0.7713190953766128*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1862725922999287 + 0.297520362558063*lm - 0.5276142075655427*
           lm^2 + 0.25*lm^3) - 0.09689695727462438*NM - 
        0.09512429051917841*lm*NM - 0.08720953249271748*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2932017899818555*NL - 
        0.09512429051917841*lm*NL - 0.08720953249271748*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14169151890477513*NH - 
        0.09512429051917841*lm*NH - 0.08720953249271748*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.61, CF*NC*(CA*(0.4278138816279037 - 0.060289733339968746*lm + 
          0.769323629080761*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.18540142456206102 + 0.30054543823718866*lm - 
          0.5308795160496639*lm^2 + 0.25*lm^3) - 0.09436008939949862*NM - 
        0.09419056785081191*lm*NM - 0.08684672043892624*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29247312288703187*NL - 
        0.09419056785081191*lm*NL - 0.08684672043892624*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.14070880876494252*NH - 
        0.09419056785081191*lm*NH - 0.08684672043892624*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.615, CF*NC*(CA*(0.4253628360289391 - 0.06796405518260368*lm + 
          0.7673185899515922*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1845183685374788 + 0.3036466469332448*lm - 0.5341604891701218*
           lm^2 + 0.25*lm^3) - 0.09183958627887645*NM - 
        0.09325921260352892*lm*NM - 0.08648216786998646*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2917539265032735*NL - 
        0.09325921260352892*lm*NL - 0.08648216786998646*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13972051740581903*NH - 
        0.09325921260352892*lm*NH - 0.08648216786998646*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.62, CF*NC*(CA*(0.4230048155900852 - 0.07563651794331455*lm + 
          0.7653041995631426*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.18362245202905123 + 0.30682393032551036*lm - 
          0.5374567643512213*lm^2 + 0.25*lm^3) - 0.08933545973218374*NM - 
        0.09233035929890866*lm*NM - 0.08611591507208653*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.29104416845523434*NL - 
        0.09233035929890866*lm*NL - 0.08611591507208653*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13872681327070305*NH - 
        0.09233035929890866*lm*NH - 0.08611591507208653*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.625, CF*NC*(CA*(0.4207394496103449 - 0.08330612834156553*lm + 
          0.7632806757387516*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.18271271598059083 + 0.3100772125998558*lm - 
          0.5407679851547701*lm^2 + 0.25*lm^3) - 0.08684771632876527*NM - 
        0.09140413812801136*lm*NM - 0.08574800164946998*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2903438136194632*NL - 
        0.09140413812801136*lm*NL - 0.08574800164946998*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1377278619466724*NH - 
        0.09140413812801136*lm*NH - 0.08574800164946998*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.63, CF*NC*(CA*(0.4185663470903123 - 0.09097192097897921*lm + 
          0.7612482326119697*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.18178821465760817 + 0.3134064011337478*lm - 
          0.5440938011804132*lm^2 + 0.25*lm^3) - 0.08437635760277734*NM - 
        0.09048067506624931*lm*NM - 0.08537846653550965*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28965282426305483*NL - 
        0.09048067506624931*lm*NL - 0.08537846653550965*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13672382620906656*NH - 
        0.09048067506624931*lm*NH - 0.08537846653550965*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.635, CF*NC*(CA*(0.41648509776876924 - 0.09863295764769722*lm + 
          0.7592070806866095*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.18084801580441284 + 0.3168113871590314*lm - 
          0.5474338679673664*lm^2 + 0.25*lm^3) - 0.08192138026040854*NM - 
        0.08956009198524345*lm*NM - 0.08500734800362596*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2889711601768374*NL - 
        0.08956009198524345*lm*NL - 0.08500734800362596*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13571486606541777*NH - 
        0.08956009198524345*lm*NH - 0.08500734800362596*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.64, CF*NC*(CA*(0.41449527311941026 - 0.10628832665597257*lm + 
          0.7571574268959412*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17989120077897866 + 0.3202920464031879*lm - 
          0.5507878468975507*lm^2 + 0.25*lm^3) - 0.07948277637970382*NM - 
        0.0886425067617447*lm*NM - 0.08463468367804992*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28829877880330523*NL - 
        0.0886425067617447*lm*NL - 0.08463468367804992*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13470113879882867*NH - 
        0.0886425067617447*lm*NH - 0.08463468367804992*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.645, CF*NC*(CA*(0.41259642730917484 - 0.11393714217056412*lm + 
          0.7550994746610392*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17891686466691586 + 0.32384823970974363*lm - 
          0.5541554051001175*lm^2 + 0.25*lm^3) - 0.07706053360325706*NM - 
        0.08772803338369711*lm*NM - 0.08426051054443139*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2876356353594993*NL - 
        0.08772803338369711*lm*NL - 0.08426051054443139*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13368279901079486*NH - 
        0.08772803338369711*lm*NH - 0.08426051054443139*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.65, CF*NC*(CA*(0.4107880981196089 - 0.1215785435755139*lm + 
          0.7530334239482798*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17792411637582173 + 0.327479813638485*lm - 0.5575362153573604*
           lm^2 + 0.25*lm^3) - 0.07465463532402723*NM - 
        0.08681678205351838*lm*NM - 0.08388486496029328*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28698168295502846*NL - 
        0.08681678205351838*lm*NL - 0.08388486496029328*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13265999866347195*NH - 
        0.08681678205351838*lm*NH - 0.08388486496029328*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.655, CF*NC*(CA*(0.40906980783262376 - 0.12921169484689693*lm + 
          0.7509594713259972*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17691207871121328 + 0.33118660104611486*lm - 
          0.5609299560120047*lm^2 + 0.25*lm^3) - 0.07226506086452399*NM - 
        0.08590885928867115*lm*NM - 0.0835077826653328*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28633687270541786*NL - 
        0.08590885928867115*lm*NL - 0.0835077826653328*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13163288712138618*NH - 
        0.08590885928867115*lm*NH - 0.0835077826653328*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.66, CF*NC*(CA*(0.40744106408197 - 0.13683578394314366*lm + 
          0.7488778100203033*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17587988843518138 + 0.33496842164796464*lm - 
          0.5643363108758673*lm^2 + 0.25*lm^3) - 0.06989178564959932*NM - 
        0.08500436801959677*lm*NM - 0.0831292987915703*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28570115384096334*NL - 
        0.08500436801959677*lm*NL - 0.0831292987915703*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.13060161119258937*NH - 
        0.08500436801959677*lm*NH - 0.0831292987915703*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.665, CF*NC*(CA*(0.4059013606716951 - 0.14445002221054373*lm + 
          0.7467886299700748*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17482669630884584 + 0.3388250825613589*lm - 
          0.5677549691398776*lm^2 + 0.25*lm^3) - 0.06753478137307307*NM - 
        0.08410340768508102*lm*NM - 0.08274944787334694*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28507447381126366*NL - 
        0.08410340768508102*lm*NL - 0.08274944787334694*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12956631516925873*NH - 
        0.08410340768508102*lm*NH - 0.08274944787334694*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.67, CF*NC*(CA*(0.4044501783628034 - 0.15205364380354952*lm + 
          0.744692117881115*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17375166711963186 + 0.34275637883120946*lm - 
          0.5711856252854483*lm^2 + 0.25*lm^3) - 0.06519401615841203*NM - 
        0.08320607432512027*lm*NM - 0.08236826385717241*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2844567783855957*NL - 
        0.08320607432512027*lm*NL - 0.08236826385717241*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12852714086774292*NH - 
        0.08320607432512027*lm*NH - 0.08236826385717241*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.675, CF*NC*(CA*(0.4030869856292947 - 0.15964590511950683*lm + 
          0.7425884572794965*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17265397969433535 + 0.3467620939383988*lm - 
          0.5746279789971875*lm^2 + 0.25*lm^3) - 0.06286945471367374*NM - 
        0.0823124606713538*lm*NM - 0.0819857801114236*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28384801174929075*NL - 
        0.0823124606713538*lm*NL - 0.0819857801114236*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12748422766805573*NH - 
        0.0823124606713538*lm*NH - 0.0819857801114236*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.68, CF*NC*(CA*(0.40181123938471064 - 0.16722608424744903*lm + 
          0.7404778285640922*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17153282689889157 + 0.35084200029149415*lm - 
          0.5780817350769402*lm^2 + 0.25*lm^3) - 0.060561058480918875*NM - 
        0.08142265623512729*lm*NM - 0.08160202943589555*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28324811659626536*NL - 
        0.08142265623512729*lm*NL - 0.08160202943589555*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12643771255281988*NH - 
        0.08142265623512729*lm*NH - 0.08160202943589555*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.685, CF*NC*(CA*(0.40062238568027886 - 0.17479348043059986*lm + 
          0.7383604090582999*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.17038741562571322 + 0.3549958597023185*lm - 
          0.5815466033591455*lm^2 + 0.25*lm^3) - 0.05826878578028811*NM - 
        0.08053674739325012*lm*NM - 0.08121704407120606*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28265703421785215*NL - 
        0.08053674739325012*lm*NL - 0.08121704407120606*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12538773014566298*NH - 
        0.08053674739325012*lm*NH - 0.08121704407120606*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.69, CF*NC*(CA*(0.39951986037570075 - 0.18234741354223857*lm + 
          0.7362363730609708*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.16921696676941744 + 0.3592234238458858*lm - 
          0.5850222986275024*lm^2 + 0.25*lm^3) - 0.05599259194893256*NM - 
        0.0796548174715077*lm*NM - 0.08083085570805529*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2820747045880725*NL - 
        0.0796548174715077*lm*NL - 0.08083085570805529*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12433441274906884*NH - 
        0.0796548174715077*lm*NH - 0.08083085570805529*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.695, CF*NC*(CA*(0.39850308978359356 - 0.18988722357458962*lm + 
          0.7341058918965455*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1680207151917171 + 0.36352443470519447*lm - 
          0.5885085405329256*lm^2 + 0.25*lm^3) - 0.05373242947497978*NM - 
        0.07877694682598856*lm*NM - 0.08044349549634161*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28150106644548545*NL - 
        0.07877694682598856*lm*NL - 0.08044349549634161*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12327789038168681*NH - 
        0.07877694682598856*lm*NH - 0.08044349549634161*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.7, CF*NC*(CA*(0.3975714912885561 - 0.1974122701404074*lm + 
          0.7319691339644107*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.16679790967620964 + 0.3678986250013553*lm - 
          0.5920050535127824*lm^2 + 0.25*lm^3) - 0.05148824812671064*NM - 
        0.07790321292228428*lm*NM - 0.08005499405413528*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.28093605737174393*NL - 
        0.07790321292228428*lm*NL - 0.08005499405413528*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12221829081510305*NH - 
        0.07790321292228428*lm*NH - 0.08005499405413528*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.705, CF*NC*(CA*(0.39672447394179433 - 0.20492193198693487*lm + 
          0.7298262647874795*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.16554781287375783 + 0.3723457186095172*lm - 
          0.5955115667113973*lm^2 + 0.25*lm^3) - 0.049259995077116064*NM - 
        0.07703369041261875*lm*NM - 0.07966538147651142*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2803796138669826*NL - 
        0.07703369041261875*lm*NL - 0.07966538147651142*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12115573961007683*NH - 
        0.07703369041261875*lm*NH - 0.07966538147651142*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.71, CF*NC*(CA*(0.39596143903220604 - 0.2124156065219221*lm + 
          0.727677447060007*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.16426970123911863 + 0.3768654309610377*lm - 
          0.5990278139018067*lm^2 + 0.25*lm^3) - 0.047047615023996354*NM - 
        0.0761684512109618*lm*NM - 0.0792746873442437*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27983167142215815*NL - 
        0.0761684512109618*lm*NL - 0.0792746873442437*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.12009036015224644*NH - 
        0.0761684512109618*lm*NH - 0.0792746873442437*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.715, CF*NC*(CA*(0.39528178063479197 - 0.2198927093513998*lm + 
          0.7255228406946491*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.16296286495944076 + 0.38145746943233233*lm - 
          0.6025535334087561*lm^2 + 0.25*lm^3) - 0.04485105030576013*NM - 
        0.07530756456618092*lm*NM - 0.07888294073236045*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27929216458845724*NL - 
        0.07530756456618092*lm*NL - 0.07888294073236045*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11902227368730815*NH - 
        0.07530756456618092*lm*NH - 0.07888294073236045*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.72, CF*NC*(CA*(0.39468488613722796 - 0.22735267382890945*lm + 
          0.7233626028687715*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1616266078752183 + 0.38612153372082364*lm - 
          0.6060884680329194*lm^2 + 0.25*lm^3) - 0.042670241013073845*NM - 
        0.07445109713328307*lm*NM - 0.07849017021856451*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27876102704388384*NL - 
        0.07445109713328307*lm*NL - 0.07849017021856451*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11795159935567327*NH - 
        0.07445109713328307*lm*NH - 0.07849017021856451*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.725, CF*NC*(CA*(0.39417013674540125 - 0.23479495061589956*lm + 
          0.7211968880700199*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.16026024739425468 + 0.39085731620839526*lm - 
          0.609632364976331*lm^2 + 0.25*lm^3) - 0.04050512509650765*NM - 
        0.07359911304279762*lm*NM - 0.07809640389151877*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27823819165713204*NL - 
        0.07359911304279762*lm*NL - 0.07809640389151877*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11687845422660721*NH - 
        0.07359911304279762*lm*NH - 0.07809640389151877*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.73, CF*NC*(CA*(0.39373690796868543 - 0.24221900725300488*lm + 
          0.7190258481411592*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.15886311439916237 + 0.39566450231274686*lm - 
          0.6131849757690122*lm^2 + 0.25*lm^3) - 0.03835563847031806*NM - 
        0.07275167396834956*lm*NM - 0.07770166935899864*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27772359054884815*NL - 
        0.07275167396834956*lm*NL - 0.07770166935899864*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11580295333185579*NH - 
        0.07275167396834956*lm*NH - 0.07770166935899864*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.735, CF*NC*(CA*(0.39338457008569916 - 0.24962432774193258*lm + 
          0.7168496323241899*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.15743455314889349 + 0.4005427708270305*lm - 
          0.6167460561967802*lm^2 + 0.25*lm^3) - 0.036221715112502606*NM - 
        0.0719088391924713*lm*NM - 0.07730599375591331*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2772171551503798*NL - 
        0.0719088391924713*lm*NL - 0.07730599375591331*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11472520969876322*NH - 
        0.0719088391924713*lm*NH - 0.07730599375591331*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.74, CF*NC*(CA*(0.3931124885912662 - 0.25701041213768616*lm + 
          0.7146683873037525*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1559739211747697 + 0.40549179424813875*lm - 
          0.6203153662302231*lm^2 + 0.25*lm^3) - 0.034103287161257045*NM - 
        0.07107066567069996*lm*NM - 0.07690940375219743*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27671881626010825*NL - 
        0.07107066567069996*lm*NL - 0.07690940375219743*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.1136453343828871*NH - 
        0.07107066567069996*lm*NH - 0.07690940375219743*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.745, CF*NC*(CA*(0.39292002462526837 - 0.2643767761508648*lm + 
          0.7124822572498278*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1544805891714545 + 0.4105112390940023*lm - 0.6238926699548272*
           lm^2 + 0.25*lm^3) - 0.032000285007960774*NM - 
        0.07023720809400544*lm*NM - 0.07651192556057475*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27622850409745453*NL - 
        0.07023720809400544*lm*NL - 0.07651192556057475*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11256343650011531*NH - 
        0.07023720809400544*lm*NH - 0.07651192556057475*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.75, CF*NC*(CA*(0.39280653538405713 - 0.27172295075978287*lm + 
          0.7102913838597421*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.15295394088328548 + 0.4156007662102439*lm - 
          0.6274777355022403*lm^2 + 0.25*lm^3) - 0.02991263738681162*NM - 
        0.06940851894959388*lm*NM - 0.07611358494419553*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2757461483546479*NL - 
        0.06940851894959388*lm*NL - 0.07611358494419553*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11147962325829018*NH - 
        0.06940851894959388*lm*NH - 0.07611358494419553*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.755, CF*NC*(CA*(0.3927713745150648 - 0.27904848183216013*lm + 
          0.7080959063994874*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.15139337298636096 + 0.4207600310665249*lm - 
          0.6310703349826571*lm^2 + 0.25*lm^3) - 0.027840271461227*NM - 
        0.06858464858012968*lm*NM - 0.07571440722414922*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27527167824634063*NL - 
        0.06858464858012968*lm*NL - 0.07571440722414922*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.11039399998834512*NH - 
        0.06858464858012968*lm*NH - 0.07571440722414922*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.76, CF*NC*(CA*(0.39281389249523363 - 0.2863529297561399*lm + 
          0.7058959617443652*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.14979829496675443 + 0.42598868404290896*lm - 
          0.6346702444183115*lm^2 + 0.25*lm^3) - 0.02578311290712395*NM - 
        0.06776564524141784*lm*NM - 0.07531441728685427*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2748050225571512*NL - 
        0.06776564524141784*lm*NL - 0.07531441728685427*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10930667017495935*NH - 
        0.06776564524141784*lm*NH - 0.07531441728685427*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.765, CF*NC*(CA*(0.3929334369938574 - 0.2936358690803989*lm + 
          0.7036916844189631*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.14816812899520743 + 0.43128637070655895*lm - 
          0.6382772436780603*lm^2 + 0.25*lm^3) - 0.02374108599318669*NM - 
        0.06695155515858775*lm*NM - 0.07491363959132663*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27434610968721374*NL - 
        0.06695155515858775*lm*NL - 0.07491363959132663*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10821773548673597*NH - 
        0.06695155515858775*lm*NH - 0.07491363959132663*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.77, CF*NC*(CA*(0.3931293532204087 - 0.3008968881631184*lm + 
          0.7014832066364738*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.14650230979863366 + 0.4366527320790709*lm - 
          0.6418911164130429*lm^2 + 0.25*lm^3) - 0.02171411365822656*NM - 
        0.0661424225808181*lm*NM - 0.07451209817632858*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2738948676958089*NL - 
        0.0661424225808181*lm*NL - 0.07451209817632858*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10712729580590905*NH - 
        0.0661424225808181*lm*NH - 0.07451209817632858*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.775, CF*NC*(CA*(0.3934009842579042 - 0.3081355888295913*lm + 
          0.699270658337365*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.14480028452874633 + 0.44208740489474196*lm - 
          0.6455116499934027*lm^2 + 0.25*lm^3) - 0.01970211758573513*NM - 
        0.06533828983464159*lm*NM - 0.0741098166673997*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27345122434314934*NL - 
        0.06533828983464159*lm*NL - 0.0741098166673997*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10603544925758542*NH - 
        0.06533828983464159*lm*NH - 0.0741098166673997*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.78, CF*NC*(CA*(0.39374767138233985 - 0.31535158603824776*lm + 
          0.6970541672274103*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1430615126281044 + 0.4475900218500573*lm - 0.6491386354460558*
           lm^2 + 0.25*lm^3) - 0.01770501827572807*NM - 
        0.06453919737586711*lm*NM - 0.07370681828377158*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2730151071303886*NL - 
        0.06453919737586711*lm*NL - 0.07370681828377158*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10494229223852657*NH - 
        0.06453919737586711*lm*NH - 0.07370681828377158*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.785, CF*NC*(CA*(0.3941687543687082 - 0.3225445075548845*lm + 
          0.6948338588150901*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.14128546569385592 + 0.453160211844674*lm - 0.652771867393489*
           lm^2 + 0.25*lm^3) - 0.015722735113973596*NM - 
        0.06374518384015604*lm*NM - 0.07330312584516789*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2725864433379213*NL - 
        0.06374518384015604*lm*NL - 0.07330312584516789*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10384791944547668*NH - 
        0.06374518384015604*lm*NH - 0.07330312584516789*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.79, CF*NC*(CA*(0.3946635717840922 - 0.32971399363489173*lm + 
          0.69260985644837*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.13947162733943977 + 0.45879760021417004*lm - 
          0.6564111439935764*lm^2 + 0.25*lm^3) - 0.013755186438696115*NM - 
        0.0629562860922883*lm*NM - 0.07289876177849151*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2721651600620384*NL - 
        0.0629562860922883*lm*NL - 0.07289876177849151*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10275242390304216*NH - 
        0.0629562860922883*lm*NH - 0.07289876177849151*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.795, CF*NC*(CA*(0.39523146126831044 - 0.3368596967132742*lm + 
          0.6903822813508692*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.13761949305449386 + 0.4645018089548185*lm - 
          0.6600562668803958*lm^2 + 0.25*lm^3) - 0.01180228960484245*NM - 
        0.062172539274152804*lm*NM - 0.07249374812440047*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2717511842500003*NL - 
        0.062172539274152804*lm*NL - 0.07249374812440047*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10165589699112869*NH - 
        0.062172539274152804*lm*NH - 0.07249374812440047*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.8, CF*NC*(CA*(0.39587175980257266 - 0.34398128110227*lm + 
          0.6881512526574244*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.13572857006320105 + 0.4702724569406385*lm - 
          0.6637070411060328*lm^2 + 0.25*lm^3) - 0.009863961045994915*NM - 
        0.06139397685149618*lm*NM - 0.07208810654377414*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2713444427335876*NL - 
        0.06139397685149618*lm*NL - 0.07208810654377414*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.10055842847194141*NH - 
        0.06139397685149618*lm*NH - 0.07208810654377414*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.805, CF*NC*(CA*(0.396583803966587 - 0.3510784226963744*lm + 
          0.6859168874490599*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.133798377181292 + 0.47610916013296756*lm - 0.6673632750833566*
           lm^2 + 0.25*lm^3) - 0.007940116334012579*NM - 
        0.060620630659462375*lm*NM - 0.07168185832407149*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27094486226118614*NL - 
        0.060620630659462375*lm*NL - 0.07168185832407149*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09946010651655396*NH - 
        0.060620630659462375*lm*NH - 0.07168185832407149*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.81, CF*NC*(CA*(0.397366930184545 - 0.3581508086845827*lm + 
          0.6836793007873733*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.13182844467191107 + 0.4820115317827905*lm - 
          0.6710247805297528*lm^2 + 0.25*lm^3) - 0.00603067023647908*NM - 
        0.05985253094695529*lm*NM - 0.07127502438558302*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.270552369528463*NL - 
        0.05985253094695529*lm*NL - 0.07127502438558302*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09836101773105237*NH - 
        0.05985253094695529*lm*NH - 0.07127502438558302*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.815, CF*NC*(CA*(0.3982204749603934 - 0.3651981372696685*lm + 
          0.6814386057483447*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.12981831410053774 + 0.48797918262605483*lm - 
          0.6746913724117996*lm^2 + 0.25*lm^3) - 0.004135536772032747*NM - 
        0.059089706419855385*lm*NM - 0.07086762528757783*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.27016689120768556*NL - 
        0.059089706419855385*lm*NL - 0.07086762528757783*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09726124718225913*NH - 
        0.059089706419855385*lm*NH - 0.07086762528757783*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.82, CF*NC*(CA*(0.39914377510278937 - 0.37222011739432154*lm + 
          0.6791949134555785*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.12776753818914618 + 0.49401172107219343*lm - 
          0.6783628688908715*lm^2 + 0.25*lm^3) - 0.00225462926365195*NM - 
        0.058332184283120564*lm*NM - 0.07045968123434761*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2697883539757356*NL - 
        0.058332184283120564*lm*NL - 0.07045968123434761*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09616087842304374*NH - 
        0.058332184283120564*lm*NH - 0.07045968123434761*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.825, CF*NC*(CA*(0.40013616794011864 - 0.3792164684739705*lm + 
          0.6769483331129865*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.12567568066977336 + 0.5001087533860693*lm - 
          0.6820390912696584*lm^2 + 0.25*lm^3) - 0.00038786038996616983*NM - 
        0.05757999028180073*lm*NM - 0.07005121208114906*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2694166845408679*NL - 
        0.05757999028180073*lm*NL - 0.07005121208114906*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09505999351722495*NH - 
        0.05757999028180073*lm*NH - 0.07005121208114906*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.83, CF*NC*(CA*(0.4011969915259444 - 0.3861869201361236*lm + 
          0.6746989720369213*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.12354231613765575 + 0.5062698838635508*lm - 
          0.6857198639395833*lm^2 + 0.25*lm^3) + 0.0014648577653392622*NM - 
        0.05683314874099458*lm*NM - 0.0696422373400463*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2690518096682602*NL - 
        0.05683314874099458*lm*NL - 0.0696422373400463*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09395867306407077*NH - 
        0.05683314874099458*lm*NH - 0.0696422373400463*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.835, CF*NC*(CA*(0.4023255848352407 - 0.39313121196606265*lm + 
          0.6724469356877686*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.12136702990408518 + 0.5124947150009177*lm - 
          0.689405014329106*lm^2 + 0.25*lm^3) + 0.0033036136659591736*NM - 
        0.056091682604776545*lm*NM - 0.0692327761856549*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.268693656204401*NL - 
        0.056091682604776545*lm*NL - 0.0692327761856549*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.0928569962224018*NH - 
        0.056091682604776545*lm*NH - 0.0692327761856549*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.84, CF*NC*(CA*(0.4035212879517505 - 0.40004909325872995*lm + 
          0.6701923277010059*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1191494178491246 + 0.518782847658295*lm - 0.6930943728528994*
           lm^2 + 0.25*lm^3) + 0.00512849627718201*NM - 
        0.05535561347412098*lm*NM - 0.06882284746078894*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2683421511003588*NL - 
        0.05535561347412098*lm*NL - 0.06882284746078894*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.09175504073430354*NH - 
        0.05535561347412098*lm*NH - 0.06882284746078894*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.845, CF*NC*(CA*(0.404783442246798 - 0.40694032277665365*lm + 
          0.6679352499177376*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.11688908627431573 + 0.5251338812173003*lm - 
          0.696787772861884*lm^2 + 0.25*lm^3) + 0.0069395950218196605*NM - 
        0.05462496164384982*lm*NM - 0.0684124696820129*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26799722143397536*NL - 
        0.05462496164384982*lm*NL - 0.0684124696820129*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.0906528829484534*NH - 
        0.05462496164384982*lm*NH - 0.0684124696820129*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.85, CF*NC*(CA*(0.4061113905498709 - 0.413804668513759*lm + 
          0.6656758024147137*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.11458565175550207 + 0.5315474137330912*lm - 
          0.7004850505941048*lm^2 + 0.25*lm^3) + 0.008736999737794711*NM - 
        0.05389974613862957*lm*NM - 0.06800166104509946*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2676587944310239*NL - 
        0.05389974613862957*lm*NL - 0.06800166104509946*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.0895505978430679*NH - 
        0.05389974613862957*lm*NH - 0.06800166104509946*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.855, CF*NC*(CA*(0.407504477311279 - 0.4206419074649181*lm + 
          0.6634140835338407*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1122387409958829 + 0.5380230420809877*lm - 0.7041860451264425*
           lm^2 + 0.25*lm^3) + 0.01052080063732821*NM - 
        0.053179984748042336*lm*NM - 0.06759043943039528*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2673267974853711*NL - 
        0.053179984748042336*lm*NL - 0.06759043943039528*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08844825904847571*NH - 
        0.053179984748042336*lm*NH - 0.06759043943039528*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.86, CF*NC*(CA*(0.40896204875718195 - 0.427451825401094*lm + 
          0.6611501899111929*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.10984799067940594 + 0.5445603620978423*lm - 
          0.707890598327139*lm^2 + 0.25*lm^3) + 0.012291088267673032*NM - 
        0.05246569406075532*lm*NM - 0.06717882240809567*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26700115817818154*NL - 
        0.05246569406075532*lm*NL - 0.06717882240809567*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08734593886932211*NH - 
        0.05246569406075532*lm*NH - 0.06717882240809567*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.865, CF*NC*(CA*(0.41048345303727146 - 0.4342342166499397*lm + 
          0.6588842165055319*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.1074130473245997 + 0.5511589687183229*lm - 0.7115985548091296*
           lm^2 + 0.25*lm^3) + 0.014047953473339841*NM - 
        0.05175688949781235*lm*NM - 0.06676682724343004*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2666818042962002*NL - 
        0.05175688949781235*lm*NL - 0.06676682724343004*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08624370830641023*NH - 
        0.05175688949781235*lm*NH - 0.06676682724343004*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.87, CF*NC*(CA*(0.4120680403653797 - 0.4409888838817148*lm + 
          0.6566162566263433*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.10493356713893931 + 0.5578184561062717*lm - 
          0.7153097618841656*lm^2 + 0.25*lm^3) + 0.015791487359764447*NM - 
        0.05105358534507045*lm*NM - 0.06635447090175937*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2663686638491486*NL - 
        0.05105358534507045*lm*NL - 0.06635447090175937*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08514163707818463*NH - 
        0.05105358534507045*lm*NH - 0.06635447090175937*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.875, CF*NC*(CA*(0.4137151631532787 - 0.44771563790038704*lm + 
          0.6543464019613964*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.10240921587383316 + 0.5645384177812943*lm - 
          0.7190240695177151*lm^2 + 0.25*lm^3) + 0.017521781258367175*NM - 
        0.05035579478480371*lm*NM - 0.06594177005358721*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26606166508626816*NL - 
        0.05035579478480371*lm*NL - 0.06594177005358721*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08403979364186247*NH - 
        0.05035579478480371*lm*NH - 0.06594177005358721*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.88, CF*NC*(CA*(0.4154241761379242 - 0.45441429743978917*lm + 
          0.6520747426038371*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.09983966868031215 + 0.571318446740731*lm - 0.7227413302846302*
           lm^2 + 0.25*lm^3) + 0.01923892669295655*NM - 
        0.049663529926496364*lm*NM - 0.06552874107948553*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26576073651204385*NL - 
        0.049663529926496364*lm*NL - 0.06552874107948553*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08293824521421794*NH - 
        0.049663529926496364*lm*NH - 0.06552874107948553*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.885, CF*NC*(CA*(0.4171944365023889 - 0.46108468896470534*lm + 
          0.6498013670788204*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.09722460996549674 + 0.5781581355771559*lm - 
          0.7264613993255666*lm^2 + 0.25*lm^3) + 0.02094301534743123*NM - 
        0.04897680183684606*lm*NM - 0.06511540007493703*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2654658069011382*NL - 
        0.04897680183684606*lm*NL - 0.06511540007493703*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08183705779202484*NH - 
        0.04897680183684606*lm*NH - 0.06511540007493703*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.89, CF*NC*(CA*(0.4190253039907218 - 0.46772664647676343*lm + 
          0.6475263623696892*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.09456373324991219 + 0.5850570765915479*lm - 
          0.7301841343041449*lm^2 + 0.25*lm^3) + 0.022634139034735726*NM - 
        0.048295620568998075*lm*NM - 0.064701762855095*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26517680531256754*NL - 
        0.048295620568998075*lm*NL - 0.064701762855095*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.08073629617216281*NH - 
        0.048295620568998075*lm*NH - 0.064701762855095*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.895, CF*NC*(CA*(0.4209161410169602 - 0.47434001132501424*lm + 
          0.6452498139437095*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.091856741025717 + 0.592014861902268*lm - 0.7339093953648389*
           lm^2 + 0.25*lm^3) + 0.024312389667027014*NM - 
        0.04761999519103041*lm*NM - 0.06428784495946234*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2648936611031484*NL - 
        0.04761999519103041*lm*NL - 0.06428784495946234*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07963602397139252*NH - 
        0.04761999519103041*lm*NH - 0.06428784495946234*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.9, CF*NC*(CA*(0.42286631276851494 - 0.4809246320210801*lm + 
          0.6429718057773668*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.08910334461590448 + 0.599031083549978*lm - 0.7376370450915817*
           lm^2 + 0.25*lm^3) + 0.02597785922701053*NM - 
        0.046949933813709335*lm*NM - 0.06387366165649093*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26461630394024177*NL - 
        0.046949933813709335*lm*NL - 0.06387366165649093*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07853630364580458*NH - 
        0.046949933813709335*lm*NH - 0.06387366165649093*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.905, CF*NC*(CA*(0.42487518730414 - 0.4874803640587604*lm + 
          0.6406924203812319*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.08630326403453305 + 0.6061053335986294*lm - 
          0.7413669484670752*lm^2 + 0.25*lm^3) + 0.027630639740405527*NM - 
        0.046285443617534235*lm*NM - 0.06345922794810276*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26434466381382393*NL - 
        0.046285443617534235*lm*NL - 0.06345922794810276*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07743719650994768*NH - 
        0.046285443617534235*lm*NH - 0.06345922794810276*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.91, CF*NC*(CA*(0.4269421356466901 - 0.49400706973798186*lm + 
          0.6384117388244043*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.08345622784803634 + 0.6132372042326469*lm - 
          0.7450989728327929*lm^2 + 0.25*lm^3) + 0.029270823249501178*NM - 
        0.0456265308790904*lm*NM - 0.06304455857413412*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26407867104790755*NL - 
        0.0456265308790904*lm*NL - 0.06304455857413412*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07633876275564075*NH - 
        0.0456265308790904*lm*NH - 0.06304455857413412*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.915, CF*NC*(CA*(0.4290665318708638 - 0.5005046179929877*lm + 
          0.6361298407585391*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.08056197303766001 + 0.6204262878504281*lm - 
          0.7488329878496633*lm^2 + 0.25*lm^3) + 0.030898501787766004*NM - 
        0.04497320099672759*lm*NM - 0.06262966801670407*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2638182563113399*NL - 
        0.04497320099672759*lm*NL - 0.06262966801670407*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07524106147047416*NH - 
        0.04497320099672759*lm*NH - 0.06262966801670407*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.92, CF*NC*(CA*(0.4312477531861211 - 0.506972884224658*lm + 
          0.6338468044414637*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.07762024486306833 + 0.6276721771542756*lm - 
          0.7525688654594231*lm^2 + 0.25*lm^3) + 0.03251376735547466*NM - 
        0.04432545851558183*lm*NM - 0.06221457050450854*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2635633506280012*NL - 
        0.04432545851558183*lm*NL - 0.06221457050450854*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07414415065600492*NH - 
        0.04432545851558183*lm*NH - 0.06221457050450854*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.925, CF*NC*(CA*(0.43348518001495834 - 0.513411750136862*lm + 
          0.6315627067603936*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.07463079672715997 + 0.6349744652368772*lm - 
          0.7563064798466287*lm^2 + 0.25*lm^3) + 0.034116711896317174*NM - 
        0.043683307151957645*lm*NM - 0.06179928001704126*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26331388538642664*NL - 
        0.043683307151957645*lm*NL - 0.06179928001704126*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07304808724565082*NH - 
        0.043683307151957645*lm*NH - 0.06179928001704126*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.93, CF*NC*(CA*(0.4357781960667178 - 0.5198211035767396*lm + 
          0.6292776232547522*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.07159339004212867 + 0.6423327456644419*lm - 
          0.7600457074013145*lm^2 + 0.25*lm^3) + 0.03570742727495702*NM - 
        0.043046749817087*lm*NM - 0.06138381028874283*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26306979234887484*NL - 
        0.043046749817087*lm*NL - 0.06138381028874283*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07195292712228807*NH - 
        0.043046749817087*lm*NH - 0.06138381028874283*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.935, CF*NC*(CA*(0.43812618840710016 - 0.5262008383788173*lm + 
          0.6269916281386014*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.06850779409680158 + 0.6497466125566003*lm - 
          0.7637864266822886*lm^2 + 0.25*lm^3) + 0.037286005255505544*NM - 
        0.042415788640281345*lm*NM - 0.06096817481307904*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26283100365986345*NL - 
        0.042415788640281345*lm*NL - 0.06096817481307904*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.07085872513555742*NH - 
        0.042415788640281345*lm*NH - 0.06096817481307904*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.94, CF*NC*(CA*(0.4405285475235455 - 0.5325508542128623*lm + 
          0.6247047943226902*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.0653737859252845 + 0.6572156606631716*lm - 0.7675285183810523*
           lm^2 + 0.25*lm^3) + 0.03885253748088136*NM - 
        0.041790424991492256*lm*NM - 0.06055238684654974*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2625974518541934*NL - 
        0.041790424991492256*lm*NL - 0.06055238684654974*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06976553511888346*NH - 
        0.041790424991492256*lm*NH - 0.06055238684654974*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.945, CF*NC*(CA*(0.44298466738663966 - 0.5388710564353845*lm + 
          0.6224171934361281*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.06219115017694075 + 0.6647394854378974*lm - 
          0.7712718652863358*lm^2 + 0.25*lm^3) + 0.040407115453024334*NM - 
        0.041170659503295993*lm*NM - 0.06013645941262936*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26236906986448133*NL - 
        0.041170659503295993*lm*NL - 0.06013645941262936*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06867340990621146*NH - 
        0.041170659503295993*lm*NH - 0.06013645941262936*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.95, CF*NC*(CA*(0.44549394550769955 - 0.5451613559446932*lm + 
          0.6201288958476884*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.0589596789877271 + 0.6723176831092401*lm - 0.7750163522492373*
           lm^2 + 0.25*lm^3) + 0.041949830513934895*NM - 
        0.040556492092316834*lm*NM - 0.0597204053056403*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2621457910282195*NL - 
        0.040556492092316834*lm*NL - 0.0597204053056403*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06758240134846663*NH - 
        0.040556492092316834*lm*NH - 0.0597204053056403*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.955, CF*NC*(CA*(0.4480557829926828 - 0.5514216690394254*lm + 
          0.6178399706867487*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.0556791718529083 + 0.6799498507483391*lm - 0.7787618661489567*
           lm^2 + 0.25*lm^3) + 0.04348077382751044*NM - 
        0.039947921980103634*lm*NM - 0.05930423709456037*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2619275490943821*NL - 
        0.039947921980103634*lm*NL - 0.05930423709456037*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06649256032974012*NH - 
        0.039947921980103634*lm*NH - 0.05930423709456037*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.96, CF*NC*(CA*(0.4506695845925651 - 0.5576519172804559*lm + 
          0.6155504858638755*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.05234943550116842 + 0.6876355863342163*lm - 
          0.7825082958591129*lm^2 + 0.25*lm^3) + 0.04500003636215135*NM - 
        0.03934494771347369*lm*NM - 0.05888796712676524*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2617142782295954*NL - 
        0.03934494771347369*lm*NL - 0.05888796712676524*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06540393678320623*NH - 
        0.03934494771347369*lm*NH - 0.05888796712676524*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.965, CF*NC*(CA*(0.4533347587503207 - 0.5638520273561107*lm + 
          0.6132605080910565*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.04897028377013569 + 0.6953744888163184*lm - 
          0.786255532214635*lm^2 + 0.25*lm^3) + 0.046507708874110314*NM - 
        0.038747567184337556*lm*NM - 0.05847160753170723*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26150591302388904*NL - 
        0.038747567184337556*lm*NL - 0.05847160753170723*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06431657970677535*NH - 
        0.038747567184337556*lm*NH - 0.05847160753170723*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.97, CF*NC*(CA*(0.4560507176446384 - 0.5700219309505978*lm + 
          0.6109701029015894*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.04554153748333476 + 0.7031661581744831*lm - 
          0.7900034679792174*lm^2 + 0.25*lm^3) + 0.04800388189155933*NM - 
        0.03815577764901824*lm*NM - 0.0580551702245314*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2613023884960451*NL - 
        0.03815577764901824*lm*NL - 0.0580551702245314*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06323053717848671*NH - 
        0.03815577764901824*lm*NH - 0.0580551702245314*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.975, CF*NC*(CA*(0.45881687723050024 - 0.5761615646155808*lm + 
          0.6086793346696319*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.04206302432857857 + 0.7110101954764108*lm - 
          0.7937519978133297*lm^2 + 0.25*lm^3) + 0.049488645699349874*NM - 
        0.03756957574707764*lm*NM - 0.057638666909630036*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2611036400985612*NL - 
        0.03756957574707764*lm*NL - 0.057638666909630036*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.062145856371645464*NH - 
        0.03756957574707764*lm*NH - 0.057638666909630036*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.98, CF*NC*(CA*(0.4616326572767446 - 0.5822708696448157*lm + 
          0.606388266629418*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.03853457873780991 + 0.7189062029327211*lm - 
          0.7975010182427705*lm^2 + 0.25*lm^3) + 0.05096209032444221*NM - 
        0.03698895751966291*lm*NM - 0.05722210908413661*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2609096037222424*NL - 
        0.03698895751966291*lm*NL - 0.05722210908413661*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.06106258356970809*NH - 
        0.03698895751966291*lm*NH - 0.05722210908413661*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.985, CF*NC*(CA*(0.4644974814007327 - 0.5883497919517778*lm + 
          0.6040969608941482*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.03495604176840102 + 0.7268537839496753*lm - 
          0.8012504276277574*lm^2 + 0.25*lm^3) + 0.05242430552198096*NM - 
        0.03641391842738511*lm*NM - 0.05680550804136028*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2607202157004374*NL - 
        0.03641391842738511*lm*NL - 0.05680550804136028*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.05998076418092048*NH - 
        0.03641391842738511*lm*NH - 0.05680550804136028*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.99, CF*NC*(CA*(0.46741077710023254 - 0.5943982819502043*lm + 
          0.601805478474557*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.0313272609859178 + 0.7348525431796361*lm - 0.8050001261325431*
           lm^2 + 0.25*lm^3) + 0.05387538076199459*NM - 
        0.03584445336774191*lm*NM - 0.05638887487416188*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.2605354128129327*NL - 
        0.03584445336774191*lm*NL - 0.05638887487416188*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.05890044275271257*NH - 
        0.03584445336774191*lm*NH - 0.05638887487416188*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {0.995, CF*NC*(CA*(0.4703719757826288 - 0.6004162944374809*lm + 
          0.5995138792971654*lm^2 + 0.1527777777777778*lm^3) + 
        CF*(0.027648090348353683 + 0.742902086569341*lm - 
          0.8087500156955475*lm^2 + 0.25*lm^3) + 0.05531540521669733*NM - 
        0.03528055669209628*lm*NM - 0.055972220478272494*lm^2*NM - 
        0.027777777777777776*lm^3*NM - 0.26035513228951906*NL - 
        0.03528055669209628*lm*NL - 0.055972220478272494*lm^2*NL - 
        0.027777777777777776*lm^3*NL + 0.057821662985853735*NH - 
        0.03528055669209628*lm*NH - 0.055972220478272494*lm^2*NH - 
        0.027777777777777776*lm^3*NH)}, 
     {1., 0.7518410136834407*(CA - 2.*CF)*CF*NC - 0.00034722222222222224*CF*
        NC*(CF*(-4399.489202281107 - 2162.8858216494473*lm + 2340.*lm^2 - 
           720.*lm^3) - 2.*CA*(-400.9831212842988 - 873.2214554123618*lm + 
           860.*lm^2 + 220.*lm^3) + 20.*((-8.17120335576568 + 5.*lm + 
             8.*lm^2 + 4.*lm^3)*NM + (37.465820901107016 + 5.*lm + 8.*lm^2 + 
             4.*lm^3)*NL + (-8.17120335576568 + 5.*lm + 8.*lm^2 + 4.*lm^3)*
            NH))}}
 
CbarTable["p", 2, 1] = {{0., -6.430041152263374*^-6*CF*NC*
       (2.*CA*(-2388.1522153911205 - 28035.755618875908*lm) + 
        15.*(-3103.0124357078876*CF + 
          4.*((-67.3596725935698 + 169.91367041742973*lm)*NM + 
            (-67.3596725935698 + 169.91367041742973*lm)*NL + 
            (-206.3135567749981 + 169.91367041742973*lm)*NH)))}, 
     {0.005, CF*NC*(0.31615565919877225*CF + CA*(0.04582222034635731 + 
          0.36645235886682315*lm) + 0.02396495099722558*NM - 
        0.06662770161214966*lm*NM + 0.02395869213049304*NL - 
        0.06662770161214966*lm*NL + 0.07997361048201287*NH - 
        0.06662770161214966*lm*NH)}, 
     {0.01, CF*NC*(0.3319462821112075*CF + CA*(0.06008664681941353 + 
          0.37213027077878336*lm) + 0.02207752691697888*NM - 
        0.06766004923250607*lm*NM + 0.02204928558067381*NL - 
        0.06766004923250607*lm*NL + 0.08033950661149586*NH - 
        0.06766004923250607*lm*NH)}, 
     {0.015, CF*NC*(0.3465448277377524*CF + CA*(0.07338732080160945 + 
          0.3775409554163912*lm) + 0.020344140982140085*NM - 
        0.0686438100757075*lm*NM + 0.020275720421108766*NL - 
        0.0686438100757075*lm*NL + 0.08069288582863712*NH - 
        0.0686438100757075*lm*NH)}, 
     {0.02, CF*NC*(0.3599567343264048*CF + CA*(0.08569039310095639 + 
          0.38266760943008166*lm) + 0.018769507206348568*NM - 
        0.06957592898728757*lm*NM + 0.01864176067259709*NL - 
        0.06957592898728757*lm*NL + 0.08103302094804168*NH - 
        0.06957592898728757*lm*NH)}, 
     {0.025, CF*NC*(0.3722271845413561*CF + CA*(0.09699701240671499 + 
          0.38750243140164353*lm) + 0.01735250313763231*NM - 
        0.07045498752757155*lm*NM + 0.01714614640839142*NL - 
        0.07045498752757155*lm*NL + 0.08135940539623648*NH - 
        0.07045498752757155*lm*NH)}, 
     {0.03, CF*NC*(0.3834175809062193*CF + CA*(0.1073268371841326 + 
          0.3920431073182405*lm) + 0.016088974811626033*NM - 
        0.07128056496695281*lm*NM + 0.0157850831399803*NL - 
        0.07128056496695281*lm*NL + 0.08167169144318061*NH - 
        0.07128056496695281*lm*NH)}, 
     {0.035, CF*NC*(0.39359553643898404*CF + CA*(0.11671011582745548 + 
          0.39629095094526595*lm) + 0.014973080890265467*NM - 
        0.07205290017186654*lm*NM + 0.014553406473498915*NL - 
        0.07205290017186654*lm*NL + 0.08196965306110401*NH - 
        0.07205290017186654*lm*NH)}, 
     {0.04, CF*NC*(0.4028299680806589*CF + CA*(0.12518327197442627 + 
          0.4002497753169285*lm) + 0.013998038500052132*NM - 
        0.07277268642125972*lm*NM + 0.013445214521692365*NL - 
        0.07277268642125972*lm*NL + 0.08225316073041262*NH - 
        0.07277268642125972*lm*NH)}, 
     {0.045, CF*NC*(0.4111885280971446*CF + CA*(0.13278622601962922 + 
          0.40392515073571944*lm) + 0.013156572502184487*NM - 
        0.07344093649740353*lm*NM + 0.01245424116846773*NL - 
        0.07344093649740353*lm*NL + 0.08252216309257344*NH - 
        0.07344093649740353*lm*NH)}, 
     {0.05, CF*NC*(0.41873623411951294*CF + CA*(0.139560681552003 + 
          0.4073238906734535*lm) + 0.012441199956624797*NM - 
        0.07405888921335518*lm*NM + 0.011574087763495737*NL - 
        0.07405888921335518*lm*NL + 0.08277667295188527*NH - 
        0.07405888921335518*lm*NH)}, 
     {0.055, CF*NC*(0.42553475929270296*CF + CA*(0.14554899132833915 + 
          0.4104536824124947*lm) + 0.011844415720989567*NM - 
        0.07462794225681722*lm*NM + 0.01079837128042189*NL - 
        0.07462794225681722*lm*NL + 0.08301675624143474*NH - 
        0.07462794225681722*lm*NH)}, 
     {0.06, CF*NC*(0.4316421031642913*CF + CA*(0.15079339120357066 + 
          0.4133228146933611*lm) + 0.011358815434442726*NM - 
        0.0751496026715202*lm*NM + 0.010120820409858672*NL - 
        0.0751496026715202*lm*NL + 0.08324252311618595*NH - 
        0.0751496026715202*lm*NH)}, 
     {0.065, CF*NC*(0.437112488373952*CF + CA*(0.15533547752240617 + 
          0.4159399730718911*lm) + 0.010977177236818913*NM - 
        0.07562544964943475*lm*NM + 0.009535337874550714*NL - 
        0.07562544964943475*lm*NL + 0.08345412063337387*NH - 
        0.07562544964943475*lm*NH)}, 
     {0.07, CF*NC*(0.44199639286044634*CF + CA*(0.15921585071599056 + 
          0.4183140840512407*lm) + 0.01069251547742414*NM - 
        0.07605710619113468*lm*NM + 0.009036040169374334*NL - 
        0.07605710619113468*lm*NL + 0.08365172665407104*NH - 
        0.07605710619113468*lm*NH)}, 
     {0.075, CF*NC*(0.4463406630020329*CF + CA*(0.16247387510604874 + 
          0.4204541952380719*lm) + 0.010498114989111707*NM - 
        0.07644621731601309*lm*NM + 0.008617281879314119*NL - 
        0.07644621731601309*lm*NL + 0.08383554470737925*NH - 
        0.07644621731601309*lm*NH)}, 
     {0.08, CF*NC*(0.4501886737814408*CF + CA*(0.16514752144701872 + 
          0.4223693826454927*lm) + 0.01038755166232737*NM - 
        0.0767944332082714*lm*NM + 0.008273669296857881*NL - 
        0.0767944332082714*lm*NL + 0.08400579962853555*NH - 
        0.0767944332082714*lm*NH)}, 
     {0.085, CF*NC*(0.45358051450693637*CF + CA*(0.16727326917331975 + 
          0.4240686787893782*lm) + 0.01035470325790136*NM - 
        0.07710339614352331*lm*NM + 0.008000066539972851*NL - 
        0.07710339614352331*lm*NL + 0.0841627338293557*NH - 
        0.07710339614352331*lm*NH)}, 
     {0.09, CF*NC*(0.4565531863403472*CF + CA*(0.1688860521357549 + 
          0.42556101692514214*lm) + 0.010393753223407867*NM - 
        0.07737473035002584*lm*NM + 0.007791596389008986*NL - 
        0.07737473035002584*lm*NL + 0.08430660409230982*NH - 
        0.07737473035002584*lm*NH)}, 
     {0.095, CF*NC*(0.45914080279288827*CF + CA*(0.17001923619250398 + 
          0.4268551879503256*lm) + 0.010499189488631043*NM - 
        0.07761003417278647*lm*NM + 0.007643637407381253*NL - 
        0.07761003417278647*lm*NL + 0.08443767880310095*NH - 
        0.07761003417278647*lm*NH)}, 
     {0.1, CF*NC*(0.4613747875348161*CF + CA*(0.1707046201751254 + 
          0.4279598073348493*lm) + 0.010665799672216153*NM - 
        0.07781087406088169*lm*NM + 0.007551818465865601*NL - 
        0.07781087406088169*lm*NL + 0.0845562355539425*NH - 
        0.07781087406088169*lm*NH)}, 
     {0.105, CF*NC*(0.4632840659628961*CF + CA*(0.1709724539685476 + 
          0.4288832900471518*lm) + 0.010888663749690119*NM - 
        0.07797878000857306*lm*NM + 0.0075120114810553985*NL - 
        0.07797878000857306*lm*NL + 0.08466255906273343*NH - 
        0.07797878000857306*lm*NH)}, 
     {0.11, CF*NC*(0.4648952483668724*CF + CA*(0.17085146903259948 + 
          0.429633831892115*lm) + 0.011163144959951367*NM - 
        0.07811524216220272*lm*NM + 0.007520322959780724*NL - 
        0.07811524216220272*lm*NL + 0.08475693936327318*NH - 
        0.07811524216220272*lm*NH)}, 
     {0.115, CF*NC*(0.4662328034730885*CF + CA*(0.1703689178481065 + 
          0.43021939601253356*lm) + 0.011484879529102775*NM - 
        0.07822170836591519*lm*NM + 0.007573084784247127*NL - 
        0.07822170836591519*lm*NL + 0.0848396702293874*NH - 
        0.07822170836591519*lm*NH)}, 
     {0.12, CF*NC*(0.4673192217733006*CF + CA*(0.1695506196226081 + 
          0.43064770356144394*lm) + 0.011849765644748116*NM - 
        0.07829958246571708*lm*NM + 0.0076668445584407476*NL - 
        0.07829958246571708*lm*NL + 0.08491104780193298*NH - 
        0.07829958246571708*lm*NH)}, 
     {0.125, CF*NC*(0.46817516846906204*CF + CA*(0.16842101022655 + 
          0.4309262277495424*lm) + 0.012253952005512828*NM - 
        0.07835022322718954*lm*NM + 0.007798355752371604*NL - 
        0.07835022322718954*lm*NL + 0.08497136939252348*NH - 
        0.07835022322718954*lm*NH)}, 
     {0.13, CF*NC*(0.46881962614264755*CF + CA*(0.16700319481018594 + 
          0.4310621906253533*lm) + 0.012693826189230473*NM - 
        0.07837494375006424*lm*NM + 0.007964567818405991*NL - 
        0.07837494375006424*lm*NL + 0.08502093244175729*NH - 
        0.07837494375006424*lm*NH)}, 
     {0.135, CF*NC*(0.4692700274485024*CF + CA*(0.16531900191612744 + 
          0.43106256206655413*lm) + 0.013166003021725103*NM - 
        0.07837501128482803*lm*NM + 0.008162616407328935*NL - 
        0.07837501128482803*lm*NL + 0.08506003361295086*NH - 
        0.07837501128482803*lm*NH)}, 
     {0.14, CF*NC*(0.46954237823469414*CF + CA*(0.16338903818209508 + 
          0.43093406055674566*lm) + 0.013667313081287153*NM - 
        0.07835164737395375*lm*NM + 0.008389813776698314*NL - 
        0.07835164737395375*lm*NL + 0.08508896800503692*NH - 
        0.07835164737395375*lm*NH)}, 
     {0.145, CF*NC*(0.46965137157249986*CF + CA*(0.16123274294421272 + 
          0.43068315539868907*lm) + 0.014194791438096743*NM - 
        0.0783060282543071*lm*NM + 0.008643639457522213*NL - 
        0.0783060282543071*lm*NL + 0.08510802847049866*NH - 
        0.0783060282543071*lm*NH)}, 
     {0.15, CF*NC*(0.46961049320843695*CF + CA*(0.15886844221864033 + 
          0.43031607007690137*lm) + 0.01474566670030609*NM - 
        0.07823928546852751*lm*NM + 0.008921731225157228*NL - 
        0.07823928546852751*lm*NL + 0.08511750502606562*NH - 
        0.07823928546852751*lm*NH)}, 
     {0.155, CF*NC*(0.4694321189668098*CF + CA*(0.1563134016698653 + 
          0.4298387865326897*lm) + 0.01531735041727225*NM - 
        0.07815250664230722*lm*NM + 0.009221876405015208*NL - 
        0.07815250664230722*lm*NL + 0.08511768434546352*NH - 
        0.07815250664230722*lm*NH)}, 
     {0.16, CF*NC*(0.46912760462928227*CF + CA*(0.15358387827606854 + 
          0.42925705015566706*lm) + 0.01590742687405908*NM - 
        0.07804673639193947*lm*NM + 0.009542003532018438*NL - 
        0.07804673639193947*lm*NL + 0.08510884932484156*NH - 
        0.07804673639193947*lm*NH)}, 
     {0.165, CF*NC*(0.46870736880611785*CF + CA*(0.15069517048203349 + 
          0.42857637532938825*lm) + 0.016513643298695712*NM - 
        0.07792297733261605*lm*NM + 0.009880174373894266*NL - 
        0.07792297733261605*lm*NL + 0.08509127871263981*NH - 
        0.07792297733261605*lm*NH)}, 
     {0.17, CF*NC*(0.46818096929511993*CF + CA*(0.14766166669292555 + 
          0.42780205139643424*lm) + 0.01713390049394914*NM - 
        0.07778219116298804*lm*NM + 0.010234576321699627*NL - 
        0.07778219116298804*lm*NL + 0.08506524679663766*NH - 
        0.07778219116298804*lm*NH)}, 
     {0.175, CF*NC*(0.46755717340148367*CF + CA*(0.14449689201164098 + 
          0.4269391489311817*lm) + 0.01776624389789966*NM - 
        0.0776252998056694*lm*NM + 0.010603515145922513*NL - 
        0.0776252998056694*lm*NL + 0.08503102314176963*NH - 
        0.0776252998056694*lm*NH)}, 
     {0.18, CF*NC*(0.466844022666532*CF + CA*(0.1412135531611672 + 
          0.42599252622752354*lm) + 0.018408855071907305*NM - 
        0.07745318658682246*lm*NM + 0.010985408112745816*NL - 
        0.07745318658682246*lm*NL + 0.0849888723730286*NH - 
        0.07745318658682246*lm*NH)}, 
     {0.185, CF*NC*(0.46604889242692354*CF + CA*(0.13782358156372687 + 
          0.42496683592465834*lm) + 0.019060043610243434*NM - 
        0.07726669744084697*lm*NM + 0.011378777452291797*NL - 
        0.07726669744084697*lm*NL + 0.08493905399841467*NH - 
        0.07726669744084697*lm*NH)}, 
     {0.19, CF*NC*(0.46517854659926844*CF + CA*(0.13433817457212918 + 
          0.4238665317073146*lm) + 0.019718239462437233*NM - 
        0.07706664212860266*lm*NM + 0.011782244168670686*NL - 
        0.07706664212860266*lm*NL + 0.08488182226744743*NH - 
        0.07706664212860266*lm*NH)}, 
     {0.195, CF*NC*(0.464239188058791*CF + CA*(0.13076783486708202 + 
          0.42269587502786904*lm) + 0.020381985657019302*NM - 
        0.07685379545961254*lm*NM + 0.012194522180262497*NL - 
        0.07685379545961254*lm*NL + 0.08481742606124809*NH - 
        0.07685379545961254*lm*NH)}, 
     {0.2, NC*(0.4632365049553355*CF^2 + CA*CF*(0.12712240804820363 + 
          0.42145894180713145*lm) + 
        CF*((0.021049931414170896 - 0.07662889851038754*lm)*NM + 
          (0.012614412777733224 - 0.07662889851038754*lm)*NL + 
          (0.08474610881063008 - 0.07662889851038754*lm)*NH))}, 
     {0.205, NC*(0.46217571328440765*CF^2 + CA*CF*(0.12341111845771123 + 
          0.42015962907839716*lm) + 
        CF*((0.02172082563066657 - 0.07639265983243584*lm)*NM + 
          (0.013040799386720186 - 0.07639265983243584*lm)*NL + 
          (0.08466810843901659 - 0.07639265983243584*lm)*NH))}, 
     {0.21, NC*(0.46106159601046065*CF^2 + CA*CF*(0.11964260328232541 + 
          0.4188016615459585*lm) + 
        CF*((0.022393510727383673 - 0.07614575664471973*lm)*NM + 
          (0.01347264262183456 - 0.07614575664471973*lm)*NL + 
          (0.08458365732734026 - 0.07614575664471973*lm)*NH))}, 
     {0.215, NC*(0.45989853901351413*CF^2 + CA*CF*(0.11582494498677656 + 
          0.4173885980348219*lm) + 
        CF*((0.02306691683804151 - 0.07588883600633126*lm)*NM + 
          (0.01390897561855712 - 0.07588883600633126*lm)*NL + 
          (0.08449298229837836 - 0.07588883600633126*lm)*NH))}, 
     {0.22, NC*(0.4586905641131827*CF^2 + CA*CF*(0.11196570213452191 + 
          0.4159238378130594*lm) + 
        CF*((0.023740056327727427 - 0.0756225159660108*lm)*NM + 
          (0.014348899629695468 - 0.0756225159660108*lm)*NL + 
          (0.08439630461824266 - 0.0756225159660108*lm)*NH))}, 
     {0.225, NC*(0.4574413594028487*CF^2 + CA*CF*(0.10807193865494061 + 
          0.41441062677217355*lm) + 
        CF*((0.02441201862429918 - 0.07534738668584973*lm)*NM + 
          (0.014791579873286833 - 0.07534738668584973*lm)*NL + 
          (0.08429384001297846 - 0.07534738668584973*lm)*NH))}, 
     {0.23, NC*(0.45615430710925653*CF^2 + CA*CF*(0.10415025161753824 + 
          0.412852063454186*lm) + 
        CF*((0.025081965347614973 - 0.07506401153712473*lm)*NM + 
          (0.015236241619138762 - 0.07506401153712473*lm)*NL + 
          (0.08418579869843885 - 0.07506401153712473*lm)*NH))}, 
     {0.235, NC*(0.45483250917604173*CF^2 + CA*CF*(0.1002067975743614 + 
          0.41125110491696726*lm) + 
        CF*((0.025749125721779054 - 0.07477292816672132*lm)*NM + 
          (0.015682166501575133 - 0.07477292816672132*lm)*NL + 
          (0.08407238542178758 - 0.07477292816672132*lm)*NH))}, 
     {0.24, NC*(0.4534788107539333*CF^2 + CA*CF*(0.0962473175319056 + 
          0.40961057243168686*lm) + 
        CF*((0.02641279225562553 - 0.07447464953303398*lm)*NM + 
          (0.016128689046377456 - 0.07447464953303398*lm)*NL + 
          (0.08395379951315307 - 0.07447464953303398*lm)*NH))}, 
     {0.245, NC*(0.45209582176619956*CF^2 + CA*CF*(0.09227716061311116 + 
          0.4079331570082536*lm) + 
        CF*((0.027072316677573732 - 0.07416966491059157*lm)*NM + 
          (0.016575193400365743 - 0.07416966491059157*lm)*NL + 
          (0.08383023494610707 - 0.07416966491059157*lm)*NH))}, 
     {0.25, NC*(0.4506859367043587*CF^2 + CA*CF*(0.08830130646915803 + 
          0.4062214247462778*lm) + 
        CF*((0.027727106111117148 - 0.0738584408629596*lm)*NM + 
          (0.017021110252536956 - 0.0738584408629596*lm)*NL + 
          (0.08370188040577597 - 0.0738584408629596*lm)*NH))}, 
     {0.255, NC*(0.4492513527969598*CF^2 + CA*CF*(0.08432438649940775 + 
          0.40447782201048477*lm) + 
        CF*((0.028376619477919494 - 0.0735414221837245*lm)*NM + 
          (0.01746591393616294 - 0.0735414221837245*lm)*NL + 
          (0.08356891936351589 - 0.0735414221837245*lm)*NH))}, 
     {0.26, NC*(0.44779408668283527*CF^2 + CA*CF*(0.08035070393629934 + 
          0.4027046804306687*lm) + 
        CF*((0.029020364115983403 - 0.07321903280557612*lm)*NM + 
          (0.017909119701735896 - 0.07321903280557612*lm)*NL + 
          (0.08343153015719063 - 0.07321903280557612*lm)*NH))}, 
     {0.265, NC*(0.4463159897097558*CF^2 + CA*CF*(0.07638425285026362 + 
          0.4009042217272415*lm) + 
        CF*((0.029657892600916193 - 0.07289167667768028*lm)*NM + 
          (0.018350281151132682 - 0.07289167667768028*lm)*NL + 
          (0.08328988607619135 - 0.07289167667768028*lm)*NH))}, 
     {0.27, NC*(0.4448187619697559*CF^2 + CA*CF*(0.07242873612785891 + 
          0.3990785623642243*lm) + 
        CF*((0.03028879975885498 - 0.07255973861167714*lm)*NM + 
          (0.018788987823844562 - 0.07255973861167714*lm)*NL + 
          (0.08314415545042432 - 0.07255973861167714*lm)*NH))}, 
     {0.275, NC*(0.4433039651735402*CF^2 + CA*CF*(0.06848758247436355 + 
          0.39722971803218204*lm) + 
        CF*((0.030912719860188176 - 0.07222358509676037*lm)*NM + 
          (0.019224862926583774 - 0.07222358509676037*lm)*NL + 
          (0.08299450174257396 - 0.07222358509676037*lm)*NH))}, 
     {0.28, NC*(0.44177303445818983*CF^2 + CA*CF*(0.06456396249006466 + 
          0.3953596079641297*lm) + 
        CF*((0.03152932398371491 - 0.07188356508438722*lm)*NM + 
          (0.019657561198029364 - 0.07188356508438722*lm)*NL + 
          (0.08284108364302022 - 0.07188356508438722*lm)*NH))}, 
     {0.285, NC*(0.44022728921489523*CF^2 + CA*CF*(0.0606608038674414 + 
          0.3934700590878608*lm) + 
        CF*((0.032138317541434445 - 0.07154001074324742*lm)*NM + 
          (0.020086766900911147 - 0.07154001074324742*lm)*NL + 
          (0.08268405516685409 - 0.07154001074324742*lm)*NH))}, 
     {0.29, NC*(0.43866794301650014*CF^2 + CA*CF*(0.056780805754426976 + 
          0.3915628100184846*lm) + 
        CF*((0.03273943795464803 - 0.07119323818517902*lm)*NM + 
          (0.020512191934050378 - 0.07119323818517902*lm)*NL + 
          (0.08252356575249464 - 0.07119323818517902*lm)*NH))}, 
     {0.295, NC*(0.4370961127182237*CF^2 + CA*CF*(0.05292645232695065 + 
          0.38963951489521514*lm) + 
        CF*((0.03333245247256344 - 0.07084354816276639*lm)*NM + 
          (0.02093357405737891 - 0.07084354816276639*lm)*NL + 
          (0.08235976036146296 - 0.07084354816276639*lm)*NH))}, 
     {0.3, NC*(0.4355128575716693*CF^2 + CA*CF*(0.049100010225689286 + 
          0.38770174706665017*lm) + 
        CF*((0.03391715612504713 - 0.07049122673939094*lm)*NM + 
          (0.021350675223344016 - 0.07049122673939094*lm)*NL + 
          (0.08219277957891767 - 0.07049122673939094*lm)*NH))}, 
     {0.305, NC*(0.4339190579207657*CF^2 + CA*CF*(0.04530360514306273 + 
          0.38575100262891504*lm) + 
        CF*((0.034493369801647196 - 0.07013654593253*lm)*NM + 
          (0.021763280008474165 - 0.07013654593253*lm)*NL + 
          (0.08202275971459884 - 0.07013654593253*lm)*NH))}, 
     {0.31, NC*(0.43231562496155096*CF^2 + CA*CF*(0.04153913188551875 + 
          0.3837887038211392*lm) + 
        CF*((0.03506093844941927 - 0.06977976433111621*lm)*NM + 
          (0.02217119413923164 - 0.06977976433111621*lm)*NL + 
          (0.08184983290386731 - 0.06977976433111621*lm)*NH))}, 
     {0.315, NC*(0.4307033651217195*CF^2 + CA*CF*(0.03780833619504467 + 
          0.3818162022827867*lm) + 
        CF*((0.03561972938252977 - 0.06942112768777939*lm)*NM + 
          (0.022574243106611252 - 0.06942112768777939*lm)*NL + 
          (0.08167412720856125 - 0.06942112768777939*lm)*NH))}, 
     {0.32, NC*(0.4290830233595618*CF^2 + CA*CF*(0.034112806238131246 + 
          0.3798347821773793*lm) + 
        CF*((0.03616963069698327 - 0.06906086948679624*lm)*NM + 
          (0.022972270864260968 - 0.06906086948679624*lm)*NL + 
          (0.08149576671742416 - 0.06906086948679624*lm)*NH))}, 
     {0.325, NC*(0.42745528852878795*CF^2 + CA*CF*(0.030453982243356877 + 
          0.37784566318714585*lm) + 
        CF*((0.03671054978421414 - 0.06869921148857197*lm)*NM + 
          (0.023365138605200418 - 0.06869921148857197*lm)*NL + 
          (0.08131487164588759 - 0.06869921148857197*lm)*NH))}, 
     {0.33, NC*(0.4258207982871785*CF^2 + CA*CF*(0.026833165599628794 + 
          0.37585000338309676*lm) + 
        CF*((0.03724241193763312 - 0.06833636425147215*lm)*NM + 
          (0.02375272361249764 - 0.06833636425147215*lm)*NL + 
          (0.08113155843501775 - 0.06833636425147215*lm)*NH))}, 
     {0.335, NC*(0.42418014358641976*CF^2 + CA*CF*(0.023251527444213396 + 
          0.37384890197497483*lm) + 
        CF*((0.037765159046562816 - 0.0679725276318136*lm)*NM + 
          (0.024134918179533345 - 0.0679725276318136*lm)*NL + 
          (0.08094593984945918 - 0.0679725276318136*lm)*NH))}, 
     {0.34, NC*(0.4225338727774739*CF^2 + CA*CF*(0.019710116768192065 + 
          0.3718434019454654*lm) + 
        CF*((0.038278748372317394 - 0.06760789126281189*lm)*NM + 
          (0.024511628595736513 - 0.06760789126281189*lm)*NL + 
          (0.08075812507423005 - 0.06760789126281189*lm)*NH))}, 
     {0.345, NC*(0.42088249536306266*CF^2 + CA*CF*(0.016209868065549794 + 
          0.36983449257297096*lm) + 
        CF*((0.03878315140148125 - 0.06724263501326744*lm)*NM + 
          (0.02488277419391527 - 0.06724263501326744*lm)*NL + 
          (0.08056821981024269 - 0.06724263501326744*lm)*NH))}, 
     {0.35, NC*(0.4192264854263096*CF^2 + CA*CF*(0.01275160855073339 + 
          0.3678231118471638*lm) + 
        CF*((0.03927835277173841 - 0.06687692942675706*lm)*NM + 
          (0.025248286455534025 - 0.06687692942675706*lm)*NL + 
          (0.08037632636844096 - 0.06687692942675706*lm)*NH))}, 
     {0.355, NC*(0.41756628476224766*CF^2 + CA*CF*(0.009336064968211178 + 
          0.3658101487814352*lm) + 
        CF*((0.03976434926587728 - 0.06651093614207912*lm)*NM + 
          (0.02560810817050193 - 0.06651093614207912*lm)*NL + 
          (0.0801825437624613 - 0.06651093614207912*lm)*NH))}, 
     {0.36, NC*(0.41590230573673875*CF^2 + CA*CF*(0.005963870016328282 + 
          0.3637964456262517*lm) + 
        CF*((0.04024114886984578 - 0.06614480829568213*lm)*NM + 
          (0.025962192648239544 - 0.06614480829568213*lm)*NL + 
          (0.07998696779973904 - 0.06614480829568213*lm)*NH))}, 
     {0.365, NC*(0.4142349338953714*CF^2 + CA*CF*(0.002635568406570264 + 
          0.36178279998732427*lm) + 
        CF*((0.040708769890969145 - 0.06577869090678623*lm)*NM + 
          (0.02631050297698112 - 0.06577869090678623*lm)*NL + 
          (0.07978969117099376 - 0.06577869090678623*lm)*NH))}, 
     {0.37, NC*(0.41256453034311596*CF^2 + CA*CF*(-0.0006483774217937835 + 
          0.3597699668523794*lm) + 
        CF*((0.04116724013271064 - 0.06541272124588716*lm)*NM + 
          (0.026653011328449185 - 0.06541272124588716*lm)*NL + 
          (0.07959080353803974 - 0.06541272124588716*lm)*NH))}, 
     {0.375, NC*(0.4108914339137796*CF^2 + CA*CF*(-0.0038875819127551126 + 
          0.3577586605302097*lm) + 
        CF*((0.04161659612250082 - 0.06504702918731085*lm)*NM + 
          (0.02698969830520715 - 0.06504702918731085*lm)*NL + 
          (0.0793903916198774 - 0.06504702918731085*lm)*NH))}, 
     {0.38, NC*(0.40921596314683595*CF^2 + CA*CF*(-0.007081731312414344 + 
          0.35574955650556284*lm) + 
        CF*((0.042056882389446076 - 0.06468173754646597*lm)*NM + 
          (0.027320552328154928 - 0.06468173754646597*lm)*NL + 
          (0.07918853927703114 - 0.06468173754646597*lm)*NH))}, 
     {0.385, NC*(0.40753841808773367*CF^2 + CA*CF*(-0.010230578878690225 + 
          0.35374329321331327*lm) + 
        CF*((0.04248815078885818 - 0.06431696240242059*lm)*NM + 
          (0.02764556906178225 - 0.06431696240242059*lm)*NL + 
          (0.07898532759410745 - 0.06431696240242059*lm)*NH))}, 
     {0.39, NC*(0.405859081926511*CF^2 + CA*CF*(-0.013333940365870751 + 
          0.3517404737352427*lm) + 
        CF*((0.042910459870757804 - 0.06395281340640777*lm)*NM + 
          (0.027964750874935666 - 0.06395281340640777*lm)*NL + 
          (0.07878083496055456 - 0.06395281340640777*lm)*NH))}, 
     {0.395, NC*(0.4041782224883354*CF^2 + CA*CF*(-0.016391689768851674 + 
          0.349741667422641*lm) + 
        CF*((0.043323874289664874 - 0.06358939407684382*lm)*NM + 
          (0.028278106334987826 - 0.06358939407684382*lm)*NL + 
          (0.07857513714961176 - 0.06358939407684382*lm)*NH))}, 
     {0.4, NC*(0.40249609358849014*CF^2 + CA*CF*(-0.01940375531273174 + 
          0.34774741144782395*lm) + 
        CF*((0.043728464253154825 - 0.06322680208142255*lm)*NM + 
          (0.02858564973342277 - 0.06322680208142255*lm)*NL + 
          (0.07836830739544229 - 0.06322680208142255*lm)*NH))}, 
     {0.405, NC*(0.4008129362633082*CF^2 + CA*CF*(-0.022370115674210583 + 
          0.34575821228755205*lm) + 
        CF*((0.04412430500680579 - 0.06286512950682764*lm)*NM + 
          (0.02888740064096843 - 0.06286512950682764*lm)*NL + 
          (0.07816041646844918 - 0.06286512950682764*lm)*NH))}, 
     {0.41, NC*(0.39912897988762513*CF^2 + CA*CF*(-0.02529079642197459 + 
          0.34377454714122324*lm) + 
        CF*((0.04451147635330782 - 0.06250446311658604*lm)*NM + 
          (0.029183383490518244 - 0.06250446311658604*lm)*NL + 
          (0.07795153274877863 - 0.06250446311658604*lm)*NH))}, 
     {0.415, NC*(0.39744444318846117*CF^2 + CA*CF*(-0.028165866663953803 + 
          0.3417968652866049*lm) + 
        CF*((0.0448900622036378 - 0.06214488459756453*lm)*NM + 
          (0.029473627186187883 - 0.06214488459756453*lm)*NL + 
          (0.07774172229801853 - 0.06214488459756453*lm)*NH))}, 
     {0.42, NC*(0.3957595351638507*CF^2 + CA*CF*(-0.030995435889993275 + 
          0.3398255893757631*lm) + 
        CF*((0.045260150158326413 - 0.06178647079559329*lm)*NM + 
          (0.02975816473695095 - 0.06178647079559329*lm)*NL + 
          (0.07753104892910506 - 0.06178647079559329*lm)*NH))}, 
     {0.425, NC*(0.394074455915017*CF^2 + CA*CF*(-0.03377965099911219 + 
          0.33786111667374474*lm) + 
        CF*((0.04562183111697349 - 0.06142929394068086*lm)*NM + 
          (0.030037032913389623 - 0.06142929394068086*lm)*NL + 
          (0.07731957427445232 - 0.06142929394068086*lm)*NH))}, 
     {0.43, NC*(0.3923893973994044*CF^2 + CA*CF*(-0.03651869350110777 + 
          0.33590382024246773*lm) + 
        CF*((0.04597519891425744 - 0.06107342186226686*lm)*NM + 
          (0.030310271926182904 - 0.06107342186226686*lm)*NL + 
          (0.0771073578523233 - 0.06107342186226686*lm)*NH))}, 
     {0.435, NC*(0.3907045441114881*CF^2 + CA*CF*(-0.03921277688283301 + 
          0.3339540500721757*lm) + 
        CF*((0.04632034998081688 - 0.06071891819494104*lm)*NM + 
          (0.03057792512503655 - 0.06071891819494104*lm)*NL + 
          (0.07689445713146292 - 0.06071891819494104*lm)*NH))}, 
     {0.44, NC*(0.3890200736976906*CF^2 + CA*CF*(-0.04186214412999618 + 
          0.3320121341627201*lm) + 
        CF*((0.046657383027457464 - 0.06036584257504001*lm)*NM + 
          (0.030840038716835362 - 0.06036584257504001*lm)*NL + 
          (0.07668092759401737 - 0.06036584257504001*lm)*NH))}, 
     {0.445, NC*(0.3873361575112307*CF^2 + CA*CF*(-0.044467065395838494 + 
          0.33007837955683933*lm) + 
        CF*((0.04698639875124383 - 0.06001425082851624*lm)*NM + 
          (0.031096661501870734 - 0.06001425082851624*lm)*NL + 
          (0.07646682279676206 - 0.06001425082851624*lm)*NH))}, 
     {0.45, NC*(0.38565296111223735*CF^2 + CA*CF*(-0.0470278358085162 + 
          0.328153073327518*lm) + 
        CF*((0.04730749956211525 - 0.05966419515045781*lm)*NM + 
          (0.03134784462706402 - 0.05966419515045781*lm)*NL + 
          (0.07625219443066762 - 0.05966419515045781*lm)*NH))}, 
     {0.455, NC*(0.3839706447180358*CF^2 + CA*CF*(-0.049544773409466746 + 
          0.3262364835214205*lm) + 
        CF*((0.04762078932875572 - 0.0593157242766219*lm)*NM + 
          (0.031593641355170045 - 0.0593157242766219*lm)*NL + 
          (0.07603709237883002 - 0.0593157242766219*lm)*NH))}, 
     {0.46, NC*(0.382289363608083*CF^2 + CA*CF*(-0.05201821721545327 + 
          0.3243288600603133*lm) + 
        CF*((0.047926373142509374 - 0.05896888364732969*lm)*NM + 
          (0.031834106849005187 - 0.05896888364732969*lm)*NL + 
          (0.07582156477279443 - 0.05896888364732969*lm)*NH))}, 
     {0.465, NC*(0.38060926848768306*CF^2 + CA*CF*(-0.05444852539739386 + 
          0.3224304356023083*lm) + 
        CF*((0.04822435709822497 - 0.058623715564056045*lm)*NM + 
          (0.03206929796980069 - 0.058623715564056045*lm)*NL + 
          (0.07560565804730295 - 0.058623715564056045*lm)*NH))}, 
     {0.47, NC*(0.37893050581424903*CF^2 + CA*CF*(-0.05683607356945158 + 
          0.32054142636468297*lm) + 
        CF*((0.04851484809096456 - 0.05828025933903327*lm)*NM + 
          (0.032299273088835026 - 0.05828025933903327*lm)*NL + 
          (0.07538941699349713 - 0.05828025933903327*lm)*NH))}, 
     {0.475, NC*(0.37725321808957096*CF^2 + CA*CF*(-0.05918125318222343 + 
          0.31866203290996065*lm) + 
        CF*((0.0487979536275838 - 0.05793855143817466*lm)*NM + 
          (0.03252409191154907 - 0.05793855143817466*lm)*NL + 
          (0.07517288481060552 - 0.05793855143817466*lm)*NH))}, 
     {0.48, NC*(0.37557754412125655*CF^2 + CA*CF*(-0.06148447001420446 + 
          0.31679244089685926*lm) + 
        CF*((0.04907378165224926 - 0.057598625617610776*lm)*NM + 
          (0.032743815313394646 - 0.057598625617610776*lm)*NL + 
          (0.07495610315615045 - 0.057598625617610776*lm)*NH))}, 
     {0.485, NC*(0.37390361925624455*CF^2 + CA*CF*(-0.06374614275602238 + 
          0.3149328217976525*lm) + 
        CF*((0.04934244038501496 - 0.05726051305411864*lm)*NM + 
          (0.03295850518671127 - 0.05726051305411864*lm)*NL + 
          (0.07473911219470365 - 0.05726051305411864*lm)*NH))}, 
     {0.49, NC*(0.3722315755890437*CF^2 + CA*CF*(-0.06596670168224067 + 
          0.3130833335834177*lm) + 
        CF*((0.04960403817263258 - 0.05692424246971232*lm)*NM + 
          (0.03316822429796751 - 0.05692424246971232*lm)*NL + 
          (0.07452195064522513 - 0.05692424246971232*lm)*NH))}, 
     {0.495, NC*(0.3705615421471246*CF^2 + CA*CF*(-0.06814658740581418 + 
          0.3112441213785841*lm) + 
        CF*((0.04985868335082085 - 0.05658984025065165*lm)*NM + 
          (0.03337303615474227 - 0.05658984025065165*lm)*NL + 
          (0.07430465582701662 - 0.05658984025065165*lm)*NH))}, 
     {0.5, CF*NC*(0.36889364556153864*CF + CA*(-0.07028624977476385 + 
          0.30941531799795635*lm) + 0.050106484115785485*NM - 
        0.05625733054508297*lm*NM + 0.03357300487634453*NL - 
        0.05625733054508297*lm*NL + 0.07408726369975129*NH - 
        0.05625733054508297*lm*NH)}, 
     {0.505, CF*NC*(0.36722800807907185*CF + CA*(-0.07238614650693499 + 
          0.307597044916014*lm) + 0.05034754841343052*NM - 
        0.05592673543927527*lm*NM + 0.033768195101755105*NL - 
        0.05592673543927527*lm*NL + 0.07386980892604283*NH - 
        0.05592673543927527*lm*NH)}, 
     {0.51, CF*NC*(0.3655647510820178*CF + CA*(-0.07444674259738807 + 
          0.3057894122456603*lm) + 0.05058198382217097*NM - 
        0.05559807495375642*lm*NM + 0.03395867184565958*NL - 
        0.05559807495375642*lm*NL + 0.07365232488278943*NH - 
        0.05559807495375642*lm*NH)}, 
     {0.515, CF*NC*(0.3639039927956585*CF + CA*(-0.07646850905221966 + 
          0.30399251970316704*lm) + 0.05080989746089647*NM - 
        0.05527136721875764*lm*NM + 0.0341445004248744*NL - 
        0.05527136721875764*lm*NL + 0.07343484372367577*NH - 
        0.05527136721875764*lm*NH)}, 
     {0.52, CF*NC*(0.36224584903476514*CF + CA*(-0.07845192207414951 + 
          0.3022064570155322*lm) + 0.05103139589670396*NM - 
        0.05494662854827859*lm*NM + 0.034325746358919614*NL - 
        0.05494662854827859*lm*NL + 0.07321739641284702*NH - 
        0.05494662854827859*lm*NH)}, 
     {0.525, CF*NC*(0.360590433292169*CF + CA*(-0.08039746222375196 + 
          0.3004313044172814*lm) + 0.05124658506208546*NM - 
        0.0546238735304148*lm*NM + 0.03450247528423899*NL - 
        0.0546238735304148*lm*NL + 0.07300001276323237*NH - 
        0.0546238735304148*lm*NH)}, 
     {0.53, CF*NC*(0.3589378568165442*CF + CA*(-0.0823056136357179 + 
          0.29866713312487675*lm) + 0.05145557017931746*NM - 
        0.05430311511361395*lm*NM + 0.03467475287470425*NL - 
        0.05430311511361395*lm*NL + 0.07278272147370722*NH - 
        0.05430311511361395*lm*NH)}, 
     {0.535, CF*NC*(0.35728822868056515*CF + CA*(-0.08417686328701764 + 
          0.2969140057897259*lm) + 0.05165845569158186*NM - 
        0.05398436468904107*lm*NM + 0.034842644768018786*NL - 
        0.05398436468904107*lm*NL + 0.07256555016512474*NH - 
        0.05398436468904107*lm*NH)}, 
     {0.54, CF*NC*(0.3556416558404941*CF + CA*(-0.08601170031400801 + 
          0.2951719769307371*lm) + 0.05185534520037736*NM - 
        0.05366763216922493*lm*NM + 0.03500621649765887*NL - 
        0.05366763216922493*lm*NL + 0.07234852541524724*NH - 
        0.05366763216922493*lm*NH)}, 
     {0.545, CF*NC*(0.35399824318816236*CF + CA*(-0.08781061537568867 + 
          0.2934410933473268*lm) + 0.05204634140880716*NM - 
        0.053352926063150334*lm*NM + 0.03516553343001177*NL - 
        0.053352926063150334*lm*NL + 0.0721316727926071*NH - 
        0.053352926063150334*lm*NH)}, 
     {0.55, CF*NC*(0.35235809359621634*CF + CA*(-0.0895741000604672 + 
          0.2917213945137448*lm) + 0.05223154607035371*NM - 
        0.053040253547953595*lm*NM + 0.03532066070638999*NL - 
        0.053040253547953595*lm*NL + 0.07191501688932671*NH - 
        0.053040253547953595*lm*NH)}, 
     {0.555, CF*NC*(0.3507213079574237*CF + CA*(-0.0913026463339373 + 
          0.2900129129555449*lm) + 0.05241105994277546*NM - 
        0.0527296205373718*lm*NM + 0.035471663189620015*NL - 
        0.0527296205373718*lm*NL + 0.0716985813529262*NH - 
        0.0527296205373718*lm*NH)}, 
     {0.56, CF*NC*(0.34908798521875556*CF + CA*(-0.09299674602531177 + 
          0.28831567460899227*lm) + 0.05258498274678248*NM - 
        0.0524210317470895*lm*NM + 0.03561860541492125*NL - 
        0.0524210317470895*lm*NL + 0.0714823889171473*NH - 
        0.0524210317470895*lm*NH)}, 
     {0.565, CF*NC*(0.3474582224108983*CF + CA*(-0.09465689035028199 + 
          0.2866296991641626*lm) + 0.052753413129169216*NM - 
        0.05211449075712047*lm*NM + 0.03576155154480801*NL - 
        0.05211449075712047*lm*NL + 0.07126646143182107*NH - 
        0.05211449075712047*lm*NH)}, 
     {0.57, CF*NC*(0.3458321146737816*CF + CA*(-0.0962835694681977 + 
          0.28495500039245664*lm) + 0.052916448630101996*NM - 
        0.05181000007135575*lm*NM + 0.035900565327762826*NL - 
        0.05181000007135575*lm*NL + 0.07105081989180664*NH - 
        0.05181000007135575*lm*NH)}, 
     {0.575, CF*NC*(0.34420975527865505*CF + CA*(-0.09787727207157754 + 
          0.28329158645922004*lm) + 0.05307418565427768*NM - 
        0.051507561174403645*lm*NM + 0.03603571006044421*NL - 
        0.051507561174403645*lm*NL + 0.07083548446502769*NH - 
        0.051507561174403645*lm*NH)}, 
     {0.58, CF*NC*(0.34259123564719307*CF + CA*(-0.09943848500606964 + 
          0.28163946022212916*lm) + 0.053226719445687215*NM - 
        0.05120717458584167*lm*NM + 0.036167048553206065*NL - 
        0.05120717458584167*lm*NL + 0.07062047451963245*NH - 
        0.05120717458584167*lm*NH)}, 
     {0.585, CF*NC*(0.34097664536805977*CF + CA*(-0.10096769291908574 + 
          0.2799986195159733*lm) + 0.05337414406573436*NM - 
        0.05090883991199515*lm*NM + 0.03629464309871895*NL - 
        0.05090883991199515*lm*NL + 0.07040580865030309*NH - 
        0.05090883991199515*lm*NH)}, 
     {0.59, CF*NC*(0.33936607221132103*CF + CA*(-0.10246537793542973 + 
          0.2783690574244367*lm) + 0.053516552374474925*NM - 
        0.05061255589535213*lm*NM + 0.03641855544349582*NL - 
        0.05061255589535213*lm*NL + 0.0701915047037389*NH - 
        0.05061255589535213*lm*NH)}, 
     {0.595, CF*NC*(0.33775960214105305*CF + CA*(-0.10393201935833457 + 
          0.27675076253945596*lm) + 0.05365403601475684*NM - 
        0.05031832046171927*lm*NM + 0.0365388467621364*NL - 
        0.05031832046171927*lm*NL + 0.06997757980333795*NH - 
        0.05031832046171927*lm*NH)}, 
     {0.6, CF*NC*(0.33615731932645826*CF + CA*(-0.1053680933944084 + 
          0.27514371920870473*lm) + 0.05378668539905453*NM - 
        0.050026130765219036*lm*NM + 0.03665557763411559*NL - 
        0.050026130765219036*lm*NL + 0.06976405037310066*NH - 
        0.050026130765219036*lm*NH)}, 
     {0.605, CF*NC*(0.3345593061517675*CF + CA*(-0.10677407290107416 + 
          0.2735479077717306*lm) + 0.05391458969880423*NM - 
        0.049735983231223746*lm*NM + 0.03676880802295117*NL - 
        0.049735983231223746*lm*NL + 0.06955093216077854*NH - 
        0.049735983231223746*lm*NH)}, 
     {0.61, CF*NC*(0.3329656432251757*CF + CA*(-0.10815042715516444 + 
          0.27196330478524877*lm) + 0.05403783683605857*NM - 
        0.049447873597317955*lm*NM + 0.03687859725759633*NL - 
        0.049447873597317955*lm*NL + 0.06933824026029066*NH - 
        0.049447873597317955*lm*NH)}, 
     {0.615, CF*NC*(0.33137640938703256*CF + CA*(-0.10949762164140786 + 
          0.27038988323807184*lm) + 0.054156513477290474*NM - 
        0.0491617969523767*lm*NM + 0.03698500401591127*NL - 
        0.0491617969523767*lm*NL + 0.06912598913342978*NH - 
        0.0491617969523767*lm*NH)}, 
     {0.62, CF*NC*(0.32979168171748247*CF + CA*(-0.1108161178596128 + 
          0.2688276127561364*lm) + 0.054270705029186656*NM - 
        0.04887774777384299*lm*NM + 0.03708808631007691*NL - 
        0.04887774777384299*lm*NL + 0.0689141926308795*NH - 
        0.04887774777384299*lm*NH)}, 
     {0.625, CF*NC*(0.3282115355437261*CF + CA*(-0.11210637314942055 + 
          0.2672764597980649*lm) + 0.05438049563628123*NM - 
        0.048595719963284524*lm*NM + 0.03718790147382197*NL - 
        0.048595719963284524*lm*NL + 0.06870286401256352*NH - 
        0.048595719963284524*lm*NH)}, 
     {0.63, CF*NC*(0.3266360444470554*CF + CA*(-0.1133688405315624 + 
          0.2657363878416823*lm) + 0.05448596818028931*NM - 
        0.04831570688030588*lm*NM + 0.0372845061513422*NL - 
        0.04831570688030588*lm*NL + 0.06849201596734697*NH - 
        0.04831570688030588*lm*NH)}, 
     {0.635, CF*NC*(0.32506528026979364*CF + CA*(-0.1146039685646142 + 
          0.26420735756188973*lm) + 0.054587204281009265*NM - 
        0.048037701374889046*lm*NM + 0.03737795628779773*NL - 
        0.048037701374889046*lm*NL + 0.0682816606321099*NH - 
        0.048037701374889046*lm*NH)}, 
     {0.64, CF*NC*(0.32349931312225716*CF + CA*(-0.11581220121629811 + 
          0.2626893270002771*lm) + 0.054684284298670616*NM - 
        0.047761695818232204*lm*NM + 0.037468307121281394*NL - 
        0.047761695818232204*lm*NL + 0.06807180961021195*NH - 
        0.047761695818232204*lm*NH)}, 
     {0.645, CF*NC*(0.32193821138983664*CF + CA*(-0.11699397774843348 + 
          0.26118225172684184*lm) + 0.05477728733761236*NM - 
        0.04748768213215306*lm*NM + 0.03755561317615732*NL - 
        0.04748768213215306*lm*NL + 0.06786247398936698*NH - 
        0.04748768213215306*lm*NH)}, 
     {0.65, CF*NC*(0.32038204174028495*CF + CA*(-0.11814973261468954 + 
          0.25968608499416423*lm) + 0.0548662912511839*NM - 
        0.047215651817120764*lm*NM + 0.03763992825767486*NL - 
        0.047215651817120764*lm*NL + 0.06765366435894585*NH - 
        0.047215651817120764*lm*NH)}, 
     {0.655, CF*NC*(0.3188308691312843*CF + CA*(-0.11927989537033899 + 
          0.25820077788437296*lm) + 0.0549513726477675*NM - 
        0.0469455959789769*lm*NM + 0.03772130544776893*NL - 
        0.0469455959789769*lm*NL + 0.0674453908267249*NH - 
        0.0469455959789769*lm*NH)}, 
     {0.66, CF*NC*(0.317284756818353*CF + CA*(-0.12038489059325692 + 
          0.2567262794492221*lm) + 0.055032606897827935*NM - 
        0.046677505354404014*lm*NM + 0.03779979710196295*NL - 
        0.046677505354404014*lm*NL + 0.06723766303509761*NH - 
        0.046677505354404014*lm*NH)}, 
     {0.665, CF*NC*(0.31574376636314433*CF + CA*(-0.12146513781545143 + 
          0.25526253684358424*lm) + 0.05511006814190077*NM - 
        0.046411370335197134*lm*NM + 0.03787545484729568*NL - 
        0.046411370335197134*lm*NL + 0.0670304901767657*NH - 
        0.046411370335197134*lm*NH)}, 
     {0.67, CF*NC*(0.3142079576421783*CF + CA*(-0.12252105146445211 + 
          0.2538094954526524*lm) + 0.055183829299436604*NM - 
        0.04614718099139135*lm*NM + 0.037948329581198016*NL - 
        0.04614718099139135*lm*NL + 0.06682388100992624*NH - 
        0.04614718099139135*lm*NH)}, 
     {0.675, CF*NC*(0.31267738885603963*CF + CA*(-0.1235530408139208 + 
          0.2523670990131301*lm) + 0.05525396207842415*NM - 
        0.045884927093296383*lm*NM + 0.03801847147125026*NL - 
        0.045884927093296383*lm*NL + 0.06661784387297044*NH - 
        0.045884927093296383*lm*NH)}, 
     {0.68, CF*NC*(0.3111521165390689*CF + CA*(-0.12456150994288405 + 
          0.2509352897286764*lm) + 0.055320536985719634*NM - 
        0.045624598132486614*lm*NM + 0.038085929955754626*NL - 
        0.045624598132486614*lm*NL + 0.06641238669870912*NH - 
        0.045624598132486614*lm*NH)}, 
     {0.685, CF*NC*(0.30963219556956434*CF + CA*(-0.12554685770302135 + 
          0.24951400837986132*lm) + 0.055383623338015164*NM - 
        0.045366183341792966*lm*NM + 0.03815075374506157*NL - 
        0.045366183341792966*lm*NL + 0.06620751702814019*NH - 
        0.045366183341792966*lm*NH)}, 
     {0.69, CF*NC*(0.30811767918050953*CF + CA*(-0.12650947769347423 + 
          0.24810319442887535*lm) + 0.05544328927338307*NM - 
        0.04510967171434097*lm*NM + 0.03821299082359251*NL - 
        0.04510967171434097*lm*NL + 0.06600324202377209*NH - 
        0.04510967171434097*lm*NH)}, 
     {0.695, CF*NC*(0.306608618970833*CF + CA*(-0.12744975824267235 + 
          0.2467027861192263*lm) + 0.0554996017633372*NM - 
        0.04485505202167751*lm*NM + 0.03827268845250483*NL - 
        0.04485505202167751*lm*NL + 0.06579956848251739*NH - 
        0.04485505202167751*lm*NH)}, 
     {0.7, CF*NC*(0.30510506491720474*CF + CA*(-0.12836808239670056 + 
          0.2453127205706464*lm) + 0.05555262662535636*NM - 
        0.04460231283102662*lm*NM + 0.038329893172948395*NL - 
        0.04460231283102662*lm*NL + 0.06559650284817019*NH - 
        0.04460231283102662*lm*NH)}, 
     {0.705, CF*NC*(0.3036070653863672*CF + CA*(-0.1292648279137586 + 
          0.24393293386942266*lm) + 0.0556024285358187*NM - 
        0.04435144252171321*lm*NM + 0.038384650809866035*NL - 
        0.04435144252171321*lm*NL + 0.06539405122348012*NH - 
        0.04435144252171321*lm*NH)}, 
     {0.71, CF*NC*(0.30211466714799756*CF + CA*(-0.13014036726429004 + 
          0.24256336115435417*lm) + 0.05564907104329919*NM - 
        0.04410242930079167*lm*NM + 0.038437006476293355*NL - 
        0.04410242930079167*lm*NL + 0.06519221938183617*NH - 
        0.04410242930079167*lm*NH)}, 
     {0.715, CF*NC*(0.30062791538809286*CF + CA*(-0.1309950676363815 + 
          0.2412039366985311*lm) + 0.05569261658218585*NM - 
        0.04385526121791475*lm*NM + 0.03848700457811587*NL - 
        0.04385526121791475*lm*NL + 0.06499101277857235*NH - 
        0.04385526121791475*lm*NH)}, 
     {0.72, CF*NC*(0.2991468537228677*CF + CA*(-0.13182929094605622 + 
          0.23985459398712136*lm) + 0.05573312648657309*NM - 
        0.04360992617947661*lm*NM + 0.03853468881924435*NL - 
        0.04360992617947661*lm*NL + 0.0647904365619073*NH - 
        0.04360992617947661*lm*NH)}, 
     {0.725, CF*NC*(0.2976715242131517*CF + CA*(-0.13264339385210727 + 
          0.23851526579134297*lm) + 0.055770661004393894*NM - 
        0.043366411962062354*lm*NM + 0.03858010220717135*NL - 
        0.043366411962062354*lm*NL + 0.06459049558352961*NH - 
        0.043366411962062354*lm*NH)}, 
     {0.73, CF*NC*(0.2962019673792718*CF + CA*(-0.1334377277751362 + 
          0.23718588423879217*lm) + 0.05580527931175471*NM - 
        0.04312470622523494*lm*NM + 0.038623287058874675*NL - 
        0.04312470622523494*lm*NL + 0.06439119440883986*NH - 
        0.04312470622523494*lm*NH)}, 
     {0.735, CF*NC*(0.2947382222164031*CF + CA*(-0.13421263892048269 + 
          0.2358663808802899*lm) + 0.05583703952743995*NM - 
        0.042884796523689074*lm*NM + 0.038664285007035205*NL - 
        0.042884796523689074*lm*NL + 0.06419253732686062*NH - 
        0.042884796523689074*lm*NH)}, 
     {0.74, CF*NC*(0.29328032621036954*CF + CA*(-0.13496846830474807 + 
          0.23455668675340224*lm) + 0.05586599872755499*NM - 
        0.04264667031880041*lm*NM + 0.038703137006539025*NL - 
        0.04264667031880041*lm*NL + 0.06399452835982465*NH - 
        0.04264667031880041*lm*NH)}, 
     {0.745, CF*NC*(0.29182831535387554*CF + CA*(-0.13570555178563418 + 
          0.23325673244278294*lm) + 0.055892212960279096*NM - 
        0.042410314989596895*lm*NM + 0.038739883341235355*NL - 
        0.042410314989596895*lm*NL + 0.063797171272452*NH - 
        0.042410314989596895*lm*NH)}, 
     {0.75, CF*NC*(0.29038222416314885*CF + CA*(-0.13642422009483388 + 
          0.23196644813748094*lm) + 0.0559157372607016*NM - 
        0.04217571784317835*lm*NM + 0.03877456363092391*NL - 
        0.04217571784317835*lm*NL + 0.0636004695809255*NH - 
        0.04217571784317835*lm*NH)}, 
     {0.755, CF*NC*(0.2889420856949722*CF + CA*(-0.13712479887372622 + 
          0.23068576368534793*lm) + 0.05593662566571658*NM - 
        0.041942866124608714*lm*NM + 0.038807216838546814*NL - 
        0.041942866124608714*lm*NL + 0.06340442656157465*NH - 
        0.041942866124608714*lm*NH)}, 
     {0.76, CF*NC*(0.28750793156408366*CF + CA*(-0.137807608711643 + 
          0.2294146086446765*lm) + 0.05595493122895342*NM - 
        0.04171174702630482*lm*NM + 0.03883788127756195*NL - 
        0.04171174702630482*lm*NL + 0.06320904525927701*NH - 
        0.04171174702630482*lm*NH)}, 
     {0.765, CF*NC*(0.2860797919609229*CF + CA*(-0.1384729651864879 + 
          0.2281529123331924*lm) + 0.05597070603572198*NM - 
        0.041482347696944075*lm*NM + 0.038866594619475954*NL - 
        0.041482347696944075*lm*NL + 0.06301432849558633*NH - 
        0.041482347696944075*lm*NH)}, 
     {0.77, CF*NC*(0.2846576956697007*CF + CA*(-0.1391211789075018 + 
          0.2269006038745202*lm) + 0.05598400121795308*NM - 
        0.041254655249912765*lm*NM + 0.03889339390151685*NL - 
        0.041254655249912765*lm*NL + 0.06282027887659593*NH - 
        0.041254655249912765*lm*NH)}, 
     {0.775, CF*NC*(0.28324167008677037*CF + CA*(-0.13975255555998065 + 
          0.22565761224223585*lm) + 0.05599486696911608*NM - 
        0.04102865677131561*lm*NM + 0.03891831553442723*NL - 
        0.04102865677131561*lm*NL + 0.06262689880054614*NH - 
        0.04102865677131561*lm*NH)}, 
     {0.78, CF*NC*(0.28183174123927723*CF + CA*(-0.14036739595176373 + 
          0.22442386630161398*lm) + 0.05600335255909742*NM - 
        0.04080433932756618*lm*NM + 0.03894139531036045*NL - 
        0.04080433932756618*lm*NL + 0.062434190465183746*NH - 
        0.04080433932756618*lm*NH)}, 
     {0.785, CF*NC*(0.28042793380406517*CF + CA*(-0.1409659960613214 + 
          0.22319929484917483*lm) + 0.05600950634902446*NM - 
        0.040581689972577245*lm*NM + 0.0389626684108635*NL - 
        0.040581689972577245*lm*NL + 0.0622421558748815*NH - 
        0.040581689972577245*lm*NH)}, 
     {0.79, CF*NC*(0.2790302711268165*CF + CA*(-0.14154864708728135 + 
          0.22198382665012914*lm) + 0.0560133758060211*NM - 
        0.04036069575456894*lm*NM + 0.038982169414931135*NL - 
        0.04036069575456894*lm*NL + 0.062050796847525555*NH - 
        0.04036069575456894*lm*NH)}, 
     {0.795, CF*NC*(0.2776387752414047*CF + CA*(-0.14211563549924253 + 
          0.2207773904738162*lm) + 0.056015007517882055*NM - 
        0.04014134372251204*lm*NM + 0.038999932307117006*NL - 
        0.04014134372251204*lm*NL + 0.06186011502117799*NH - 
        0.04014134372251204*lm*NH)}, 
     {0.8, CF*NC*(0.2762534668894368*CF + CA*(-0.1426672430897354 + 
          0.21957991512722608*lm) + 0.0560144472076543*NM - 
        0.039923620932222924*lm*NM + 0.03901599048568871*NL - 
        0.039923620932222924*lm*NL + 0.06167011186052193*NH - 
        0.039923620932222924*lm*NH)}, 
     {0.805, CF*NC*(0.27487436553996547*CF + CA*(-0.1432037470271957 + 
          0.21839132948669213*lm) + 0.05601173974811492*NM - 
        0.03970751445212584*lm*NM + 0.039030376770814314*NL - 
        0.03970751445212584*lm*NL + 0.061480788663096114*NH - 
        0.03970751445212584*lm*NH)}, 
     {0.81, CF*NC*(0.27350148940934893*CF + CA*(-0.14372541990982687 + 
          0.21721156252783755*lm) + 0.05600692917613573*NM - 
        0.039493011368697734*lm*NM + 0.03904312341276887*NL - 
        0.039493011368697734*lm*NL + 0.06129214656532577*NH - 
        0.039493011368697734*lm*NH)}, 
     {0.815, CF*NC*(0.27213485548123884*CF + CA*(-0.144232529820235 + 
          0.21604054335385445*lm) + 0.05600005870692569*NM - 
        0.0392800987916099*lm*NM + 0.039054262100150484*NL - 
        0.0392800987916099*lm*NL + 0.06110418654835626*NH - 
        0.0392800987916099*lm*NH)}, 
     {0.82, CF*NC*(0.2707744795266758*CF + CA*(-0.1447253403807267 + 
          0.21487820122219217*lm) + 0.05599117074814335*NM - 
        0.0390687638585804*lm*NM + 0.03906382396809599*NL - 
        0.0390687638585804*lm*NL + 0.06091690944369598*NH - 
        0.0390687638585804*lm*NH)}, 
     {0.825, CF*NC*(0.2694203761242739*CF + CA*(-0.14520411080916787 + 
          0.21372446556972655*lm) + 0.05598030691387197*NM - 
        0.03885899373995028*lm*NM + 0.03907183960648709*NL - 
        0.03885899373995028*lm*NL + 0.06073031593867454*NH - 
        0.03885899373995028*lm*NH)}, 
     {0.83, CF*NC*(0.26807255868047425*CF + CA*(-0.1456690959753074 + 
          0.21257926603648*lm) + 0.055967508038450825*NM - 
        0.03865077564299637*lm*NM + 0.03907833906813866*NL - 
        0.03865077564299637*lm*NL + 0.060544406581722304*NH - 
        0.03865077564299637*lm*NH)}, 
     {0.835, CF*NC*(0.2667310394498509*CF + CA*(-0.14612054645747694 + 
          0.21144253248795886*lm) + 0.055952814190157074*NM - 
        0.03844409681599252*lm*NM + 0.03908335187696139*NL - 
        0.03844409681599252*lm*NL + 0.06035918178747691*NH - 
        0.03844409681599252*lm*NH)}, 
     {0.84, CF*NC*(0.2653958295554498*CF + CA*(-0.1465587085995826 + 
          0.2103141950361707*lm) + 0.055936264684732846*NM - 
        0.038238944552031036*lm*NM + 0.03908690703609158*NL - 
        0.038238944552031036*lm*NL + 0.060174641841722463*NH - 
        0.038238944552031036*lm*NH)}, 
     {0.845, CF*NC*(0.2640669390091454*CF + CA*(-0.14698382456831105 + 
          0.209194184059383*lm) + 0.055917898098753076*NM - 
        0.038035306192615095*lm*NM + 0.03908903303598148*NL - 
        0.038035306192615095*lm*NL + 0.05999078690616681*NH - 
        0.038035306192615095*lm*NH)}, 
     {0.85, CF*NC*(0.26274437673199746*CF + CA*(-0.14739613241047728 + 
          0.2080824302206811*lm) + 0.055897752282830115*NM - 
        0.03783316913103293*lm*NM + 0.0390897578624442*NL - 
        0.03783316913103293*lm*NL + 0.05980761702306201*NH - 
        0.03783316913103293*lm*NH)}, 
     {0.855, CF*NC*(0.26142815057459273*CF + CA*(-0.14779586611044584 + 
          0.20697886448537997*lm) + 0.05587586437465148*NM - 
        0.03763252081552363*lm*NM + 0.03908910900464752*NL - 
        0.03763252081552363*lm*NL + 0.059625132119673144*NH - 
        0.03763252081552363*lm*NH)}, 
     {0.86, CF*NC*(0.2601182673373566*CF + CA*(-0.1481832556475631 + 
          0.20588341813734434*lm) + 0.055852270811847925*NM - 
        0.037433348752244425*lm*NM + 0.039087113463051555*NL - 
        0.037433348752244425*lm*NL + 0.059443332012600374*NH - 
        0.037433348752244425*lm*NH)}, 
     {0.865, CF*NC*(0.25881473279081973*CF + CA*(-0.1485585270535415 + 
          0.20479602279426648*lm) + 0.05582700734468909*NM - 
        0.03723564050804845*lm*NM + 0.03908379775728562*NL - 
        0.03723564050804845*lm*NL + 0.059262216411958966*NH - 
        0.03723564050804845*lm*NH)}, 
     {0.87, CF*NC*(0.25751755169582663*CF + CA*(-0.14892190246974105 + 
          0.203716610421951*lm) + 0.055800109048604635*NM - 
        0.037039383713082*lm*NM + 0.039079187933960056*NL - 
        0.037039383713082*lm*NL + 0.05908178492542182*NH - 
        0.037039383713082*lm*NH)}, 
     {0.875, CF*NC*(0.25622672782367206*CF + CA*(-0.1492736002042982 + 
          0.20264511334765262*lm) + 0.055771610336529144*NM - 
        0.036844566063209565*lm*NM + 0.03907330957440917*NL - 
        0.036844566063209565*lm*NL + 0.05890203706212903*NH - 
        0.036844566063209565*lm*NH)}, 
     {0.88, CF*NC*(0.25494226397615327*CF + CA*(-0.1496138347890542 + 
          0.20158146427251142*lm) + 0.055741544971069285*NM - 
        0.036651175322274805*lm*NM + 0.03906618780236177*NL - 
        0.036651175322274805*lm*NL + 0.058722972236468704*NH - 
        0.036651175322274805*lm*NH)}, 
     {0.885, CF*NC*(0.2536641620055262*CF + CA*(-0.14994281703624063 + 
          0.2005255962831279*lm) + 0.055709946076492226*NM - 
        0.03645919932420508*lm*NM + 0.039057847291536184*NL - 
        0.03645919932420508*lm*NL + 0.05854458977173325*NH - 
        0.03645919932420508*lm*NH)}, 
     {0.89, CF*NC*(0.2523924228343538*CF + CA*(-0.1502607540948809 + 
          0.19947744286231833*lm) + 0.055676846150534476*NM - 
        0.036268625974966974*lm*NM + 0.0390483122731569*NL - 
        0.036268625974966974*lm*NL + 0.05836688890365509*NH - 
        0.036268625974966974*lm*NH)}, 
     {0.895, CF*NC*(0.251127046475236*CF + CA*(-0.15056784950687158 + 
          0.19843693789908914*lm) + 0.0556422770760307*NM - 
        0.036079443254379846*lm*NM + 0.03903760654339034*NL - 
        0.036079443254379846*lm*NL + 0.05818986878382578*NH - 
        0.036079443254379846*lm*NH)}, 
     {0.9, CF*NC*(0.249868032050411*CF + CA*(-0.15086430326270883 + 
          0.19740401569786772*lm) + 0.05560627013236228*NM - 
        0.03589163921779413*lm*NM + 0.03902575347069744*NL - 
        0.03589163921779413*lm*NL + 0.05801352848300224*NH - 
        0.03589163921779413*lm*NH)}, 
     {0.905, CF*NC*(0.2486153778112189*CF + CA*(-0.15115031185682912 + 
          0.19637861098702442*lm) + 0.05556885600672557*NM - 
        0.0357052019976408*lm*NM + 0.03901277600310113*NL - 
        0.0357052019976408*lm*NL + 0.057837866994303724*NH - 
        0.0357052019976408*lm*NH)}, 
     {0.91, CF*NC*(0.2473690811574171*CF + CA*(-0.1514260683425346 + 
          0.1953606589267204*lm) + 0.055530064805220214*NM - 
        0.03552011980485825*lm*NM + 0.03899869667536689*NL - 
        0.03552011980485825*lm*NL + 0.057662883236303156*NH - 
        0.03552011980485825*lm*NH)}, 
     {0.915, CF*NC*(0.2461291386563408*CF + CA*(-0.15169176238647808 + 
          0.19435009511611295*lm) + 0.05548992606375785*NM - 
        0.03533638093020235*lm*NM + 0.03898353761609492*NL - 
        0.03533638093020235*lm*NL + 0.05748857605601616*NH - 
        0.03533638093020235*lm*NH)}, 
     {0.92, CF*NC*(0.24489554606189917*CF + CA*(-0.15194758032268205 + 
          0.19334685559995*lm) + 0.05544846875879188*NM - 
        0.03515397374544545*lm*NM + 0.03896732055472255*NL - 
        0.03515397374544545*lm*NL + 0.05731494423179107*NH - 
        0.03515397374544545*lm*NH)}, 
     {0.925, CF*NC*(0.24366829833340042*CF + CA*(-0.15219370520607112 + 
          0.1923508768745827*lm) + 0.055405721317869125*NM - 
        0.03497288670446958*lm*NM + 0.0389500668284359*NL - 
        0.03497288670446958*lm*NL + 0.05714198647610324*NH - 
        0.03497288670446958*lm*NH)}, 
     {0.93, CF*NC*(0.24244738965419857*CF + CA*(-0.15243031686549743 + 
          0.19136209589342487*lm) + 0.055361711630004376*NM - 
        0.03479310834425907*lm*NM + 0.03893179738898964*NL - 
        0.03479310834425907*lm*NL + 0.056969701438256595*NH - 
        0.03479310834425907*lm*NH)}, 
     {0.935, CF*NC*(0.24123281345015551*CF + CA*(-0.15265759195624082 + 
          0.19038045007188634*lm) + 0.055316467055878844*NM - 
        0.03461462728579752*lm*NM + 0.03891253280943439*NL - 
        0.03461462728579752*lm*NL + 0.05679808770699556*NH - 
        0.03461462728579752*lm*NH)}, 
     {0.94, CF*NC*(0.24002456240791212*CF + CA*(-0.15287570401196823 + 
          0.18940587729180575*lm) + 0.055270014437863856*NM - 
        0.03443743223487377*lm*NM + 0.03889229329075085*NL - 
        0.03443743223487377*lm*NL + 0.05662714381303013*NH - 
        0.03443743223487377*lm*NH)}, 
     {0.945, CF*NC*(0.2388226284929632*CF + CA*(-0.15308482349613742 + 
          0.18843831590540766*lm) + 0.05522238010987113*NM - 
        0.0342615119828014*lm*NM + 0.03887109866839058*NL - 
        0.0342615119828014*lm*NL + 0.05645686823147697*NH - 
        0.0342615119828014*lm*NH)}, 
     {0.95, CF*NC*(0.23762700296753062*CF + CA*(-0.15328511785283194 + 
          0.187477704738808*lm) + 0.05517358990703115*NM - 
        0.034086855407056006*lm*NM + 0.038848968418722714*NL - 
        0.034086855407056006*lm*NL + 0.056287259384219294*NH - 
        0.034086855407056006*lm*NH)}, 
     {0.955, CF*NC*(0.2364376764082303*CF + CA*(-0.1534767515570165 + 
          0.18652398309508977*lm) + 0.05512366917520111*NM - 
        0.033913451471834506*lm*NM + 0.03882592166538677*NL - 
        0.033913451471834506*lm*NL + 0.05611831564218801*NH - 
        0.033913451471834506*lm*NH)}, 
     {0.96, CF*NC*(0.23525463872352875*CF + CA*(-0.153659886164202 + 
          0.18557709075697096*lm) + 0.055072642780304326*NM - 
        0.033741289228540174*lm*NM + 0.038801977185551326*NL - 
        0.033741289228540174*lm*NL + 0.05595003532756681*NH - 
        0.033741289228540174*lm*NH)}, 
     {0.965, CF*NC*(0.23407787917098485*CF + CA*(-0.153834680359512 + 
          0.1846369679890855*lm) + 0.055020535117502524*NM - 
        0.03357035781619736*lm*NM + 0.03877715341607865*NL - 
        0.03357035781619736*lm*NL + 0.05578241671592356*NH - 
        0.03357035781619736*lm*NH)}, 
     {0.97, CF*NC*(0.23290738637427372*CF + CA*(-0.15400129000614293 + 
          0.18370355553989656*lm) + 0.054967370120203196*NM - 
        0.033400646461799376*lm*NM + 0.038751468459595435*NL - 
        0.033400646461799376*lm*NL + 0.05561545803827046*NH - 
        0.033400646461799376*lm*NH)}, 
     {0.975, CF*NC*(0.23174314833998919*CF + CA*(-0.1541598681932114 + 
          0.18277679464326144*lm) + 0.05491317126890368*NM - 
        0.03323214448059299*lm*NM + 0.03872494009046993*NL - 
        0.03323214448059299*lm*NL + 0.055449157483055254*NH - 
        0.03323214448059299*lm*NH)}, 
     {0.98, CF*NC*(0.23058515247422232*CF + CA*(-0.1543105652829839 + 
          0.18185662701966543*lm) + 0.05485796159987397*NM - 
        0.033064841276302805*lm*NM + 0.03869758576069573*NL - 
        0.033064841276302805*lm*NL + 0.05528351319808557*NH - 
        0.033064841276302805*lm*NH)}, 
     {0.985, CF*NC*(0.2294333855989132*CF + CA*(-0.15445352895748382 + 
          0.1809429948771429*lm) + 0.05480176371368026*NM - 
        0.03289872634129871*lm*NM + 0.03866942260568269*NL - 
        0.03289872634129871*lm*NL + 0.055118523292388824*NH - 
        0.03289872634129871*lm*NH)}, 
     {0.99, CF*NC*(0.22828783396797384*CF + CA*(-0.15458890426447314 + 
          0.18003584091190097*lm) + 0.05474459978355128*NM - 
        0.03273378925670927*lm*NM + 0.038640467449955494*NL - 
        0.03273378925670927*lm*NL + 0.05495418583800953*NH - 
        0.03273378925670927*lm*NH)}, 
     {0.995, CF*NC*(0.22714848328318055*CF + CA*(-0.15471683366280575 + 
          0.17913510830866217*lm) + 0.05468649156358952*NM - 
        0.03257001969248403*lm*NM + 0.038610736812760296*NL - 
        0.03257001969248403*lm*NL + 0.05479049887174614*NH - 
        0.03257001969248403*lm*NH)}, {1., 0.000048225308641975306*CF*NC*
       (4686.653648767114*CF + CA*(-3210.709509744441 + 3696.*lm) + 
        1132.7550187886534*NM - 672.*lm*NM + 800.*NL - 672.*lm*NL + 
        1132.7550187886534*NH - 672.*lm*NH)}}
 
CbarTable["p", 2, 2] = {{0., -1.6075102880658437*^-7*CF*NC*
       (15.*CA*(-29093.002395114298 + 3898.992508165458*lm + 15840.*lm^2) + 
        2.*(CF*(-609746.3369659903 + 167166.91012706028*lm - 194400.*lm^2) + 
          60.*((-625.7551981765639 + 369.5683520871487*lm - 360.*lm^2)*NM + 
            (-625.7551981765639 + 369.5683520871487*lm - 360.*lm^2)*NL + 
            (-294.90179009708874 + 369.5683520871487*lm - 360.*lm^2)*NH)))}, 
     {0.005, CF*NC*(CA*(0.07898157739390183 - 0.007626824617365363*lm - 
          0.03856788118573948*lm^2) + CF*(0.20488783424700702 - 
          0.0573244190532116*lm + 0.06311107830393733*lm^2) + 
        0.01099323883920637*NM - 0.007538103567096425*lm*NM + 
        0.007012342033770815*lm^2*NM + 0.010990970485455307*NL - 
        0.007538103567096425*lm*NL + 0.007012342033770815*lm^2*NL + 
        0.005754963827769322*NH - 0.007538103567096425*lm*NH + 
        0.007012342033770815*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(0.08710683937291368 - 0.0059638260507676255*lm - 
          0.03892215308437482*lm^2) + CF*(0.21292476763622514 - 
          0.060686892292777656*lm + 0.06369079595624971*lm^2) + 
        0.010015617971488169*NM - 0.007922447216905845*lm*NM + 
        0.007076755106249968*lm^2*NM + 0.010004087792812068*NL - 
        0.007922447216905845*lm*NL + 0.007076755106249968*lm^2*NL + 
        0.005818296287862061*NH - 0.007922447216905845*lm*NH + 
        0.007076755106249968*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(0.0944434062222507 - 0.004431235280190808*lm - 
          0.03925519230031893*lm^2) + CF*(0.22009979465776747 - 
          0.06379754155613278*lm + 0.0642357692187037*lm^2) + 
        0.009149928379585177*NM - 0.008278167010287043*lm*NM + 
        0.0071373076909670785*lm^2*NM + 0.009120662808954868*NL - 
        0.008278167010287043*lm*NL + 0.0071373076909670785*lm^2*NL + 
        0.00587831475284417*NH - 0.008278167010287043*lm*NH + 
        0.0071373076909670785*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(0.10098377122913704 - 0.0030343294599753066*lm - 
          0.03956575399565578*lm^2) + CF*(0.22645318866705355 - 
          0.06664547844606203*lm + 0.06474396108380037*lm^2) + 
        0.008395782718913012*NM - 0.008604015402966158*lm*NM + 
        0.007193773453755596*lm^2*NM + 0.008340162644740728*NL - 
        0.008604015402966158*lm*NL + 0.007193773453755596*lm^2*NL + 
        0.005934805787819339*NH - 0.008604015402966158*lm*NH + 
        0.007193773453755596*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(0.1067496895950481 - 0.0017723946162891354*lm - 
          0.03985309110596748*lm^2) + CF*(0.2320476060557572 - 
          0.06923051915852586*lm + 0.06521414908249223*lm^2) + 
        0.007748278106140779*NM - 0.008899949333956433*lm*NM + 
        0.007246016564721359*lm^2*NM + 0.0076581651503304145*NL - 
        0.008899949333956433*lm*NL + 0.007246016564721359*lm^2*NL + 
        0.0059876528159735*NH - 0.008899949333956433*lm*NH + 
        0.007246016564721359*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(0.11177686972105222 - 0.0006414791436828064*lm - 
          0.04011680419898632*lm^2) + CF*(0.23695106157841017 - 
          0.07155840701759346*lm + 0.06564567959834125*lm^2) + 
        0.007200514719001132*NM - 0.009166594846368555*lm*NM + 
        0.0072939643998156944*lm^2*NM + 0.007068574315515892*NL - 
        0.009166594846368555*lm*NL + 0.0072939643998156944*lm^2*NL + 
        0.006036806140887246*NH - 0.009166594846368555*lm*NH + 
        0.0072939643998156944*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(0.11610783577169287 + 0.00036421390257404773*lm - 
          0.040356751372729024*lm^2) + CF*(0.24123044819877038 - 
          0.07363837110196131*lm + 0.06603832042810204*lm^2) + 
        0.006744748411279579*NM - 0.009404973093330923*lm*NM + 
        0.007337591158678004*lm^2*NM + 0.006564609427519078*NL - 
        0.009404973093330923*lm*NL + 0.007337591158678004*lm^2*NL + 
        0.00608226482126474*NH - 0.009404973093330923*lm*NH + 
        0.007337591158678004*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(0.11978809897130052 + 0.0012515240634180373*lm - 
          0.04057298753689717*lm^2) + CF*(0.24494883657048724 - 
          0.07548170276972935*lm + 0.06639216142401355*lm^2) + 
        0.006372992989486971*NM - 0.009616340334118328*lm*NM + 
        0.007376906824890395*lm^2*NM + 0.006139311012407262*NL - 
        0.009616340334118328*lm*NL + 0.007376906824890395*lm^2*NL + 
        0.006124064397326738*NH - 0.009616340334118328*lm*NH + 
        0.007376906824890395*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(0.12286394677247557 + 0.002027835910274758*lm - 
          0.04076572064778902*lm^2) + CF*(0.24816440065341844 - 
          0.07710086224876196*lm + 0.06670754287820022*lm^2) + 
        0.006077355356284843*NM - 0.009802087340199482*lm*NM + 
        0.007411949208688913*lm^2*NM + 0.005785816891439954*NL - 
        0.009802087340199482*lm*NL + 0.007411949208688913*lm^2*NL + 
        0.006162268025364189*NH - 0.009802087340199482*lm*NH + 
        0.007411949208688913*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(0.12538111645064 + 0.002700757211954012*lm - 
          0.0409352787595133*lm^2) + CF*(0.25093011213790944 - 
          0.07850889236611823*lm + 0.0669850016064763*lm^2) + 
        0.005850226155203892*NM - 0.00996367325561455*lm*NM + 
        0.007442777956275145*lm^2*NM + 0.005497516181025765*NL - 
        0.00996367325561455*lm*NL + 0.007442777956275145*lm^2*NL + 
        0.006196959807321256*NH - 0.00996367325561455*lm*NH + 
        0.007442777956275145*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(0.12738398888572558 + 0.003277905715964095*lm - 
          0.04108208446314588*lm^2) + CF*(0.2532938143264599 - 
          0.0797190233817342*lm + 0.06722522912151144*lm^2) + 
        0.005684386658985405*NM - 0.010102580915035493*lm*NM + 
        0.00746946990239016*lm^2*NM + 0.005268133766672501*NL - 
        0.010102580915035493*lm*NL + 0.00746946990239016*lm^2*NL + 
        0.006228239633180885*NH - 0.010102580915035493*lm*NH + 
        0.00746946990239016*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(0.12891510408392173 + 0.0037667664778984625*lm - 
          0.04120663462632425*lm^2) + CF*(0.25529848299236924 - 
          0.08074440285775955*lm + 0.06742903847943968*lm^2) + 
        0.005573064862772805*NM - 0.010220286215296241*lm*NM + 
        0.007492115386604409*lm^2*NM + 0.005091773302087803*NL - 
        0.010220286215296241*lm*NL + 0.007492115386604409*lm^2*NL + 
        0.006256219117524008*NH - 0.010220286215296241*lm*NH + 
        0.007492115386604409*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(0.13001488278018117 + 0.0041745966853529715*lm - 
          0.04130948407825977*lm^2) + CF*(0.25698257365178984 - 
          0.08159791038709734*lm + 0.06759733758260689*lm^2) + 
        0.005509959880470425*NM - 0.010318237035281314*lm*NM + 
        0.007510815286956321*lm^2*NM + 0.004962934736409575*NL - 
        0.010318237035281314*lm*NL + 0.007510815286956321*lm^2*NL + 
        0.006281018356194966*NH - 0.010318237035281314*lm*NH + 
        0.007510815286956321*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(0.1307214831947917 + 0.004508363300870777*lm - 
          0.04139123231608057*lm^2) + CF*(0.25838040093931636 - 
          0.08229203149416577*lm + 0.06773110742631366*lm^2) + 
        0.005489246261330039*NM - 0.010397838822061264*lm*NM + 
        0.00752567860292374*lm^2*NM + 0.004876515958935892*NL - 
        0.010397838822061264*lm*NL + 0.00752567860292374*lm^2*NL + 
        0.00630276331446343*NH - 0.010397838822061264*lm*NH + 
        0.00752567860292374*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(0.13107074770819846 + 0.004774703811426862*lm - 
          0.04145251257710085*lm^2) + CF*(0.25952252037102996 - 
          0.08283877362849261*lm + 0.06783138421707412*lm^2) + 
        0.005505565555991477*NM - 0.010460444925704256*lm*NM + 
        0.0075368204685637916*lm^2*NM + 0.004827804524256762*NL - 
        0.010460444925704256*lm*NL + 0.0075368204685637916*lm^2*NL + 
        0.006321583711661409*NH - 0.010460444925704256*lm*NH + 
        0.0075368204685637916*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(0.1310962097065079 + 0.0049799034554702405*lm - 
          0.04149398279716884*lm^2) + CF*(0.26043609639451143 - 
          0.0832496125352321*lm + 0.06789924457718537*lm^2) + 
        0.00555400988424534*NM - 0.010507350366455146*lm*NM + 
        0.0075443605085761525*lm^2*NM + 0.004812463270150918*NL - 
        0.010507350366455146*lm*NL + 0.0075443605085761525*lm^2*NL + 
        0.006337611302520646*NH - 0.010507350366455146*lm*NH + 
        0.0075443605085761525*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(0.1308291405620719 + 0.0051298842901576274*lm - 
          0.041516318094470143*lm^2) + CF*(0.26114524838012004 - 
          0.08353546076148902*lm + 0.06793579324549659*lm^2) + 
        0.005630100648043968*NM - 0.010539788107674643*lm*NM + 
        0.0075484214717218435*lm^2*NM + 0.00482651231561446*NL - 
        0.010539788107674643*lm*NL + 0.0075484214717218435*lm^2*NL + 
        0.006350978479550716*NH - 0.010539788107674643*lm*NH + 
        0.0075484214717218435*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(0.13029862300353712 + 0.005230202789756277*lm - 
          0.04152020450179607*lm^2) + CF*(0.2616713707026412 - 
          0.08370665238235604*lm + 0.06794215282112083*lm^2) + 
        0.005729764497622036*NM - 0.010558927168801057*lm*NM + 
        0.007549128091235648*lm^2*NM + 0.004866309084330302*NL - 
        0.010558927168801057*lm*NL + 0.007549128091235648*lm^2*NL + 
        0.006361817137851572*NH - 0.010558927168801057*lm*NH + 
        0.007549128091235648*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(0.12953164131413378 + 0.0052860535762640016*lm - 
          0.04150633373058742*lm^2) + CF*(0.26203342568424454 - 
          0.08377293962891667*lm + 0.06791945519550668*lm^2) + 
        0.005849307975010149*NM - 0.010565872092018643*lm*NM + 
        0.007546606132834077*lm^2*NM + 0.004928527450086103*NL - 
        0.010565872092018643*lm*NL + 0.007546606132834077*lm^2*NL + 
        0.006370257756156802*NH - 0.010565872092018643*lm*NH + 
        0.007546606132834077*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(0.128553181643486 + 0.005302277521066903*lm - 
          0.041475398794581425*lm^2) + CF*(0.2622482096882196 - 
          0.08374349822466594*lm + 0.06786883439113324*lm^2) + 
        0.005985391798845293*NM - 0.01056166340257646*lm*NM + 
        0.007540981599014804*lm^2*NM + 0.0050101367355993845*NL - 
        0.01056166340257646*lm*NL + 0.007540981599014804*lm^2*NL + 
        0.006376428657142654*NH - 0.01056166340257646*lm*NH + 
        0.007540981599014804*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(0.12738633769099475 + 0.0052833729120534195*lm - 
          0.04142809035443119*lm^2) + CF*(0.2623305935095182 - 
          0.08362693904303312*lm + 0.0677914205799783*lm^2) + 
        0.006135005439294339*NM - 0.010547278793299574*lm*NM + 
        0.007532380064442034*lm^2*NM + 0.005108381049400089*NL - 
        0.010547278793299574*lm*NL + 0.007532380064442034*lm^2*NL + 
        0.006380455417063374*NH - 0.010547278793299574*lm*NH + 
        0.007532380064442034*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(0.12605241840735762 + 0.0052335087114075045*lm - 
          0.0413650936703939*lm^2) + CF*(0.26229373866279715 - 
          0.08343132428656984*lm + 0.0676883350970082*lm^2) + 
        0.0062954424135512384*NM - 0.010523634829933837*lm*NM + 
        0.0075209261218898*lm^2*NM + 0.005220759276438974*NL - 
        0.010523634829933837*lm*NL + 0.0075209261218898*lm^2*NL + 
        0.00638246040021195*NH - 0.010523634829933837*lm*NH + 
        0.0075209261218898*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(0.12457105535055224 + 0.005156539172843828*lm - 
          0.04128708607022587*lm^2) + CF*(0.26214929137812454 - 
          0.08316418682316151*lm + 0.06756068629673323*lm^2) + 
        0.006464276579659774*NM - 0.010491589022883375*lm*NM + 
        0.007506742921859248*lm^2*NM + 0.0053450059213316185*NL - 
        0.010491589022883375*lm*NL + 0.007506742921859248*lm^2*NL + 
        0.006382562397980982*NH - 0.010491589022883375*lm*NH + 
        0.007506742921859248*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(0.12296030804535972 + 0.005056019268458654*lm - 
          0.04119473485525209*lm^2) + CF*(0.261907556174905 - 
          0.08283255164012414*lm + 0.06740956612677615*lm^2) + 
        0.006639339598985814*NM - 0.010451942147546685*lm*NM + 
        0.007489951791864016*lm^2*NM + 0.005479072922010765*NL - 
        0.010451942147546685*lm*NL + 0.007489951791864016*lm^2*NL + 
        0.0063808763557053755*NH - 0.010451942147546685*lm*NH + 
        0.007489951791864016*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(0.12123676621282996 + 0.004935220511842089*lm - 
          0.04108869558023316*lm^2) + CF*(0.2615776508556549 - 
          0.08244295862327104*lm + 0.06723604731310881*lm^2) + 
        0.006818699661898809*NM - 0.010405440723198798*lm*NM + 
        0.007470671923678757*lm^2*NM + 0.0056211124950586175*NL - 
        0.010405440723198798*lm*NL + 0.007470671923678757*lm^2*NL + 
        0.006377513173215361*NH - 0.010405440723198798*lm*NH + 
        0.007470671923678757*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(0.11941564811369478 + 0.0047971468676095905*lm - 
          0.040969610652878796*lm^2) + CF*(0.2611676446805298 - 
          0.0820014860559269*lm + 0.06704118106834712*lm^2) + 
        0.007000641517853452*NM - 0.010352779581553862*lm*NM + 
        0.0074490201187052355*lm^2*NM + 0.00576946103472456*NL - 
        0.010352779581553862*lm*NL + 0.0074490201187052355*lm^2*NL + 
        0.006372579567265712*NH - 0.010352779581553862*lm*NH + 
        0.0074490201187052355*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(0.1175108945262889 + 0.004644550516550976*lm - 
          0.040838108207201275*lm^2) + CF*(0.26068468137462414 - 
          0.08151377437730721*lm + 0.06682599524814754*lm^2) + 
        0.00718364781368139*NM - 0.010294604472444275*lm*NM + 
        0.007425110583127505*lm^2*NM + 0.00592262406053827*NL - 
        0.010294604472444275*lm*NL + 0.007425110583127505*lm^2*NL + 
        0.006366177985845842*NH - 0.010294604472444275*lm*NH + 
        0.007425110583127505*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(0.11553525808228322 + 0.00447994730626885*lm - 
          0.04069480121176826*lm^2) + CF*(0.2601350884979302 - 
          0.0809850498513924*lm + 0.06659149289198442*lm^2) + 
        0.0073663817180181935*NM - 0.010231514666672941*lm*NM + 
        0.007399054765776046*lm^2*NM + 0.006079262189989322*NL - 
        0.010231514666672941*lm*NL + 0.007399054765776046*lm^2*NL + 
        0.006358406565898619*NH - 0.010231514666672941*lm*NH + 
        0.007399054765776046*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(0.1135003878319159 + 0.004305631763936079*lm - 
          0.04054028677960775*lm^2) + CF*(0.2595244745817899 - 
          0.0804201478842433*lm + 0.06633865109390358*lm^2) + 
        0.0075476707922167915*NM - 0.010164065525914137*lm*NM + 
        0.007370961232655954*lm^2*NM + 0.006238178100494612*NL - 
        0.010164065525914137*lm*NL + 0.007370961232655954*lm^2*NL + 
        0.006349359127246085*NH - 0.010164065525914137*lm*NH + 
        0.007370961232655954*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(0.1114169090184689 + 0.004123691583928257*lm - 
          0.04037514565127196*lm^2) + CF*(0.2588578153114207 - 
          0.07982353579542442*lm + 0.06606842015662685*lm^2) + 
        0.007726492056551611*NM - 0.010092771017206915*lm*NM + 
        0.007340935572958539*lm^2*NM + 0.006398304437063167*NL - 
        0.010092771017206915*lm*NL + 0.007340935572958539*lm^2*NL + 
        0.006339125196586158*NH - 0.010092771017206915*lm*NH + 
        0.007340935572958539*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(0.10929449811973199 + 0.003936021531032183*lm - 
          0.04019994182655987*lm^2) + CF*(0.2581395299150592 - 
          0.0791993349021569*lm + 0.06578172298891616*lm^2) + 
        0.00790195819334617*NM - 0.010018106155589955*lm*NM + 
        0.007309080332101796*lm^2*NM + 0.006558692617440291*NL - 
        0.010018106155589955*lm*NL + 0.007309080332101796*lm^2*NL + 
        0.006327790056323463*NH - 0.010018106155589955*lm*NH + 
        0.007309080332101796*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(0.10714195326967345 + 0.0037443367215415943*lm - 
          0.04001522232377175*lm^2) + CF*(0.25737354880834246 - 
          0.07855134181629131*lm + 0.0654794547116265*lm^2) + 
        0.008073304824657403*NM - 0.009940509363136563*lm*NM + 
        0.0072754949679585*lm^2*NM + 0.006718502484164875*NL - 
        0.009940509363136563*lm*NL + 0.0072754949679585*lm^2*NL + 
        0.006315434813759226*NH - 0.009940509363136563*lm*NH + 
        0.0072754949679585*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(0.10496726021210419 + 0.003550185261230146*lm - 
          0.03982151704823277*lm^2) + CF*(0.25656337343867797 - 
          0.07788304888666568*lm + 0.06516248244256273*lm^2) + 
        0.008239878800439627*NM - 0.009860384736343644*lm*NM + 
        0.007240275826951414*lm^2*NM + 0.0068769927522483185*NL - 
        0.009860384736343644*lm*NL + 0.007240275826951414*lm^2*NL + 
        0.006302136486813277*NH - 0.009860384736343644*lm*NH + 
        0.007240275826951414*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(0.10277765396397845 + 0.0033549602320145874*lm - 
          0.03961933875426492*lm^2) + CF*(0.25571212917884045 - 
          0.0771976637448174*lm + 0.06483164523425168*lm^2) + 
        0.008401127433038775*NM - 0.009778104216725113*lm*NM + 
        0.007203516137139075*lm^2*NM + 0.007033512201601661*NL - 
        0.009778104216725113*lm*NL + 0.007203516137139075*lm^2*NL + 
        0.006287968103004489*NH - 0.009778104216725113*lm*NH + 
        0.007203516137139075*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(0.10057967638227332 + 0.003159911028918285*lm - 
          0.039409183086877214*lm^2) + CF*(0.2548226120318148 - 
          0.07649812793183414*lm + 0.06448775414216272*lm^2) + 
        0.008556588614950645*NM - 0.009694009661725324*lm*NM + 
        0.0071653060157958574*lm^2*NM + 0.0071874915645485475*NL - 
        0.009694009661725324*lm*NL + 0.0071653060157958574*lm^2*NL + 
        0.006272998808889702*NH - 0.009694009661725324*lm*NH + 
        0.0071653060157958574*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(0.09837922983752793 + 0.0029661540563618322*lm - 
          0.039191528691241685*lm^2) + CF*(0.25389732982964697 - 
          0.07578713459951712*lm + 0.06413159240385004*lm^2) + 
        0.008705881758655257*NM - 0.00960841481483246*lm*NM + 
        0.00712573248931667*lm^2*NM + 0.007338436060508194*NL - 
        0.00960841481483246*lm*NL + 0.00712573248931667*lm^2*NL + 
        0.0062572939875678866*NH - 0.00960841481483246*lm*NH + 
        0.00712573248931667*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(0.09618162720091468 + 0.002774682798347296*lm - 
          0.038966837379571184*lm^2) + CF*(0.2529385385373298 - 
          0.07506714529089961*lm + 0.06376391571202557*lm^2) + 
        0.008848699499740703*NM - 0.009521607175137468*lm*NM + 
        0.007084879523558397*lm^2*NM + 0.0074859185320259045*NL - 
        0.009521607175137468*lm*NL + 0.007084879523558397*lm^2*NL + 
        0.006240915382206191*NH - 0.009521607175137468*lm*NH + 
        0.007084879523558397*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(0.09399163835155402 + 0.0025863772811616044*lm - 
          0.0387355543463554*lm^2) + CF*(0.2519482742079911 - 
          0.07434040581423002*lm + 0.06338545256676338*lm^2) + 
        0.008984800107243406*NM - 0.009433849767632285*lm*NM + 
        0.00704282806297371*lm^2*NM + 0.007629573138630687*NL - 
        0.009433849767632285*lm*NL + 0.00704282806297371*lm^2*NL + 
        0.00622392122384604*NH - 0.009433849767632285*lm*NH + 
        0.00704282806297371*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(0.09181353340773869 + 0.002402012950114914*lm - 
          0.0384981084240728*lm^2) + CF*(0.2509283810773161 - 
          0.07360896123136113*lm + 0.0629969046939373*lm^2) + 
        0.009114000547983662*NM - 0.00934538281633526*lm*NM + 
        0.006999656077104145*lm^2*NM + 0.007769089567409232*NL - 
        0.00934538281633526*lm*NL + 0.006999656077104145*lm^2*NL + 
        0.006206366362007808*NH - 0.00934538281633526*lm*NH + 
        0.006999656077104145*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(0.08965112287220574 + 0.002222268983798869*lm - 
          0.0382549123725058*lm^2) + CF^2*(0.24988053624947354 - 
          0.07287466998653674*lm + 0.06259894751864585*lm^2) + 
        CF*((0.009236170184102764 - 0.00925642532292345*lm + 
            0.006955438613182872*lm^2)*NM + (0.007904207721629962 - 
            0.00925642532292345*lm + 0.006955438613182872*lm^2)*NL + 
          (0.006188302396837492 - 0.00925642532292345*lm + 
            0.006955438613182872*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(0.08750779492258122 + 0.002047736070594038*lm - 
          0.038006363195666165*lm^2) + CF^2*(0.24880627128457006 - 
          0.07213921720519428*lm + 0.06219223068381736*lm^2) + 
        CF*((0.009351224917215595 - 0.009167176553981169*lm + 
            0.006910247853757484*lm^2)*NM + (0.008034712851177664 - 
            0.009167176553981169*lm + 0.006910247853757484*lm^2)*NL + 
          (0.006169777811733435 - 0.009167176553981169*lm + 
            0.006910247853757484*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(0.08538654994835031 + 0.0018789236728321067*lm - 
          0.03775284248110473*lm^2) + CF^2*(0.24770699119980144 - 
          0.07140412719489829*lm + 0.061777378605444105*lm^2) + 
        CF*((0.009459122030597213 - 0.0090778174402747*lm + 
            0.006864153178382678*lm^2)*NM + (0.008160431090931454 - 
            0.0090778174402747*lm + 0.006864153178382678*lm^2)*NL + 
          (0.006150838105559508 - 0.0090778174402747*lm + 
            0.006864153178382678*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(0.0832900326059936 + 0.0017162668042517229*lm - 
          0.03749471675705072*lm^2) + CF^2*(0.24658399100163914 - 
          0.07067077518211527*lm + 0.06135499105699208*lm^2) + 
        CF*((0.009559855345703496 - 0.00898851189166081*lm + 
            0.006817221228554676*lm^2)*NM + (0.008281225375511209 - 
            0.00898851189166081*lm + 0.006817221228554676*lm^2)*NL + 
          (0.0061315259236970005 - 0.00898851189166081*lm + 
            0.006817221228554676*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(0.08122056149587453 + 0.001560132346277286*lm - 
          0.037232337863413165*lm^2) + CF^2*(0.24543847015150458 - 
          0.06994039831942467*lm + 0.060925643776494266*lm^2) + 
        CF*((0.009653450883271445 - 0.008899408031352635*lm + 
            0.00676951597516603*lm^2)*NM + (0.008396991701013238 - 
            0.008899408031352635*lm + 0.00676951597516603*lm^2)*NL + 
          (0.006111881187313716 - 0.008899408031352635*lm + 
            0.00676951597516603*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(0.07918015664220879 + 0.0014108249282775648*lm - 
          0.036966043333191964*lm^2) + CF^2*(0.24427154516417324 - 
          0.06921410599808263*lm + 0.060489889090677755*lm^2) + 
        CF*((0.009739962911402946 - 0.008810639353318028*lm + 
            0.006721098787853084*lm^2)*NM + (0.008507655706444696 - 
            0.008810639353318028*lm + 0.006721098787853084*lm^2)*NL + 
          (0.006091941220337837 - 0.008810639353318028*lm + 
            0.006721098787853084*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(0.07717056492234349 + 0.0012685923963900328*lm - 
          0.03669615678129801*lm^2) + CF^2*(0.24308426056387075 - 
          0.0684928895007396*lm + 0.060048256551214936*lm^2) + 
        CF*((0.009819470360334582 - 0.008722325806586158*lm + 
            0.0066720285056905484*lm^2)*NM + (0.008613169549542155 - 
            0.008722325806586158*lm + 0.0066720285056905484*lm^2)*NL + 
          (0.006071740873719414 - 0.008722325806586158*lm + 
            0.0066720285056905484*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(0.07519328358637518 + 0.0011336308947785762*lm - 
          0.036422988298179006*lm^2) + CF^2*(0.2418775983920689 - 
          0.06777763102865587*lm + 0.05960125357883837*lm^2) + 
        CF*((0.009892073573591835 - 0.00863457481019951*lm + 
            0.006622361508759819*lm^2)*NM + (0.00871350905352099 - 
            0.00863457481019951*lm + 0.006622361508759819*lm^2)*NL + 
          (0.006051312646642555 - 0.00863457481019951*lm + 
            0.006622361508759819*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(0.07324958199978833 + 0.001006089582367935*lm - 
          0.036146834845996484*lm^2) + CF^2*(0.24065248643933854 - 
          0.06706911213704199*lm + 0.05914936611163061*lm^2) + 
        CF*((0.00995789136740785 - 0.008547482202479308*lm + 
            0.006572151790181179*lm^2)*NM + (0.008808671103048928 - 
            0.008547482202479308*lm + 0.006572151790181179*lm^2)*NL + 
          (0.006030686804423908 - 0.008547482202479308*lm + 
            0.006572151790181179*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(0.07134052173356405 + 0.0008860750072006753*lm - 
          0.035867980655407104*lm^2) + CF^2*(0.23940980535459522 - 
          0.06636802161123875*lm + 0.058693059254302536*lm^2) + 
        CF*((0.01001705837256472 - 0.00846113312818028*lm + 
            0.006521451028255837*lm^2)*NM + (0.008898671269371636 - 
            0.00846113312818028*lm + 0.006521451028255837*lm^2)*NL + 
          (0.006009891492892319 - 0.00846113312818028*lm + 
            0.006521451028255837*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(0.06946697511845322 + 0.0007736551596178168*lm - 
          0.035586697621271285*lm^2) + CF^2*(0.2381503947677992 - 
          0.06567496281539455*lm + 0.05823277792571665*lm^2) + 
        CF*((0.01006972263471017 - 0.008375602867001553*lm + 
            0.0064703086584129614*lm^2)*NM + (0.008983541646043884 - 
            0.008375602867001553*lm + 0.0064703086584129614*lm^2)*NL + 
          (0.00598895284909773 - 0.008375602867001553*lm + 
            0.0064703086584129614*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(0.06762964237258656 + 0.0006688632244932073*lm - 
          0.035303245695850693*lm^2) + CF^2*(0.23687505854696495 - 
          0.06499046054414014*lm + 0.05776894750230114*lm^2) + 
        CF*((0.010116043451124894 - 0.008290957606798925*lm + 
            0.0064187719447001265*lm^2)*NM + (0.009063328878141088 - 
            0.008290957606798925*lm + 0.0064187719447001265*lm^2)*NL + 
          (0.005967895108242153 - 0.008290957606798925*lm + 
            0.0064187719447001265*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(0.065829067404476 + 0.000571701051770646*lm - 
          0.03501787327826565*lm^2) + CF^2*(0.23558456929669516 - 
          0.06431496740653525*lm + 0.057301974455343796*lm^2) + 
        CF*((0.010156189423638917 - 0.008207255164713987*lm + 
            0.006366886050593755*lm^2)*NM + (0.009138092369147664 - 
            0.008207255164713987*lm + 0.006366886050593755*lm^2)*NL + 
          (0.005946740706764105 - 0.008207255164713987*lm + 
            0.006366886050593755*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(0.06406565238669207 + 0.0004821423635744582*lm - 
          0.03473081759916835*lm^2) + CF^2*(0.23427967219332813 - 
          0.06364886977029431*lm + 0.0568322469804573*lm^2) + 
        CF*((0.010190336709012749 - 0.008124545659300429*lm + 
            0.0063146941089397*lm^2)*NM + (0.009207902650945803 - 
            0.008124545659300429*lm + 0.0063146941089397*lm^2)*NL + 
          (0.005925510381540789 - 0.008124545659300429*lm + 
            0.0063146941089397*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(0.0623396711891001 + 0.0004001357151986015*lm - 
          0.034442305099750395*lm^2) + CF^2*(0.2329610882409779 - 
          0.06299249329301371*lm + 0.05636013561777337*lm^2) + 
        CF*((0.010218667449589105 - 0.00804287213658992*lm + 
            0.006262237290863708*lm^2)*NM + (0.009272839903466432 - 
            0.00804287213658992*lm + 0.006262237290863708*lm^2)*NL + 
          (0.005904223265200266 - 0.00804287213658992*lm + 
            0.006262237290863708*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(0.06065128175447742 + 0.00032560722633404244*lm - 
          0.034152551804346516*lm^2) + CF^2*(0.2316295170231624 - 
          0.06234610806583493*lm + 0.055885993861657934*lm^2) + 
        CF*((0.01024136836842177 - 0.00796227115290125*lm + 
            0.006209554873517548*lm^2)*NM + (0.009332992611618492 - 
            0.00796227115290125*lm + 0.006209554873517548*lm^2)*NL + 
          (0.005882896977559577 - 0.00796227115290125*lm + 
            0.006209554873517548*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(0.0590005374936373 + 0.0002584630979747805*lm - 
          0.033861763686022325*lm^2) + CF^2*(0.23028563901616125 - 
          0.061709933393701615*lm + 0.055410158758945616*lm^2) + 
        CF*((0.010258629514354807 - 0.00788277331705843*lm + 
            0.006156684306549513*lm^2)*NM + (0.009388456348088558 - 
            0.00788277331705843*lm + 0.006156684306549513*lm^2)*NL + 
          (0.005861547713224637 - 0.00788277331705843*lm + 
            0.006156684306549513*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(0.0573873977718103 + 0.00019859192955368885*lm - 
          0.03357013702464483*lm^2) + CF^2*(0.2289301175226788 - 
          0.06108414223511444*lm + 0.05493295149487335*lm^2) + 
        CF*((0.01027064314372507 - 0.007804403794547408*lm + 
            0.00610366127720815*lm^2)*NM + (0.009439332671505409 - 
            0.007804403794547408*lm + 0.00610366127720815*lm^2)*NL + 
          (0.00584019032540436 - 0.007804403794547408*lm + 
            0.00610366127720815*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(0.055811737553009964 + 0.00014586685000324295*lm - 
          0.03327785875703194*lm^2) + CF^2*(0.22756360027761874 - 
          0.060468865323063115*lm + 0.054454677966052266*lm^2) + 
        CF*((0.010277602726444785 - 0.007727182776007981*lm + 
            0.006050519774005807*lm^2)*NM + (0.009485728130298347 - 
            0.007727182776007981*lm + 0.006050519774005807*lm^2)*NL + 
          (0.005818838406005467 - 0.007727182776007981*lm + 
            0.006050519774005807*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(0.05427335626442554 + 0.00010014747561516592*lm - 
          0.032985106818862686*lm^2) + CF^2*(0.22618672077171392 - 
          0.05986419498762587*lm + 0.05397562933995712*lm^2) + 
        CF*((0.010279702065243252 - 0.0076511259123280065*lm + 
            0.005997292148884124*lm^2)*NM + (0.009527753363348537 - 
            0.0076511259123280065*lm + 0.005997292148884124*lm^2)*NL + 
          (0.005797504362085288 - 0.0076511259123280065*lm + 
            0.005997292148884124*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(0.05277196334388996 + 0.00006128170678821259*lm - 
          0.0326920504781048*lm^2) + CF^2*(0.2248001445225843 - 
          0.059270188699578646*lm + 0.05349608260053512*lm^2) + 
        CF*((0.010277134517761561 - 0.007576244718481611*lm + 
            0.0059440091778372355*lm^2)*NM + (0.009565522289244018 - 
            0.007576244718481611*lm + 0.0059440091778372355*lm^2)*NL + 
          (0.0057761994887496155 - 0.007576244718481611*lm + 
            0.0059440091778372355*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(0.05130728017247992 + 0.000029107375005270446*lm - 
          0.03239885065978211*lm^2) + CF^2*(0.22340438103179125 - 
          0.058686872353250624*lm + 0.05301630107964345*lm^2) + 
        CF*((0.010270092312075513 - 0.007502546948132356*lm + 
            0.005890700119960384*lm^2)*NM + (0.009599151376605468 - 
            0.007502546948132356*lm + 0.005890700119960384*lm^2)*NL + 
          (0.0057549340385893875 - 0.007502546948132356*lm + 
            0.005890700119960384*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(0.04987889878368467 + 3.4537506697161663*^-6*lm - 
          0.032105660261961426*lm^2) + CF^2*(0.2220000807757863 - 
          0.058114243305802935*lm + 0.05253653497411869*lm^2) + 
        CF*((0.010258765946985325 - 0.007430036940906228*lm + 
            0.005837392774902077*lm^2)*NM + (0.00962875898855531 - 
            0.007430036940906228*lm + 0.005837392774902077*lm^2)*NL + 
          (0.005733717287755979 - 0.007430036940906228*lm + 
            0.005837392774902077*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(0.04848639163238675 - 0.000015857078243820752*lm - 
          0.03181262446288855*lm^2) + CF^2*(0.22058782878411692 - 
          0.05755227318909352*lm + 0.05205702184836308*lm^2) + 
        CF*((0.010243343669168611 - 0.007358715944128226*lm + 
            0.005784113538707009*lm^2)*NM + (0.009654464794961105 - 
            0.007358715944128226*lm + 0.005784113538707009*lm^2)*NL + 
          (0.005712557598778996 - 0.007358715944128226*lm + 
            0.005784113538707009*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(0.047129290171757945 - 0.00002900894740812896*lm - 
          0.031519881019246826*lm^2) + CF^2*(0.21916819941851748 - 
          0.05700091050932434*lm + 0.0515779871224039*lm^2) + 
        CF*((0.010224011019934125 - 0.007288582410710185*lm + 
            0.005730887458044878*lm^2)*NM + (0.009676389246598915 - 
            0.007288582410710185*lm + 0.005730887458044878*lm^2)*NL + 
          (0.005691462480233366 - 0.007288582410710185*lm + 
            0.005730887458044878*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(0.045807090128661895 - 0.000036190468519446124*lm - 
          0.031227560555548917*lm^2) + CF^2*(0.21774175667235712 - 
          0.05646008304874679*lm + 0.05109964454544368*lm^2) + 
        CF*((0.010200950444950011 - 0.007219632274776379*lm + 
            0.005677738282827076*lm^2)*NM + (0.009694653105856658 - 
            0.007219632274776379*lm + 0.005677738282827076*lm^2)*NL + 
          (0.005670438643364755 - 0.007219632274776379*lm + 
            0.005677738282827076*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(0.04451925632781478 - 0.000037593984689008864*lm - 
          0.03093578684470549*lm^2) + CF^2*(0.21630905438217912 - 
          0.05592970008282709*lm + 0.05062219665497262*lm^2) + 
        CF*((0.010174340960876872 - 0.007151859206517318*lm + 
            0.00562468851721918*lm^2)*NM + (0.009709377029034558 - 
            0.007151859206517318*lm + 0.00562468851721918*lm^2)*NL + 
          (0.005649492055783098 - 0.007151859206517318*lm + 
            0.00562468851721918*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(0.043265227099117426 - 0.000033414621245848265*lm - 
          0.030644677079842253*lm^2) + CF^2*(0.21487063636702908 - 
          0.055409654425444425*lm + 0.05014583522156005*lm^2) + 
        CF*((0.010144357873359572 - 0.007085254847670863*lm + 
            0.005571759469062228*lm^2)*NM + (0.009720681195702421 - 
            0.007085254847670863*lm + 0.005571759469062228*lm^2)*NL + 
          (0.005628627992334488 - 0.007085254847670863*lm + 
            0.005571759469062228*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(0.04204441830006831 - 0.000023849424852727287*lm - 
          0.030354342137460907*lm^2) + CF^2*(0.2134270365092031 - 
          0.054899824313909905*lm + 0.04967074167948148*lm^2) + 
        CF*((0.010111172541317909 - 0.0070198090289433504*lm + 
            0.005518971297720165*lm^2)*NM + (0.009728684980944204 - 
            0.0070198090289433504*lm + 0.005518971297720165*lm^2)*NL + 
          (0.005607851083261816 - 0.0070198090289433504*lm + 
            0.005518971297720165*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(0.04085622698285544 - 9.096584313213377*^-6*lm - 
          0.030064886832059913*lm^2) + CF^2*(0.21197877878819074 - 
          0.05440007514485211*lm + 0.04919708754337077*lm^2) + 
        CF*((0.010074952182882959 - 0.006955509970601545*lm + 
            0.00546634306037453*lm^2)*NM + (0.009733506666661866 - 
            0.006955509970601545*lm + 0.00546634306037453*lm^2)*NL + 
          (0.005587165359762 - 0.006955509970601545*lm + 0.00546634306037453*
             lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(0.03970003473354358 + 0.00001064527310474303*lm - 
          0.029776410162348388*lm^2) + CF^2*(0.21052637727800602 - 
          0.05391026107131435*lm + 0.04872503481111554*lm^2) + 
        CF*((0.01003585971877726 - 0.006892344467388919*lm + 
            0.005413892756790616*lm^2)*NM + (0.009735263188424785 - 
            0.006892344467388919*lm + 0.005413892756790616*lm^2)*NL + 
          (0.005566574297048878 - 0.006892344467388919*lm + 
            0.005413892756790616*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(0.03857521070878356 + 0.00003517771558333153*lm - 
          0.02948900554920067*lm^2) + CF^2*(0.20907033611663597 - 
          0.05343022647074749*lm + 0.04825473635323746*lm^2) + 
        CF*((0.009994053649272765 - 0.006830298058846711*lm + 
            0.00536163737258194*lm^2)*NM + (0.009734069914640455 - 
            0.006830298058846711*lm + 0.00536163737258194*lm^2)*NL + 
          (0.005546080855026296 - 0.006830298058846711*lm + 
            0.00536163737258194*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(0.037481114393591 + 0.00006430307626809031*lm - 
          0.02920276106551129*lm^2) + CF^2*(0.20761114945510062 - 
          0.052959807292959134*lm + 0.04778633628901848*lm^2) + 
        CF*((0.009949687961218326 - 0.006769355186051357*lm + 
            0.005309592921002053*lm^2)*NM + (0.009730040455088452 - 
            0.006769355186051357*lm + 0.005309592921002053*lm^2)*NL + 
          (0.005525687516676391 - 0.006769355186051357*lm + 
            0.005309592921002053*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(0.03641709810202459 + 0.00009782496337102028*lm - 
          0.028917759658119768*lm^2) + CF^2*(0.2061493013924788 - 
          0.05249883229649331*lm + 0.04731997034965053*lm^2) + 
        CF*((0.009902912061894842 - 0.006709499335715008*lm + 
            0.005257774483294503*lm^2)*NM + (0.00972328649610481 - 
            0.006709499335715008*lm + 0.005257774483294503*lm^2)*NL + 
          (0.0055053963242632075 - 0.006709499335715008*lm + 
            0.005257774483294503*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(0.03538250924095484 + 0.00013554871550880982*lm - 
          0.02863407936198243*lm^2) + CF^2*(0.20468526590233777 - 
          0.05204712418136278*lm + 0.04685576622869852*lm^2) + 
        CF*((0.009853870736862575 - 0.006650713172534726*lm + 
            0.005206196247633169*lm^2)*NM + (0.009713917659929492 - 
            0.006650713172534726*lm + 0.005206196247633169*lm^2)*NL + 
          (0.005485208913451909 - 0.006650713172534726*lm + 
            0.005206196247633169*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(0.03437669235566592 + 0.00017728180659743397*lm - 
          0.02835179350677482*lm^2) + CF^2*(0.20321950675505568 - 
          0.051604500625537*lm + 0.04639384392017698*lm^2) + 
        CF*((0.009802704129022738 - 0.0065929786606185*lm + 
            0.005154871546686331*lm^2)*NM + (0.00970204138593708 - 
            0.0065929786606185*lm + 0.005154871546686331*lm^2)*NL + 
          (0.0054651265454387695 - 0.0065929786606185*lm + 
            0.005154871546686331*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(0.03339899097459499 + 0.00022283420432128994*lm - 
          0.02807097091611266*lm^2) + CF^2*(0.2017524774398801 - 
          0.05117077523210155*lm + 0.045934316044547986*lm^2) + 
        CF*((0.00974954773658746 - 0.006536277174762172*lm + 
            0.0051038128938386655*lm^2)*NM + (0.009687762831661739 - 
            0.006536277174762172*lm + 0.0051038128938386655*lm^2)*NL + 
          (0.005445150137185632 - 0.006536277174762172*lm + 
            0.0051038128938386655*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(0.032448749269264575 + 0.00027201868591157966*lm - 
          0.027791676099582822*lm^2) + CF^2*(0.20028462108983033 - 
          0.05074575839354654*lm + 0.04547728816295371*lm^2) + 
        CF*((0.009694532427695638 - 0.00648058960230061*lm + 
            0.005053032018105968*lm^2)*NM + (0.00967118479170305 - 
            0.00648058960230061*lm + 0.005053032018105968*lm^2)*NL + 
          (0.005425280289849523 - 0.00648058960230061*lm + 
            0.005053032018105968*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(0.03152531354425006 + 0.0003246511147037069*lm - 
          0.02751396943777794*lm^2) + CF^2*(0.198816370412019 - 
          0.05032925807921242*lm + 0.04502285908000027*lm^2) + 
        CF*((0.00963778446970165 - 0.0064258964362087926*lm + 
            0.005002539897777807*lm^2)*NM + (0.0096524076327608 - 
            0.0064258964362087926*lm + 0.005002539897777807*lm^2)*NL + 
          (0.005405517315494304 - 0.0064258964362087926*lm + 
            0.005002539897777807*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(0.030628033570922947 + 0.0003805506806959279*lm - 
          0.027237907360529324*lm^2) + CF^2*(0.19734814762545452 - 
          0.04992108055151831*lm + 0.044571121135411625*lm^2) + 
        CF*((0.009579425571315697 - 0.006372177860083731*lm + 
            0.004952346792823513*lm^2)*NM + (0.009631529243195248 - 
            0.006372177860083731*lm + 0.004952346792823513*lm^2)*NL + 
          (0.005385861262169403 - 0.006372177860083731*lm + 
            0.004952346792823513*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(0.029756263777678392 + 0.0004395401081003399*lm - 
          0.026963542518533307*lm^2) + CF^2*(0.19588036440796203 - 
          0.049521031016220345*lm + 0.044122160484872684*lm^2) + 
        CF*((0.009519572935962135 - 0.006319413825596199*lm + 
            0.004902462276096965*lm^2)*NM + (0.00960864499564594 - 
            0.006319413825596199*lm + 0.004902462276096965*lm^2)*NL + 
          (0.00536631193743668 - 0.006319413825596199*lm + 
            0.004902462276096965*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(0.02890936430840595 + 0.000501445832661513*lm - 
          0.026690923948565544*lm^2) + CF^2*(0.19441342185347793 - 
          0.04912891421159367*lm + 0.04367605737037998*lm^2) + 
        CF*((0.009458339324859075 - 0.006267584122961889*lm + 
            0.0048528952633755534*lm^2)*NM + (0.009583847721367623 - 
            0.006267584122961889*lm + 0.0048528952633755534*lm^2)*NL + 
          (0.005346868930423 - 0.006267584122961889*lm + 
            0.0048528952633755534*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(0.028086701960075122 + 0.0005660981513167315*lm - 
          0.026420097232476673*lm^2) + CF^2*(0.1929477104406558 - 
          0.04874453494110004*lm + 0.04323288638041638*lm^2) + 
        CF*((0.009395833128477245 - 0.006216668444944752*lm + 
            0.0048036540422684865*lm^2)*NM + (0.009557227695057154 - 
            0.006216668444944752*lm + 0.0048036540422684865*lm^2)*NL + 
          (0.005327531632476121 - 0.006216668444944752*lm + 
            0.0048036540422684865*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(0.027287651009488347 + 0.0006333313465840087*lm - 
          0.026151104650161086*lm^2) + CF^2*(0.19148361001344072 - 
          0.04836769855379265*lm + 0.04279271670026359*lm^2) + 
        CF*((0.009332158445160364 - 0.006166646444870732*lm + 
            0.004754746300029288*lm^2)*NM + (0.009528872629051336 - 
            0.006166646444870732*lm + 0.004754746300029288*lm^2)*NL + 
          (0.005308299256492799 - 0.006166646444870732*lm + 
            0.004754746300029288*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(0.026511593938495726 + 0.000702983787888928*lm - 
          0.025883985326688234*lm^2) + CF^2*(0.19002148977402897 - 
          0.04799821137641927*lm + 0.04235561235276257*lm^2) + 
        CF*((0.009267415165797037 - 0.006117497789097744*lm + 
            0.004706179150306952*lm^2)*NM + (0.009498867675872972 - 
            0.006117497789097744*lm + 0.004706179150306952*lm^2)*NL + 
          (0.005289170854991785 - 0.006117497789097744*lm + 
            0.004706179150306952*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(0.025757922066253373 + 0.0007748980118781524*lm - 
          0.02561877537378345*lm^2) + CF^2*(0.18856170828844138 - 
          0.047635881100912804*lm + 0.04192163242982746*lm^2) + 
        CF*((0.009201699063582997 - 0.006069202204357487*lm + 
            0.0046579591588697174*lm^2)*NM + (0.009467295438191975 - 
            0.006069202204357487*lm + 0.0046579591588697174*lm^2)*NL + 
          (0.005270145336996147 - 0.006069202204357487*lm + 
            0.0046579591588697174*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(0.025026036096469518 + 0.0008489207836153557*lm - 
          0.025355508025842036*lm^2) + CF^2*(0.18710461350473714 - 
          0.04728051713070451*lm + 0.041490831315014236*lm^2) + 
        CF*((0.009135101887929565 - 0.0060217395203563204*lm + 
            0.004610092368334915*lm^2)*NM + (0.009434235985350543 - 
            0.0060217395203563204*lm + 0.004610092368334915*lm^2)*NL + 
          (0.0052512214837893015 - 0.0060217395203563204*lm + 
            0.004610092368334915*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(0.024315346586955156 + 0.0009249031404136767*lm - 
          0.025094213770657414*lm^2) + CF^2*(0.1856505427837939 - 
          0.04693193088905687*lm + 0.041063258897439406*lm^2) + 
        CF*((0.009067711461771212 - 0.005975089707995938*lm + 
            0.0045625843219377115*lm^2)*NM + (0.009399766875676905 - 
            0.005975089707995938*lm + 0.0045625843219377115*lm^2)*NL + 
          (0.005232397963604345 - 0.005975089707995938*lm + 
            0.0045625843219377115*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(0.02362527434825586 + 0.0010027004199268837*lm - 
          0.024834920475040292*lm^2) + CF^2*(0.18419982294241885 - 
          0.046589936092391294*lm + 0.04063896077733866*lm^2) + 
        CF*((0.008999611781511756 - 0.005929232913549749*lm + 
            0.004515440086370962*lm^2)*NM + (0.009363963183881453 - 
            0.005929232913549749*lm + 0.004515440086370962*lm^2)*NL + 
          (0.005213673345309437 - 0.005929232913549749*lm + 
            0.004515440086370962*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(0.022955250777606705 + 0.0010821722739986473*lm - 
          0.0245776535055023*lm^2) + CF^2*(0.18275277030848527 - 
          0.04625434899137798*lm + 0.04021797846354922*lm^2) + 
        CF*((0.008930883118984677 - 0.005884149489107724*lm + 
            0.0044686642737276905*lm^2)*NM + (0.009326897532892732 - 
            0.005884149489107724*lm + 0.0044686642737276905*lm^2)*NL + 
          (0.005195046111136351 - 0.005884149489107724*lm + 
            0.0044686642737276905*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(0.02230471813398018 + 0.0011631826696550487*lm - 
          0.024322435844173606*lm^2) + CF^2*(0.1813096907876894 - 
          0.04592498858236132*lm + 0.03980034956319317*lm^2) + 
        CF*((0.008861602124832876 - 0.0058398200195807605*lm + 
            0.004422261062577019*lm^2)*NM + (0.009288640129549131 - 
            0.0058398200195807605*lm + 0.004422261062577019*lm^2)*NL + 
          (0.005176514668514289 - 0.0058398200195807605*lm + 
            0.004422261062577019*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(0.021673129759538102 + 0.0012455998785191494*lm - 
          0.02406928820011997*lm^2) + CF^2*(0.17987087994148318 - 
          0.04560167679151293*lm + 0.03938610796383268*lm^2) + 
        CF*((0.00879184193282514 - 0.005796225346535375*lm + 
            0.004376234218203631*lm^2)*NM + (0.009249258803615696 - 
            0.005796225346535375*lm + 0.004376234218203631*lm^2)*NL + 
          (0.005158077361053538 - 0.005796225346535375*lm + 
            0.004376234218203631*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(0.021059950252405563 + 0.0013292964558275782*lm - 
          0.02381822911622064*lm^2) + CF^2*(0.17843662307564676 - 
          0.045284238633935374*lm + 0.03897528400836105*lm^2) + 
        CF*((0.008721672264601254 - 0.0057533465891106165*lm + 
            0.004330587112040116*lm^2)*NM + (0.009208819049644686 - 
            0.0057533465891106165*lm + 0.004330587112040116*lm^2)*NL + 
          (0.005139732478729445 - 0.0057533465891106165*lm + 
            0.004330587112040116*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(0.020464655595277142 + 0.0014141492101371728*lm - 
          0.023569275071764317*lm^2) + CF^2*(0.17700719533897616 - 
          0.04497250234978137*lm + 0.038567904662887065*lm^2) + 
        CF*((0.008651159534488882 - 0.005711165162251394*lm + 
            0.004285322740320785*lm^2)*NM + (0.009167384071243484 - 
            0.005711165162251394*lm + 0.004285322740320785*lm^2)*NL + 
          (0.005121478267311894 - 0.005711165162251394*lm + 
            0.004285322740320785*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(0.019886733244030383 + 0.0015000391647242834*lm - 
          0.023322440580916197*lm^2) + CF^2*(0.17558286183149452 - 
          0.04466629951930624*lm + 0.03816399367786287*lm^2) + 
        CF*((0.008580366954002681 - 0.005669662792475932*lm + 
            0.0042404437419847636*lm^2)*NM + (0.009125014827354904 - 
            0.005669662792475932*lm + 0.0042404437419847636*lm^2)*NL + 
          (0.005103312937085877 - 0.005669662792475932*lm + 
            0.0042404437419847636*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(0.019325682180184066 + 0.0015868515115999527*lm - 
          0.02307773828720484*lm^2) + CF^2*(0.17416387772159506 - 
          0.044365465158633474*lm + 0.03776357174269883*lm^2) + 
        CF*((0.008509354635717658 - 0.0056288215313796235*lm + 
            0.004195952415855425*lm^2)*NM + (0.009081770080192673 - 
            0.0056288215313796235*lm + 0.004195952415855425*lm^2)*NL + 
          (0.005085234670898605 - 0.0056288215313796235*lm + 
            0.004195952415855425*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(0.01878101293073635 + 0.0016744755589904626*lm - 
          0.022835179054173413*lm^2) + CF^2*(0.17275048837150858 - 
          0.044069837797885036*lm + 0.03736665663410195*lm^2) + 
        CF*((0.008438179696238715 - 0.005588623767063188*lm + 
            0.004151850737122439*lm^2)*NM + (0.009037706444509698 - 
            0.005588623767063188*lm + 0.004151850737122439*lm^2)*NL + 
          (0.00506724163158308 - 0.005588623767063188*lm + 
            0.004151850737122439*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(0.01825224755863682 + 0.0017628046730642562*lm - 
          0.02259477205233563*lm^2) + CF^2*(0.17134292947048455 - 
          0.04377925954320848*lm + 0.0369732633583674*lm^2) + 
        CF*((0.008366896358023495 - 0.005549052233659597*lm + 
            0.004108140373151933*lm^2)*NM + (0.00899287843790839 - 
            0.005549052233659597*lm + 0.004108140373151933*lm^2)*NL + 
          (0.005049331968784454 - 0.005549052233659597*lm + 
            0.004108140373151933*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(0.01773891962688593 + 0.0018517362146226923*lm - 
          0.022356524842572438*lm^2) + CF^2*(0.1699414271750737 - 
          0.04349357612412113*lm + 0.03658340428784581*lm^2) + 
        CF*((0.008295556049845288 - 0.005510090019121715*lm + 
            0.004064822698649534*lm^2)*NM + (0.008947338531931458 - 
            0.005510090019121715*lm + 0.004064822698649534*lm^2)*NL + 
          (0.005031503825233089 - 0.005510090019121715*lm + 
            0.004064822698649534*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(0.01724057413901383 + 0.0019411714714131043*lm - 
          0.022120443456101424*lm^2) + CF^2*(0.1685461982559089 - 
          0.04321263692748766*lm + 0.036197089291802334*lm^2) + 
        CF*((0.00822420750571541 - 0.005471720571420894*lm + 
            0.004021898810200259*lm^2)*NM + (0.008901137203698194 - 
            0.005471720571420894*lm + 0.004021898810200259*lm^2)*NL + 
          (0.00501375534249317 - 0.005471720571420894*lm + 
            0.004021898810200259*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(0.016756769833958803 + 0.0020310158952238093*lm - 
          0.021886532398924238*lm^2) + CF*(0.16715745529826256 - 
          0.04293629539354316*lm + 0.03581432574369421*lm^2) + 
        0.008152896211598247*NM - 0.005433927742684318*lm*NM + 
        0.0039793695270771345*lm^2*NM + 0.008854322532524031*NL - 
        0.005433927742684318*lm*NL + 0.0039793695270771345*lm^2*NL + 
        0.004996084645765894*NH - 0.005433927742684318*lm*NH + 
        0.0039793695270771345*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(0.016287069104449707 + 0.0021211777312730644*lm - 
          0.021654795028942346*lm^2) + CF*(0.16577538563705693 - 
          0.04266440745562347*lm + 0.03543511913826929*lm^2) + 
        0.008081667234814979*NM - 0.005396695627259447*lm*NM + 
        0.0039372354598077*lm^2*NM + 0.008806942165818166*NL - 
        0.005396695627259447*lm*NL + 0.0039372354598077*lm^2*NL + 
        0.0049784899346872625*NH - 0.005396695627259447*lm*NH + 
        0.0039372354598077*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(0.015831053668476994 + 0.0022115699891550214*lm - 
          0.021425233145961654*lm^2) + CF*(0.16440018510513538 - 
          0.0423968340232917*lm + 0.035059472420664525*lm^2) + 
        0.008010560992689385*NM - 0.005360008825192866*lm*NM + 
        0.0038954969356293913*lm^2*NM + 0.00875904034385047*NL - 
        0.005360008825192866*lm*NL + 0.0038954969356293913*lm^2*NL + 
        0.004960969351601886*NH - 0.005360008825192866*lm*NH + 
        0.0038954969356293913*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(0.015388313290730263 + 0.002302108917866869*lm - 
          0.02119784739863625*lm^2) + CF*(0.16303203446783635 - 
          0.04213343922346264*lm + 0.03468738665231386*lm^2) + 
        0.007939616398492971*NM - 0.005323852259131291*lm*NM + 
        0.0038541540724793184*lm^2*NM + 0.008710660089819034*NL - 
        0.005323852259131291*lm*NL + 0.0038541540724793184*lm^2*NL + 
        0.004943521081690854*NH - 0.005323852259131291*lm*NH + 
        0.0038541540724793184*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(0.014958448609310757 + 0.002392714309074529*lm - 
          0.020972637258626414*lm^2) + CF*(0.16167110592277506 - 
          0.04187409084988381*lm + 0.03431886096866141*lm^2) + 
        0.007868870136661474*NM - 0.00528821122348082*lm*NM + 
        0.0038132067742957117*lm^2*NM + 0.008661842691607741*NL - 
        0.00528821122348082*lm*NL + 0.0038132067742957117*lm^2*NL + 
        0.004926143330910013*NH - 0.00528821122348082*lm*NH + 
        0.0038132067742957117*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(0.014541070980339094 + 0.002483309414120714*lm - 
          0.020749601082566734*lm^2) + CF*(0.16031756327239208 - 
          0.04161866033948773*lm + 0.033953892680563744*lm^2) + 
        0.0077983567500972*NM - 0.005253071383657225*lm*NM + 
        0.0037726547422848606*lm^2*NM + 0.008612627753095103*NL - 
        0.005253071383657225*lm*NL + 0.0037726547422848606*lm^2*NL + 
        0.004908834329225098*NH - 0.005253071383657225*lm*NH + 
        0.0037726547422848606*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(0.014135802312907482 + 0.002573820859947937*lm - 
          0.020528736171415915*lm^2) + CF*(0.15897156209939822 - 
          0.04136702274222956*lm + 0.03359247737140786*lm^2) + 
        0.0077281087252330715*NM - 0.00521841877453306*lm*NM + 
        0.0037324974857119845*lm^2*NM + 0.008563053244921154*NL - 
        0.00521841877453306*lm*NL + 0.0037324974857119845*lm^2*NL + 
        0.004891592333515107*NH - 0.00521841877453306*lm*NH + 
        0.0037324974857119845*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(0.013742274895734654 + 0.002664178564252888*lm - 
          0.020310038827289704*lm^2) + CF*(0.15763324994461667 - 
          0.04111905668511171*lm + 0.03323460899011042*lm^2) + 
        0.0076581565748296745*NM - 0.005184239798162606*lm*NM + 
        0.0036927343322344917*lm^2*NM + 0.008513155554625085*NL - 
        0.005184239798162606*lm*NL + 0.0036927343322344917*lm^2*NL + 
        0.004874415630165906*NH - 0.005184239798162606*lm*NH + 
        0.0036927343322344917*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(0.01336013121676493 + 0.002754315650159222*lm - 
          0.020093504407874784*lm^2) + CF*(0.15630276648675134 - 
          0.04087464433104218*lm + 0.032880279940158734*lm^2) + 
        0.00758852891848704*NM - 0.005150521220859478*lm*NM + 
        0.003653364437795415*lm^2*NM + 0.008462969536077553*NL - 
        0.005150521220859478*lm*NL + 0.003653364437795415*lm^2*NL + 
        0.0048573025373748*NH - 0.005150521220859478*lm*NH + 
        0.003653364437795415*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(0.012989023776844792 + 0.0028441683606686835*lm - 
          0.01987912737851803*lm^2) + CF*(0.15498024372363817 - 
          0.04063367133312271*lm + 0.03252948116484768*lm^2) + 
        0.0075192525608623086*NM - 0.005117250169695999*lm*NM + 
        0.0036143867960941873*lm^2*NM + 0.008412528558141813*NL - 
        0.005117250169695999*lm*NL + 0.0036143867960941873*lm^2*NL + 
        0.004840251407185704*NH - 0.005117250169695999*lm*NH + 
        0.0036143867960941873*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(0.01262861489851047 + 0.002933675973125373*lm - 
          0.019666901362082146*lm^2) + CF*(0.15366580615456266 - 
          0.040396026784915814*lm + 0.032182202228861694*lm^2) + 
        0.007450352567592776*NM - 0.0050844141284880845*lm*NM + 
        0.0035758002476512993*lm^2*NM + 0.008361864552507132*NL - 
        0.0050844141284880845*lm*NL + 0.0035758002476512993*lm^2*NL + 
        0.004823260627273356*NH - 0.0050844141284880845*lm*NH + 
        0.0035758002476512993*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(0.012278576530827829 + 0.0030227807139048034*lm - 
          0.019456819186655355*lm^2) + CF*(0.1523595709632534 - 
          0.04016160316719565*lm + 0.031838431396345124*lm^2) + 
        0.0073818523389312125*NM - 0.0050520009333244265*lm*NM + 
        0.0035376034884827914*lm^2*NM + 0.008311008060646427*NL - 
        0.0050520009333244265*lm*NL + 0.0035376034884827914*lm^2*NL + 
        0.004806328622494049*NH - 0.0050520009333244265*lm*NH + 
        0.0035376034884827914*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(0.011938590051140527 + 0.0031114276735179913*lm - 
          0.019248872931199725*lm^2) + CF*(0.15106164820118625 - 
          0.03993029629164713*lm + 0.03149815570559955*lm^2) + 
        0.0073137736811069425*NM - 0.005019998767694117*lm*NM + 
        0.00349979507839995*lm^2*NM + 0.008259988279857702*NL - 
        0.005019998767694117*lm*NL + 0.00349979507839995*lm^2*NL + 
        0.00478945385621931*NH - 0.005019998767694117*lm*NH + 
        0.00349979507839995*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(0.011608346064503838 + 0.003199564722301095*lm - 
          0.019043053969219566*lm^2) + CF*(0.14977214097085859 - 
          0.03970200524193968*lm + 0.031161361040541107*lm^2) + 
        0.007246136875431938*NM - 0.004988396157262578*lm*NM + 
        0.003462373448949012*lm^2*NM + 0.008208833108355901*NL - 
        0.004988396157262578*lm*NL + 0.003462373448949012*lm^2*NL + 
        0.004772634831468013*NH - 0.004988396157262578*lm*NH + 
        0.003462373448949012*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(0.011287544201508853 + 0.003287142426842905*lm - 
          0.018839353010528335*lm^2) + CF*(0.14849114560871624 - 
          0.03947663231256694*lm + 0.030828032199046364*lm^2) + 
        0.007178960745176245*NM - 0.004957181964341631*lm*NM + 
        0.0034253369110051517*lm^2*NM + 0.008157569189388043*NL - 
        0.004957181964341631*lm*NL + 0.0034253369110051517*lm^2*NL + 
        0.004755870091851543*NH - 0.004957181964341631*lm*NH + 
        0.0034253369110051517*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(0.010975892915134781 + 0.003374113967285727*lm - 
          0.018637760141189664*lm^2) + CF*(0.14721875186743902 - 
          0.03925408294581083*lm + 0.03049815295831036*lm^2) + 
        0.007112262720241493*NM - 0.00492634538209584*lm*NM + 
        0.0033886836620344845*lm^2*NM + 0.008106221954350222*NL - 
        0.00492634538209584*lm*NL + 0.0033886836620344845*lm^2*NL + 
        0.0047391582223457315*NH - 0.00492634538209584*lm*NH + 
        0.0033886836620344845*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(0.010673109277205415 + 0.0034604350556197627*lm - 
          0.018438264861705248*lm^2) + CF*(0.14595504309731192 - 
          0.03903426566715837*lm + 0.030171706137335864*lm^2) + 
        0.007046058899665073*NM - 0.004895875928523816*lm*NM + 
        0.003352411793037318*lm^2*NM + 0.008054815664890249*NL - 
        0.004895875928523816*lm*NL + 0.003352411793037318*lm^2*NL + 
        0.004722497849902535*NH - 0.004895875928523816*lm*NH + 
        0.003352411793037318*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(0.010378918774968776 + 0.003546063855076889*lm - 
          0.01824085612351965*lm^2) + CF*(0.14470009642643017 - 
          0.0388170920194713*lm + 0.029848673656668517*lm^2) + 
        0.006980364111990876*NM - 0.0048657634402499315*lm*NM + 
        0.0033165192951853904*lm^2*NM + 0.008003373453984256*NL - 
        0.0048657634402499315*lm*NL + 0.0033165192951853904*lm^2*NL + 
        0.004705887643913586*NH - 0.0048657634402499315*lm*NH + 
        0.0033165192951853904*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(0.010093055108266694 + 0.003630960900716672*lm - 
          0.018045522363909446*lm^2) + CF*(0.14345398293950662 - 
          0.0386024764961824*lm + 0.029529036595488185*lm^2) + 
        0.006915191973545263*NM - 0.004835998066158936*lm*NM + 
        0.0032810040661653537*lm^2*NM + 0.007951917365979869*NL - 
        0.004835998066158936*lm*NL + 0.0032810040661653537*lm^2*NL + 
        0.004689326316537101*NH - 0.004835998066158936*lm*NH + 
        0.0032810040661653537*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(0.009815259987712719 + 0.003715089021285483*lm - 
          0.017852251539321677*lm^2) + CF*(0.14221676785506815 - 
          0.03839033647376837*lm + 0.029212775246162743*lm^2) + 
        0.0068505549446593724*NM - 0.004806570260903203*lm*NM + 
        0.003245863916240305*lm^2*NM + 0.007900468395602161*NL - 
        0.004806570260903203*lm*NL + 0.003245863916240305*lm^2*NL + 
        0.0046728126228988785*NH - 0.004806570260903203*lm*NH + 
        0.003245863916240305*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(0.009545282934252417 + 0.003798413262418551*lm - 
          0.01766103115722394*lm^2) + CF*(0.14098851070084717 - 
          0.03818059214372657*lm + 0.028899869166366443*lm^2) + 
        0.006786464383880799*NM - 0.0047774707783097385*lm*NM + 
        0.003211096574040716*lm^2*NM + 0.007849046525922073*NL - 
        0.0047774707783097385*lm*NL + 0.003211096574040716*lm^2*NL + 
        0.004656345361177506*NH - 0.0047774707783097385*lm*NH + 
        0.003211096574040716*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(0.009282881080439351 + 0.0038809008112447377*lm - 
          0.017471848306526323*lm^2) + CF*(0.13976926548719054 - 
          0.03797316644426217*lm + 0.028590297228861257*lm^2) + 
        0.006722930600219312*NM - 0.0047486906647117464*lm*NM + 
        0.0031766996920956953*lm^2*NM + 0.007797670765289873*NL - 
        0.0047486906647117464*lm*NL + 0.0031766996920956953*lm^2*NL + 
        0.004639923372583258*NH - 0.0047486906647117464*lm*NH + 
        0.0031766996920956953*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(0.009027818973722457 + 0.003962520922444555*lm - 
          0.017284689686632916*lm^2) + CF*(0.13855908087832508 - 
          0.037767984991872984*lm + 0.028284037669035682*lm^2) + 
        0.006659962903472587*NM - 0.004720221252227289*lm*NM + 
        0.0031426708521150757*lm^2*NM + 0.007746359183238915*NL - 
        0.004720221252227289*lm*NL + 0.0031426708521150757*lm^2*NL + 
        0.004623545541239599*NH - 0.004720221252227289*lm*NH + 
        0.0031426708521150757*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(0.008779868382006208 + 0.004043244845803518*lm - 
          0.017099541635178492*lm^2) + CF*(0.1373580003613346 - 
          0.03756497601300154*lm + 0.027981068130292077*lm^2) + 
        0.006597569652678914*NM - 0.00469205415200558*lm*NM + 
        0.003109007570032453*lm^2*NM + 0.007695128945367333*NL - 
        0.00469205415200558*lm*NL + 0.003109007570032453*lm^2*NL + 
        0.004607210793975637*NH - 0.00469205415200558*lm*NH + 
        0.003109007570032453*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(0.008538808101713327 + 0.0041230457552952*lm - 
          0.016916390154503864*lm^2) + CF*(0.13616606241271784 - 
          0.03736407027590741*lm + 0.02768136570736996*lm^2) + 
        0.0065357583027446*NM - 0.004664181247459526*lm*NM + 
        0.0030757073008188846*lm^2*NM + 0.00764399634720732*NL - 
        0.004664181247459526*lm*NL + 0.0030757073008188846*lm^2*NL + 
        0.004590918100037369*NH - 0.004664181247459526*lm*NH + 
        0.0030757073008188846*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(0.008304423768550872 + 0.0042018986797213425*lm - 
          0.016735220936921303*lm^2) + CF*(0.13498330066241063 - 
          0.03716520102289745*lm + 0.027384906987689403*lm^2) + 
        0.00647453544929427*NM - 0.004636594687501372*lm*NM + 
        0.0030427674430766*lm^2*NM + 0.007592976847093538*NL - 
        0.004636594687501372*lm*NL + 0.0030427674430766*lm^2*NL + 
        0.004574666470725045*NH - 0.004636594687501372*lm*NH + 
        0.0030427674430766*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(0.008076507671154054 + 0.00427978043492992*lm - 
          0.01655601938881943*lm^2) + CF*(0.13380974405516913 - 
          0.03696830390303785*lm + 0.027091668090795433*lm^2) + 
        0.006413906871792597*NM - 0.0046092868797967135*lm*NM + 
        0.003010185343421715*lm^2*NM + 0.007542085098043724*NL - 
        0.0046092868797967135*lm*NL + 0.003010185343421715*lm^2*NL + 
        0.004558454958963521*NH - 0.0046092868797967135*lm*NH + 
        0.003010185343421715*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(0.007854858567757807 + 0.004356669557626272*lm - 
          0.01637877065365517*lm^2) + CF*(0.13264541700922317 - 
          0.03677331690545855*lm + 0.026801624705981186*lm^2) + 
        0.006353877574986075*NM - 0.004582250484050601*lm*NM + 
        0.0029779583006645763*lm^2*NM + 0.007491334978666003*NL - 
        0.004582250484050601*lm*NL + 0.0029779583006645763*lm^2*NL + 
        0.004542282658812053*NH - 0.004582250484050601*lm*NH + 
        0.0029779583006645763*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(0.007639281506024071 + 0.004432546240787099*lm - 
          0.01620345963387835*lm^2) + CF*(0.13149033957212 - 
          0.036580180293348794*lm + 0.02651475212816457*lm^2) + 
        0.006294451828713414*NM - 0.004555478405338098*lm*NM + 
        0.002946083569796063*lm^2*NM + 0.007440739623108584*NL - 
        0.004555478405338098*lm*NL + 0.002946083569796063*lm^2*NL + 
        0.004526148704919496*NH - 0.004555478405338098*lm*NH + 
        0.002946083569796063*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(0.007429587646132394 + 0.00450739227068232*lm - 
          0.016030071011832927*lm^2) + CF*(0.13034452757369092 - 
          0.03638883653873149*lm + 0.026231025292090246*lm^2) + 
        0.006235633206132911*NM - 0.0045289637874903555*lm*NM + 
        0.002914558365787805*lm^2*NM + 0.007390311450068519*NL - 
        0.0045289637874903555*lm*NL + 0.002914558365787805*lm^2*NL + 
        0.0045100522719305845*NH - 0.0045289637874903555*lm*NH + 
        0.002914558365787805*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(0.007225594087223065 + 0.004581190965505465*lm - 
          0.015858589269677023*lm^2) + CF*(0.12920799277608178 - 
          0.03619923025809381*lm + 0.025950418804926042*lm^2) + 
        0.0061774246204148444*NM - 0.00450270000654609*lm*NM + 
        0.0028833798672140043*lm^2*NM + 0.007340062190877106*NL - 
        0.00450270000654609*lm*NL + 0.0028833798672140043*lm^2*NL + 
        0.0044939925738484935*NH - 0.00450270000654609*lm*NH + 
        0.0028833798672140043*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(0.007027123697265146 + 0.0046539271156093446*lm - 
          0.015688998708362267*lm^2) + CF*(0.12808074302079986 - 
          0.03601130814894204*lm + 0.025672906977320074*lm^2) + 
        0.0061198283599464606*NM - 0.0044766806642772645*lm*NM + 
        0.0028525452197022305*lm^2*NM + 0.007290002916680206*NL - 
        0.0044766806642772645*lm*NL + 0.0028525452197022305*lm^2*NL + 
        0.004477968863358596*NH - 0.0044766806642772645*lm*NH + 
        0.0028525452197022305*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(0.0068340049464064665 + 0.004725586925340237*lm - 
          0.015521283465711445*lm^2) + CF*(0.12696278237273734 - 
          0.035825018927340274*lm + 0.025398463852982365*lm^2) + 
        0.006062846122096601*NM - 0.004450899581796741*lm*NM + 
        0.002822051539220263*lm^2*NM + 0.007240144064732345*NL - 
        0.004450899581796741*lm*NL + 0.002822051539220263*lm^2*NL + 
        0.004461980431117986*NH - 0.004450899581796741*lm*NH + 
        0.002822051539220263*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(0.006646071743848734 + 0.004796157956460644*lm - 
          0.0153554275336319*lm^2) + CF*(0.1258541112611403 - 
          0.035640313266484244*lm + 0.0251270632368522*lm^2) + 
        0.006006479045586365*NM - 0.0044253507932547715*lm*NM + 
        0.0027918959152058*lm^2*NM + 0.007190495463823953*NL - 
        0.0044253507932547715*lm*NL + 0.0027918959152058*lm^2*NL + 
        0.004446026605015006*NH - 0.0044253507932547715*lm*NH + 
        0.0027918959152058*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(0.006463163278278348 + 0.00486562907314787*lm - 
          0.015191414774500589*lm^2) + CF*(0.12475472661750048 - 
          0.035457143736354606*lm + 0.024858678721910055*lm^2) + 
        0.005950727741511494*NM - 0.004400028539630328*lm*NM + 
        0.0027620754135455616*lm^2*NM + 0.00714106635886144*NL - 
        0.004400028539630328*lm*NL + 0.0027620754135455616*lm^2*NL + 
        0.004430106749402742*NH - 0.004400028539630328*lm*NH + 
        0.0027620754135455616*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(0.0062851238618720304 + 0.00493399038855313*lm - 
          0.015029228936755377*lm^2) + CF*(0.12366462201035382 - 
          0.035275464744487166*lm + 0.024593283714690616*lm^2) + 
        0.005895592323061404*NM - 0.004374927262622475*lm*NM + 
        0.0027325870794100687*lm^2*NM + 0.007091865434620102*NL - 
        0.004374927262622475*lm*NL + 0.0027325870794100687*lm^2*NL + 
        0.004414220264310177*NH - 0.004374927262622475*lm*NH + 
        0.0027325870794100687*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(0.006111802777886125 + 0.005001233212903661*lm - 
          0.014868853669725738*lm^2) + CF*(0.12258378777697664 - 
          0.03509523247789142*lm + 0.024330851459551207*lm^2) + 
        0.005841072433978939*NM - 0.004350041598646291*lm*NM + 
        0.0027034279399501342*lm^2*NM + 0.007042900838690029*NL - 
        0.004350041598646291*lm*NL + 0.0027034279399501342*lm^2*NL + 
        0.004398366584634403*NH - 0.004350041598646291*lm*NH + 
        0.0027034279399501342*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(0.005943054131829088 + 0.00506735000312835*lm - 
          0.014710272537734707*lm^2) + CF*(0.12151221115197677 - 
          0.03491640484614309*lm + 0.024071355061747703*lm^2) + 
        0.005787167275804065*NM - 0.004325366372937153*lm*NM + 
        0.002674595006860856*lm^2*NM + 0.006994180203635285*NL - 
        0.004325366372937153*lm*NL + 0.002674595006860856*lm^2*NL + 
        0.0043825451793170845*NH - 0.004325366372937153*lm*NH + 
        0.002674595006860856*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(0.00577873670620835 + 0.005132334313985628*lm - 
          0.01455346903350272*lm^2) + CF*(0.12044987639278278 - 
          0.034738941425671487*lm + 0.02381476750936809*lm^2) + 
        0.005733875633943786*NM - 0.004300896593766612*lm*NM + 
        0.0026460852788186763*lm^2*NM + 0.006945710668386701*NL - 
        0.004300896593766612*lm*NL + 0.0026460852788186763*lm^2*NL + 
        0.004366755550508094*NH - 0.004300896593766612*lm*NH + 
        0.0026460852788186763*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(0.00561871381883518 + 0.005196180750670867*lm - 
          0.01439842659088268*lm^2) + CF*(0.11939676490203936 - 
          0.034562803405257345*lm + 0.02356106169417166*lm^2) + 
        0.005681195902609647*NM - 0.004276627446772514*lm*NM + 
        0.002617895743796851*lm^2*NM + 0.0068974988988885644*NL - 
        0.004276627446772514*lm*NL + 0.002617895743796851*lm^2*NL + 
        0.00435099723271907*NH - 0.004276627446772514*lm*NH + 
        0.002617895743796851*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(0.00546285318466454 + 0.005258884922879216*lm - 
          0.01424512859695451*lm^2) + CF*(0.11835285534692254 - 
          0.03438795353275308*lm + 0.023310210431380107*lm^2) + 
        0.005629126108663196*NM - 0.004252554289405529*lm*NM + 
        0.002590023381264456*lm^2*NM + 0.0068495511080194455*NL - 
        0.004252554289405529*lm*NL + 0.002590023381264456*lm^2*NL + 
        0.004335269791969393*NH - 0.004252554289405529*lm*NH + 
        0.002590023381264456*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(0.005311026781140838 + 0.005320443400298644*lm - 
          0.014093558403506254*lm^2) + CF*(0.11731812377539215 - 
          0.034214356063033066*lm + 0.02306218647846478*lm^2) + 
        0.005577663934408795*NM - 0.004228672645493763*lm*NM + 
        0.0025624651642738644*lm^2*NM + 0.006801873074807254*NL - 
        0.004228672645493763*lm*NL + 0.0025624651642738644*lm^2*NL + 
        0.00431957282492691*NH - 0.004228672645493763*lm*NH + 
        0.0025624651642738644*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(0.005163110717015258 + 0.005380853669507047*lm - 
          0.013943699337927756*lm^2) + CF*(0.11629254372940376 - 
          0.0340419767071783*lm + 0.02281696255297269*lm^2) + 
        0.005526806739372174*NM - 0.004204978199926712*lm*NM + 
        0.0025352180614414102*lm^2*NM + 0.00675447016295847*NL - 
        0.004204978199926712*lm*NL + 0.0025352180614414102*lm^2*NL + 
        0.0043039059580455685*NH - 0.004204978199926712*lm*NH + 
        0.0025352180614414102*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(0.0050189851045955745 + 0.005440114092246399*lm - 
          0.013795534713541866*lm^2) + CF*(0.11527608635510574 - 
          0.03387078258289633*lm + 0.022574511349432145*lm^2) + 
        0.00547655158110211*NM - 0.004181466793459447*lm*NM + 
        0.002508279038825794*lm^2*NM + 0.006707347338721271*NL - 
        0.004181466793459447*lm*NL + 0.002508279038825794*lm^2*NL + 
        0.004288268846701911*NH - 0.004181466793459447*lm*NH + 
        0.002508279038825794*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(0.004878533935385236 + 0.005498223865046347*lm - 
          0.013649047839397164*lm^2) + CF*(0.1142687205100505 - 
          0.03370074216617484*lm + 0.022334805555377178*lm^2) + 
        0.005426895235031591*NM - 0.004158134417637523*lm*NM + 
        0.002481645061708575*lm^2*NM + 0.00666050918810206*NL - 
        0.004158134417637523*lm*NL + 0.002481645061708575*lm^2*NL + 
        0.004272661174332264*NH - 0.004158134417637523*lm*NH + 
        0.002481645061708575*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(0.004741644959064894 + 0.005555182980169013*lm - 
          0.013504222029545187*lm^2) + CF*(0.11327041286745226 - 
          0.03353182524416414*lm + 0.02209781786652849*lm^2) + 
        0.00537783421343382*NM - 0.004134977209842839*lm*NM + 
        0.002455313096280943*lm^2*NM + 0.006613959933454606*NL - 
        0.004134977209842839*lm*NL + 0.002455313096280943*lm^2*NL + 
        0.004257082651572276*NH - 0.004134977209842839*lm*NH + 
        0.002455313096280943*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(0.004608209565766369 + 0.005610992187846451*lm - 
          0.013361040611824282*lm^2) + CF*(0.11228112801752646 - 
          0.03336400286928194*lm + 0.021863521001167004*lm^2) + 
        0.005329364783507382*NM - 0.004111991448460345*lm*NM + 
        0.0024292801112407785*lm^2*NM + 0.006567703449460743*NL - 
        0.004111991448460345*lm*NL + 0.0024292801112407785*lm^2*NL + 
        0.004241533015400327*NH - 0.004111991448460345*lm*NH + 
        0.0024292801112407785*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(0.004478122671586342 + 0.005665652959781811*lm - 
          0.013219486936171214*lm^2) + CF*(0.11130082856594822 - 
          0.03319724731453136*lm + 0.021631887713734716*lm^2) + 
        0.005281482984623918*NM - 0.004089173548165239*lm*NM + 
        0.002403543079303857*lm^2*NM + 0.006521743278521241*NL - 
        0.004089173548165239*lm*NL + 0.002403543079303857*lm^2*NL + 
        0.004226012028286222*NH - 0.004089173548165239*lm*NH + 
        0.002403543079303857*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(0.004351282607284737 + 0.005719167453885104*lm - 
          0.013079544382480959*lm^2) + CF*(0.11032947522947001 - 
          0.03303153203002133*lm + 0.021402890807696116*lm^2) + 
        0.005234184644770616*NM - 0.004066520055330075*lm*NM + 
        0.0023780989786329016*lm^2*NM + 0.006476082645575138*NL - 
        0.004066520055330075*lm*NL + 0.0023780989786329016*lm^2*NL + 
        0.0042105194773464005*NH - 0.004066520055330075*lm*NH + 
        0.0023780989786329016*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(0.004227591010110769 + 0.00577153848021431*lm - 
          0.012941196368034103*lm^2) + CF*(0.10936702692874008 - 
          0.032866831600676875*lm + 0.02117650314769217*lm^2) + 
        0.0051874653962188655*NM - 0.00404402764355099*lm*NM + 
        0.0023529447941880188*lm^2*NM + 0.006430724472365474*NL - 
        0.00404402764355099*lm*NL + 0.0023529447941880188*lm^2*NL + 
        0.004195055173506855*NH - 0.00404402764355099*lm*NH + 
        0.0023529447941880188*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(0.00410695271869805 + 0.0058227694680925346*lm - 
          0.012804426354510677*lm^2) + CF*(0.10841344087836549 - 
          0.032703121705125286*lm + 0.02095269767101747*lm^2) + 
        0.005141320690449428*NM - 0.004021693109292022*lm*NM + 
        0.0023280775190019413*lm^2*NM + 0.006385671391169002*NL - 
        0.004021693109292022*lm*NL + 0.0023280775190019413*lm^2*NL + 
        0.004179618950674777*NH - 0.004021693109292022*lm*NH + 
        0.0023280775190019413*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(0.003989275670968756 + 0.0058728644343719535*lm - 
          0.012669217854608311*lm^2) + CF*(0.10746867267426485 - 
          0.032540379075742705*lm + 0.020731447398449964*lm^2) + 
        0.005095745812363513*NM - 0.00399951336764641*lm*NM + 
        0.002303494155383329*lm^2*NM + 0.0063409257580071*NL - 
        0.00399951336764641*lm*NL + 0.002303494155383329*lm^2*NL + 
        0.004164210664919878*NH - 0.00399951336764641*lm*NH + 
        0.002303494155383329*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(0.003874470804985825 + 0.005921827952815367*lm - 
          0.012535554438282035*lm^2) + CF*(0.10653267637835731 - 
          0.032378581459844694*lm + 0.020512725444461512*lm^2) + 
        0.0050507358938082095*NM - 0.0039774854482135125*lm*NM + 
        0.0022791917160512793*lm^2*NM + 0.006296489665354688*NL - 
        0.0039774854482135125*lm*NL + 0.0022791917160512793*lm^2*NL + 
        0.004148830193666246*NH - 0.0039774854482135125*lm*NH + 
        0.0022791917160512793*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(0.003762451962691366 + 0.005969665124566348*lm - 
          0.0124034197386222*lm^2) + CF*(0.10560540460063547 - 
          0.0322177075820033*lm + 0.020296505026836328*lm^2) + 
        0.0050062859264437785*NM - 0.003955606491089928*lm*NM + 
        0.0022551672252040366*lm^2*NM + 0.006252364954363625*NL - 
        0.003955606491089928*lm*NL + 0.0022551672252040366*lm^2*NL + 
        0.004133477434895489*NH - 0.003955606491089928*lm*NH + 
        0.0022551672252040366*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(0.0036531357964688237 + 0.00601638154967918*lm - 
          0.012272797457386447*lm^2) + CF*(0.10468680857867092 - 
          0.03205773710747198*lm + 0.020082759475723275*lm^2) + 
        0.004962390773979399*NM - 0.003933873742973244*lm*NM + 
        0.0022314177195248085*lm^2*NM + 0.006208553226616616*NL - 
        0.003933873742973244*lm*NL + 0.0022314177195248085*lm^2*NL + 
        0.004118152306361834*NH - 0.003933873742973244*lm*NH + 
        0.0022314177195248085*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(0.0035464416784661106 + 0.006061983299679998*lm - 
          0.012143671370200913*lm^2) + CF*(0.10377683825460188 - 
          0.031898650606699504*lm + 0.019871462242146948*lm^2) + 
        0.0049190451838030695*NM - 0.00391228455337674*lm*NM + 
        0.002207940249127439*lm^2*NM + 0.006165055855427308*NL - 
        0.00391228455337674*lm*NL + 0.002207940249127439*lm^2*NL + 
        0.004102854744819803*NH - 0.00391228455337674*lm*NH + 
        0.002207940249127439*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(0.0034422916126166958 + 0.006106476891130896*lm - 
          0.012016025331445317*lm^2) + CF*(0.1028754423496529 - 
          0.031740429520912744*lm + 0.019662586906001426*lm^2) + 
        0.004876243798030477*NM - 0.003890836370953294*lm*NM + 
        0.002184731878444603*lm^2*NM + 0.006121873996701833*NL - 
        0.003890836370953294*lm*NL + 0.002184731878444603*lm^2*NL + 
        0.004087584705264971*NH - 0.003890836370953294*lm*NH + 
        0.002184731878444603*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(0.0033406101492956196 + 0.006149869260169047*lm - 
          0.011889843278835896*lm^2) + CF*(0.10198256843623761 - 
          0.031583056128748205*lm + 0.019456107183549648*lm^2) + 
        0.0048339811639968085*NM - 0.0038695267399266454*lm*NM + 
        0.002161789687061072*lm^2*NM + 0.006079008599376673*NL - 
        0.0038695267399266454*lm*NL + 0.002161789687061072*lm^2*NL + 
        0.0040723421601883015*NH - 0.0038695267399266454*lm*NH + 
        0.002161789687061072*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(0.0032413243025475277 + 0.0061921677379932665*lm - 
          0.01176510923771967*lm^2) + CF*(0.1010981630076951 - 
          0.031426513513911354*lm + 0.019251996934450368*lm^2) + 
        0.004792251744214609*NM - 0.0038483532966281206*lm*NM + 
        0.002139110770494485*lm^2*NM + 0.006036460415447335*NL - 
        0.0038483532966281206*lm*NL + 0.002139110770494485*lm^2*NL + 
        0.004057127098844405*NH - 0.0038483532966281206*lm*NH + 
        0.002139110770494485*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(0.0031443634698240653 + 0.006233380027270851*lm - 
          0.011641807325092892*lm^2) + CF*(0.10022217154571149 - 
          0.03127078553384274*lm + 0.019050230168333824*lm^2) + 
        0.004751049925820008*NM - 0.003827313766136857*lm*NM + 
        0.0021166922409259804*lm^2*NM + 0.005994230009601909*NL - 
        0.003827313766136857*lm*NL + 0.0021166922409259804*lm^2*NL + 
        0.0040419395265341215*NH - 0.003827313766136857*lm*NH + 
        0.0021166922409259804*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(0.003049659354168361 + 0.006273514179437921*lm - 
          0.011519921753356071*lm^2) + CF*(0.09935453858547803 - 
          0.031115856789369324*lm + 0.0188507810509463*lm^2) + 
        0.004710370029528814*NM - 0.003806405959021523*lm*NM + 
        0.002094531227882922*lm^2*NM + 0.005952317768473218*NL - 
        0.003806405959021523*lm*NL + 0.002094531227882922*lm^2*NL + 
        0.0040267794639016734*NH - 0.003806405959021523*lm*NH + 
        0.002094531227882922*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(0.0029571458887848075 + 0.0063125785728669614*lm - 
          0.011399436833817401*lm^2) + CF*(0.09849520777863713 - 
          0.03096171259531958*lm + 0.01865362390988302*lm^2) + 
        0.0046702063181232175*NM - 0.003785627768181491*lm*NM + 
        0.0020726248788758912*lm^2*NM + 0.005910723909522869*NL - 
        0.003785627768181491*lm*NL + 0.0020726248788758912*lm^2*NL + 
        0.004011646946246641*NH - 0.003785627768181491*lm*NH + 
        0.0020726248788758912*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(0.0028667591639329297 + 0.00635058189187568*lm - 
          0.01128033697995597*lm^2) + CF*(0.0976441219540676 - 
          0.030808338952080513*lm + 0.01845873323992795*lm^2) + 
        0.004630553004489075*NM - 0.0037649771657853894*lm*NM + 
        0.0020509703599919946*lm^2*NM + 0.00586944848957014*NL - 
        0.0037649771657853894*lm*NL + 0.0020509703599919946*lm^2*NL + 
        0.0039965420228509525*NH - 0.0037649771657853894*lm*NH + 
        0.0020509703599919946*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(0.002778437356084795 + 0.00638753310655182*lm - 
          0.011162606710455658*lm^2) + CF*(0.09680122317656063 - 
          0.03065572251807479*lm + 0.01826608370801835*lm^2) + 
        0.004591404259223023*NM - 0.003744452200304946*lm*NM + 
        0.0020295648564464834*lm^2*NM + 0.005828491412978245*NL - 
        0.003744452200304946*lm*NL + 0.0020295648564464834*lm^2*NL + 
        0.003981464756321037*NH - 0.003744452200304946*lm*NH + 
        0.0020295648564464834*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(0.0026921206592861696 + 0.006423441453369002*lm - 
          0.011046230652020164*lm^2) + CF*(0.09596645280343707 - 
          0.030503850583136184*lm + 0.018075650157851175*lm^2) + 
        0.00455275421782795*NM - 0.003724050993642005*lm*NM + 
        0.0020084055730945753*lm^2*NM + 0.005787852439510183*NL - 
        0.003724050993642005*lm*NL + 0.0020084055730945753*lm^2*NL + 
        0.0039664152219452365*NH - 0.003724050993642005*lm*NH + 
        0.0020084055730945753*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(0.0026077512186624212 + 0.006458316416569218*lm - 
          0.010931193541979174*lm^2) + CF*(0.0951397515391571 - 
          0.030352711042761524*lm + 0.01788740761414774*lm^2) + 
        0.004514596987514677*NM - 0.003703771738346609*lm*NM + 
        0.0019874897349053044*lm^2*NM + 0.005747531191865962*NL - 
        0.003703771738346609*lm*NL + 0.0019874897349053044*lm^2*NL + 
        0.003951393507066576*NH - 0.003703771738346609*lm*NH + 
        0.0019874897349053044*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(0.002525273066011039 + 0.0064921677102880585*lm - 
          0.010817480230695306*lm^2) + CF*(0.09432105948797229 - 
          0.03020229237321742*lm + 0.01770133128659232*lm^2) + 
        0.004476926653627004*NM - 0.0036836126949240156*lm*NM + 
        0.0019668145873991466*lm^2*NM + 0.0057075271629126794*NL - 
        0.0036836126949240156*lm*NL + 0.0019668145873991466*lm^2*NL + 
        0.0039363997104709*NH - 0.0036836126949240156*lm*NH + 
        0.0019668145873991466*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(0.0024446320574235533 + 0.006525005261399311*lm - 
          0.010705075683780998*lm^2) + CF*(0.09351031620467015 - 
          0.030052583607480185*lm + 0.017517396573459815*lm^2) + 
        0.004439737285706647*NM - 0.0036635721892285355*lm*NM + 
        0.0019463773970510908*lm^2*NM + 0.005667839722618552*NL - 
        0.0036635721892285355*lm*NL + 0.0019463773970510908*lm^2*NL + 
        0.0039214339417904*NH - 0.0036635721892285355*lm*NH + 
        0.0019463773970510908*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(0.0023657758128805984 + 0.006556839193056037*lm - 
          0.010593964984134207*lm^2) + CF*(0.09270746074346041 - 
          0.029903574311987494*lm + 0.017335579064946885*lm^2) + 
        0.004403022943213953*NM - 0.0036436486099420714*lm*NM + 
        0.001926175451660765*lm^2*NM + 0.005628468124701658*NL - 
        0.0036436486099420714*lm*NL + 0.001926175451660765*lm^2*NL + 
        0.003906496320922511*NH - 0.0036436486099420714*lm*NH + 
        0.001926175451660765*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(0.002288653657764846 + 0.006587679808905824*lm - 
          0.01048413333380134*lm^2) + CF*(0.09191243170505184 - 
          0.02975525456418055*lm + 0.017155854546220376*lm^2) + 
        0.004366777680919674*NM - 0.0036238404061352536*lm*NM + 
        0.0019062060606911528*lm^2*NM + 0.005589411513003818*NL - 
        0.0036238404061352536*lm*NL + 0.0019062060606911528*lm^2*NL + 
        0.0038915869774641242*NH - 0.0036238404061352536*lm*NH + 
        0.0019062060606911528*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(0.0022132165662375664 + 0.0066175375779583415*lm - 
          0.01037556605567557*lm^2) + CF*(0.09112516728196807 - 
          0.029607614930815714*lm + 0.016978199000196384*lm^2) + 
        0.004330995553982471*NM - 0.003604146084909086*lm*NM + 
        0.001886466555577376*lm^2*NM + 0.005550668927599691*NL - 
        0.003604146084909086*lm*NL + 0.001886466555577376*lm^2*NL + 
        0.0038767060501610404*NH - 0.003604146084909086*lm*NH + 
        0.001886466555577376*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(0.002139417106425622 + 0.006646423120083936*lm - 
          0.010268248595038257*lm^2) + CF*(0.09034560530214975 - 
          0.029460646447024775*lm + 0.0168025886100626*lm^2) + 
        0.004295670622726282*NM - 0.003584564209115023*lm*NM + 
        0.0018669542900069558*lm^2*NM + 0.005512239310650871*NL - 
        0.003584564209115023*lm*NL + 0.0018669542900069558*lm^2*NL + 
        0.0038618536863725865*NH - 0.003584564209115023*lm*NH + 
        0.0018669542900069558*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(0.0020672093873667532 + 0.006674347192122478*lm - 
          0.010162166520950982*lm^2) + CF*(0.08957368327089027 - 
          0.029314340596103435*lm + 0.01662899976155615*lm^2) + 
        0.0042607969571311025*NM - 0.0035650933951514216*lm*NM + 
        0.0018476666401729058*lm^2*NM + 0.005474121512014409*NL - 
        0.0035650933951514216*lm*NL + 0.0018476666401729058*lm^2*NL + 
        0.003847030041551265*NH - 0.0035650933951514216*lm*NH + 
        0.0018476666401729058*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(0.0019965490076621216 + 0.00670132067458219*lm - 
          0.01005730552750526*lm^2) + CF*(0.08880933841115113 - 
          0.02916868929000765*lm + 0.01645740904500861*lm^2) + 
        0.0042263686410502*NM - 0.003545732310834343*lm*NM + 
        0.0018286010050009567*lm^2*NM + 0.005436314294614924*NL - 
        0.003545732310834343*lm*NL + 0.0018286010050009567*lm^2*NL + 
        0.003832235278737308*NH - 0.003545732310834343*lm*NH + 
        0.0018286010050009567*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(0.0019273930057861416 + 0.006727354558908726*lm - 
          0.009953651434936844*lm^2) + CF*(0.08805250770230252 - 
          0.02902368485053799*lm + 0.01628779325716938*lm^2) + 
        0.004192379776166288*NM - 0.0035264796733406913*lm*NM + 
        0.0018097548063521537*lm^2*NM + 0.005398816339589117*NL - 
        0.0035264796733406913*lm*NL + 0.0018097548063521537*lm^2*NL + 
        0.0038174695680679993*NH - 0.0035264796733406913*lm*NH + 
        0.0018097548063521537*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(0.001859699812004758 + 0.006752459935305267*lm - 
          0.0098511901906111*lm^2) + CF*(0.08730312791733406 - 
          0.028879319991192347*lm + 0.016120129402818165*lm^2) + 
        0.004158824485698648*NM - 0.0035073342472217084*lm*NM + 
        0.0017911254892020183*lm^2*NM + 0.005361626251211252*NL - 
        0.0035073342472217084*lm*NL + 0.0017911254892020183*lm^2*NL + 
        0.00380273308630158*NH - 0.0035073342472217084*lm*NH + 
        0.0017911254892020183*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(0.0017934292018544147 + 0.00677664798108491*lm - 
          0.009749907869885792*lm^2) + CF*(0.08656113565857951 - 
          0.028735587799667773*lm + 0.015954394696176752*lm^2) + 
        0.004125696917872751*NM - 0.0034882948424848777*lm*NM + 
        0.0017727105217974167*lm^2*NM + 0.005324742561607844*NL - 
        0.0034882948424848777*lm*NL + 0.0017727105217974167*lm^2*NL + 
        0.0037880260163555847*NH - 0.0034882948424848777*lm*NH + 
        0.0017727105217974167*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(0.0017285422511350765 + 0.006799929949537122*lm - 
          0.009649790676857246*lm^2) + CF*(0.08582646739199876 - 
          0.028592481720992453*lm + 0.015790566562130036*lm^2) + 
        0.004092991249163416*NM - 0.0034693603127423102*lm*NM + 
        0.0017545073957922265*lm^2*NM + 0.00528816373526955*NL - 
        0.0034693603127423102*lm*NL + 0.0017545073957922265*lm^2*NL + 
        0.003773348546859399*NH - 0.0034693603127423102*lm*NH + 
        0.0017545073957922265*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(0.0016650012923717687 + 0.006822317159290555*lm - 
          0.009550824944995668*lm^2) + CF*(0.0850990594800597 - 
          0.028449995541269268*lm + 0.015628622637265638*lm^2) + 
        0.004060701687322149*NM - 0.0034505295534237265*lm*NM + 
        0.0017365136263628488*lm^2*NM + 0.00525188817336795*NL - 
        0.0034505295534237265*lm*NL + 0.0017365136263628488*lm^2*NL + 
        0.0037587008717208537*NH - 0.0034505295534237265*lm*NH + 
        0.0017365136263628488*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(0.001602769872700199 + 0.006843820984154962*lm - 
          0.009452997137675145*lm^2) + CF*(0.08437884821326141 - 
          0.02830812337201272*lm + 0.015468540770741146*lm^2) + 
        0.004028822474198811*NM - 0.0034318015000521754*lm*NM + 
        0.0017187267523045718*lm^2*NM + 0.0052159142178846785*NL - 
        0.0034318015000521754*lm*NL + 0.0017187267523045718*lm^2*NL + 
        0.003744083189706636*NH - 0.0034318015000521754*lm*NH + 
        0.0017187267523045718*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(0.0015418127131331246 + 0.0068644528434254745*lm - 
          0.009356293848603576*lm^2) + CF*(0.08366576984033938 - 
          0.02816685963506138*lm + 0.01531029902498767*lm^2) + 
        0.003997347888367412*NM - 0.0034131751265806657*lm*NM + 
        0.001701144336109741*lm^2*NM + 0.005180240155560084*NL - 
        0.0034131751265806657*lm*NL + 0.001701144336109741*lm^2*NL + 
        0.0037294957040363073*NH - 0.0034131751265806657*lm*NH + 
        0.001701144336109741*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(0.0014820956691652153 + 0.006884224192632966*lm - 
          0.009260701802157637*lm^2) + CF*(0.08295976059719312 - 
          0.028026199048048345*lm + 0.01515387567625795*lm^2) + 
        0.003966272247565367*NM - 0.003394649443787926*lm*NM + 
        0.0016837639640286612*lm^2*NM + 0.005144864221668356*NL - 
        0.003394649443787926*lm*NL + 0.0016837639640286612*lm^2*NL + 
        0.003714938621989701*NH - 0.003394649443787926*lm*NH + 
        0.0016837639640286612*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(0.001423585692675237 + 0.00690314651472469*lm - 
          0.00916620785362758*lm^2) + CF*(0.08226075673457484 - 
          0.027886136610412633*lm + 0.014999249215026947*lm^2) + 
        0.003935589910955212*NM - 0.003376223497731532*lm*NM + 
        0.0016665832461141054*lm^2*NM + 0.0051097846036258195*NL - 
        0.003376223497731532*lm*NL + 0.0016665832461141054*lm^2*NL + 
        0.0037004121545274682*NH - 0.003376223497731532*lm*NH + 
        0.0016665832461141054*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(0.0013662507950854533 + 0.006921231311659823*lm - 
          0.009072798989376542*lm^2) + CF*(0.0815686945445779 - 
          0.027746667589934774*lm + 0.014846398346252525*lm^2) + 
        0.0039052952812173554*NM - 0.0033578963682566886*lm*NM + 
        0.0016495998162502805*lm^2*NM + 0.0050749994444388505*NL - 
        0.0033578963682566886*lm*NL + 0.0016495998162502805*lm^2*NL + 
        0.003685916515924532*NH - 0.0033578963682566886*lm*NH + 
        0.0016495998162502805*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(0.0013100600117391897 + 0.006938490096405044*lm - 
          0.008980462326918785*lm^2) + CF*(0.08088351038596212 - 
          0.02760778750978027*lm + 0.014695301989503466*lm^2) + 
        0.003875382806482134*NM - 0.003339667167558983*lm*NM + 
        0.0016328113321670517*lm^2*NM + 0.005040506845997656*NL - 
        0.003339667167558983*lm*NL + 0.0016328113321670517*lm^2*NL + 
        0.0036714519234162172*NH - 0.003339667167558983*lm*NH + 
        0.0016328113321670517*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(0.0012549833674585543 + 0.006954934385315667*lm - 
          0.008889185114921098*lm^2) + CF*(0.0802051407083529 - 
          0.027469492136034897*lm + 0.014545939278961797*lm^2) + 
        0.00384584698210905*NM - 0.0033215350387994663*lm*NM + 
        0.0016162154754401996*lm^2*NM + 0.0050063048722219184*NL - 
        0.0033215350387994663*lm*NL + 0.0016162154754401996*lm^2*NL + 
        0.003657018596856805*NH - 0.0033215350387994663*lm*NH + 
        0.0016162154754401996*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(0.0012009918432453217 + 0.006970575690888298*lm - 
          0.008798954733131486*lm^2) + CF*(0.07953352207534974 - 
          0.02733177746571635*lm + 0.014398289563306067*lm^2) + 
        0.003816682352320761*NM - 0.0033034991547704474*lm*NM + 
        0.001599809951478452*lm^2*NM + 0.004972391552064126*NL - 
        0.0033034991547704474*lm*NL + 0.001599809951478452*lm^2*NL + 
        0.0036426167583902594*NH - 0.0033034991547704474*lm*NH + 
        0.001599809951478452*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(0.001148057344089011 + 0.006985425514871439*lm - 
          0.008709758692238969*lm^2) + CF*(0.07886859118657903 - 
          0.027194639715246934*lm + 0.014252332405481948*lm^2) + 
        0.003787883511699067*NM - 0.0032855587166104364*lm*NM + 
        0.0015835924894979942*lm^2*NM + 0.004938764882376147*NL - 
        0.0032855587166104364*lm*NL + 0.0015835924894979942*lm^2*NL + 
        0.003628246632132888*NH - 0.0032855587166104364*lm*NH + 
        0.0015835924894979942*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(0.0010961526678471688 + 0.006999495341720827*lm - 
          0.008621584633668276*lm^2) + CF*(0.07821028489872558 - 
          0.027058075309372532*lm + 0.01410804758236627*lm^2) + 
        0.0037594451065498195*NM - 0.0032677129525666934*lm*NM + 
        0.001567560842485141*lm^2*NM + 0.004905422830644474*NL - 
        0.0032677129525666934*lm*NL + 0.001567560842485141*lm^2*NL + 
        0.0036139084438676734*NH - 0.0032677129525666934*lm*NH + 
        0.001567560842485141*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(0.0010452514751638539 + 0.007012796632386735*lm - 
          0.008534420329312961*lm^2) + CF*(0.07755854024557571 - 
          0.026922080870513326*lm + 0.013965415084330302*lm^2) + 
        0.0037313618361434*NM - 0.0032499611168038934*lm*NM + 
        0.0015517127871478114*lm^2*NM + 0.004872363337599307*NL - 
        0.0032499611168038934*lm*NL + 0.0015517127871478114*lm^2*NL + 
        0.0035996024207500255*NH - 0.0032499611168038934*lm*NH + 
        0.0015517127871478114*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(0.0009953282603932703 + 0.00702534081842086*lm - 
          0.008448253681210372*lm^2) + CF*(0.07691329445710474 - 
          0.026786653208532248*lm + 0.013824415114707882*lm^2) + 
        0.003703628453837118*NM - 0.0032323024882574326*lm*NM + 
        0.0015360461238564313*lm^2*NM + 0.004839584319702507*NL - 
        0.0032323024882574326*lm*NL + 0.0015360461238564313*lm^2*NL + 
        0.0035853287910247015*NH - 0.0032323024882574326*lm*NH + 
        0.0015360461238564313*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(0.0009463583234964435 + 0.0070371392963907865*lm - 
          0.008363072721161718*lm^2) + CF*(0.07627448497764042 - 
          0.02665178931090737*lm + 0.013685028089173719*lm^2) + 
        0.0036762397680856033*NM - 0.003214736369529962*lm*NM + 
        0.0015205586765748577*lm^2*NM + 0.004807083671519214*NL - 
        0.003214736369529962*lm*NL + 0.0015205586765748577*lm^2*NL + 
        0.0035710877837536402*NH - 0.003214736369529962*lm*NH + 
        0.0015205586765748577*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(0.0008983177428797469 + 0.007048203422590417*lm - 
          0.008278865610300374*lm^2) + CF*(0.07564204948313304 - 
          0.026517486333294912*lm + 0.013547234635036976*lm^2) + 
        0.0036491906433450093*NM - 0.0031972620858297493*lm*NM + 
        0.0015052482927818862*lm^2*NM + 0.004774859267977821*NL - 
        0.0031972620858297493*lm*NL + 0.0015052482927818862*lm^2*NL + 
        0.0035568796285544504*NH - 0.0031972620858297493*lm*NH + 
        0.0015052482927818862*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(0.0008511833491449959 + 0.007058544508035118*lm - 
          0.008195620638611404*lm^2) + CF*(0.07501592589756254 - 
          0.026383741590469842*lm + 0.013411015590455024*lm^2) + 
        0.00362247600087659*NM - 0.00317987898394952*lm*NM + 
        0.0014901128433838916*lm^2*NM + 0.004742908966522746*NL - 
        0.00317987898394952*lm*NL + 0.0014901128433838916*lm^2*NL + 
        0.003542704555349307*NH - 0.00317987898394952*lm*NH + 
        0.0014901128433838916*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(0.0008049326997217053 + 0.007068173813730698*lm - 
          0.008113326224405127*lm^2) + CF*(0.07439605240851158 - 
          0.026250552547631416*lm + 0.013276352003572028*lm^2) + 
        0.0035960908194549723*NM - 0.003162586431284454*lm*NM + 
        0.001475150222619114*lm^2*NM + 0.004711230609164334*NL - 
        0.003162586431284454*lm*NL + 0.001475150222619114*lm^2*NL + 
        0.003528562794124*NH - 0.003162586431284454*lm*NH + 
        0.001475150222619114*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(0.0007595440543529718 + 0.00707710254620566*lm - 
          0.00803197091374751*lm^2) + CF*(0.07378236748193352 - 
          0.026117916812061368*lm + 0.013143225131586835*lm^2) + 
        0.0035700301359861968*NM - 0.003145383814888056*lm*NM + 
        0.0014603583479540928*lm^2*NM + 0.00467982202443004*NL - 
        0.003145383814888056*lm*NL + 0.0014603583479540928*lm^2*NL + 
        0.003514454574696882*NH - 0.003145383814888056*lm*NH + 
        0.0014603583479540928*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(0.0007149963514072853 + 0.007085341853296561*lm - 
          0.007951543379849931*lm^2) + CF*(0.07317480987614251 - 
          0.025985832125122763*lm + 0.013011616439754434*lm^2) + 
        0.0035442890460404015*NM - 0.003128270540564648*lm*NM + 
        0.0014457351599727148*lm^2*NM + 0.004648681029220898*NL - 
        0.003128270540564648*lm*NL + 0.0014457351599727148*lm^2*NL + 
        0.00350038012649747*NH - 0.003128270540564648*lm*NH + 
        0.0014457351599727148*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(0.0006712691849894041 + 0.0070929028201766*lm - 
          0.007872032422420867*lm^2) + CF*(0.07257331865505322 - 
          0.025854296354587906*lm + 0.012881507600325054*lm^2) + 
        0.0035188627043037817*NM - 0.0031112460319972684*lm*NM + 
        0.0014312786222583393*lm^2*NM + 0.004617805430577122*NL - 
        0.0031112460319972684*lm*NL + 0.0014312786222583393*lm^2*NL + 
        0.0034863396783544522*NH - 0.0031112460319972684*lm*NH + 
        0.0014312786222583393*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(0.000628342782824225 + 0.00709979646561789*lm - 
          0.0077934269669818305*lm^2) + CF*(0.07197783320069606 - 
          0.025723307487283995*lm + 0.012752880491424813*lm^2) + 
        0.0034937463249542734*NM - 0.0030943097299097923*lm*NM + 
        0.0014169867212694238*lm^2*NM + 0.004587193027356545*NL - 
        0.0030943097299097923*lm*NL + 0.0014169867212694238*lm^2*NL + 
        0.003472333458292853*NH - 0.0030943097299097923*lm*NH + 
        0.0014169867212694238*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(0.0005861979848883763 + 0.007106033738478208*lm - 
          0.00771571606414989*lm^2) + CF*(0.07138829322503376 - 
          0.025592863622045544*lm + 0.012625717195881639*lm^2) + 
        0.0034689351819651884*NM - 0.003077461091262128*lm*NM + 
        0.0014028574662090709*lm^2*NM + 0.004556841611829479*NL - 
        0.003077461091262128*lm*NL + 0.0014028574662090709*lm^2*NL + 
        0.0034583616933401146*NH - 0.003077461091262128*lm*NH + 
        0.0014028574662090709*lm^2*NH)}, 
     {1., 1.6744898834019205*^-8*CF*NC*
       (108.*CF*(39152.13306039918 - 14080.*lm + 6912.*lm^2) - 
        6.*CA*(-5422.708413722624 - 70784.*lm + 76032.*lm^2) + 
        205699.93545396117*NM - 182784.*lm*NM + 82944.*lm^2*NM + 
        270336.*NL - 182784.*lm*NL + 82944.*lm^2*NL + 
        205699.93545396117*NH - 182784.*lm*NH + 82944.*lm^2*NH)}}
 
CbarTable["p", 2, 3] = {{0., -1.286008230452675*^-7*CF*NC*
       (CF*(-769577.7091909414 - 97666.17974587942*lm - 777600.*lm^2) + 
        4.*CA*(-6575.71205023619 + 127610.61095281024*lm + 59400.*lm^2) + 
        20.*((-5945.359133912704 - 1891.294943738554*lm - 2160.*lm^2)*NM + 
          (-5945.359133912704 - 1891.294943738554*lm - 2160.*lm^2)*NL + 
          (987.1190910339575 - 1891.294943738554*lm - 2160.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(0.00875286390845238 - 0.06547315404108738*lm - 
          0.03100079897644475*lm^2) + CF*(0.10345361881797978 + 
          0.009055611736680633*lm + 0.10145716028654646*lm^2) + 
        0.014728844750835345*NM + 0.004730471219532804*lm*NM + 
        0.0056365089048081365*lm^2*NM + 0.014728024225846436*NL + 
        0.004730471219532804*lm*NL + 0.0056365089048081365*lm^2*NL - 
        0.0025618281565920886*NH + 0.004730471219532804*lm*NH + 
        0.0056365089048081365*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(0.01353716560398896 - 0.0653361023001587*lm - 
          0.03141599648147472*lm^2) + CF*(0.10734970513143262 + 
          0.005858539910756929*lm + 0.10281598848482637*lm^2) + 
        0.014240459749118325*NM + 0.004609473959687594*lm*NM + 
        0.005711999360268132*lm^2*NM + 0.014235252485434488*NL + 
        0.004609473959687594*lm*NL + 0.005711999360268132*lm^2*NL - 
        0.0025833904631262362*NH + 0.004609473959687594*lm*NH + 
        0.005711999360268132*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(0.01768151412409602 - 0.06523853044070677*lm - 
          0.03179766023965615*lm^2) + CF*(0.11066024754134078 + 
          0.0030126628310355856*lm + 0.1040650698752383*lm^2) + 
        0.01383254831080265*NM + 0.004503414735414684*lm*NM + 
        0.005781392770846572*lm^2*NM + 0.013818571879257986*NL + 
        0.004503414735414684*lm*NL + 0.005781392770846572*lm^2*NL - 
        0.0026034578516877993*NH + 0.004503414735414684*lm*NH + 
        0.005781392770846572*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(0.021199151348150334 - 0.0651780443610215*lm - 
          0.03214392679638835*lm^2) + CF*(0.11344414402060875 + 
          0.0005224810170037021*lm + 0.10519830587908913*lm^2) + 
        0.013500954883768382*NM + 0.004412289468128919*lm*NM + 
        0.005844350326616062*lm^2*NM + 0.013474160392408318*NL + 
        0.004412289468128919*lm*NL + 0.005844350326616062*lm^2*NL - 
        0.002621942903607973*NH + 0.004412289468128919*lm*NH + 
        0.005844350326616062*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(0.02412662146172566 - 0.06514919361842553*lm - 
          0.03245389221214417*lm^2) + CF*(0.11576791361473832 - 
          0.001623859413479113*lm + 0.10621273814883547*lm^2) + 
        0.01323835139123437*NM + 0.004335316344341527*lm*NM + 
        0.005900707674935304*lm^2*NM + 0.013195477086319563*NL + 
        0.004335316344341527*lm*NL + 0.005900707674935304*lm^2*NL - 
        0.0026387774142200204*NH + 0.004335316344341527*lm*NH + 
        0.005900707674935304*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(0.026509823822952427 - 0.06514539646752152*lm - 
          0.032727303610271*lm^2) + CF*(0.11769486025241814 - 
          0.003446224716434315*lm + 0.10710753908815963*lm^2) + 
        0.013036422619557144*NM + 0.004271357199982523*lm*NM + 
        0.005950418838231091*lm^2*NM + 0.012975164923168483*NL + 
        0.004271357199982523*lm*NL + 0.005950418838231091*lm^2*NL - 
        0.002653908508311217*NH + 0.004271357199982523*lm*NH + 
        0.005950418838231091*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(0.028397790485102988 - 0.06515981919149917*lm - 
          0.03296437430138055*lm^2) + CF*(0.11928189266586779 - 
          0.004968391864232621*lm + 0.10788340680451816*lm^2) + 
        0.01288679503079537*NM + 0.004219120179953111*lm*NM + 
        0.005993522600251009*lm^2*NM + 0.01280583855721231*NL + 
        0.004219120179953111*lm*NL + 0.005993522600251009*lm^2*NL - 
        0.0026672963403222226*NH + 0.004219120179953111*lm*NH + 
        0.005993522600251009*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(0.029839542613599657 - 0.06518582175636264*lm - 
          0.03316565992768213*lm^2) + CF*(0.12057883328352298 - 
          0.006215770136808099*lm + 0.10854215976332335*lm^2) + 
        0.012781472817410657*NM + 0.0041772694269824676*lm*NM + 
        0.0060301199868512964*lm^2*NM + 0.01268044580044112*NL + 
        0.0041772694269824676*lm*NL + 0.0060301199868512964*lm^2*NL - 
        0.0026789124932719488*NH + 0.0041772694269824676*lm*NH + 
        0.0060301199868512964*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(0.030882421540077695 - 0.06521718989032808*lm - 
          0.03333197005745208*lm^2) + CF*(0.12162865843290507 - 
          0.007214056359084292*lm + 0.10908644746075227*lm^2) + 
        0.012713043251586443*NM + 0.004144487735359995*lm*NM + 
        0.006060358192264015*lm^2*NM + 0.012592433923502837*NL + 
        0.004144487735359995*lm*NL + 0.006060358192264015*lm^2*NL - 
        0.002688738740911876*NH + 0.004144487735359995*lm*NH + 
        0.006060358192264015*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(0.03157120428793183 - 0.06524825132354897*lm - 
          0.033464302501207986*lm^2) + CF*(0.12246808921860172 - 
          0.00798841966398519*lm + 0.10951953545849887*lm^2) + 
        0.012674763150200476*NM + 0.004119512884993831*lm*NM + 
        0.006084418636583271*lm^2*NM + 0.012535817427459272*NL + 
        0.004119512884993831*lm*NL + 0.006084418636583271*lm^2*NL - 
        0.0026967660209508302*NH + 0.004119512884993831*lm*NH + 
        0.006084418636583271*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(0.03194766438530788 - 0.06527392549607845*lm - 
          0.03356379318239765*lm^2) + CF*(0.12312829112212827 - 
          0.008563006964078091*lm + 0.10984514132421047*lm^2) + 
        0.012660580800329488*NM + 0.004101158279393321*lm*NM + 
        0.006102507851345027*lm^2*NM + 0.012505193343746444*NL + 
        0.004101158279393321*lm*NL + 0.006102507851345027*lm^2*NL - 
        0.002702993542617253*NH + 0.004101158279393321*lm*NH + 
        0.006102507851345027*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(0.03205039563178455 - 0.06528973383206099*lm - 
          0.033631677165811884*lm^2) + CF*(0.12363557622919176 - 
          0.00896065134148074*lm + 0.11006730708811163*lm^2) + 
        0.012665122115004167*NM + 0.004088323831922388*lm*NM + 
        0.006114850393783979*lm^2*NM + 0.012495727996007022*NL + 
        0.004088323831922388*lm*NL + 0.006114850393783979*lm^2*NL - 
        0.0027074279870824077*NH + 0.004088323831922388*lm*NH + 
        0.006114850393783979*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(0.03191479435860047 - 0.06529178639455555*lm - 
          0.033669257970545055*lm^2) + CF*(0.12401206182142069 - 
          0.009202712579856113*lm + 0.11019029881269289*lm^2) + 
        0.012683657163168171*NM + 0.004080000640536864*lm*NM + 
        0.006121683267371828*lm^2*NM + 0.012503128418243123*NL + 
        0.004080000640536864*lm*NL + 0.006121683267371828*lm^2*NL - 
        0.0027100827771979878*NH + 0.004080000640536864*lm*NH + 
        0.006121683267371828*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(0.03157313750207352 - 0.06527675455447146*lm - 
          0.033677883196911944*lm^2) + CF*(0.12427626700956197 - 
          0.009309005265750186*lm + 0.11021852682625728*lm^2) + 
        0.012712056495776048*NM + 0.004075271658552376*lm*NM + 
        0.006123251490347627*lm^2*NM + 0.012523606000000728*NL + 
        0.004075271658552376*lm*NL + 0.006123251490347627*lm^2*NL - 
        0.002710977402660762*NH + 0.004075271658552376*lm*NH + 
        0.006123251490347627*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(0.031054717593309696 - 0.06524183572137568*lm - 
          0.03365892506341753*lm^2) + CF*(0.12444364253181837 - 
          0.00929778537299725*lm + 0.11015648202573008*lm^2) + 
        0.012746742902668803*NM + 0.004073309785905573*lm*NM + 
        0.0061198045569850045*lm^2*NM + 0.012553836811647756*NL + 
        0.004073309785905573*lm*NL + 0.0061198045569850045*lm^2*NL - 
        0.0027101367921282186*NH + 0.004073309785905573*lm*NH + 
        0.0061198045569850045*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(0.030386009948062384 - 0.06518471400885474*lm - 
          0.03361376482269137*lm^2) + CF*(0.1245270353122284 - 
          0.009185775830324887*lm + 0.11000868487426267*lm^2) + 
        0.012784642007308507*NM + 0.004073374323631784*lm*NM + 
        0.006111593604125704*lm^2*NM + 0.012590921257804056*NL + 
        0.004073374323631784*lm*NL + 0.006111593604125704*lm^2*NL - 
        0.0027075907269179618*NH + 0.004073374323631784*lm*NH + 
        0.006111593604125704*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(0.02959085611158714 - 0.06510351934071103*lm - 
          0.033543780280156*lm^2) + CF*(0.12453709235320469 - 
          0.008988217731267652*lm + 0.10977964455323781*lm^2) + 
        0.012823133752959915*NM + 0.00407480642687004*lm*NM + 
        0.006098869141846546*lm^2*NM + 0.01263234462696629*NL + 
        0.00407480642687004*lm*NL + 0.006098869141846546*lm^2*NL - 
        0.002703373292733984*NH + 0.00407480642687004*lm*NH + 
        0.006098869141846546*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(0.028690653198648323 - 0.0649967866219894*lm - 
          0.03345033581907166*lm^2) + CF*(0.12448260972675419 - 
          0.008718937923707403*lm + 0.10947382631696181*lm^2) + 
        0.012860005991543183*NM + 0.004077023989667442*lm*NM + 
        0.006081879239831211*lm^2*NM + 0.012675939443248806*NL + 
        0.004077023989667442*lm*NL + 0.006081879239831211*lm^2*NL - 
        0.0026975223669200433*NH + 0.004077023989667442*lm*NH + 
        0.006081879239831211*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(0.027704542408236797 - 0.0648634160169187*lm - 
          0.03333477446601532*lm^2) + CF*(0.12437083269815066 - 
          0.008390426484119593*lm + 0.10909562552514106*lm^2) + 
        0.012893410853402539*NM + 0.004079516258874234*lm*NM + 
        0.0060608680847300585*lm^2*NM + 0.012719850113417384*NL + 
        0.004079516258874234*lm*NL + 0.0060608680847300585*lm^2*NL - 
        0.002690079139352509*NH + 0.004079516258874234*lm*NH + 
        0.0060608680847300585*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(0.026649592406506436 - 0.0647026349859244*lm - 
          0.03319841162759526*lm^2) + CF*(0.12420771281941083 - 
          0.008013919498163139*lm + 0.10864934714485722*lm^2) + 
        0.0129218242358316*NM + 0.0040818383811377645*lm*NM + 
        0.006036074841380956*lm^2*NM + 0.012762500102712905*NL + 
        0.0040818383811377645*lm*NL + 0.006036074841380956*lm^2*NL - 
        0.0026810876654318363*NH + 0.0040818383811377645*lm*NH + 
        0.006036074841380956*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(0.025540974893674236 - 0.06451396246971827*lm - 
          0.03304253020238995*lm^2) + CF*(0.1239981274117146 - 
          0.00759948391823071*lm + 0.1081391897532762*lm^2) + 
        0.012944008530378377*NM + 0.004083606022040358*lm*NM + 
        0.0060077327640709*lm^2*NM + 0.012802561709380893*NL + 
        0.004083606022040358*lm*NL + 0.0060077327640709*lm^2*NL - 
        0.002670594449820645*NH + 0.004083606022040358*lm*NH + 
        0.0060077327640709*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(0.024392130770321763 - 0.06429717542843177*lm - 
          0.03286837682840875*lm^2) + CF*(0.12374606634759433 - 
          0.0071561022305489655*lm + 0.10756923325661046*lm^2) + 
        0.012958978570556143*NM + 0.004084490150661604*lm*NM + 
        0.005976068514256136*lm^2*NM + 0.012838928405658529*NL + 
        0.004084490150661604*lm*NL + 0.005976068514256136*lm^2*NL - 
        0.00265864805967231*NH + 0.004084490150661604*lm*NH + 
        0.005976068514256136*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(0.023214926067144873 - 0.0640522778209303*lm - 
          0.032677159070333056*lm^2) + CF*(0.12345479051602759 - 
          0.006691755357424642*lm + 0.10694342968472638*lm^2) + 
        0.012965970695328548*NM + 0.004084212050340008*lm*NM + 
        0.005941301649151466*lm^2*NM + 0.012870689650581557*NL + 
        0.004084212050340008*lm*NL + 0.005941301649151466*lm^2*NL - 
        0.0026452987661370435*NH + 0.004084212050340008*lm*NH + 
        0.005941301649151466*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(0.022019797311445075 - 0.06377947202605926*lm - 
          0.032470043385556924*lm^2) + CF*(0.12312696584351882 - 
          0.006213502723236624*lm + 0.10626559653454992*lm^2) + 
        0.012964414772016142*NM + 0.0040825385932042125*lm*NM + 
        0.005903644251919441*lm^2*NM + 0.012897108043573469*NL + 
        0.0040825385932042125*lm*NL + 0.005903644251919441*lm^2*NL - 
        0.002630598212947184*NH + 0.0040825385932042125*lm*NH + 
        0.005903644251919441*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(0.020815886347778974 - 0.06347913265167682*lm - 
          0.032248153735836796*lm^2) + CF*(0.12276477627002219 - 
          0.005727558779679817*lm + 0.10553941222637497*lm^2) + 
        0.012953908993531623*NM + 0.004079277799450079*lm*NM + 
        0.005863300679243054*lm^2*NM + 0.012917598668431608*NL + 
        0.004079277799450079*lm*NL + 0.005863300679243054*lm^2*NL - 
        0.002614599110884943*NH + 0.004079277799450079*lm*NH + 
        0.005863300679243054*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(0.019611164859360836 - 0.06315178264073903*lm - 
          0.03201257073379582*lm^2) + CF*(0.12237001864778019 - 
          0.00523936555403135*lm + 0.10476841331060449*lm^2) + 
        0.012934197251398804*NM + 0.004074274690495668*lm*NM + 
        0.0058204674061446944*lm^2*NM + 0.012931710469152908*NL + 
        0.004074274690495668*lm*NL + 0.0058204674061446944*lm^2*NL - 
        0.002597354956933172*NH + 0.004074274690495668*lm*NH + 
        0.0058204674061446944*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(0.018412548985466654 - 0.06279807156074234*lm - 
          0.03176433123179419*lm^2) + CF*(0.1219441821456247 - 
          0.004753660980274163*lm + 0.10395599312223551*lm^2) + 
        0.012905148882663474*NM + 0.004067407436744582*lm*NM + 
        0.005775332951235306*lm^2*NM + 0.012939109498137619*NL + 
        0.004067407436744582*lm*NL + 0.005775332951235306*lm^2*NL - 
        0.002578919776908192*NH + 0.004067407436744582*lm*NH + 
        0.005775332951235306*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(0.017226004522124073 - 0.06241875594950626*lm - 
          0.031504428275660815*lm^2) + CF*(0.12148851439966685 - 
          0.004274542915701103*lm + 0.10310540162943539*lm^2) + 
        0.012866740592043228*NM + 0.004058583794798635*lm*NM + 
        0.005728077868301966*lm^2*NM + 0.012939563881050466*NL + 
        0.004058583794798635*lm*NL + 0.005728077868301966*lm^2*NL - 
        0.00255934789037618*NH + 0.004058583794798635*lm*NH + 
        0.005728077868301966*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(0.016056643245577266 - 0.062014681583762284*lm - 
          0.03123381135815233*lm^2) + CF*(0.12100407635064664 - 
          0.003805528848844229*lm + 0.10221974626304399*lm^2) + 
        0.012819040358082155*NM + 0.0040477378249132645*lm*NM + 
        0.005678874792391333*lm^2*NM + 0.012932930349236638*NL + 
        0.0040477378249132645*lm*NL + 0.005678874792391333*lm^2*NL - 
        0.0025386936966624685*NH + 0.0040477378249132645*lm*NH + 
        0.005678874792391333*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(0.014908810922278906 - 0.06158676753527785*lm - 
          0.030953386917278964*lm^2) + CF*(0.12049178744488986 - 
          0.003349611378267931*lm + 0.10130199354745842*lm^2) + 
        0.012762193142026366*NM + 0.0040348268767958825*lm*NM + 
        0.005627888530414357*lm^2*NM + 0.012919142198888532*NL + 
        0.0040348268767958825*lm*NL + 0.005627888530414357*lm^2*NL - 
        0.002517011480776814*NH + 0.0040348268767958825*lm*NH + 
        0.005627888530414357*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(0.01378616757396581 - 0.06113599188082529*lm - 
          0.030664019033211268*lm^2) + CF*(0.11995246264599159 - 
          0.002909309593350514*lm + 0.10035497138141869*lm^2) + 
        0.012696408229486797*NM + 0.004019828830150751*lm*NM + 
        0.0055752761878565945*lm^2*NM + 0.012898198545330716*NL + 
        0.004019828830150751*lm*NL + 0.0055752761878565945*lm^2*NL - 
        0.0024943552380970856*NH + 0.004019828830150751*lm*NH + 
        0.0055752761878565945*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(0.012691760557805394 - 0.060663378936149925*lm - 
          0.03036653028467018*lm^2) + CF*(0.11938684250426831 - 
          0.00248671652318548*lm + 0.09938137184073877*lm^2) + 
        0.01262194804693209*NM + 0.004002739575409366*lm*NM + 
        0.005521187324485487*lm^2*NM + 0.012870154750292469*NL + 
        0.004002739575409366*lm*NL + 0.005521187324485487*lm^2*NL - 
        0.002470778516678485*NH + 0.004002739575409366*lm*NH + 
        0.005521187324485487*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(0.011628091004038884 - 0.06016998788943108*lm - 
          0.030061702731752852*lm^2) + CF*(0.11879561735717181 - 
          0.0020835428423084975*lm + 0.09838375439482751*lm^2) + 
        0.012539118307126371*NM + 0.00398357071965623*lm*NM + 
        0.005465764133045973*lm^2*NM + 0.012835113909510004*NL + 
        0.00398357071965623*lm*NL + 0.005465764133045973*lm^2*NL - 
        0.0024463342760847003*NH + 0.00398357071965623*lm*NH + 
        0.005465764133045973*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(0.010597174130159927 - 0.05965690271600836*lm - 
          0.029750278997255932*lm^2) + CF*(0.11817944658300966 - 
          0.001701157035228831*lm + 0.09736454944556486*lm^2) + 
        0.012448259349424744*NM + 0.003962347502719157*lm*NM + 
        0.005409141635864714*lm^2*NM + 0.012793219297210348*NL + 
        0.003962347502719157*lm*NL + 0.005409141635864714*lm^2*NL - 
        0.0024210747616705643*NH + 0.003962347502719157*lm*NH + 
        0.005409141635864714*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(0.009600593923746143 - 0.05912522326296072*lm - 
          0.02943296342288524*lm^2) + CF*(0.11753897369953814 - 
          0.0013406222280878746*lm + 0.09632606211126078*lm^2) + 
        0.01234973855208874*NM + 0.003939106908630984*lm*NM + 
        0.005351447895070044*lm^2*NM + 0.012744647672829604*NL + 
        0.003939106908630984*lm*NL + 0.005351447895070044*lm^2*NL - 
        0.0023950513932821976*NH + 0.003939106908630984*lm*NH + 
        0.005351447895070044*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(0.00863955265728023 - 0.058576057399184846*lm - 
          0.02911042328041543*lm^2) + CF*(0.11687483798563178 - 
          0.0010027298969881074*lm + 0.0952704761904505*lm^2) + 
        0.012243943704239497*NM + 0.003913895958102765*lm*NM + 
        0.005292804232802806*lm^2*NM + 0.012689603363624062*NL + 
        0.003913895958102765*lm*NL + 0.005292804232802806*lm^2*NL - 
        0.0023683146673794853*NH + 0.003913895958102765*lm*NH + 
        0.005292804232802806*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(0.007714915668903382 - 0.05801051413371636*lm - 
          0.02878329002099004*lm^2) + CF*(0.1161876832058508 - 
          0.00068803066001111*lm + 0.09419985825051286*lm^2) + 
        0.012131277234435143*NM + 0.0038867701682151964*lm*NM + 
        0.0052333254583618255*lm^2*NM + 0.012628313044598893*NL + 
        0.0038867701682151964*lm*NL + 0.0052333254583618255*lm^2*NL - 
        0.00234091407162649*NH + 0.0038867701682151964*lm*NH + 
        0.0052333254583618255*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(0.006827251814020309 - 0.05742969761202305*lm - 
          0.02845216054841819*lm^2) + CF*(0.11547816393200648 - 
          0.0003968623547259467*lm + 0.09311616179482317*lm^2) + 
        0.012012151200692886*NM + 0.0038577921661884125*lm*NM + 
        0.005173120099712398*lm^2*NM + 0.012561021144390219*NL + 
        0.0038577921661884125*lm*NL + 0.005173120099712398*lm^2*NL - 
        0.002312898011037407*NH + 0.0038577921661884125*lm*NH + 
        0.005173120099712398*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(0.005976869964895485 - 0.05683470190677457*lm - 
          0.028117598504600112*lm^2) + CF*(0.11474694988041072 - 
          0.00012937559588394623*lm + 0.09202123146960037*lm^2) + 
        0.0118869829523129*NM + 0.0038270304447953515*lm*NM + 
        0.00511229063720002*lm^2*NM + 0.012487985812395174*NL + 
        0.0038270304447953515*lm*NL + 0.00511229063720002*lm^2*NL - 
        0.002284313744808438*NH + 0.0038270304447953515*lm*NH + 
        0.00511229063720002*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(0.0051638516079565225 - 0.05622660652608803*lm - 
          0.02778013555715922*lm^2) + CF^2*(0.1139947292194129 + 
          0.00011444300038284823*lm + 0.09091680727797563*lm^2) + 
        CF*((0.011756192270048331 + 0.0037945582477146985*lm + 
            0.005050933737665313*lm^2)*NM + (0.012409475388567105 + 
            0.0037945582477146985*lm + 0.005050933737665313*lm^2)*NL + 
          (-0.002255207333009006 + 0.0037945582477146985*lm + 
            0.005050933737665313*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(0.004388081279229751 - 0.05560647256842195*lm - 
          0.02744027268102271*lm^2) + CF^2*(0.11322220831269239 + 
          0.0003347497487264731*lm + 0.08980452877425614*lm^2) + 
        CF*((0.011620195674810357 + 0.0037604525738565873*lm + 
            0.0049891404874586745*lm^2)*NM + (0.012325765322903042 + 
            0.0037604525738565873*lm + 0.0049891404874586745*lm^2)*NL + 
          (-0.0022256235923487186 + 0.0037604525738565873*lm + 
            0.0049891404874586745*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(0.003649272136115215 - 0.054975339459116784*lm - 
          0.02709848142711749*lm^2) + CF^2*(0.11243011415085429 + 
          0.0005318248156126876*lm + 0.08868593921602089*lm^2) + 
        CF*((0.011479406825226001 + 0.003724793290423797*lm + 
            0.004926996623112271*lm^2)*NM + (0.012237135496776403 + 
            0.003724793290423797*lm + 0.004926996623112271*lm^2)*NL + 
          (-0.002195606060279009 + 0.003724793290423797*lm + 
            0.004926996623112271*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(0.0029469904115442236 - 0.05433422220904726*lm - 
          0.02675520517256807*lm^2) + CF^2*(0.11161919274036072 + 
          0.0007060549715346184*lm + 0.08756248965567733*lm^2) + 
        CF*((0.011334232508056924 + 0.003687662345182923*lm + 
            0.00486458275864874*lm^2)*NM + (0.012143867902940883 + 
            0.003687662345182923*lm + 0.00486458275864874*lm^2)*NL + 
          (-0.002165196966730247 + 0.003687662345182923*lm + 
            0.00486458275864874*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(0.002280676687065613 - 0.0536841091409594*lm - 
          0.026410860347827383*lm^2) + CF^2*(0.11079020825867526 + 
          0.0008579180265304736*lm + 0.08643554295652597*lm^2) + 
        CF*((0.011185071131915391 + 0.003649143069106942*lm + 
            0.004801974608695888*lm^2)*NM + (0.012046244645283153 + 
            0.003649143069106942*lm + 0.004801974608695888*lm^2)*NL + 
          (-0.0021344372128259377 + 0.003649143069106942*lm + 
            0.004801974608695888*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(0.0016496650451862144 - 0.0530259600338177*lm - 
          0.026065837637065617*lm^2) + CF^2*(0.1099439414657049 + 
          0.000987968810762408*lm + 0.08530637772130566*lm^2) + 
        CF*((0.01103231117086231 + 0.0036093195612078694*lm + 
            0.004739243206739203*lm^2)*NM + (0.011944546223264595 + 
            0.0036093195612078694*lm + 0.004739243206739203*lm^2)*NL + 
          (-0.0021033663559558487 + 0.0036093195612078694*lm + 
            0.004739243206739203*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(0.0010532001834060193 - 0.052360704639896734*lm - 
          0.025720503148906566*lm^2) + CF^2*(0.10908118775334609 + 
          0.0010968265712805445*lm + 0.08417619212369422*lm^2) + 
        CF*((0.010876329899143236 + 0.003568276148002845*lm + 
            0.004676455117983012*lm^2)*NM + (0.01183905006949632 + 
            0.003568276148002845*lm + 0.004676455117983012*lm^2)*NL + 
          (-0.0020720226006270426 + 0.003568276148002845*lm + 
            0.004676455117983012*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(0.000490452680728908 - 0.051689241533429395*lm - 
          0.025375199555254347*lm^2) + CF^2*(0.10820275494071838 + 
          0.0011851636651182519*lm + 0.08304610763537787*lm^2) + 
        CF*((0.010717492381567252 + 0.003526096910647314*lm + 
            0.0046136726464098814*lm^2)*NM + (0.011730029312067089 + 
            0.003526096910647314*lm + 0.0046136726464098814*lm^2)*NL + 
          (-0.0020404427945518006 + 0.003526096910647314*lm + 
            0.0046136726464098814*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.000039467408995098483 - 0.051012437253387846*lm - 
          0.025030247196510716*lm^2) + CF^2*(0.10730946090385748 + 
          0.0012536954374917668*lm + 0.08191717264312598*lm^2) + 
        CF*((0.010556150687662486 + 0.003482865273324236*lm + 
            0.004550954035729221*lm^2)*NM + (0.011617751736118235 + 
            0.003482865273324236*lm + 0.004550954035729221*lm^2)*NL + 
          (-0.0020086624294635516 + 0.003482865273324236*lm + 
            0.004550954035729221*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.0005374984778521024 - 0.0503311257064386*lm - 
          0.024685945151957916*lm^2) + CF^2*(0.10640213111290828 + 
          0.0013031711820776543*lm + 0.08079036595186226*lm^2) + 
        CF*((0.01039264330130469 + 0.003438663646998575*lm + 
            0.004488353663992348*lm^2)*NM + (0.011502478921759724 + 
            0.003438663646998575*lm + 0.004488353663992348*lm^2)*NL + 
          (-0.0019767156461890237 + 0.003438663646998575*lm + 
            0.004488353663992348*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.0010046166536542022 - 0.04964610779929969*lm - 
          0.024342572274485365*lm^2) + CF^2*(0.10548159613613858 + 
          0.0013343660880983494*lm + 0.07966660017104302*lm^2) + 
        CF*((0.010227294700439813 + 0.003393573123132256*lm + 
            0.004425922231724611*lm^2)*NM + (0.011384465537771253 + 
            0.003393573123132256*lm + 0.004425922231724611*lm^2)*NL + 
          (-0.0019446352435361055 + 0.003393573123132256*lm + 
            0.004425922231724611*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.0014418263265334617 - 0.04895815127265127*lm - 
          0.02400038818918014*lm^2) + CF^2*(0.10454868915865154 + 
          0.001348074086252961*lm + 0.07854672498277138*lm^2) + 
        CF*((0.010060415084345499 + 0.003347673212407305*lm + 
            0.004363706943487299*lm^2)*NM + (0.011263958772654644 + 
            0.003347673212407305*lm + 0.004363706943487299*lm^2)*NL + 
          (-0.0019124526905884185 + 0.003347673212407305*lm + 
            0.004363706943487299*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.0018501517919464608 - 0.0482679907114308*lm - 
          0.0236596342555898*lm^2) + CF^2*(0.10360424355389637 + 
          0.0013451015123897869*lm + 0.07743153029102118*lm^2) + 
        CF*((0.009892300228338865 + 0.003301041623925315*lm + 
            0.00430175168283451*lm^2)*NM + (0.011141197886519408 + 
            0.003301041623925315*lm + 0.00430175168283451*lm^2)*NL + 
          (-0.0018801981420270848 + 0.003301041623925315*lm + 
            0.00430175168283451*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.0022306299005444047 - 0.04757632770879591*lm - 
          0.023320534493708533*lm^2) + CF^2*(0.10264909053785412 + 
          0.0013262615142367383*lm + 0.07632174925213703*lm^2) + 
        CF*((0.009723231448073459 + 0.0032537540807410837*lm + 
            0.004240097180674279*lm^2)*NM + (0.011016413869011425 + 
            0.0032537540807410837*lm + 0.004240097180674279*lm^2)*NL + 
          (-0.0018479004561283037 + 0.0032537540807410837*lm + 
            0.004240097180674279*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.002584303615303363 - 0.0468838311632795*lm - 
          0.022983296473940484*lm^2) + CF^2*(0.10168405692885979 + 
          0.0012923691324988142*lm + 0.07521806118744158*lm^2) + 
        CF*((0.009553475657555583 + 0.0032058841679488887*lm + 
            0.004178781177080088*lm^2)*NM + (0.01088982919005279 + 
            0.0032058841679488887*lm + 0.004178781177080088*lm^2)*NL + 
          (-0.001815587215111787 + 0.0032058841679488887*lm + 
            0.004178781177080088*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.0029122163854373956 - 0.04619113769070788*lm - 
          0.02264811217146251*lm^2) + CF^2*(0.10070996303028763 + 
          0.0012442369932136467*lm + 0.07412109437933184*lm^2) + 
        CF*((0.009383285506839893 + 0.0031575032098729184*lm + 
            0.0041178385766295475*lm^2)*NM + (0.010761657631564874 + 
            0.0031575032098729184*lm + 0.0041178385766295475*lm^2)*NL + 
          (-0.0017832847475401292 + 0.0031575032098729184*lm + 
            0.0041178385766295475*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.0032154072549613155 - 0.04549885213431924*lm - 
          0.022315158785547552*lm^2) + CF^2*(0.09972762064854163 + 
          0.001182671553444869*lm + 0.07303142875270108*lm^2) + 
        CF*((0.009212899586941476 + 0.0031086801732205936*lm + 
            0.004057301597372282*lm^2)*NM + (0.010632104189611406 + 
            0.0031086801732205936*lm + 0.004057301597372282*lm^2)*NL + 
          (-0.0017510181524928224 + 0.0031086801732205936*lm + 
            0.004057301597372282*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.0034949066314333465 - 0.04480754815821999*lm - 
          0.021984599524523044*lm^2) + CF^2*(0.09873783125490312 + 
          0.0011084698472079173*lm + 0.07194959844389359*lm^2) + 
        CF*((0.009042542690979908 + 0.0030594815933404507*lm + 
            0.003997199913549645*lm^2)*NM + (0.01050136503753689 + 
            0.0030594815933404507*lm + 0.003997199913549645*lm^2)*NL + 
          (-0.0017188113252608664 + 0.0030594815933404507*lm + 
            0.003997199913549645*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.003751732647391469 - 0.0441177689108642*lm - 
          0.02165658435713007*lm^2) + CF^2*(0.09774138429656312 + 
          0.0010224166829837552*lm + 0.07087609425969842*lm^2) + 
        CF*((0.008872426121837898 + 0.003009971520986532*lm + 
            0.0039375607922054676*lm^2)*NM + (0.0103696275417003 + 
            0.003009971520986532*lm + 0.0039375607922054676*lm^2)*NL + 
          (-0.0016866869843283332 + 0.003009971520986532*lm + 
            0.0039375607922054676*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.003986888053355212 - 0.043430027746648794*lm - 
          0.021331250731121392*lm^2) + CF^2*(0.09673905565950425 + 
          0.0009252822483032085*lm + 0.06981136602912455*lm^2) + 
        CF*((0.008702748037812194 + 0.002960211487230368*lm + 
            0.003878409223840253*lm^2)*NM + (0.010237070322325511 + 
            0.002960211487230368*lm + 0.003878409223840253*lm^2)*NL + 
          (-0.0016546666994276995 + 0.002960211487230368*lm + 
            0.003878409223840253*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.004201391079578496 - 0.04274480899499564*lm - 
          0.021008724259992253*lm^2) + CF^2*(0.0957316732687738 + 
          0.0008178200806981457*lm + 0.06875582485088375*lm^2) + 
        CF*((0.008533693828716412 + 0.002910260484381164*lm + 
            0.0038197680472713187*lm^2)*NM + (0.010103863352818461 + 
            0.002910260484381164*lm + 0.0038197680472713187*lm^2)*NL + 
          (-0.0016227709204727884 + 0.002910260484381164*lm + 
            0.0038197680472713187*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.00439613358197709 - 0.0420625687674521*lm - 
          0.0206891193787802*lm^2) + CF^2*(0.0947198365558702 + 
          0.0007007653678354676*lm + 0.0677098452396443*lm^2) + 
        CF*((0.008365436515896761 + 0.0028601749609760384*lm + 
            0.0037616580688691276*lm^2)*NM + (0.009970168091645465 + 
            0.0028601749609760384*lm + 0.0037616580688691276*lm^2)*NL + 
          (-0.0015910190071913865 + 0.0028601749609760384*lm + 
            0.0037616580688691276*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.004572097571050898 - 0.04138373579439426*lm - 
          0.020372539969899926*lm^2) + CF^2*(0.09370435207876919 + 
          0.0005748335428949204*lm + 0.06667376717421794*lm^2) + 
        CF*((0.0081981371703605 + 0.002810008829086576*lm + 
            0.0037040981763454407*lm^2)*NM + (0.009836137641535759 + 
            0.002810008829086576*lm + 0.0037040981763454407*lm^2)*NL + 
          (-0.001559429259294817 + 0.002810008829086576*lm + 
            0.0037040981763454407*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.004730201714312583 - 0.04070871228386977*lm - 
          0.02005907995999914*lm^2) + CF^2*(0.09268592855367837 + 
          0.0004407191442406415*lm + 0.06564789805090628*lm^2) + 
        CF*((0.008031945344055625 + 0.0027598134823566857*lm + 
            0.0036471054472725704*lm^2)*NM + (0.009701916931371547 + 
            0.0027598134823566857*lm + 0.0036471054472725704*lm^2)*NL + 
          (-0.0015280189470368215 + 0.0027598134823566857*lm + 
            0.0036471054472725704*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.004871339908970466 - 0.04003787479598113*lm - 
          0.019748823888832614*lm^2) + CF^2*(0.0916652555613085 + 
          0.00029909491118680604*lm + 0.06463251454527037*lm^2) + 
        CF*((0.007866999509886891 + 0.002709637823341088*lm + 
            0.0035906952525150207*lm^2)*NM + (0.009567642916667287 + 
            0.002709637823341088*lm + 0.0035906952525150207*lm^2)*NL + 
          (-0.0014968043420282053 + 0.002709637823341088*lm + 
            0.0035906952525150207*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.004996380345481571 - 0.0393715751269896*lm - 
          0.019441847451155184*lm^2) + CF^2*(0.09064300283035015 + 
          0.00015061109018660632*lm + 0.06362786438559878*lm^2) + 
        CF*((0.007703427506741442 + 0.002659528298854761*lm + 
            0.003534881354755488*lm^2)*NM + (0.009433444795022755 + 
            0.002659528298854761*lm + 0.003534881354755488*lm^2)*NL + 
          (-0.001465800748185977 + 0.002659528298854761*lm + 
            0.003534881354755488*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.005106164806308805 - 0.03871014119802548*lm - 
          0.019138218012632144*lm^2) + CF^2*(0.08961981964128507 - 
          4.105071902935478*^-6*lm + 0.06263416804134156*lm^2) + 
        CF*((0.007541346986646793 + 0.0026095289421724016*lm + 
            0.003479676002296753*lm^2)*NM + (0.009299444233367078 + 
            0.0026095289421724016*lm + 0.003479676002296753*lm^2)*NL + 
          (-0.001435022532708329 + 0.0026095289421724016*lm + 
            0.003479676002296753*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.005201508170884059 - 0.03805387794392633*lm - 
          0.018837995100757718*lm^2) + CF^2*(0.08859633434075234 - 
          0.00016444966869507815*lm + 0.061651620329752535*lm^2) + 
        CF*((0.007380865858426079 + 0.002559681421034407*lm + 
            0.003425090018319585*lm^2)*NM + (0.009165755604198323 + 
            0.002559681421034407*lm + 0.003425090018319585*lm^2)*NL + 
          (-0.0014044831569775434 + 0.002559681421034407*lm + 
            0.003425090018319585*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.005283198106309858 - 0.037403068198298216*lm - 
          0.01854123087176031*lm^2) + CF^2*(0.0875731539681797 - 
          0.0003298423285447352*lm + 0.06068039194394282*lm^2) + 
        CF*((0.00722208273428062 + 0.0025100250905229103*lm + 
            0.0033711328857746014*lm^2)*NM + (0.009032486228369928 + 
            0.0025100250905229103*lm + 0.0033711328857746014*lm^2)*NL + 
          (-0.0013741952073019782 + 0.0025100250905229103*lm + 
            0.0033711328857746014*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.005351994913613631 - 0.03675797357141133*lm - 
          0.018247970554457444*lm^2) + CF^2*(0.08655086397198403 - 
          0.000499726279682052*lm + 0.05972063090549709*lm^2) + 
        CF*((0.007065087361671386 + 0.0024605970499689315*lm + 
            0.0033178128280831718*lm^2)*NM + (0.008899736622285223 + 
            0.0024605970499689315*lm + 0.0033178128280831718*lm^2)*NL + 
          (-0.0013441704254215996 + 0.0024605970499689315*lm + 
            0.0033178128280831718*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.005408631518297262 - 0.03611883531800583*lm - 
          0.017958252872004962*lm^2) + CF^2*(0.08553002802607092 - 
          0.0006735683020302853*lm + 0.05877246394474351*lm^2) + 
        CF*((0.006909961056642293 + 0.002411432203140408*lm + 
            0.003265136885819084*lm^2)*NM + (0.008767600747638249 + 
            0.002411432203140408*lm + 0.003265136885819084*lm^2)*NL + 
          (-0.0013144197387042096 + 0.002411432203140408*lm + 
            0.003265136885819084*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.005453813579956882 - 0.03548587519250076*lm - 
          0.017672110442463754*lm^2) + CF^2*(0.08451118792547994 - 
          0.0008508585800261661*lm + 0.05783599781169956*lm^2) + 
        CF*((0.0067567771230055435 + 0.0023625633210415833*lm + 
            0.0032131109895388644*lm^2)*NM + (0.008636166262086324 + 
            0.0023625633210415833*lm + 0.0032131109895388644*lm^2)*NL + 
          (-0.001284953289974111 + 0.0023625633210415833*lm + 
            0.0032131109895388644*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.0054882197088522286 - 0.03485929628947295*lm - 
          0.017389570159084752*lm^2) + CF^2*(0.08349486356271299 - 
          0.0010311104693850963*lm + 0.056911320520641004*lm^2) + 
        CF*((0.006605601264548493 + 0.0023140211067275364*lm + 
            0.0031617400289245005*lm^2)*NM + (0.008505514769460248 + 
            0.0023140211067275364*lm + 0.0031617400289245005*lm^2)*NL + 
          (-0.001255780466916372 + 0.0023140211067275364*lm + 
            0.0031617400289245005*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.005512501772973947 - 0.034239283867608224*lm - 
          0.01711065355118831*lm^2) + CF^2*(0.08248155297449009 - 
          0.0012138601894956874*lm + 0.05599850253116174*lm^2) + 
        CF*((0.006456491985597374 + 0.002265834261604201*lm + 
            0.0031110279183978744*lm^2)*NM + (0.00837572206831441 + 
            0.002265834261604201*lm + 0.0031110279183978744*lm^2)*NL + 
          (-0.0012269099310127153 + 0.002265834261604201*lm + 
            0.0031110279183978744*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.005527285283074388 - 0.03362600615562653*lm - 
          0.016835377126488835*lm^2) + CF^2*(0.08147173245372465 - 
          0.0013986664519789367*lm + 0.05509759786850892*lm^2) + 
        CF*((0.0063095009804998905 + 0.0022180295527445973*lm + 
            0.0030609776593616064*lm^2)*NM + (0.0082468583977939 + 
            0.0022180295527445973*lm + 0.0030609776593616064*lm^2)*NL + 
          (-0.0011983496459648901 + 0.0022180295527445973*lm + 
            0.0030609776593616064*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.005533169843800129 - 0.0330196151389505*lm - 
          0.016563752695689216*lm^2) + CF^2*(0.08046585672037747 - 
          0.0015851100348980554*lm + 0.05420864518589198*lm^2) + 
        CF*((0.0061646735109296726 + 0.0021706318808067185*lm + 
            0.0030115913992162214*lm^2)*NM + (0.008118988679950978 + 
            0.0021706318808067185*lm + 0.0030115913992162214*lm^2)*NL + 
          (-0.0011701069055729102 + 0.0021706318808067185*lm + 
            0.0030115913992162214*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.005530729660495619 - 0.03242024732612511*lm - 
          0.016295787680142816*lm^2) + CF^2*(0.07946435914550877 - 
          0.0017727933111475354*lm + 0.053331668771376496*lm^2) + 
        CF*((0.006022048770932892 + 0.0021236643481880465*lm + 
            0.0029628704872986943*lm^2)*NM + (0.007992172757781144 + 
            0.0021236643481880465*lm + 0.0029628704872986943*lm^2)*NL + 
          (-0.0011421883610375078 + 0.0021236643481880465*lm + 
            0.0029628704872986943*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.005520514092286266 - 0.03182802449420831*lm - 
          0.016031485403353828*lm^2) + CF^2*(0.0784676520229694 - 
          0.0019613397386770482*lm + 0.05246667950188525*lm^2) + 
        CF*((0.005881660239215085 + 0.002077148327096494*lm + 
            0.002914815527882514*lm^2)*NM + (0.007866465628371167 + 
            0.002077148327096494*lm + 0.002914815527882514*lm^2)*NL + 
          (-0.0011146000476611477 + 0.002077148327096494*lm + 
            0.002914815527882514*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.005503048243110929 - 0.03124305441254048*lm - 
          0.015770845367059517*lm^2) + CF^2*(0.07747612688356009 - 
          0.002150393319410271*lm + 0.05161367574674024*lm^2) + 
        CF*((0.0057435360185525645 + 0.0020311035272580504*lm + 
            0.0028674264303744576*lm^2)*NM + (0.007741917670659591 + 
            0.0020311035272580504*lm + 0.0028674264303744576*lm^2)*NL + 
          (-0.0010873474109284295 + 0.0020311035272580504*lm + 
            0.0028674264303744576*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.00547883358328013 - 0.030665431544467218*lm - 
          0.01551386351261091*lm^2) + CF^2*(0.07649015484676121 - 
          0.002339618032994381*lm + 0.050772644223090246*lm^2) + 
        CF*((0.005607699162208582 + 0.0019855480630179612*lm + 
            0.002820702456838347*lm^2)*NM + (0.007618574867405609 + 
            0.0019855480630179612*lm + 0.002820702456838347*lm^2)*NL + 
          (-0.0010604353319475753 + 0.0019855480630179612*lm + 
            0.002820702456838347*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.005448348594976437 - 0.03009523772673691*lm - 
          0.015260532468341444*lm^2) + CF^2*(0.07551008700545245 - 
          0.0025286972508568603*lm + 0.04994356080548109*lm^2) + 
        CF*((0.005474167987375174 + 0.00194049851962522*lm + 
            0.0027746422669711716*lm^2)*NM + (0.007496479021046362 + 
            0.00194049851962522*lm + 0.0027746422669711716*lm^2)*NL + 
          (-0.001033868152240914 + 0.00194049851962522*lm + 
            0.0027746422669711716*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.005412049435858641 - 0.029532542826423834*lm - 
          0.015010841783586668*lm^2) + CF^2*(0.0745362548393256 - 
          0.0027173331354469724*lm + 0.04912639129173819*lm^2) + 
        CF*((0.005342956375678893 + 0.0018959700185198149*lm + 
            0.0027292439606521218*lm^2)*NM + (0.0073756679631967175 + 
            0.0018959700185198149*lm + 0.0027292439606521218*lm^2)*NL + 
          (-0.0010076496978766686 + 0.0018959700185198149*lm + 
            0.0027292439606521218*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.005370370615615405 - 0.0289774053753411*lm - 
          0.014764778149991822*lm^2) + CF^2*(0.07356897065299514 - 
          0.002905246028994822*lm + 0.04832109212724597*lm^2) + 
        CF*((0.005214074060890687 + 0.0018519762814688694*lm + 
            0.002684505118180331*lm^2)*NM + (0.007256175757610431 + 
            0.0018519762814688694*lm + 0.002684505118180331*lm^2)*NL + 
          (-0.000981783302929187 + 0.0018519762814688694*lm + 
            0.002684505118180331*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.005323725680924241 - 0.0284298731820068*lm - 
          0.0145223256107185*lm^2) + CF^2*(0.07260852803508976 - 
          0.0030921738356266483*lm + 0.04752761108962418*lm^2) + 
        CF*((0.005087526904016106 + 0.0018085296934217492*lm + 
            0.0026404228383124545*lm^2)*NM + (0.0071380328964784105 + 
            0.0018085296934217492*lm + 0.0026404228383124545*lm^2)*NL + 
          (-0.0009562718322728543 + 0.0018085296934217492*lm + 
            0.0026404228383124545*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.005272507904819779 - 0.027889983921312877*lm - 
          0.014283465758136495*lm^2) + CF^2*(0.07165520233487406 - 
          0.0032778714002267206*lm + 0.04674588793571944*lm^2) + 
        CF*((0.004963317155951439 + 0.0017656413639757142*lm + 
            0.0025969937742066356*lm^2)*NM + (0.007021266489989277 + 
            0.0017656413639757142*lm + 0.0025969937742066356*lm^2)*NL + 
          (-0.0009311177036991852 + 0.0017656413639757142*lm + 
            0.0025969937742066356*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.005217090976987739 - 0.027357765702120892*lm - 
          0.014048177920562422*lm^2) + CF^2*(0.07070925115324285 - 
          0.0034621098870299656*lm + 0.04597585501274974*lm^2) + 
        CF*((0.0048414437080591625 + 0.0017233211873629078*lm + 
            0.002554214167374986*lm^2)*NM + (0.006905900449120418 + 
            0.0017233211873629078*lm + 0.002554214167374986*lm^2)*NL + 
          (-0.0009063229093632097 + 0.0017233211873629078*lm + 
            0.002554214167374986*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.005157829691915306 - 0.026833237613072984*lm - 
          0.013816439338582853*lm^2) + CF^2*(0.0697709148451162 - 
          0.0036446761605616715*lm + 0.04521743783536206*lm^2) + 
        CF*((0.004721902330778854 + 0.0016815779008866596*lm + 
            0.0025120798797423367*lm^2)*NM + (0.006791955661664959 + 
            0.0016815779008866596*lm + 0.0025120798797423367*lm^2)*NL + 
          (-0.000881889036559756 + 0.0016815779008866596*lm + 
            0.0025120798797423367*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.005095060632276498 - 0.026316410246961016*lm - 
          0.013588225331476567*lm^2) + CF^2*(0.06884041703059553 - 
          0.003825372171207999*lm + 0.04447055563028695*lm^2) + 
        CF*((0.00460468590076682 + 0.0016404191417504006*lm + 
            0.0024705864239048304*lm^2)*NM + (0.006679450161532096 + 
            0.0016404191417504006*lm + 0.0024705864239048304*lm^2)*NL + 
          (-0.0008578172878377605 + 0.0016404191417504006*lm + 
            0.0024705864239048304*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.005029102845247779 - 0.025807286204043434*lm - 
          0.013363509454228041*lm^2) + CF^2*(0.06791796511237923 - 
          0.004004014347400504*lm + 0.04373512185020086*lm^2) + 
        CF*((0.0044897846167558245 + 0.001599851502236119*lm + 
            0.0024297289916778257*lm^2)*NM + (0.00656839929138571 + 
            0.001599851502236119*lm + 0.0024297289916778257*lm^2)*NL + 
          (-0.0008341085004448146 + 0.001599851502236119*lm + 
            0.0024297289916778257*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.0049602585098033995 - 0.025305860574738107*lm - 
          0.013142263645602526*lm^2) + CF^2*(0.06700375079721364 - 
          0.004180432996126716*lm + 0.04301104465833554*lm^2) + 
        CF*((0.004377186204548693 + 0.0015598805832013854*lm + 
            0.002389502481018641*lm^2)*NM + (0.0064588158587094765 + 
            0.0015598805832013854*lm + 0.002389502481018641*lm^2)*NL + 
          (-0.000810763165134318 + 0.0015598805832013854*lm + 
            0.002389502481018641*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.0048888135933093085 - 0.024812121402151666*lm - 
          0.012924458367732107*lm^2) + CF^2*(0.06609795061931707 - 
          0.004354471713234366*lm + 0.04229822738530507*lm^2) + 
        CF*((0.0042668761114341355 + 0.0015205110458746912*lm + 
            0.0023499015214058375*lm^2)*NM + (0.006350710285406444 + 
            0.0015205110458746912*lm + 0.0023499015214058375*lm^2)*NL + 
          (-0.0007877814443166867 + 0.0015205110458746912*lm + 
            0.0023499015214058375*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.004815038496021765 - 0.024326050124932*lm - 
          0.012710062737641794*lm^2) + CF^2*(0.06520072646396144 - 
          0.004525986804776893*lm + 0.041596568959554964*lm^2) + 
        CF*((0.004158837690501512 + 0.001481746661938296*lm + 
            0.0023109204977530533*lm^2)*NM + (0.006244090751057502 + 
            0.001481746661938296*lm + 0.0023109204977530533*lm^2)*NL + 
          (-0.000765163189581845 + 0.001481746661938296*lm + 
            0.0023109204977530533*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.004739188682281957 - 0.023847622000951488*lm - 
          0.012499044651125155*lm^2) + CF^2*(0.06431222608948292 - 
          0.004694846720450085*lm + 0.040905964312773234*lm^2) + 
        CF*((0.0040530523750324995 + 0.0014435903618961023*lm + 
            0.002272553572931846*lm^2)*NM + (0.006138963329976789 + 
            0.0014435903618961023*lm + 0.002272553572931846*lm^2)*NL + 
          (-0.00074290795859657 + 0.0014435903618961023*lm + 
            0.002272553572931846*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.004661505297461369 - 0.023376806512344514*lm - 
          0.012291370899360162*lm^2) + CF^2*(0.06343258364627466 - 
          0.004860931499992257*lm + 0.04022630476154235*lm^2) + 
        CF*((0.0039494998435174134 + 0.0014060442817313613*lm + 
            0.002234794708974575*lm^2)*NM + (0.006035332122213185 + 
            0.0014060442817313613*lm + 0.002234794708974575*lm^2)*NL + 
          (-0.0007210150313900171 + 0.0014060442817313613*lm + 
            0.002234794708974575*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.004582215769852468 - 0.022913567752434996*lm - 
          0.01208700727863781*lm^2) + CF^2*(0.06256192019138289 - 
          0.005024132233261377*lm + 0.039557478366451015*lm^2) + 
        CF*((0.0038481581755501846 + 0.0013691098078653823*lm + 
            0.0021976376870250563*lm^2)*NM + (0.0059331993786558975 + 
            0.0013691098078653823*lm + 0.0021976376870250563*lm^2)*NL + 
          (-0.0006994834260328784 + 0.0013691098078653823*lm + 
            0.0021976376870250563*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.004501534396883398 - 0.02245786479509762*lm - 
          0.011885918693558628*lm^2) + CF^2*(0.061700344197515966 - 
          0.005184350534560347*lm + 0.03889937026982823*lm^2) + 
        CF*((0.003749003998994959 + 0.001332787620433935*lm + 
            0.0021610761261015685*lm^2)*NM + (0.005832565620409024 + 
            0.001332787620433935*lm + 0.0021610761261015685*lm^2)*NL + 
          (-0.000678311913742726 + 0.001332787620433935*lm + 
            0.0021610761261015685*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.004419662915177323 - 0.022009652047101577*lm - 
          0.01168806925403552*lm^2) + CF^2*(0.060847952055404976 - 
          0.005341498031654772*lm + 0.038251863013207155*lm^2) + 
        CF*((0.00365201262878356 + 0.001297077734902811*lm + 
            0.0021251035007337307*lm^2)*NM + (0.0057334297526051735 + 
            0.001297077734902811*lm + 0.0021251035007337307*lm^2)*NL + 
          (-0.0006574990333938595 + 0.001297077734902811*lm + 
            0.0021251035007337307*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.004336791054104123 - 0.02156887958398762*lm - 
          0.011493422366425284*lm^2) + CF^2*(0.060004828568579194 - 
          0.005495495869814497*lm + 0.03761483683557366*lm^2) + 
        CF*((0.0035571581976958913 + 0.0012619795420480968*lm + 
            0.0020897131575318695*lm^2)*NM + (0.00563578917283186 + 
            0.0012619795420480968*lm + 0.0020897131575318695*lm^2)*NL + 
          (-0.0006370431054819902 + 0.0012619795420480968*lm + 
            0.0020897131575318695*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.004253097072585707 - 0.021135493470028893*lm - 
          0.011301940819095795*lm^2) + CF^2*(0.05917104743973659 - 
          0.005646274231109841*lm + 0.03698816995340442*lm^2) + 
        CF*((0.003464413779461955 + 0.001227491846330193*lm + 
            0.00205489833074469*lm^2)*NM + (0.005539639874346722 + 
            0.001227491846330193*lm + 0.00205489833074469*lm^2)*NL + 
          (-0.0006169422455295815 + 0.001227491846330193*lm + 
            0.00205489833074469*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.004168748279017074 - 0.02070943606282318*lm - 
          0.011113586862721124*lm^2) + CF^2*(0.05834667174800045 - 
          0.005793771869104477*lm + 0.03637173882345095*lm^2) + 
        CF*((0.0033737515045302005 + 0.0011936129026935407*lm + 
            0.002020652156858386*lm^2)*NM + (0.005444976544258795 + 
            0.0011936129026935407*lm + 0.002020652156858386*lm^2)*NL + 
          (-0.0005971943769623792 + 0.0011936129026935407*lm + 
            0.002020652156858386*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.004083873263925737 - 0.02029063889396172*lm - 
          0.010928321840379562*lm^2) + CF*(0.0575317515769003 - 
          0.005937956959794948*lm + 0.035765416932151295*lm^2) + 
        0.0032851375656196536*NM + 0.001160339207739918*lm*NM + 
        0.0019869676073417386*lm^2*NM + 0.00535178871381439*NL + 
        0.001160339207739918*lm*NL + 0.0019869676073417386*lm^2*NL - 
        0.0005777971338559803*NH + 0.001160339207739918*lm*NH + 
        0.0019869676073417386*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.003998680775164269 - 0.01987905397075901*lm - 
          0.010746108124005348*lm^2) + CF*(0.05672633628709001 - 
          0.006078737478576172*lm + 0.03516908113310841*lm^2) + 
        0.0031985536957825226*NM + 0.0011276707428475076*lm*NM + 
        0.001953837840728245*lm^2*NM + 0.005260077362015155*NL + 
        0.0011276707428475076*lm*NL + 0.001953837840728245*lm^2*NL - 
        0.000558748331512438*NH + 0.0011276707428475076*lm*NH + 
        0.001953837840728245*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.003913273682511829 - 0.019474605162878383*lm - 
          0.010566906238381801*lm^2) + CF*(0.05593045648720143 - 
          0.006216101259867633*lm + 0.03458260223470408*lm^2) + 
        0.0031139635803923127*NM + 0.0010956028008978014*lm*NM + 
        0.001921255679705782*lm^2*NM + 0.005169828978303879*NL + 
        0.0010956028008978014*lm*NL + 0.001921255679705782*lm^2*NL - 
        0.0005400452556640156*NH + 0.0010956028008978014*lm*NH + 
        0.001921255679705782*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.003827780520106975 - 0.019077222802159247*lm - 
          0.010390676993156588*lm^2) + CF*(0.05514413734127346 - 
          0.0063500168749038455*lm + 0.034005851977603384*lm^2) + 
        0.003031336629785243*NM + 0.0010641317837943717*lm*NM + 
        0.0018892139987557433*lm^2*NM + 0.0050810339360245335*NL + 
        0.0010641317837943717*lm*NL + 0.0018892139987557433*lm^2*NL - 
        0.0005216851805102803*NH + 0.0010641317837943717*lm*NH + 
        0.0018892139987557433*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.0037423211908749186 - 0.01868683481773344*lm - 
          0.01021738099147692*lm^2) + CF*(0.05436739562029076 - 
          0.006480459391327021*lm + 0.033438701426651736*lm^2) + 
        0.00295064178598023*NM + 0.001033253704370099*lm*NM + 
        0.0018577056348139853*lm^2*NM + 0.004993681720007228*NL + 
        0.001033253704370099*lm*NL + 0.0018577056348139853*lm^2*NL - 
        0.0005036652448998451*NH + 0.001033253704370099*lm*NH + 
        0.0018577056348139853*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.0036570073908460013 - 0.018303366960702828*lm - 
          0.010046978684118617*lm^2) + CF*(0.05360024011491776 - 
          0.006607409996204067*lm + 0.03288102114802456*lm^2) + 
        0.002871847601899572*NM + 0.0010029642147119087*lm*NM + 
        0.0018267233971124756*lm^2*NM + 0.004907760998854411*NL + 
        0.0010029642147119087*lm*NL + 0.0018267233971124756*lm^2*NL - 
        0.0004859824623086179*NH + 0.0010029642147119087*lm*NH + 
        0.0018267233971124756*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.0035719430168566807 - 0.01792674301690414*lm - 
          0.009879430420014185*lm^2) + CF*(0.052842672036555134 - 
          0.006730855634192752*lm + 0.03233268137459188*lm^2) + 
        0.0027949223152513533*NM + 0.0009732586331528421*lm*NM + 
        0.0017962600763662155*lm^2*NM + 0.00482325969330183*NL + 
        0.0009732586331528421*lm*NL + 0.0017962600763662155*lm^2*NL - 
        0.00046863373037969524*NH + 0.0009732586331528421*lm*NH + 
        0.0017962600763662155*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.0034872245580391567 - 0.01755688500826321*lm - 
          0.009714696493377032*lm^2) + CF*(0.05209468540660325 - 
          0.006850788660518773*lm + 0.03179355216014301*lm^2) + 
        0.0027198339173566785*NM + 0.0009441319699771382*lm*NM + 
        0.0017663084533412786*lm^2*NM + 0.004740165040828841*NL + 
        0.0009441319699771382*lm*NL + 0.0017663084533412786*lm^2*NL - 
        0.00045161584003904965*NH + 0.0009441319699771382*lm*NH + 
        0.0017663084533412786*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.0034029414715175685 - 0.017193713383224965*lm - 
          0.009552737187608955*lm^2) + CF*(0.05135626743386716 - 
          0.006967206508410638*lm + 0.03126350352308385*lm^2) + 
        0.0026465502171923003*NM + 0.0009155789518834585*lm*NM + 
        0.001736861306837992*lm^2*NM + 0.004658463656686751*NL + 
        0.0009155789518834585*lm*NL + 0.001736861306837992*lm^2*NL - 
        0.0004349254842009435*NH + 0.0009155789518834585*lm*NH + 
        0.001736861306837992*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.003319176542737696 - 0.01683714719672981*lm - 
          0.00939351281616843*lm^2) + CF*(0.050627398880082254 - 
          0.007080111370627328*lm + 0.030742405580187586*lm^2) + 
        0.0025750389009070707*NM + 0.0008875940452507423*lm*NM + 
        0.0017079114211215325*lm^2*NM + 0.0045781415915079615*NL + 
        0.0008875940452507423*lm*NL + 0.0017079114211215325*lm^2*NL - 
        0.00041855926607678456*NH + 0.0008875940452507423*lm*NH + 
        0.0017079114211215325*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.0032360062308635367 - 0.016487104280191563*lm - 
          0.009236983760568158*lm^2) + CF*(0.04990805441358007 - 
          0.007189509894704421*lm + 0.030230128670950332*lm^2) + 
        0.0025052675870589503*NM + 0.0008601714782504626*lm*NM + 
        0.0016794515928305741*lm^2*NM + 0.004499184385652932*NL + 
        0.0008601714782504626*lm*NL + 0.0016794515928305741*lm^2*NL - 
        0.0004025137071008969*NH + 0.0008601714782504626*lm*NH + 
        0.0016794515928305741*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.0031535009996782916 - 0.01614350140191665*lm - 
          0.009083110505661685*lm^2) + CF*(0.04919820295114935 - 
          0.00729541289153732*lm + 0.0297265434730746*lm^2) + 
        0.002437203877808002*NM + 0.0008333052618482573*lm*NM + 
        0.0016514746373930335*lm^2*NM + 0.004421577120446249*NL + 
        0.0008333052618482573*lm*NL + 0.0016514746373930335*lm^2*NL - 
        0.00038678525448642987*NH + 0.0008333052618482573*lm*NH + 
        0.0016514746373930335*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.0030717256344294152 - 0.01580625441838923*lm - 
          0.008931853672370664*lm^2) + CF*(0.04849780798817945 - 
          0.007397835056915423*lm + 0.02923152110957672*lm^2) + 
        0.002370815406289895*NM + 0.0008069892097370621*lm*NM + 
        0.0016239733949764844*lm^2*NM + 0.004345304466447486*NL + 
        0.0008069892097370621*lm*NL + 0.0016239733949764844*lm^2*NL - 
        0.0003713702884243631*NH + 0.0008069892097370621*lm*NH + 
        0.0016239733949764844*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.0029907395450576918 - 0.015475278416831958*lm - 
          0.008783174047996554*lm^2) + CF*(0.047806827917201554 - 
          0.0074967947056180494*lm + 0.02874493324798872*lm^2) + 
        0.00230606988038395*NM + 0.0007812169572429717*lm*NM + 
        0.0015969407359993732*lm^2*NM + 0.004270350728897059*NL + 
        0.0007812169572429717*lm*NL + 0.0015969407359993732*lm^2*NL - 
        0.0003562651289382915*NH + 0.0007812169572429717*lm*NH + 
        0.0015969407359993732*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.0029105970562489933 - 0.015150487849437436*lm - 
          0.008637032614253071*lm^2) + CF*(0.04712521633496767 - 
          0.007592313517681696*lm + 0.02826665219210096*lm^2) + 
        0.002242935123079639*NM + 0.0007559819792441124*lm*NM + 
        0.001570369566227831*lm^2*NM + 0.00419669989047187*NL + 
        0.0007559819792441124*lm*NL + 0.001570369566227831*lm^2*NL - 
        0.0003414660424073954*NH + 0.0007559819792441124*lm*NH + 
        0.001570369566227831*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.0028313476847446426 - 0.014831796659651158*lm - 
          0.008493390573148707*lm^2) + CF*(0.04645292233822968 - 
          0.007684416296448398*lm + 0.0277965509666685*lm^2) + 
        0.0021813791096357356*NM + 0.0007312776071418319*lm*NM + 
        0.001544252831481583*lm^2*NM + 0.0041243356514802975*NL + 
        0.0007312776071418319*lm*NL + 0.001544252831481583*lm^2*NL - 
        0.0003269692477697101*NH + 0.0007312776071418319*lm*NH + 
        0.001544252831481583*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.00275303640434233 - 0.014519118400872567*lm - 
          0.00835220937084186*lm^2) + CF*(0.04578989080839944 - 
          0.007773130738006555*lm + 0.027334503395482452*lm^2) + 
        0.0021213700017169504*NM + 0.0007070970449225157*lm*NM + 
        0.0015185835219712473*lm^2*NM + 0.004053241467620935*NL + 
        0.0007070970449225157*lm*NL + 0.0015185835219712473*lm^2*NL - 
        0.000312770922417519*NH + 0.0007070970449225157*lm*NH + 
        0.0015185835219712473*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.002675703899014451 - 0.014212366347927177*lm - 
          0.00821345071958477*lm^2) + CF*(0.04513606268528736 - 
          0.00785848721163834*lm + 0.02688038417318652*lm^2) + 
        0.0020628761786839114*NM + 0.0006834333843473084*lm*NM + 
        0.0014933546762881402*lm^2*NM + 0.003983400585424502*NL + 
        0.0006834333843473084*lm*NL + 0.0014933546762881402*lm^2*NL - 
        0.00029886720779639904*NH + 0.0006834333843473084*lm*NH + 
        0.0014933546762881402*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.0025993868045647026 - 0.013911453601649287*lm - 
          0.008077076617866418*lm^2) + CF*(0.04449137523013117 - 
          0.0079405185508916*lm + 0.02643406893119919*lm^2) + 
        0.002005866266203719*NM + 0.0006602796193059884*lm*NM + 
        0.0014685593850666215*lm^2*NM + 0.003914796075493446*NL + 
        0.0006602796193059884*lm*NL + 0.0014685593850666215*lm^2*NL - 
        0.0002852542147191451*NH + 0.0006602796193059884*lm*NH + 
        0.0014685593850666215*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.0025241179392369224 - 0.013616293186901706*lm - 
          0.007943049368858724*lm^2) + CF*(0.04385576227813834 - 
          0.008019259854898859*lm + 0.025995434298083098*lm^2) + 
        0.0019503091623400326*NM + 0.0006376286593701923*lm*NM + 
        0.0014441907943379497*lm^2*NM + 0.003847410863649047*NL + 
        0.0006376286593701923*lm*NL + 0.0014441907943379497*lm^2*NL - 
        0.000271928028405506*NH + 0.0006376286593701923*lm*NH + 
        0.0014441907943379497*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.002449926523682616 - 0.013326798144346171*lm - 
          0.007811331597264976*lm^2) + CF*(0.043229154480775585 - 
          0.008094748299571583*lm + 0.025564357954685375*lm^2) + 
        0.0018961740612737051*NM + 0.000615473342580136*lm*NM + 
        0.0014202421085936319*lm^2*NM + 0.0037812277600912402*NL + 
        0.000615473342580136*lm*NL + 0.0014202421085936319*lm^2*NL - 
        0.0002588847132583584*NH + 0.000615473342580136*lm*NH + 
        0.0014202421085936319*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.0023768383906854415 - 0.01304288161626573*lm - 
          0.007681886264664184*lm^2) + CF*(0.04261147953804729 - 
          0.008167022958303988*lm + 0.025140718684355513*lm^2) + 
        0.00184343047479739*NM + 0.0005938064474979249*lm*NM + 
        0.0013967065935753063*lm^2*NM + 0.003716229486671881*NL + 
        0.0005938064474979249*lm*NL + 0.0013967065935753063*lm^2*NL - 
        0.0002461203173866508*NH + 0.0005938064474979249*lm*NH + 
        0.0013967065935753063*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.002304876185032292 - 0.012764456926728328*lm - 
          0.007554676683440136*lm^2) + CF*(0.04200266242101086 - 
          0.008236124631827529*lm + 0.02472439641853135*lm^2) + 
        0.0017920482517202506*NM + 0.0005726207045594992*lm*NM + 
        0.0013735775788072974*lm^2*NM + 0.003652398702377906*NL + 
        0.0005726207045594992*lm*NL + 0.0013735775788072974*lm^2*NL - 
        0.00023363087688514796*NH + 0.0005726207045594992*lm*NH + 
        0.0013735775788072974*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.0022340595539115616 - 0.012491437656369075*lm - 
          0.007429666529379214*lm^2) + CF*(0.04140262558478258 - 
          0.008302095686864438*lm + 0.024315272277968338*lm^2) + 
        0.0017419975953119385*NM + 0.000551908806756212*lm*NM + 
        0.0013508484598871299*lm^2*NM + 0.0035897180271166245*NL + 
        0.000551908806756212*lm*NL + 0.0013508484598871299*lm^2*NL - 
        0.00022141241988071024*NH + 0.000551908806756212*lm*NH + 
        0.0013508484598871299*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.00216440532820977 - 0.012223737712057396*lm - 
          0.0073068198530166426*lm^2) + CF*(0.04081128917229082 - 
          0.008364979903236381*lm + 0.023913228609872647*lm^2) + 
        0.00169324907890834*NM + 0.0005316634196760058*lm*NM + 
        0.0013285127005484803*lm^2*NM + 0.003528170063891348*NL + 
        0.0005316634196760058*lm*NL + 0.0013285127005484803*lm^2*NL - 
        0.00020946097035455066*NH + 0.0005316634196760058*lm*NH + 
        0.0013285127005484803*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.0020959276950680986 - 0.011961271391704161*lm - 
          0.007186101089806521*lm^2) + CF*(0.04022857120903639 - 
          0.00842482232909236*lm + 0.02351814902118498*lm^2) + 
        0.0016457736597952123*NM + 0.0005118771909331319*lm*NM + 
        0.0013065638345102766*lm^2*NM + 0.0034677374194516685*NL + 
        0.0005118771909331319*lm*NL + 0.0013065638345102766*lm^2*NL - 
        0.00019777255174961857*NH + 0.0005118771909331319*lm*NH + 
        0.0013065638345102766*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.002028638362050546 - 0.011703953444453333*lm - 
          0.0070674750691870685*lm^2) + CF*(0.039654387789121094 - 
          0.008481669143928276*lm + 0.023129918408248587*lm^2) + 
        0.0015995426914797413*NM + 0.0004925427590143424*lm*NM + 
        0.0012849954671249216*lm^2*NM + 0.003408402723498905*NL + 
        0.0004925427590143424*lm*NL + 0.0012849954671249216*lm^2*NL - 
        0.0001863431903719745*NH + 0.0004925427590143424*lm*NH + 
        0.0012849954671249216*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.0019625467132654228 - 0.01145169912649225*lm - 
          0.0069509070226086225*lm^2) + CF*(0.03908865325280612 - 
          0.008535567529079139*lm + 0.022748422983082765*lm^2) + 
        0.0015545279344542358*NM + 0.0004736527615684964*lm*NM + 
        0.0012638012768379314*lm^2*NM + 0.003350148646523632*NL + 
        0.0004736527615684964*lm*NL + 0.0012638012768379314*lm^2*NL - 
        0.00017516891859473632*NH + 0.0004736527615684964*lm*NH + 
        0.0012638012768379314*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.0018976599577718706 - 0.011204424252704782*lm - 
          0.006836362590588378*lm^2) + CF*(0.038531280355861404 - 
          0.00858656554537353*lm + 0.022373550296471055*lm^2) + 
        0.0015107015655506123*NM + 0.0004551998431655423*lm*NM + 
        0.0012429750164706143*lm^2*NM + 0.0032929579163486693*NL + 
        0.0004551998431655423*lm*NL + 0.0012429750164706143*lm^2*NL - 
        0.0001642457778728985*NH + 0.0004551998431655423*lm*NH + 
        0.0012429750164706143*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.0018339832705929746 - 0.010962045244381909*lm - 
          0.006723807828852366*lm^2) + CF*(0.037982180430966225 - 
          0.008634712017648837*lm + 0.022005189258062288*lm^2) + 
        0.0014680361859790378*NM + 0.0004371766625498822*lm*NM + 
        0.0012225105143367939*lm^2*NM + 0.003236813333447565*NL + 
        0.0004371766625498822*lm*NL + 0.0012225105143367939*lm^2*NL - 
        0.00015356982157705296*NH + 0.0004371766625498822*lm*NH + 
        0.0012225105143367939*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.001771519926646959 - 0.010724479173194952*lm - 
          0.006613209213621946*lm^2) + CF*(0.0374412635414191 - 
          0.008680056425834524*lm + 0.02164323015367182*lm^2) + 
        0.001426504828139029*NM + 0.0004195758994121856*lm*NM + 
        0.00120240167520399*lm^2*NM + 0.003181697785105342*NL + 
        0.0004195758994121856*lm*NL + 0.00120240167520399*lm^2*NL - 
        0.00014313711765377027*NH + 0.0004195758994121856*lm*NH + 
        0.00120240167520399*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.0017102714278978976 - 0.010491643801627764*lm - 
          0.00650453364609898*lm^2) + CF*(0.03690843862741285 - 
          0.00872264880231974*lm + 0.0212875646599603*lm^2) + 
        0.001386080961286501*NM + 0.00040239026070280464*lm*NM + 
        0.0011826424811089056*lm^2*NM + 0.0031275942584851617*NL + 
        0.00040239026070280464*lm*NL + 0.0011826424811089056*lm^2*NL - 
        0.00013294375112013777*NH + 0.00040239026070280464*lm*NH + 
        0.0011826424811089056*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.0016502376240173954 - 0.01026345762005548*lm - 
          0.006397748456200926*lm^2) + CF*(0.03638361364512766 - 
          0.008762539635330347*lm + 0.020938085856657577*lm^2) + 
        0.0013467384961356617*NM + 0.00038561248650904634*lm*NM + 
        0.001163226992036532*lm^2*NM + 0.0030744858526615564*NL + 
        0.00038561248650904634*lm*NL + 0.001163226992036532*lm^2*NL - 
        0.00012298582639969167*NH + 0.00038561248650904634*lm*NH + 
        0.001163226992036532*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.0015914168268388118 - 0.01003983988064909*lm - 
          0.006292821405594282*lm^2) + CF*(0.03586669569889132 - 
          0.008799779778049422*lm + 0.020594688236490376*lm^2) + 
        0.001308451788470279*NM + 0.0003692353555176867*lm*NM + 
        0.0011441493464716876*lm^2*NM + 0.0030223557896780027*NL + 
        0.0003692353555176867*lm*NL + 0.0011441493464716876*lm^2*NL - 
        0.00011325946950672894*NH + 0.0003692353555176867*lm*NH + 
        0.0011441493464716876*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.0015338059188758472 - 0.00982071062827711*lm - 
          0.0061897206900722096*lm^2) + CF*(0.03535759116665221 - 
          0.008834420363224*lm + 0.020257267712963593*lm^2) + 
        0.0012711956418346836*NM + 0.00035325169008326084*lm*NM + 
        0.0011254037618313108*lm^2*NM + 0.002971187424683841*NL + 
        0.00035325169008326084*lm*NL + 0.0011254037618313108*lm^2*NL - 
        0.00010376083008573739*NH + 0.00035325169008326084*lm*NH + 
        0.0011254037618313108*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.0014774004561676954 - 0.009605990728567796*lm - 
          0.006088414941319615*lm^2) + CF*(0.03485620581900618 - 
          0.008866512723009617*lm + 0.01992572162613692*lm^2) + 
        0.0012349453093709164*NM + 0.0003376543609218373*lm*NM + 
        0.0011069845347853845*lm^2*NM + 0.0029209642552028925*NL + 
        0.0003376543609218373*lm*NL + 0.0011069845347853845*lm^2*NL - 
        0.0000944860833124422*NH + 0.0003376543609218373*lm*NH + 
        0.0011069845347853845*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.0014221947657035256 - 0.009395601893288015*lm - 
          0.0059888732281066165*lm^2) + CF*(0.03436244493201396 - 
          0.00889610831381278*lm + 0.019599948746530746*lm^2) + 
        0.0011996764948646562*NM + 0.00032243629144918217*lm*NM + 
        0.0010888860414739303*lm^2*NM + 0.0028716699295835745*NL + 
        0.00032243629144918217*lm*NL + 0.0010888860414739303*lm^2*NL - 
        0.00008543143166273152*NH + 0.00032243629144918217*lm*NH + 
        0.0010888860414739303*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.0013681820376697832 - 0.009189466703187637*lm - 
          0.005891065056949065*lm^2) + CF*(0.03387621339404092 - 
          0.008923258645899974*lm + 0.01927984927728785*lm^2) + 
        0.001165365353058986*NM + 0.00030759046178143964*lm*NM + 
        0.0010711027376271028*lm^2*NM + 0.002823288254677898*NL + 
        0.00030759046178143964*lm*NL + 0.0010711027376271028*lm^2*NL - 
        0.00007659310655549588*NH + 0.00030759046178143964*lm*NH + 
        0.0010711027376271028*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0013153544127547264 - 0.008987508628451508*lm - 
          0.005794960372272626*lm^2) + CF*(0.033397415806846104 - 
          0.008948015217550221*lm + 0.018965324854710412*lm^2) + 
        0.0011319884892916556*NM + 0.0002931099124156994*lm*NM + 
        0.001053629158595023*lm^2*NM + 0.002775803202794365*NL + 
        0.0002931099124156994*lm*NL + 0.001053629158595023*lm^2*NL - 
        0.00006796736987519224*NH + 0.0002931099124156994*lm*NH + 
        0.001053629158595023*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.0012637030647357384 - 0.008789652046894376*lm - 
          0.005700529556114938*lm^2) + CF*(0.03292595658114198 - 
          0.008970429453536303*lm + 0.018656278547285254*lm^2) + 
        0.0010995229585082592*NM + 0.000278987747607091*lm*NM + 
        0.0010364599192936252*lm^2*NM + 0.0027291989179675786*NL + 
        0.000278987747607091*lm*NL + 0.0010364599192936252*lm^2*NL - 
        0.00005955051537972777*NH + 0.000278987747607091*lm*NH + 
        0.0010364599192936252*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.0012132182785662981 - 0.008595822260027903*lm - 
          0.005607743427398407*lm^2) + CF*(0.03246174002684146 - 
          0.008990552647727884*lm + 0.018352614853303875*lm^2) + 
        0.0010679462637006843*NM + 0.00026521713845833463*lm*NM + 
        0.0010195897140724375*lm^2*NM + 0.0026834597215852148*NL + 
        0.00026521713845833463*lm*NL + 0.0010195897140724375*lm^2*NL - 
        0.000051338869999046724*NH + 0.00026521713845833463*lm*NH + 
        0.0010195897140724375*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.0011638895241710403 - 0.008405945507122689*lm - 
          0.00551657324080438*lm^2) + CF*(0.032004670438202695 - 
          0.00900843590961755*lm + 0.01805423969717797*lm^2) + 
        0.0010372363538172689*NM + 0.00025179132573699604*lm*NM + 
        0.0010030133165098874*lm^2*NM + 0.0026385701174109774*NL + 
        0.00025179132573699604*lm*NL + 0.0010030133165098874*lm^2*NL - 
        0.000043328795029599686*NH + 0.00025179132573699604*lm*NH + 
        0.0010030133165098874*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.001115705526149126 - 0.0082199489773825*lm - 
          0.005426990685277739*lm^2) + CF*(0.031554652174077207 - 
          0.009024130114578498*lm + 0.017761060424545325*lm^2) + 
        0.0010073716211883438*NM + 0.0002387036224350276*lm*NM + 
        0.000986725579141407*lm^2*NM + 0.0025945147960401943*NL + 
        0.0002387036224350276*lm*NL + 0.000986725579141407*lm^2*NL - 
        0.00003551668722967523*NH + 0.0002387036224350276*lm*NH + 
        0.000986725579141407*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.0010686543295781413 - 0.008037760820342214*lm - 
          0.005338967882189255*lm^2) + CF*(0.031111589733460926 - 
          0.009037685857670053*lm + 0.017472985796255742*lm^2) + 
        0.00097833089850821*NM + 0.00022594741608454195*lm*NM + 
        0.000970721433125319*lm^2*NM + 0.0025512786388228363*NL + 
        0.00022594741608454195*lm*NL + 0.000970721433125319*lm^2*NL - 
        0.00002789897982038133*NH + 0.00022594741608454195*lm*NH + 
        0.000970721433125319*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.0010227233621029892 - 0.007859310154595662*lm - 
          0.005252477383181573*lm^2) + CF*(0.03067538782654221 - 
          0.009049153410814522*lm + 0.017189925981321512*lm^2) + 
        0.000950093455412121*NM + 0.00021351617084314504*lm*NM + 
        0.0009549958878511951*lm^2*NM + 0.0025088467212869784*NL + 
        0.00021351617084314504*lm*NL + 0.0009549958878511951*lm^2*NL - 
        0.00002047214339687666*NH + 0.00021351617084314504*lm*NH + 
        0.0009549958878511951*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.0009778994924867022 - 0.007684527074954406*lm - 
          0.005167492167723139*lm^2) + CF*(0.030245951441435357 - 
          0.009058582683175949*lm + 0.016911792548912095*lm^2) + 
        0.0009226389946844785*NM + 0.00020140342936156232*lm*NM + 
        0.0009395440304951163*lm^2*NM + 0.0024672043160939867*NL + 
        0.00020140342936156232*lm*NL + 0.0009395440304951163*lm^2*NL - 
        0.00001323268675427069*NH + 0.00020140342936156232*lm*NH + 
        0.0009395440304951163*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.0009341690857928083 - 0.007513342658133531*lm - 
          0.005083985640393064*lm^2) + CF*(0.029823185906782314 - 
          0.009066023184578232*lm + 0.016638498459468208*lm^2) + 
        0.0008959476481322205*NM + 0.00018960281444571807*lm*NM + 
        0.0009243610255260117*lm^2*NM + 0.002426336895555117*NL + 
        0.00018960281444571807*lm*NL + 0.0009243610255260117*lm^2*NL - 
        6.1771576324358395*^-6*NH + 0.00018960281444571807*lm*NH + 
        0.0009243610255260117*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.0008915180553618143 - 0.007345688967055846*lm - 
          0.005001931627918523*lm^2) + CF*(0.0294069969503999 - 
          0.009071523991806793*lm + 0.016369958055006077*lm^2) + 
        0.0008699999721552687*NM + 0.00017810803052487577*lm*NM + 
        0.0009094421141670042*lm^2*NM + 0.0023862301337376412*NL + 
        0.00017810803052487577*lm*NL + 0.0009094421141670042*lm^2*NL + 
        6.978566161949587*^-7*NH + 0.00017810803052487577*lm*NH + 
        0.0009094421141670042*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.0008499319117375339 - 0.0071814990538613625*lm - 
          0.004921304375985111*lm^2) + CF*(0.02899729075414406 - 
          0.009075133717644415*lm + 0.016106087048678545*lm^2) + 
        0.0008447769430438954*NM + 0.0001669128649369163*lm*NM + 
        0.0008947826138154747*lm^2*NM + 0.002346869908187144*NL + 
        0.0001669128649369163*lm*NL + 0.0008947826138154747*lm^2*NL + 
        7.395728431936596*^-6*NH + 0.0001669128649369163*lm*NH + 
        0.0008947826138154747*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0008093958086923799 - 0.007020706961704569*lm - 
          0.004842078545839318*lm^2) + CF*(0.02859397400515736 - 
          0.009076900482498216*lm + 0.01584680251365595*lm^2) + 
        0.0008202599520309837*NM + 0.00015601118904131923*lm*NM + 
        0.0008803779174253305*lm^2*NM + 0.002308242301291216*NL + 
        0.00015601118904131923*lm*NL + 0.0008803779174253305*lm^2*NL + 
        0.000013919789522516253*NH + 0.00015601118904131923*lm*NH + 
        0.0008803779174253305*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.000769894586494355 - 0.006863247725417945*lm - 
          0.004764229210701224*lm^2) + CF*(0.02819695394366031 - 
          0.009076871888480779*lm + 0.015592022871385823*lm^2) + 
        0.0007964308001253589*NM + 0.00014539695916992166*lm*NM + 
        0.000866223492854768*lm^2*NM + 0.0022703336013084378*NL + 
        0.00014539695916992166*lm*NL + 0.000866223492854768*lm^2*NL + 
        0.000020273330403498093*NH + 0.00014539695916992166*lm*NH + 
        0.000866223492854768*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.0007314128125523202 - 0.006709057371116135*lm - 
          0.0046877318520044*lm^2) + CF*(0.027806138407441845 - 
          0.009075094995814338*lm + 0.015341667879287127*lm^2) + 
        0.0007732716927506742*NM + 0.000135064217425056*lm*NM + 
        0.0008523148821826181*lm^2*NM + 0.0022331303030852464*NL + 
        0.000135064217425056*lm*NL + 0.0008523148821826181*lm^2*NL + 
        0.000026459600001020868*NH + 0.000135064217425056*lm*NH + 
        0.0008523148821826181*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0006939348195701704 - 0.006558072914811493*lm - 
          0.0046125623554790305*lm^2) + CF*(0.02742143587319892 - 
          0.009071616301432661*lm + 0.015095658617931372*lm^2) + 
        0.0007507652342127385*NM + 0.00012500709233421485*lm*NM + 
        0.0008386477009961873*lm^2*NM + 0.0021966191084820804*NL + 
        0.00012500709233421485*lm*NL + 0.0008386477009961873*lm^2*NL + 
        0.0000324818053135446*NH + 0.00012500709233421485*lm*NH + 
        0.0008386477009961873*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.0006574447413348273 - 0.006410232360108046*lm - 
          0.0045386970070932986*lm^2) + CF*(0.02704275549486997 - 
          0.009066481719660712*lm + 0.014853917477759887*lm^2) + 
        0.0007288944220166535*NM + 0.00011521979936995576*lm*NM + 
        0.0008252176376533271*lm^2*NM + 0.0021607869265290154*NL + 
        0.00011521979936995576*lm*NL + 0.0008252176376533271*lm^2*NL + 
        0.00003834311112944108*NH + 0.00011521979936995576*lm*NH + 
        0.0008252176376533271*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.0006219265462574404 - 0.006265474695037507*lm - 
          0.004466112488867179*lm^2) + CF*(0.026670007139101937 - 
          0.0090597365648575*lm + 0.014616368145383493*lm^2) + 
        0.0007076426410537051*NM + 0.00010569664134334002*lm*NM + 
        0.0008120204525213051*lm^2*NM + 0.002125620873330012*NL + 
        0.00010569664134334002*lm*NL + 0.0008120204525213051*lm^2*NL + 
        0.000044046639797396626*NH + 0.00010569664134334002*lm*NH + 
        0.0008120204525213051*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.0005873640687818777 - 0.006123739888097655*lm - 
          0.004394785874571916*lm^2) + CF*(0.026303101417985492 - 
          0.009051425535912674*lm + 0.01438293558950809*lm^2) + 
        0.000686993657676601*NM + 0.00009643200867879966*lm*NM + 
        0.0007990519771948939*lm^2*NM + 0.002091108271733837*NL + 
        0.00009643200867879966*lm*NL + 0.0007990519771948939*lm^2*NL + 
        0.000049595471046724455*NH + 0.00009643200867879966*lm*NH + 
        0.0007990519771948939*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0005537410387694774 - 0.005984968883550284*lm - 
          0.004324694625327689*lm^2) + CF*(0.025941949719188145 - 
          0.009041592702492288*lm + 0.014153546046526983*lm^2) + 
        0.0006669316136803729*NM + 0.00008742037957794166*lm*NM + 
        0.0007863081136959435*lm^2*NM + 0.0020572366507887216*NL + 
        0.00008742037957794166*lm*NL + 0.0007863081136959435*lm^2*NL + 
        0.000054992641854808545*NH + 0.00008742037957794166*lm*NH + 
        0.0007863081136959435*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.0005210411089641235 - 0.0058491035960328746*lm - 
          0.004255816585111149*lm^2) + CF*(0.02558646423361028 - 
          0.009030281492933983*lm + 0.013928127005818306*lm^2) + 
        0.000647441020205063*NM + 0.00007865632007943037*lm*NM + 
        0.0007737848336565725*lm^2*NM + 0.00202399374499687*NL + 
        0.00007865632007943037*lm*NL + 0.0007737848336565725*lm^2*NL + 
        0.000060241146359020486*NH + 0.00007865632007943037*lm*NH + 
        0.0007737848336565725*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0004892478806369817 - 0.005716086904535335*lm - 
          0.004188129976183832*lm^2) + CF*(0.02523655798068431 - 
          0.009017534683696336*lm + 0.01370660719478345*lm^2) + 
        0.0006285067515751784*NM + 0.0000701344840217362*lm*NM + 
        0.0007614781774879694*lm^2*NM + 0.001991367493384023*NL + 
        0.0000701344840217362*lm*NL + 0.0007614781774879694*lm^2*NL + 
        0.00006534393581056664*NH + 0.0000701344840217362*lm*NH + 
        0.0007614781774879694*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.00045834492750570095 - 0.00558586264579038*lm - 
          0.004121613394451753*lm^2) + CF*(0.02489214483143268 - 
          0.009003394390271601*lm + 0.013488916563660282*lm^2) + 
        0.0006101140390898306*NM + 0.0000618496129152006*lm*NM + 
        0.0007493842535366823*lm^2*NM + 0.001959346038398421*NL + 
        0.0000618496129152006*lm*NL + 0.0007493842535366823*lm^2*NL + 
        0.00007030391856783395*NH + 0.0000618496129152006*lm*NH + 
        0.0007493842535366823*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0004283158180185293 - 0.005458375607123535*lm - 
          0.00405624580476582*lm^2) + CF*(0.024553139529395973 - 
          0.008987902059475222*lm + 0.013274986270142683*lm^2) + 
        0.0005922484647764687*NM + 0.00005379653572954387*lm*NM + 
        0.0007374992372301491*lm^2*NM + 0.0019279177246527045*NL + 
        0.00005379653572954387*lm*NL + 0.0007374992372301491*lm^2*NL + 
        0.00007512396012690995*NH + 0.00005379653572954387*lm*NH + 
        0.0007374992372301491*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.000399144136089613 - 0.005333571518806274*lm - 
          0.003992006536172124*lm^2) + CF*(0.024219457709538022 - 
          0.008971098463029648*lm + 0.013064748663836044*lm^2) + 
        0.0005748959551201717*NM + 0.000045970168602632515*lm*NM + 
        0.0007258193702131136*lm^2*NM + 0.0018970710975214984*NL + 
        0.000045970168602632515*lm*NL + 0.0007258193702131136*lm^2*NL + 
        0.0000798068831870558*NH + 0.000045970168602632515*lm*NH + 
        0.0007258193702131136*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.00037081350036774046 - 0.005211397045953406*lm - 
          0.0039288752771205575*lm^2) + CF*(0.0238910159152308 - 
          0.008953023692363784*lm + 0.012858137270576369*lm^2) + 
        0.000558042774779564*NM + 0.00003836551447602738*lm*NM + 
        0.0007143409594764649*lm^2*NM + 0.0018667949016067003*NL + 
        0.00003836551447602738*lm*NL + 0.0007143409594764649*lm^2*NL + 
        0.0000843554677490102*NH + 0.00003836551447602738*lm*NH + 
        0.0007143409594764649*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.0003433075821169454 - 0.0050917997800036*lm - 
          0.003866832070639668*lm^2) + CF*(0.023567731613417627 - 
          0.008933717154553293*lm + 0.012655086776638914*lm^2) + 
        0.0005416755202995863*NM + 0.00003097766266254956*lm*NM + 
        0.0007030603764799396*lm^2*NM + 0.001837078079081792*NL + 
        0.00003097766266254956*lm*NL + 0.0007030603764799396*lm^2*NL + 
        0.00008877245124409768*NH + 0.00003097766266254956*lm*NH + 
        0.0007030603764799396*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.00031661012178370003 - 0.00497472822981978*lm - 
          0.003805857309485163*lm^2) + CF*(0.023249523208049468 - 
          0.008913217569330435*lm + 0.012455533012860533*lm^2) + 
        0.0005257811138305596*NM + 0.000023801788350831357*lm*NM + 
        0.0006919740562700296*lm^2*NM + 0.001807909767925828*NL + 
        0.000023801788350831357*lm*NL + 0.0006919740562700296*lm^2*NL + 
        0.00009306052869220648*NH + 0.000023801788350831357*lm*NH + 
        0.0006919740562700296*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.0002907049443218967 - 0.004860131812444051*lm - 
          0.00374593173126894*lm^2) + CF*(0.022936310051884977 - 
          0.008891562967095677*lm + 0.012259412938698349*lm^2) + 
        0.0005103467968622355*NM + 0.00001683315205156031*lm*NM + 
        0.0006810784965943528*lm^2*NM + 0.0017792793000571264*NL + 
        0.00001683315205156031*lm*NL + 0.0006810784965943528*lm^2*NL + 
        0.00009722235288678963*NH + 0.00001683315205156031*lm*NH + 
        0.0006810784965943528*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.0002655759733434344 - 0.00474796084353992*lm - 
          0.0036870364135751102*lm^2) + CF*(0.022628012456741536 - 
          0.00886879068786657*lm + 0.012066664626245815*lm^2) + 
        0.0004953601239808314*NM + 0.00001006709898987725*lm*NM + 
        0.0006703702570136564*lm^2*NM + 0.0017511761993760878*NL + 
        0.00001006709898987725*lm*NL + 0.0006703702570136564*lm^2*NL + 
        0.00010126053460512759*NH + 0.00001006709898987725*lm*NH + 
        0.0006703702570136564*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.00024120724415898758 - 0.004638166527552666*lm - 
          0.0036291527690690026*lm^2) + CF*(0.022324551702280607 - 
          0.008844937381102607*lm + 0.011877227244225826*lm^2) + 
        0.0004808089566563875*NM + 3.4990584481535282*^-6*lm*NM + 
        0.000659845958012546*lm^2*NM + 0.0017235901797260048*NL + 
        3.4990584481535282*^-6*lm*NL + 0.000659845958012546*lm^2*NL + 
        0.00010517764284217229*NH + 3.4990584481535282*^-6*lm*NH + 
        0.000659845958012546*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.00021758291577043452 - 0.0045307009476169904*lm - 
          0.00357226254060475*lm^2) + CF*(0.022025850043407427 - 
          0.00882003900634774*lm + 0.011691041041979182*lm^2) + 
        0.0004666814570671721*NM - 2.87545693685297*^-6*lm*NM + 
        0.0006495022801099545*lm^2*NM + 0.0016965111427801874*NL - 
        2.87545693685297*^-6*lm*NL + 0.0006495022801099545*lm^2*NL + 
        0.00010897620506637108*NH - 2.87545693685297*^-6*lm*NH + 
        0.0006495022801099545*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0001946872818734553 - 0.004425517055239374*lm - 
          0.003516347796336654*lm^2) + CF*(0.021731830716361637 - 
          0.00879413083463527*lm + 0.011508047333465414*lm^2) + 
        0.000452966081967277*NM - 9.06085191867833*^-6*lm*NM + 
        0.0006393359629703007*lm^2*NM + 0.0016699291758632182*NL - 
        9.06085191867833*^-6*lm*NL + 0.0006393359629703007*lm^2*NL + 
        0.00011265870749594366*NH - 9.06085191867833*^-6*lm*NH + 
        0.0006393359629703007*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.00017250478092597325 - 0.004322568659780987*lm - 
          0.0034613909248391653*lm^2) + CF*(0.021442417943572083 - 
          0.008767247450602483*lm + 0.011328188481291813*lm^2) + 
        0.0004396515766030076*NM - 0.000015061449424090139*lm*NM + 
        0.0006293438045162119*lm^2*NM + 0.0016438345497136705*NL - 
        0.000015061449424090139*lm*NL + 0.0006293438045162119*lm^2*NL + 
        0.00011622759539415803*NH - 0.000015061449424090139*lm*NH + 
        0.0006293438045162119*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0001510200053353981 - 0.004221810417765464*lm - 
          0.0034073746302399604*lm^2) + CF*(0.02115753693734602 - 
          0.008739422755265161*lm + 0.011151407880785323*lm^2) + 
        0.0004267269686831591*NM - 0.000020881491370898233*lm*NM + 
        0.0006195226600436291*lm^2*NM + 0.0016182177161951678*NL - 
        0.000020881491370898233*lm*NL + 0.0006195226600436291*lm^2*NL + 
        0.00011968527338222021*NH - 0.000020881491370898233*lm*NH + 
        0.0006195226600436291*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.00013021770981503587 - 0.0041231978220344296*lm - 
          0.003354281927370281*lm^2) + CF*(0.02087711390245977 - 
          0.008710689969404637*lm + 0.01097764994412092*lm^2) + 
        0.000414181562407797*NM - 0.000026525139517441485*lm*NM + 
        0.0006098694413400511*lm^2*NM + 0.001593069305962227*NL - 
        0.000026525139517441485*lm*NL + 0.0006098694413400511*lm^2*NL + 
        0.0001230341057684594*NH - 0.000026525139517441485*lm*NH + 
        0.0006098694413400511*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.00011008281895755026 - 0.004026687190772279*lm - 
          0.0033020961369363794*lm^2) + CF*(0.020601076037714952 - 
          0.008681081637522459*lm + 0.01080686008451906*lm^2) + 
        0.0004020049325597098*NM - 0.00003199647634073128*lm*NM + 
        0.0006003811158066144*lm^2*NM + 0.001568380126086922*NL - 
        0.00003199647634073128*lm*NL + 0.0006003811158066144*lm^2*NL + 
        0.00012627641689255366*NH - 0.00003199647634073128*lm*NH + 
        0.0006003811158066144*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.00009060043407099156 - 0.003932235656420405*lm - 
          0.003250800880715626*lm^2) + CF*(0.020329351536521687 - 
          0.008650629632320134*lm + 0.010638984700523867*lm^2) + 
        0.00039018691866228827*NM - 0.00003729950594040186*lm*NM + 
        0.0005910547055846593*lm^2*NM + 0.0015441411576520136*NL - 
        0.00003729950594040186*lm*NL + 0.0005910547055846593*lm^2*NL + 
        0.00012941449148360282*NH - 0.00003729950594040186*lm*NH + 
        0.0005910547055846593*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.00007175583932064534 - 0.003839801154499848*lm - 
          0.0032003800767805694*lm^2) + CF*(0.020061869586567256 - 
          0.008619365159663606*lm + 0.010473971160372773*lm^2) + 
        0.00037871761920719023*NM - 0.00004243815496577922*lm*NM + 
        0.0005818872866873762*lm^2*NM + 0.0015203435533158267*NL - 
        0.00004243815496577922*lm*NL + 0.0005818872866873762*lm^2*NL + 
        0.00013245057503091372*NH - 0.00004243815496577922*lm*NH + 
        0.0005818872866873762*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.00005353450721779212 - 0.0037493424123601496*lm - 
          0.003150817934753961*lm^2) + CF*(0.019798560368626195 - 
          0.008587318763994243*lm + 0.010311767786467509*lm^2) + 
        0.0003675873859547877*NM - 0.00004741627356353399*lm*NM + 
        0.0005728759881370838*lm^2*NM + 0.0014969786348538118*NL - 
        0.00004741627356353399*lm*NL + 0.0005728759881370838*lm^2*NL + 
        0.0001353868741664192*NH - 0.00004741627356353399*lm*NH + 
        0.0005728759881370838*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.00003592210349440571 - 0.00366081893787108*lm - 
          0.0031020989510975334*lm^2) + CF*(0.019539355054565208 - 
          0.008554520334150217*lm + 0.010152323839955563*lm^2) + 
        0.00035678681831005063*NM - 0.000052237636343530313*lm*NM + 
        0.0005640179911086424*lm^2*NM + 0.0014740378906813916*NL - 
        0.000052237636343530313*lm*NL + 0.0005640179911086424*lm^2*NL + 
        0.00013822555705770605*NH - 0.000052237636343530313*lm*NH + 
        0.0005640179911086424*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.000018904491400848158 - 0.003574191008072857*lm - 
          0.003054207904437075*lm^2) + CF*(0.019284185804593842 - 
          0.008520999109564014*lm + 0.009995589505430428*lm^2) + 
        0.0003463067577762014*NM - 0.00005690594336062188*lm*NM + 
        0.0005553105280794682*lm^2*NM + 0.0014515129733623944*NL - 
        0.00005690594336062188*lm*NL + 0.0005553105280794682*lm^2*NL + 
        0.00014096875381067918*NH - 0.00005690594336062188*lm*NH + 
        0.0005553105280794682*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-2.4677354617395575*^-6 - 0.0034894196577994548*lm - 
          0.0030071298509261354*lm^2) + CF*(0.019032985763809518 - 
          0.008486783686803721*lm + 0.009841515875758261*lm^2) + 
        0.0003361382824881806*NM - 0.00006142482111027918*lm*NM + 
        0.0005467508819865701*lm^2*NM + 0.0014293956971070739*NL - 
        0.00006142482111027918*lm*NL + 0.0005467508819865701*lm^2*NL + 
        0.00014361855688093823*NH - 0.00006142482111027918*lm*NH + 
        0.0005467508819865701*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(0.000013401895276612106 - 0.003406466668288665*lm - 
          0.0029608501196504875*lm^2) + CF*(0.01878568905808325 - 
          0.008451902026427514*lm + 0.00969005493703796*lm^2) + 
        0.0003262727018276835*NM - 0.000065797823536058*lm*NM + 
        0.0005383363853909977*lm^2*NM + 0.0014076780352634437*NL - 
        0.000065797823536058*lm*NL + 0.0005383363853909977*lm^2*NL + 
        0.00014617702149299032*NH - 0.000065797823536058*lm*NH + 
        0.0005383363853909977*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(0.00002871792447554659 - 0.0033252945557916487*lm - 
          0.0029153543080752873*lm^2) + CF*(0.018542230789330195 - 
          0.008416381460122416*lm + 0.00954115955370094*lm^2) + 
        0.00031670155112127103*NM - 0.00007002843304703946*lm*NM + 
        0.0005300644196500522*lm^2*NM + 0.0013863521178053922*NL - 
        0.00007002843304703946*lm*NL + 0.0005300644196500522*lm^2*NL + 
        0.00014864616606646874*NH - 0.00007002843304703946*lm*NH + 
        0.0005300644196500522*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(0.000043493666180109014 - 0.0032458665601938774*lm - 
          0.0028706282775366808*lm^2) + CF*(0.018302547030207096 - 
          0.008380248698100048*lm + 0.00939478345375641*lm^2) + 
        0.00030741658642281913*NM - 0.0000741200615434856*lm*NM + 
        0.0005219324140975783*lm^2*NM + 0.0013654102288207942*NL - 
        0.0000741200615434856*lm*NL + 0.0005219324140975783*lm^2*NL + 
        0.00015102797264856935*NH - 0.0000741200615434856*lm*NH + 
        0.0005219324140975783*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(0.000057742222913341205 - 0.003168146633658541*lm - 
          0.0028266581487794485*lm^2) + CF*(0.018066574818276677 - 
          0.008343529836723604*lm + 0.009250881214187287*lm^2) + 
        0.0002984097793813454*NM - 0.00007807605144906327*lm*NM + 
        0.000513937845232627*lm^2*NM + 0.0013448448040026078*NL - 
        0.00007807605144906327*lm*NL + 0.000513937845232627*lm^2*NL + 
        0.00015332438735195966*NH - 0.00007807605144906327*lm*NH + 
        0.000513937845232627*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(0.00007147648416180089 - 0.0030920994293027275*lm - 
          0.0027834302975421124*lm^2) + CF*(0.017834252149677085 - 
          0.008306250366341753*lm + 0.00910940824650146*lm^2) + 
        0.00028967331219504705*NM - 0.00008189967674809212*lm*NM + 
        0.0005060782359167477*lm^2*NM + 0.0013246484281457178*NL - 
        0.00008189967674809212*lm*NL + 0.0005060782359167477*lm^2*NL + 
        0.00015553732079745373*NH - 0.00008189967674809212*lm*NH + 
        0.0005060782359167477*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(0.00008470912522671546 - 0.0030176902899159606*lm - 
          0.0027409313501907825*lm^2) + CF*(0.017605517972332684 - 
          0.008268435179306581*lm + 0.00897032078244256*lm^2) + 
        0.00028119957265218965*NM - 0.00008559414402637001*lm*NM + 
        0.0004983511545801423*lm^2*NM + 0.001304813832652091*NL - 
        0.00008559414402637001*lm*NL + 0.0004983511545801423*lm^2*NL + 
        0.00015766864856078575*NH - 0.00008559414402637001*lm*NH + 
        0.0004983511545801423*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(0.00009745260641652324 - 0.00294488523672998*lm - 
          0.002699148179402875*lm^2) + CF*(0.017380312178740653 - 
          0.008230108578153972*lm + 0.008833575859863954*lm^2) + 
        0.0002729811492593102*NM - 0.0000891625935142226*lm*NM + 
        0.0004907542144368864*lm^2*NM + 0.0012853338930465992*NL - 
        0.0000891625935142226*lm*NL + 0.0004907542144368864*lm^2*NL + 
        0.00015972021162284956*NH - 0.0000891625935142226*lm*NH + 
        0.0004907542144368864*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(0.00010971917255783697 - 0.002873650958248004*lm - 
          0.0026580678999017144*lm^2) + CF*(0.01715857559836619 - 
          0.008191294283926146*lm + 0.008699131308769247*lm^2) + 
        0.0002650108264570312*NM - 0.00009260810013051174*lm*NM + 
        0.00048328507270940265*lm^2*NM + 0.0012662016265056917*NL - 
        0.00009260810013051174*lm*NL + 0.00048328507270940265*lm^2*NL + 
        0.00016169381682280807*NH - 0.00009260810013051174*lm*NH + 
        0.00048328507270940265*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(0.00012152085280308603 - 0.0028039547991410875*lm - 
          0.002617677864242888*lm^2) + CF*(0.016940249989677456 - 
          0.008152015444617211*lm + 0.00856694573752218*lm^2) + 
        0.00025728157992363206*NM - 0.00009593367452642097*lm*NM + 
        0.0004759414298623433*lm^2*NM + 0.001247410189400927*NL - 
        0.00009593367452642097*lm*NL + 0.0004759414298623433*lm^2*NL + 
        0.00016359123731350832*NH - 0.00009593367452642097*lm*NH + 
        0.0004759414298623433*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(0.0001328694607142559 - 0.00273576474921862*lm - 
          0.0025779656586531257*lm^2) + CF*(0.016725278031849887 - 
          0.008112294643723802*lm + 0.008436978519228411*lm^2) + 
        0.00024978657196638094*NM - 0.0000991422641279163*lm*NM + 
        0.00046872102884602286*lm^2*NM + 0.001228952874859196*NL - 
        0.0000991422641279163*lm*NL + 0.00046872102884602286*lm^2*NL + 
        0.0001654142130186705*NH - 0.0000991422641279163*lm*NH + 
        0.00046872102884602286*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(0.00014377659460325097 - 0.002669049432479429*lm - 
          0.002538919098922355*lm^2) + CF*(0.016513603316167864 - 
          0.008072153908883904*lm + 0.008309189778291343*lm^2) + 
        0.00024251914700050423*NM - 0.00010223675417585533*lm*NM + 
        0.00046162165434951907*lm^2*NM + 0.0012108231103413352*NL - 
        0.00010223675417585533*lm*NL + 0.00046162165434951907*lm^2*NL + 
        0.00016716445109134906*NH - 0.00010223675417585533*lm*NH + 
        0.00046162165434951907*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(0.0001542536381104601 - 0.00260377809624946*lm - 
          0.0025005262263494863*lm^2) + CF*(0.01630517033715047 - 
          0.008031614720588035*lm + 0.008183540377143772*lm^2) + 
        0.0002354728271155468*NM - 0.0001052199687627892*lm*NM + 
        0.0004546411320635429*lm^2*NM + 0.0011930144552406644*NL - 
        0.0001052199687627892*lm*NL + 0.0004546411320635429*lm^2*NL + 
        0.0001688436263731933*NH - 0.0001052199687627892*lm*NH + 
        0.0004546411320635429*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(0.00016431176100410697 - 0.0025399206004114903*lm - 
          0.0024627753037423845*lm^2) + CF*(0.01609992448342655 - 
          0.007990698020947932*lm + 0.008059991903156894*lm^2) + 
        0.00022864130772877163*NM - 0.00010809467186557004*lm*NM + 
        0.0004477773279531608*lm^2*NM + 0.0011755205985028636*NL - 
        0.00010809467186557004*lm*NL + 0.0004477773279531608*lm^2*NL + 
        0.00017045338185406265*NH - 0.00010809467186557004*lm*NH + 
        0.0004477773279531608*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(0.00017396192018392142 - 0.00247744740673188*lm - 
          0.002425654811472396*lm^2) + CF*(0.015897812028383 - 
          0.0079494242225088*lm + 0.007938506655727842*lm^2) + 
        0.00022201845332514298*NM - 0.00011086356837293993*lm*NM + 
        0.00044102814754043565*lm^2*NM + 0.0011583353562684602*NL - 
        0.00011086356837293993*lm*NL + 0.00044102814754043565*lm^2*NL + 
        0.0001719953291315775*NH - 0.00011086356837293993*lm*NH + 
        0.00044102814754043565*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(0.00018321486087357483 - 0.002416329568288914*lm - 
          0.002389153443583718*lm^2) + CF*(0.015698780120609036 - 
          0.007907813217092136*lm + 0.007819047633546714*lm^2) + 
        0.0002155982932833479*NM - 0.0001135293051073389*lm*NM + 
        0.0004343915351970397*lm^2*NM + 0.001141452669539094*NL - 
        0.0001135293051073389*lm*NL + 0.0004343915351970397*lm^2*NL + 
        0.0001734710488702127*NH - 0.0001135293051073389*lm*NH + 
        0.0004343915351970397*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(0.00019208111798718633 - 0.0023565387190068797*lm - 
          0.0023532601039578127*lm^2) + CF*(0.015502776774157814 - 
          0.007865884384656888*lm + 0.00770157852204375*lm^2) + 
        0.00020937501778722556*NM - 0.00011609447184022643*lm*NM + 
        0.000427865473446875*lm^2*NM + 0.0011248666018685988*NL - 
        0.00011609447184022643*lm*NL + 0.000427865473446875*lm^2*NL + 
        0.0001748820912595639*NH - 0.00011609447184022643*lm*NH + 
        0.000427865473446875*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(0.00020057101765602654 - 0.002298047063299638*lm - 
          0.0023179639025330055*lm^2) + CF*(0.015309750858645818 - 
          0.00782365660216761*lm + 0.0075860636810171096*lm^2) + 
        0.00020334297382189903*NM - 0.00011856160230026541*lm*NM + 
        0.0004214479822787283*lm^2*NM + 0.0011085713370798432*NL - 
        0.00011856160230026541*lm*NL + 0.0004214479822787283*lm^2*NL + 
        0.0001762299764714404*NH - 0.00011856160230026541*lm*NH + 
        0.0004214479822787283*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(0.0002086946789023258 - 0.00224082736582706*lm - 
          0.0022832541515793365*lm^2) + CF*(0.015119652089209156 - 
          0.0077811482524589495*lm + 0.007472468132441465*lm^2) + 
        0.00019749666125383312*NM - 0.00012093317517376948*lm*NM + 
        0.00041513711846897025*lm^2*NM + 0.0010925611770081721*NL - 
        0.00012093317517376948*lm*NL + 0.00041513711846897025*lm^2*NL + 
        0.00017751619511545977*NH - 0.00012093317517376948*lm*NH + 
        0.00041513711846897025*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(0.0002164620154478352 - 0.002184852941367369*lm - 
          0.0022491203620286595*lm^2) + CF*(0.014932431016334968 - 
          0.0077383772330865954*lm + 0.007360757548457431*lm^2) + 
        0.00019183072899398073*NM - 0.00012321161509686233*lm*NM + 
        0.0004089309749143017*lm^2*NM + 0.0010768305392721937*NL - 
        0.00012321161509686233*lm*NL + 0.0004089309749143017*lm^2*NL + 
        0.00017874220869284064*NH - 0.00012321161509686233*lm*NH + 
        0.0004089309749143017*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(0.00022388273764549363 - 0.0021300976448081037*lm - 
          0.0022155522398599465*lm^2) + CF*(0.01474803901558505 - 
          0.00769536096515544*lm + 0.007250898239541644*lm^2) + 
        0.00018633997124312273*NM - 0.00012539929363884484*lm*NM + 
        0.0004028276799745358*lm^2*NM + 0.0010613739550725712*NL - 
        0.00012539929363884484*lm*NL + 0.0004028276799745358*lm^2*NL + 
        0.0001799094500481095*NH - 0.00012539929363884484*lm*NH + 
        0.0004028276799745358*lm^2*NH)}, 
     {1., 2.9901605060748578*^-12*CF*NC*
       (-10.*CA*(-7.724212598420302*^6 + 6.9445632*^7*lm + 
          7.299072*^7*lm^2) + 20.*CF*(2.43572681928521*^8 - 
          1.27954944*^8*lm + 1.1943936*^8*lm^2) + 6.05383301166257*^7*NM - 
        4.263936*^7*lm*NM + 1.327104*^8*lm^2*NM + 3.49876224*^8*NL - 
        4.263936*^7*lm*NL + 1.327104*^8*lm^2*NL + 6.05383301166257*^7*NH - 
        4.263936*^7*lm*NH + 1.327104*^8*lm^2*NH)}}
 
CbarTable["p", 2, 4] = {{0., -9.720394788002078*^-11*CF*NC*
       (CF*(-6.680692866407926*^8 - 7.327430668528489*^8*lm - 
          1.1573604*^9*lm^2) + 35.*CA*(7.177114445052359*^6 + 
          1.9947862188032452*^7*lm + 6.73596*^6*lm^2) + 
        70.*(9.*(-252382.29040926497 - 114897.19381850964*lm - 68040.*lm^2)*
           NM + 9.*(-252382.29040926497 - 114897.19381850964*lm - 
            68040.*lm^2)*NL + (496876.36851328495 - 1.0340747443665867*^6*
             lm - 612360.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.021067927382582334 - 0.06840544106002758*lm - 
          0.023358932741695485*lm^2) + CF*(0.06720950660691574 + 
          0.06882171907348365*lm + 0.11467112436832329*lm^2) + 
        0.015187139113107623*NM + 0.007031980054158124*lm*NM + 
        0.00424707868030827*lm^2*NM + 0.015186956839078442*NL + 
        0.007031980054158124*lm*NL + 0.00424707868030827*lm^2*NL - 
        0.0034343526441434477*NH + 0.007031980054158124*lm*NH + 
        0.00424707868030827*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.01820438205358834 - 0.06892169753114538*lm - 
          0.02376379561694898*lm^2) + CF*(0.06906610781109362 + 
          0.0667285867376853*lm + 0.11665863302865861*lm^2) + 
        0.014972695681554092*NM + 0.007032157590170471*lm*NM + 
        0.0043206901121725415*lm^2*NM + 0.014970443052443898*NL + 
        0.007032157590170471*lm*NL + 0.0043206901121725415*lm^2*NL - 
        0.0034837335337202313*NH + 0.007032157590170471*lm*NH + 
        0.0043206901121725415*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.01585603805923191 - 0.06941109425811559*lm - 
          0.02412681051761693*lm^2) + CF*(0.07054418105497358 + 
          0.0649819094500533*lm + 0.1184407061773922*lm^2) + 
        0.014813608143565263*NM + 0.007037135365167513*lm*NM + 
        0.004386692821384896*lm^2*NM + 0.01480704851386129*NL + 
        0.007037135365167513*lm*NL + 0.004386692821384896*lm^2*NL - 
        0.00352856521980051*NH + 0.007037135365167513*lm*NH + 
        0.004386692821384896*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.01399371123780703 - 0.06986643997168296*lm - 
          0.024445928301887118*lm^2) + CF*(0.07170799719051663 + 
          0.06356980579892392*lm + 0.12000728439108221*lm^2) + 
        0.014703031242795341*NM + 0.007046080057224676*lm*NM + 
        0.004444714236706749*lm^2*NM + 0.014690550812068548*NL + 
        0.007046080057224676*lm*NL + 0.004444714236706749*lm^2*NL - 
        0.003568597778615662*NH + 0.007046080057224676*lm*NH + 
        0.004444714236706749*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.01257088543378084 - 0.07028026890553571*lm - 
          0.024720477971962487*lm^2) + CF*(0.07261793344495782 + 
          0.06246329499722388*lm + 0.12135507368054313*lm^2) + 
        0.014632263911757116*NM + 0.007057789526502776*lm*NM + 
        0.004494632358538634*lm^2*NM + 0.01461316820456282*NL + 
        0.007057789526502776*lm*NL + 0.004494632358538634*lm^2*NL - 
        0.0036037075391246393*NH + 0.007057789526502776*lm*NH + 
        0.004494632358538634*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.011536140401574689 - 0.07064588219796009*lm - 
          0.024950693652412585*lm^2) + CF*(0.07332524549595536 + 
          0.061626815738030465*lm + 0.12248522338457088*lm^2) + 
        0.014592563273937082*NM + 0.007070991620558426*lm*NM + 
        0.004536489754984107*lm^2*NM + 0.014567118490595084*NL + 
        0.007070991620558426*lm*NL + 0.004536489754984107*lm^2*NL - 
        0.0036338575378157133*NH + 0.007070991620558426*lm*NH + 
        0.004536489754984107*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.010838350361732725 - 0.07095768123775845*lm - 
          0.025137432384278305*lm^2) + CF*(0.07387177402498782 + 
          0.061023088163401795*lm + 0.12340194079554805*lm^2) + 
        0.014575825414125058*NM + 0.007084470086536307*lm*NM + 
        0.004570442251686965*lm^2*NM + 0.01454518573333556*NL + 
        0.007084470086536307*lm*NL + 0.004570442251686965*lm^2*NL - 
        0.003659073776389674*NH + 0.007084470086536307*lm*NH + 
        0.004570442251686965*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.010429067397075208 - 0.0712112377593694*lm - 
          0.025281986867772527*lm^2) + CF*(0.07429092873845473 + 
          0.06061559827219847*lm + 0.12411157189633786*lm^2) + 
        0.014574840336733322*NM + 0.0070971206480040985*lm*NM + 
        0.00459672488504955*lm^2*NM + 0.014540925001492878*NL + 
        0.0070971206480040985*lm*NL + 0.00459672488504955*lm^2*NL - 
        0.003679429239826137*NH + 0.0070971206480040985*lm*NH + 
        0.00459672488504955*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.010263598697913857 - 0.07140325217190327*lm - 
          0.02538595363349469*lm^2) + CF*(0.0746089574326151 + 
          0.060369900123862716*lm + 0.12462195420079211*lm^2) + 
        0.014583359352675754*NM + 0.007107973934248105*lm*NM + 
        0.004615627933362671*lm^2*NM + 0.014548711843411478*NL + 
        0.007107973934248105*lm*NL + 0.004615627933362671*lm^2*NL - 
        0.0036950324034250486*NH + 0.007107973934248105*lm*NH + 
        0.004615627933362671*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.010301418620426198 - 0.07153146331004585*lm - 
          0.025451136807310024*lm^2) + CF*(0.07484618304059454 + 
          0.06025427274097089*lm + 0.12494194432679466*lm^2) + 
        0.01459607410818188*NM + 0.007116201340630812*lm*NM + 
        0.004627479419510913*lm^2*NM + 0.014563720488376723*NL + 
        0.007116201340630812*lm*NL + 0.004627479419510913*lm^2*NL - 
        0.00370601860963435*NH + 0.007116201340630812*lm*NH + 
        0.004627479419510913*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.010506225303960604 - 0.07159453911094525*lm - 
          0.025479476215860893*lm^2) + CF*(0.07501810749735689 + 
          0.060240005168312925*lm + 0.12508106505968075*lm^2) + 
        0.014608553904165366*NM + 0.007121111788402401*lm*NM + 
        0.0046326320392474345*lm^2*NM + 0.014581869355902296*NL + 
        0.007121111788402401*lm*NL + 0.0046326320392474345*lm^2*NL - 
        0.003712543408512822*NH + 0.007121111788402401*lm*NH + 
        0.0046326320392474345*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.010845804685803349 - 0.07159196288259248*lm - 
          0.025472992884701076*lm^2) + CF*(0.07513635881963562 + 
          0.060301461096845824*lm + 0.12504923779762347*lm^2) + 
        0.01461716490922265*NM + 0.007122143658226483*lm*NM + 
        0.004631453251763832*lm^2*NM + 0.014599752957974551*NL + 
        0.007122143658226483*lm*NL + 0.004631453251763832*lm^2*NL - 
        0.003714777309307346*NH + 0.007122143658226483*lm*NH + 
        0.004631453251763832*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.011291792504776871 - 0.0715239226334314*lm - 
          0.025433747365591407*lm^2) + CF*(0.07520948676287315 + 
          0.0604160118813664*lm + 0.12485657797653964*lm^2) + 
        0.014618983709357545*NM + 0.007118854311561416*lm*NM + 
        0.004624317702834801*lm^2*NM + 0.014614570031401593*NL + 
        0.007118854311561416*lm*NL + 0.004624317702834801*lm^2*NL - 
        0.003712901584070048*NH + 0.007118854311561416*lm*NH + 
        0.004624317702834801*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.011819386593240671 - 0.07139120720537366*lm - 
          0.02536380775212787*lm^2) + CF*(0.07524362262621478 + 
          0.06056389222148027*lm + 0.12451323805590045*lm^2) + 
        0.01461171184407935*NM + 0.0071109086070962006*lm*NM + 
        0.0046116014094777944*lm^2*NM + 0.014624053033108932*NL + 
        0.0071109086070962006*lm*NL + 0.0046116014094777944*lm^2*NL - 
        0.0037071048781441712*NH + 0.0071109086070962006*lm*NH + 
        0.0046116014094777944*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.012407040297369394 - 0.07119511093412069*lm - 
          0.02526522514215446*lm^2) + CF*(0.07524302137661862 + 
          0.06072801258899231*lm + 0.12402928706148553*lm^2) + 
        0.014593594820931833*NM + 0.007098067244382895*lm*NM + 
        0.004593677298573538*lm^2*NM + 0.014626401618128004*NL + 
        0.007098067244382895*lm*NL + 0.004593677298573538*lm^2*NL - 
        0.0036975804533945326*NH + 0.007098067244382895*lm*NH + 
        0.004593677298573538*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.01303615532352452 - 0.07093734743903793*lm - 
          0.025140014900756045*lm^2) + CF*(0.07521050376337557 + 
          0.060893750173908405*lm + 0.12341461860371149*lm^2) + 
        0.014563347322751156*NM + 0.0070801754251046695*lm*NM + 
        0.004570911800137463*lm^2*NM + 0.014620221333257523*NL + 
        0.0070801754251046695*lm*NL + 0.004570911800137463*lm^2*NL - 
        0.0036845239364853392*NH + 0.0070801754251046695*lm*NH + 
        0.004570911800137463*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.013690784745923107 - 0.07061997251636465*lm - 
          0.024990142486861985*lm^2) + CF*(0.07514781441502857 + 
          0.06104873235859898*lm + 0.12267888129914065*lm^2) + 
        0.014520085302686236*NM + 0.007057152113453609*lm*NM + 
        0.004543662270338543*lm^2*NM + 0.014604467980608916*NL + 
        0.007057152113453609*lm*NL + 0.004543662270338543*lm^2*NL - 
        0.0036681314760366145*NH + 0.007057152113453609*lm*NH + 
        0.004543662270338543*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.014357352248106562 - 0.07024531576220738*lm - 
          0.024817512896662786*lm^2) + CF*(0.07505590989008434 + 
          0.061182621707988064*lm + 0.12183142694725367*lm^2) + 
        0.01446326507555591*NM + 0.007028980046793426*lm*NM + 
        0.004512275072120506*lm^2*NM + 0.014578397667181909*NL + 
        0.007028980046793426*lm*NL + 0.004512275072120506*lm^2*NL - 
        0.003648598234606521*NH + 0.007028980046793426*lm*NH + 
        0.004512275072120506*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.015024390755019379 - 0.06981592036880732*lm - 
          0.024623962988180367*lm^2) + CF*(0.0749351886540921 + 
          0.0612869081522157*lm + 0.12088127285106726*lm^2) + 
        0.014392629181580432*NM + 0.006995696565658766*lm*NM + 
        0.004477084179669157*lm^2*NM + 0.01454152231483687*NL + 
        0.006995696565658766*lm*NL + 0.004477084179669157*lm^2*NL - 
        0.0036261171573958467*NH + 0.006995696565658766*lm*NH + 
        0.004477084179669157*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.015682301778234386 - 0.06933449045226*lm - 
          0.024411256108337144*lm^2) + CF*(0.07478567312620057 + 
          0.061354711824894013*lm + 0.1198370754409278*lm^2) + 
        0.014308158617863078*NM + 0.006957385280299836*lm*NM + 
        0.004438410201515844*lm^2*NM + 0.014493570278499136*NL + 
        0.006957385280299836*lm*NL + 0.004438410201515844*lm^2*NL - 
        0.0036008779713511325*NH + 0.006957385280299836*lm*NH + 
        0.004438410201515844*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.016323135646495544 - 0.0688038452428909*lm - 
          0.024181078562782825*lm^2) + CF*(0.074607152326758 + 
          0.0613805985285004*lm + 0.11870711294457023*lm^2) + 
        0.014210030944182703*NM + 0.006914168558559345*lm*NM + 
        0.004396559738687786*lm^2*NM + 0.014434451662258416*NL + 
        0.006914168558559345*lm*NL + 0.004396559738687786*lm^2*NL - 
        0.003573066377227683*NH + 0.006914168558559345*lm*NH + 
        0.004396559738687786*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.016940392083013154 - 0.06822687947713599*lm - 
          0.023935037560216664*lm^2) + CF*(0.07439929226747455 + 
          0.06136040879040604*lm + 0.11749927529560907*lm^2) + 
        0.014098583736503207*NM + 0.00686620080009029*lm*NM + 
        0.0043518250109484844*lm^2*NM + 0.014364227905414296*NL + 
        0.00686620080009029*lm*NL + 0.0043518250109484844*lm^2*NL - 
        0.0035428634039988026*NH + 0.00686620080009029*lm*NH + 
        0.0043518250109484844*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.017528840166080986 - 0.0676065293574798*lm - 
          0.023674660334258423*lm^2) + CF*(0.074161720041355 + 
          0.06129110079391406*lm + 0.11622105982272317*lm^2) + 
        0.01397428286187984*NM + 0.006813662450457188*lm*NM + 
        0.004304483697137895*lm^2*NM + 0.014283085216672774*NL + 
        0.006813662450457188*lm*NL + 0.004304483697137895*lm^2*NL - 
        0.003510444900326359*NH + 0.006813662450457188*lm*NH + 
        0.004304483697137895*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.01808435647185105 - 0.06694574348570552*lm - 
          0.023401394202152617*lm^2) + CF*(0.07389408656816307 + 
          0.061170607015967014*lm + 0.11487957153784012*lm^2) + 
        0.013837695068298732*NM + 0.006756754702688001*lm*NM + 
        0.00425479894584593*lm^2*NM + 0.014191311454338046*NL + 
        0.006756754702688001*lm*NL + 0.00425479894584593*lm^2*NL - 
        0.003475981142028569*NH + 0.006756754702688001*lm*NH + 
        0.00425479894584593*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.01860378008303506 - 0.06624745821875319*lm - 
          0.023116607364362034*lm^2) + CF*(0.0735961121083971 + 
          0.06099770410765867*lm + 0.11348152706141362*lm^2) + 
        0.013689464413728399*NM + 0.0066956948314911835*lm*NM + 
        0.0042030195207930976*lm^2*NM + 0.014089276077127209*NL + 
        0.0066956948314911835*lm*NL + 0.0042030195207930976*lm^2*NL - 
        0.003439636537867262*NH + 0.0066956948314911835*lm*NH + 
        0.0042030195207930976*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.019084783112253565 - 0.06551457694232417*lm - 
          0.02282159028505185*lm^2) + CF*(0.07326761795172923 + 
          0.06077189536788302*lm + 0.11203326139934544*lm^2) + 
        0.013530292094814047*NM + 0.0066307121053692545*lm*NM + 
        0.004149380051827609*lm^2*NM + 0.01397741282024743*NL + 
        0.0066307121053692545*lm*NL + 0.004149380051827609*lm^2*NL - 
        0.0034015694187250175*NH + 0.0066307121053692545*lm*NH + 
        0.004149380051827609*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.019525755405220096 - 0.06474995280282841*lm - 
          0.022517557522531574*lm^2) + CF*(0.07290854709399619 + 
          0.06049330505139596*lm + 0.11054073692879138*lm^2) + 
        0.013360919273773192*NM + 0.006562044223399513*lm*NM + 
        0.0040941013677330135*lm^2*NM + 0.013856204782214894*NL + 
        0.006562044223399513*lm*NL + 0.0040941013677330135*lm^2*NL - 
        0.0033619318974956068*NH + 0.006562044223399513*lm*NH + 
        0.0040941013677330135*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.01992570213774281 - 0.06395637448203*lm - 
          0.022205649902369402*lm^2) + CF*(0.07251897622215643 + 
          0.06016258369709862*lm + 0.10900955406617707*lm^2) + 
        0.013182112540029678*NM + 0.006489934225936501*lm*NM + 
        0.004037390891339892*lm^2*NM + 0.013726171638117351*NL + 
        0.006489934225936501*lm*NL + 0.004037390891339892*lm^2*NL - 
        0.0033208697888752175*NH + 0.006489934225936501*lm*NH + 
        0.004037390891339892*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.02028415308868683 - 0.06313655464004933*lm - 
          0.021886936945232215*lm^2) + CF*(0.07209912091370455 + 
          0.059780823644075595*lm + 0.10744496318568542*lm^2) + 
        0.012994651679670198*NM + 0.00641462783152548*lm*NM + 
        0.003979443080951312*lm^2*NM + 0.01358785872379038*NL + 
        0.00641462783152548*lm*NL + 0.003979443080951312*lm^2*NL - 
        0.003278522579796734*NH + 0.00641462783152548*lm*NH + 
        0.003979443080951312*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.020601082449804065 - 0.06229312069083821*lm - 
          0.021562419477389703*lm^2) + CF*(0.07164933561272661 + 
          0.05934948391014827*lm + 0.10585187743445854*lm^2) + 
        0.012799319460180059*NM + 0.006336371155632472*lm*NM + 
        0.0039204399049799455*lm^2*NM + 0.013441827762240125*NL + 
        0.006336371155632472*lm*NL + 0.0039204399049799455*lm^2*NL - 
        0.003235023442555575*NH + 0.006336371155632472*lm*NH + 
        0.0039204399049799455*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.02087683811679933 - 0.06142860760969764*lm - 
          0.021233032364917186*lm^2) + CF*(0.07117010965797065 + 
          0.05887032363206559*lm + 0.104234886155048*lm^2) + 
        0.012596893169701957*NM + 0.006255408770212125*lm*NM + 
        0.003860551339075852*lm^2*NM + 0.013288649028396925*NL + 
        0.006255408770212125*lm*NL + 0.003860551339075852*lm^2*NL - 
        0.0031904992837801147*NH + 0.006255408770212125*lm*NH + 
        0.003860551339075852*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.02111207949020529 - 0.06054545250485325*lm - 
          0.020899647323461428*lm^2) + CF*(0.07066206039959111 + 
          0.058345343301947745*lm + 0.10259826867881064*lm^2) + 
        0.012388137679026414*NM + 0.006171982066527699*lm*NM + 
        0.003799935876992987*lm^2*NM + 0.013128894770873258*NL + 
        0.006171982066527699*lm*NL + 0.003799935876992987*lm^2*NL - 
        0.0031450708233389884*NH + 0.006171982066527699*lm*NH + 
        0.003799935876992987*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.021307722896940728 - 0.05964599071462529*lm - 
          0.02056307576441093*lm^2) + CF*(0.07012592424260153 + 
          0.05777673307691821*lm + 0.1009460082980173*lm^2) + 
        0.012173799820453432*NM + 0.006086327886927688*lm*NM + 
        0.0037387410480747146*lm^2*NM + 0.012963133729868782*NL + 
        0.006086327886927688*lm*NL + 0.0037387410480747146*lm^2*NL - 
        0.0030988526980804108*NH + 0.006086327886927688*lm*NH + 
        0.0037387410480747146*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.021464893822023667 - 0.058732453218472716*lm - 
          0.020224071645767696*lm^2) + CF*(0.06956254628959851 + 
          0.05716682748492622*lm + 0.09928180626104141*lm^2) + 
        0.011954603900184787*NM + 0.0059986773944206975*lm*NM + 
        0.0036771039355941266*lm^2*NM + 0.012791926608814364*NL + 
        0.0059986773944206975*lm*NL + 0.0036771039355941266*lm^2*NL - 
        0.0030519535859878594*NH + 0.0059986773944206975*lm*NH + 
        0.0036771039355941266*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.021584885213444132 - 0.05780696517432838*lm - 
          0.019883334302217563*lm^2) + CF*(0.06897286911671589 + 
          0.05651806589738981*lm + 0.09760909566543167*lm^2) + 
        0.011731248179175056*NM + 0.005909255151844071*lm*NM + 
        0.003615151691312284*lm^2*NM + 0.012615822373905706*NL + 
        0.005909255151844071*lm*NL + 0.003615151691312284*lm^2*NL - 
        0.0030044763469305293*NH + 0.005909255151844071*lm*NH + 
        0.003615151691312284*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.02166912119035312 - 0.05687154541636388*lm - 
          0.019541511234056504*lm^2) + CF*(0.06835792109882138 + 
          0.05583295818694215*lm + 0.09593105514900466*lm^2) + 
        0.011504402169579868*NM + 0.005818278385177052*lm*NM + 
        0.003553002042555728*lm^2*NM + 0.012435355270490531*NL + 
        0.005818278385177052*lm*NL + 0.003553002042555728*lm^2*NL - 
        0.0029565181767007005*NH + 0.005818278385177052*lm*NH + 
        0.003553002042555728*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.021719125543715193 - 0.05592810676682165*lm - 
          0.019199200838926424*lm^2) + CF*(0.06771880459568204 + 
          0.055114055035180305*lm + 0.09425062230018426*lm^2) + 
        0.011274704596472769*NM + 0.005725956408100302*lm*NM + 
        0.0034907637888957135*lm^2*NM + 0.01225104245848987*NL + 
        0.005725956408100302*lm*NL + 0.0034907637888957135*lm^2*NL - 
        0.0029081707714757868*NH + 0.005725956408100302*lm*NH + 
        0.0034907637888957135*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.02173649446646331 - 0.054978457033017396*lm - 
          0.018856955073890055*lm^2) + CF*(0.06705668421109583 + 
          0.054363922400185005*lm + 0.09257050672636936*lm^2) + 
        0.011042761860589603*NM + 0.005632490187251745*lm*NM + 
        0.0034285372861618283*lm^2*NM + 0.012063382180800452*NL + 
        0.005632490187251745*lm*NL + 0.0034285372861618283*lm^2*NL - 
        0.0028595205002303254*NH + 0.005632490187251745*lm*NH + 
        0.0034285372861618283*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.021722872981911143 - 0.05402430057623223*lm - 
          0.018515282038348888*lm^2) + CF*(0.06637277522868822 + 
          0.05358511969624327*lm + 0.09089320273371271*lm^2) + 
        0.010809146795666249*NM + 0.005538072029779672*lm*NM + 
        0.0033664149160634337*lm^2*NM + 0.011872852389081718*NL + 
        0.005538072029779672*lm*NL + 0.0033664149160634337*lm^2*NL - 
        0.002810648582960886*NH + 0.005538072029779672*lm*NH + 
        0.0033664149160634337*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.02167994099163631 - 0.05306724035315173*lm - 
          0.01817464847077849*lm^2) + CF^2*(0.0656683450823255 + 
          0.05278018127839235*lm + 0.08922100158382168*lm^2) + 
        CF*((0.010574414777111534 + 0.005442885376756532*lm + 
            0.0033044815401415436*lm^2)*NM + (0.011679909760608844 + 
            0.005442885376756532*lm + 0.0033044815401415436*lm^2)*NL + 
          (-0.00276163127288168 + 0.005442885376756532*lm + 
            0.0033044815401415436*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.02160937799071905 - 0.052108780342930844*lm - 
          0.01783548215430372*lm^2) + CF^2*(0.06494466684039904 + 
          0.05195160086197418*lm + 0.08755600330294554*lm^2) + 
        CF*((0.010339054294680428 + 0.005347104687801441*lm + 
            0.0032428149371461308*lm^2)*NM + (0.011484989048094469 + 
            0.005347104687801441*lm + 0.0032428149371461308*lm^2)*NL + 
          (-0.002712540041006437 + 0.005347104687801441*lm + 
            0.0032428149371461308*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.02151287077565257 - 0.05115032828401803*lm - 
          0.01749817422782919*lm^2) + CF^2*(0.06420305412247095 + 
          0.05110181854230528*lm + 0.08590012802752513*lm^2) + 
        CF*((0.010103547703073937 + 0.005250895403877515*lm + 
            0.003181486223241671*lm^2)*NM + (0.01128850271165813 + 
            0.005250895403877515*lm + 0.003181486223241671*lm^2)*NL + 
          (-0.0026634417617577436 + 0.005250895403877515*lm + 
            0.003181486223241671*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.021392088677765937 - 0.05019319865469578*lm - 
          0.01716308140083534*lm^2) + CF^2*(0.0634448271806748 + 
          0.05023321011185135*lm + 0.08425512687682804*lm^2) + 
        CF*((0.009868337421750629 + 0.0051544139766935325*lm + 
            0.003120560254697335*lm^2)*NM + (0.011090840788555318 + 
            0.0051544139766935325*lm + 0.003120560254697335*lm^2)*NL + 
          (-0.002614398898442729 + 0.0051544139766935325*lm + 
            0.003120560254697335*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.02124867612378276 - 0.04923861584001382*lm - 
          0.01683052807109395*lm^2) + CF^2*(0.06267131032738227 + 
          0.049348078402027075*lm + 0.08262259234900667*lm^2) + 
        CF*((0.009633834134472474 + 0.005057807954460111*lm + 
            0.003060096012926173*lm^2)*NM + (0.01089237096195989 + 
            0.005057807954460111*lm + 0.003060096012926173*lm^2)*NL + 
          (-0.002565469687607135 + 0.005057807954460111*lm + 
            0.003060096012926173*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.021084244225198574 - 0.04828771743551963*lm - 
          0.016500808345489518*lm^2) + CF^2*(0.06188382461350741 + 
          0.04844864640402193*lm + 0.081003968241494*lm^2) + 
        CF*((0.009400417657972358 + 0.004961216114939878*lm + 
            0.0030001469719071854*lm^2)*NM + (0.010693438795107021 + 
            0.004961216114939878*lm + 0.0030001469719071854*lm^2)*NL + 
          (-0.0025167083214324894 + 0.004961216114939878*lm + 
            0.0030001469719071854*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.020900363915053056 - 0.0473415576450313*lm - 
          0.01617418796488745*lm^2) + CF^2*(0.061083681228148466 + 
          0.04753705194801033*lm + 0.07940055910035657*lm^2) + 
        CF*((0.009168437935024854 + 0.004864768637800331*lm + 
            0.0029407614481613545*lm^2)*NM + (0.010494368101523642 + 
            0.004864768637800331*lm + 0.0029407614481613545*lm^2)*NL + 
          (-0.002468165127471831 + 0.004864768637800331*lm + 
            0.0029407614481613545*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.02069856043522114 - 0.04640111073574574*lm - 
          0.01585090613459507*lm^2) + CF^2*(0.06027217560050815 + 
          0.046615343742875945*lm + 0.07781353920619398*lm^2) + 
        CF*((0.008938216122552125 + 0.004768587309237556*lm + 
            0.0028819829335627396*lm^2)*NM + (0.010295461425966148 + 
            0.004768587309237556*lm + 0.0028819829335627396*lm^2)*NL + 
          (-0.0024198867451413523 + 0.004768587309237556*lm + 
            0.0028819829335627396*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.020480308999195142 - 0.04546727451931273*lm - 
          0.015531177262440616*lm^2) + CF^2*(0.0594505821774128 + 
          0.04568547859930897*lm + 0.07624396110652666*lm^2) + 
        CF*((0.008710045749414225 + 0.0046727857526987*lm + 
            0.0028238504113528395*lm^2)*NM + (0.010097000614110702 + 
            0.0046727857526987*lm + 0.0028238504113528395*lm^2)*NL + 
          (-0.0023719162984811937 + 0.0046727857526987*lm + 
            0.0028238504113528395*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.020247031475172407 - 0.044540873832211406*lm - 
          0.015215192606869005*lm^2) + CF^2*(0.058620149844722316 + 
          0.04474931967796479*lm + 0.07469276370644784*lm^2) + 
        CF*((0.008484193922661263 + 0.0045774696803001546*lm + 
            0.0027663986557943648*lm^2)*NM + (0.009899247452053015 + 
            0.0045774696803001546*lm + 0.0027663986557943648*lm^2)*NL + 
          (-0.0023242935647934445 + 0.0045774696803001546*lm + 
            0.0027663986557943648*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.020000093951788995 - 0.04362266399290681*lm - 
          0.014903121837738032*lm^2) + CF^2*(0.05778209795704192 + 
          0.043808635621445845*lm + 0.07316077993071397*lm^2) + 
        CF*((0.008260902564015188 + 0.004482737160225495*lm + 
            0.0027096585159523696*lm^2)*NM + (0.009702444359319527 + 
            0.004482737160225495*lm + 0.0027096585159523696*lm^2)*NL + 
          (-0.0022770551388412745 + 0.004482737160225495*lm + 
            0.0027096585159523696*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.0197408050646945 - 0.042713334216902786*lm - 
          0.014595114512709569*lm^2) + CF^2*(0.05693761293798173 + 
          0.04286510044432167*lm + 0.07164874397148334*lm^2) + 
        CF*((0.008040389661356366 + 0.004388678895999945*lm + 
            0.002653657184129012*lm^2)*NM + (0.00950681512141262 + 
            0.004388678895999945*lm + 0.002653657184129012*lm^2)*NL + 
          (-0.0022302345923622814 + 0.004388678895999945*lm + 
            0.002653657184129012*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.01947041497628086 - 0.04181351097399931*lm - 
          0.014291301472279203*lm^2) + CF^2*(0.056087845411995116 + 
          0.04192029406936736*lm + 0.07015729813664336*lm^2) + 
        CF*((0.007822850522445059 + 0.004295378514084025*lm + 
            0.0025984184495053096*lm^2)*NM + (0.009312565649946472 + 
            0.004295378514084025*lm + 0.0025984184495053096*lm^2)*NL + 
          (-0.0021838626287086654 + 0.004295378514084025*lm + 
            0.0025984184495053096*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.01919011491352206 - 0.040923761274855835*lm - 
          0.013991796156585213*lm^2) + CF^2*(0.05523390782853189 + 
          0.040975703410801805*lm + 0.06868699931414558*lm^2) + 
        CF*((0.007608459020281157 + 0.0042029128567144*lm + 
            0.0025439629375609476*lm^2)*NM + (0.00911988476021076 + 
            0.0042029128567144*lm + 0.0025439629375609476*lm^2)*NL + 
          (-0.002137967232479048 + 0.0042029128567144*lm + 
            0.0025439629375609476*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.01890103718017758 - 0.04004459587640303*lm - 
          0.01369669584719252*lm^2) + CF^2*(0.05437687253963097 + 
          0.040032723916662356*lm + 0.06723832506803601*lm^2) + 
        CF*((0.007397368821338433 + 0.004111352277351042*lm + 
            0.002490308335853185*lm^2)*NM + (0.008928944957556195 + 
            0.004111352277351042*lm + 0.002490308335853185*lm^2)*NL + 
          (-0.0020925738140516476 + 0.004111352277351042*lm + 
            0.002490308335853185*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.018604255569753037 - 0.039176472397771965*lm - 
          0.013406082837066896*lm^2) + CF^2*(0.05351777029310655 + 
          0.03909266149266967*lm + 0.06581167938196476*lm^2) + 
        CF*((0.007189714589613542 + 0.004020760936471984*lm + 
            0.0024374696067394354*lm^2)*NM + (0.008739903225355184 + 
            0.004020760936471984*lm + 0.0024374696067394354*lm^2)*NL + 
          (-0.0020477053489676277 + 0.004020760936471984*lm + 
            0.0024374696067394354*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.018300786114644817 - 0.038319798340259094*lm - 
          0.013120025531945384*lm^2) + CF^2*(0.052657589104873725 + 
          0.0381567347391193*lm + 0.06440739806591371*lm^2) + 
        CF*((0.006985613160731723 + 0.003931197095795284*lm + 
            0.0023854591876264334*lm^2)*NM + (0.008552901808475994 + 
            0.003931197095795284*lm + 0.0023854591876264334*lm^2)*NL + 
          (-0.0020033825121471686 + 0.003931197095795284*lm + 
            0.0023854591876264334*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.01799158811503459 - 0.037474934006447726*lm - 
          0.012838579486276253*lm^2) + CF^2*(0.05179727347581178 + 
          0.03722607744057764*lm + 0.06302575384171978*lm^2) + 
        CF*((0.006785164681646991 + 0.0038427134093067354*lm + 
            0.002334287179322955*lm^2)*NM + (0.00836806898724026 + 
            0.0038427134093067354*lm + 0.002334287179322955*lm^2)*NL + 
          (-0.0019596238069499194 + 0.0038427134093067354*lm + 
            0.002334287179322955*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.01767756539831626 - 0.036642195314991535*lm - 
          0.012561788376850149*lm^2) + CF^2*(0.05093772392053168 + 
          0.03630174125554725*lm + 0.06166696112271891*lm^2) + 
        CF*((0.0065884537124033605 + 0.003755357209735617*lm + 
            0.0022839615230636633*lm^2)*NM + (0.00818551983772988 + 
            0.003755357209735617*lm + 0.0022839615230636633*lm^2)*NL + 
          (-0.001916445689115352 + 0.003755357209735617*lm + 
            0.0022839615230636633*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.01735956776633154 - 0.03582185650875766*lm - 
          0.012289684917177567*lm^2) + CF^2*(0.050079796777646304 + 
          0.035384698559879954*lm + 0.06033118050250806*lm^2) + 
        CF*((0.00639555028749551 + 0.003669170789352865*lm + 
            0.0022344881667595577*lm^2)*NM + (0.008005356975086456 + 
            0.003669170789352865*lm + 0.0022344881667595577*lm^2)*NL + 
          (-0.0018738626856414644 + 0.003669170789352865*lm + 
            0.0022344881667595577*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.01703844466690873 - 0.035014152755048905*lm - 
          0.012022291715589275*lm^2) + CF^2*(0.04922440842031277 + 
          0.034475845403628795*lm + 0.05901852296743826*lm^2) + 
        CF*((0.006206510934789088 + 0.003584191674170052*lm + 
            0.0021858712210162316*lm^2)*NM + (0.007827671277118683 + 
            0.003584191674170052*lm + 0.0021858712210162316*lm^2)*NL + 
          (-0.0018318875086755118 + 0.003584191674170052*lm + 
            0.0021858712210162316*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.016714830404952488 - 0.034219282637496407*lm - 
          0.01175962207994896*lm^2) + CF^2*(0.04837210253535347 + 
          0.033576004546309546*lm + 0.05772905384702216*lm^2) + 
        CF*((0.0060213796510623875 + 0.0035004528907962816*lm + 
            0.0021381131054452654*lm^2)*NM + (0.007652542586113392 + 
            0.0035004528907962816*lm + 0.0021381131054452654*lm^2)*NL + 
          (-0.0017905311645076175 + 0.0035004528907962816*lm + 
            0.0021381131054452654*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.016389483361828047 - 0.03343741053995395*lm - 
          0.01150168077177323*lm^2) + CF^2*(0.04752372543941267 + 
          0.03268592854025016*lm + 0.05646279651597768*lm^2) + 
        CF*((0.005840188833174927 + 0.0034179832253664172*lm + 
            0.002091214685776951*lm^2)*NM + (0.007480040387245121 + 
            0.0034179832253664172*lm + 0.002091214685776951*lm^2)*NL + 
          (-0.0017498030577689444 + 0.0034179832253664172*lm + 
            0.002091214685776951*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.016063053822906317 - 0.03266866892334883*lm - 
          0.011248464712455181*lm^2) + CF^2*(0.04667995865699144 + 
          0.03180630283589827*lm + 0.05521973586114362*lm^2) + 
        CF*((0.005662960165313847 + 0.0033368074740903245*lm + 
            0.0020451754022645786*lm^2)*NM + (0.00731022446240759 + 
            0.0033368074740903245*lm + 0.0020451754022645786*lm^2)*NL + 
          (-0.0017097110909466034 + 0.0033368074740903245*lm + 
            0.0020451754022645786*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.015736146838887674 - 0.03191316049696558*lm - 
          0.010999963644185672*lm^2) + CF^2*(0.04584144163169846 + 
          0.03093774888668409*lm + 0.053999821526002384*lm^2) + 
        CF*((0.0054897054614618645 + 0.0032569466850912734*lm + 
            0.00199999338985194*lm^2)*NM + (0.007143145518656406 + 
            0.0032569466850912734*lm + 0.00199999338985194*lm^2)*NL + 
          (-0.001670261759336129 + 0.0032569466850912734*lm + 
            0.00199999338985194*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.015409324130811742 - 0.03117096028607123*lm - 
          0.010756160748062633*lm^2) + CF^2*(0.04500877260636475 + 
          0.03008082723434453*lm + 0.05280297094503474*lm^2) + 
        CF*((0.005320427465853787 + 0.003178418391304242*lm + 
            0.0019556655905568422*lm^2)*NM + (0.006978845790764053 + 
            0.003178418391304242*lm + 0.0019556655905568422*lm^2)*NL + 
          (-0.001631460241557492 + 0.003178418391304242*lm + 
            0.0019556655905568422*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.015083106553326696 - 0.030442117598144608*lm - 
          0.010517033221774197*lm^2) + CF^2*(0.04418251071337618 + 
          0.029236040558546967*lm + 0.05162907217961878*lm^2) + 
        CF*((0.005155121716207282 + 0.00310123683429342*lm + 
            0.0019121878585043994*lm^2)*NM + (0.006817359617652152 + 
            0.00310123683429342*lm + 0.0019121878585043994*lm^2)*NL + 
          (-0.001593310485766889 + 0.00310123683429342*lm + 
            0.0019121878585043994*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.014757973219446387 - 0.029726657890257975*lm - 
          0.010282552819137076*lm^2) + CF^2*(0.043363171490815276 + 
          0.028403836677245133*lm + 0.05047798656667291*lm^2) + 
        CF*((0.004993771698853141 + 0.0030254131789242754*lm + 
            0.0018695550580249227*lm^2)*NM + (0.006658713992688327 + 
            0.0030254131789242754*lm + 0.0018695550580249227*lm^2)*NL + 
          (-0.0015558152916994 + 0.0030254131789242754*lm + 
            0.0018695550580249227*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.01443436900188805 - 0.02902458454038523*lm - 
          0.010052686353668419*lm^2) + CF^2*(0.04255123926114241 + 
          0.027584611486490926*lm + 0.04934955119073588*lm^2) + 
        CF*((0.00483636076339225 + 0.002950955718890573*lm + 
            0.00182776115521244*lm^2)*NM + (0.006502929088021049 + 
            0.002950955718890573*lm + 0.00182776115521244*lm^2)*NL + 
          (-0.0015189763886772265 + 0.002950955718890573*lm + 
            0.00182776115521244*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.014112700555001289 - 0.028335880525585635*lm - 
          0.0098273961682676*lm^2) + CF^2*(0.04174715666480663 + 
          0.026778711830444436*lm + 0.04824358118967731*lm^2) + 
        CF*((0.0046828610814817675 + 0.002877870073151993*lm + 
            0.0017867993033213816*lm^2)*NM + (0.006350018753280277 + 
            0.002877870073151993*lm + 0.0017867993033213816*lm^2)*NL + 
          (-0.001482794509728301 + 0.002877870073151993*lm + 
            0.0017867993033213816*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.013793341450556204 - 0.027660510010141526*lm - 
          0.009606640572984803*lm^2) + CF^2*(0.04095133253787386 + 
          0.025986438294099877*lm + 0.04715987190374358*lm^2) + 
        CF*((0.004533240875289558 + 0.002806159373384621*lm + 
            0.0017466619223608733*lm^2)*NM + (0.006199990989098631 + 
            0.002806159373384621*lm + 0.0017466619223608733*lm^2)*NL + 
          (-0.0014472694619467406 + 0.002806159373384621*lm + 
            0.0017466619223608733*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.013476632871508 - 0.026998419846819593*lm - 
          0.009390374252756172*lm^2) + CF^2*(0.040164141022950975 + 
          0.025208047912802088*lm + 0.046098200877166665*lm^2) + 
        CF*((0.004387462806011067 + 0.0027358244425856053*lm + 
            0.0017073407732283948*lm^2)*NM + (0.006052848396010934 + 
            0.0027358244425856053*lm + 0.0017073407732283948*lm^2)*NL + 
          (-0.0014124001932412273 + 0.0027358244425856053*lm + 
            0.0017073407732283948*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.013162885606005014 - 0.02634954099448302*lm - 
          0.009178548646890878*lm^2) + CF^2*(0.03938592339774055 + 
          0.024443756793990353*lm + 0.045058329721100666*lm^2) + 
        CF*((0.004245485020897371 + 0.002666863965005636*lm + 
            0.0016688270267074322*lm^2)*NM + (0.005908588599372431 + 
            0.002666863965005636*lm + 0.0016688270267074322*lm^2)*NL + 
          (-0.0013781848556026005 + 0.002666863965005636*lm + 
            0.0016688270267074322*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.012852381676654138 - 0.025713789855311128*lm - 
          0.008971112302004123*lm^2) + CF^2*(0.038616989290040586 + 
          0.02369374264779429*lm + 0.04404000584620206*lm^2) + 
        CF*((0.004107261538832532 + 0.002599274647609334*lm + 
            0.0016311113276371132*lm^2)*NM + (0.005767204651000595 + 
            0.002599274647609334*lm + 0.0016311113276371132*lm^2)*NL + 
          (-0.0013446208650345944 + 0.002599274647609334*lm + 
            0.0016311113276371132*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.012545375967574386 - 0.02509106953488801*lm - 
          0.008768011200001907*lm^2) + CF^2*(0.03785761800221751 + 
          0.022958147224139178*lm + 0.04304296407273663*lm^2) + 
        CF*((0.003972742707166695 + 0.002533051373284982*lm + 
            0.0015941838545458012*lm^2)*NM + (0.005628685408294705 + 
            0.002533051373284982*lm + 0.0015941838545458012*lm^2)*NL + 
          (-0.0013117049582744556 + 0.002533051373284982*lm + 
            0.0015941838545458012*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.012242097795072434 - 0.024481271028406183*lm - 
          0.008569189062638368*lm^2) + CF^2*(0.0371080598341341 + 
          0.022237078654912475*lm + 0.04206692812567926*lm^2) + 
        CF*((0.0038418756268078606 + 0.0024681873460418325*lm + 
            0.0015580343750251579*lm^2)*NM + (0.005493015891623502 + 
            0.0024681873460418325*lm + 0.0015580343750251579*lm^2)*NL + 
          (-0.0012794332464415607 + 0.0024681873460418325*lm + 
            0.0015580343750251579*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.01194275242090328 - 0.023884274336198243*lm - 
          0.008374587634084973*lm^2) + CF^2*(0.036368537399262074 + 
          0.021530613700514366*lm + 0.041111612021871684*lm^2) + 
        CF*((0.0037146045487893983 + 0.002404674228446133*lm + 
            0.0015226522971063588*lm^2)*NM + (0.00536017762079601 + 
            0.002404674228446133*lm + 0.0015226522971063588*lm^2)*NL + 
          (-0.0012478012657416804 + 0.002404674228446133*lm + 
            0.0015226522971063588*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.011647522506756687 - 0.023299949511762084*lm - 
          0.008184146942872499*lm^2) + CF^2*(0.03563924692767403 + 
          0.02083879990077696*lm + 0.040176721355919535*lm^2) + 
        CF*((0.00359087124258627 + 0.002342502271556495*lm + 
            0.0014880267168859089*lm^2)*NM + (0.005230148931445853 + 
            0.002342502271556495*lm + 0.0014880267168859089*lm^2)*NL + 
          (-0.001216804025351869 + 0.002342502271556495*lm + 
            0.0014880267168859089*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.011356569509640925 - 0.022728157645385907*lm - 
          0.00799780554449187*lm^2) + CF^2*(0.03492035955138373 + 
          0.02016165763080142*lm + 0.03926195449114191*lm^2) + 
        CF*((0.0034706153380068164 + 0.002281660437625765*lm + 
            0.0014541464626348854*lm^2)*NM + (0.00510290527216645 + 
            0.002281660437625765*lm + 0.0014541464626348854*lm^2)*NL + 
          (-0.0011864360526131 + 0.002281660437625765*lm + 
            0.0014541464626348854*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.011070035018131948 - 0.022168751786410007*lm - 
          0.007815500745868328*lm^2) + CF^2*(0.034212022567894906 + 
          0.019499182062740872*lm + 0.038367003661535434*lm^2) + 
        CF*((0.0033537746419672098 + 0.0022221365158405534*lm + 
            0.0014210001356124234*lm^2)*NM + (0.00497841948323469 + 
            0.0022221365158405534*lm + 0.0014210001356124234*lm^2)*NL + 
          (-0.0011566914356465337 + 0.0022221365158405534*lm + 
            0.0014210001356124234*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.01078804202985375 - 0.021621577807085332*lm - 
          0.007637168812855093*lm^2) + CF^2*(0.03351436067848483 + 
          0.018851345034959454*lm + 0.037491555990379545*lm^2) + 
        CF*((0.0032402854316011783 + 0.0021639172313713613*lm + 
            0.001388576147791835*lm^2)*NM + (0.004856662057755126 + 
            0.0021639172313713613*lm + 0.001388576147791835*lm^2)*NL + 
          (-0.0011275638635122927 + 0.0021639172313713613*lm + 
            0.001388576147791835*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.010510696170850901 - 0.02108647521090548*lm - 
          0.007462745161827581*lm^2) + CF^2*(0.0328274771982702 + 
          0.018218096830333153*lm + 0.036635294430789944*lm^2) + 
        CF*((0.003130082724962608 + 0.0021069883480061844*lm + 
            0.0013568627566959237*lm^2)*NM + (0.004737601386046423 + 
            0.0021069883480061844*lm + 0.0013568627566959237*lm^2)*NL + 
          (-0.0010990466640293669 + 0.0021069883480061844*lm + 
            0.0013568627566959237*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.010238086857783702 - 0.020563277888200886*lm - 
          0.007292164536397334*lm^2) + CF^2*(0.03215145523562263 + 
          0.017599367865733982*lm + 0.035797898633223274*lm^2) + 
        CF*((0.003023100530648609 + 0.0020513347646387943*lm + 
            0.001325848097526788*lm^2)*NM + (0.004621203984077504 + 
            0.0020513347646387943*lm + 0.001325848097526788*lm^2)*NL + 
          (-0.0010711328393495426 + 0.0020513347646387943*lm + 
            0.001325848097526788*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.009970288404085976 - 0.02005181482169236*lm - 
          0.00712536117020587*lm^2) + CF^2*(0.03148635883894183 + 
          0.016995070294963176*lm + 0.034979045744647*lm^2) + 
        CF*((0.0029192720775808884 + 0.0019969406058798975*lm + 
            0.0012955202127647037*lm^2)*NM + (0.004507434706743386 + 
            0.0019969406058798975*lm + 0.0012955202127647037*lm^2)*NL + 
          (-0.0010438150994161858 + 0.0019969406058798975*lm + 
            0.0012955202127647037*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.00970736107139028 - 0.01955191074460728*lm - 
          0.006962268936702755*lm^2) + CF^2*(0.030832234109179964 + 
          0.016405099527576978*lm + 0.03417841114381352*lm^2) + 
        CF*((0.0028185300260318443 + 0.0019437893070552315*lm + 
            0.0012658670794005009*lm^2)*NM + (0.004396256946750701 + 
            0.0019437893070552315*lm + 0.0012658670794005009*lm^2)*NL + 
          (-0.001017085893385875 + 0.0019437893070552315*lm + 
            0.0012658670794005009*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.00944935206769978 - 0.019063386753866176*lm - 
          0.006802821486759133*lm^2) + CF^2*(0.03018911027694111 + 
          0.015829335666187005*lm + 0.03339566911681756*lm^2) + 
        CF*((0.0027208066613293356 + 0.001891863693849588*lm + 
            0.001236876633956206*lm^2)*NM + (0.004287632819860787 + 
            0.001891863693849588*lm + 0.001236876633956206*lm^2)*NL + 
          (-0.0009909374391263216 + 0.001891863693849588*lm + 
            0.001236876633956206*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.009196296493821384 - 0.018586060880751553*lm - 
          0.006646952374917625*lm^2) + CF^2*(0.029557000743154996 + 
          0.015267644864920228*lm + 0.03263049347686834*lm^2) + 
        CF*((0.002626034070818169 + 0.0018411460568499229*lm + 
            0.0012085367954395682*lm^2)*NM + (0.004181523337214728 + 
            0.0018411460568499229*lm + 0.0012085367954395682*lm^2)*NL + 
          (-0.0009653617508801078 + 0.0018411460568499229*lm + 
            0.0012085367954395682*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.008948218239760787 - 0.018119748621374436*lm - 
          0.006494595175031847*lm^2) + CF^2*(0.028935904082815645 + 
          0.01471988061179645*lm + 0.03188255813197452*lm^2) + 
        CF*((0.0025341443056824562 + 0.0017916182212342634*lm + 
            0.0011808354863694268*lm^2)*NM + (0.0040778885654399345 + 
            0.0017916182212342634*lm + 0.0011808354863694268*lm^2)*NL + 
          (-0.0009403506651968766 + 0.0017916182212342634*lm + 
            0.0011808354863694268*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.008705130832741307 - 0.01766426342915866*lm - 
          0.006345683586003687*lm^2) + CF^2*(0.028325805011331737 + 
          0.014185884937827645*lm + 0.0311515376040181*lm^2) + 
        CF*((0.002445069528200827 + 0.001743261611846176*lm + 
            0.0011537606520006705*lm^2)*NM + (0.0039766877752123965 + 
            0.001743261611846176*lm + 0.0011537606520006705*lm^2)*NL + 
          (-0.000915895865181191 + 0.001743261611846176*lm + 
            0.0011537606520006705*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.008467038238618184 - 0.01721941717146842*lm - 
          0.00620015152828381*lm^2) + CF^2*(0.02772667531339632 + 
          0.013665489555667213*lm + 0.030437107502484156*lm^2) + 
        CF*((0.0023587421456037483 + 0.001696057313887261*lm + 
            0.0011273002778697837*lm^2)*NM + (0.0038778795789227325 + 
            0.001696057313887261*lm + 0.0011273002778697837*lm^2)*NL + 
          (-0.0008919889032147521 + 0.001696057313887261*lm + 
            0.0011273002778697837*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.008233935618435603 - 0.01678502055241143*lm - 
          0.006057933231760514*lm^2) + CF^2*(0.027138474734383605 + 
          0.013158516930641316*lm + 0.029738944955915253*lm^2) + 
        CF*((0.0022750949312194306 + 0.001649986129452538*lm + 
            0.001101442405774639*lm^2)*NM + (0.0037814220580679307 + 
            0.001649986129452538*lm + 0.001101442405774639*lm^2)*NL + 
          (-0.0008686212221538126 + 0.001649986129452538*lm + 
            0.001101442405774639*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.008005810041950867 - 0.016360883503758816*lm - 
          0.005918963315623952*lm^2) + CF^2*(0.026561151834586846 + 
          0.012664781286981907*lm + 0.029056729003972128*lm^2) + 
        CF*((0.002194061134152783 + 0.0016050286301258123*lm + 
            0.001076175148295264*lm^2)*NM + (0.0036872728809644244 + 
            0.0016050286301258123*lm + 0.001076175148295264*lm^2)*NL + 
          (-0.0008457841751318242 + 0.0016050286301258123*lm + 
            0.001076175148295264*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.0077826411598338925 - 0.01594681554583356*lm - 
          0.005783176860756738*lm^2) + CF^2*(0.025994644806532817 + 
          0.012184089552054255*lm + 0.028390140952805804*lm^2) + 
        CF*((0.0021155745776762673 + 0.0015611652058442117*lm + 
            0.0010514867019557706*lm^2)*NM + (0.0035953894113520653 + 
            0.0015611652058442117*lm + 0.0010514867019557706*lm^2)*NL + 
          (-0.0008234690440211435 + 0.0015611652058442117*lm + 
            0.0010514867019557706*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.0075644018363750214 - 0.015542626120132415*lm - 
          0.0056505094751680114*lm^2) + CF^2*(0.02543888225601263 + 
          0.011716242241333013*lm + 0.027738864696279328*lm^2) + 
        CF*((0.002039569747710034 + 0.0015183761102331307*lm + 
            0.0010273653591214567*lm^2)*NM + (0.003505728808432757 + 
            0.0015183761102331307*lm + 0.0010273653591214567*lm^2)*NL + 
          (-0.0008016670566313672 + 0.0015183761102331307*lm + 
            0.0010273653591214567*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.00735105874440455 - 0.015148124895361603*lm - 
          0.005520897352955974*lm^2) + CF^2*(0.024893783947362413 + 
          0.011261034286832073*lm + 0.027102587005420235*lm^2) + 
        CF*((0.0019659818717387817 + 0.0014766415026048595*lm + 
            0.001003799518719268*lm^2)*NM + (0.003418248118862151 + 
            0.0014766415026048595*lm + 0.001003799518719268*lm^2)*NL + 
          (-0.000780369402690873 + 0.0014766415026048595*lm + 
            0.001003799518719268*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.007142572924148376 - 0.01476312204848469*lm - 
          0.005394277327253724*lm^2) + CF^2*(0.024359261513720348 + 
          0.010818255811636406*lm + 0.026480997788336465*lm^2) + 
        CF*((0.001894746988943978 + 0.001435941486806272*lm + 
            0.0009807776958643136*lm^2)*NM + (0.0033329043611879934 + 
            0.001435941486806272*lm + 0.0009807776958643136*lm^2)*NL + 
          (-0.0007595672487429509 + 0.001435941486806272*lm + 
            0.0009807776958643136*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.006938900307700757 - 0.01438742852230177*lm - 
          0.005270586917584743*lm^2) + CF^2*(0.02383521913304755 + 
          0.010387692853120259*lm + 0.02587379032268874*lm^2) + 
        CF*((0.0018258020121964388 + 0.0013962561470931085*lm + 
            0.0009582885304699534*lm^2)*NM + (0.003249654603204469 + 
            0.0013962561470931085*lm + 0.0009582885304699534*lm^2)*NL + 
          (-0.000739251751903957 + 0.0013962561470931085*lm + 
            0.0009582885304699534*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.006739992210752983 - 0.014020856261002532*lm - 
          0.005149764372027558*lm^2) + CF^2*(0.02332155417075979 + 
          0.009969128037366864*lm + 0.02528066146268074*lm^2) + 
        CF*((0.0017590847825068462 + 0.0013575655812006948*lm + 
            0.0009363207949141015*lm^2)*NM + (0.003168456032668361 + 
            0.0013575655812006948*lm + 0.0009363207949141015*lm^2)*NL + 
          (-0.0007194140726654275 + 0.0013575655812006948*lm + 
            0.0009363207949141015*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.006545795793172246 - 0.013663218425061987*lm - 
          0.005031748704563867*lm^2) + CF^2*(0.022818157789867545 + 
          0.009562341207231335*lm + 0.02470131182240444*lm^2) + 
        CF*((0.001694534116471876 + 0.0013198499307733506*lm + 
            0.0009148634008297941*lm^2)*NM + (0.0030892660218000026 + 
            0.0013198499307733506*lm + 0.0009148634008297941*lm^2)*NL + 
          (-0.0007000453867034889 + 0.0013198499307733506*lm + 
            0.0009148634008297941*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.00635625448998174 - 0.01331432958677674*lm - 
          0.004916479727960634*lm^2) + CF^2*(0.022324915529570125 + 
          0.00916711000641179*lm + 0.02413544593726129*lm^2) + 
        CF*((0.0016320898472654444 + 0.0012830894093073596*lm + 
            0.0008939054050837516*lm^2)*NM + (0.00301204218596994 + 
            0.0012830894093073596*lm + 0.0008939054050837516*lm^2)*NL + 
          (-0.0006811368958058654 + 0.0012830894093073596*lm + 
            0.0008939054050837516*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.006171240331570912 - 0.012974001183470205*lm - 
          0.004803904970815353*lm^2) + CF*(0.02184152720489744 + 
          0.008783108498708002*lm + 0.02358280622036628*lm^2) + 
        0.0015716983548399505*NM + 0.001247261874822435*lm*NM + 
        0.0008734372674209733*lm^2*NM + 0.0029367414379883015*NL + 
        0.001247261874822435*lm*NL + 0.0008734372674209733*lm^2*NL - 
        0.000662679349670201*NH + 0.001247261874822435*lm*NH + 
        0.0008734372674209733*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.005990838669205336 - 0.012642061522460392*lm - 
          0.004693950992924798*lm^2) + CF*(0.021368261051564242 + 
          0.008410333232450226*lm + 0.023043032147085373*lm^2) + 
        0.0015132897637931504*NM + 0.0012123531048944983*lm*NM + 
        0.000853445635077236*lm^2*NM + 0.002863324267077857*NL + 
        0.0012123531048944983*lm*NL + 0.000853445635077236*lm^2*NL - 
        0.0006446650946381324*NH + 0.0012123531048944983*lm*NH + 
        0.000853445635077236*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.00581490193375417 - 0.012318324555384053*lm - 
          0.004586568390737942*lm^2) + CF*(0.020904772119735907 + 
          0.008048435549649206*lm + 0.02251588119089535*lm^2) + 
        0.001456813614253805*NM + 0.0011783407047750974*lm*NM + 
        0.0008339215255887167*lm^2*NM + 0.0027917480328962696*NL + 
        0.0011783407047750974*lm*NL + 0.0008339215255887167*lm^2*NL - 
        0.0006270848787529161*NH + 0.0011783407047750974*lm*NH + 
        0.0008339215255887167*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.005643362762795811 - 0.012002612145048473*lm - 
          0.004481700394486598*lm^2) + CF*(0.02045092944622352 + 
          0.007697189823006844*lm + 0.0220010746638433*lm^2) + 
        0.0014022140873373595*NM + 0.0011452054226896006*lm*NM + 
        0.0008148546171793814*lm^2*NM + 0.002721971817097971*NL + 
        0.0011452054226896006*lm*NL + 0.0008148546171793814*lm^2*NL - 
        0.000609930103544443*NH + 0.0011452054226896006*lm*NH + 
        0.0008148546171793814*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.005476151778722882 - 0.011694748288331353*lm - 
          0.004379291145456004*lm^2) + CF*(0.020006598778147512 + 
          0.007356370488455959*lm + 0.021498338350420382*lm^2) + 
        0.0013494365070117725*NM + 0.0011129281840538982*lm*NM + 
        0.0007962347537192733*lm^2*NM + 0.0026539551613562933*NL + 
        0.0011129281840538982*lm*NL + 0.0007962347537192733*lm^2*NL - 
        0.0005931922390537873*NH + 0.0011129281840538982*lm*NH + 
        0.0007962347537192733*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.005313197879625306 - 0.01139455922016641*lm - 
          0.004279285707713062*lm^2) + CF*(0.019571643000444915 + 
          0.007025752421584156*lm + 0.02100740256513685*lm^2) + 
        0.001298427351598253*NM + 0.0010814901076669032*lm*NM + 
        0.0007780519468569203*lm^2*NM + 0.002587658098793641*NL + 
        0.0010814901076669032*lm*NL + 0.0007780519468569203*lm^2*NL - 
        0.0005768628303869472*NH + 0.0010814901076669032*lm*NH + 
        0.0007780519468569203*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.005154428508880478 - 0.011101873505342318*lm - 
          0.004181630077335745*lm^2) + CF*(0.01914592253658556 + 
          0.006705111282793403*lm + 0.02052800219783002*lm^2) + 
        0.0012491342617016908*NM + 0.0010508725202655383*lm*NM + 
        0.0007602963776974082*lm^2*NM + 0.0025230411817946503*NL + 
        0.0010508725202655383*lm*NL + 0.0007602963776974082*lm^2*NL - 
        0.0005609335036679964*NH + 0.0010508725202655383*lm*NH + 
        0.0007602963776974082*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.004999769904740791 - 0.010816522118966294*lm - 
          0.0040862711893401415*lm^2) + CF*(0.018729295723798157 + 
          0.0063942238331286105*lm + 0.020059876747669788*lm^2) + 
        0.00120150604488444*NM + 0.0010210569695515246*lm*NM + 
        0.000742958398061844*lm^2*NM + 0.0024600655064647217*NL + 
        0.0010210569695515246*lm*NL + 0.000742958398061844*lm^2*NL - 
        0.0005453959714286273*NH + 0.0010210569695515246*lm*NH + 
        0.000742958398061844*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.004849147331138427 - 0.01053833851639282*lm - 
          0.00399315692248894*lm^2) + CF*(0.018321619164057522 + 
          0.006092868222604392*lm + 0.019602770346763887*lm^2) + 
        0.0011554926773753582*NM + 0.0009920252357929894*lm*NM + 
        0.0007260285313616254*lm^2*NM + 0.002398692733979957*NL + 
        0.0009920252357929894*lm*NL + 0.0007260285313616254*lm^2*NL - 
        0.0005302420374690904*NH + 0.0009920252357929894*lm*NH + 
        0.0007260285313616254*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.004702485290860487 - 0.010267158693370063*lm - 
          0.003902236102153181*lm^2) + CF*(0.017922748052036173 + 
          0.0058008242527600685*lm + 0.019156431774206527*lm^2) + 
        0.0011110453030856282*NM + 0.0009637593420979532*lm*NM + 
        0.0007094974731187602*lm^2*NM + 0.002338885109059108*NL + 
        0.0009637593420979532*lm*NL + 0.0007094974731187602*lm^2*NL - 
        0.0005154636012236594*NH + 0.0009637593420979532*lm*NH + 
        0.0007094974731187602*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.00455970772218407 - 0.010002821237111081*lm - 
          0.003813458501387895*lm^2) + CF*(0.017532536481176142 + 
          0.0055178736150787045*lm + 0.018720614461358757*lm^2) + 
        0.0010681162301837397*NM + 0.0009362415634510969*lm*NM + 
        0.0006933560911614355*lm^2*NM + 0.002280605475773602*NL + 
        0.0009362415634510969*lm*NL + 0.0006933560911614355*lm^2*NL - 
        0.0005010526616619578*NH + 0.0009362415634510969*lm*NH + 
        0.0006933560911614355*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.004420738180000629 - 0.009745167368954099*lm - 
          0.0037267748403716243*lm^2) + CF*(0.017150837728990963 + 
          0.005243800106816352*lm + 0.018295076489097065*lm^2) + 
        0.0010266589254640667*NM + 0.0009094544345998735*lm*NM + 
        0.0006775954255221136*lm^2*NM + 0.0022238172908979953*NL + 
        0.0009094544345998735*lm*NL + 0.0006775954255221136*lm^2*NL - 
        0.0004870013207557934*NH + 0.0009094544345998735*lm*NH + 
        0.0006775954255221136*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.0042855000024017076 - 0.009494040979235606*lm - 
          0.0036421367843499325*lm^2) + CF*(0.016777504522662946 + 
          0.004978389825702423*lm + 0.01787958057771785*lm^2) + 
        0.0009866280067266553*NM + 0.0008833807568709522*lm*NM + 
        0.0006622066880636241*lm^2*NM + 0.002168484634990291*NL + 
        0.0008833807568709522*lm*NL + 0.0006622066880636241*lm^2*NL - 
        0.0004733017865395226*NH + 0.0008833807568709522*lm*NH + 
        0.0006622066880636241*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.004153916463643855 - 0.009249288654961722*lm - 
          0.003559496940213618*lm^2) + CF*(0.016412389285957205 + 
          0.0047214313448911485*lm + 0.01747389407013958*lm^2) + 
        0.000947979233370075*NM + 0.0008580036039931948*lm*NM + 
        0.0006471812618570215*lm^2*NM + 0.002114572221379405*NL + 
        0.0008580036039931948*lm*NL + 0.0006471812618570215*lm^2*NL - 
        0.0004599463757904438*NH + 0.0008580036039931948*lm*NH + 
        0.0006471812618570215*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.004025910914358989 - 0.00901075970082721*lm - 
          0.0034788088518335836*lm^2) + CF*(0.016055344368431573 + 
          0.004472715869467083*lm + 0.01707778890900123*lm^2) + 
        0.0009106694953844131*NM + 0.0008333063269988289*lm*NM + 
        0.0006325107003333788*lm^2*NM + 0.002062045403225584*NL + 
        0.0008333063269988289*lm*NL + 0.0006325107003333788*lm^2*NL - 
        0.0004469275163542503*NH + 0.0008333063269988289*lm*NH + 
        0.0006325107003333788*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.0039014069098275697 - 0.008778306154097335*lm - 
          0.003400026994266045*lm^2) + CF*(0.01570622225788023 + 
          0.004232037375734527*lm + 0.016691041608215128*lm^2) + 
        0.0008746568009176792*NM + 0.000809272558270183*lm*NM + 
        0.00061818672623019*lm^2*NM + 0.0020108701788088138*NL + 
        0.000809272558270183*lm*NL + 0.00061818672623019*lm^2*NL - 
        0.0004342377491391968*NH + 0.000809272558270183*lm*NH + 
        0.00061818672623019*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.003780328327085612 - 0.008551782793835614*lm - 
          0.003323106766934018*lm^2) + CF*(0.015364875776908966 + 
          0.003999192734451302*lm + 0.016313433219494272*lm^2) + 
        0.0008399002625759423*NM + 0.0007858862147952975*lm*NM + 
        0.0006042012303516397*lm^2*NM + 0.001961013195190096*NL + 
        0.0007858862147952975*lm*NL + 0.0006042012303516397*lm^2*NL - 
        0.000421869729801316*NH + 0.0007858862147952975*lm*NH + 
        0.0006042012303516397*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.003662599471592582 - 0.008331047144930109*lm - 
          0.003248004485883742*lm^2) + CF*(0.015031158264501262 + 
          0.0037739818191013983*lm + 0.01594474929433837*lm^2) + 
        0.0008063600826054188*NM + 0.0007631315006918811*lm*NM + 
        0.0005905462701606803*lm^2*NM + 0.0019124417503809238*NL + 
        0.0007631315006918811*lm*NL + 0.0005905462701606803*lm^2*NL - 
        0.00040981623014177166*NH + 0.0007631315006918811*lm*NH + 
        0.0005905462701606803*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.0035481451741455673 - 0.008115959477342253*lm - 
          0.003174677375207843*lm^2) + CF*(0.014704923743396705 + 
          0.0035562076002384414*lm + 0.01558477984192941*lm^2) + 
        0.0007739975370934209*NM + 0.0007409929090554542*lm*NM + 
        0.0005772140682196077*lm^2*NM + 0.0018651237941473*NL + 
        0.0007409929090554542*lm*NL + 0.0005772140682196077*lm^2*NL - 
        0.00039807013923625224*NH + 0.0007409929090554542*lm*NH + 
        0.0005772140682196077*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.003436890878685608 - 0.007906382800975179*lm - 
          0.0031030835577206613*lm^2) + CF*(0.014386027074067047 + 
          0.00334567622687258*lm + 0.015233319283355973*lm^2) + 
        0.0007427749593144881*NM + 0.0007194552231840945*lm*NM + 
        0.0005641970104946657*lm^2*NM + 0.0018190279275662*NL + 
        0.0007194552231840945*lm*NL + 0.0005641970104946657*lm^2*NL - 
        0.0003866244643151831*NH + 0.0007194552231840945*lm*NH + 
        0.0005641970104946657*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.003328762721604688 - 0.0077021828565330295*lm - 
          0.0030331820449651164*lm^2) + CF*(0.01407432409603996 + 
          0.0031421970958170533*lm + 0.014890166402556027*lm^2) + 
        0.0007126557223381519*NM + 0.0006985035172289536*lm*NM + 
        0.0005514876445391121*lm^2*NM + 0.0017741234014444357*NL + 
        0.0006985035172289536*lm*NL + 0.0005514876445391121*lm^2*NL - 
        0.00037547233141246704*NH + 0.0006985035172289536*lm*NH + 
        0.0005514876445391121*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.0032236876031264184 - 0.007503228102718716*lm - 
          0.002964932726624859*lm^2) + CF*(0.013769671757286604 + 
          0.002945582909857334*lm + 0.014555124294340216*lm^2) + 
        0.0006836042210055529*NM + 0.0006781231563166587*lm*NM + 
        0.0005390786775681561*lm^2*NM + 0.0017303801137024193*NL + 
        0.0006781231563166587*lm*NL + 0.0005390786775681561*lm^2*NL - 
        0.000364606985799452*NH + 0.0006781231563166587*lm*NH + 
        0.0005390786775681561*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.00312159325129992 - 0.007309389700094968*lm - 
          0.0028982963594101573*lm^2) + CF*(0.013471928232356324 + 
          0.0027556497255550663*lm + 0.014228000309831682*lm^2) + 
        0.0006555858533735183*NM + 0.0006582997961868172*lm*NM + 
        0.0005269629744382104*lm^2*NM + 0.001687768605818315*NL + 
        0.0006582997961868172*lm*NL + 0.0005269629744382104*lm^2*NL - 
        0.0003540217922198634*NH + 0.0006582997961868172*lm*NH + 
        0.0005269629744382104*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.0030224082791146262 - 0.007120541491912183*lm - 
          0.0028332345554810236*lm^2) + CF*(0.013180953029910125 + 
          0.002572216991451086*lm + 0.013908605999634116*lm^2) + 
        0.0006285670017166791*NM + 0.0006390193823851188*lm*NM + 
        0.0005151335555420043*lm^2*NM + 0.0016462600584214813*NL + 
        0.0006390193823851188*lm*NL + 0.0005151335555420043*lm^2*NL - 
        0.0003437102349405277*NH + 0.0006390193823851188*lm*NH + 
        0.0005151335555420043*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.002926062235213685 - 0.0069365599821865145*lm - 
          0.002769709770466412*lm^2) + CF*(0.012896607090274046 + 
          0.002395107577386298*lm + 0.013596757055016931*lm^2) + 
        0.0006025150131707128*NM + 0.0006202681490499487*lm*NM + 
        0.0005035835946302568*lm^2*NM + 0.0016058262861179283*NL + 
        0.0006202681490499487*lm*NL + 0.0005035835946302568*lm^2*NL - 
        0.000333665917631851*NH + 0.0006202681490499487*lm*NH + 
        0.0005035835946302568*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.0028324856486551674 - 0.006757324311292723*lm - 
          0.0027076852911339998*lm^2) + CF*(0.012618752873604156 + 
          0.002224147795616163*lm + 0.01329227324738509*lm^2) + 
        0.0005773981800928225*NM + 0.0006020326173279992*lm*NM + 
        0.0004923064165698181*lm^2*NM + 0.0015664397316247183*NL + 
        0.0006020326173279992*lm*NL + 0.0004923064165698181*lm^2*NL - 
        0.00032388256309119775*NH + 0.0006020326173279992*lm*NH + 
        0.0004923064165698181*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.002741610068143417 - 0.006582716229318542*lm - 
          0.0026471252227609626*lm^2) + CF*(0.012347254439226567 + 
          0.00205916741435374*lm + 0.01299497836628109*lm^2) + 
        0.0005531857202090601*NM + 0.0005842995934520742*lm*NM + 
        0.00048129549504744777*lm^2*NM + 0.0015280734592847847*NL + 
        0.0005842995934520742*lm*NL + 0.00048129549504744777*lm^2*NL - 
        0.00031435401282153835*NH + 0.0005842995934520742*lm*NH + 
        0.00048129549504744777*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.0026533680961274096 - 0.006412620067410555*lm - 
          0.0025879944762523606*lm^2) + CF*(0.012081977516688602 + 
          0.0018999996643376492*lm + 0.012704700156147952*lm^2) + 
        0.0005298477566120543*NM + 0.0005670561665121168*lm*NM + 
        0.0004705444502277019*lm^2*NM + 0.0014907011480285546*NL + 
        0.0005670561665121168*lm*NL + 0.0004705444502277019*lm^2*NL - 
        0.00030507422647700145*NH + 0.0005670561665121168*lm*NH + 
        0.0004705444502277019*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.002567693418138945 - 0.006246922707325826*lm - 
          0.002530258755050168*lm^2) + CF*(0.011822789569031074 + 
          0.0017464812389847777*lm + 0.012421270252064461*lm^2) + 
        0.0005073552976670753*NM + 0.0005502897059484584*lm*NM + 
        0.00046004704637275784*lm^2*NM + 0.0014542970838439656*NL + 
        0.0005502897059484584*lm*NL + 0.00046004704637275784*lm^2*NL - 
        0.00029603728118626906*NH + 0.0005502897059484584*lm*NH + 
        0.00046004704637275784*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.0024845208277207726 - 0.00608551354938873*lm - 
          0.002473884541872662*lm^2) + CF*(0.011569559848766415 + 
          0.001598452288653005*lm + 0.012144524114647615*lm^2) + 
        0.0004856802168791341*NM + 0.0005339878587943596*lm*NM + 
        0.00044979718943139314*lm^2*NM + 0.0014188361518119865*NL + 
        0.0005339878587943596*lm*NL + 0.00044979718943139314*lm^2*NL - 
        0.00028723737076409426*NH + 0.0005339878587943596*lm*NH + 
        0.00044979718943139314*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.0024037862472732485 - 0.005928284479038518*lm - 
          0.0024188390853207443*lm^2) + CF*(0.011322159447023247 + 
          0.001455756409506532*lm + 0.011874300964301835*lm^2) + 
        0.0004647952327689552*NM + 0.000518138546693112*lm*NM + 
        0.0004397889246037717*lm^2*NM + 0.0013842938277605506*NL + 
        0.000518138546693112*lm*NL + 0.0004397889246037717*lm^2*NL - 
        0.0002786688048205973*NH + 0.000518138546693112*lm*NH + 
        0.0004397889246037717*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.0023254267451278633 - 0.0057751298321400335*lm - 
          0.002365090386384868*lm^2) + CF*(0.011080461336294763 + 
          0.0013182406274455136*lm + 0.011610443714980262*lm^2) + 
        0.0004446738888011444*NM + 0.0005027299627132597*lm*NM + 
        0.00043001643388815785*lm^2*NM + 0.0013506461695858745*NL + 
        0.0005027299627132597*lm*NL + 0.00043001643388815785*lm^2*NL - 
        0.00027032600777740566*NH + 0.0005027299627132597*lm*NH + 
        0.00043001643388815785*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.0022493805491367977 - 0.005625946359217749*lm - 
          0.0023126071848835242*lm^2) + CF*(0.01084434040720599 + 
          0.0011857553775324707*lm + 0.011352798907610028*lm^2) + 
        0.00042529053340368764*NM + 0.0004877505679838992*lm*NM + 
        0.0004204740336151862*lm^2*NM + 0.0013178698082864512*NL + 
        0.0004877505679838992*lm*NL + 0.0004204740336151862*lm^2*NL - 
        0.00026220351779914424*NH + 0.0004877505679838992*lm*NH + 
        0.0004204740336151862*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.002175587057049588 - 0.005480633188761725*lm - 
          0.0022613589458616756*lm^2) + CF*(0.010613673499693742 + 
          0.0010581544793203932*lm + 0.011101216643320953*lm^2) + 
        0.0004066203001140297*NM + 0.0004731890881705045*lm*NM + 
        0.0004111561719748501*lm^2*NM + 0.001285941938751562*NL + 
        0.0004731890881705045*lm*NL + 0.0004111561719748501*lm^2*NL - 
        0.0002542959856482533*NH + 0.0004731890881705045*lm*NH + 
        0.0004111561719748501*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.002103986843930906 - 0.005339091789743265*lm - 
          0.0022113158459751807*lm^2) + CF*(0.01038833942897253 + 
          0.0009352951084613624*lm + 0.01085555051660543*lm^2) + 
        0.000388639087883386*NM + 0.00045903450981030393*lm*NM + 
        0.0004020574265409419*lm^2*NM + 0.001254840310342925*NL + 
        0.00045903450981030393*lm*NL + 0.0004020574265409419*lm^2*NL - 
        0.00024659817347061255*NH + 0.00045903450981030393*lm*NH + 
        0.0004020574265409419*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.002034521666857371 - 0.005201225933467872*lm - 
          0.002162448759885014*lm^2) + CF*(0.010168219006640191 + 
          0.0008170377649499328*lm + 0.01061565754852643*lm^2) + 
        0.0003713235415676052*NM + 0.0004452760765248991*lm*NM + 
        0.0003931725017972752*lm^2*NM + 0.0012245432173050817*NL + 
        0.0004452760765248991*lm*NL + 0.0003931725017972752*lm^2*NL - 
        0.00023910495351897558*NH + 0.0004452760765248991*lm*NH + 
        0.0003931725017972752*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.001967134467116091 - 0.005066941654883576*lm - 
          0.0021147292466830356*lm^2) + CF*(0.009953195057258243 + 
          0.0007032462383322817*lm + 0.010381398120080357*lm^2) + 
        0.00035465103262982125*NM + 0.00043190328512655933*lm*NM + 
        0.0003844962266696428*lm^2*NM + 0.0011950294890373076*NL + 
        0.00043190328512655933*lm*NL + 0.0003844962266696428*lm^2*NL - 
        0.00023181130682077357*NH + 0.00043190328512655933*lm*NH + 
        0.0003844962266696428*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.001901769370113339 - 0.004936147213453758*lm - 
          0.0020681295363691355*lm^2) + CF*(0.009743152430724029 + 
          0.0005937875701902296*lm + 0.01015263590581212*lm^2) + 
        0.0003385996400772805*NM + 0.0004189058816334453*lm*NM + 
        0.00037602355206711556*lm^2*NM + 0.0011662784802572025*NL + 
        0.0004189058816334453*lm*NL + 0.00037602355206711556*lm^2*NL - 
        0.00022471232179642386*NH + 0.0004189058816334453*lm*NH + 
        0.00037602355206711556*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0018383716831882465 - 0.00480875305369519*lm - 
          0.002022622516397778*lm^2) + CF*(0.00953797801073462 + 
          0.0004885320141885634*lm + 0.009929237807770908*lm^2) + 
        0.00032314813165210165*NM + 0.0004062738572079041*lm*NM + 
        0.0003677495484359596*lm^2*NM + 0.001138270061083647*NL + 
        0.0004062738572079041*lm*NL + 0.0003677495484359596*lm^2*NL - 
        0.0002178031928338799*NH + 0.0004062738572079041*lm*NH + 
        0.0003677495484359596*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.0017768878915136838 - 0.004684671765474193*lm - 
          0.0019781817183103126*lm^2) + CF*(0.009337560719626086 + 
          0.0003873529939546142*lm + 0.00971107388988699*lm^2) + 
        0.00030827594529329546*NM + 0.00039399744403093793*lm*NM + 
        0.0003596694033291477*lm^2*NM + 0.0011109846070645332*NL + 
        0.00039399744403093793*lm*NL + 0.0003596694033291477*lm^2*NL - 
        0.00021107921882478325*NH + 0.00039399744403093793*lm*NH + 
        0.0003596694033291477*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.0017172656522545064 - 0.004563818044146417*lm - 
          0.00193478130446786*lm^2) + CF*(0.009141791519856087 + 
          0.00029012705904067463*lm + 0.009498017312842222*lm^2) + 
        0.00029396317088513385*NM + 0.00038206711112496783*lm*NM + 
        0.00035177841899415634*lm^2*NM + 0.001084402989172518*NL + 
        0.00038206711112496783*lm*NL + 0.00035177841899415634*lm^2*NL - 
        0.0002045358016672214*NH + 0.00038206711112496783*lm*NH + 
        0.00035177841899415634*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.0016594537871420618 - 0.004446108650618879*lm - 
          0.0018923960548981249*lm^2) + CF*(0.008950563412382859 + 
          0.00019673383920254*lm + 0.009289944269499886*lm^2) + 
        0.00028019053230489833*NM + 0.00037047356013609784*lm*NM + 
        0.00034407200998147724*lm^2*NM + 0.0010585065637900694*NL + 
        0.00037047356013609784*lm*NL + 0.00034407200998147724*lm^2*NL - 
        0.00019816844473975997*NH + 0.00037047356013609784*lm*NH + 
        0.00034407200998147724*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.0016034022736132229 - 0.004331462371406429*lm - 
          0.0018510013542681622*lm^2) + CF*(0.008763771432179454 + 
          0.0001070559972111626*lm + 0.009086733920952796*lm^2) + 
        0.0002669393697811398*NM + 0.0003592077210862223*lm*NM + 
        0.0003365457007760295*lm^2*NM + 0.0010332771627031999*NL + 
        0.0003592077210862223*lm*NL + 0.0003365457007760295*lm^2*NL - 
        0.0001919727513511007*NH + 0.0003592077210862223*lm*NH + 
        0.0003365457007760295*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.0015490622346522106 - 0.004219799978748816*lm - 
          0.0018105731789938607*lm^2) + CF*(0.008581312641108495 + 
          0.000020979180399071065*lm + 0.00888826833324259*lm^2) + 
        0.00025419162257184214*NM + 0.00034826074810451126*lm*NM + 
        0.00032919512345342924*lm^2*NM + 0.001008697083121556*NL + 
        0.00034826074810451126*lm*NL + 0.00032919512345342924*lm^2*NL - 
        0.0001859444231694176*NH + 0.00034826074810451126*lm*NH + 
        0.00032919512345342924*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.0014963859274640637 - 0.004111044190848836*lm - 
          0.0017710880844957538*lm^2) + CF*(0.008403086118369842 - 
          0.00006160802887123133*lm + 0.008694432414797337*lm^2) + 
        0.00024192981197028273*NM + 0.0003376240151470519*lm*NM + 
        0.0003220160153628643*lm^2*NM + 0.0009847490777409186*NL + 
        0.0003376240151470519*lm*NL + 0.0003220160153628643*lm^2*NL - 
        0.00018007925863514188*NH + 0.0003376240151470519*lm*NH + 
        0.0003220160153628643*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.00144532673109976 - 0.004005119632286814*lm - 
          0.0017325231926096896*lm^2) + CF*(0.00822899294872122 - 
          0.00014081416364325136*lm + 0.008505113854629386*lm^2) + 
        0.00023013702464491932*NM + 0.00032728911171271566*lm*NM + 
        0.0003150042168381254*lm^2*NM + 0.0009614163448626624*NL + 
        0.00032728911171271566*lm*NL + 0.0003150042168381254*lm^2*NL - 
        0.00017437315136070036*NH + 0.00032728911171271566*lm*NH + 
        0.0003150042168381254*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.0013958391331446698 - 0.0039019527946617416*lm - 
          0.0016948561791598994*lm^2) + CF*(0.008058936208660206 - 
          0.00021674492354600402*lm + 0.008320203061330415*lm^2) + 
        0.00021879689631829137*NM + 0.00031724783856265393*lm*NM + 
        0.00030815566893816355*lm^2*NM + 0.0009386825185833326*NL + 
        0.00031724783856265393*lm*NL + 0.00030815566893816355*lm^2*NL - 
        0.0001688220885204613*NH + 0.00031724783856265393*lm*NH + 
        0.00030815566893816355*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.001347878715574212 - 0.0038014719975047713*lm - 
          0.0016580652617010708*lm^2) + CF*(0.007892820950744743 - 
          0.00028950322656815333*lm + 0.008139593102896166*lm^2) + 
        0.00020789359578870156*NM + 0.00030749220345020653*lm*NM + 
        0.0003014664112183765*lm^2*NM + 0.0009165316590661921*NL + 
        0.00030749220345020653*lm*NL + 0.0003014664112183765*lm^2*NL - 
        0.00016342214923390614*NH + 0.00030749220345020653*lm*NH + 
        0.0003014664112183765*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.001301402139873222 - 0.0037036073495065164*lm - 
          0.001622129187435187*lm^2) + CF*(0.007730554186218882 - 
          0.0003591892612891982*lm + 0.007963179647409101*lm^2) + 
        0.0001974118092973241*NM + 0.0002980144168674225*lm*NM + 
        0.0002949325795336704*lm^2*NM + 0.0008949482429053926*NL + 
        0.0002980144168674225*lm*NL + 0.0002949325795336704*lm^2*NL - 
        0.00015816950294482283*NH + 0.0002980144168674225*lm*NH + 
        0.0002949325795336704*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0012563671315086523 - 0.0036082907100955723*lm - 
          0.0015870272213080938*lm^2) + CF*(0.007572044866100253 - 
          0.00042590053944069074*lm + 0.007790860904603369*lm^2) + 
        0.00018733672524237106*NM + 0.000288806887813851*lm*NM + 
        0.00028855040387419883*lm^2*NM + 0.0008739171535923014*NL + 
        0.000288806887813851*lm*NL + 0.00028855040387419883*lm^2*NL - 
        0.00015306040779910742*NH + 0.000288806887813851*lm*NH + 
        0.00028855040387419883*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0012127324638387365 - 0.003515455651401977*lm - 
          0.0015527391342900244*lm^2) + CF*(0.0074172038608763214 - 
          0.00048973194868041*lm + 0.007622537568332847*lm^2) + 
        0.0001776540192410236*NM + 0.0002798622195927505*lm*NM + 
        0.0002823162062345499*lm^2*NM + 0.0008534236720924765*NL + 
        0.0002798622195927505*lm*NL + 0.0002823162062345499*lm^2*NL - 
        0.0001480912090235638*NH + 0.0002798622195927505*lm*NH + 
        0.0002823162062345499*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.0011704579415356797 - 0.003425037420635832*lm - 
          0.0015192451918436473*lm^2) + CF*(0.0072659439389473205 - 
          0.000550775805471736*lm + 0.007458112759959723*lm^2) + 
        0.00016834983953899557*NM + 0.0002711732056393899*lm*NM + 
        0.00027622639851702675*lm^2*NM + 0.0008334534675408244*NL + 
        0.0002711732056393899*lm*NL + 0.00027622639851702675*lm^2*NL - 
        0.00014325833730790592*NH + 0.0002711732056393899*lm*NH + 
        0.00027622639851702675*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0011295043835932187 - 0.003336972902908093*lm - 
          0.0014865261425825605*lm^2) + CF*(0.00711817974394518 - 
          0.0006091219079692061*lm + 0.007297491972678025*lm^2) + 
        0.00015941079276684153*NM + 0.00026273282538567236*lm*NM + 
        0.0002702774804695565*lm^2*NM + 0.0008139925880615813*NL + 
        0.00026273282538567236*lm*NL + 0.0002702774804695565*lm^2*NL - 
        0.00013855830719199298*NH + 0.00026273282538567236*lm*NH + 
        0.0002702774804695565*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.0010898336059850604 - 0.0032512005845175226*lm - 
          0.0014545632071226028*lm^2) + CF*(0.0069738277710496 - 
          0.0006648575888194327*lm + 0.007140583016783687*lm^2) + 
        0.00015082393004143364*NM + 0.0002545342401648977*lm*NM + 
        0.00026446603765865504*lm^2*NM + 0.0007950274517189335*NL + 
        0.0002545342401648977*lm*NL + 0.00026446603765865504*lm^2*NL - 
        0.00013398771546016381*NH + 0.0002545342401648977*lm*NH + 
        0.00026446603765865504*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.0010514084040351823 - 0.0031676605167250027*lm - 
          0.0014233380671278043*lm^2) + CF*(0.006832806342414635 - 
          0.0007180677677942274*lm + 0.00698729596590013*lm^2) + 
        0.00014257673341041928*NM + 0.0002465707891600954*lm*NM + 
        0.0002587887394777826*lm^2*NM + 0.0007765448376033341*NL + 
        0.0002465707891600954*lm*NL + 0.0002587887394777826*lm^2*NL - 
        0.00012954323954438398*NH + 0.0002465707891600954*lm*NH + 
        0.0002587887394777826*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.0010141925345562848 - 0.0030862942800338245*lm - 
          0.0013928328545523268*lm^2) + CF*(0.006695035581811864 - 
          0.000768835004179968*lm + 0.006837543104165968*lm^2) + 
        0.0001346571026369173*NM + 0.00023883598539899993*lm*NM + 
        0.00025324233719133213*lm^2*NM + 0.0007585318770578654*NL + 
        0.00023883598539899993*lm*NL + 0.00025324233719133213*lm^2*NL - 
        0.00012522163593777283*NH + 0.00023883598539899993*lm*NH + 
        0.00025324233719133213*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0009781506978082854 - 0.003007044948992142*lm - 
          0.0013630301410792927*lm^2) + CF*(0.006560437388589214 - 
          0.0008172395488539607*lm + 0.006691238874389255*lm^2) + 
        0.0001270533423212177*NM + 0.00023132351179840443*lm*NM + 
        0.00024782366201441685*lm^2*NM + 0.000740976045048349*NL + 
        0.00023132351179840443*lm*NL + 0.00024782366201441685*lm^2*NL - 
        0.00012101973861994437*NH + 0.00023132351179840443*lm*NH + 
        0.00024782366201441685*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.0009432485193246197 - 0.002929857057531567*lm - 
          0.0013339129277569893*lm^2) + CF*(0.006428935411037977 - 
          0.0008633593959848405*lm + 0.006548299827170675*lm^2) + 
        0.00011975414935581055*NM + 0.00022402721726032037*lm*NM + 
        0.00024252962322854352*lm^2*NM + 0.0007238651516803065*NL + 
        0.00022402721726032037*lm*NL + 0.00024252962322854352*lm^2*NL - 
        0.00011693445749546647*NH + 0.00022402721726032037*lm*NH + 
        0.00024252962322854352*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0009094525316502648 - 0.0028546765648537887*lm - 
          0.001305464634832568*lm^2) + CF*(0.006300455019254283 - 
          0.0009072703342999252*lm + 0.006408644570996243*lm^2) + 
        0.00011274860070968033*NM + 0.0002169411128220781*lm*NM + 
        0.00023735720633319418*lm^2*NM + 0.0007071873338653215*NL + 
        0.0002169411128220781*lm*NL + 0.00023735720633319418*lm^2*NL - 
        0.00011296277684662538*NH + 0.0002169411128220781*lm*NH + 
        0.00023735720633319418*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0008767301560317893 - 0.002781450821875222*lm - 
          0.0012776690917830089*lm^2) + CF*(0.006174923277575437 - 
          0.000949045997867929*lm + 0.006272193723298407*lm^2) + 
        0.00010602614153745875*NM + 0.00021005936786223665*lm*NM + 
        0.00023230347123327433*lm^2*NM + 0.0006909310471388464*NL + 
        0.00021005936786223665*lm*NL + 0.00023230347123327433*lm^2*NL - 
        0.00010910175380156935*NH + 0.00021005936786223665*lm*NH + 
        0.00023230347123327433*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.000845049684096369 - 0.002710128538237868*lm - 
          0.001250510527542814*lm^2) + CF*(0.0060522689166659475 - 
          0.000988757916350562*lm + 0.0061388698624829045*lm^2) + 
        0.00009957657360872894*NM + 0.00020337630636391987*lm*NM + 
        0.0002273655504623298*lm^2*NM + 0.0006750850576310345*NL + 
        0.00020337630636391987*lm*NL + 0.0002273655504623298*lm^2*NL - 
        0.00010534851681880145*NH + 0.00020337630636391987*lm*NH + 
        0.0002273655504623298*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0008143802595535485 - 0.0026406597498929924*lm - 
          0.0012239735609276044*lm^2) + CF*(0.00593242230532281 - 
          0.0010264755646813188*lm + 0.006008597480917331*lm^2) + 
        0.00009339004405251223*NM + 0.00019688640323696616*lm*NM + 
        0.00022254064744138265*lm^2*NM + 0.0006596384341917459*NL + 
        0.00019688640323696616*lm*NL + 0.00022254064744138265*lm^2*NL - 
        0.00010170026418889284*NH + 0.00019688640323696616*lm*NH + 
        0.00022254064744138265*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0007846918599505957 - 0.002572995787262671*lm - 
          0.001198043191252543*lm^2) + CF*(0.005815315422064659 - 
          0.0010622664121342183*lm + 0.005881302938876121*lm^2) + 
        0.00008745703441174328*NM + 0.00019058428070006247*lm*NM + 
        0.00021782603477318966*lm^2*NM + 0.0006445805406704888*NL + 
        0.00019058428070006247*lm*NL + 0.00021782603477318966*lm^2*NL - 
        0.00009815426255419653*NH + 0.00019058428070006247*lm*NH + 
        0.00021782603477318966*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.0007559552785095434 - 0.002507089243982891*lm - 
          0.0011727047891442624*lm^2) + CF*(0.005700881826564691 - 
          0.0010961959707494011*lm + 0.00575691441943547*lm^2) + 
        0.00008176835000234761*NM + 0.00018446470472383684*lm*NM + 
        0.00021321905257168407*lm^2*NM + 0.0006299010283516975*NL + 
        0.00018446470472383684*lm*NL + 0.00021321905257168407*lm^2*NL - 
        0.00009470784544725577*NH + 0.00018446470472383684*lm*NH + 
        0.00021321905257168407*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.0007281421060714534 - 0.0024428939462306032*lm - 
          0.0011479440875447773*lm^2) + CF*(0.005589056630982872 - 
          0.001128327843086353*lm + 0.005635361884310725*lm^2) + 
        0.00007631510957137318*NM + 0.0001785225815356984*lm*NM + 
        0.00020871710682632315*lm^2*NM + 0.0006155898285454216*NL + 
        0.0001785225815356984*lm*NL + 0.00020871710682632315*lm^2*NL - 
        0.00009135841184852057*NH + 0.0001785225815356984*lm*NH + 
        0.00020871710682632315*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.0007012247131710465 - 0.0023803649226359553*lm - 
          0.0011237471729056618*lm^2) + CF*(0.005479776471248733 - 
          0.0011587237692791152*lm + 0.0055165770306277945*lm^2) + 
        0.00007108873524849416*NM + 0.00017275295418704532*lm*NM + 
        0.00020431766780102943*lm^2*NM + 0.0006016371453332056*NL + 
        0.00017275295418704532*lm*NL + 0.00020431766780102943*lm^2*NL - 
        0.00008810342476391194*NH + 0.00017275295418704532*lm*NH + 
        0.00020431766780102943*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.0006751762322626197 - 0.0023194583747798495*lm - 
          0.0011001004765706023*lm^2) + CF*(0.005372979478342185 - 
          0.0011874436733711787*lm + 0.005400493248619321*lm^2) + 
        0.00006608094278509612*NM + 0.0001671509991833043*lm*NM + 
        0.00020001826846738224*lm^2*NM + 0.0005880334484686652*NL + 
        0.0001671509991833043*lm*NL + 0.00020001826846738224*lm^2*NL - 
        0.00008494040982270252*NH + 0.0001671509991833043*lm*NH + 
        0.00020001826846738224*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.0006499705401160935 - 0.002260131648275985*lm - 
          0.0010769907663442867*lm^2) + CF*(0.005268605249616024 - 
          0.001214545708910855*lm + 0.005287045580235589*lm^2) + 
        0.00006128373207506714*NM + 0.000161712023177121*lm*NM + 
        0.0001958165029716885*lm^2*NM + 0.0005747694664320208*NL + 
        0.000161712023177121*lm*NL + 0.0001958165029716885*lm^2*NL - 
        0.00008186695389611804*NH + 0.000161712023177121*lm*NH + 
        0.0001958165029716885*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.0006255822404001076 - 0.002202343204435645*lm - 
          0.0010544051382454511*lm^2) + CF*(0.005166594820200363 - 
          0.0012400863037907916*lm + 0.005176170678659487*lm^2) + 
        0.00005668937795135505*NM + 0.00015643145972488892*lm*NM + 
        0.00019171002513553658*lm^2*NM + 0.0005618361796376303*NL + 
        0.00015643145972488892*lm*NL + 0.00019171002513553658*lm^2*NL - 
        0.00007888070373700277*NH + 0.00015643145972488892*lm*NH + 
        0.00019171002513553658*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0006019866464672852 - 0.00214605259251266*lm - 
          0.0010323310084417883*lm^2) + CF*(0.005066890634525942 - 
          0.001264120204317961*lm + 0.005067806768714233*lm^2) + 
        0.000052290421252306735*NM + 0.00015130486610668133*lm*NM + 
        0.00018769654698941606*lm^2*NM + 0.0005492248137933568*NL + 
        0.00015130486610668133*lm*NL + 0.00018769654698941606*lm^2*NL - 
        0.00007597936464083609*NH + 0.00015130486610668133*lm*NH + 
        0.00018769654698941606*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0005791597643551205 - 0.002091220422525231*lm - 
          0.0010107561053643093*lm^2) + CF*(0.004969436518000163 - 
          0.0012867005185029146*lm + 0.004961893608152064*lm^2) + 
        0.00004807966015177843*NM + 0.00014632792020954064*lm*NM + 
        0.00018377383733896534*lm^2*NM + 0.0005369268334104324*NL + 
        0.00014632792020954064*lm*NL + 0.00018377383733896534*lm^2*NL - 
        0.00007316069912833435*NH + 0.00014632792020954064*lm*NH + 
        0.00018377383733896534*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0005570782760143942 - 0.002037808338650623*lm - 
          0.000989668461998665*lm^2) + CF*(0.004874177648866846 - 
          0.0013078787585593696*lm + 0.004858372449811629*lm^2) + 
        0.00004405014174699507*NM + 0.0001414964174739759*lm*NM + 
        0.00017993972036339364*lm^2*NM + 0.000524933935462315*NL + 
        0.0001414964174739759*lm*NL + 0.00017993972036339364*lm^2*NL - 
        0.00007042252564982384*NH + 0.0001414964174739759*lm*NH + 
        0.00017993972036339364*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.0005357195227755851 - 0.001985778993188106*lm - 
          0.0009690564083508454*lm^2) + CF*(0.004781060530277945 - 
          0.0013277048826073055*lm + 0.004757186004631423*lm^2) + 
        0.000040195153898140424*NM + 0.000136806267903427*lm*NM + 
        0.00017619207424560823*lm^2*NM + 0.0005132380431908882*NL + 
        0.000136806267903427*lm*NL + 0.00017619207424560823*lm^2*NL - 
        0.00006776271731152504*NH + 0.000136806267903427*lm*NH + 
        0.00017619207424560823*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.0005150614890624131 - 0.0019350960210849856*lm - 
          0.0009489085640846112*lm^2) + CF*(0.004690032962602954 - 
          0.0013462273355746759*lm + 0.004658278405506274*lm^2) + 
        0.000036508217313676314*NM + 0.00013225349313636837*lm*NM + 
        0.00017252882983356569*lm^2*NM + 0.0005018313000582329*NL + 
        0.00013225349313636837*lm*NL + 0.00017252882983356569*lm^2*NL - 
        0.00006517920062384675*NH + 0.00013225349313636837*lm*NH + 
        0.00017252882983356569*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.0004950827863604157 - 0.0018857240150200437*lm - 
          0.0009292138313279514*lm^2) + CF*(0.004601044015999296 - 
          0.0013634930892946354*lm + 0.004561595171973579*lm^2) + 
        0.00003298307787541788*NM + 0.00012783422358064728*lm*NM + 
        0.0001689479693323548*lm^2*NM + 0.0004907060638420777*NL + 
        0.00012783422358064728*lm*NL + 0.0001689479693323548*lm^2*NL - 
        0.00006266995427174915*NH + 0.00012783422358064728*lm*NH + 
        0.0001689479693323548*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.00047576263744731625 - 0.001837628501038279*lm - 
          0.0009099613876458083*lm^2) + CF*(0.004514044003264798 - 
          0.0013795476817968198*lm + 0.004467083175715786*lm^2) + 
        0.000029613699197430944*NM + 0.0001235446956095827*lm*NM + 
        0.0001654475250265106*lm^2*NM + 0.0004798549008729426*NL + 
        0.0001235446956095827*lm*NL + 0.0001654475250265106*lm^2*NL - 
        0.00006023300790719988*NH + 0.0001235446956095827*lm*NH + 
        0.0001654475250265106*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0004570808608908868 - 0.0017907759147304245*lm - 
          0.0008911406791762774*lm^2) + CF*(0.004428984452991212 - 
          0.0013944352557927226*lm + 0.0043746906068653614*lm^2) + 
        0.000026394255412866026*NM + 0.00011938124881928573*lm*NM + 
        0.00016202557803205044*lm^2*NM + 0.00046927058041089777*NL + 
        0.00011938124881928573*lm*NL + 0.00016202557803205044*lm^2*NL - 
        0.000057866440963713045*NH + 0.00011938124881928573*lm*NH + 
        0.00016202557803205044*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.00043901785581903336 - 0.0017451335779503664*lm - 
          0.0008727414139274517*lm^2) + CF*(0.004345818083035809 - 
          0.0014081985963565957*lm + 0.004284366941098399*lm^2) + 
        0.000023319124182900974*NM + 0.00011534032334660672*lm*NM + 
        0.00015868025707771848*lm^2*NM + 0.00045894606915978907*NL + 
        0.00011534032334660672*lm*NL + 0.00015868025707771848*lm^2*NL - 
        0.000055568381492931064*NH + 0.00011534032334660672*lm*NH + 
        0.00015868025707771848*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.0004215545869659317 - 0.0017006696760632773*lm - 
          0.0008547535552320597*lm^2) + CF*(0.0042644987743262275 - 
          0.0014208791678045614*lm + 0.004196062907502839*lm^2) + 
        0.000020382879922028496*NM + 0.00011141845724706139*lm*NM + 
        0.00015540973731491996*lm^2*NM + 0.00044887452591671343*NL + 
        0.00011141845724706139*lm*NL + 0.00015540973731491996*lm^2*NL - 
        0.00005333700502318097*NH + 0.00011141845724706139*lm*NH + 
        0.00015540973731491996*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.00040467256999721107 - 0.001657353235717001*lm - 
          0.0008371673153570266*lm^2) + CF*(0.004184981545012026 - 
          0.0014325171497757783*lm + 0.0041097304572072215*lm^2) + 
        0.00001758028723399655*NM + 0.0001076122839320436*lm*NM + 
        0.000152212239155823*lm^2*NM + 0.00043904929635447476*NL + 
        0.0001076122839320436*lm*NL + 0.000152212239155823*lm^2*NL - 
        0.00005117053343991073*NH + 0.0001076122839320436*lm*NH + 
        0.000152212239155823*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.00038835385711642284 - 0.0016151541031289812*lm - 
          0.0008199731492650766*lm^2) + CF*(0.0041072225249748195 - 
          0.0014431514725205474*lm + 0.004025322732755831*lm^2) + 
        0.000014906294552786517*NM + 0.0001039185296645904*lm*NM + 
        0.00014908602713910486*lm^2*NM + 0.0004294639079347064*NL + 
        0.0001039185296645904*lm*NL + 0.00014908602713910486*lm^2*NL - 
        0.00004906723388788756*NH + 0.0001039185296645904*lm*NH + 
        0.00014908602713910486*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.0003725810229543275 - 0.0015740429228808294*lm - 
          0.0008031617485254943*lm^2) + CF*(0.0040311789307073504 - 
          0.0014528198514012069*lm + 0.0039427940382160635*lm^2) + 
        0.000012356027983096597*NM + 0.00010033401111292897*lm*NM + 
        0.00014602940882281715*lm^2*NM + 0.00042011206494930726*NL + 
        0.00010033401111292897*lm*NL + 0.00014602940882281715*lm^2*NL - 
        0.00004702541769501834*NH + 0.00010033401111292897*lm*NH + 
        0.00014602940882281715*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.00035733715074189146 - 0.0015339911172124428*lm - 
          0.0007867240353711536*lm^2) + CF*(0.003956809040570478 - 
          0.0014615588206125156*lm + 0.003862099810003845*lm^2) + 
        9.924785334884619*^-6*NM + 0.00009685563296100366*lm*NM + 
        0.00014304073370384612*lm^2*NM + 0.0004109876436878116*NL + 
        0.00009685563296100366*lm*NL + 0.00014304073370384612*lm^2*NL - 
        0.00004504343931763255*NH + 0.00009685563296100366*lm*NH + 
        0.00014304073370384612*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.00034260581876729594 - 0.001494970865807442*lm - 
          0.0007706511568989381*lm^2) + CF*(0.003884072170435756 - 
          0.001469403766129015*lm + 0.0037831965884129685*lm^2) + 
        7.608030346615122*^-6*NM + 0.00009348038557515254*lm*NM + 
        0.0001401183921634433*lm^2*NM + 0.00040208468772829015*NL + 
        0.00009348038557515254*lm*NL + 0.0001401183921634433*lm^2*NL - 
        0.00004311969530704986*NH + 0.00009348038557515254*lm*NH + 
        0.0001401183921634433*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.00032837108711672013 - 0.0014569550860615748*lm - 
          0.0007549344794106791*lm^2) + CF*(0.0038129286497200644 - 
          0.001476388957887551*lm + 0.0037060419898342425*lm^2) + 
        5.401387091949481*^-6*NM + 0.00009020534272607961*lm*NM + 
        0.0001372608144383053*lm^2*NM + 0.0003933974033493635*NL + 
        0.00009020534272607961*lm*NL + 0.0001372608144383053*lm^2*NL - 
        0.00004125262329723828*NH + 0.00009020534272607961*lm*NH + 
        0.0001372608144383053*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.0003146174846981699 - 0.0014199174138256384*lm - 
          0.0007395655828917538*lm^2) + CF*(0.003743339797817652 - 
          0.001482547581213772*lm + 0.003630594679650428*lm^2) + 
        3.300634564714523*^-6*NM + 0.0000870276593652474*lm*NM + 
        0.00013446646961668253*lm^2*NM + 0.0003849201550609016*NL + 
        0.0000870276593652474*lm*NL + 0.00013446646961668253*lm^2*NL - 
        0.00003944070101335368*NH + 0.0000870276593652474*lm*NH + 
        0.00013446646961668253*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.00030132999654717505 - 0.0013838321846143943*lm - 
          0.0007245362556245039*lm^2) + CF*(0.003675267900933881 - 
          0.001487911767501973*lm + 0.003556814345793019*lm^2) + 
        1.3017014370839657*^-6*NM + 0.00008394456945479805*lm*NM + 
        0.0001317338646590007*lm^2*NM + 0.0003766474612509768*NL + 
        0.00008394456945479805*lm*NL + 0.0001317338646590007*lm^2*NL - 
        0.000037682445300938284*NH + 0.00008394456945479805*lm*NH + 
        0.0001317338646590007*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.000288494051412771 - 0.0013486744152729014*lm - 
          0.0007098384889336519*lm^2) + CF*(0.003608676189324027 - 
          0.0014925126241581586*lm + 0.0034846616729470184*lm^2) - 
        5.993390139922188*^-7*NM + 0.00008095338385009567*lm*NM + 
        0.00012906154344248215*lm^2*NM + 0.0003685739899466409*NL + 
        0.00008095338385009567*lm*NL + 0.00012906154344248215*lm^2*NL - 
        0.0000359764111755436*NH + 0.00008095338385009567*lm*NH + 
        0.00012906154344248215*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.00027609550962181173 - 0.0013144197860916554*lm - 
          0.0006954644720609225*lm^2) + CF*(0.0035435288149395596 - 
          0.0014963802638166316*lm + 0.0034140983173899827*lm^2) - 
        2.4062738169732875*^-6*NM + 0.00007805148823397182*lm*NM + 
        0.00012644808582925864*lm^2*NM + 0.00036069455468610087*NL + 
        0.00007805148823397182*lm*NL + 0.00012644808582925864*lm^2*NL - 
        0.000034321190892532364*NH + 0.00007805148823397182*lm*NH + 
        0.00012644808582925864*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.00026412065121932744 - 0.0012810446233619062*lm - 
          0.0006814065871660945*lm^2) + CF*(0.003479790829483543 - 
          0.0014995438328407958*lm + 0.0033450868824517364*lm^2) - 
        4.122755057287603*^-6*NM + 0.00007523634110174624*lm*NM + 
        0.00012389210675747172*lm^2*NM + 0.0003530041104998775*NL + 
        0.00007523634110174624*lm*NL + 0.00012389210675747172*lm^2*NL - 
        0.00003271541303680464*NH + 0.00007523634110174624*lm*NH + 
        0.00012389210675747172*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.00025255616438233996 - 0.0012485258823625247*lm - 
          0.0006676574044517446*lm^2) + CF*(0.0034174281628759906 - 
          0.0015020315391191985*lm + 0.0032775908945812914*lm^2) - 
        5.7523044749225314*^-6*NM + 0.0000725054717960884*lm*NM + 
        0.00012139225535486264*lm^2*NM + 0.0003454977499985459*NL + 
        0.0000725054717960884*lm*NL + 0.00012139225535486264*lm^2*NL - 
        0.00003115774163218465*NH + 0.0000725054717960884*lm*NH + 
        0.00012139225535486264*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.00024138913410427903 - 0.0012168411307698023*lm - 
          0.0006542096774089701*lm^2) + CF*(0.0033564076021293304 - 
          0.0015038706791681241*lm + 0.003211574780007671*lm^2) - 
        7.298317912595647*^-6*NM + 0.00006985647859078089*lm*NM + 
        0.00011894721407435819*lm^2*NM + 0.00033817069956467187*NL + 
        0.00006985647859078089*lm*NL + 0.00011894721407435819*lm^2*NL - 
        0.000029646875270197416*NH + 0.00006985647859078089*lm*NH + 
        0.00011894721407435819*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.00023060703114690214 - 0.0011859685324815963*lm - 
          0.0006410563381814133*lm^2) + CF*(0.003296696770633478 - 
          0.0015050876645522843*lm + 0.0031470038419814834*lm^2) - 
        8.764069618954034*^-6*NM + 0.00006728702682244252*lm*NM + 
        0.00011655569785116605*lm^2*NM + 0.0003310183156465782*NL + 
        0.00006728702682244252*lm*NL + 0.00011655569785116605*lm^2*NL - 
        0.000028181546257957925*NH + 0.00006728702682244252*lm*NH + 
        0.00011655569785116605*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.00022019770125640445 - 0.0011558868318472697*lm - 
          0.0006281904930449437*lm^2) + CF*(0.003238264107849418 - 
          0.0015057080476353624*lm + 0.003083844238584269*lm^2) - 
        0.000010152716411144113*NM + 0.00006479484706926871*lm*NM + 
        0.00011421645328089885*lm^2*NM + 0.00032403608115159823*NL + 
        0.00006479484706926871*lm*NL + 0.00011421645328089885*lm^2*NL - 
        0.000026760519784889834*NH + 0.00006479484706926871*lm*NH + 
        0.00011421645328089885*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.0002101493546402177 - 0.0011265753382949267*lm - 
          0.0006156054180003892*lm^2) + CF*(0.0031810788494096498 - 
          0.001505756546672329*lm + 0.0030220629610928193*lm^2) - 
        0.00001146730170099035*NM + 0.00006237773337584702*lm*NM + 
        0.00011192825781825258*lm^2*NM + 0.00031721960193649824*NL + 
        0.00006237773337584702*lm*NL + 0.00011192825781825258*lm^2*NL - 
        0.000025382593107986032*NH + 0.00006237773337584702*lm*NH + 
        0.00011192825781825258*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.00020045055570082712 - 0.0010980139113475021*lm - 
          0.0006032945544767467*lm^2) + CF*(0.0031251110076233506 - 
          0.0015052570702555742*lm + 0.0029616278128858477*lm^2) - 
        0.000012710759388917707*NM + 0.00006003354152310858*lm*NM + 
        0.00010968991899577214*lm^2*NM + 0.0003105646033927762*NL + 
        0.00006003354152310858*lm*NL + 0.00010968991899577214*lm^2*NL - 
        0.00002404659475531945*NH + 0.00006003354152310858*lm*NH + 
        0.00010968991899577214*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.000191090213022792 - 0.0010701829460193408*lm - 
          0.00059125150514234*lm^2) + CF*(0.0030703313523836513 - 
          0.0015042327411270058*lm + 0.002902507388880578*lm^2) - 
        0.000013885917629649871*NM + 0.00005776018734247917*lm*NM + 
        0.00010750027366224363*lm^2*NM + 0.0003040669271245756*NL + 
        0.00005776018734247917*lm*NL + 0.00010750027366224363*lm^2*NL - 
        0.00002275138374750921*NH + 0.00005776018734247917*lm*NH + 
        0.00010750027366224363*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.0001820575696090269 - 0.0010430633585849656*lm - 
          0.0005794700298214293*lm^2) + CF*(0.0030167113924740056 - 
          0.0015027059193683235*lm + 0.0028446710554870165*lm^2) - 
        0.0000149955024736134*NM + 0.00005555564507329936*lm*NM + 
        0.00010535818724025987*lm^2*NM + 0.00029772252771698116*NL + 
        0.00005555564507329936*lm*NL + 0.00010535818724025987*lm^2*NL - 
        0.00002149584883684465*NH + 0.00005555564507329936*lm*NH + 
        0.00010535818724025987*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.00017334219336229413 - 0.0010166365727118322*lm - 
          0.0005679440415138235*lm^2) + CF*(0.0029642233572702496 - 
          0.0015006982249817329*lm + 0.002788088931067861*lm^2) - 
        0.000016042141387876958*NM + 0.00005341794576258882*lm*NM + 
        0.00010326255300251337*lm^2*NM + 0.0002915274695924975*NL + 
        0.00005341794576258882*lm*NL + 0.00010326255300251337*lm^2*NL - 
        0.000020278907763767866*NH + 0.00005341794576258882*lm*NH + 
        0.00010326255300251337*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.00016493396780776516 - 0.0009908845059489525*lm - 
          0.0005566676025150798*lm^2) + CF*(0.002912840178834609 - 
          0.001498230559873369*lm + 0.00273273186689221*lm^2) - 
        0.00001702836666035516*NM + 0.000051345175706237344*lm*NM + 
        0.00010121229136637815*lm^2*NM + 0.0002854779239535431*NL + 
        0.000051345175706237344*lm*NL + 0.00010121229136637815*lm^2*NL - 
        0.000019099506530414036*NH + 0.000051345175706237344*lm*NH + 
        0.00010121229136637815*lm^2*NH)}, 
     {1., 9.53495059335095*^-17*CF*NC*
       (-3.*CA*(5.482394534265398*^11 + 3.37631379456*^12*lm + 
          1.907490816*^12*lm^2) + 2.*(35.*CF*(4.288786136813557*^11 - 
            2.24036388864*^11*lm + 4.013162496*^11*lm^2) + 
          3.*(35.*(-8.967818680840341*^8 + 2.463891456*^9*lm + 
              4.9545216*^9*lm^2)*NM + 131072.*(3.728303*^6 + 657930.*lm + 
              1.323*^6*lm^2)*NL + 35.*(-8.967818680840341*^8 + 
              2.463891456*^9*lm + 4.9545216*^9*lm^2)*NH)))}}



(* vector  *)
CbarData["v", 0, -1] = (-2*NC*(-1 + x)^2)/(3*ep) + 
     NC*((-1 - 2*lm*(-1 + x)^2 + 4*x - x^2)/3 + (4*(-2 + x)*x^3*HPL[{0}, x])/
        (3*(-1 + x^2)))
 
CbarData["v", 0, 0] = (4*NC)/(9*ep) + 
     NC*((2*(2 + 9*x - 16*x^2 + 9*x^3 + 2*x^4 + 6*lm*(-1 + x^2)^2))/
        (27*(-1 + x^2)^2) - (8*x^3*(3 - 3*x + x^3)*HPL[{0}, x])/
        (9*(-1 + x^2)^3))
 
CbarData["v", 0, 1] = NC*((3 + 4*x - 21*x^2 + 40*x^3 - 21*x^4 + 4*x^5 + 
        3*x^6)/(18*(-1 + x^2)^4) - (4*x^3*(2 - 3*x + 2*x^2)*HPL[{0}, x])/
       (3*(-1 + x^2)^5))
 
CbarData["v", 0, 2] = NC*((2 + 5*x - 28*x^2 + 145*x^3 - 188*x^4 + 145*x^5 - 
        28*x^6 + 5*x^7 + 2*x^8)/(45*(-1 + x^2)^6) - 
      (8*x^3*(1 - x + x^2)^2*HPL[{0}, x])/(3*(-1 + x^2)^7))
 
CbarData["v", 0, 3] = NC*((5 + 18*x - 115*x^2 + 1068*x^3 - 1990*x^4 + 
        2868*x^5 - 1990*x^6 + 1068*x^7 - 115*x^8 + 18*x^9 + 5*x^10)/
       (270*(-1 + x^2)^8) - (4*x^3*(6 - 15*x + 36*x^2 - 40*x^3 + 36*x^4 - 
         15*x^5 + 6*x^6)*HPL[{0}, x])/(9*(-1 + x^2)^9))
 
CbarData["v", 0, 4] = NC*((3 + 14*x - 102*x^2 + 1428*x^3 - 3399*x^4 + 
        7378*x^5 - 8124*x^6 + 7378*x^7 - 3399*x^8 + 1428*x^9 - 102*x^10 + 
        14*x^11 + 3*x^12)/(315*(-1 + x^2)^10) - 
      (8*x^3*(1 - 3*x + 10*x^2 - 15*x^3 + 20*x^4 - 15*x^5 + 10*x^6 - 3*x^7 + 
         x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11))
 
CbarData["v", 0, 5] = NC*((7 + 40*x - 329*x^2 + 6312*x^3 - 18165*x^4 + 
        53352*x^5 - 78533*x^6 + 102352*x^7 - 78533*x^8 + 53352*x^9 - 
        18165*x^10 + 6312*x^11 - 329*x^12 + 40*x^13 + 7*x^14)/
       (1260*(-1 + x^2)^12) - (4*x^3*(2 - 7*x + 30*x^2 - 56*x^3 + 100*x^4 - 
         105*x^5 + 100*x^6 - 56*x^7 + 30*x^8 - 7*x^9 + 2*x^10)*HPL[{0}, x])/
       (3*(-1 + x^2)^13))
 
CbarData["v", 0, 6] = NC*((20 + 135*x - 1240*x^2 + 30699*x^3 - 103336*x^4 + 
        385263*x^5 - 703096*x^6 + 1205523*x^7 - 1267576*x^8 + 1205523*x^9 - 
        703096*x^10 + 385263*x^11 - 103336*x^12 + 30699*x^13 - 1240*x^14 + 
        135*x^15 + 20*x^16)/(5670*(-1 + x^2)^14) - 
      (8*x^3*(3 - 12*x + 63*x^2 - 140*x^3 + 315*x^4 - 420*x^5 + 525*x^6 - 
         420*x^7 + 315*x^8 - 140*x^9 + 63*x^10 - 12*x^11 + 3*x^12)*
        HPL[{0}, x])/(9*(-1 + x^2)^15))
 
CbarData["v", 0, 7] = NC*((9 + 70*x - 711*x^2 + 21796*x^3 - 83898*x^4 + 
        380644*x^5 - 825210*x^6 + 1763620*x^7 - 2333430*x^8 + 2874940*x^9 - 
        2333430*x^10 + 1763620*x^11 - 825210*x^12 + 380644*x^13 - 
        83898*x^14 + 21796*x^15 - 711*x^16 + 70*x^17 + 9*x^18)/
       (3780*(-1 + x^2)^16) - (4*x^3*(2 - 9*x + 56*x^2 - 144*x^3 + 392*x^4 - 
         630*x^5 + 980*x^6 - 1008*x^7 + 980*x^8 - 630*x^9 + 392*x^10 - 
         144*x^11 + 56*x^12 - 9*x^13 + 2*x^14)*HPL[{0}, x])/(3*(-1 + x^2)^17))
 
CbarData["v", 0, 8] = NC*((35 + 308*x - 3430*x^2 + 126346*x^3 - 546995*x^4 + 
        2931214*x^5 - 7341860*x^6 + 18853582*x^7 - 29919800*x^8 + 
        45475870*x^9 - 46898300*x^10 + 45475870*x^11 - 29919800*x^12 + 
        18853582*x^13 - 7341860*x^14 + 2931214*x^15 - 546995*x^16 + 
        126346*x^17 - 3430*x^18 + 308*x^19 + 35*x^20)/(20790*(-1 + x^2)^18) - 
      (8*x^3*(1 - 5*x + 36*x^2 - 105*x^3 + 336*x^4 - 630*x^5 + 1176*x^6 - 
         1470*x^7 + 1764*x^8 - 1470*x^9 + 1176*x^10 - 630*x^11 + 336*x^12 - 
         105*x^13 + 36*x^14 - 5*x^15 + x^16)*HPL[{0}, x])/(3*(-1 + x^2)^19))
 
CbarData["v", 0, 9] = NC*((77 + 756*x - 9163*x^2 + 396426*x^3 - 1905838*x^4 + 
        11798256*x^5 - 33477158*x^6 + 100595316*x^7 - 185670353*x^8 + 
        336603396*x^9 - 419117105*x^10 + 497967060*x^11 - 419117105*x^12 + 
        336603396*x^13 - 185670353*x^14 + 100595316*x^15 - 33477158*x^16 + 
        11798256*x^17 - 1905838*x^18 + 396426*x^19 - 9163*x^20 + 756*x^21 + 
        77*x^22)/(62370*(-1 + x^2)^20) - 
      (4*x^3*(6 - 33*x + 270*x^2 - 880*x^3 + 3240*x^4 - 6930*x^5 + 
         15120*x^6 - 22176*x^7 + 31752*x^8 - 32340*x^9 + 31752*x^10 - 
         22176*x^11 + 15120*x^12 - 6930*x^13 + 3240*x^14 - 880*x^15 + 
         270*x^16 - 33*x^17 + 6*x^18)*HPL[{0}, x])/(9*(-1 + x^2)^21))
 
 
CbarLData["v", 0, -1] = (2*NC*(-1 + x)^2)/(3*ep) + 
     NC*((1 + 2*lm*(-1 + x)^2 - 4*x + x^2)/3 - (4*(-2 + x)*x^3*HPL[{0}, x])/
        (3*(-1 + x^2)))
 
CbarLData["v", 0, 0] = (2*NC*(-1 + 3*x + 3*x^2 - 3*x^4 - 3*x^5 + x^6 + 
       12*x^3*HPL[{0}, x]))/(9*(-1 + x^2)^3)
 
CbarLData["v", 0, 1] = NC*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6)/
       (18*(-1 + x^2)^4) + (4*x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
       (3*(-1 + x^2)^5))
 
CbarLData["v", 0, 2] = 
    NC*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 5*x^7 - 
         x^8)/(45*(-1 + x^2)^6) + (8*x^3*(1 + x + 3*x^2 + x^3 + x^4)*
        HPL[{0}, x])/(3*(-1 + x^2)^7))
 
CbarLData["v", 0, 3] = 
    NC*(-(-1 + 6*x + 23*x^2 + 356*x^3 + 398*x^4 + 956*x^5 + 398*x^6 + 
         356*x^7 + 23*x^8 + 6*x^9 - x^10)/(90*(-1 + x^2)^8) + 
      (4*x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*x^5 + 2*x^6)*HPL[{0}, x])/
       (3*(-1 + x^2)^9))
 
CbarLData["v", 0, 4] = 
    NC*((2*(1 - 7*x - 34*x^2 - 714*x^3 - 1133*x^4 - 3689*x^5 - 2708*x^6 - 
         3689*x^7 - 1133*x^8 - 714*x^9 - 34*x^10 - 7*x^11 + x^12))/
       (315*(-1 + x^2)^10) + (8*x^3*(1 + 2*x + 10*x^2 + 10*x^3 + 20*x^4 + 
         10*x^5 + 10*x^6 + 2*x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11))
 
CbarLData["v", 0, 5] = 
    NC*(-(-5 + 40*x + 235*x^2 + 6312*x^3 + 12975*x^4 + 53352*x^5 + 
         56095*x^6 + 102352*x^7 + 56095*x^8 + 53352*x^9 + 12975*x^10 + 
         6312*x^11 + 235*x^12 + 40*x^13 - 5*x^14)/(1260*(-1 + x^2)^12) + 
      (4*x^3*(2 + 5*x + 30*x^2 + 40*x^3 + 100*x^4 + 75*x^5 + 100*x^6 + 
         40*x^7 + 30*x^8 + 5*x^9 + 2*x^10)*HPL[{0}, x])/(3*(-1 + x^2)^13))
 
CbarLData["v", 0, 6] = 
    NC*(-(-5 + 45*x + 310*x^2 + 10233*x^3 + 25834*x^4 + 128421*x^5 + 
         175774*x^6 + 401841*x^7 + 316894*x^8 + 401841*x^9 + 175774*x^10 + 
         128421*x^11 + 25834*x^12 + 10233*x^13 + 310*x^14 + 45*x^15 - 5*x^16)/
       (1890*(-1 + x^2)^14) + (8*x^3*(1 + 3*x + 21*x^2 + 35*x^3 + 105*x^4 + 
         105*x^5 + 175*x^6 + 105*x^7 + 105*x^8 + 35*x^9 + 21*x^10 + 3*x^11 + 
         x^12)*HPL[{0}, x])/(3*(-1 + x^2)^15))
 
CbarLData["v", 0, 7] = 
    NC*(-(-7 + 70*x + 553*x^2 + 21796*x^3 + 65254*x^4 + 380644*x^5 + 
         641830*x^6 + 1763620*x^7 + 1814890*x^8 + 2874940*x^9 + 
         1814890*x^10 + 1763620*x^11 + 641830*x^12 + 380644*x^13 + 
         65254*x^14 + 21796*x^15 + 553*x^16 + 70*x^17 - 7*x^18)/
       (3780*(-1 + x^2)^16) + (4*x^3*(2 + 7*x + 56*x^2 + 112*x^3 + 392*x^4 + 
         490*x^5 + 980*x^6 + 784*x^7 + 980*x^8 + 490*x^9 + 392*x^10 + 
         112*x^11 + 56*x^12 + 7*x^13 + 2*x^14)*HPL[{0}, x])/(3*(-1 + x^2)^17))
 
CbarLData["v", 0, 8] = 
    NC*(-(-14 + 154*x + 1372*x^2 + 63173*x^3 + 218798*x^4 + 1465607*x^5 + 
         2936744*x^6 + 9426791*x^7 + 11967920*x^8 + 22737935*x^9 + 
         18759320*x^10 + 22737935*x^11 + 11967920*x^12 + 9426791*x^13 + 
         2936744*x^14 + 1465607*x^15 + 218798*x^16 + 63173*x^17 + 1372*x^18 + 
         154*x^19 - 14*x^20)/(10395*(-1 + x^2)^18) + 
      (8*x^3*(1 + 4*x + 36*x^2 + 84*x^3 + 336*x^4 + 504*x^5 + 1176*x^6 + 
         1176*x^7 + 1764*x^8 + 1176*x^9 + 1176*x^10 + 504*x^11 + 336*x^12 + 
         84*x^13 + 36*x^14 + 4*x^15 + x^16)*HPL[{0}, x])/(3*(-1 + x^2)^19))
 
CbarLData["v", 0, 9] = 
    NC*(-(-21 + 252*x + 2499*x^2 + 132142*x^3 + 519774*x^4 + 3932752*x^5 + 
         9130134*x^6 + 33531772*x^7 + 50637369*x^8 + 112201132*x^9 + 
         114304665*x^10 + 165989020*x^11 + 114304665*x^12 + 112201132*x^13 + 
         50637369*x^14 + 33531772*x^15 + 9130134*x^16 + 3932752*x^17 + 
         519774*x^18 + 132142*x^19 + 2499*x^20 + 252*x^21 - 21*x^22)/
       (20790*(-1 + x^2)^20) + (4*x^3*(2 + 9*x + 90*x^2 + 240*x^3 + 
         1080*x^4 + 1890*x^5 + 5040*x^6 + 6048*x^7 + 10584*x^8 + 8820*x^9 + 
         10584*x^10 + 6048*x^11 + 5040*x^12 + 1890*x^13 + 1080*x^14 + 
         240*x^15 + 90*x^16 + 9*x^17 + 2*x^18)*HPL[{0}, x])/(3*(-1 + x^2)^21))
 
CbarData["v", 1, -1] = (-5*CF*NC*(-1 + x)^2)/(12*ep) + 
     (CF*NC*(1 - 2*x + x^2))/(2*ep^2) + CF*NC*(-(lm^2*(-1 + x)^2)/2 + 
       (-39 + 198*x - 39*x^2 - 4*Pi^2*(-1 + x^2))/72 + 
       (2*x^2*(1 - 5*x + x^2)*HPL[{0}, x])/(3*(-1 + x^2)) + 
       lm*((-1 + 5*x - x^2)/3 + (2*(-2 + x)*x^3*HPL[{0}, x])/(-1 + x^2)) + 
       (2*(-1 + x^2)*HPL[{-1, 0}, x])/3 - (8*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
         HPL[{0, 0}, x])/(3*(-1 + x^2)^2) - (2*(-1 + x^2)*HPL[{1, 0}, x])/3)
 
CbarData["v", 1, 0] = (CF*NC)/(6*ep) + 
     CF*NC*(-lm/3 + (4*Pi^2*(-2 + 9*x - 9*x^3 + 2*x^4) + 
         3*(19 + 84*x - 142*x^2 + 84*x^3 + 19*x^4))/(324*(-1 + x^2)^2) + 
       (2*x^2*(-4 + 48*x - 31*x^2 + 9*x^4)*HPL[{0}, x])/(27*(-1 + x^2)^3) + 
       ((8 - 36*x + 8*x^2)*HPL[{-1, 0}, x])/(27 - 27*x^2) + 
       (8*x^3*(-54 + 54*x - 27*x^2 - 4*x^3 - 9*x^4 + 2*x^5)*HPL[{0, 0}, x])/
        (27*(-1 + x^2)^4) + (4*(2 - 9*x + 2*x^2)*HPL[{1, 0}, x])/
        (27*(-1 + x^2)))
 
CbarData["v", 1, 1] = 
    CF*NC*(-(4*Pi^2*(-9 - 12*x + 41*x^2 - 41*x^4 + 12*x^5 + 9*x^6) + 
         3*(69 - 168*x + 23*x^2 + 144*x^3 + 23*x^4 - 168*x^5 + 69*x^6))/
       (1296*(-1 + x^2)^4) + (x^2*(18 + 438*x - 691*x^2 + 762*x^3 - 198*x^4 + 
         36*x^5 + 27*x^6)*HPL[{0}, x])/(54*(-1 + x^2)^5) + 
      lm*(-(3 + 4*x - 21*x^2 + 40*x^3 - 21*x^4 + 4*x^5 + 3*x^6)/
         (12*(-1 + x^2)^4) + (2*x^3*(2 - 3*x + 2*x^2)*HPL[{0}, x])/
         (-1 + x^2)^5) + ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*
        HPL[{-1, 0}, x])/(27*(-1 + x^2)^3) - 
      (2*x^3*(216 - 324*x + 648*x^2 - 516*x^3 + 408*x^4 - 59*x^5 + 12*x^6 + 
         9*x^7)*HPL[{0, 0}, x])/(27*(-1 + x^2)^6) - 
      ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{1, 0}, x])/(27*(-1 + x^2)^3))
 
CbarData["v", 1, 2] = CF*NC*((-92 + 147*x + 74*x^2 - 3567*x^3 + 4908*x^4 - 
        3567*x^5 + 74*x^6 + 147*x^7 - 92*x^8 - 
        4*Pi^2*(-2 - 5*x + 14*x^2 - 15*x^3 + 15*x^5 - 14*x^6 + 5*x^7 + 
          2*x^8))/(1080*(-1 + x^2)^6) + 
      (2*x^2*(2 + 299*x - 568*x^2 + 1217*x^3 - 1048*x^4 + 719*x^5 - 88*x^6 + 
         15*x^7 + 6*x^8)*HPL[{0}, x])/(45*(-1 + x^2)^7) + 
      lm*(-(2 + 5*x - 28*x^2 + 145*x^3 - 188*x^4 + 145*x^5 - 28*x^6 + 5*x^7 + 
           2*x^8)/(15*(-1 + x^2)^6) + (8*x^3*(1 - x + x^2)^2*HPL[{0}, x])/
         (-1 + x^2)^7) + (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 
         2*x^6)*HPL[{-1, 0}, x])/(45*(-1 + x^2)^5) - 
      (4*x^3*(180 - 360*x + 1260*x^2 - 1560*x^3 + 1940*x^4 - 1050*x^5 + 
         545*x^6 - 18*x^7 + 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
       (45*(-1 + x^2)^8) - (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 
         2*x^6)*HPL[{1, 0}, x])/(45*(-1 + x^2)^5))
 
CbarData["v", 1, 3] = CF*NC*((-577 + 171*x + 3270*x^2 - 83664*x^3 + 
        149875*x^4 - 223542*x^5 + 149875*x^6 - 83664*x^7 + 3270*x^8 + 
        171*x^9 - 577*x^10 - 6*Pi^2*(-5 - 18*x + 47*x^2 - 144*x^3 + 144*x^4 - 
          144*x^6 + 144*x^7 - 47*x^8 + 18*x^9 + 5*x^10))/
       (9720*(-1 + x^2)^8) + (x^2*(10 + 5016*x - 11700*x^2 + 36954*x^3 - 
         46374*x^4 + 53154*x^5 - 28575*x^6 + 14466*x^7 - 1070*x^8 + 162*x^9 + 
         45*x^10)*HPL[{0}, x])/(270*(-1 + x^2)^9) + 
      lm*(-(5 + 18*x - 115*x^2 + 1068*x^3 - 1990*x^4 + 2868*x^5 - 1990*x^6 + 
           1068*x^7 - 115*x^8 + 18*x^9 + 5*x^10)/(60*(-1 + x^2)^8) + 
        (2*x^3*(6 - 15*x + 36*x^2 - 40*x^3 + 36*x^4 - 15*x^5 + 6*x^6)*
          HPL[{0}, x])/(-1 + x^2)^9) + 
      ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 18*x^7 + 
         5*x^8)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^7) - 
      (2*x^3*(1080 - 2700*x + 13500*x^2 - 22000*x^3 + 39600*x^4 - 35115*x^5 + 
         29430*x^6 - 10845*x^7 + 4428*x^8 - 57*x^9 + 18*x^10 + 5*x^11)*
        HPL[{0, 0}, x])/(135*(-1 + x^2)^10) - 
      ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 18*x^7 + 
         5*x^8)*HPL[{1, 0}, x])/(135*(-1 + x^2)^7))
 
CbarData["v", 1, 4] = 
    CF*NC*(-(15129 + 14145*x - 192874*x^2 + 5402655*x^3 - 12004625*x^4 + 
         27166800*x^5 - 29023260*x^6 + 27166800*x^7 - 12004625*x^8 + 
         5402655*x^9 - 192874*x^10 + 14145*x^11 + 15129*x^12 + 
         60*Pi^2*(-9 - 42*x + 106*x^2 - 630*x^3 + 935*x^4 - 840*x^5 + 
           840*x^7 - 935*x^8 + 630*x^9 - 106*x^10 + 42*x^11 + 9*x^12))/
       (340200*(-1 + x^2)^10) + (x^2*(18 + 22584*x - 62924*x^2 + 263451*x^3 - 
         423882*x^4 + 687762*x^5 - 593982*x^6 + 477651*x^7 - 181616*x^8 + 
         73488*x^9 - 3762*x^10 + 504*x^11 + 108*x^12)*HPL[{0}, x])/
       (945*(-1 + x^2)^11) + 
      lm*((-2*(3 + 14*x - 102*x^2 + 1428*x^3 - 3399*x^4 + 7378*x^5 - 
           8124*x^6 + 7378*x^7 - 3399*x^8 + 1428*x^9 - 102*x^10 + 14*x^11 + 
           3*x^12))/(105*(-1 + x^2)^10) + 
        (16*x^3*(1 - 3*x + 10*x^2 - 15*x^3 + 20*x^4 - 15*x^5 + 10*x^6 - 
           3*x^7 + x^8)*HPL[{0}, x])/(-1 + x^2)^11) + 
      (2*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
         672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{-1, 0}, x])/
       (945*(-1 + x^2)^9) - (4*x^3*(3780 - 11340*x + 73710*x^2 - 147840*x^3 + 
         353850*x^4 - 425215*x^5 + 503160*x^6 - 327516*x^7 + 209412*x^8 - 
         57414*x^9 + 19446*x^10 - 124*x^11 + 42*x^12 + 9*x^13)*
        HPL[{0, 0}, x])/(945*(-1 + x^2)^12) - 
      (2*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
         672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{1, 0}, x])/
       (945*(-1 + x^2)^9))
 
CbarData["v", 1, 5] = 
    CF*NC*(-(62917 + 131656*x - 1370025*x^2 + 44965824*x^3 - 119732847*x^4 + 
         366102840*x^5 - 518856445*x^6 + 691672960*x^7 - 518856445*x^8 + 
         366102840*x^9 - 119732847*x^10 + 44965824*x^11 - 1370025*x^12 + 
         131656*x^13 + 62917*x^14 + 240*Pi^2*(-7 - 40*x + 99*x^2 - 960*x^3 + 
           1773*x^4 - 3000*x^5 + 2215*x^6 - 2215*x^8 + 3000*x^9 - 1773*x^10 + 
           960*x^11 - 99*x^12 + 40*x^13 + 7*x^14))/(1814400*(-1 + x^2)^12) + 
      (x^2*(14 + 36830*x - 119635*x^2 + 624986*x^3 - 1218098*x^4 + 
         2572244*x^5 - 2972507*x^6 + 3307244*x^7 - 2123618*x^8 + 
         1330586*x^9 - 387175*x^10 + 130910*x^11 - 5026*x^12 + 600*x^13 + 
         105*x^14)*HPL[{0}, x])/(1260*(-1 + x^2)^13) + 
      lm*(-(7 + 40*x - 329*x^2 + 6312*x^3 - 18165*x^4 + 53352*x^5 - 
           78533*x^6 + 102352*x^7 - 78533*x^8 + 53352*x^9 - 18165*x^10 + 
           6312*x^11 - 329*x^12 + 40*x^13 + 7*x^14)/(168*(-1 + x^2)^12) + 
        (10*x^3*(2 - 7*x + 30*x^2 - 56*x^3 + 100*x^4 - 105*x^5 + 100*x^6 - 
           56*x^7 + 30*x^8 - 7*x^9 + 2*x^10)*HPL[{0}, x])/(-1 + x^2)^13) + 
      ((7 + 40*x - 92*x^2 + 1000*x^3 - 1865*x^4 + 4000*x^5 - 4080*x^6 + 
         4000*x^7 - 1865*x^8 + 1000*x^9 - 92*x^10 + 40*x^11 + 7*x^12)*
        HPL[{-1, 0}, x])/(630*(-1 + x^2)^11) - 
      (x^3*(5040 - 17640*x + 141120*x^2 - 335160*x^3 + 1007440*x^4 - 
         1512140*x^5 + 2336320*x^6 - 2124668*x^7 + 1884400*x^8 - 951328*x^9 + 
         495040*x^10 - 107408*x^11 + 31120*x^12 - 113*x^13 + 40*x^14 + 
         7*x^15)*HPL[{0, 0}, x])/(315*(-1 + x^2)^14) - 
      ((7 + 40*x - 92*x^2 + 1000*x^3 - 1865*x^4 + 4000*x^5 - 4080*x^6 + 
         4000*x^7 - 1865*x^8 + 1000*x^9 - 92*x^10 + 40*x^11 + 7*x^12)*
        HPL[{1, 0}, x])/(630*(-1 + x^2)^11))
 
CbarData["v", 1, 6] = 
    CF*NC*(-(530052 + 1696401*x - 17328358*x^2 + 667762515*x^3 - 
         2075987732*x^4 + 8035738389*x^5 - 14055862562*x^6 + 
         24558727095*x^7 - 25221686000*x^8 + 24558727095*x^9 - 
         14055862562*x^10 + 8035738389*x^11 - 2075987732*x^12 + 
         667762515*x^13 - 17328358*x^14 + 1696401*x^15 + 530052*x^16 + 
         2800*Pi^2*(-4 - 27*x + 66*x^2 - 945*x^3 + 2044*x^4 - 5103*x^5 + 
           5894*x^6 - 4725*x^7 + 4725*x^9 - 5894*x^10 + 5103*x^11 - 
           2044*x^12 + 945*x^13 - 66*x^14 + 27*x^15 + 4*x^16))/
       (19051200*(-1 + x^2)^14) + (x^2*(60 + 293985*x - 1092243*x^2 + 
         6843879*x^3 - 15623255*x^4 + 40767381*x^5 - 58339291*x^6 + 
         83412999*x^7 - 73580251*x^8 + 62914401*x^9 - 31816775*x^10 + 
         16417107*x^11 - 3848835*x^12 + 1119213*x^13 - 33960*x^14 + 
         3645*x^15 + 540*x^16)*HPL[{0}, x])/(8505*(-1 + x^2)^15) + 
      lm*(-(20 + 135*x - 1240*x^2 + 30699*x^3 - 103336*x^4 + 385263*x^5 - 
           703096*x^6 + 1205523*x^7 - 1267576*x^8 + 1205523*x^9 - 
           703096*x^10 + 385263*x^11 - 103336*x^12 + 30699*x^13 - 1240*x^14 + 
           135*x^15 + 20*x^16)/(630*(-1 + x^2)^14) + 
        (8*x^3*(3 - 12*x + 63*x^2 - 140*x^3 + 315*x^4 - 420*x^5 + 525*x^6 - 
           420*x^7 + 315*x^8 - 140*x^9 + 63*x^10 - 12*x^11 + 3*x^12)*
          HPL[{0}, x])/(-1 + x^2)^15) + 
      ((4 + 27*x - 62*x^2 + 972*x^3 - 2106*x^4 + 6075*x^5 - 8000*x^6 + 
         10800*x^7 - 8000*x^8 + 6075*x^9 - 2106*x^10 + 972*x^11 - 62*x^12 + 
         27*x^13 + 4*x^14)*HPL[{-1, 0}, x])/(567*(-1 + x^2)^13) - 
      (2*x^3*(4536 - 18144*x + 172368*x^2 - 472416*x^3 + 1714608*x^4 - 
         3071712*x^5 + 5889996*x^6 - 6801480*x^7 + 7786044*x^8 - 
         5602128*x^9 + 3996216*x^10 - 1635504*x^11 + 719928*x^12 - 
         128916*x^13 + 32643*x^14 - 74*x^15 + 27*x^16 + 4*x^17)*
        HPL[{0, 0}, x])/(567*(-1 + x^2)^16) - 
      ((4 + 27*x - 62*x^2 + 972*x^3 - 2106*x^4 + 6075*x^5 - 8000*x^6 + 
         10800*x^7 - 8000*x^8 + 6075*x^9 - 2106*x^10 + 972*x^11 - 62*x^12 + 
         27*x^13 + 4*x^14)*HPL[{1, 0}, x])/(567*(-1 + x^2)^13))
 
CbarData["v", 1, 7] = 
    CF*NC*(-(4348503 + 18592590*x - 197815541*x^2 + 8856087840*x^3 - 
         31512520240*x^4 + 148038444960*x^5 - 306957447664*x^6 + 
         667159553760*x^7 - 860209765058*x^8 + 1077841457700*x^9 - 
         860209765058*x^10 + 667159553760*x^11 - 306957447664*x^12 + 
         148038444960*x^13 - 31512520240*x^14 + 8856087840*x^15 - 
         197815541*x^16 + 18592590*x^17 + 4348503*x^18 + 
         2800*Pi^2*(-27 - 210*x + 509*x^2 - 10080*x^3 + 24760*x^4 - 
           82320*x^5 + 122136*x^6 - 164640*x^7 + 107072*x^8 - 107072*x^10 + 
           164640*x^11 - 122136*x^12 + 82320*x^13 - 24760*x^14 + 10080*x^15 - 
           509*x^16 + 210*x^17 + 27*x^18))/(190512000*(-1 + x^2)^16) + 
      (x^2*(162 + 1357524*x - 5682252*x^2 + 41533902*x^3 - 108549186*x^4 + 
         337877454*x^5 - 573477332*x^6 + 1005439650*x^7 - 1115698754*x^8 + 
         1215479130*x^9 - 858530912*x^10 + 599259918*x^11 - 248657154*x^12 + 
         109356174*x^13 - 21404595*x^14 + 5463738*x^15 - 135918*x^16 + 
         13230*x^17 + 1701*x^18)*HPL[{0}, x])/(34020*(-1 + x^2)^17) + 
      lm*(-(9 + 70*x - 711*x^2 + 21796*x^3 - 83898*x^4 + 380644*x^5 - 
           825210*x^6 + 1763620*x^7 - 2333430*x^8 + 2874940*x^9 - 
           2333430*x^10 + 1763620*x^11 - 825210*x^12 + 380644*x^13 - 
           83898*x^14 + 21796*x^15 - 711*x^16 + 70*x^17 + 9*x^18)/
         (360*(-1 + x^2)^16) + (14*x^3*(2 - 9*x + 56*x^2 - 144*x^3 + 
           392*x^4 - 630*x^5 + 980*x^6 - 1008*x^7 + 980*x^8 - 630*x^9 + 
           392*x^10 - 144*x^11 + 56*x^12 - 9*x^13 + 2*x^14)*HPL[{0}, x])/
         (-1 + x^2)^17) + ((27 + 210*x - 482*x^2 + 10290*x^3 - 25242*x^4 + 
         92610*x^5 - 147378*x^6 + 257250*x^7 - 254450*x^8 + 257250*x^9 - 
         147378*x^10 + 92610*x^11 - 25242*x^12 + 10290*x^13 - 482*x^14 + 
         210*x^15 + 27*x^16)*HPL[{-1, 0}, x])/(5670*(-1 + x^2)^15) - 
      (x^3*(45360 - 204120*x + 2245320*x^2 - 6970320*x^3 + 29695680*x^4 - 
         61668180*x^5 + 141666840*x^6 - 197215452*x^7 + 278011440*x^8 - 
         257027652*x^9 + 234770760*x^10 - 138713100*x^11 + 83049120*x^12 - 
         28476045*x^13 + 10880730*x^14 - 1656675*x^15 + 372540*x^16 - 
         563*x^17 + 210*x^18 + 27*x^19)*HPL[{0, 0}, x])/
       (2835*(-1 + x^2)^18) - ((27 + 210*x - 482*x^2 + 10290*x^3 - 
         25242*x^4 + 92610*x^5 - 147378*x^6 + 257250*x^7 - 254450*x^8 + 
         257250*x^9 - 147378*x^10 + 92610*x^11 - 25242*x^12 + 10290*x^13 - 
         482*x^14 + 210*x^15 + 27*x^16)*HPL[{1, 0}, x])/(5670*(-1 + x^2)^15))
 
CbarData["v", 1, 8] = 
    CF*NC*(-(19978295 + 106458666*x - 1202188214*x^2 + 61750661238*x^3 - 
         247622461713*x^4 + 1370635589520*x^5 - 3281192772992*x^6 + 
         8558244275952*x^7 - 13213347969766*x^8 + 20354712918624*x^9 - 
         20625533267220*x^10 + 20354712918624*x^11 - 13213347969766*x^12 + 
         8558244275952*x^13 - 3281192772992*x^14 + 1370635589520*x^15 - 
         247622461713*x^16 + 61750661238*x^17 - 1202188214*x^18 + 
         106458666*x^19 + 19978295*x^20 + 58800*Pi^2*(-5 - 44*x + 106*x^2 - 
           2772*x^3 + 7587*x^4 - 31680*x^5 + 56208*x^6 - 103488*x^7 + 
           104664*x^8 - 77616*x^9 + 77616*x^11 - 104664*x^12 + 103488*x^13 - 
           56208*x^14 + 31680*x^15 - 7587*x^16 + 2772*x^17 - 106*x^18 + 
           44*x^19 + 5*x^20))/(1047816000*(-1 + x^2)^18) + 
      (x^2*(210 + 2821728*x - 13145976*x^2 + 109809471*x^3 - 323122610*x^4 + 
         1169546426*x^5 - 2290024528*x^6 + 4765789042*x^7 - 6335944176*x^8 + 
         8416225146*x^9 - 7558396176*x^10 + 6682593778*x^11 - 
         3915636208*x^12 + 2315956922*x^13 - 812352890*x^14 + 
         311759967*x^15 - 52282656*x^16 + 11896464*x^17 - 249270*x^18 + 
         22176*x^19 + 2520*x^20)*HPL[{0}, x])/(62370*(-1 + x^2)^19) + 
      lm*((-2*(35 + 308*x - 3430*x^2 + 126346*x^3 - 546995*x^4 + 
           2931214*x^5 - 7341860*x^6 + 18853582*x^7 - 29919800*x^8 + 
           45475870*x^9 - 46898300*x^10 + 45475870*x^11 - 29919800*x^12 + 
           18853582*x^13 - 7341860*x^14 + 2931214*x^15 - 546995*x^16 + 
           126346*x^17 - 3430*x^18 + 308*x^19 + 35*x^20))/
         (3465*(-1 + x^2)^18) + (32*x^3*(1 - 5*x + 36*x^2 - 105*x^3 + 
           336*x^4 - 630*x^5 + 1176*x^6 - 1470*x^7 + 1764*x^8 - 1470*x^9 + 
           1176*x^10 - 630*x^11 + 336*x^12 - 105*x^13 + 36*x^14 - 5*x^15 + 
           x^16)*HPL[{0}, x])/(-1 + x^2)^19) + 
      ((5 + 44*x - 101*x^2 + 2816*x^3 - 7688*x^4 + 34496*x^5 - 63896*x^6 + 
         137984*x^7 - 168560*x^8 + 215600*x^9 - 168560*x^10 + 137984*x^11 - 
         63896*x^12 + 34496*x^13 - 7688*x^14 + 2816*x^15 - 101*x^16 + 
         44*x^17 + 5*x^18)*HPL[{-1, 0}, x])/(1485*(-1 + x^2)^17) - 
      (2*x^3*(11880 - 59400*x + 742500*x^2 - 2574000*x^3 + 12602700*x^4 - 
         29721780*x^5 + 79718760*x^6 - 129484080*x^7 + 217493496*x^8 - 
         244299264*x^9 + 273247656*x^10 - 209164560*x^11 + 159454680*x^12 - 
         79617615*x^13 + 41157600*x^14 - 12119140*x^15 + 4095080*x^16 - 
         541970*x^17 + 109604*x^18 - 116*x^19 + 44*x^20 + 5*x^21)*
        HPL[{0, 0}, x])/(1485*(-1 + x^2)^20) - 
      ((5 + 44*x - 101*x^2 + 2816*x^3 - 7688*x^4 + 34496*x^5 - 63896*x^6 + 
         137984*x^7 - 168560*x^8 + 215600*x^9 - 168560*x^10 + 137984*x^11 - 
         63896*x^12 + 34496*x^13 - 7688*x^14 + 2816*x^15 - 101*x^16 + 
         44*x^17 + 5*x^18)*HPL[{1, 0}, x])/(1485*(-1 + x^2)^17))
 
CbarData["v", 1, 9] = 
    CF*NC*(-(304927709 + 1941296292*x - 23403488661*x^2 + 1363066804800*x^3 - 
         6084175765955*x^4 + 38821309936380*x^5 - 105289881375525*x^6 + 
         321065661841920*x^7 - 575954268655320*x^8 + 1056250581775200*x^9 - 
         1290950998018248*x^10 + 1554142929042816*x^11 - 
         1290950998018248*x^12 + 1056250581775200*x^13 - 
         575954268655320*x^14 + 321065661841920*x^15 - 105289881375525*x^16 + 
         38821309936380*x^17 - 6084175765955*x^18 + 1363066804800*x^19 - 
         23403488661*x^20 + 1941296292*x^21 + 304927709*x^22 + 
         352800*Pi^2*(-11 - 108*x + 259*x^2 - 8640*x^3 + 26005*x^4 - 
           131220*x^5 + 268275*x^6 - 622080*x^7 + 805620*x^8 - 952560*x^9 + 
           579180*x^10 - 579180*x^12 + 952560*x^13 - 805620*x^14 + 
           622080*x^15 - 268275*x^16 + 131220*x^17 - 26005*x^18 + 8640*x^19 - 
           259*x^20 + 108*x^21 + 11*x^22))/(18860688000*(-1 + x^2)^20) + 
      (x^2*(1848 + 37855944*x - 194355030*x^2 + 1826173512*x^3 - 
         5972994772*x^4 + 24660507024*x^5 - 54629701971*x^6 + 
         131774311188*x^7 - 203480851350*x^8 + 319587253812*x^9 - 
         346393739110*x^10 + 371869080948*x^11 - 279117598998*x^12 + 
         208240929108*x^13 - 103940297151*x^14 + 53430754464*x^15 - 
         16202102452*x^16 + 5520366432*x^17 - 808877730*x^18 + 
         166053024*x^19 - 2991912*x^20 + 244944*x^21 + 24948*x^22)*
        HPL[{0}, x])/(748440*(-1 + x^2)^21) + 
      lm*(-(77 + 756*x - 9163*x^2 + 396426*x^3 - 1905838*x^4 + 11798256*x^5 - 
           33477158*x^6 + 100595316*x^7 - 185670353*x^8 + 336603396*x^9 - 
           419117105*x^10 + 497967060*x^11 - 419117105*x^12 + 
           336603396*x^13 - 185670353*x^14 + 100595316*x^15 - 33477158*x^16 + 
           11798256*x^17 - 1905838*x^18 + 396426*x^19 - 9163*x^20 + 
           756*x^21 + 77*x^22)/(4620*(-1 + x^2)^20) + 
        (6*x^3*(6 - 33*x + 270*x^2 - 880*x^3 + 3240*x^4 - 6930*x^5 + 
           15120*x^6 - 22176*x^7 + 31752*x^8 - 32340*x^9 + 31752*x^10 - 
           22176*x^11 + 15120*x^12 - 6930*x^13 + 3240*x^14 - 880*x^15 + 
           270*x^16 - 33*x^17 + 6*x^18)*HPL[{0}, x])/(-1 + x^2)^21) + 
      ((11 + 108*x - 248*x^2 + 8748*x^3 - 26253*x^4 + 139968*x^5 - 
         294528*x^6 + 762048*x^7 - 1100148*x^8 + 1714608*x^9 - 1679328*x^10 + 
         1714608*x^11 - 1100148*x^12 + 762048*x^13 - 294528*x^14 + 
         139968*x^15 - 26253*x^16 + 8748*x^17 - 248*x^18 + 108*x^19 + 
         11*x^20)*HPL[{-1, 0}, x])/(4455*(-1 + x^2)^19) - 
      (2*x^3*(35640 - 196020*x + 2744280*x^2 - 10505220*x^3 + 58152600*x^4 - 
         153387465*x^5 + 471036060*x^6 - 872756181*x^7 + 1704903552*x^8 - 
         2246471964*x^9 + 2981751696*x^10 - 2788907484*x^11 + 
         2592767232*x^12 - 1687043556*x^13 + 1105980480*x^14 - 
         477115540*x^15 + 217297080*x^16 - 56002364*x^17 + 16971768*x^18 - 
         1985676*x^19 + 364824*x^20 - 281*x^21 + 108*x^22 + 11*x^23)*
        HPL[{0, 0}, x])/(4455*(-1 + x^2)^22) - 
      ((11 + 108*x - 248*x^2 + 8748*x^3 - 26253*x^4 + 139968*x^5 - 
         294528*x^6 + 762048*x^7 - 1100148*x^8 + 1714608*x^9 - 1679328*x^10 + 
         1714608*x^11 - 1100148*x^12 + 762048*x^13 - 294528*x^14 + 
         139968*x^15 - 26253*x^16 + 8748*x^17 - 248*x^18 + 108*x^19 + 
         11*x^20)*HPL[{1, 0}, x])/(4455*(-1 + x^2)^19))
 
 
CbarLData["v", 1, -1] = (5*CF*NC*(-1 + x)^2)/(12*ep) - 
     (CF*NC*(1 - 2*x + x^2))/(2*ep^2) + CF*NC*((lm^2*(-1 + x)^2)/2 + 
       (39 - 198*x + 39*x^2 + 4*Pi^2*(-1 + x^2))/72 - 
       (2*x^2*(1 - 5*x + x^2)*HPL[{0}, x])/(3*(-1 + x^2)) + 
       lm*((1 - 5*x + x^2)/3 - (2*(-2 + x)*x^3*HPL[{0}, x])/(-1 + x^2)) - 
       (2*(-1 + x^2)*HPL[{-1, 0}, x])/3 + (8*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
         HPL[{0, 0}, x])/(3*(-1 + x^2)^2) + (2*(-1 + x^2)*HPL[{1, 0}, x])/3)
 
CbarLData["v", 1, 0] = CF*NC*((3*(1 - 36*x - 22*x^2 - 36*x^3 + x^4) - 
        4*Pi^2*(-1 + 3*x - 3*x^3 + x^4))/(108*(-1 + x^2)^2) + 
      (4*x^2*(1 - 6*x + x^2)*HPL[{0}, x])/(9*(-1 + x^2)^3) + 
      (4*(1 - 3*x + x^2)*HPL[{-1, 0}, x])/(9*(-1 + x^2)) - 
      (8*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0}, x])/
       (9*(-1 + x^2)^4) - (4*(1 - 3*x + x^2)*HPL[{1, 0}, x])/(9*(-1 + x^2)))
 
CbarLData["v", 1, 1] = CF*NC*((-4*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 
        3*(3 - 72*x - 127*x^2 - 112*x^3 - 127*x^4 - 72*x^5 + 3*x^6))/
       (432*(-1 + x^2)^4) + (x^2*(2 - 122*x - 27*x^2 - 230*x^3 - 22*x^4 - 
         12*x^5 + 3*x^6)*HPL[{0}, x])/(18*(-1 + x^2)^5) + 
      lm*((-1 + 4*x + 7*x^2 + 40*x^3 + 7*x^4 + 4*x^5 - x^6)/
         (12*(-1 + x^2)^4) - (2*x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
         (-1 + x^2)^5) + ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0}, x])/
       (9*(-1 + x^2)^3) + (2*x^3*(72 + 36*x + 216*x^2 + 68*x^3 + 136*x^4 + 
         3*x^5 + 4*x^6 - x^7)*HPL[{0, 0}, x])/(9*(-1 + x^2)^6) - 
      ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/(9*(-1 + x^2)^3))
 
CbarLData["v", 1, 2] = 
    CF*NC*(-(11 + 219*x + 658*x^2 - 1479*x^3 + 1326*x^4 - 1479*x^5 + 
         658*x^6 + 219*x^7 + 11*x^8 + 4*Pi^2*(-1 + 5*x + 2*x^2 + 15*x^3 - 
           15*x^5 - 2*x^6 - 5*x^7 + x^8))/(1080*(-1 + x^2)^6) + 
      (2*x^2*(1 - 263*x - 184*x^2 - 1109*x^3 - 424*x^4 - 683*x^5 - 44*x^6 - 
         15*x^7 + 3*x^8)*HPL[{0}, x])/(45*(-1 + x^2)^7) + 
      lm*((-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 5*x^7 - 
          x^8)/(15*(-1 + x^2)^6) - (8*x^3*(1 + x + 3*x^2 + x^3 + x^4)*
          HPL[{0}, x])/(-1 + x^2)^7) + 
      (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*HPL[{-1, 0}, x])/
       (45*(-1 + x^2)^5) + (4*x^3*(180 + 180*x + 1260*x^2 + 800*x^3 + 
         1940*x^4 + 535*x^5 + 545*x^6 + 4*x^7 + 5*x^8 - x^9)*HPL[{0, 0}, x])/
       (45*(-1 + x^2)^8) + (2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*
        HPL[{1, 0}, x])/(45*(-1 + x^2)^5))
 
CbarLData["v", 1, 3] = 
    CF*NC*(-(61 + 201*x + 978*x^2 - 19344*x^3 - 7591*x^4 - 51570*x^5 - 
         7591*x^6 - 19344*x^7 + 978*x^8 + 201*x^9 + 61*x^10 + 
         6*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 16*x^4 - 16*x^6 - 48*x^7 - 
           3*x^8 - 6*x^9 + x^10))/(3240*(-1 + x^2)^8) + 
      (x^2*(2 - 1512*x - 1780*x^2 - 11358*x^3 - 7758*x^4 - 16758*x^5 - 
         5155*x^6 - 4662*x^7 - 214*x^8 - 54*x^9 + 9*x^10)*HPL[{0}, x])/
       (90*(-1 + x^2)^9) + lm*((-1 + 6*x + 23*x^2 + 356*x^3 + 398*x^4 + 
          956*x^5 + 398*x^6 + 356*x^7 + 23*x^8 + 6*x^9 - x^10)/
         (20*(-1 + x^2)^8) - (6*x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 
           3*x^5 + 2*x^6)*HPL[{0}, x])/(-1 + x^2)^9) - 
      ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^8)*
        HPL[{-1, 0}, x])/(45*(-1 + x^2)^7) + 
      (2*x^3*(360 + 540*x + 4500*x^2 + 4400*x^3 + 13200*x^4 + 7055*x^5 + 
         9810*x^6 + 2169*x^7 + 1476*x^8 + 5*x^9 + 6*x^10 - x^11)*
        HPL[{0, 0}, x])/(45*(-1 + x^2)^10) + 
      ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^8)*
        HPL[{1, 0}, x])/(45*(-1 + x^2)^7))
 
CbarLData["v", 1, 4] = CF*NC*((-4519 + 2230*x - 7106*x^2 + 2867370*x^3 + 
        2876915*x^4 + 14316800*x^5 + 7125020*x^6 + 14316800*x^7 + 
        2876915*x^8 + 2867370*x^9 - 7106*x^10 + 2230*x^11 - 4519*x^12 - 
        240*Pi^2*(-1 + 7*x + 4*x^2 + 105*x^3 + 65*x^4 + 140*x^5 - 140*x^7 - 
          65*x^8 - 105*x^9 - 4*x^10 - 7*x^11 + x^12))/
       (226800*(-1 + x^2)^10) + (x^2*(4 - 6928*x - 11460*x^2 - 81817*x^3 - 
         81218*x^4 - 217254*x^5 - 119018*x^6 - 153217*x^7 - 37836*x^8 - 
         23896*x^9 - 836*x^10 - 168*x^11 + 24*x^12)*HPL[{0}, x])/
       (315*(-1 + x^2)^11) + 
      lm*((4*(-1 + 7*x + 34*x^2 + 714*x^3 + 1133*x^4 + 3689*x^5 + 2708*x^6 + 
           3689*x^7 + 1133*x^8 + 714*x^9 + 34*x^10 + 7*x^11 - x^12))/
         (105*(-1 + x^2)^10) - (16*x^3*(1 + 2*x + 10*x^2 + 10*x^3 + 20*x^4 + 
           10*x^5 + 10*x^6 + 2*x^7 + x^8)*HPL[{0}, x])/(-1 + x^2)^11) + 
      (4*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 112*x^7 - 
         3*x^8 - 7*x^9 + x^10)*HPL[{-1, 0}, x])/(315*(-1 + x^2)^9) + 
      (8*x^3*(630 + 1260*x + 12285*x^2 + 16310*x^3 + 58975*x^4 + 47040*x^5 + 
         83860*x^6 + 36344*x^7 + 34902*x^8 + 6356*x^9 + 3241*x^10 + 6*x^11 + 
         7*x^12 - x^13)*HPL[{0, 0}, x])/(315*(-1 + x^2)^12) + 
      (4*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 252*x^5 + 68*x^6 + 112*x^7 + 
         3*x^8 + 7*x^9 - x^10)*HPL[{1, 0}, x])/(315*(-1 + x^2)^9))
 
CbarLData["v", 1, 5] = CF*NC*((-33887 + 88456*x + 357835*x^2 + 38148864*x^3 + 
        58045437*x^4 + 308482680*x^5 + 254107015*x^6 + 581132800*x^7 + 
        254107015*x^8 + 308482680*x^9 + 58045437*x^10 + 38148864*x^11 + 
        357835*x^12 + 88456*x^13 - 33887*x^14 - 
        1200*Pi^2*(-1 + 8*x + 5*x^2 + 192*x^3 + 171*x^4 + 600*x^5 + 225*x^6 - 
          225*x^8 - 600*x^9 - 171*x^10 - 192*x^11 - 5*x^12 - 8*x^13 + x^14))/
       (1814400*(-1 + x^2)^12) + (x^2*(10 - 34310*x - 73129*x^2 - 
         587186*x^3 - 767766*x^4 - 2446244*x^5 - 1929345*x^6 - 3181244*x^7 - 
         1414566*x^8 - 1292786*x^9 - 264229*x^10 - 128390*x^11 - 3590*x^12 - 
         600*x^13 + 75*x^14)*HPL[{0}, x])/(1260*(-1 + x^2)^13) + 
      lm*((-5 + 40*x + 235*x^2 + 6312*x^3 + 12975*x^4 + 53352*x^5 + 
          56095*x^6 + 102352*x^7 + 56095*x^8 + 53352*x^9 + 12975*x^10 + 
          6312*x^11 + 235*x^12 + 40*x^13 - 5*x^14)/(168*(-1 + x^2)^12) - 
        (10*x^3*(2 + 5*x + 30*x^2 + 40*x^3 + 100*x^4 + 75*x^5 + 100*x^6 + 
           40*x^7 + 30*x^8 + 5*x^9 + 2*x^10)*HPL[{0}, x])/(-1 + x^2)^13) - 
      ((-1 + 8*x + 4*x^2 + 200*x^3 + 175*x^4 + 800*x^5 + 400*x^6 + 800*x^7 + 
         175*x^8 + 200*x^9 + 4*x^10 + 8*x^11 - x^12)*HPL[{-1, 0}, x])/
       (126*(-1 + x^2)^11) + (x^3*(1008 + 2520*x + 28224*x^2 + 47432*x^3 + 
         201488*x^4 + 214228*x^5 + 467264*x^6 + 301924*x^7 + 376880*x^8 + 
         135520*x^9 + 99008*x^10 + 15280*x^11 + 6224*x^12 + 7*x^13 + 8*x^14 - 
         x^15)*HPL[{0, 0}, x])/(63*(-1 + x^2)^14) + 
      ((-1 + 8*x + 4*x^2 + 200*x^3 + 175*x^4 + 800*x^5 + 400*x^6 + 800*x^7 + 
         175*x^8 + 200*x^9 + 4*x^10 + 8*x^11 - x^12)*HPL[{1, 0}, x])/
       (126*(-1 + x^2)^11))
 
CbarLData["v", 1, 6] = CF*NC*((-106795 + 447867*x + 2475714*x^2 + 
        195845265*x^3 + 393705676*x^4 + 2342972583*x^5 + 2676880150*x^6 + 
        7136097885*x^7 + 4801356910*x^8 + 7136097885*x^9 + 2676880150*x^10 + 
        2342972583*x^11 + 393705676*x^12 + 195845265*x^13 + 2475714*x^14 + 
        447867*x^15 - 106795*x^16 - 2800*Pi^2*(-1 + 9*x + 6*x^2 + 315*x^3 + 
          364*x^4 + 1701*x^5 + 1106*x^6 + 1575*x^7 - 1575*x^9 - 1106*x^10 - 
          1701*x^11 - 364*x^12 - 315*x^13 - 6*x^14 - 9*x^15 + x^16))/
       (6350400*(-1 + x^2)^14) + (x^2*(15 - 92115*x - 240375*x^2 - 
         2157813*x^3 - 3507887*x^4 - 12971727*x^5 - 13369639*x^6 - 
         26775333*x^7 - 17179879*x^8 - 20354067*x^9 - 7556267*x^10 - 
         5348889*x^11 - 929523*x^12 - 367191*x^13 - 8490*x^14 - 1215*x^15 + 
         135*x^16)*HPL[{0}, x])/(2835*(-1 + x^2)^15) + 
      lm*((-5 + 45*x + 310*x^2 + 10233*x^3 + 25834*x^4 + 128421*x^5 + 
          175774*x^6 + 401841*x^7 + 316894*x^8 + 401841*x^9 + 175774*x^10 + 
          128421*x^11 + 25834*x^12 + 10233*x^13 + 310*x^14 + 45*x^15 - 
          5*x^16)/(210*(-1 + x^2)^14) - (24*x^3*(1 + 3*x + 21*x^2 + 35*x^3 + 
           105*x^4 + 105*x^5 + 175*x^6 + 105*x^7 + 105*x^8 + 35*x^9 + 
           21*x^10 + 3*x^11 + x^12)*HPL[{0}, x])/(-1 + x^2)^15) - 
      ((-1 + 9*x + 5*x^2 + 324*x^3 + 369*x^4 + 2025*x^5 + 1475*x^6 + 
         3600*x^7 + 1475*x^8 + 2025*x^9 + 369*x^10 + 324*x^11 + 5*x^12 + 
         9*x^13 - x^14)*HPL[{-1, 0}, x])/(189*(-1 + x^2)^13) + 
      (2*x^3*(1512 + 4536*x + 57456*x^2 + 116928*x^3 + 571536*x^4 + 
         760284*x^5 + 1963332*x^6 + 1687392*x^7 + 2595348*x^8 + 1393476*x^9 + 
         1332072*x^10 + 407616*x^11 + 239976*x^12 + 32103*x^13 + 10881*x^14 + 
         8*x^15 + 9*x^16 - x^17)*HPL[{0, 0}, x])/(189*(-1 + x^2)^16) + 
      ((-1 + 9*x + 5*x^2 + 324*x^3 + 369*x^4 + 2025*x^5 + 1475*x^6 + 
         3600*x^7 + 1475*x^8 + 2025*x^9 + 369*x^10 + 324*x^11 + 5*x^12 + 
         9*x^13 - x^14)*HPL[{1, 0}, x])/(189*(-1 + x^2)^13))
 
CbarLData["v", 1, 7] = CF*NC*((-948403 + 5256730*x + 35145481*x^2 + 
        2659091040*x^3 + 6611849840*x^4 + 44230292960*x^5 + 64503115824*x^6 + 
        198683465120*x^7 + 180536005258*x^8 + 320641292300*x^9 + 
        180536005258*x^10 + 198683465120*x^11 + 64503115824*x^12 + 
        44230292960*x^13 + 6611849840*x^14 + 2659091040*x^15 + 
        35145481*x^16 + 5256730*x^17 - 948403*x^18 - 
        19600*Pi^2*(-1 + 10*x + 7*x^2 + 480*x^3 + 680*x^4 + 3920*x^5 + 
          3528*x^6 + 7840*x^7 + 3136*x^8 - 3136*x^10 - 7840*x^11 - 
          3528*x^12 - 3920*x^13 - 680*x^14 - 480*x^15 - 7*x^16 - 10*x^17 + 
          x^18))/(63504000*(-1 + x^2)^16) + 
      (x^2*(42 - 428316*x - 1322892*x^2 - 13167258*x^3 - 25623722*x^4 - 
         107884186*x^5 - 137408132*x^6 - 323292470*x^7 - 271097002*x^8 - 
         393305630*x^9 - 211310912*x^10 - 195011674*x^11 - 61948010*x^12 - 
         35774682*x^13 - 5399055*x^14 - 1797054*x^15 - 35238*x^16 - 
         4410*x^17 + 441*x^18)*HPL[{0}, x])/(11340*(-1 + x^2)^17) + 
      lm*((-7 + 70*x + 553*x^2 + 21796*x^3 + 65254*x^4 + 380644*x^5 + 
          641830*x^6 + 1763620*x^7 + 1814890*x^8 + 2874940*x^9 + 
          1814890*x^10 + 1763620*x^11 + 641830*x^12 + 380644*x^13 + 
          65254*x^14 + 21796*x^15 + 553*x^16 + 70*x^17 - 7*x^18)/
         (360*(-1 + x^2)^16) - (14*x^3*(2 + 7*x + 56*x^2 + 112*x^3 + 
           392*x^4 + 490*x^5 + 980*x^6 + 784*x^7 + 980*x^8 + 490*x^9 + 
           392*x^10 + 112*x^11 + 56*x^12 + 7*x^13 + 2*x^14)*HPL[{0}, x])/
         (-1 + x^2)^17) - ((-1 + 10*x + 6*x^2 + 490*x^3 + 686*x^4 + 
         4410*x^5 + 4214*x^6 + 12250*x^7 + 7350*x^8 + 12250*x^9 + 4214*x^10 + 
         4410*x^11 + 686*x^12 + 490*x^13 + 6*x^14 + 10*x^15 - x^16)*
        HPL[{-1, 0}, x])/(270*(-1 + x^2)^15) + 
      (x^3*(2160 + 7560*x + 106920*x^2 + 255600*x^3 + 1414080*x^4 + 
         2259900*x^5 + 6746040*x^6 + 7239636*x^7 + 13238640*x^8 + 
         9456396*x^9 + 11179560*x^10 + 5114340*x^11 + 3954720*x^12 + 
         1051575*x^13 + 518130*x^14 + 61145*x^15 + 17740*x^16 + 9*x^17 + 
         10*x^18 - x^19)*HPL[{0, 0}, x])/(135*(-1 + x^2)^18) + 
      ((-1 + 10*x + 6*x^2 + 490*x^3 + 686*x^4 + 4410*x^5 + 4214*x^6 + 
         12250*x^7 + 7350*x^8 + 12250*x^9 + 4214*x^10 + 4410*x^11 + 
         686*x^12 + 490*x^13 + 6*x^14 + 10*x^15 - x^16)*HPL[{1, 0}, x])/
       (270*(-1 + x^2)^15))
 
CbarLData["v", 1, 8] = CF*NC*((-6925253 + 46878933*x + 363460124*x^2 + 
        28270305819*x^3 + 83584045413*x^4 + 624881491560*x^5 + 
        1107817911192*x^6 + 3890395556376*x^7 + 4453872501456*x^8 + 
        9239726703312*x^9 + 6947690102136*x^10 + 9239726703312*x^11 + 
        4453872501456*x^12 + 3890395556376*x^13 + 1107817911192*x^14 + 
        624881491560*x^15 + 83584045413*x^16 + 28270305819*x^17 + 
        363460124*x^18 + 46878933*x^19 - 6925253*x^20 - 
        117600*Pi^2*(-1 + 11*x + 8*x^2 + 693*x^3 + 1161*x^4 + 7920*x^5 + 
          9024*x^6 + 25872*x^7 + 17052*x^8 + 19404*x^9 - 19404*x^11 - 
          17052*x^12 - 25872*x^13 - 9024*x^14 - 7920*x^15 - 1161*x^16 - 
          693*x^17 - 8*x^18 - 11*x^19 + x^20))/(523908000*(-1 + x^2)^18) + 
      (x^2*(168 - 2685648*x - 9584214*x^2 - 104910591*x^3 - 237933368*x^4 - 
         1123823546*x^5 - 1705383141*x^6 - 4605758962*x^7 - 4769843125*x^8 - 
         8176180026*x^9 - 5747804725*x^10 - 6522563698*x^11 - 
         3005872485*x^12 - 2270234042*x^13 - 629317592*x^14 - 
         306861087*x^15 - 40893558*x^16 - 11760384*x^17 - 199416*x^18 - 
         22176*x^19 + 2016*x^20)*HPL[{0}, x])/(62370*(-1 + x^2)^19) + 
      lm*((4*(-14 + 154*x + 1372*x^2 + 63173*x^3 + 218798*x^4 + 1465607*x^5 + 
           2936744*x^6 + 9426791*x^7 + 11967920*x^8 + 22737935*x^9 + 
           18759320*x^10 + 22737935*x^11 + 11967920*x^12 + 9426791*x^13 + 
           2936744*x^14 + 1465607*x^15 + 218798*x^16 + 63173*x^17 + 
           1372*x^18 + 154*x^19 - 14*x^20))/(3465*(-1 + x^2)^18) - 
        (32*x^3*(1 + 4*x + 36*x^2 + 84*x^3 + 336*x^4 + 504*x^5 + 1176*x^6 + 
           1176*x^7 + 1764*x^8 + 1176*x^9 + 1176*x^10 + 504*x^11 + 336*x^12 + 
           84*x^13 + 36*x^14 + 4*x^15 + x^16)*HPL[{0}, x])/(-1 + x^2)^19) + 
      (4*(1 - 11*x - 7*x^2 - 704*x^3 - 1168*x^4 - 8624*x^5 - 10192*x^6 - 
         34496*x^7 - 27244*x^8 - 53900*x^9 - 27244*x^10 - 34496*x^11 - 
         10192*x^12 - 8624*x^13 - 1168*x^14 - 704*x^15 - 7*x^16 - 11*x^17 + 
         x^18)*HPL[{-1, 0}, x])/(1485*(-1 + x^2)^17) + 
      (8*x^3*(2970 + 11880*x + 185625*x^2 + 509850*x^3 + 3150675*x^4 + 
         5881095*x^5 + 19929690*x^6 + 25653276*x^7 + 54373374*x^8 + 
         48489540*x^9 + 68311914*x^10 + 41594916*x^11 + 39863670*x^12 + 
         15860460*x^13 + 10289400*x^14 + 2417360*x^15 + 1023770*x^16 + 
         108064*x^17 + 27401*x^18 + 10*x^19 + 11*x^20 - x^21)*HPL[{0, 0}, x])/
       (1485*(-1 + x^2)^20) + (4*(-1 + 11*x + 7*x^2 + 704*x^3 + 1168*x^4 + 
         8624*x^5 + 10192*x^6 + 34496*x^7 + 27244*x^8 + 53900*x^9 + 
         27244*x^10 + 34496*x^11 + 10192*x^12 + 8624*x^13 + 1168*x^14 + 
         704*x^15 + 7*x^16 + 11*x^17 - x^18)*HPL[{1, 0}, x])/
       (1485*(-1 + x^2)^17))
 
CbarLData["v", 1, 9] = CF*NC*((-73645157 + 583594764*x + 5125791933*x^2 + 
        421055817600*x^3 + 1441475870555*x^4 + 11949383141460*x^5 + 
        24935254284525*x^6 + 98571880736640*x^7 + 136160587053720*x^8 + 
        323808841994400*x^9 + 304877203292424*x^10 + 476218409974272*x^11 + 
        304877203292424*x^12 + 323808841994400*x^13 + 136160587053720*x^14 + 
        98571880736640*x^15 + 24935254284525*x^16 + 11949383141460*x^17 + 
        1441475870555*x^18 + 421055817600*x^19 + 5125791933*x^20 + 
        583594764*x^21 - 73645157*x^22 - 1058400*Pi^2*(-1 + 12*x + 9*x^2 + 
          960*x^3 + 1855*x^4 + 14580*x^5 + 20025*x^6 + 69120*x^7 + 
          61020*x^8 + 105840*x^9 + 44100*x^10 - 44100*x^12 - 105840*x^13 - 
          61020*x^14 - 69120*x^15 - 20025*x^16 - 14580*x^17 - 1855*x^18 - 
          960*x^19 - 9*x^20 - 12*x^21 + x^22))/(6286896000*(-1 + x^2)^20) + 
      (x^2*(56 - 1340472*x - 5428566*x^2 - 64864056*x^3 - 168070068*x^4 - 
         880088112*x^5 - 1550693875*x^6 - 4725298044*x^7 - 5825879830*x^8 - 
         11510577756*x^9 - 9998343654*x^10 - 13446941724*x^11 - 
         8117902486*x^12 - 7557395004*x^13 - 3044954335*x^14 - 
         1945652832*x^15 - 478043028*x^16 - 201686016*x^17 - 24050466*x^18 - 
         6088512*x^19 - 90664*x^20 - 9072*x^21 + 756*x^22)*HPL[{0}, x])/
       (27720*(-1 + x^2)^21) + lm*((-21 + 252*x + 2499*x^2 + 132142*x^3 + 
          519774*x^4 + 3932752*x^5 + 9130134*x^6 + 33531772*x^7 + 
          50637369*x^8 + 112201132*x^9 + 114304665*x^10 + 165989020*x^11 + 
          114304665*x^12 + 112201132*x^13 + 50637369*x^14 + 33531772*x^15 + 
          9130134*x^16 + 3932752*x^17 + 519774*x^18 + 132142*x^19 + 
          2499*x^20 + 252*x^21 - 21*x^22)/(1540*(-1 + x^2)^20) - 
        (18*x^3*(2 + 9*x + 90*x^2 + 240*x^3 + 1080*x^4 + 1890*x^5 + 
           5040*x^6 + 6048*x^7 + 10584*x^8 + 8820*x^9 + 10584*x^10 + 
           6048*x^11 + 5040*x^12 + 1890*x^13 + 1080*x^14 + 240*x^15 + 
           90*x^16 + 9*x^17 + 2*x^18)*HPL[{0}, x])/(-1 + x^2)^21) - 
      ((-1 + 12*x + 8*x^2 + 972*x^3 + 1863*x^4 + 15552*x^5 + 21888*x^6 + 
         84672*x^7 + 82908*x^8 + 190512*x^9 + 127008*x^10 + 190512*x^11 + 
         82908*x^12 + 84672*x^13 + 21888*x^14 + 15552*x^15 + 1863*x^16 + 
         972*x^17 + 8*x^18 + 12*x^19 - x^20)*HPL[{-1, 0}, x])/
       (495*(-1 + x^2)^19) + (2*x^3*(3960 + 17820*x + 304920*x^2 + 
         946220*x^3 + 6461400*x^4 + 13798235*x^5 + 52337340*x^6 + 
         78581151*x^7 + 189433728*x^8 + 202573844*x^9 + 331305744*x^10 + 
         251899604*x^11 + 288085248*x^12 + 152618796*x^13 + 122886720*x^14 + 
         43224060*x^15 + 24144120*x^16 + 5078964*x^17 + 1885752*x^18 + 
         180036*x^19 + 40536*x^20 + 11*x^21 + 12*x^22 - x^23)*HPL[{0, 0}, x])/
       (495*(-1 + x^2)^22) + ((-1 + 12*x + 8*x^2 + 972*x^3 + 1863*x^4 + 
         15552*x^5 + 21888*x^6 + 84672*x^7 + 82908*x^8 + 190512*x^9 + 
         127008*x^10 + 190512*x^11 + 82908*x^12 + 84672*x^13 + 21888*x^14 + 
         15552*x^15 + 1863*x^16 + 972*x^17 + 8*x^18 + 12*x^19 - x^20)*
        HPL[{1, 0}, x])/(495*(-1 + x^2)^19))
 

CbarData["v", 2, -1] = 
    NC*(CF^2*(-(lm^3*(-1 + x)^2)/4 - (Pi^2*(1 + x^2)*HPL[{-2}, x])/9 + 
        lm^2*((7 - 2*x + 7*x^2)/16 + (3*(-2 + x)*x^3*HPL[{0}, x])/
           (2*(-1 + x^2))) + (Pi^2*(1 + x^2)*HPL[{2}, x])/9 + 
        (x^2*(-6 - 12*x + 57*x^2 + 39*x^3 - 46*x^4 - 22*x^5 + 22*x^6 - x^7 - 
           5*x^8 + 2*x^9)*HPL[{-2, 0}, x])/(9*(-1 + x^2)^2) + 
        ((-12 + 30*x - 12*x^2 + (181 - 12*Pi^2)*x^3 + 6*x^4 - 554*x^5 + 
           6*x^6 + (181 + 12*Pi^2)*x^7 - 12*x^8 + 30*x^9 - 12*x^10)*
          HPL[{-1, 0}, x])/(108*x^3*(-1 + x^2)) + 
        (x^2*(384 + 747*x - 99*x^2 + 1746*x^3 - 3923*x^4 - 15*x^6 + 6*x^7)*
          HPL[{0, 0}, x])/(27*(-1 + x^2)^2) + 
        ((12 - 30*x + 12*x^2 + (-181 + 12*Pi^2)*x^3 - 6*x^4 + 554*x^5 - 
           6*x^6 - (181 + 12*Pi^2)*x^7 + 12*x^8 - 30*x^9 + 12*x^10)*
          HPL[{1, 0}, x])/(108*x^3*(-1 + x^2)) + 
        (x^2*(6 + 12*x - 57*x^2 - 39*x^3 + 46*x^4 + 22*x^5 - 22*x^6 + x^7 + 
           5*x^8 - 2*x^9)*HPL[{2, 0}, x])/(9*(-1 + x^2)^2) + 
        (4*(1 + x^2)*HPL[{-2, -1, 0}, x])/3 - 
        (8*(1 + x^2)*HPL[{-2, 0, 0}, x])/3 - (4*(1 + x^2)*HPL[{-2, 1, 0}, x])/
         3 - (4*(1 + x^2)*HPL[{-1, -2, 0}, x])/3 - 
        ((-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 11*x^6 + x^8 + 2*x^9)*
          HPL[{-1, -1, 0}, x])/(18*x^5) + 
        ((56 - 91*x + 51*x^2 - 39*x^3 + 69*x^4 - 39*x^5 + x^6 + 15*x^7 - 
           9*x^8 + 2*x^9)*HPL[{-1, 0, 0}, x])/(9*(-1 + x)^2) + 
        ((-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 11*x^6 + x^8 + 2*x^9)*
          HPL[{-1, 1, 0}, x])/(18*x^5) + (4*(1 + x^2)*HPL[{-1, 2, 0}, x])/3 - 
        (2*x^2*(3 + 366*x - 309*x^2 - 828*x^3 + 1415*x^4 + 652*x^5 - 
           1155*x^6 - 21*x^7 + 27*x^8 - 3*x^9 - 5*x^10 + 2*x^11)*
          HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
        (4*(1 + x^2)*HPL[{1, -2, 0}, x])/3 + 
        ((-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 11*x^6 + x^8 + 2*x^9)*
          HPL[{1, -1, 0}, x])/(18*x^5) + 
        ((-56 - 85*x - 39*x^2 + 3*x^3 + 3*x^4 - 9*x^5 - 13*x^6 + 5*x^7 + 
           x^8 - 2*x^9)*HPL[{1, 0, 0}, x])/(9*(1 + x)^2) - 
        ((-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 11*x^6 + x^8 + 2*x^9)*
          HPL[{1, 1, 0}, x])/(18*x^5) - (4*(1 + x^2)*HPL[{1, 2, 0}, x])/3 - 
        (4*(1 + x^2)*HPL[{2, -1, 0}, x])/3 + (8*(1 + x^2)*HPL[{2, 0, 0}, x])/
         3 + (4*(1 + x^2)*HPL[{2, 1, 0}, x])/3 - 
        (8*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/3 - 
        (8*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/3 + 
        ((-1 + x + (4*x)/(-1 + x^2))*master3l10a[x])/12 + 
        ((x - x^2 + 3*x^3 + x^4)*master3l10b[x])/(12 - 12*x^2) + 
        ((-11 - 6*x + x^2)*master3l8a[x])/(12*(-1 + x^2)^2) + 
        ((-5 - 18*x + 39*x^2)*master3l8b[x])/(36*(-1 + x^2)^2) + 
        ((-9 + x^2)*master3l9a[x])/(3*(-1 + x^2)^2) + 
        ((-1 + 9*x^2)*master3l9b[x])/(9*(-1 + x^2)^2) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 
             11*x^6 + x^8 + 2*x^9) - 288*x^5*(1 + x^2)*Zeta[3]))/(216*x^5) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 
              11*x^6 + x^8 + 2*x^9)) + 288*x^5*(1 + x^2)*Zeta[3]))/
         (216*x^5) + (HPL[{0}, x]*(24 - 60*x + 12*x^2 + 4*(-2947 + 6*Pi^2)*
            x^3 + 8*(-3 + 11*Pi^2)*x^8 - 88*Pi^2*x^9 + 4*Pi^2*x^10 + 
           20*Pi^2*x^11 - 8*Pi^2*x^12 + x^5*(12643 - 228*Pi^2 - 
             1728*Zeta[3]) + 6*x^4*(-2283 + 8*Pi^2 + 576*Zeta[3]) - 
           6*x^6*(1499 + 26*Pi^2 + 576*Zeta[3]) + x^7*(21885 + 184*Pi^2 + 
             1728*Zeta[3])))/(432*x*(-1 + x^2)^2) + 
        lm*((x^2*(4 + 2*x - 7*x^2)*HPL[{0}, x])/(4*(-1 + x^2)) + 
          (-1 + x^2)*HPL[{-1, 0}, x] - (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
            HPL[{0, 0}, x])/(-1 + x^2)^2 + (1 - x^2)*HPL[{1, 0}, x] + 
          (95 - 8*Pi^2*(-1 + x^2) + x^2*(95 - 144*Zeta[3]) - 144*Zeta[3] + 
            x*(-82 + 288*Zeta[3]))/96) + 
        (24*Pi^4*x^3*(-1 + x^2)^2*(39 - 88*x + 39*x^2) + 10*Pi^2*(-1 + x^2)*
           (12 - 30*x + 12*x^2 + 554*x^5 + 12*x^8 - 30*x^9 + 12*x^10 + 
            6*x^4*(-1 + 192*Log[2]^2) - 6*x^6*(1 + 192*Log[2]^2) + 
            x^7*(-181 + 576*Log[2]^2) - x^3*(181 + 576*Log[2]^2)) + 
          15*x^2*(-12 + 528*x^9*Zeta[3] - 24*x^10*Zeta[3] - 
            120*x^11*Zeta[3] + 48*x^12*Zeta[3] - 12*x^8*(1 + 44*Zeta[3]) + 
            3*x^2*(377 + 256*Log[2]^4 + 6144*PolyLog[4, 1/2] + 
              4072*Zeta[3]) - 6*x^4*(-2927 + 256*Log[2]^4 + 6144*PolyLog[4, 
                1/2] + 4192*Zeta[3]) + 3*x^6*(377 + 256*Log[2]^4 + 
              6144*PolyLog[4, 1/2] + 4384*Zeta[3]) + 
            x^3*(10405 + 384*Log[2]^4 + 9216*PolyLog[4, 1/2] + 
              6288*Zeta[3]) + x^5*(-17675 + 384*Log[2]^4 + 9216*PolyLog[4, 
                1/2] + 6504*Zeta[3]) - x*(-14255 + 384*Log[2]^4 + 
              9216*PolyLog[4, 1/2] + 9096*Zeta[3]) - 
            x^7*(6625 + 384*Log[2]^4 + 9216*PolyLog[4, 1/2] + 9768*Zeta[3])))/
         (12960*x^3*(-1 + x^2)^2)) + CA*CF*((-11*lm^3*(-1 + x)^2)/72 + 
        (Pi^2*(1 + x^2)*HPL[{-2}, x])/18 + 
        lm^2*((-119 + 304*x - 119*x^2)/144 + (11*(-2 + x)*x^3*HPL[{0}, x])/
           (12*(-1 + x^2))) - (Pi^2*(1 + x^2)*HPL[{2}, x])/18 + 
        (x^2*(6 + 6*x - 42*x^2 - 21*x^3 + 31*x^4 + 6*x^5 - 9*x^6 + 3*x^7)*
          HPL[{-2, 0}, x])/(18*(-1 + x^2)^2) + 
        ((-6 + (161 + 4*Pi^2)*x + 12*x^2 - 294*x^3 + 12*x^4 + 
           (161 - 4*Pi^2)*x^5 - 6*x^6)*HPL[{-1, 0}, x])/(72*x*(-1 + x^2)) + 
        (x^2*(-326 - 1666*x + 711*x^2 - 598*x^3 + 2229*x^4 + 6*x^5)*
          HPL[{0, 0}, x])/(36*(-1 + x^2)^2) + 
        ((6 - (161 + 4*Pi^2)*x - 12*x^2 + 294*x^3 - 12*x^4 + 
           (-161 + 4*Pi^2)*x^5 + 6*x^6)*HPL[{1, 0}, x])/(72*x*(-1 + x^2)) - 
        (x^2*(6 + 6*x - 42*x^2 - 21*x^3 + 31*x^4 + 6*x^5 - 9*x^6 + 3*x^7)*
          HPL[{2, 0}, x])/(18*(-1 + x^2)^2) - 
        (2*(1 + x^2)*HPL[{-2, -1, 0}, x])/3 + (8*x^2*HPL[{-2, 0, 0}, x])/3 + 
        (2*(1 + x^2)*HPL[{-2, 1, 0}, x])/3 + 
        (2*(1 + x^2)*HPL[{-1, -2, 0}, x])/3 + 
        ((3 - 9*x + 12*x^2 + 35*x^3 - 35*x^5 - 12*x^6 + 9*x^7 - 3*x^8)*
          HPL[{-1, -1, 0}, x])/(36*x^3) + 
        ((-67 + 119*x - 129*x^2 + 149*x^3 - 109*x^4 + 33*x^5 - 15*x^6 + 
           3*x^7)*HPL[{-1, 0, 0}, x])/(18*(-1 + x)^2) + 
        ((-3 + 9*x - 12*x^2 - 35*x^3 + 35*x^5 + 12*x^6 - 9*x^7 + 3*x^8)*
          HPL[{-1, 1, 0}, x])/(36*x^3) - (2*(1 + x^2)*HPL[{-1, 2, 0}, x])/3 + 
        (x^2*(9 + 330*x - 72*x^2 + 366*x^3 - 907*x^4 - 6*x^5 + 9*x^6 - 3*x^7)*
          HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^2) - 
        (2*(1 + x^2)*HPL[{1, -2, 0}, x])/3 + 
        ((-3 + 9*x - 12*x^2 - 35*x^3 + 35*x^5 + 12*x^6 - 9*x^7 + 3*x^8)*
          HPL[{1, -1, 0}, x])/(36*x^3) + 
        ((67 + 101*x + 93*x^2 + 107*x^3 + 61*x^4 + 3*x^5 + 3*x^6 - 3*x^7)*
          HPL[{1, 0, 0}, x])/(18*(1 + x)^2) + 
        ((3 - 9*x + 12*x^2 + 35*x^3 - 35*x^5 - 12*x^6 + 9*x^7 - 3*x^8)*
          HPL[{1, 1, 0}, x])/(36*x^3) + (2*(1 + x^2)*HPL[{1, 2, 0}, x])/3 + 
        (2*(1 + x^2)*HPL[{2, -1, 0}, x])/3 - (8*x^2*HPL[{2, 0, 0}, x])/3 - 
        (2*(1 + x^2)*HPL[{2, 1, 0}, x])/3 - 
        (4*(-1 + x^2)*HPL[{-1, 0, 0, 0}, x])/3 + 
        (4*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/3 + 
        (4*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/3 + 
        (4*(-1 + x^2)*HPL[{1, 0, 0, 0}, x])/3 + 
        ((1 + x*(-1 - 4/(-1 + x^2)))*master3l10a[x])/24 + 
        (x*(1 - x + 3*x^2 + x^3)*master3l10b[x])/(24*(-1 + x^2)) + 
        ((11 + 6*x - x^2)*master3l8a[x])/(24*(-1 + x^2)^2) + 
        ((5 + 18*x - 39*x^2)*master3l8b[x])/(72*(-1 + x^2)^2) - 
        ((-9 + x^2)*master3l9a[x])/(6*(-1 + x^2)^2) + 
        ((1 - 9*x^2)*master3l9b[x])/(18*(-1 + x^2)^2) + 
        (HPL[{1}, x]*(Pi^2*(3 - 9*x + 12*x^2 + 35*x^3 - 35*x^5 - 12*x^6 + 
             9*x^7 - 3*x^8) - 288*x^3*(1 + x^2)*Zeta[3]))/(432*x^3) + 
        (HPL[{-1}, x]*(Pi^2*(-3 + 9*x - 12*x^2 - 35*x^3 + 35*x^5 + 12*x^6 - 
             9*x^7 + 3*x^8) + 288*x^3*(1 + x^2)*Zeta[3]))/(432*x^3) - 
        (x*HPL[{0}, x]*(-18 + 12*(-426 + Pi^2)*x + 12*Pi^2*x^6 - 
           18*Pi^2*x^7 + 6*Pi^2*x^8 + x^3*(6345 - 84*Pi^2 - 864*Zeta[3]) + 
           6*x^2*(-1905 + 2*Pi^2 + 288*Zeta[3]) - 6*x^4*(-18 + 7*Pi^2 + 
             288*Zeta[3]) + x^5*(10107 + 62*Pi^2 + 864*Zeta[3])))/
         (432*(-1 + x^2)^2) + (-8*Pi^4*x*(-1 + x^2)^2*(47 - 88*x + 31*x^2) + 
          10*Pi^2*(-1 + x^2)*(6 + 294*x^3 + 6*x^6 + 
            12*x^4*(-1 + 32*Log[2]^2) - 12*x^2*(1 + 32*Log[2]^2) + 
            x*(-161 + 192*Log[2]^2) - x^5*(161 + 192*Log[2]^2)) + 
          15*x*(-5269 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 2256*Zeta[3] + 
            48*x^7*Zeta[3] - 72*x^8*Zeta[3] + 24*x^9*Zeta[3] + 
            16*x^3*(-878 + 32*Log[2]^4 + 768*PolyLog[4, 1/2] + 415*Zeta[3]) - 
            4*x*(-931 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 806*Zeta[3]) - 
            4*x^5*(-931 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 848*Zeta[3]) - 
            x^2*(2951 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 1096*Zeta[3]) - 
            x^4*(-6409 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 
              2008*Zeta[3]) + x^6*(1691 + 128*Log[2]^4 + 3072*PolyLog[4, 
                1/2] + 2680*Zeta[3])))/(8640*x*(-1 + x^2)^2) + 
        lm*((x^2*(22 - 304*x + 119*x^2)*HPL[{0}, x])/(36*(-1 + x^2)) + 
          (11*(-1 + x^2)*HPL[{-1, 0}, x])/18 - 
          (22*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
           (9*(-1 + x^2)^2) - (11*(-1 + x^2)*HPL[{1, 0}, x])/18 + 
          (-44*Pi^2*(-1 + x^2) + 9*(-137 + x*(550 - 144*Zeta[3]) + 
              72*Zeta[3] + x^2*(-137 + 72*Zeta[3])))/864)) + 
      CF*(NH*((lm^3*(-1 + x)^2)/36 + (x*(48 - 472*x + 2985*x^2 - 1552*x^3 - 
             807*x^4 + 521*x^5 + 102*x^6 - 49*x^7)*HPL[{0}, x])/
           (36*(-1 + x^2)^3) + lm^2*((7 - 20*x + 7*x^2)/72 - 
            ((-2 + x)*x^3*HPL[{0}, x])/(6*(-1 + x^2))) + 
          (x*(-24 + 136*x - 1016*x^2 + 523*x^3 + 378*x^4 - 208*x^5 - 58*x^6 + 
             29*x^7)*HPL[{0, 0}, x])/(18*(-1 + x^2)^3) + 
          lm*((4*Pi^2*(-1 + x^2) + 9*(9 - 38*x + 9*x^2))/432 - 
            (x^2*(2 - 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((1 - x^2)*HPL[{-1, 0}, x])/9 + (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
              HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + ((-1 + x^2)*HPL[{1, 0}, x])/
             9) - ((14 + 5*x - 19*x^3 + 8*x^4)*HPL[{-1, 0, 0}, x])/
           (9*(-1 + x)^2) + (2*x^3*(54 - 33*x - 6*x^2 + x^5)*
            HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
          ((2 + 43*x - 12*x^2 - 5*x^3 + 8*x^4)*HPL[{1, 0, 0}, x])/
           (9*(1 + x)^2) + ((-9 + 54*x - 28*x^2 - 6*x^3 + 5*x^4)*
            master3l8a[x])/(18*(-1 + x^2)^3) - 
          ((27 - 108*x + 51*x^2 + 12*x^3 - 15*x^4 + x^6)*master3l9a[x])/
           (18*(-1 + x^2)^3) + (x^5*(7671 - 768*Zeta[3]) + 
            39*(99 - 32*Zeta[3]) + 4*x^8*(113 + 32*Zeta[3]) + 
            3*x^3*(-6687 + 64*Zeta[3]) - 3*x^7*(309 + 64*Zeta[3]) + 
            3*x^4*(3253 + 96*Zeta[3]) + 3*x*(-5641 + 256*Zeta[3]) - 
            x^6*(4517 + 320*Zeta[3]) + 3*x^2*(3535 + 384*Zeta[3]))/
           (432*(-1 + x^2)^3)) + NM*((lm^3*(-1 + x)^2)/36 + 
          ((-2*Pi^2*(-1 + x^2)^4 + 3*(-38 + 219*x^2 + 9*x^3 + 188*x^4 + 459*
                x^5 - 1030*x^6 + 1860*x^7 - 891*x^8))*HPL[{0}, x])/
           (108*(-1 + x^2)^3) + lm^2*((7 - 20*x + 7*x^2)/72 - 
            ((-2 + x)*x^3*HPL[{0}, x])/(6*(-1 + x^2))) + 
          (2*(-1 + x^2)*HPL[{-2, 0}, x])/9 + 
          ((12 + 14*x^2 - 32*x^3 - 601*x^4 + 30*x^5 + 978*x^6 - 2446*x^7 + 
             1229*x^8)*HPL[{0, 0}, x])/(18*(-1 + x^2)^3) + 
          lm*((4*Pi^2*(-1 + x^2) + 9*(9 - 38*x + 9*x^2))/432 - 
            (x^2*(2 - 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((1 - x^2)*HPL[{-1, 0}, x])/9 + (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
              HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + ((-1 + x^2)*HPL[{1, 0}, x])/
             9) - (2*(-1 + x^2)*HPL[{2, 0}, x])/9 - 
          ((12 - 27*x + 13*x^3 + 10*x^4)*HPL[{-1, 0, 0}, x])/(9*(-1 + x)^2) - 
          (2*(1 + 28*x^2 - 30*x^3 - 243*x^4 + 138*x^5 + 332*x^6 - 1020*x^7 + 
             490*x^8)*HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
          ((12 + 3*x - 12*x^2 + 35*x^3 - 2*x^4)*HPL[{1, 0, 0}, x])/
           (9*(1 + x)^2) - ((2 - 15*x^2 + 6*x^3 + 18*x^4 - 54*x^5 + 27*x^6)*
            master3l8b[x])/(54*x^2*(-1 + x^2)^3) - 
          ((1 - 15*x^2 + 12*x^3 + 51*x^4 - 108*x^5 + 27*x^6)*master3l9b[x])/
           (54*x^2*(-1 + x^2)^3) + (-15 + x^2*(13 - 128*Zeta[3]) + 
            156*x^10*(9 + 8*Zeta[3]) + 3*x^3*(249 + 64*Zeta[3]) - 
            3*x^7*(1173 + 64*Zeta[3]) - 12*x^8*(-485 + 96*Zeta[3]) - 
            3*x^6*(283 + 96*Zeta[3]) - 3*x^9*(1379 + 256*Zeta[3]) + 
            x^4*(347 + 320*Zeta[3]) + x^5*(-3171 + 768*Zeta[3]))/
           (432*x^2*(-1 + x^2)^3)) + NL*((lm^3*(-1 + x)^2)/36 - 
          (Pi^2*(-1 + x^2)*HPL[{-1}, x])/54 + 
          (x^2*(84 + 6*(-57 + 4*Pi^2)*x - 3*(1 + 4*Pi^2)*x^2 + 342*x^3 + 
             (-81 + 4*Pi^2)*x^4)*HPL[{0}, x])/(216*(-1 + x^2)^2) + 
          lm^2*((7 - 20*x + 7*x^2)/72 - ((-2 + x)*x^3*HPL[{0}, x])/
             (6*(-1 + x^2))) + (Pi^2*(-1 + x^2)*HPL[{1}, x])/54 - 
          (2*x^3*(6 - 3*x + x^3)*HPL[{-2, 0}, x])/(9*(-1 + x^2)^2) + 
          ((-7 + 6*x + 10*x^2 + 6*x^3 - 7*x^4)*HPL[{-1, 0}, x])/
           (18*(-1 + x^2)) + (2*x^3*(20 - 10*x - 13*x^2 + 7*x^3)*
            HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + 
          ((7 - 6*x - 10*x^2 - 6*x^3 + 7*x^4)*HPL[{1, 0}, x])/
           (18*(-1 + x^2)) + lm*((4*Pi^2*(-1 + x^2) + 9*(9 - 38*x + 9*x^2))/
             432 - (x^2*(2 - 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((1 - x^2)*HPL[{-1, 0}, x])/9 + (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
              HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + ((-1 + x^2)*HPL[{1, 0}, x])/
             9) + (2*x^3*(6 - 3*x + x^3)*HPL[{2, 0}, x])/(9*(-1 + x^2)^2) + 
          (2*(-1 + x^2)*HPL[{-1, -1, 0}, x])/9 - 
          (2*(-1 + x^2)*HPL[{-1, 1, 0}, x])/9 - 
          (8*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x^2)^2) - (2*(-1 + x^2)*HPL[{1, -1, 0}, x])/9 + 
          (2*(-1 + x^2)*HPL[{1, 1, 0}, x])/9 + 
          (4*Pi^2*(-7 + 6*x + 17*x^2 - 17*x^4 - 6*x^5 + 7*x^6) + 
            3*(73 + 96*Zeta[3] - 8*x*(41 + 16*Zeta[3]) - 8*x^5*(41 + 
                16*Zeta[3]) + 16*x^3*(41 + 28*Zeta[3]) - x^4*(73 + 
                64*Zeta[3]) + x^6*(73 + 64*Zeta[3]) - x^2*(73 + 
                160*Zeta[3])))/(864*(-1 + x^2)^2))))
 
CbarData["v", 2, 0] = 
    NC*(CF*(NL*(lm^2/36 + (Pi^2*(2 - 9*x + 2*x^2)*HPL[{-1}, x])/
           (243*(-1 + x^2)) + (x^2*(-90 + (309 + 54*Pi^2)*x + 
             (60 - 54*Pi^2)*x^2 + 3*(-124 + 9*Pi^2)*x^3 + 4*(9 + Pi^2)*x^4 + 
             9*(7 + Pi^2)*x^5 - 2*(3 + Pi^2)*x^6)*HPL[{0}, x])/
           (243*(-1 + x^2)^4) - (Pi^2*(2 - 9*x + 2*x^2)*HPL[{1}, x])/
           (243*(-1 + x^2)) + (4*x^3*(-54 + 54*x - 27*x^2 - 4*x^3 - 9*x^4 + 
             2*x^5)*HPL[{-2, 0}, x])/(81*(-1 + x^2)^4) + 
          ((30 - 29*x - 82*x^2 + 238*x^3 - 82*x^4 - 29*x^5 + 30*x^6)*
            HPL[{-1, 0}, x])/(81*(-1 + x^2)^3) + 
          (2*x^3*(180 - 180*x + 9*x^2 + 68*x^3 + 29*x^4 - 21*x^5)*
            HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + 
          ((-30 + 29*x + 82*x^2 - 238*x^3 + 82*x^4 + 29*x^5 - 30*x^6)*
            HPL[{1, 0}, x])/(81*(-1 + x^2)^3) + 
          lm*((6 - 63*x + 66*x^2 - 63*x^3 + 6*x^4 + Pi^2*(2 - 9*x + 9*x^3 - 
                2*x^4))/(486*(-1 + x^2)^2) + (x^2*(4 - 48*x + 31*x^2 - 9*x^4)*
              HPL[{0}, x])/(81*(-1 + x^2)^3) + (2*(2 - 9*x + 2*x^2)*
              HPL[{-1, 0}, x])/(81*(-1 + x^2)) - 
            (4*x^3*(-54 + 54*x - 27*x^2 - 4*x^3 - 9*x^4 + 2*x^5)*
              HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + ((4 - 18*x + 4*x^2)*
              HPL[{1, 0}, x])/(81 - 81*x^2)) - 
          (4*x^3*(-54 + 54*x - 27*x^2 - 4*x^3 - 9*x^4 + 2*x^5)*
            HPL[{2, 0}, x])/(81*(-1 + x^2)^4) + 
          ((8 - 36*x + 8*x^2)*HPL[{-1, -1, 0}, x])/(81 - 81*x^2) + 
          (4*(2 - 9*x + 2*x^2)*HPL[{-1, 1, 0}, x])/(81*(-1 + x^2)) + 
          (8*x^3*(-54 + 54*x - 27*x^2 - 4*x^3 - 9*x^4 + 2*x^5)*
            HPL[{0, 0, 0}, x])/(81*(-1 + x^2)^4) + 
          (4*(2 - 9*x + 2*x^2)*HPL[{1, -1, 0}, x])/(81*(-1 + x^2)) + 
          ((8 - 36*x + 8*x^2)*HPL[{1, 1, 0}, x])/(81 - 81*x^2) + 
          (1139*x^6 - 351*x^7 - 164*x^8 + Pi^2*(30 - 29*x - 112*x^2 + 
              267*x^3 - 267*x^5 + 112*x^6 + 29*x^7 - 30*x^8) + 
            27*x*(-13 + 8*Zeta[3]) - 4*(41 + 12*Zeta[3]) + 
            27*x^3*(13 + 24*Zeta[3]) + 27*x^5*(13 + 48*Zeta[3]) + 
            x^2*(1139 + 96*Zeta[3]) - 6*x^4*(325 + 216*Zeta[3]))/
           (972*(-1 + x^2)^4)) + NH*(lm^2/36 + 
          (x*(-3888 - 15264*x - 674280*x^2 + 769648*x^3 + 40495*x^4 - 
             368496*x^5 + 3853*x^6 + 82102*x^7 + 649*x^8 - 8972*x^9 - 
             45*x^10 + 374*x^11)*HPL[{0}, x])/(324*(-9 + x^2)*(-1 + x^2)^5) + 
          (x*(972 + 828*x + 119340*x^2 - 127460*x^3 - 18663*x^4 + 68920*x^5 - 
             3909*x^6 - 14768*x^7 + 147*x^8 + 1500*x^9 + 33*x^10 - 60*x^11)*
            HPL[{0, 0}, x])/(81*(-9 + x^2)*(-1 + x^2)^5) + 
          lm*((6 - 63*x + 66*x^2 - 63*x^3 + 6*x^4 + Pi^2*(2 - 9*x + 9*x^3 - 
                2*x^4))/(486*(-1 + x^2)^2) + (x^2*(4 - 48*x + 31*x^2 - 9*x^4)*
              HPL[{0}, x])/(81*(-1 + x^2)^3) + (2*(2 - 9*x + 2*x^2)*
              HPL[{-1, 0}, x])/(81*(-1 + x^2)) - 
            (4*x^3*(-54 + 54*x - 27*x^2 - 4*x^3 - 9*x^4 + 2*x^5)*
              HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + ((4 - 18*x + 4*x^2)*
              HPL[{1, 0}, x])/(81 - 81*x^2)) + 
          (2*(-71 - 269*x + 475*x^2 - 238*x^3 - 14*x^4 + x^5 + 4*x^6)*
            HPL[{-1, 0, 0}, x])/(81*(-1 + x)^4*(1 + x)^2) - 
          (4*x^3*(7722 - 6984*x - 639*x^2 + 2484*x^3 - 681*x^4 - 222*x^5 + 
             135*x^6 - 16*x^7 - 9*x^8 + 2*x^9)*HPL[{0, 0, 0}, x])/
           (81*(-9 + x^2)*(-1 + x^2)^5) + ((34 + 998*x - 578*x^2 - 44*x^3 + 
             172*x^4 + 74*x^5 - 8*x^6)*HPL[{1, 0, 0}, x])/
           (81*(-1 + x)^2*(1 + x)^4) - ((216 + 5985*x - 6984*x^2 + 531*x^3 + 
             2418*x^4 + 23*x^5 - 412*x^6 - 11*x^7 + 26*x^8)*master3l8a[x])/
           (81*(-9 + x^2)*(-1 + x^2)^5) - ((648 + 10233*x - 13968*x^2 + 
             2232*x^3 + 4770*x^4 + 750*x^5 - 1014*x^6 - 168*x^7 + 94*x^8 + 
             9*x^9 - 2*x^10)*master3l9a[x])/(81*(-9 + x^2)*(-1 + x^2)^5) + 
          (185904 + x^3*(5420643 - 408192*Zeta[3]) + 
            x^6*(2738996 - 51072*Zeta[3]) + x*(3545073 - 43200*Zeta[3]) + 
            x^9*(205 - 16128*Zeta[3]) - 63936*Zeta[3] + 
            152*x^8*(-4771 + 40*Zeta[3]) - 2*x^12*(2173 + 64*Zeta[3]) + 
            8*x^10*(11447 + 192*Zeta[3]) + x^11*(-169 + 576*Zeta[3]) + 
            6*x^7*(-1999 + 9696*Zeta[3]) + 6*x^5*(-121413 + 68128*Zeta[3]) - 
            2*x^4*(1947983 + 182208*Zeta[3]) + x^2*(-4358332 + 
              471936*Zeta[3]))/(3888*(-9 + x^2)*(-1 + x^2)^5)) + 
        NM*(lm^2/36 + ((4*Pi^2*(-1 + x^2)^4*(-2 + 9*x + 16*x^2 - 81*x^3 + 18*
                x^4) + 3*(-152 + 684*x + 3820*x^2 - 10858*x^3 - 20114*x^4 + 
               40409*x^5 + 11216*x^6 + 193583*x^7 - 56946*x^8 + 241539*x^9 - 
               439264*x^10 + 167859*x^11 + 42048*x^12))*HPL[{0}, x])/
           (972*(-1 + x^2)^5*(-1 + 9*x^2)) + ((8 - 36*x + 8*x^2)*
            HPL[{-2, 0}, x])/(81 - 81*x^2) - 
          ((-24 + 108*x + 416*x^2 - 1230*x^3 + 1338*x^4 - 4431*x^5 - 
             27072*x^6 + 95535*x^7 + 61168*x^8 + 130923*x^9 - 306360*x^10 + 
             112023*x^11 + 28998*x^12)*HPL[{0, 0}, x])/(81*(-1 + x^2)^5*
            (-1 + 9*x^2)) + lm*((6 - 63*x + 66*x^2 - 63*x^3 + 6*x^4 + 
              Pi^2*(2 - 9*x + 9*x^3 - 2*x^4))/(486*(-1 + x^2)^2) + 
            (x^2*(4 - 48*x + 31*x^2 - 9*x^4)*HPL[{0}, x])/(81*(-1 + x^2)^3) + 
            (2*(2 - 9*x + 2*x^2)*HPL[{-1, 0}, x])/(81*(-1 + x^2)) - 
            (4*x^3*(-54 + 54*x - 27*x^2 - 4*x^3 - 9*x^4 + 2*x^5)*
              HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + ((4 - 18*x + 4*x^2)*
              HPL[{1, 0}, x])/(81 - 81*x^2)) + (4*(2 - 9*x + 2*x^2)*
            HPL[{2, 0}, x])/(81*(-1 + x^2)) - 
          (2*(-12 + 51*x - 66*x^2 + 238*x^3 - 395*x^4 + 217*x^5 + 79*x^6)*
            HPL[{-1, 0, 0}, x])/(81*(-1 + x)^4*(1 + x)^2) + 
          (4*(-2 + 9*x - 40*x^2 + 9*x^3 + 1894*x^4 - 3129*x^5 - 14812*x^6 + 
             21633*x^7 + 42408*x^8 + 56856*x^9 - 131600*x^10 + 48654*x^11 + 
             12168*x^12)*HPL[{0, 0, 0}, x])/(81*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          (2*(-12 + 57*x + 150*x^2 - 22*x^3 - 353*x^4 + 479*x^5 + 25*x^6)*
            HPL[{1, 0, 0}, x])/(81*(-1 + x)^2*(1 + x)^4) + 
          ((-4 + 18*x + 110*x^2 - 303*x^3 - 792*x^4 + 1431*x^5 + 2286*x^6 + 
             2871*x^7 - 6984*x^8 + 2511*x^9 + 648*x^10)*master3l8b[x])/
           (243*x^2*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          ((-2 + 9*x + 94*x^2 - 168*x^3 - 1014*x^4 + 750*x^5 + 4770*x^6 + 
             2232*x^7 - 13968*x^8 + 10233*x^9 + 648*x^10)*master3l9b[x])/
           (243*x^2*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          (-60 + 270*x + x^10*(967814 - 364416*Zeta[3]) + 
            x^5*(99835 - 16128*Zeta[3]) - 2*x^2*(283 + 64*Zeta[3]) + 
            64*x^6*(-2063 + 95*Zeta[3]) + 16*x^4*(1051 + 96*Zeta[3]) - 
            576*x^14*(116 + 111*Zeta[3]) + x^3*(-9529 + 576*Zeta[3]) - 
            27*x^13*(16511 + 1600*Zeta[3]) - 8*x^8*(-53227 + 6384*Zeta[3]) + 
            6*x^7*(-39919 + 9696*Zeta[3]) + 12*x^9*(-148779 + 
              34064*Zeta[3]) - 3*x^11*(120559 + 136064*Zeta[3]) + 
            x^12*(778148 + 471936*Zeta[3]))/(3888*x^2*(-1 + x^2)^5*
            (-1 + 9*x^2)))) + CA*CF*((-11*lm^2)/72 - 
        (Pi^2*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{-2}, x])/
         (81*(-1 + x^2)^2) + (Pi^2*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{2}, x])/(81*(-1 + x^2)^2) + 
        (x*(-45 + 153*x^2 - 144*x^3 - 645*x^4 + 408*x^5 + 381*x^6 - 412*x^7 - 
           108*x^8 + 192*x^9 - 12*x^10 - 40*x^11 + 16*x^12)*HPL[{-2, 0}, x])/
         (81*(-1 + x^2)^4) + ((-48 + 120*x - 36*x^2 - 2*(509 + 6*Pi^2)*x^3 + 
           (2819 + 54*Pi^2)*x^4 + (892 - 48*Pi^2)*x^5 - 4690*x^6 + 
           (892 + 48*Pi^2)*x^7 + (2819 - 54*Pi^2)*x^8 + 2*(-509 + 6*Pi^2)*
            x^9 - 36*x^10 + 120*x^11 - 48*x^12)*HPL[{-1, 0}, x])/
         (486*x^3*(-1 + x^2)^3) + (x*(-7290 + 10692*x - 171099*x^2 + 
           84645*x^3 + 1875594*x^4 - 1661100*x^5 + 1481856*x^6 - 
           4364912*x^7 + 3930232*x^8 + 922636*x^9 - 454773*x^10 - 
           26985*x^11 - 8088*x^12 - 2160*x^13 + 864*x^14)*HPL[{0, 0}, x])/
         (486*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4)) + 
        ((48 - 120*x + 36*x^2 + 2*(509 + 6*Pi^2)*x^3 - (2819 + 54*Pi^2)*x^4 + 
           (-892 + 48*Pi^2)*x^5 + 4690*x^6 - 4*(223 + 12*Pi^2)*x^7 + 
           (-2819 + 54*Pi^2)*x^8 - 2*(-509 + 6*Pi^2)*x^9 + 36*x^10 - 
           120*x^11 + 48*x^12)*HPL[{1, 0}, x])/(486*x^3*(-1 + x^2)^3) + 
        lm*((-417 + 693*x - 24*x^2 + 693*x^3 - 417*x^4 + 
            11*Pi^2*(-2 + 9*x - 9*x^3 + 2*x^4))/(972*(-1 + x^2)^2) + 
          (11*x^2*(-4 + 48*x - 31*x^2 + 9*x^4)*HPL[{0}, x])/
           (162*(-1 + x^2)^3) - (11*(2 - 9*x + 2*x^2)*HPL[{-1, 0}, x])/
           (81*(-1 + x^2)) + (22*x^3*(-54 + 54*x - 27*x^2 - 4*x^3 - 9*x^4 + 
             2*x^5)*HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + 
          (11*(2 - 9*x + 2*x^2)*HPL[{1, 0}, x])/(81*(-1 + x^2))) + 
        (x*(45 - 153*x^2 + 144*x^3 + 645*x^4 - 408*x^5 - 381*x^6 + 412*x^7 + 
           108*x^8 - 192*x^9 + 12*x^10 + 40*x^11 - 16*x^12)*HPL[{2, 0}, x])/
         (81*(-1 + x^2)^4) + (4*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{-2, -1, 0}, x])/(27*(-1 + x^2)^2) - 
        (16*x^2*(5 - 9*x + 2*x^2)*HPL[{-2, 0, 0}, x])/(27*(-1 + x^2)^2) - 
        (4*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{-2, 1, 0}, x])/
         (27*(-1 + x^2)^2) - (4*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{-1, -2, 0}, x])/(27*(-1 + x^2)^2) - 
        (2*(4 - 10*x + 9*x^2 + 18*x^3 - 12*x^4 - 30*x^5 + 97*x^6 - 30*x^7 - 
           12*x^8 + 18*x^9 + 9*x^10 - 10*x^11 + 4*x^12)*HPL[{-1, -1, 0}, x])/
         (81*x^5*(-1 + x^2)) + (2*(-57 + 152*x - 157*x^2 + 128*x^3 - 
           249*x^4 + 234*x^5 + 31*x^6 - 144*x^7 + 16*x^8 + 58*x^9 - 36*x^10 + 
           8*x^11)*HPL[{-1, 0, 0}, x])/(81*(-1 + x)^4*(1 + x)^2) + 
        (2*(4 - 10*x + 9*x^2 + 18*x^3 - 12*x^4 - 30*x^5 + 97*x^6 - 30*x^7 - 
           12*x^8 + 18*x^9 + 9*x^10 - 10*x^11 + 4*x^12)*HPL[{-1, 1, 0}, x])/
         (81*x^5*(-1 + x^2)) + (4*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{-1, 2, 0}, x])/(27*(-1 + x^2)^2) - 
        (x*(-405 + 1512*x - 37647*x^2 + 5466*x^3 + 328662*x^4 - 79644*x^5 + 
           244398*x^6 - 1329128*x^7 + 945199*x^8 + 367284*x^9 - 91215*x^10 - 
           56130*x^11 + 312*x^12 + 10016*x^13 - 2840*x^14 - 720*x^15 + 
           288*x^16)*HPL[{0, 0, 0}, x])/(81*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4)) + (4*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{1, -2, 0}, x])/(27*(-1 + x^2)^2) + 
        (2*(4 - 10*x + 9*x^2 + 18*x^3 - 12*x^4 - 30*x^5 + 97*x^6 - 30*x^7 - 
           12*x^8 + 18*x^9 + 9*x^10 - 10*x^11 + 4*x^12)*HPL[{1, -1, 0}, x])/
         (81*x^5*(-1 + x^2)) - (2*(-57 - 124*x + 115*x^2 + 496*x^3 + 
           103*x^4 - 250*x^5 - 137*x^6 + 80*x^7 + 56*x^8 - 22*x^9 - 4*x^10 + 
           8*x^11)*HPL[{1, 0, 0}, x])/(81*(-1 + x)^2*(1 + x)^4) - 
        (2*(4 - 10*x + 9*x^2 + 18*x^3 - 12*x^4 - 30*x^5 + 97*x^6 - 30*x^7 - 
           12*x^8 + 18*x^9 + 9*x^10 - 10*x^11 + 4*x^12)*HPL[{1, 1, 0}, x])/
         (81*x^5*(-1 + x^2)) - (4*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{1, 2, 0}, x])/(27*(-1 + x^2)^2) - 
        (4*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{2, -1, 0}, x])/
         (27*(-1 + x^2)^2) + (16*x^2*(5 - 9*x + 2*x^2)*HPL[{2, 0, 0}, x])/
         (27*(-1 + x^2)^2) + (4*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{2, 1, 0}, x])/(27*(-1 + x^2)^2) + 
        (8*(2 - 9*x + 2*x^2)*HPL[{-1, 0, 0, 0}, x])/(27*(-1 + x^2)) - 
        (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{-1, 1, 0, 0}, x])/
         (27*(-1 + x^2)^2) - (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{1, -1, 0, 0}, x])/(27*(-1 + x^2)^2) - 
        (8*(2 - 9*x + 2*x^2)*HPL[{1, 0, 0, 0}, x])/(27*(-1 + x^2)) - 
        ((4 + 13*x - 22*x^2 + 9*x^3 + 4*x^4 + 4*x^5)*master3l10a[x])/
         (54*(-1 + x^2)^3) + (x*(4 + 4*x + 9*x^2 - 22*x^3 + 13*x^4 + 4*x^5)*
          master3l10b[x])/(54*(-1 + x^2)^3) + 
        ((729 + 9*x - 1005*x^2 - 888*x^3 + 429*x^4 + 95*x^5 - 41*x^6)*
          master3l8a[x])/(324*(-9 + x^2)*(-1 + x^2)^4) + 
        ((-30 - 9*x + 223*x^2 + 233*x^3 + 102*x^4 - 2553*x^5 + 2025*x^6 + 
           297*x^7)*master3l8b[x])/(324*x*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        ((513 + 1017*x - 1779*x^2 - 393*x^3 + 331*x^4 + 159*x^5 - 25*x^6 - 
           15*x^7)*master3l9a[x])/(108*(-9 + x^2)*(-1 + x^2)^4) + 
        ((-15 - 25*x + 159*x^2 + 331*x^3 - 393*x^4 - 1779*x^5 + 1017*x^6 + 
           513*x^7)*master3l9b[x])/(324*x*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        (HPL[{-1}, x]*(Pi^2*(-4 + 10*x - 5*x^2 - 28*x^3 + 21*x^4 + 48*x^5 - 
             109*x^6 + 109*x^8 - 48*x^9 - 21*x^10 + 28*x^11 + 5*x^12 - 
             10*x^13 + 4*x^14) - 72*x^5*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
            Zeta[3]))/(486*x^5*(-1 + x^2)^2) + 
        (HPL[{1}, x]*(Pi^2*(4 - 10*x + 5*x^2 + 28*x^3 - 21*x^4 - 48*x^5 + 
             109*x^6 - 109*x^8 + 48*x^9 + 21*x^10 - 28*x^11 - 5*x^12 + 
             10*x^13 - 4*x^14) + 72*x^5*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
            Zeta[3]))/(486*x^5*(-1 + x^2)^2) + 
        (HPL[{0}, x]*(864 - 2160*x + 6*(6419 + 135*Pi^2)*x^2 - 47568*x^3 + 
           (558213 - 24354*Pi^2)*x^12 - 24*(36 + 13*Pi^2)*x^14 - 
           10016*Pi^2*x^15 + 2840*Pi^2*x^16 + 720*Pi^2*x^17 - 288*Pi^2*x^18 + 
           3*x^13*(37449 + 13208*Pi^2 + 7776*Zeta[3]) + 
           6*x^10*(-703355 + 12673*Pi^2 + 11664*Zeta[3]) - 
           48*x^7*(-31837 + 645*Pi^2 + 15228*Zeta[3]) - 
           16*x^11*(116523 + 4898*Pi^2 + 19116*Zeta[3]) - 
           3*x^4*(139181 + 3378*Pi^2 + 23328*Zeta[3]) + 
           x^5*(571043 + 2592*Pi^2 + 69984*Zeta[3]) + 
           8*x^6*(121780 + 4689*Pi^2 + 88452*Zeta[3]) - 
           2*x^8*(3345367 + 57696*Pi^2 + 353808*Zeta[3]) + 
           x^9*(7524610 + 76920*Pi^2 + 943488*Zeta[3])))/
         (1944*x*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4)) + 
        (24*Pi^4*x^3*(-1 + x^2)^2*(1242 - 243*x - 14142*x^2 + 3267*x^3 + 
            27944*x^4 - 9837*x^5 - 11518*x^6 + 1053*x^7 + 954*x^8) + 
          20*Pi^2*(-9 + 91*x^2 - 91*x^4 + 9*x^6)*(48 - 120*x + 36*x^2 - 
            2819*x^4 + 4690*x^6 - 2819*x^8 + 36*x^10 - 120*x^11 + 48*x^12 + 
            x^3*(1018 - 864*Log[2]^2) + 2*x^9*(509 + 432*Log[2]^2) + 
            4*x^5*(-223 + 648*Log[2]^2) - 4*x^7*(223 + 648*Log[2]^2)) + 
          15*x^2*(5211 + x^6*(4512380 - 2738688*Zeta[3]) + 
            x^2*(247308 - 244512*Zeta[3]) + 120192*x^15*Zeta[3] - 
            34080*x^16*Zeta[3] - 8640*x^17*Zeta[3] + 3456*x^18*Zeta[3] + 
            288*x^14*(-3 + 13*Zeta[3]) - 9*x*(-30839 + 1152*Log[2]^4 + 
              27648*PolyLog[4, 1/2] + 11520*Zeta[3]) + 
            3*x^12*(-61789 + 33408*Zeta[3]) + 24*x^10*(16609 + 
              39424*Zeta[3]) - 9*x^13*(3631 + 1152*Log[2]^4 + 
              27648*PolyLog[4, 1/2] + 65408*Zeta[3]) + 
            4*x^3*(-798785 + 33984*Log[2]^4 + 815616*PolyLog[4, 1/2] + 
              413712*Zeta[3]) + x^8*(11513885 + 436224*Zeta[3]) + 
            16*x^7*(-836075 + 40608*Log[2]^4 + 974592*PolyLog[4, 1/2] + 
              621912*Zeta[3]) + 4*x^11*(118585 + 33984*Log[2]^4 + 
              815616*PolyLog[4, 1/2] + 675216*Zeta[3]) + 
            3*x^4*(-1108363 + 832736*Zeta[3]) - x^5*(-7366219 + 
              450432*Log[2]^4 + 10810368*PolyLog[4, 1/2] + 7498944*Zeta[3]) - 
            x^9*(332291 + 450432*Log[2]^4 + 10810368*PolyLog[4, 1/2] + 
              8573568*Zeta[3])))/(116640*x^3*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4))) + 
      CF^2*((3*lm)/8 + (2*Pi^2*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{-2}, x])/(81*(-1 + x^2)^2) - 
        (2*Pi^2*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{2}, x])/
         (81*(-1 + x^2)^2) + (2*x*(45 - 33*x^2 + 168*x^3 + 687*x^4 - 
           564*x^5 - 757*x^6 + 846*x^7 + 589*x^8 - 699*x^9 - 167*x^10 + 
           321*x^11 - 43*x^12 - 63*x^13 + 27*x^14)*HPL[{-2, 0}, x])/
         (81*(-1 + x^2)^4) + ((-108 + 252*x + 10*x^2 - 906*x^3 + 728*x^4 + 
           (1047 + 16*Pi^2)*x^5 - 2*(523 + 36*Pi^2)*x^6 + (-411 + 64*Pi^2)*
            x^7 - 560*x^8 - (411 + 64*Pi^2)*x^9 + 2*(-523 + 36*Pi^2)*x^10 + 
           (1047 - 16*Pi^2)*x^11 + 728*x^12 - 906*x^13 + 10*x^14 + 252*x^15 - 
           108*x^16)*HPL[{-1, 0}, x])/(324*x^5*(-1 + x^2)^3) + 
        (x*(4860 - 4068*x + 57618*x^2 - 41380*x^3 - 744822*x^4 + 730006*x^5 - 
           983106*x^6 + 2848025*x^7 - 2468812*x^8 - 527226*x^9 + 
           344590*x^10 - 73599*x^11 + 4186*x^12 + 31086*x^13 - 9918*x^14 - 
           2268*x^15 + 972*x^16)*HPL[{0, 0}, x])/(162*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4)) + ((108 - 252*x - 10*x^2 + 906*x^3 - 
           728*x^4 - (1047 + 16*Pi^2)*x^5 + 2*(523 + 36*Pi^2)*x^6 + 
           (411 - 64*Pi^2)*x^7 + 560*x^8 + (411 + 64*Pi^2)*x^9 + 
           (1046 - 72*Pi^2)*x^10 + (-1047 + 16*Pi^2)*x^11 - 728*x^12 + 
           906*x^13 - 10*x^14 - 252*x^15 + 108*x^16)*HPL[{1, 0}, x])/
         (324*x^5*(-1 + x^2)^3) - (2*x*(45 - 33*x^2 + 168*x^3 + 687*x^4 - 
           564*x^5 - 757*x^6 + 846*x^7 + 589*x^8 - 699*x^9 - 167*x^10 + 
           321*x^11 - 43*x^12 - 63*x^13 + 27*x^14)*HPL[{2, 0}, x])/
         (81*(-1 + x^2)^4) - (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{-2, -1, 0}, x])/(27*(-1 + x^2)^2) + 
        (16*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{-2, 0, 0}, x])/
         (27*(-1 + x^2)^2) + (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{-2, 1, 0}, x])/(27*(-1 + x^2)^2) + 
        (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{-1, -2, 0}, x])/
         (27*(-1 + x^2)^2) + ((27 - 63*x + 65*x^2 + 69*x^3 - 69*x^4 - 
           45*x^5 + 31*x^6 - 31*x^8 + 45*x^9 + 69*x^10 - 69*x^11 - 65*x^12 + 
           63*x^13 - 27*x^14)*HPL[{-1, -1, 0}, x])/(81*x^7) + 
        (2*(151 - 425*x + 526*x^2 - 634*x^3 + 1009*x^4 - 671*x^5 - 404*x^6 + 
           554*x^7 + 293*x^8 - 551*x^9 + 110*x^10 + 164*x^11 - 117*x^12 + 
           27*x^13)*HPL[{-1, 0, 0}, x])/(81*(-1 + x)^4*(1 + x)^2) + 
        ((-27 + 63*x - 65*x^2 - 69*x^3 + 69*x^4 + 45*x^5 - 31*x^6 + 31*x^8 - 
           45*x^9 - 69*x^10 + 69*x^11 + 65*x^12 - 63*x^13 + 27*x^14)*
          HPL[{-1, 1, 0}, x])/(81*x^7) - 
        (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{-1, 2, 0}, x])/
         (27*(-1 + x^2)^2) - (2*x*(-405 + 1080*x + 21078*x^2 - 47406*x^3 - 
           138807*x^4 + 432810*x^5 - 235356*x^6 - 1453636*x^7 + 433045*x^8 + 
           1879056*x^9 - 781634*x^10 - 628766*x^11 - 42849*x^12 + 
           220758*x^13 + 32684*x^14 - 82470*x^15 + 9734*x^16 + 17244*x^17 - 
           5688*x^18 - 1134*x^19 + 486*x^20)*HPL[{0, 0, 0}, x])/
         (81*(-1 + x^2)^5*(9 - 82*x^2 + 9*x^4)) - 
        (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{1, -2, 0}, x])/
         (27*(-1 + x^2)^2) + ((-27 + 63*x - 65*x^2 - 69*x^3 + 69*x^4 + 
           45*x^5 - 31*x^6 + 31*x^8 - 45*x^9 - 69*x^10 + 69*x^11 + 65*x^12 - 
           63*x^13 + 27*x^14)*HPL[{1, -1, 0}, x])/(81*x^7) - 
        (2*(151 + 275*x - 206*x^2 - 1046*x^3 - 371*x^4 + 665*x^5 + 532*x^6 - 
           430*x^7 - 395*x^8 + 229*x^9 + 154*x^10 - 88*x^11 - 9*x^12 + 
           27*x^13)*HPL[{1, 0, 0}, x])/(81*(-1 + x)^2*(1 + x)^4) + 
        ((27 - 63*x + 65*x^2 + 69*x^3 - 69*x^4 - 45*x^5 + 31*x^6 - 31*x^8 + 
           45*x^9 + 69*x^10 - 69*x^11 - 65*x^12 + 63*x^13 - 27*x^14)*
          HPL[{1, 1, 0}, x])/(81*x^7) + (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{1, 2, 0}, x])/(27*(-1 + x^2)^2) + 
        (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{2, -1, 0}, x])/
         (27*(-1 + x^2)^2) - (16*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{2, 0, 0}, x])/(27*(-1 + x^2)^2) - 
        (8*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{2, 1, 0}, x])/
         (27*(-1 + x^2)^2) + (16*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
          HPL[{-1, 1, 0, 0}, x])/(27*(-1 + x^2)^2) + 
        (16*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*HPL[{1, -1, 0, 0}, x])/
         (27*(-1 + x^2)^2) + ((4 + 13*x - 22*x^2 + 9*x^3 + 4*x^4 + 4*x^5)*
          master3l10a[x])/(27*(-1 + x^2)^3) - 
        (x*(4 + 4*x + 9*x^2 - 22*x^3 + 13*x^4 + 4*x^5)*master3l10b[x])/
         (27*(-1 + x^2)^3) + ((-729 - 9*x + 1005*x^2 + 888*x^3 - 429*x^4 - 
           95*x^5 + 41*x^6)*master3l8a[x])/(162*(-9 + x^2)*(-1 + x^2)^4) - 
        ((-30 - 9*x + 223*x^2 + 233*x^3 + 102*x^4 - 2553*x^5 + 2025*x^6 + 
           297*x^7)*master3l8b[x])/(162*x*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        ((-513 - 1017*x + 1779*x^2 + 393*x^3 - 331*x^4 - 159*x^5 + 25*x^6 + 
           15*x^7)*master3l9a[x])/(54*(-9 + x^2)*(-1 + x^2)^4) + 
        ((15 + 25*x - 159*x^2 - 331*x^3 + 393*x^4 + 1779*x^5 - 1017*x^6 - 
           513*x^7)*master3l9b[x])/(162*x*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(27 - 63*x + 92*x^2 + 6*x^3 + 
             23*x^4 - 39*x^5 + 54*x^6 - 39*x^7 + 23*x^8 + 6*x^9 + 92*x^10 - 
             63*x^11 + 27*x^12) + 288*x^7*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
            Zeta[3]))/(972*x^7*(-1 + x^2)^2) - 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(27 - 63*x + 92*x^2 + 6*x^3 + 
             23*x^4 - 39*x^5 + 54*x^6 - 39*x^7 + 23*x^8 + 6*x^9 + 92*x^10 - 
             63*x^11 + 27*x^12) + 288*x^7*(2 - 9*x + 10*x^2 - 9*x^3 + 2*x^4)*
            Zeta[3]))/(972*x^7*(-1 + x^2)^2) + 
        (HPL[{0}, x]*(2916 - 6804*x - 28296*x^2 + 89856*x^3 - 
           3*(31229 + 540*Pi^2)*x^4 - 120195*x^5 + (-1149663 + 226456*Pi^2)*
            x^14 - 8*(-3537 + 9304*Pi^2)*x^16 + 84*(81 + 1580*Pi^2)*x^17 - 
           4*(729 + 2266*Pi^2)*x^18 - 32220*Pi^2*x^19 + 10404*Pi^2*x^20 + 
           2268*Pi^2*x^21 - 972*Pi^2*x^22 + x^12*(8878257 - 294232*Pi^2 - 
             139968*Zeta[3]) - 12*x^15*(24444 + 22607*Pi^2 + 3888*Zeta[3]) + 
           9*x^6*(100177 + 1772*Pi^2 + 15552*Zeta[3]) - 
           6*x^7*(197357 + 1008*Pi^2 + 23328*Zeta[3]) + 
           9*x^13*(420471 + 35884*Pi^2 + 67968*Zeta[3]) + 
           12*x^9*(-246777 + 6284*Pi^2 + 121824*Zeta[3]) - 
           6*x^8*(131217 + 6196*Pi^2 + 235872*Zeta[3]) + 
           6*x^10*(1960947 + 42296*Pi^2 + 235872*Zeta[3]) - 
           6*x^11*(2493211 + 36916*Pi^2 + 314496*Zeta[3])))/
         (1944*x^3*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4)) + 
        (-32*Pi^4*x^5*(-1 + x^2)^2*(1098 + 405*x - 12830*x^2 - 3285*x^3 + 
            27944*x^4 - 3285*x^5 - 12830*x^6 + 405*x^7 + 1098*x^8) + 
          20*Pi^2*(-9 + 91*x^2 - 91*x^4 + 9*x^6)*(108 - 252*x - 10*x^2 + 
            906*x^3 - 728*x^4 + 1046*x^6 + 560*x^8 + 1046*x^10 - 728*x^12 + 
            906*x^13 - 10*x^14 - 252*x^15 + 108*x^16 + 
            x^7*(411 - 3456*Log[2]^2) + 3*x^5*(-349 + 384*Log[2]^2) - 
            3*x^11*(349 + 384*Log[2]^2) + x^9*(411 + 3456*Log[2]^2)) + 
          5*x^2*(-5832 + 13608*x + 34236*x^2 + x^6*(5386276 - 
              6573600*Zeta[3]) + x^14*(1501212 - 4818048*Zeta[3]) + 
            773280*x^19*Zeta[3] - 249696*x^20*Zeta[3] - 54432*x^21*Zeta[3] + 
            23328*x^22*Zeta[3] - 504*x^17*(-27 + 6320*Zeta[3]) + 
            24*x^18*(-243 + 9064*Zeta[3]) + 64*x^12*(-148571 + 
              13605*Zeta[3]) + 48*x^4*(-4781 + 13662*Zeta[3]) - 
            36*x^10*(1081957 + 23568*Zeta[3]) + 144*x^8*(-76003 + 
              42600*Zeta[3]) + 9*x^3*(-126455 + 4608*Log[2]^4 + 
              110592*PolyLog[4, 1/2] + 62496*Zeta[3]) + 
            24*x^16*(2439 + 74432*Zeta[3]) + 9*x^15*(11425 + 4608*Log[2]^4 + 
              110592*PolyLog[4, 1/2] + 785920*Zeta[3]) - 
            12*x^9*(-2262319 + 216576*Log[2]^4 + 5197824*PolyLog[4, 1/2] + 
              3610528*Zeta[3]) - 2*x^5*(-5258119 + 271872*Log[2]^4 + 
              6524928*PolyLog[4, 1/2] + 4146480*Zeta[3]) - 
            2*x^13*(2080841 + 271872*Log[2]^4 + 6524928*PolyLog[4, 1/2] + 
              8021952*Zeta[3]) + 3*x^7*(-4668595 + 600576*Log[2]^4 + 
              14413824*PolyLog[4, 1/2] + 11145152*Zeta[3]) + 
            3*x^11*(5596085 + 600576*Log[2]^4 + 14413824*PolyLog[4, 1/2] + 
              12868736*Zeta[3])))/(77760*x^5*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4))))
 
CbarData["v", 2, 1] = 
    NC*(CA*CF*((Pi^2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{-2}, x])/(324*(-1 + x^2)^4) + 
        lm^2*((-11*(3 + 4*x - 21*x^2 + 40*x^3 - 21*x^4 + 4*x^5 + 3*x^6))/
           (288*(-1 + x^2)^4) + (11*x^3*(2 - 3*x + 2*x^2)*HPL[{0}, x])/
           (12*(-1 + x^2)^5)) - (Pi^2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{2}, x])/(324*(-1 + x^2)^4) + 
        (x*(-237 + 653*x - 342*x^2 - 2627*x^3 - 10926*x^4 + 13653*x^5 + 
           3714*x^6 - 12905*x^7 - 6138*x^8 + 9991*x^9 + 3636*x^10 - 
           5782*x^11 - 508*x^12 + 2042*x^13 - 388*x^14 - 315*x^15 + 135*x^16)*
          HPL[{-2, 0}, x])/(648*(-1 + x^2)^6) + 
        ((-1620 + 3780*x + 2226*x^2 - 18834*x^3 + 10110*x^4 + 
           (50827 + 432*Pi^2)*x^5 + 16*(901 + 36*Pi^2)*x^6 - 
           16*(8741 + 300*Pi^2)*x^7 + 8*(5149 + 936*Pi^2)*x^8 + 151646*x^9 - 
           8*(-5149 + 936*Pi^2)*x^10 + 16*(-8741 + 300*Pi^2)*x^11 - 
           16*(-901 + 36*Pi^2)*x^12 + (50827 - 432*Pi^2)*x^13 + 10110*x^14 - 
           18834*x^15 + 2226*x^16 + 3780*x^17 - 1620*x^18)*HPL[{-1, 0}, x])/
         (15552*x^5*(-1 + x^2)^5) + (x*(-691092 + 2541780*x - 22315662*x^2 + 
           2977857*x^3 + 488417472*x^4 - 679367181*x^5 - 1325077662*x^6 + 
           2887391724*x^7 - 4800441492*x^8 + 8768691812*x^9 - 
           18749220934*x^10 + 10454311599*x^11 + 624638642*x^12 - 
           3856727449*x^13 + 536442282*x^14 + 573618462*x^15 - 
           63331428*x^16 - 73746126*x^17 + 16193412*x^18 + 7411014*x^19 - 
           2702646*x^20 - 306180*x^21 + 131220*x^22)*HPL[{0, 0}, x])/
         (7776*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) - 
        ((-1620 + 3780*x + 2226*x^2 - 18834*x^3 + 10110*x^4 + 
           (50827 + 432*Pi^2)*x^5 + 16*(901 + 36*Pi^2)*x^6 - 
           16*(8741 + 300*Pi^2)*x^7 + 8*(5149 + 936*Pi^2)*x^8 + 151646*x^9 - 
           8*(-5149 + 936*Pi^2)*x^10 + 16*(-8741 + 300*Pi^2)*x^11 - 
           16*(-901 + 36*Pi^2)*x^12 + (50827 - 432*Pi^2)*x^13 + 10110*x^14 - 
           18834*x^15 + 2226*x^16 + 3780*x^17 - 1620*x^18)*HPL[{1, 0}, x])/
         (15552*x^5*(-1 + x^2)^5) + 
        lm*(-(44*Pi^2*(-9 - 12*x + 41*x^2 - 41*x^4 + 12*x^5 + 9*x^6) + 
             3*(2505 + 480*x - 11969*x^2 + 24864*x^3 - 11969*x^4 + 480*x^5 + 
               2505*x^6))/(15552*(-1 + x^2)^4) + 
          (x^2*(198 + 8310*x - 12839*x^2 + 11874*x^3 - 2178*x^4 + 396*x^5 + 
             297*x^6)*HPL[{0}, x])/(648*(-1 + x^2)^5) + 
          (11*(9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{-1, 0}, x])/
           (324*(-1 + x^2)^3) - (11*x^3*(216 - 324*x + 648*x^2 - 516*x^3 + 
             408*x^4 - 59*x^5 + 12*x^6 + 9*x^7)*HPL[{0, 0}, x])/
           (162*(-1 + x^2)^6) - (11*(9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*
            HPL[{1, 0}, x])/(324*(-1 + x^2)^3)) + 
        (x*(237 - 653*x + 342*x^2 + 2627*x^3 + 10926*x^4 - 13653*x^5 - 
           3714*x^6 + 12905*x^7 + 6138*x^8 - 9991*x^9 - 3636*x^10 + 
           5782*x^11 + 508*x^12 - 2042*x^13 + 388*x^14 + 315*x^15 - 135*x^16)*
          HPL[{2, 0}, x])/(648*(-1 + x^2)^6) - 
        ((9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{-2, -1, 0}, x])/(27*(-1 + x^2)^4) + 
        (4*x^2*(-25 + 84*x - 66*x^2 + 12*x^3 + 9*x^4)*HPL[{-2, 0, 0}, x])/
         (27*(-1 + x^2)^4) + ((9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{-2, 1, 0}, x])/(27*(-1 + x^2)^4) + 
        ((9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{-1, -2, 0}, x])/(27*(-1 + x^2)^4) - 
        ((135 - 315*x + 17*x^2 + 1097*x^3 - 862*x^4 - 1546*x^5 + 1134*x^6 + 
           2143*x^7 + 632*x^8 - 3990*x^9 + 632*x^10 + 2143*x^11 + 1134*x^12 - 
           1546*x^13 - 862*x^14 + 1097*x^15 + 17*x^16 - 315*x^17 + 135*x^18)*
          HPL[{-1, -1, 0}, x])/(1296*x^7*(-1 + x^2)^3) + 
        ((-607 + 2449*x - 6739*x^2 + 16113*x^3 - 24253*x^4 + 19605*x^5 - 
           3251*x^6 - 2907*x^7 - 4345*x^8 + 6403*x^9 + 527*x^10 - 3821*x^11 + 
           1333*x^12 + 647*x^13 - 585*x^14 + 135*x^15)*HPL[{-1, 0, 0}, x])/
         (648*(-1 + x)^6*(1 + x)^4) + ((135 - 315*x + 17*x^2 + 1097*x^3 - 
           862*x^4 - 1546*x^5 + 1134*x^6 + 2143*x^7 + 632*x^8 - 3990*x^9 + 
           632*x^10 + 2143*x^11 + 1134*x^12 - 1546*x^13 - 862*x^14 + 
           1097*x^15 + 17*x^16 - 315*x^17 + 135*x^18)*HPL[{-1, 1, 0}, x])/
         (1296*x^7*(-1 + x^2)^3) - ((9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{-1, 2, 0}, x])/(27*(-1 + x^2)^4) + 
        (x*(19197 - 35397*x + 2323026*x^2 - 3299499*x^3 - 37904334*x^4 + 
           59164897*x^5 + 75611898*x^6 - 111515963*x^7 + 345395808*x^8 - 
           1029716517*x^9 + 2019841118*x^10 - 1070436685*x^11 + 
           114698222*x^12 + 233298519*x^13 - 151335162*x^14 + 75392045*x^15 + 
           23546141*x^16 - 46441042*x^17 + 3653408*x^18 + 11302848*x^19 - 
           2922300*x^20 - 1260684*x^21 + 461376*x^22 + 51030*x^23 - 
           21870*x^24)*HPL[{0, 0, 0}, x])/(648*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) - ((9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{1, -2, 0}, x])/(27*(-1 + x^2)^4) + 
        ((135 - 315*x + 17*x^2 + 1097*x^3 - 862*x^4 - 1546*x^5 + 1134*x^6 + 
           2143*x^7 + 632*x^8 - 3990*x^9 + 632*x^10 + 2143*x^11 + 1134*x^12 - 
           1546*x^13 - 862*x^14 + 1097*x^15 + 17*x^16 - 315*x^17 + 135*x^18)*
          HPL[{1, -1, 0}, x])/(1296*x^7*(-1 + x^2)^3) + 
        ((607 - 885*x - 1081*x^2 - 3865*x^3 + 2485*x^4 + 2743*x^5 + 
           1663*x^6 - 7117*x^7 - 3639*x^8 + 4169*x^9 + 2989*x^10 - 
           1827*x^11 - 861*x^12 + 613*x^13 + 45*x^14 - 135*x^15)*
          HPL[{1, 0, 0}, x])/(648*(-1 + x)^4*(1 + x)^6) - 
        ((135 - 315*x + 17*x^2 + 1097*x^3 - 862*x^4 - 1546*x^5 + 1134*x^6 + 
           2143*x^7 + 632*x^8 - 3990*x^9 + 632*x^10 + 2143*x^11 + 1134*x^12 - 
           1546*x^13 - 862*x^14 + 1097*x^15 + 17*x^16 - 315*x^17 + 135*x^18)*
          HPL[{1, 1, 0}, x])/(1296*x^7*(-1 + x^2)^3) + 
        ((9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{1, 2, 0}, x])/(27*(-1 + x^2)^4) + 
        ((9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{2, -1, 0}, x])/(27*(-1 + x^2)^4) - 
        (4*x^2*(-25 + 84*x - 66*x^2 + 12*x^3 + 9*x^4)*HPL[{2, 0, 0}, x])/
         (27*(-1 + x^2)^4) - ((9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{2, 1, 0}, x])/(27*(-1 + x^2)^4) - 
        (2*(9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{-1, 0, 0, 0}, x])/
         (27*(-1 + x^2)^3) + (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{-1, 1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{1, -1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        (2*(9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{1, 0, 0, 0}, x])/
         (27*(-1 + x^2)^3) - ((18 + 41*x - 167*x^2 + 475*x^3 - 364*x^4 + 
           163*x^5 + 33*x^6 + 17*x^7)*master3l10a[x])/(432*(-1 + x^2)^5) + 
        (x*(17 + 33*x + 163*x^2 - 364*x^3 + 475*x^4 - 167*x^5 + 41*x^6 + 
           18*x^7)*master3l10b[x])/(432*(-1 + x^2)^5) + 
        ((-37341 + 102897*x - 31860*x^2 + 3816*x^3 - 28278*x^4 + 83922*x^5 + 
           3916*x^6 - 19744*x^7 + 1003*x^8 + 1141*x^9 - 112*x^10)*
          master3l8a[x])/(2592*(-9 + x^2)^2*(-1 + x^2)^6) + 
        ((474 - 754*x - 8031*x^2 + 13071*x^3 + 35748*x^4 - 11232*x^5 - 
           160038*x^6 - 290070*x^7 + 1260954*x^8 - 998838*x^9 + 339309*x^10 + 
           59535*x^11)*master3l8b[x])/(7776*x*(1 - 9*x^2)^2*(-1 + x^2)^6) + 
        ((9531 + 1701*x - 49122*x^2 + 69606*x^3 - 16860*x^4 - 15144*x^5 - 
           3150*x^6 + 3594*x^7 + 209*x^8 - 237*x^9)*master3l9a[x])/
         (2592*(-9 + x^2)*(-1 + x^2)^6) + 
        ((-237 + 209*x + 3594*x^2 - 3150*x^3 - 15144*x^4 - 16860*x^5 + 
           69606*x^6 - 49122*x^7 + 1701*x^8 + 9531*x^9)*master3l9b[x])/
         (7776*x*(-1 + x^2)^6*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(135 - 315*x - 118*x^2 + 1412*x^3 - 879*x^4 - 
             2643*x^5 + 1996*x^6 + 3689*x^7 - 502*x^8 - 6133*x^9 + 
             6133*x^11 + 502*x^12 - 3689*x^13 - 1996*x^14 + 2643*x^15 + 
             879*x^16 - 1412*x^17 + 118*x^18 + 315*x^19 - 135*x^20) - 
           576*x^7*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
            Zeta[3]))/(15552*x^7*(-1 + x^2)^4) + 
        (HPL[{-1}, x]*(Pi^2*(-135 + 315*x + 118*x^2 - 1412*x^3 + 879*x^4 + 
             2643*x^5 - 1996*x^6 - 3689*x^7 + 502*x^8 + 6133*x^9 - 
             6133*x^11 - 502*x^12 + 3689*x^13 + 1996*x^14 - 2643*x^15 - 
             879*x^16 + 1412*x^17 - 118*x^18 - 315*x^19 + 135*x^20) + 
           576*x^7*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
            Zeta[3]))/(15552*x^7*(-1 + x^2)^4) + 
        (HPL[{0}, x]*(131220 - 306180*x - 2637036*x^2 + 7257924*x^3 + 
           27*(713435 + 2844*Pi^2)*x^4 - 81*(996919 + 2612*Pi^2)*x^5 + 
           18*(372132793 + 17939974*Pi^2)*x^12 + 
           8*(-50562873 + 29323190*Pi^2)*x^19 + (47817405 + 35113516*Pi^2)*
            x^20 + (7194501 - 95478620*Pi^2)*x^21 + 4*(659259 + 1826704*Pi^2)*
            x^22 + 108*(2835 + 209312*Pi^2)*x^23 - 180*(729 + 32470*Pi^2)*
            x^24 - 2521368*Pi^2*x^25 + 922752*Pi^2*x^26 + 102060*Pi^2*x^27 - 
           43740*Pi^2*x^28 + 12*x^16*(-170030617 + 18013674*Pi^2 - 
             15303168*Zeta[3]) - 6*x^18*(119412331 + 23410932*Pi^2 - 
             1679616*Zeta[3]) + 12*x^7*(54569765 + 392205*Pi^2 + 
             1259712*Zeta[3]) - 6*x^6*(16926221 + 214740*Pi^2 + 
             1679616*Zeta[3]) - 4*x^17*(-1093420074 + 97651333*Pi^2 + 
             3779136*Zeta[3]) + 12*x^8*(49261735 + 670732*Pi^2 + 
             15303168*Zeta[3]) - 4*x^9*(761133737 + 9479903*Pi^2 + 
             72643392*Zeta[3]) + 4*x^15*(-2835103570 + 124443503*Pi^2 + 
             72643392*Zeta[3]) - 10*x^10*(269946041 + 5768964*Pi^2 + 
             84665088*Zeta[3]) + 4*x^11*(1623803795 + 40250483*Pi^2 + 
             390137472*Zeta[3]) - 2*x^13*(11649268015 + 235603908*Pi^2 + 
             780274944*Zeta[3]) + x^14*(31272679562 - 204111528*Pi^2 + 
             846650880*Zeta[3])))/(31104*x^3*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) + 
        (192*Pi^4*x^5*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(-27 - 36*x - 127*x^2 + 
            840*x^3 - 783*x^4 + 156*x^5 + 117*x^6) + 
          20*Pi^2*(9 - 82*x^2 + 9*x^4)^2*(-1620 + 3780*x + 3846*x^2 - 
            22614*x^3 + 7884*x^4 + 69661*x^5 + 4306*x^6 - 190683*x^7 + 
            26776*x^8 + 291502*x^9 - 291502*x^11 - 26776*x^12 + 190683*x^13 - 
            4306*x^14 - 69661*x^15 - 7884*x^16 + 22614*x^17 - 3846*x^18 - 
            3780*x^19 + 1620*x^20) + 15*x^2*(-262440 + 612360*x + 
            6513372*x^2 + x^19*(850506525 - 5321320224*Zeta[3]) + 
            60512832*x^25*Zeta[3] - 22146048*x^26*Zeta[3] - 
            2449440*x^27*Zeta[3] + 1049760*x^28*Zeta[3] + 
            1080*x^24*(-243 + 129880*Zeta[3]) - 81*x^3*(-308681 + 
              136032*Zeta[3]) + 576*x^8*(-4834897 + 209683*Zeta[3]) - 
            648*x^23*(-945 + 837248*Zeta[3]) - 54*x^4*(2063963 + 
              858384*Zeta[3]) - 48*x^22*(-111699 + 3653408*Zeta[3]) + 
            320*x^15*(32888314 + 7363999*Zeta[3]) - 576*x^16*
             (-16189023 + 7596044*Zeta[3]) - 78*x^20*(985599 + 
              11322160*Zeta[3]) + 24*x^6*(44166181 + 26476848*Zeta[3]) + 
            9*x^5*(-64758355 + 43345344*Zeta[3]) - 32*x^7*(-85793689 + 
              139597266*Zeta[3]) + 32*x^17*(-205345991 + 177973578*Zeta[3]) + 
            64*x^9*(-29820655 + 278960516*Zeta[3]) + 
            12*x^18*(8455727 + 324389088*Zeta[3]) + 
            3*x^21*(-13629573 + 761182528*Zeta[3]) - 
            16*x^10*(66993491 + 1354138632*Zeta[3]) - 
            8*x^14*(6333169117 + 2364596496*Zeta[3]) - 
            2*x^11*(-7081057873 + 5951018992*Zeta[3]) + 
            4*x^12*(-11419095443 + 7061259672*Zeta[3]) + 
            x^13*(48247071506 + 8324488192*Zeta[3])))/
         (3732480*x^5*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF^2*(-(Pi^2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
           HPL[{-2}, x])/(162*(-1 + x^2)^4) + 
        lm^2*((3 + 4*x - 21*x^2 + 40*x^3 - 21*x^4 + 4*x^5 + 3*x^6)/
           (16*(-1 + x^2)^4) - (3*x^3*(2 - 3*x + 2*x^2)*HPL[{0}, x])/
           (2*(-1 + x^2)^5)) + (Pi^2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{2}, x])/(162*(-1 + x^2)^4) + 
        (x*(237 - 653*x + 2574*x^2 + 1343*x^3 + 13422*x^4 - 16729*x^5 - 
           12850*x^6 + 25229*x^7 + 26902*x^8 - 33433*x^9 - 25170*x^10 + 
           31124*x^11 + 12054*x^12 - 18780*x^13 - 1010*x^14 + 6489*x^15 - 
           1431*x^16 - 972*x^17 + 432*x^18)*HPL[{-2, 0}, x])/
         (324*(-1 + x^2)^6) + ((-25920 + 58320*x + 46980*x^2 - 301860*x^3 + 
           141870*x^4 + 649710*x^5 - 528930*x^6 - (760111 + 2160*Pi^2)*x^7 + 
           (631130 - 2880*Pi^2)*x^8 + 12*(44447 + 2000*Pi^2)*x^9 - 
           10*(71993 + 3744*Pi^2)*x^10 + 24074*x^11 + 10*(-71993 + 3744*Pi^2)*
            x^12 + (533364 - 24000*Pi^2)*x^13 + 10*(63113 + 288*Pi^2)*x^14 + 
           (-760111 + 2160*Pi^2)*x^15 - 528930*x^16 + 649710*x^17 + 
           141870*x^18 - 301860*x^19 + 46980*x^20 + 58320*x^21 - 25920*x^22)*
          HPL[{-1, 0}, x])/(38880*x^7*(-1 + x^2)^5) + 
        (x*(3455460 - 15138900*x + 106844670*x^2 + 54584955*x^3 - 
           2371620060*x^4 + 2752779765*x^5 + 6548689290*x^6 - 
           12670752360*x^7 + 21957484950*x^8 - 41908771904*x^9 + 
           99066420010*x^10 - 56471596471*x^11 - 12968282210*x^12 + 
           28308384601*x^13 + 3623430450*x^14 - 10733640426*x^15 - 
           1399754370*x^16 + 4127948946*x^17 - 345854880*x^18 - 
           1010294370*x^19 + 278399430*x^20 + 115254900*x^21 - 
           44162820*x^22 - 4723920*x^23 + 2099520*x^24)*HPL[{0, 0}, x])/
         (19440*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        ((25920 - 58320*x - 46980*x^2 + 301860*x^3 - 141870*x^4 - 
           649710*x^5 + 528930*x^6 + (760111 + 2160*Pi^2)*x^7 + 
           10*(-63113 + 288*Pi^2)*x^8 - 12*(44447 + 2000*Pi^2)*x^9 + 
           10*(71993 + 3744*Pi^2)*x^10 - 24074*x^11 + (719930 - 37440*Pi^2)*
            x^12 + 12*(-44447 + 2000*Pi^2)*x^13 - 10*(63113 + 288*Pi^2)*
            x^14 + (760111 - 2160*Pi^2)*x^15 + 528930*x^16 - 649710*x^17 - 
           141870*x^18 + 301860*x^19 - 46980*x^20 - 58320*x^21 + 25920*x^22)*
          HPL[{1, 0}, x])/(38880*x^7*(-1 + x^2)^5) + 
        lm*((2*Pi^2*(-9 - 12*x + 41*x^2 - 41*x^4 + 12*x^5 + 9*x^6) + 
            3*(84 - 18*x - 335*x^2 + 732*x^3 - 335*x^4 - 18*x^5 + 84*x^6))/
           (432*(-1 + x^2)^4) - (x^2*(18 + 636*x - 988*x^2 + 960*x^3 - 
             198*x^4 + 36*x^5 + 27*x^6)*HPL[{0}, x])/(36*(-1 + x^2)^5) - 
          ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{-1, 0}, x])/
           (18*(-1 + x^2)^3) + (x^3*(216 - 324*x + 648*x^2 - 516*x^3 + 
             408*x^4 - 59*x^5 + 12*x^6 + 9*x^7)*HPL[{0, 0}, x])/
           (9*(-1 + x^2)^6) + ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*
            HPL[{1, 0}, x])/(18*(-1 + x^2)^3)) - 
        (x*(237 - 653*x + 2574*x^2 + 1343*x^3 + 13422*x^4 - 16729*x^5 - 
           12850*x^6 + 25229*x^7 + 26902*x^8 - 33433*x^9 - 25170*x^10 + 
           31124*x^11 + 12054*x^12 - 18780*x^13 - 1010*x^14 + 6489*x^15 - 
           1431*x^16 - 972*x^17 + 432*x^18)*HPL[{2, 0}, x])/
         (324*(-1 + x^2)^6) + (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{-2, -1, 0}, x])/(27*(-1 + x^2)^4) - 
        (4*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{-2, 0, 0}, x])/(27*(-1 + x^2)^4) - 
        (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{-2, 1, 0}, x])/(27*(-1 + x^2)^4) - 
        (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{-1, -2, 0}, x])/(27*(-1 + x^2)^4) - 
        ((432 - 972*x + 729*x^2 + 1629*x^3 - 1685*x^4 - 915*x^5 + 659*x^6 + 
           539*x^7 + 105*x^8 - 762*x^9 + 105*x^10 + 539*x^11 + 659*x^12 - 
           915*x^13 - 1685*x^14 + 1629*x^15 + 729*x^16 - 972*x^17 + 432*x^18)*
          HPL[{-1, -1, 0}, x])/(648*x^9*(-1 + x^2)) + 
        ((539 - 2855*x + 9573*x^2 - 22697*x^3 + 32581*x^4 - 23191*x^5 - 
           2759*x^6 + 6015*x^7 + 18889*x^8 - 18473*x^9 - 14513*x^10 + 
           22329*x^11 + 979*x^12 - 12233*x^13 + 4707*x^14 + 1809*x^15 - 
           1836*x^16 + 432*x^17)*HPL[{-1, 0, 0}, x])/(324*(-1 + x)^6*
          (1 + x)^4) + ((432 - 972*x + 729*x^2 + 1629*x^3 - 1685*x^4 - 
           915*x^5 + 659*x^6 + 539*x^7 + 105*x^8 - 762*x^9 + 105*x^10 + 
           539*x^11 + 659*x^12 - 915*x^13 - 1685*x^14 + 1629*x^15 + 
           729*x^16 - 972*x^17 + 432*x^18)*HPL[{-1, 1, 0}, x])/
         (648*x^9*(-1 + x^2)) + (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{-1, 2, 0}, x])/(27*(-1 + x^2)^4) + 
        (x*(19197 - 70389*x - 1801899*x^2 + 3709026*x^3 + 17768640*x^4 - 
           42162548*x^5 + 52320264*x^6 + 125260764*x^7 - 743446890*x^8 - 
           14488642*x^9 + 347876102*x^10 + 524255480*x^11 - 1281473696*x^12 + 
           480514932*x^13 - 993855000*x^14 + 768275246*x^15 + 
           793414035*x^16 - 921121819*x^17 - 302564197*x^18 + 
           526697922*x^19 + 33227644*x^20 - 188300772*x^21 + 26058924*x^22 + 
           39504834*x^23 - 11517282*x^24 - 4078026*x^25 + 1577070*x^26 + 
           157464*x^27 - 69984*x^28)*HPL[{0, 0, 0}, x])/
         (324*(-1 + x^2)^7*(9 - 82*x^2 + 9*x^4)^2) + 
        (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{1, -2, 0}, x])/(27*(-1 + x^2)^4) + 
        ((432 - 972*x + 729*x^2 + 1629*x^3 - 1685*x^4 - 915*x^5 + 659*x^6 + 
           539*x^7 + 105*x^8 - 762*x^9 + 105*x^10 + 539*x^11 + 659*x^12 - 
           915*x^13 - 1685*x^14 + 1629*x^15 + 729*x^16 - 972*x^17 + 432*x^18)*
          HPL[{1, -1, 0}, x])/(648*x^9*(-1 + x^2)) + 
        ((-539 + 1563*x + 415*x^2 + 3177*x^3 - 1189*x^4 - 5949*x^5 - 
           4517*x^6 + 17113*x^7 + 11735*x^8 - 18099*x^9 - 15363*x^10 + 
           12543*x^11 + 9325*x^12 - 5947*x^13 - 2439*x^14 + 2079*x^15 + 
           108*x^16 - 432*x^17)*HPL[{1, 0, 0}, x])/(324*(-1 + x)^4*
          (1 + x)^6) - ((432 - 972*x + 729*x^2 + 1629*x^3 - 1685*x^4 - 
           915*x^5 + 659*x^6 + 539*x^7 + 105*x^8 - 762*x^9 + 105*x^10 + 
           539*x^11 + 659*x^12 - 915*x^13 - 1685*x^14 + 1629*x^15 + 
           729*x^16 - 972*x^17 + 432*x^18)*HPL[{1, 1, 0}, x])/
         (648*x^9*(-1 + x^2)) - (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 
           12*x^5 + 9*x^6)*HPL[{1, 2, 0}, x])/(27*(-1 + x^2)^4) - 
        (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{2, -1, 0}, x])/(27*(-1 + x^2)^4) + 
        (4*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{2, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        (2*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{2, 1, 0}, x])/(27*(-1 + x^2)^4) - 
        (4*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{-1, 1, 0, 0}, x])/(27*(-1 + x^2)^4) - 
        (4*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
          HPL[{1, -1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        ((18 + 41*x - 167*x^2 + 475*x^3 - 364*x^4 + 163*x^5 + 33*x^6 + 
           17*x^7)*master3l10a[x])/(216*(-1 + x^2)^5) - 
        (x*(17 + 33*x + 163*x^2 - 364*x^3 + 475*x^4 - 167*x^5 + 41*x^6 + 
           18*x^7)*master3l10b[x])/(216*(-1 + x^2)^5) + 
        ((37341 - 102897*x + 31860*x^2 - 3816*x^3 + 28278*x^4 - 83922*x^5 - 
           3916*x^6 + 19744*x^7 - 1003*x^8 - 1141*x^9 + 112*x^10)*
          master3l8a[x])/(1296*(-9 + x^2)^2*(-1 + x^2)^6) + 
        ((-474 + 754*x + 8031*x^2 - 13071*x^3 - 35748*x^4 + 11232*x^5 + 
           160038*x^6 + 290070*x^7 - 1260954*x^8 + 998838*x^9 - 339309*x^10 - 
           59535*x^11)*master3l8b[x])/(3888*x*(1 - 9*x^2)^2*(-1 + x^2)^6) + 
        ((-9531 - 1701*x + 49122*x^2 - 69606*x^3 + 16860*x^4 + 15144*x^5 + 
           3150*x^6 - 3594*x^7 - 209*x^8 + 237*x^9)*master3l9a[x])/
         (1296*(-9 + x^2)*(-1 + x^2)^6) + 
        ((237 - 209*x - 3594*x^2 + 3150*x^3 + 15144*x^4 + 16860*x^5 - 
           69606*x^6 + 49122*x^7 - 1701*x^8 - 9531*x^9)*master3l9b[x])/
         (3888*x*(-1 + x^2)^6*(-1 + 9*x^2)) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(432 - 972*x + 729*x^2 + 1629*x^3 - 
             1685*x^4 - 915*x^5 + 659*x^6 + 539*x^7 + 105*x^8 - 762*x^9 + 
             105*x^10 + 539*x^11 + 659*x^12 - 915*x^13 - 1685*x^14 + 
             1629*x^15 + 729*x^16 - 972*x^17 + 432*x^18) - 
           576*x^9*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
            Zeta[3]))/(7776*x^9*(-1 + x^2)^4) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(432 - 972*x + 729*x^2 + 1629*x^3 - 
              1685*x^4 - 915*x^5 + 659*x^6 + 539*x^7 + 105*x^8 - 762*x^9 + 
              105*x^10 + 539*x^11 + 659*x^12 - 915*x^13 - 1685*x^14 + 
              1629*x^15 + 729*x^16 - 972*x^17 + 432*x^18)) + 
           576*x^9*(9 + 12*x - 91*x^2 + 168*x^3 - 91*x^4 + 12*x^5 + 9*x^6)*
            Zeta[3]))/(7776*x^9*(-1 + x^2)^4) + 
        (HPL[{0}, x]*(2099520 - 4723920*x - 43113060*x^2 + 112892940*x^3 + 
           257017860*x^4 - 954241560*x^5 - 135*(1798043 + 2844*Pi^2)*x^6 + 
           27*(137601311 + 39180*Pi^2)*x^7 - 30*(1295918739 + 73193018*Pi^2)*
            x^14 - 2*(707711931 + 2939554100*Pi^2)*x^21 - 
           15*(5917167 + 164944900*Pi^2)*x^22 + 
           15*(59120361 + 250163564*Pi^2)*x^23 + 
           20*(-12850893 + 24638186*Pi^2)*x^24 - 180*(627183 + 8484250*Pi^2)*
            x^25 + 180*(239517 + 891596*Pi^2)*x^26 + 6480*(729 + 54914*Pi^2)*
            x^27 - 1080*(1944 + 92687*Pi^2)*x^28 - 39205620*Pi^2*x^29 + 
           15070860*Pi^2*x^30 + 1574640*Pi^2*x^31 - 699840*Pi^2*x^32 + 
           20*x^16*(-6750934609 + 149833600*Pi^2 - 211662720*Zeta[3]) + 
           60*x^10*(73210591 + 360020*Pi^2 - 15303168*Zeta[3]) + 
           120*x^20*(45335611 + 38657056*Pi^2 - 419904*Zeta[3]) + 
           120*x^8*(-11436085 + 23553*Pi^2 + 419904*Zeta[3]) - 
           18*x^9*(525072367 + 1191790*Pi^2 + 4199040*Zeta[3]) + 
           2*x^19*(-7272744687 + 3162728950*Pi^2 + 37791360*Zeta[3]) + 
           10*x^11*(1875002741 + 15667750*Pi^2 + 145286784*Zeta[3]) - 
           10*x^17*(-4923227725 + 500791666*Pi^2 + 145286784*Zeta[3]) + 
           20*x^12*(-88859507 + 3476970*Pi^2 + 211662720*Zeta[3]) + 
           x^18*(2187200820 - 4868564960*Pi^2 + 918190080*Zeta[3]) + 
           4*x^15*(26579607073 + 785885660*Pi^2 + 1950687360*Zeta[3]) - 
           2*x^13*(9691774181 + 369472790*Pi^2 + 3901374720*Zeta[3])))/
         (77760*x^5*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        (-960*Pi^4*x^7*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(9 + 12*x - 91*x^2 + 
            168*x^3 - 91*x^4 + 12*x^5 + 9*x^6) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^
            2*(-25920 + 58320*x + 72900*x^2 - 360180*x^3 + 94890*x^4 + 
            951570*x^5 - 670800*x^6 - 1409821*x^7 + 1160060*x^8 + 
            1293475*x^9 - 1351060*x^10 - 509290*x^11 + 509290*x^13 + 
            1351060*x^14 - 1293475*x^15 - 1160060*x^16 + 1409821*x^17 + 
            670800*x^18 - 951570*x^19 - 94890*x^20 + 360180*x^21 - 
            72900*x^22 - 58320*x^23 + 25920*x^24) + 
          3*x^2*(-4199040 + 9447840*x + 87625800*x^2 - 228935160*x^3 - 
            548011980*x^4 + 940934880*x^29*Zeta[3] - 361700640*x^30*Zeta[3] - 
            37791360*x^31*Zeta[3] + 16796160*x^32*Zeta[3] + 
            1215*x^5*(1451777 + 27552*Zeta[3]) + 25920*x^28*
             (-162 + 92687*Zeta[3]) + 1620*x^6*(713077 + 113448*Zeta[3]) - 
            38880*x^27*(-243 + 219656*Zeta[3]) - 1080*x^26*
             (-81135 + 3566384*Zeta[3]) - 240*x^8*(19294325 + 
              10468836*Zeta[3]) - 40*x^10*(-383704957 + 13834992*Zeta[3]) + 
            1080*x^25*(-211977 + 33937000*Zeta[3]) - 240*x^24*
             (2259387 + 49276372*Zeta[3]) - 27*x^7*(151252799 + 
              50732160*Zeta[3]) + 160*x^16*(1695921907 + 112187556*Zeta[3]) + 
            180*x^22*(5457213 + 330766328*Zeta[3]) - 300*x^20*
             (-539867 + 378124512*Zeta[3]) + 24*x^9*(93977389 + 
              706769520*Zeta[3]) - 168*x^19*(-290701227 + 822165800*Zeta[
                3]) - 45*x^23*(-46519299 + 2000844544*Zeta[3]) + 
            40*x^12*(584505493 + 2126823960*Zeta[3]) - 
            40*x^14*(-4695631559 + 2457167580*Zeta[3]) + 
            40*x^18*(-1130017283 + 2869264512*Zeta[3]) + 
            10*x^13*(-4883205809 + 4854305488*Zeta[3]) - 
            10*x^15*(21925683689 + 6531003968*Zeta[3]) + 
            8*x^17*(-10657102301 + 7997578120*Zeta[3]) - 
            8*x^11*(2886613301 + 8846381480*Zeta[3]) + 
            3*x^21*(-3750161391 + 46688781920*Zeta[3])))/
         (1866240*x^7*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF*(NH*((x*(279936 + 602640*x + 103809600*x^2 - 146091951*x^3 + 
             83073096*x^4 + 15027336*x^5 - 28227792*x^6 + 9410845*x^7 + 
             1967664*x^8 - 2313096*x^9 + 9600*x^10 + 204747*x^11 - 696*x^12 - 
             7280*x^13 - 48*x^14 + 39*x^15)*HPL[{0}, x])/(2592*(-9 + x^2)^2*
            (-1 + x^2)^7) + lm^2*((3 + 4*x - 21*x^2 + 40*x^3 - 21*x^4 + 
              4*x^5 + 3*x^6)/(144*(-1 + x^2)^4) - (x^3*(2 - 3*x + 2*x^2)*
              HPL[{0}, x])/(6*(-1 + x^2)^5)) + 
          (x*(-69984 - 972*x - 18742752*x^2 + 25800903*x^3 - 13080312*x^4 - 
             5241168*x^5 + 7334544*x^6 - 2006935*x^7 - 228864*x^8 + 
             526624*x^9 - 100464*x^10 - 31779*x^11 + 4440*x^12 - 324*x^13 + 
             192*x^14 + 51*x^15)*HPL[{0, 0}, x])/(648*(-9 + x^2)^2*
            (-1 + x^2)^7) + lm*((4*Pi^2*(-9 - 12*x + 41*x^2 - 41*x^4 + 
                12*x^5 + 9*x^6) + 3*(159 - 48*x - 607*x^2 + 1344*x^3 - 
                607*x^4 - 48*x^5 + 159*x^6))/(7776*(-1 + x^2)^4) - 
            (x^2*(18 + 618*x - 961*x^2 + 942*x^3 - 198*x^4 + 36*x^5 + 27*x^6)*
              HPL[{0}, x])/(324*(-1 + x^2)^5) - 
            ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{-1, 0}, x])/
             (162*(-1 + x^2)^3) + (x^3*(216 - 324*x + 648*x^2 - 516*x^3 + 408*
                x^4 - 59*x^5 + 12*x^6 + 9*x^7)*HPL[{0, 0}, x])/
             (81*(-1 + x^2)^6) + ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*
              HPL[{1, 0}, x])/(162*(-1 + x^2)^3)) + 
          ((-99 - 1329*x + 2438*x^2 - 2593*x^3 + 1392*x^4 - 622*x^5 + 
             56*x^6 + 6*x^7 - 9*x^8)*HPL[{-1, 0, 0}, x])/(81*(-1 + x)^6*
            (1 + x)^4) + (x^3*(650916 - 838863*x + 462024*x^2 + 137286*x^3 - 
             279972*x^4 + 83535*x^5 - 10776*x^6 - 18660*x^7 + 7764*x^8 + 
             2007*x^9 - 528*x^10 - 194*x^11 + 12*x^12 + 9*x^13)*
            HPL[{0, 0, 0}, x])/(81*(-9 + x^2)^2*(-1 + x^2)^7) + 
          ((-9 + 1671*x - 1838*x^2 + 1703*x^3 - 204*x^4 + 266*x^5 - 8*x^6 + 
             30*x^7 + 9*x^8)*HPL[{1, 0, 0}, x])/(81*(-1 + x)^4*(1 + x)^6) + 
          ((11259 + 922536*x - 1298700*x^2 + 852912*x^3 - 50481*x^4 - 
             120528*x^5 + 78944*x^6 + 4352*x^7 - 11511*x^8 - 408*x^9 + 
             748*x^10 + 16*x^11 - 19*x^12)*master3l8a[x])/(648*(-9 + x^2)^2*
            (-1 + x^2)^7) - ((3753 + 162864*x - 246069*x^2 + 199728*x^3 - 
             74676*x^4 + 44232*x^5 - 546*x^6 + 8760*x^7 + 249*x^8 - 888*x^9 - 
             169*x^10 + 24*x^11 + 18*x^12)*master3l9a[x])/
           (648*(-9 + x^2)*(-1 + x^2)^7) + 
          (x^4*(562595505 - 41296128*Zeta[3]) + x^10*(9051967 - 
              566400*Zeta[3]) + x^14*(63031 - 14720*Zeta[3]) + 
            8*x^15*(-299 + 96*Zeta[3]) + 88*x^11*(11407 + 96*Zeta[3]) - 
            972*x*(276687 + 512*Zeta[3]) + x^16*(-1127 + 576*Zeta[3]) - 
            12*x^13*(1313 + 3072*Zeta[3]) + 486*(-9671 + 3104*Zeta[3]) + 
            x^12*(-1137813 + 171008*Zeta[3]) + 216*x^3*(-2973303 + 
              201824*Zeta[3]) - 27*x^2*(-14258327 + 417920*Zeta[3]) + 
            12*x^9*(-1306261 + 543872*Zeta[3]) - 12*x^5*(20174379 + 
              1075328*Zeta[3]) - 24*x^7*(-5119201 + 1528800*Zeta[3]) - 
            3*x^8*(6926713 + 2624000*Zeta[3]) + 3*x^6*(-43372449 + 
              19784320*Zeta[3]))/(15552*(-9 + x^2)^2*(-1 + x^2)^7)) + 
        NM*(((-8*Pi^2*(1 - 9*x^2)^2*(-1 + x^2)^4*(9 + 12*x - 32*x^2 + 12*
                x^3 + 9*x^4) + 3*(-1368 - 1824*x + 24748*x^2 + 79248*x^3 - 
               174139*x^4 - 1096752*x^5 + 1244220*x^6 + 187272*x^7 - 1834455*
                x^8 + 32172480*x^9 - 32680900*x^10 + 73015008*x^11 - 57556425*
                x^12 + 45611856*x^13 - 34358148*x^14 + 10944072*x^15 + 
               2169747*x^16))*HPL[{0}, x])/(7776*(1 - 9*x^2)^2*
            (-1 + x^2)^7) + lm^2*((3 + 4*x - 21*x^2 + 40*x^3 - 21*x^4 + 
              4*x^5 + 3*x^6)/(144*(-1 + x^2)^4) - (x^3*(2 - 3*x + 2*x^2)*
              HPL[{0}, x])/(6*(-1 + x^2)^5)) + 
          ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{-2, 0}, x])/
           (81*(-1 + x^2)^3) + ((216 + 288*x - 2664*x^2 - 13392*x^3 + 
             5587*x^4 + 115776*x^5 - 14316*x^6 + 1490328*x^7 - 1540795*x^8 - 
             10061424*x^9 + 12074508*x^10 - 38492784*x^11 + 31899393*x^12 - 
             30345840*x^13 + 23847048*x^14 - 7295832*x^15 - 1511217*x^16)*
            HPL[{0, 0}, x])/(648*(1 - 9*x^2)^2*(-1 + x^2)^7) + 
          lm*((4*Pi^2*(-9 - 12*x + 41*x^2 - 41*x^4 + 12*x^5 + 9*x^6) + 
              3*(159 - 48*x - 607*x^2 + 1344*x^3 - 607*x^4 - 48*x^5 + 
                159*x^6))/(7776*(-1 + x^2)^4) - 
            (x^2*(18 + 618*x - 961*x^2 + 942*x^3 - 198*x^4 + 36*x^5 + 27*x^6)*
              HPL[{0}, x])/(324*(-1 + x^2)^5) - 
            ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{-1, 0}, x])/
             (162*(-1 + x^2)^3) + (x^3*(216 - 324*x + 648*x^2 - 516*x^3 + 408*
                x^4 - 59*x^5 + 12*x^6 + 9*x^7)*HPL[{0, 0}, x])/
             (81*(-1 + x^2)^6) + ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*
              HPL[{1, 0}, x])/(162*(-1 + x^2)^3)) - 
          ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{2, 0}, x])/
           (81*(-1 + x^2)^3) + ((-27 + 18*x + 168*x^2 - 810*x^3 + 1392*x^4 - 
             2405*x^5 + 2326*x^6 - 1341*x^7 - 81*x^8)*HPL[{-1, 0, 0}, x])/
           (81*(-1 + x)^6*(1 + x)^4) + ((-9 - 12*x - 58*x^2 + 624*x^3 + 
             2486*x^4 + 4476*x^5 - 18216*x^6 - 212496*x^7 + 207232*x^8 + 
             319500*x^9 - 470086*x^10 + 6833712*x^11 - 6855786*x^12 + 
             7083396*x^13 - 5235192*x^14 + 1730160*x^15 + 306909*x^16)*
            HPL[{0, 0, 0}, x])/(81*(1 - 9*x^2)^2*(-1 + x^2)^7) + 
          ((27 + 90*x - 24*x^2 + 126*x^3 - 204*x^4 + 1843*x^5 - 1822*x^6 + 
             1611*x^7 - 27*x^8)*HPL[{1, 0, 0}, x])/(81*(-1 + x)^4*
            (1 + x)^6) + ((-36 - 48*x + 719*x^2 + 2160*x^3 - 5784*x^4 - 
             32280*x^5 + 40107*x^6 + 56160*x^7 - 97308*x^8 + 758304*x^9 - 
             700587*x^10 + 710640*x^11 - 540648*x^12 + 163944*x^13 + 
             33777*x^14)*master3l8b[x])/(1944*x^2*(1 - 9*x^2)^2*
            (-1 + x^2)^7) + ((18 + 24*x - 169*x^2 - 888*x^3 + 249*x^4 + 
             8760*x^5 - 546*x^6 + 44232*x^7 - 74676*x^8 + 199728*x^9 - 
             246069*x^10 + 162864*x^11 + 3753*x^12)*master3l9b[x])/
           (1944*x^2*(-1 + x^2)^7*(-1 + 9*x^2)) + 
          (-270 - 360*x + x^12*(185481747 - 59352960*Zeta[3]) + 
            x^9*(13611252 - 6526464*Zeta[3]) + x^6*(1539873 - 
              171008*Zeta[3]) + x^2*(10412 - 576*Zeta[3]) - 
            88*x^7*(-37733 + 96*Zeta[3]) - 8*x^3*(-3089 + 96*Zeta[3]) + 
            972*x^17*(-17373 + 512*Zeta[3]) + 12*x^5*(-41317 + 
              3072*Zeta[3]) - 243*x^18*(7763 + 6208*Zeta[3]) + 
            x^4*(-165511 + 14720*Zeta[3]) - 216*x^15*(131097 + 
              201824*Zeta[3]) + 27*x^16*(1463023 + 417920*Zeta[3]) + 
            x^8*(-8329267 + 566400*Zeta[3]) + 12*x^13*(-13910511 + 
              1075328*Zeta[3]) + 24*x^11*(-6362311 + 1528800*Zeta[3]) + 
            3*x^10*(-965477 + 2624000*Zeta[3]) + x^14*(53393835 + 
              41296128*Zeta[3]))/(15552*(-1 + x^2)^7*(x - 9*x^3)^2)) + 
        NL*(-(Pi^2*(9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{-1}, x])/
           (972*(-1 + x^2)^3) + (x^2*(102 + 48*(290 + 27*Pi^2)*x - 
             27*(733 + 72*Pi^2)*x^2 + 144*(29 + 18*Pi^2)*x^3 - 
             3*(-5831 + 472*Pi^2)*x^4 + 240*(-76 + 5*Pi^2)*x^5 + 
             (2673 - 236*Pi^2)*x^6 + 48*(3 + Pi^2)*x^7 + 9*(-53 + 4*Pi^2)*
              x^8)*HPL[{0}, x])/(3888*(-1 + x^2)^6) + 
          lm^2*((3 + 4*x - 21*x^2 + 40*x^3 - 21*x^4 + 4*x^5 + 3*x^6)/
             (144*(-1 + x^2)^4) - (x^3*(2 - 3*x + 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x^2)^5)) + (Pi^2*(9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*
            HPL[{1}, x])/(972*(-1 + x^2)^3) - 
          (x^3*(324 - 486*x + 648*x^2 - 354*x^3 + 300*x^4 - 59*x^5 + 12*x^6 + 
             9*x^7)*HPL[{-2, 0}, x])/(81*(-1 + x^2)^6) + 
          ((-17 - 64*x + 66*x^2 + 2632*x^3 - 3658*x^4 + 2632*x^5 + 66*x^6 - 
             64*x^7 - 17*x^8)*HPL[{-1, 0}, x])/(648*(-1 + x^2)^5) + 
          (x^3*(1440 - 2160*x + 3024*x^2 - 1920*x^3 + 1792*x^4 - 497*x^5 + 
             136*x^6 + 71*x^7)*HPL[{0, 0}, x])/(324*(-1 + x^2)^6) + 
          ((17 + 64*x - 66*x^2 - 2632*x^3 + 3658*x^4 - 2632*x^5 - 66*x^6 + 
             64*x^7 + 17*x^8)*HPL[{1, 0}, x])/(648*(-1 + x^2)^5) + 
          lm*((4*Pi^2*(-9 - 12*x + 41*x^2 - 41*x^4 + 12*x^5 + 9*x^6) + 
              3*(159 - 48*x - 607*x^2 + 1344*x^3 - 607*x^4 - 48*x^5 + 
                159*x^6))/(7776*(-1 + x^2)^4) - 
            (x^2*(18 + 618*x - 961*x^2 + 942*x^3 - 198*x^4 + 36*x^5 + 27*x^6)*
              HPL[{0}, x])/(324*(-1 + x^2)^5) - 
            ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{-1, 0}, x])/
             (162*(-1 + x^2)^3) + (x^3*(216 - 324*x + 648*x^2 - 516*x^3 + 408*
                x^4 - 59*x^5 + 12*x^6 + 9*x^7)*HPL[{0, 0}, x])/
             (81*(-1 + x^2)^6) + ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*
              HPL[{1, 0}, x])/(162*(-1 + x^2)^3)) + 
          (x^3*(324 - 486*x + 648*x^2 - 354*x^3 + 300*x^4 - 59*x^5 + 12*x^6 + 
             9*x^7)*HPL[{2, 0}, x])/(81*(-1 + x^2)^6) + 
          ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{-1, -1, 0}, x])/
           (81*(-1 + x^2)^3) - ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*
            HPL[{-1, 1, 0}, x])/(81*(-1 + x^2)^3) - 
          (2*x^3*(216 - 324*x + 648*x^2 - 516*x^3 + 408*x^4 - 59*x^5 + 
             12*x^6 + 9*x^7)*HPL[{0, 0, 0}, x])/(81*(-1 + x^2)^6) - 
          ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*HPL[{1, -1, 0}, x])/
           (81*(-1 + x^2)^3) + ((9 + 12*x - 32*x^2 + 12*x^3 + 9*x^4)*
            HPL[{1, 1, 0}, x])/(81*(-1 + x^2)^3) + 
          (4*Pi^2*(-17 - 64*x + 83*x^2 + 2696*x^3 - 3724*x^4 + 3724*x^6 - 
              2696*x^7 - 83*x^8 + 64*x^9 + 17*x^10) + 
            3*(407 + 707*x^8 - 2048*x^9 + 407*x^10 + x^2*(707 - 
                3776*Zeta[3]) + 576*Zeta[3] + 256*x*(-8 + 3*Zeta[3]) + 
              32*x^3*(143 + 600*Zeta[3]) + 64*x^5*(-79 + 648*Zeta[3]) + 
              32*x^7*(143 + 648*Zeta[3]) - 2*x^4*(557 + 11328*Zeta[3]) - 
              2*x^6*(557 + 15552*Zeta[3])))/(31104*(-1 + x^2)^6))))
 
CbarData["v", 2, 2] = 
    NC*(CF*(NL*(-(Pi^2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6)*
             HPL[{-1}, x])/(810*(-1 + x^2)^5) + 
          (x^2*(28 + 50*(2015 + 144*Pi^2)*x - 32*(5839 + 450*Pi^2)*x^2 + 
             675*(365 + 48*Pi^2)*x^3 - 10*(7217 + 3120*Pi^2)*x^4 + 
             5*(-37161 + 6320*Pi^2)*x^5 - 4*(-62297 + 3450*Pi^2)*x^6 + 
             5*(-32111 + 1460*Pi^2)*x^7 + (10862 - 360*Pi^2)*x^8 + 
             5*(-153 + 20*Pi^2)*x^9 + 20*(-53 + 2*Pi^2)*x^10)*HPL[{0}, x])/
           (16200*(-1 + x^2)^8) + lm^2*((2 + 5*x - 28*x^2 + 145*x^3 - 
              188*x^4 + 145*x^5 - 28*x^6 + 5*x^7 + 2*x^8)/
             (180*(-1 + x^2)^6) - (2*x^3*(1 - x + x^2)^2*HPL[{0}, x])/
             (3*(-1 + x^2)^7)) + (Pi^2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 
             5*x^5 + 2*x^6)*HPL[{1}, x])/(810*(-1 + x^2)^5) - 
          (2*x^3*(360 - 720*x + 1620*x^2 - 1560*x^3 + 1580*x^4 - 690*x^5 + 
             365*x^6 - 18*x^7 + 5*x^8 + 2*x^9)*HPL[{-2, 0}, x])/
           (135*(-1 + x^2)^8) - ((14 + 155*x + 2008*x^2 - 51050*x^3 + 
             87558*x^4 - 134010*x^5 + 87558*x^6 - 51050*x^7 + 2008*x^8 + 
             155*x^9 + 14*x^10)*HPL[{-1, 0}, x])/(8100*(-1 + x^2)^7) + 
          (x^3*(18000 - 36000*x + 99000*x^2 - 111600*x^3 + 137000*x^4 - 
             78250*x^5 + 44975*x^6 - 3526*x^7 + 1055*x^8 + 374*x^9)*
            HPL[{0, 0}, x])/(4050*(-1 + x^2)^8) + 
          ((14 + 155*x + 2008*x^2 - 51050*x^3 + 87558*x^4 - 134010*x^5 + 
             87558*x^6 - 51050*x^7 + 2008*x^8 + 155*x^9 + 14*x^10)*
            HPL[{1, 0}, x])/(8100*(-1 + x^2)^7) + 
          lm*((212 + 153*x - 1754*x^2 + 12267*x^3 - 16188*x^4 + 12267*x^5 - 
              1754*x^6 + 153*x^7 + 212*x^8 + 4*Pi^2*(-2 - 5*x + 14*x^2 - 
                15*x^3 + 15*x^5 - 14*x^6 + 5*x^7 + 2*x^8))/
             (6480*(-1 + x^2)^6) - (x^2*(2 + 449*x - 868*x^2 + 1667*x^3 - 
               1348*x^4 + 869*x^5 - 88*x^6 + 15*x^7 + 6*x^8)*HPL[{0}, x])/
             (135*(-1 + x^2)^7) - ((2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*
                x^5 + 2*x^6)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^5) + 
            (2*x^3*(180 - 360*x + 1260*x^2 - 1560*x^3 + 1940*x^4 - 1050*x^5 + 
               545*x^6 - 18*x^7 + 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x^2)^8) + ((2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*
                x^5 + 2*x^6)*HPL[{1, 0}, x])/(135*(-1 + x^2)^5)) + 
          (2*x^3*(360 - 720*x + 1620*x^2 - 1560*x^3 + 1580*x^4 - 690*x^5 + 
             365*x^6 - 18*x^7 + 5*x^8 + 2*x^9)*HPL[{2, 0}, x])/
           (135*(-1 + x^2)^8) + (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 
             5*x^5 + 2*x^6)*HPL[{-1, -1, 0}, x])/(135*(-1 + x^2)^5) - 
          (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6)*
            HPL[{-1, 1, 0}, x])/(135*(-1 + x^2)^5) - 
          (4*x^3*(180 - 360*x + 1260*x^2 - 1560*x^3 + 1940*x^4 - 1050*x^5 + 
             545*x^6 - 18*x^7 + 5*x^8 + 2*x^9)*HPL[{0, 0, 0}, x])/
           (135*(-1 + x^2)^8) - (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 
             5*x^5 + 2*x^6)*HPL[{1, -1, 0}, x])/(135*(-1 + x^2)^5) + 
          (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6)*
            HPL[{1, 1, 0}, x])/(135*(-1 + x^2)^5) + 
          (11830 - 486*x^10 - 40605*x^11 + 11830*x^12 + 
            4*Pi^2*(-14 - 155*x - 1994*x^2 + 51205*x^3 - 85550*x^4 + 
              82960*x^5 - 82960*x^7 + 85550*x^8 - 51205*x^9 + 1994*x^10 + 
              155*x^11 + 14*x^12) + x^6*(1299052 - 4492800*Zeta[3]) + 
            5760*Zeta[3] - 162*x^2*(3 + 320*Zeta[3]) + 
            15*x*(-2707 + 960*Zeta[3]) + 405*x^9*(1399 + 2560*Zeta[3]) - 
            90*x^4*(7343 + 22080*Zeta[3]) - 90*x^8*(7343 + 23040*Zeta[3]) + 
            45*x^3*(12591 + 23360*Zeta[3]) + 30*x^5*(-17533 + 
              151680*Zeta[3]) + 30*x^7*(-17533 + 155520*Zeta[3]))/
           (388800*(-1 + x^2)^8)) + 
        NH*(-(x*(-283435200 - 895655232*x - 193724110080*x^2 + 
              334961660664*x^3 - 422207082315*x^4 + 204021712494*x^5 + 
              55657536210*x^6 - 148146572772*x^7 + 55838240910*x^8 + 
              23777655876*x^9 - 17928876150*x^10 + 638719628*x^11 + 
              2117219400*x^12 - 582916656*x^13 - 108881130*x^14 + 
              69062324*x^15 + 1708050*x^16 - 3555172*x^17 + 36750*x^18 + 
              67756*x^19 - 1245*x^20 + 290*x^21)*HPL[{0}, x])/
           (32400*(-9 + x^2)^4*(-1 + x^2)^9) + 
          lm^2*((2 + 5*x - 28*x^2 + 145*x^3 - 188*x^4 + 145*x^5 - 28*x^6 + 
              5*x^7 + 2*x^8)/(180*(-1 + x^2)^6) - (2*x^3*(1 - x + x^2)^2*
              HPL[{0}, x])/(3*(-1 + x^2)^7)) + 
          (x*(-70858800 - 48183984*x - 35292887460*x^2 + 60412868604*x^3 - 
             73419739335*x^4 + 30450916602*x^5 + 19581691950*x^6 - 
             32646678588*x^7 + 12800192400*x^8 + 5648451984*x^9 - 
             4485917610*x^10 + 340000428*x^11 + 361780890*x^12 - 
             177962396*x^13 + 18070410*x^14 + 17009612*x^15 - 3402120*x^16 - 
             512208*x^17 + 92310*x^18 - 6456*x^19 + 1365*x^20 + 402*x^21)*
            HPL[{0, 0}, x])/(8100*(-9 + x^2)^4*(-1 + x^2)^9) + 
          lm*((212 + 153*x - 1754*x^2 + 12267*x^3 - 16188*x^4 + 12267*x^5 - 
              1754*x^6 + 153*x^7 + 212*x^8 + 4*Pi^2*(-2 - 5*x + 14*x^2 - 
                15*x^3 + 15*x^5 - 14*x^6 + 5*x^7 + 2*x^8))/
             (6480*(-1 + x^2)^6) - (x^2*(2 + 449*x - 868*x^2 + 1667*x^3 - 
               1348*x^4 + 869*x^5 - 88*x^6 + 15*x^7 + 6*x^8)*HPL[{0}, x])/
             (135*(-1 + x^2)^7) - ((2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*
                x^5 + 2*x^6)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^5) + 
            (2*x^3*(180 - 360*x + 1260*x^2 - 1560*x^3 + 1940*x^4 - 1050*x^5 + 
               545*x^6 - 18*x^7 + 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x^2)^8) + ((2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*
                x^5 + 2*x^6)*HPL[{1, 0}, x])/(135*(-1 + x^2)^5)) - 
          (2*(33 + 1959*x - 3908*x^2 + 7042*x^3 - 6786*x^4 + 5220*x^5 - 
             1969*x^6 + 668*x^7 - 22*x^8 + x^9 + 2*x^10)*HPL[{-1, 0, 0}, x])/
           (135*(-1 + x)^8*(1 + x)^6) + (2*x^3*(424423800 - 695617632*x + 
             872211645*x^2 - 358250634*x^3 - 250668720*x^4 + 402710796*x^5 - 
             210566880*x^6 - 53176980*x^7 + 62085360*x^8 - 9134780*x^9 - 
             2276030*x^10 + 2627248*x^11 - 719120*x^12 - 234444*x^13 + 
             78920*x^14 + 11236*x^15 - 2600*x^16 - 420*x^17 + 25*x^18 + 
             10*x^19)*HPL[{0, 0, 0}, x])/(675*(-9 + x^2)^4*(-1 + x^2)^9) + 
          (2*(-57 + 2091*x - 3368*x^2 + 6338*x^3 - 4126*x^4 + 2800*x^5 - 
             359*x^6 + 452*x^7 - 2*x^8 + 9*x^9 + 2*x^10)*HPL[{1, 0, 0}, x])/
           (135*(-1 + x)^6*(1 + x)^8) + ((15037812 + 1735636005*x - 
             2985204942*x^2 + 3929620230*x^3 - 2166048324*x^4 + 
             34797330*x^5 + 962469540*x^6 - 415724850*x^7 - 83359836*x^8 + 
             92233980*x^9 - 12121928*x^10 - 9708110*x^11 + 3086388*x^12 + 
             555870*x^13 - 261924*x^14 - 11910*x^15 + 9720*x^16 - 145*x^17 - 
             106*x^18)*master3l8a[x])/(8100*(-9 + x^2)^4*(-1 + x^2)^9) - 
          ((1670868 + 98532045*x - 176922090*x^2 + 253747665*x^3 - 
             180718794*x^4 + 87764715*x^5 - 2630094*x^6 + 10352625*x^7 + 
             2262670*x^8 - 2398235*x^9 + 934478*x^10 - 839365*x^11 - 
             137070*x^12 + 128305*x^13 + 7766*x^14 - 4605*x^15 - 554*x^16 + 
             50*x^17 + 20*x^18)*master3l9a[x])/(2700*(-9 + x^2)^3*
            (-1 + x^2)^9) + (x^20*(610726 - 88320*Zeta[3]) + 
            30*x^22*(-99 + 64*Zeta[3]) + 5*x^21*(-6763 + 960*Zeta[3]) - 
            45*x^19*(12373 + 5760*Zeta[3]) - 450*x^17*(-116919 + 
              10976*Zeta[3]) + 72*x^18*(-279623 + 26800*Zeta[3]) + 
            52488*(-115219 + 35040*Zeta[3]) - 152*x^16*(-1776967 + 
              50400*Zeta[3]) - 65610*x*(7675867 + 55200*Zeta[3]) - 
            5832*x^2*(-149392627 + 1209360*Zeta[3]) - 29700*x^7*
             (-14482525 + 5848768*Zeta[3]) + 10935*x^3*(-171178807 + 
              7905920*Zeta[3]) + 20*x^15*(-54618791 + 14909760*Zeta[3]) - 
            120*x^9*(-1213981919 + 24091840*Zeta[3]) - 
            12*x^14*(106229743 + 36372800*Zeta[3]) + 2025*x^5*
             (-752159255 + 38493504*Zeta[3]) + 450*x^11*(-154325491 + 
              43482752*Zeta[3]) - 1458*x^4*(-1302116703 + 96035200*Zeta[3]) - 
            30*x^13*(-393112961 + 134657280*Zeta[3]) + 
            36*x^12*(-219122481 + 213760000*Zeta[3]) - 
            16*x^10*(-8103852209 + 3034918800*Zeta[3]) + 
            32*x^8*(-17392594003 + 3057891600*Zeta[3]) + 
            18*x^6*(19996977463 + 4927012800*Zeta[3]))/(194400*(-9 + x^2)^4*
            (-1 + x^2)^9)) + NM*(((-4560 - 11400*x + 171624*x^2 + 
             1076100*x^3 - 3672218*x^4 - 32999925*x^5 + 69218376*x^6 + 
             306149430*x^7 - 709902164*x^8 + 577046250*x^9 + 
             1407294772*x^10 - 16757782650*x^11 + 18860631944*x^12 + 
             13856559840*x^13 - 48455898188*x^14 + 206024214690*x^15 - 
             206272762524*x^16 + 233810252190*x^17 - 143179154604*x^18 + 
             75181286430*x^19 - 38474565678*x^20 + 7671853845*x^21 + 
             2918464020*x^22 - 40*Pi^2*(1 - 10*x^2 + 9*x^4)^4*
              (2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6))*
            HPL[{0}, x])/(32400*(1 - 9*x^2)^4*(-1 + x^2)^9) + 
          lm^2*((2 + 5*x - 28*x^2 + 145*x^3 - 188*x^4 + 145*x^5 - 28*x^6 + 
              5*x^7 + 2*x^8)/(180*(-1 + x^2)^6) - (2*x^3*(1 - x + x^2)^2*
              HPL[{0}, x])/(3*(-1 + x^2)^7)) + 
          (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6)*
            HPL[{-2, 0}, x])/(135*(-1 + x^2)^5) + 
          ((720 + 1800*x - 23088*x^2 - 206760*x^3 + 501738*x^4 + 
             5192505*x^5 - 9201032*x^6 - 8454690*x^7 + 39622400*x^8 - 
             742629600*x^9 + 941411892*x^10 + 4996507710*x^11 - 
             9102026508*x^12 + 10192242330*x^13 + 3846046068*x^14 - 
             88025859270*x^15 + 102691991808*x^16 - 139987653840*x^17 + 
             94406418540*x^18 - 55127118510*x^19 + 26796711762*x^20 - 
             5039340075*x^21 - 2025380700*x^22)*HPL[{0, 0}, x])/
           (8100*(1 - 9*x^2)^4*(-1 + x^2)^9) + 
          lm*((212 + 153*x - 1754*x^2 + 12267*x^3 - 16188*x^4 + 12267*x^5 - 
              1754*x^6 + 153*x^7 + 212*x^8 + 4*Pi^2*(-2 - 5*x + 14*x^2 - 
                15*x^3 + 15*x^5 - 14*x^6 + 5*x^7 + 2*x^8))/
             (6480*(-1 + x^2)^6) - (x^2*(2 + 449*x - 868*x^2 + 1667*x^3 - 
               1348*x^4 + 869*x^5 - 88*x^6 + 15*x^7 + 6*x^8)*HPL[{0}, x])/
             (135*(-1 + x^2)^7) - ((2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*
                x^5 + 2*x^6)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^5) + 
            (2*x^3*(180 - 360*x + 1260*x^2 - 1560*x^3 + 1940*x^4 - 1050*x^5 + 
               545*x^6 - 18*x^7 + 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x^2)^8) + ((2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*
                x^5 + 2*x^6)*HPL[{1, 0}, x])/(135*(-1 + x^2)^5)) - 
          (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6)*
            HPL[{2, 0}, x])/(135*(-1 + x^2)^5) - 
          (2*(6 + 3*x - 66*x^2 + 764*x^3 - 2057*x^4 + 5220*x^5 - 6698*x^6 + 
             6946*x^7 - 3864*x^8 + 1957*x^9 + 29*x^10)*HPL[{-1, 0, 0}, x])/
           (135*(-1 + x)^8*(1 + x)^6) + (2*(-10 - 25*x + 140*x^2 + 3700*x^3 - 
             3698*x^4 - 33835*x^5 + 49740*x^6 - 1440630*x^7 + 1884816*x^8 + 
             21008770*x^9 - 38083856*x^10 + 28414050*x^11 + 99613588*x^12 - 
             1394486970*x^13 + 1404533052*x^14 + 3380714910*x^15 - 
             5689906830*x^16 + 9826444935*x^17 - 7354994724*x^18 + 
             4656888450*x^19 - 2067497946*x^20 + 479248245*x^21 + 
             134159328*x^22)*HPL[{0, 0, 0}, x])/(675*(1 - 9*x^2)^4*
            (-1 + x^2)^9) - (2*(-6 - 27*x + 6*x^2 - 436*x^3 + 327*x^4 - 
             2800*x^5 + 4158*x^6 - 6354*x^7 + 3364*x^8 - 2073*x^9 + 61*x^10)*
            HPL[{1, 0, 0}, x])/(135*(-1 + x)^6*(1 + x)^8) + 
          ((-40 - 100*x + 1574*x^2 + 10255*x^3 - 35224*x^4 - 327590*x^5 + 
             675852*x^6 + 3432350*x^7 - 7422604*x^8 - 603990*x^9 + 
             24417192*x^10 - 156107460*x^11 + 129348084*x^12 + 
             426542670*x^13 - 648373644*x^14 + 1037472210*x^15 - 
             733045788*x^16 + 440773650*x^17 - 202734414*x^18 + 
             37940805*x^19 + 15037812*x^20)*master3l8b[x])/
           (8100*x^2*(1 - 9*x^2)^4*(-1 + x^2)^9) + 
          ((20 + 50*x - 554*x^2 - 4605*x^3 + 7766*x^4 + 128305*x^5 - 
             137070*x^6 - 839365*x^7 + 934478*x^8 - 2398235*x^9 + 
             2262670*x^10 + 10352625*x^11 - 2630094*x^12 + 87764715*x^13 - 
             180718794*x^14 + 253747665*x^15 - 176922090*x^16 + 
             98532045*x^17 + 1670868*x^18)*master3l9b[x])/
           (8100*x^2*(-1 + x^2)^9*(-1 + 9*x^2)^3) + 
          (-900 - 2250*x + x^16*(364807305476 - 97852531200*Zeta[3]) + 
            x^12*(5765193036 - 7695360000*Zeta[3]) + 
            x^6*(38198286 - 1929600*Zeta[3]) + x^3*(297290 - 4800*Zeta[3]) - 
            480*x^2*(-105 + 4*Zeta[3]) + 45*x^5*(-237607 + 5760*Zeta[3]) + 
            225*x^7*(695041 + 21952*Zeta[3]) + 98415*x^23*
             (-154017 + 36800*Zeta[3]) + 2*x^4*(-850673 + 44160*Zeta[3]) - 
            26244*x^24*(104767 + 70080*Zeta[3]) + 1920*x^11*
             (-5564969 + 2104020*Zeta[3]) + 1458*x^22*(34559147 + 
              4837440*Zeta[3]) - 12150*x^19*(26662771 + 6415584*Zeta[3]) - 
            40*x^9*(11902547 + 7454880*Zeta[3]) + x^8*(-509218004 + 
              7660800*Zeta[3]) - 10935*x^21*(4114093 + 7905920*Zeta[3]) + 
            48*x^10*(62320087 + 9093200*Zeta[3]) - 450*x^13*
             (-212668031 + 43482752*Zeta[3]) + 30*x^15*(-3558772931 + 
              96367360*Zeta[3]) + 1350*x^17*(-534058057 + 128672896*Zeta[
                3]) - 576*x^18*(-902997571 + 153969150*Zeta[3]) + 
            486*x^20*(201304001 + 288105600*Zeta[3]) + 
            4*x^14*(-35686652921 + 12139675200*Zeta[3]))/
           (194400*x^2*(1 - 9*x^2)^4*(-1 + x^2)^9))) + 
      CF^2*(-(Pi^2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 
            180*x^6 + 15*x^7 + 6*x^8)*HPL[{-2}, x])/(405*(-1 + x^2)^6) + 
        lm^2*((2 + 5*x - 28*x^2 + 145*x^3 - 188*x^4 + 145*x^5 - 28*x^6 + 
            5*x^7 + 2*x^8)/(10*(-1 + x^2)^6) - (12*x^3*(1 - x + x^2)^2*
            HPL[{0}, x])/(-1 + x^2)^7) + 
        (Pi^2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{2}, x])/(405*(-1 + x^2)^6) + 
        (x*(2265 - 9630*x + 71235*x^2 - 48750*x^3 + 455400*x^4 - 546220*x^5 - 
           53640*x^6 + 549270*x^7 + 1110390*x^8 - 1325717*x^9 - 
           1639548*x^10 + 1939342*x^11 + 1643684*x^12 - 1995612*x^13 - 
           970156*x^14 + 1395818*x^15 + 255359*x^16 - 632907*x^17 + 
           43479*x^18 + 167904*x^19 - 46728*x^20 - 19800*x^21 + 9000*x^22)*
          HPL[{-2, 0}, x])/(4050*(-1 + x^2)^8) + 
        ((-270000 + 594000*x + 996840*x^2 - 4146120*x^3 + 303390*x^4 + 
           12520530*x^5 - 7609785*x^6 - 21390945*x^7 + 17526180*x^8 + 
           (22712411 - 3600*Pi^2)*x^9 - 5*(4046893 + 1800*Pi^2)*x^10 + 
           6*(-2524693 + 18600*Pi^2)*x^11 - 80*(-95557 + 5400*Pi^2)*x^12 + 
           4*(3188203 + 121800*Pi^2)*x^13 - 23135640*x^14 + 
           (12752812 - 487200*Pi^2)*x^15 + 80*(95557 + 5400*Pi^2)*x^16 - 
           6*(2524693 + 18600*Pi^2)*x^17 + 5*(-4046893 + 1800*Pi^2)*x^18 + 
           (22712411 + 3600*Pi^2)*x^19 + 17526180*x^20 - 21390945*x^21 - 
           7609785*x^22 + 12520530*x^23 + 303390*x^24 - 4146120*x^25 + 
           996840*x^26 + 594000*x^27 - 270000*x^28)*HPL[{-1, 0}, x])/
         (243000*x^9*(-1 + x^2)^7) + (x*(2674919700 - 13894229700*x + 
           119095600050*x^2 + 68480185995*x^3 - 5244364071450*x^4 + 
           8340862561470*x^5 + 53470233819450*x^6 - 143229175268400*x^7 - 
           61728109532730*x^8 + 723570727130538*x^9 - 1150617251604660*x^10 - 
           134011631379693*x^11 - 252619836316830*x^12 - 1483499750049022*
            x^13 + 22864715271541570*x^14 - 26943094647880748*x^15 + 
           4009416485271340*x^16 + 13003680031234168*x^17 + 
           725239902739810*x^18 - 7418110553039167*x^19 - 3903659185305150*
            x^20 + 6026323550962602*x^21 + 2060440935409830*x^22 - 
           3594229359873552*x^23 - 386817451769610*x^24 + 1444198195732482*
            x^25 - 106032103284960*x^26 - 383068664168607*x^27 + 
           80528762400390*x^28 + 64077414622470*x^29 - 19679958667890*x^30 - 
           6398939232180*x^31 + 2393751063060*x^32 + 346264910640*x^33 - 
           145743954480*x^34 - 7794468000*x^35 + 3542940000*x^36)*
          HPL[{0, 0}, x])/(243000*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        ((270000 - 594000*x - 996840*x^2 + 4146120*x^3 - 303390*x^4 - 
           12520530*x^5 + 7609785*x^6 + 21390945*x^7 - 17526180*x^8 + 
           (-22712411 + 3600*Pi^2)*x^9 + 5*(4046893 + 1800*Pi^2)*x^10 - 
           6*(-2524693 + 18600*Pi^2)*x^11 + 80*(-95557 + 5400*Pi^2)*x^12 - 
           4*(3188203 + 121800*Pi^2)*x^13 + 23135640*x^14 + 
           4*(-3188203 + 121800*Pi^2)*x^15 - 80*(95557 + 5400*Pi^2)*x^16 + 
           6*(2524693 + 18600*Pi^2)*x^17 + (20234465 - 9000*Pi^2)*x^18 - 
           (22712411 + 3600*Pi^2)*x^19 - 17526180*x^20 + 21390945*x^21 + 
           7609785*x^22 - 12520530*x^23 - 303390*x^24 + 4146120*x^25 - 
           996840*x^26 - 594000*x^27 + 270000*x^28)*HPL[{1, 0}, x])/
         (243000*x^9*(-1 + x^2)^7) + 
        lm*((79 + 9*x - 499*x^2 + 4176*x^3 - 5556*x^4 + 4176*x^5 - 499*x^6 + 
            9*x^7 + 79*x^8 + 2*Pi^2*(-2 - 5*x + 14*x^2 - 15*x^3 + 15*x^5 - 
              14*x^6 + 5*x^7 + 2*x^8))/(180*(-1 + x^2)^6) - 
          (x^2*(4 + 763*x - 1466*x^2 + 2929*x^3 - 2426*x^4 + 1603*x^5 - 
             176*x^6 + 30*x^7 + 12*x^8)*HPL[{0}, x])/(15*(-1 + x^2)^7) - 
          (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6)*
            HPL[{-1, 0}, x])/(15*(-1 + x^2)^5) + 
          (4*x^3*(180 - 360*x + 1260*x^2 - 1560*x^3 + 1940*x^4 - 1050*x^5 + 
             545*x^6 - 18*x^7 + 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
           (15*(-1 + x^2)^8) + (2*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 
             5*x^5 + 2*x^6)*HPL[{1, 0}, x])/(15*(-1 + x^2)^5)) - 
        (x*(2265 - 9630*x + 71235*x^2 - 48750*x^3 + 455400*x^4 - 546220*x^5 - 
           53640*x^6 + 549270*x^7 + 1110390*x^8 - 1325717*x^9 - 
           1639548*x^10 + 1939342*x^11 + 1643684*x^12 - 1995612*x^13 - 
           970156*x^14 + 1395818*x^15 + 255359*x^16 - 632907*x^17 + 
           43479*x^18 + 167904*x^19 - 46728*x^20 - 19800*x^21 + 9000*x^22)*
          HPL[{2, 0}, x])/(4050*(-1 + x^2)^8) + 
        (4*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-2, -1, 0}, x])/(135*(-1 + x^2)^6) - 
        (8*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-2, 0, 0}, x])/(135*(-1 + x^2)^6) - 
        (4*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-2, 1, 0}, x])/(135*(-1 + x^2)^6) - 
        (4*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-1, -2, 0}, x])/(135*(-1 + x^2)^6) + 
        ((-9000 + 19800*x + 1728*x^2 - 68904*x^3 + 55161*x^4 + 90387*x^5 - 
           86834*x^6 - 56843*x^7 + 46656*x^8 + 19487*x^9 - 8094*x^10 - 
           3127*x^11 - 2234*x^12 - 3127*x^13 - 8094*x^14 + 19487*x^15 + 
           46656*x^16 - 56843*x^17 - 86834*x^18 + 90387*x^19 + 55161*x^20 - 
           68904*x^21 + 1728*x^22 + 19800*x^23 - 9000*x^24)*
          HPL[{-1, -1, 0}, x])/(8100*x^11*(-1 + x^2)^3) + 
        ((958 - 25695*x + 150757*x^2 - 521982*x^3 + 1016071*x^4 - 
           1194240*x^5 + 654813*x^6 - 351706*x^7 + 801883*x^8 - 453668*x^9 - 
           1129749*x^10 + 1052974*x^11 + 966261*x^12 - 1341812*x^13 - 
           278249*x^14 + 928154*x^15 - 182241*x^16 - 308313*x^17 + 
           165960*x^18 + 19872*x^19 - 37800*x^20 + 9000*x^21)*
          HPL[{-1, 0, 0}, x])/(4050*(-1 + x)^8*(1 + x)^6) + 
        ((9000 - 19800*x - 1728*x^2 + 68904*x^3 - 55161*x^4 - 90387*x^5 + 
           86834*x^6 + 56843*x^7 - 46656*x^8 - 19487*x^9 + 8094*x^10 + 
           3127*x^11 + 2234*x^12 + 3127*x^13 + 8094*x^14 - 19487*x^15 - 
           46656*x^16 + 56843*x^17 + 86834*x^18 - 90387*x^19 - 55161*x^20 + 
           68904*x^21 - 1728*x^22 - 19800*x^23 + 9000*x^24)*
          HPL[{-1, 1, 0}, x])/(8100*x^11*(-1 + x^2)^3) + 
        (4*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-1, 2, 0}, x])/(135*(-1 + x^2)^6) + 
        (x*(14860665 - 67906350*x - 2197169550*x^2 + 5375180898*x^3 + 
           45027361755*x^4 - 102678709266*x^5 - 120201421932*x^6 + 
           449097269616*x^7 - 3790662756735*x^8 + 5179388846670*x^9 + 
           30534002316606*x^10 - 54519044986194*x^11 - 33577155357381*x^12 + 
           134001712450974*x^13 - 174250709445704*x^14 - 5705564451284*x^15 + 
           18830896379385*x^16 + 189387836582468*x^17 - 793336565176434*
            x^18 + 477371492445412*x^19 + 719324202635667*x^20 - 
           723141520050286*x^21 - 494557622336172*x^22 + 631982292463648*
            x^23 + 265846159400847*x^24 - 412233714348730*x^25 - 
           87019631749534*x^26 + 198556458439014*x^27 + 6383598854517*x^28 - 
           68235661703358*x^29 + 7836419462976*x^30 + 16062239230308*x^31 - 
           3701335938066*x^32 - 2460659191578*x^33 + 777705476256*x^34 + 
           230719476438*x^35 - 87128107326*x^36 - 11931887088*x^37 + 
           5035278816*x^38 + 259815600*x^39 - 118098000*x^40)*
          HPL[{0, 0, 0}, x])/(4050*(-1 + x^2)^9*(9 - 82*x^2 + 9*x^4)^4) + 
        (4*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{1, -2, 0}, x])/(135*(-1 + x^2)^6) + 
        ((9000 - 19800*x - 1728*x^2 + 68904*x^3 - 55161*x^4 - 90387*x^5 + 
           86834*x^6 + 56843*x^7 - 46656*x^8 - 19487*x^9 + 8094*x^10 + 
           3127*x^11 + 2234*x^12 + 3127*x^13 + 8094*x^14 - 19487*x^15 - 
           46656*x^16 + 56843*x^17 + 86834*x^18 - 90387*x^19 - 55161*x^20 + 
           68904*x^21 - 1728*x^22 - 19800*x^23 + 9000*x^24)*
          HPL[{1, -1, 0}, x])/(8100*x^11*(-1 + x^2)^3) - 
        ((958 - 24743*x + 42681*x^2 - 169658*x^3 + 33667*x^4 + 146256*x^5 + 
           91329*x^6 - 606574*x^7 - 258393*x^8 + 854580*x^9 + 725151*x^10 - 
           1067350*x^11 - 917391*x^12 + 876252*x^13 + 674283*x^14 - 
           497842*x^15 - 274149*x^16 + 204903*x^17 + 51048*x^18 - 
           59328*x^19 - 1800*x^20 + 9000*x^21)*HPL[{1, 0, 0}, x])/
         (4050*(-1 + x)^6*(1 + x)^8) + ((-9000 + 19800*x + 1728*x^2 - 
           68904*x^3 + 55161*x^4 + 90387*x^5 - 86834*x^6 - 56843*x^7 + 
           46656*x^8 + 19487*x^9 - 8094*x^10 - 3127*x^11 - 2234*x^12 - 
           3127*x^13 - 8094*x^14 + 19487*x^15 + 46656*x^16 - 56843*x^17 - 
           86834*x^18 + 90387*x^19 + 55161*x^20 - 68904*x^21 + 1728*x^22 + 
           19800*x^23 - 9000*x^24)*HPL[{1, 1, 0}, x])/
         (8100*x^11*(-1 + x^2)^3) - (4*(6 + 15*x - 180*x^2 + 735*x^3 - 
           992*x^4 + 735*x^5 - 180*x^6 + 15*x^7 + 6*x^8)*HPL[{1, 2, 0}, x])/
         (135*(-1 + x^2)^6) - (4*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 
           735*x^5 - 180*x^6 + 15*x^7 + 6*x^8)*HPL[{2, -1, 0}, x])/
         (135*(-1 + x^2)^6) + (8*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 
           735*x^5 - 180*x^6 + 15*x^7 + 6*x^8)*HPL[{2, 0, 0}, x])/
         (135*(-1 + x^2)^6) + (4*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 
           735*x^5 - 180*x^6 + 15*x^7 + 6*x^8)*HPL[{2, 1, 0}, x])/
         (135*(-1 + x^2)^6) - (8*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 
           735*x^5 - 180*x^6 + 15*x^7 + 6*x^8)*HPL[{-1, 1, 0, 0}, x])/
         (135*(-1 + x^2)^6) - (8*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 
           735*x^5 - 180*x^6 + 15*x^7 + 6*x^8)*HPL[{1, -1, 0, 0}, x])/
         (135*(-1 + x^2)^6) + ((12 + 59*x - 288*x^2 + 2032*x^3 - 3056*x^4 + 
           3408*x^5 - 1432*x^6 + 592*x^7 + 84*x^8 + 29*x^9)*master3l10a[x])/
         (540*(-1 + x^2)^7) - (x*(29 + 84*x + 592*x^2 - 1432*x^3 + 3408*x^4 - 
           3056*x^5 + 2032*x^6 - 288*x^7 + 59*x^8 + 12*x^9)*master3l10b[x])/
         (540*(-1 + x^2)^7) + ((18254889 - 105470991*x + 300347757*x^2 - 
           382662549*x^3 + 116505*x^4 - 2498499*x^5 + 73616445*x^6 - 
           43746489*x^7 - 42249717*x^8 + 32410419*x^9 + 7137951*x^10 - 
           6597295*x^11 - 371045*x^12 + 546655*x^13 - 10313*x^14 - 
           16323*x^15 + 1048*x^16)*master3l8a[x])/(16200*(-9 + x^2)^4*
          (-1 + x^2)^8) - ((1510 - 5132*x - 53133*x^2 + 205139*x^3 + 
           721473*x^4 - 3009345*x^5 - 5808417*x^6 + 20867427*x^7 + 
           43093641*x^8 - 88829313*x^9 - 247173111*x^10 + 394340481*x^11 + 
           457334163*x^12 - 1164732939*x^13 + 1015853157*x^14 - 
           309744567*x^15 + 78339069*x^16 + 13530969*x^17)*master3l8b[x])/
         (16200*x*(1 - 9*x^2)^4*(-1 + x^2)^8) + 
        ((-1765881 + 1507329*x + 325836*x^2 - 35009775*x^3 + 64737117*x^4 - 
           29158623*x^5 - 18804594*x^6 + 12922353*x^7 + 5192769*x^8 - 
           2758853*x^9 - 978880*x^10 + 382667*x^11 + 79035*x^12 - 
           27933*x^13 - 2042*x^14 + 755*x^15)*master3l9a[x])/
         (5400*(-9 + x^2)^3*(-1 + x^2)^8) + 
        ((755 - 2042*x - 27933*x^2 + 79035*x^3 + 382667*x^4 - 978880*x^5 - 
           2758853*x^6 + 5192769*x^7 + 12922353*x^8 - 18804594*x^9 - 
           29158623*x^10 + 64737117*x^11 - 35009775*x^12 + 325836*x^13 + 
           1507329*x^14 - 1765881*x^15)*master3l9b[x])/(16200*x*(-1 + x^2)^8*
          (-1 + 9*x^2)^3) + (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*
            (9000 - 19800*x - 1728*x^2 + 68904*x^3 - 55161*x^4 - 90387*x^5 + 
             86834*x^6 + 56843*x^7 - 46656*x^8 - 19487*x^9 + 8094*x^10 + 
             3127*x^11 + 2234*x^12 + 3127*x^13 + 8094*x^14 - 19487*x^15 - 
             46656*x^16 + 56843*x^17 + 86834*x^18 - 90387*x^19 - 55161*x^20 + 
             68904*x^21 - 1728*x^22 - 19800*x^23 + 9000*x^24) - 
           2880*x^11*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 
             180*x^6 + 15*x^7 + 6*x^8)*Zeta[3]))/(97200*x^11*(-1 + x^2)^6) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(9000 - 19800*x - 1728*x^2 + 
              68904*x^3 - 55161*x^4 - 90387*x^5 + 86834*x^6 + 56843*x^7 - 
              46656*x^8 - 19487*x^9 + 8094*x^10 + 3127*x^11 + 2234*x^12 + 
              3127*x^13 + 8094*x^14 - 19487*x^15 - 46656*x^16 + 56843*x^17 + 
              86834*x^18 - 90387*x^19 - 55161*x^20 + 68904*x^21 - 1728*x^22 - 
              19800*x^23 + 9000*x^24)) + 2880*x^11*(6 + 15*x - 180*x^2 + 
             735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 15*x^7 + 6*x^8)*
            Zeta[3]))/(97200*x^11*(-1 + x^2)^6) + 
        (HPL[{0}, x]*(3542940000 - 7794468000*x - 143972484480*x^2 + 
           342367676640*x^3 + 2322060065820*x^4 - 6228404932860*x^5 - 
           18530778719520*x^6 + 60991418026260*x^7 - 
           135*(-529140974287 + 2201580*Pi^2)*x^8 + 
           27*(-13074795032687 + 46801800*Pi^2)*x^9 + 
           160*(17968254167025 + 5432102454149*Pi^2)*x^21 + 
           9*(39522027098661 + 160107440723500*Pi^2)*x^33 + 
           45*(-1592389942491 + 2492934038248*Pi^2)*x^34 - 
           45*(1356403134213 + 12092052073208*Pi^2)*x^35 + 
           1440*(12868596333 + 33545681074*Pi^2)*x^36 + 
           180*(34602249627 + 767812635760*Pi^2)*x^37 - 
           180*(12900333699 + 166991188240*Pi^2)*x^38 - 
           3240*(105669036 + 6918554897*Pi^2)*x^39 + 
           1620*(88871904 + 4293176233*Pi^2)*x^40 + 
           12028500*(648 + 182107*Pi^2)*x^41 - 218700*(16200 + 3759073*Pi^2)*
            x^42 - 116720714880*Pi^2*x^43 + 49171808160*Pi^2*x^44 + 
           2598156000*Pi^2*x^45 - 1180980000*Pi^2*x^46 + 
           x^25*(-3632488794564871 + 2570737937974540*Pi^2 - 
             316132844544000*Zeta[3]) - 8*x^23*(-3694805515306738 + 
             184152482412615*Pi^2 - 94270706928000*Zeta[3]) - 
           60*x^20*(56224061917471 + 9096693087120*Pi^2 - 15661773273600*
              Zeta[3]) + 60*x^22*(-337204009992359 + 13515648158256*Pi^2 - 
             15661773273600*Zeta[3]) - 120*x^14*(-16877131313671 + 
             13138155630*Pi^2 - 181618977600*Zeta[3]) + 
           60*x^29*(56834337304203 + 59522421102260*Pi^2 - 
             61977830400*Zeta[3]) + x^32*(75410670010995 - 758812804774240*
              Pi^2 - 51018336000*Zeta[3]) - 2*x^31*(662224570830711 + 
             1336120893738980*Pi^2 - 51018336000*Zeta[3]) + 
           180*x^12*(-2385143958973 + 731567700*Pi^2 - 9762768000*Zeta[3]) + 
           135*x^10*(-526957133407 + 10994940*Pi^2 + 377913600*Zeta[3]) - 
           27*x^11*(-47061687152261 + 1468740600*Pi^2 + 3779136000*Zeta[3]) + 
           180*x^13*(-16473253885841 + 2627699940*Pi^2 + 20659276800*
              Zeta[3]) + 40*x^30*(11314941798951 + 47405404492934*Pi^2 + 
             43932456000*Zeta[3]) - 20*x^28*(152767374636561 + 
             143298639254732*Pi^2 + 1089713865600*Zeta[3]) + 
           5*x^18*(1581982977234319 + 24706000356552*Pi^2 + 
             6695132889600*Zeta[3]) - 5*x^24*(3992001507310129 + 
             397833609725520*Pi^2 + 6695132889600*Zeta[3]) - 
           15*x^16*(319131100512073 + 229980766640*Pi^2 + 7001875872000*
              Zeta[3]) + 15*x^26*(812638715301763 + 193455069571464*Pi^2 + 
             7001875872000*Zeta[3]) - 6*x^15*(-749496209142359 + 
             572266520100*Pi^2 + 8521321824000*Zeta[3]) + 
           x^27*(-5321663491206279 - 3508633495451960*Pi^2 + 
             51127930944000*Zeta[3]) + x^17*(-3975364987749329 + 
             28708663786740*Pi^2 + 316132844544000*Zeta[3]) - 
           x^19*(80133933322079 + 220927597424520*Pi^2 + 754165655424000*
              Zeta[3])))/(972000*x^7*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        (-2400*Pi^4*x^9*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
            15*x^7 + 6*x^8) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^4*
           (-270000 + 594000*x + 1266840*x^2 - 4740120*x^3 - 693450*x^4 + 
            16666650*x^5 - 7913175*x^6 - 33911475*x^7 + 25135965*x^8 + 
            44103356*x^9 - 37760645*x^10 - 37860569*x^11 + 27879025*x^12 + 
            27900970*x^13 - 30780200*x^14 + 30780200*x^16 - 27900970*x^17 - 
            27879025*x^18 + 37860569*x^19 + 37760645*x^20 - 44103356*x^21 - 
            25135965*x^22 + 33911475*x^23 + 7913175*x^24 - 16666650*x^25 + 
            693450*x^26 + 4740120*x^27 - 1266840*x^28 - 594000*x^29 + 
            270000*x^30) + 3*x^2*(-3542940000 + 7794468000*x + 
            145153464480*x^2 - 344965832640*x^3 - 2369608026480*x^4 + 
            6341553183240*x^5 + 19284819118650*x^6 + 
            x^9*(373513771456263 - 829974723120*Zeta[3]) + 1400648578560*x^43*
             Zeta[3] - 590061697920*x^44*Zeta[3] - 31177872000*x^45*Zeta[3] + 
            14171760000*x^46*Zeta[3] - 144342000*x^41*
             (-54 + 182107*Zeta[3]) + 38880*x^7*(-1622246780 + 
              345141*Zeta[3]) + 2624400*x^42*(-1350 + 3759073*Zeta[3]) + 
            135*x^8*(-570535962127 + 469907568*Zeta[3]) - 
            19440*x^40*(-7466742 + 4293176233*Zeta[3]) + 
            38880*x^39*(-8872578 + 6918554897*Zeta[3]) - 
            45*x^10*(-1885832217637 + 25725360240*Zeta[3]) - 
            270*x^12*(-1789254468041 + 37258932096*Zeta[3]) - 
            4320*x^36*(-4464594495 + 134182724296*Zeta[3]) + 
            2160*x^38*(-1097040753 + 166991188240*Zeta[3]) + 
            1200*x^14*(-1870783348225 + 311971986432*Zeta[3]) + 
            18*x^11*(-76460677624357 + 992724219360*Zeta[3]) - 
            1080*x^37*(-5871808503 + 1535625271520*Zeta[3]) - 
            54*x^13*(-57882551245857 + 3066406950080*Zeta[3]) + 
            1350*x^35*(-46656303759 + 4836828249920*Zeta[3]) + 
            180*x^20*(78265511654881 + 5305616191936*Zeta[3]) + 
            60*x^15*(-61401871099079 + 8433146279408*Zeta[3]) - 
            135*x^34*(572154849997 + 9971355649984*Zeta[3]) + 
            24*x^23*(-1197441590399381 + 153265061749400*Zeta[3]) - 
            90*x^22*(-315444851437077 + 161659618001536*Zeta[3]) - 
            234*x^29*(-13417916060367 + 183710099550080*Zeta[3]) + 
            5*x^17*(378640617885509 + 318823619910816*Zeta[3]) - 
            60*x^30*(-5608245841767 + 379449418873504*Zeta[3]) - 
            5*x^16*(-734431922952509 + 602936886426624*Zeta[3]) + 
            15*x^32*(6201268150881 + 606994347598592*Zeta[3]) - 
            27*x^33*(-13727422703669 + 640454216385760*Zeta[3]) - 
            35*x^25*(-419933449980227 + 814283342153472*Zeta[3]) + 
            30*x^28*(-29638420587535 + 1158898628399296*Zeta[3]) + 
            30*x^27*(-191432705301613 + 1414000719739680*Zeta[3]) + 
            5*x^18*(-951034469785193 + 1604973185370432*Zeta[3]) - 
            6*x^19*(560919705422849 + 1812586452515200*Zeta[3]) + 
            4*x^21*(-2903634109725863 + 1985425560697920*Zeta[3]) + 
            12*x^31*(-112280762842323 + 2673451694071600*Zeta[3]) + 
            5*x^24*(711589067496277 + 6617818296393696*Zeta[3]) - 
            5*x^26*(475666584549541 + 7576362914806368*Zeta[3])))/
         (11664000*x^9*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4)) + 
      CA*CF*((Pi^2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 
           180*x^6 + 15*x^7 + 6*x^8)*HPL[{-2}, x])/(810*(-1 + x^2)^6) + 
        lm^2*((-11*(2 + 5*x - 28*x^2 + 145*x^3 - 188*x^4 + 145*x^5 - 28*x^6 + 
             5*x^7 + 2*x^8))/(360*(-1 + x^2)^6) + 
          (11*x^3*(1 - x + x^2)^2*HPL[{0}, x])/(3*(-1 + x^2)^7)) - 
        (Pi^2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{2}, x])/(810*(-1 + x^2)^6) + 
        (x*(-2265 + 9630*x - 26775*x^2 - 1770*x^3 - 316980*x^4 + 405760*x^5 - 
           166020*x^6 - 171450*x^7 - 279600*x^8 + 331656*x^9 + 277566*x^10 - 
           360012*x^11 - 177380*x^12 + 259960*x^13 + 52300*x^14 - 
           120380*x^15 + 5815*x^16 + 32490*x^17 - 8505*x^18 - 3888*x^19 + 
           1728*x^20)*HPL[{-2, 0}, x])/(8100*(-1 + x^2)^8) + 
        ((-51840 + 116640*x + 177390*x^2 - 799740*x^3 + 113235*x^4 + 
           2363190*x^5 - 1470900*x^6 + (-3787973 + 3600*Pi^2)*x^7 + 
           (4037921 + 9000*Pi^2)*x^8 - 9*(-232171 + 12400*Pi^2)*x^9 + 
           4*(358669 + 108000*Pi^2)*x^10 - 4*(1427899 + 121800*Pi^2)*x^11 + 
           10722516*x^12 + (-5711596 + 487200*Pi^2)*x^13 + 
           (1434676 - 432000*Pi^2)*x^14 + 9*(232171 + 12400*Pi^2)*x^15 + 
           (4037921 - 9000*Pi^2)*x^16 - (3787973 + 3600*Pi^2)*x^17 - 
           1470900*x^18 + 2363190*x^19 + 113235*x^20 - 799740*x^21 + 
           177390*x^22 + 116640*x^23 - 51840*x^24)*HPL[{-1, 0}, x])/
         (486000*x^7*(-1 + x^2)^7) + (x*(-2674919700 + 12871501020*x - 
           70110911610*x^2 - 105760312875*x^3 + 3766497902910*x^4 - 
           6436326930300*x^5 - 39388760396550*x^6 + 119444922415530*x^7 + 
           37202075851050*x^8 - 631028278141944*x^9 + 926807687217348*x^10 + 
           241614115988259*x^11 + 257426335483434*x^12 + 1008962161829476*
            x^13 - 17563852149472966*x^14 + 22709569646200004*x^15 - 
           8963276043461332*x^16 - 6767036146062724*x^17 + 
           4567893147161510*x^18 + 641170111227211*x^19 - 
           311857715754342*x^20 - 386066220833316*x^21 - 71532039771066*
            x^22 + 239326294042746*x^23 - 12341103510006*x^24 - 
           71936777906496*x^25 + 14233354561728*x^26 + 12399118168221*x^27 - 
           3652453624050*x^28 - 1248188390820*x^29 + 451998246870*x^30 + 
           67804785720*x^31 - 27799088220*x^32 - 1530550080*x^33 + 
           680244480*x^34)*HPL[{0, 0}, x])/(486000*(-1 + x^2)^8*
          (9 - 82*x^2 + 9*x^4)^4) + ((51840 - 116640*x - 177390*x^2 + 
           799740*x^3 - 113235*x^4 - 2363190*x^5 + 1470900*x^6 + 
           (3787973 - 3600*Pi^2)*x^7 - (4037921 + 9000*Pi^2)*x^8 + 
           9*(-232171 + 12400*Pi^2)*x^9 - 4*(358669 + 108000*Pi^2)*x^10 + 
           (5711596 + 487200*Pi^2)*x^11 - 10722516*x^12 + 
           (5711596 - 487200*Pi^2)*x^13 + 4*(-358669 + 108000*Pi^2)*x^14 - 
           9*(232171 + 12400*Pi^2)*x^15 + (-4037921 + 9000*Pi^2)*x^16 + 
           (3787973 + 3600*Pi^2)*x^17 + 1470900*x^18 - 2363190*x^19 - 
           113235*x^20 + 799740*x^21 - 177390*x^22 - 116640*x^23 + 
           51840*x^24)*HPL[{1, 0}, x])/(486000*x^7*(-1 + x^2)^7) + 
        lm*(-(3340 + 4203*x - 33406*x^2 + 208017*x^3 - 272820*x^4 + 
             208017*x^5 - 33406*x^6 + 4203*x^7 + 3340*x^8 + 
             44*Pi^2*(-2 - 5*x + 14*x^2 - 15*x^3 + 15*x^5 - 14*x^6 + 5*x^7 + 
               2*x^8))/(12960*(-1 + x^2)^6) + 
          (x^2*(22 + 6199*x - 12068*x^2 + 22117*x^3 - 17348*x^4 + 10819*x^5 - 
             968*x^6 + 165*x^7 + 66*x^8)*HPL[{0}, x])/(270*(-1 + x^2)^7) + 
          (11*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6)*
            HPL[{-1, 0}, x])/(270*(-1 + x^2)^5) - 
          (11*x^3*(180 - 360*x + 1260*x^2 - 1560*x^3 + 1940*x^4 - 1050*x^5 + 
             545*x^6 - 18*x^7 + 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
           (135*(-1 + x^2)^8) - (11*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 
             5*x^5 + 2*x^6)*HPL[{1, 0}, x])/(270*(-1 + x^2)^5)) + 
        (x*(2265 - 9630*x + 26775*x^2 + 1770*x^3 + 316980*x^4 - 405760*x^5 + 
           166020*x^6 + 171450*x^7 + 279600*x^8 - 331656*x^9 - 277566*x^10 + 
           360012*x^11 + 177380*x^12 - 259960*x^13 - 52300*x^14 + 
           120380*x^15 - 5815*x^16 - 32490*x^17 + 8505*x^18 + 3888*x^19 - 
           1728*x^20)*HPL[{2, 0}, x])/(8100*(-1 + x^2)^8) - 
        (2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-2, -1, 0}, x])/(135*(-1 + x^2)^6) + 
        (8*x^2*(-69 + 345*x - 496*x^2 + 390*x^3 - 111*x^4 + 15*x^5 + 6*x^6)*
          HPL[{-2, 0, 0}, x])/(135*(-1 + x^2)^6) + 
        (2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-2, 1, 0}, x])/(135*(-1 + x^2)^6) + 
        (2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-1, -2, 0}, x])/(135*(-1 + x^2)^6) + 
        ((-1728 + 3888*x + 3321*x^2 - 20826*x^3 + 9332*x^4 + 46238*x^5 - 
           35995*x^6 - 54880*x^7 + 44720*x^8 + 34512*x^9 - 31654*x^10 + 
           4268*x^11 - 15592*x^12 + 4268*x^13 - 31654*x^14 + 34512*x^15 + 
           44720*x^16 - 54880*x^17 - 35995*x^18 + 46238*x^19 + 9332*x^20 - 
           20826*x^21 + 3321*x^22 + 3888*x^23 - 1728*x^24)*
          HPL[{-1, -1, 0}, x])/(16200*x^9*(-1 + x^2)^5) + 
        ((-2116 + 23025*x - 117424*x^2 + 413688*x^3 - 813652*x^4 + 
           1015848*x^5 - 693204*x^6 + 350152*x^7 - 300280*x^8 + 196148*x^9 + 
           168400*x^10 - 237624*x^11 - 56600*x^12 + 173444*x^13 - 
           30328*x^14 - 60488*x^15 + 30924*x^16 + 4455*x^17 - 7344*x^18 + 
           1728*x^19)*HPL[{-1, 0, 0}, x])/(8100*(-1 + x)^8*(1 + x)^6) - 
        ((-1728 + 3888*x + 3321*x^2 - 20826*x^3 + 9332*x^4 + 46238*x^5 - 
           35995*x^6 - 54880*x^7 + 44720*x^8 + 34512*x^9 - 31654*x^10 + 
           4268*x^11 - 15592*x^12 + 4268*x^13 - 31654*x^14 + 34512*x^15 + 
           44720*x^16 - 54880*x^17 - 35995*x^18 + 46238*x^19 + 9332*x^20 - 
           20826*x^21 + 3321*x^22 + 3888*x^23 - 1728*x^24)*
          HPL[{-1, 1, 0}, x])/(16200*x^9*(-1 + x^2)^5) - 
        (2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-1, 2, 0}, x])/(135*(-1 + x^2)^6) + 
        (x*(14860665 - 58458510*x + 1951121115*x^2 - 3336974172*x^3 - 
           64111056930*x^4 + 149305544082*x^5 + 548692063938*x^6 - 
           1774862278542*x^7 + 94067362203*x^8 + 6061409878068*x^9 - 
           12673655626671*x^10 + 11567647290198*x^11 - 34985267972676*x^12 - 
           2044866072348*x^13 + 320758014106228*x^14 - 461342962598756*x^15 + 
           289293076319281*x^16 + 55108552721110*x^17 - 171616962132977*
            x^18 + 79356051836384*x^19 + 49195324794598*x^20 - 
           56615699018294*x^21 - 14514398638454*x^22 + 27946246684762*x^23 + 
           2407021148905*x^24 - 10410505393032*x^25 + 762172214787*x^26 + 
           2662040150982*x^27 - 539786179440*x^28 - 434956695264*x^29 + 
           129205483344*x^30 + 42732107928*x^31 - 15528036798*x^32 - 
           2285668692*x^33 + 937973682*x^34 + 51018336*x^35 - 22674816*x^36)*
          HPL[{0, 0, 0}, x])/(8100*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) - 
        (2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{1, -2, 0}, x])/(135*(-1 + x^2)^6) - 
        ((-1728 + 3888*x + 3321*x^2 - 20826*x^3 + 9332*x^4 + 46238*x^5 - 
           35995*x^6 - 54880*x^7 + 44720*x^8 + 34512*x^9 - 31654*x^10 + 
           4268*x^11 - 15592*x^12 + 4268*x^13 - 31654*x^14 + 34512*x^15 + 
           44720*x^16 - 54880*x^17 - 35995*x^18 + 46238*x^19 + 9332*x^20 - 
           20826*x^21 + 3321*x^22 + 3888*x^23 - 1728*x^24)*
          HPL[{1, -1, 0}, x])/(16200*x^9*(-1 + x^2)^5) + 
        ((2116 - 17441*x + 29292*x^2 - 159440*x^3 + 48328*x^4 + 47208*x^5 + 
           71328*x^6 - 290800*x^7 - 66948*x^8 + 177564*x^9 + 154460*x^10 - 
           166848*x^11 - 124708*x^12 + 94812*x^13 + 54372*x^14 - 38368*x^15 - 
           10728*x^16 + 11097*x^17 + 432*x^18 - 1728*x^19)*HPL[{1, 0, 0}, x])/
         (8100*(-1 + x)^6*(1 + x)^8) + ((-1728 + 3888*x + 3321*x^2 - 
           20826*x^3 + 9332*x^4 + 46238*x^5 - 35995*x^6 - 54880*x^7 + 
           44720*x^8 + 34512*x^9 - 31654*x^10 + 4268*x^11 - 15592*x^12 + 
           4268*x^13 - 31654*x^14 + 34512*x^15 + 44720*x^16 - 54880*x^17 - 
           35995*x^18 + 46238*x^19 + 9332*x^20 - 20826*x^21 + 3321*x^22 + 
           3888*x^23 - 1728*x^24)*HPL[{1, 1, 0}, x])/
         (16200*x^9*(-1 + x^2)^5) + (2*(6 + 15*x - 180*x^2 + 735*x^3 - 
           992*x^4 + 735*x^5 - 180*x^6 + 15*x^7 + 6*x^8)*HPL[{1, 2, 0}, x])/
         (135*(-1 + x^2)^6) + (2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 
           735*x^5 - 180*x^6 + 15*x^7 + 6*x^8)*HPL[{2, -1, 0}, x])/
         (135*(-1 + x^2)^6) - (8*x^2*(-69 + 345*x - 496*x^2 + 390*x^3 - 
           111*x^4 + 15*x^5 + 6*x^6)*HPL[{2, 0, 0}, x])/(135*(-1 + x^2)^6) - 
        (2*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{2, 1, 0}, x])/(135*(-1 + x^2)^6) - 
        (4*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6)*
          HPL[{-1, 0, 0, 0}, x])/(45*(-1 + x^2)^5) + 
        (4*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{-1, 1, 0, 0}, x])/(135*(-1 + x^2)^6) + 
        (4*(6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
           15*x^7 + 6*x^8)*HPL[{1, -1, 0, 0}, x])/(135*(-1 + x^2)^6) + 
        (4*(2 + 5*x - 12*x^2 + 20*x^3 - 12*x^4 + 5*x^5 + 2*x^6)*
          HPL[{1, 0, 0, 0}, x])/(45*(-1 + x^2)^5) - 
        ((12 + 59*x - 288*x^2 + 2032*x^3 - 3056*x^4 + 3408*x^5 - 1432*x^6 + 
           592*x^7 + 84*x^8 + 29*x^9)*master3l10a[x])/(1080*(-1 + x^2)^7) + 
        (x*(29 + 84*x + 592*x^2 - 1432*x^3 + 3408*x^4 - 3056*x^5 + 2032*x^6 - 
           288*x^7 + 59*x^8 + 12*x^9)*master3l10b[x])/(1080*(-1 + x^2)^7) + 
        ((-18254889 + 105470991*x - 300347757*x^2 + 382662549*x^3 - 
           116505*x^4 + 2498499*x^5 - 73616445*x^6 + 43746489*x^7 + 
           42249717*x^8 - 32410419*x^9 - 7137951*x^10 + 6597295*x^11 + 
           371045*x^12 - 546655*x^13 + 10313*x^14 + 16323*x^15 - 1048*x^16)*
          master3l8a[x])/(32400*(-9 + x^2)^4*(-1 + x^2)^8) + 
        ((1510 - 5132*x - 53133*x^2 + 205139*x^3 + 721473*x^4 - 3009345*x^5 - 
           5808417*x^6 + 20867427*x^7 + 43093641*x^8 - 88829313*x^9 - 
           247173111*x^10 + 394340481*x^11 + 457334163*x^12 - 
           1164732939*x^13 + 1015853157*x^14 - 309744567*x^15 + 
           78339069*x^16 + 13530969*x^17)*master3l8b[x])/
         (32400*x*(1 - 9*x^2)^4*(-1 + x^2)^8) + 
        ((1765881 - 1507329*x - 325836*x^2 + 35009775*x^3 - 64737117*x^4 + 
           29158623*x^5 + 18804594*x^6 - 12922353*x^7 - 5192769*x^8 + 
           2758853*x^9 + 978880*x^10 - 382667*x^11 - 79035*x^12 + 
           27933*x^13 + 2042*x^14 - 755*x^15)*master3l9a[x])/
         (10800*(-9 + x^2)^3*(-1 + x^2)^8) + 
        ((-755 + 2042*x + 27933*x^2 - 79035*x^3 - 382667*x^4 + 978880*x^5 + 
           2758853*x^6 - 5192769*x^7 - 12922353*x^8 + 18804594*x^9 + 
           29158623*x^10 - 64737117*x^11 + 35009775*x^12 - 325836*x^13 - 
           1507329*x^14 + 1765881*x^15)*master3l9b[x])/(32400*x*(-1 + x^2)^8*
          (-1 + 9*x^2)^3) + (HPL[{1}, x]*(Pi^2*(1728 - 3888*x - 5049*x^2 + 
             24714*x^3 - 6011*x^4 - 67064*x^5 + 45327*x^6 + 101118*x^7 - 
             80715*x^8 - 89392*x^9 + 76374*x^10 + 30244*x^11 - 16062*x^12 + 
             16062*x^14 - 30244*x^15 - 76374*x^16 + 89392*x^17 + 80715*x^18 - 
             101118*x^19 - 45327*x^20 + 67064*x^21 + 6011*x^22 - 24714*x^23 + 
             5049*x^24 + 3888*x^25 - 1728*x^26) - 2880*x^9*
            (6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
             15*x^7 + 6*x^8)*Zeta[3]))/(194400*x^9*(-1 + x^2)^6) + 
        (HPL[{-1}, x]*(Pi^2*(-1728 + 3888*x + 5049*x^2 - 24714*x^3 + 
             6011*x^4 + 67064*x^5 - 45327*x^6 - 101118*x^7 + 80715*x^8 + 
             89392*x^9 - 76374*x^10 - 30244*x^11 + 16062*x^12 - 16062*x^14 + 
             30244*x^15 + 76374*x^16 - 89392*x^17 - 80715*x^18 + 
             101118*x^19 + 45327*x^20 - 67064*x^21 - 6011*x^22 + 24714*x^23 - 
             5049*x^24 - 3888*x^25 + 1728*x^26) + 2880*x^9*
            (6 + 15*x - 180*x^2 + 735*x^3 - 992*x^4 + 735*x^5 - 180*x^6 + 
             15*x^7 + 6*x^8)*Zeta[3]))/(194400*x^9*(-1 + x^2)^6) + 
        (HPL[{0}, x]*(680244480 - 1530550080*x - 27458965980*x^2 + 
           67039510680*x^3 + 438325450920*x^4 - 1214796181320*x^5 + 
           3645*(-937890163 + 81540*Pi^2)*x^6 - 4374*(-2683769423 + 
             288900*Pi^2)*x^7 - 80*(21805317383055 + 6446942021368*Pi^2)*
            x^19 - 54*(268250229063 + 1919604504760*Pi^2)*x^31 + 
           45*(81105790293 + 168474590656*Pi^2)*x^32 + 
           405*(3117272769 + 65709804208*Pi^2)*x^33 - 
           1080*(405856899 + 4998020180*Pi^2)*x^34 - 
           29160*(2299023 + 149162104*Pi^2)*x^35 + 
           4860*(5649993 + 265854904*Pi^2)*x^36 + 42515280*(36 + 10051*Pi^2)*
            x^37 - 393660*(1728 + 394453*Pi^2)*x^38 - 22856686920*Pi^2*x^39 + 
           9379736820*Pi^2*x^40 + 510183360*Pi^2*x^41 - 226748160*Pi^2*x^42 + 
           x^25*(906199721805507 + 637554126015240*Pi^2 - 51127930944000*
              Zeta[3]) - 60*x^20*(-462124407227617 + 1513773724096*Pi^2 - 
             15661773273600*Zeta[3]) + 60*x^18*(-81347229507967 + 
             4482140395104*Pi^2 - 15661773273600*Zeta[3]) + 
           2*x^29*(59688763379973 + 135280027675220*Pi^2 - 
             51018336000*Zeta[3]) - 80*x^27*(7970948963865 + 
             6146691248278*Pi^2 - 46483372800*Zeta[3]) - 
           64800*x^11*(-2726817334 + 10743111*Pi^2 + 57386880*Zeta[3]) + 
           243*x^9*(-263400986897 + 190474200*Pi^2 + 419904000*Zeta[3]) - 
           81*x^8*(-145498027871 + 90350100*Pi^2 + 629856000*Zeta[3]) + 
           108*x^10*(94678281157 + 581229000*Pi^2 + 16271280000*Zeta[3]) - 
           8*x^28*(4168839402207 + 17971623674980*Pi^2 + 219662280000*
              Zeta[3]) - 24*x^12*(12511949066219 + 27573363000*Pi^2 + 
             908094888000*Zeta[3]) + 4*x^26*(339883554413739 + 
             84162287278480*Pi^2 + 5448569328000*Zeta[3]) + 
           15*x^14*(103282964014319 + 763908420200*Pi^2 + 7001875872000*
              Zeta[3]) - 15*x^24*(616588580857829 + 31296625057040*Pi^2 + 
             7001875872000*Zeta[3]) + 6*x^13*(-3609634427297 + 
             1006779145500*Pi^2 + 8521321824000*Zeta[3]) - 
           x^16*(3242170324587989 + 94019279407920*Pi^2 + 33475664448000*
              Zeta[3]) + x^22*(16319157009877739 + 368167922879880*Pi^2 + 
             33475664448000*Zeta[3]) - 2*x^15*(769197310864079 + 
             19149032732760*Pi^2 + 158066422272000*Zeta[3]) + 
           x^23*(9259764669935758 - 606567082856160*Pi^2 + 316132844544000*
              Zeta[3]) + x^17*(5034369301986347 + 185625131609280*Pi^2 + 
             754165655424000*Zeta[3]) + x^30*(24927820932760*Pi^2 + 
             81*(-200454178421 + 629856000*Zeta[3])) + 
           4*x^21*(126510282730800*Pi^2 - 37*(241905159761339 + 5095713888000*
                Zeta[3]))))/(1944000*x^5*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^
           4) + (480*Pi^4*x^7*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (-18 - 45*x - 564*x^2 + 3315*x^3 - 4960*x^4 + 4035*x^5 - 
            1236*x^6 + 195*x^7 + 78*x^8) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^4*
           (-51840 + 116640*x + 229230*x^2 - 916380*x^3 - 64155*x^4 + 
            3162930*x^5 - 1584135*x^6 - 6151163*x^7 + 5508821*x^8 + 
            5877512*x^9 - 2603245*x^10 - 7801135*x^11 + 9287840*x^12 - 
            9287840*x^14 + 7801135*x^15 + 2603245*x^16 - 5877512*x^17 - 
            5508821*x^18 + 6151163*x^19 + 1584135*x^20 - 3162930*x^21 + 
            64155*x^22 + 916380*x^23 - 229230*x^24 - 116640*x^25 + 
            51840*x^26) + 3*x^2*(-680244480 + 1530550080*x + 
            27685714140*x^2 - 67549694040*x^3 - 445164309270*x^4 + 
            x^16*(76409282282257 - 10050554898714240*Zeta[3]) + 
            x^25*(912404000399175 - 8045510817826560*Zeta[3]) + 
            x^29*(35101158880743 - 3265740963897600*Zeta[3]) + 
            x^15*(2825217977103170 - 2149474380014400*Zeta[3]) + 
            274280243040*x^39*Zeta[3] - 112556841840*x^40*Zeta[3] - 
            6122200320*x^41*Zeta[3] + 2720977920*x^42*Zeta[3] - 
            510183360*x^37*(-3 + 10051*Zeta[3]) - 98415*x^5*
             (-13006727 + 173504*Zeta[3]) + 4723920*x^38*
             (-144 + 394453*Zeta[3]) - 3645*x^6*(-904374073 + 
              21056112*Zeta[3]) - 102060*x^36*(-271269 + 151917088*Zeta[3]) + 
            4374*x^7*(-2964906411 + 232013360*Zeta[3]) + 
            87480*x^35*(-772173 + 596648416*Zeta[3]) + 
            81*x^8*(-82620937277 + 17362907280*Zeta[3]) - 
            729*x^9*(-87824694117 + 29262318080*Zeta[3]) + 
            1620*x^34*(-276168771 + 39984161440*Zeta[3]) + 
            54*x^10*(-909622826161 + 221314317120*Zeta[3]) - 
            1215*x^33*(-981985437 + 262851559936*Zeta[3]) - 
            135*x^32*(-26036987841 + 674401967488*Zeta[3]) + 
            108*x^11*(-152243976923 + 1791112715200*Zeta[3]) + 
            162*x^31*(-62315692497 + 7684005705760*Zeta[3]) - 
            24*x^12*(-7434590762363 + 18767661921360*Zeta[3]) - 
            15*x^13*(76430992846965 + 37201165260032*Zeta[3]) + 
            36*x^18*(-336070057290441 + 51475700997280*Zeta[3]) - 
            3*x^30*(4949622796329 + 99333152130880*Zeta[3]) + 
            12*x^28*(8123693604363 + 145029842086880*Zeta[3]) + 
            18*x^20*(-1466709255217457 + 316425001386560*Zeta[3]) + 
            33*x^17*(6995870286809 + 428349319285760*Zeta[3]) + 
            10*x^23*(-997924968277723 + 441900503041728*Zeta[3]) + 
            12*x^27*(-2548078363107 + 505738834475840*Zeta[3]) - 
            6*x^26*(196226203657873 + 751713003481280*Zeta[3]) - 
            8*x^19*(-1738110166595167 + 1837618136025120*Zeta[3]) + 
            3*x^21*(8534647885504249 + 3526658077847680*Zeta[3]) + 
            x^14*(628781277013163 + 3652313631768000*Zeta[3]) + 
            x^24*(6679273814523413 + 9425544762751200*Zeta[3]) - 
            x^22*(8236708404125093 + 15420709017951840*Zeta[3])))/
         (23328000*x^7*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4)))
 
CbarData["v", 2, 3] = 
    NC*(CF*(NL*(-(Pi^2*(5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 
              42*x^6 + 18*x^7 + 5*x^8)*HPL[{-1}, x])/(4860*(-1 + x^2)^7) + 
          (x^2*(-675 + 27*(48529 + 3000*Pi^2)*x - 18*(168809 + 11250*Pi^2)*
              x^2 + 27*(270661 + 24000*Pi^2)*x^3 - 4*(1733029 + 215625*Pi^2)*
              x^4 + 90*(21271 + 13200*Pi^2)*x^5 + (4933466 - 850950*Pi^2)*
              x^6 + 36*(-224842 + 17775*Pi^2)*x^7 - 27*(-182851 + 7550*Pi^2)*
              x^8 + 9*(-269657 + 9360*Pi^2)*x^9 + (107170 - 1710*Pi^2)*x^10 + 
             45*(-251 + 12*Pi^2)*x^11 + 10*(-626 + 15*Pi^2)*x^12)*
            HPL[{0}, x])/(145800*(-1 + x^2)^10) + 
          lm^2*((5 + 18*x - 115*x^2 + 1068*x^3 - 1990*x^4 + 2868*x^5 - 
              1990*x^6 + 1068*x^7 - 115*x^8 + 18*x^9 + 5*x^10)/
             (720*(-1 + x^2)^8) - (x^3*(6 - 15*x + 36*x^2 - 40*x^3 + 36*x^4 - 
               15*x^5 + 6*x^6)*HPL[{0}, x])/(6*(-1 + x^2)^9)) + 
          (Pi^2*(5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
             18*x^7 + 5*x^8)*HPL[{1}, x])/(4860*(-1 + x^2)^7) - 
          (x^3*(2700 - 6750*x + 21600*x^2 - 28750*x^3 + 39600*x^4 - 
             28365*x^5 + 21330*x^6 - 6795*x^7 + 2808*x^8 - 57*x^9 + 18*x^10 + 
             5*x^11)*HPL[{-2, 0}, x])/(405*(-1 + x^2)^10) + 
          ((75 + 178*x - 6512*x^2 + 148486*x^3 - 320287*x^4 + 731896*x^5 - 
             760792*x^6 + 731896*x^7 - 320287*x^8 + 148486*x^9 - 6512*x^10 + 
             178*x^11 + 75*x^12)*HPL[{-1, 0}, x])/(16200*(-1 + x^2)^9) + 
          (x^3*(36000 - 90000*x + 369000*x^2 - 563000*x^3 + 980000*x^4 - 
             872225*x^5 + 761850*x^6 - 303375*x^7 + 134892*x^8 - 4463*x^9 + 
             1442*x^10 + 375*x^11)*HPL[{0, 0}, x])/(8100*(-1 + x^2)^10) - 
          ((75 + 178*x - 6512*x^2 + 148486*x^3 - 320287*x^4 + 731896*x^5 - 
             760792*x^6 + 731896*x^7 - 320287*x^8 + 148486*x^9 - 6512*x^10 + 
             178*x^11 + 75*x^12)*HPL[{1, 0}, x])/(16200*(-1 + x^2)^9) + 
          lm*((1252 + 2259*x - 18795*x^2 + 227844*x^3 - 418525*x^4 + 
              610722*x^5 - 418525*x^6 + 227844*x^7 - 18795*x^8 + 2259*x^9 + 
              1252*x^10 + 6*Pi^2*(-5 - 18*x + 47*x^2 - 144*x^3 + 144*x^4 - 
                144*x^6 + 144*x^7 - 47*x^8 + 18*x^9 + 5*x^10))/
             (58320*(-1 + x^2)^8) - (x^2*(10 + 7716*x - 18450*x^2 + 53154*
                x^3 - 64374*x^4 + 69354*x^5 - 35325*x^6 + 17166*x^7 - 1070*
                x^8 + 162*x^9 + 45*x^10)*HPL[{0}, x])/(1620*(-1 + x^2)^9) - 
            ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 18*
                x^7 + 5*x^8)*HPL[{-1, 0}, x])/(810*(-1 + x^2)^7) + 
            (x^3*(1080 - 2700*x + 13500*x^2 - 22000*x^3 + 39600*x^4 - 35115*
                x^5 + 29430*x^6 - 10845*x^7 + 4428*x^8 - 57*x^9 + 18*x^10 + 5*
                x^11)*HPL[{0, 0}, x])/(405*(-1 + x^2)^10) + 
            ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 18*
                x^7 + 5*x^8)*HPL[{1, 0}, x])/(810*(-1 + x^2)^7)) + 
          (x^3*(2700 - 6750*x + 21600*x^2 - 28750*x^3 + 39600*x^4 - 
             28365*x^5 + 21330*x^6 - 6795*x^7 + 2808*x^8 - 57*x^9 + 18*x^10 + 
             5*x^11)*HPL[{2, 0}, x])/(405*(-1 + x^2)^10) + 
          ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
             18*x^7 + 5*x^8)*HPL[{-1, -1, 0}, x])/(405*(-1 + x^2)^7) - 
          ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
             18*x^7 + 5*x^8)*HPL[{-1, 1, 0}, x])/(405*(-1 + x^2)^7) - 
          (2*x^3*(1080 - 2700*x + 13500*x^2 - 22000*x^3 + 39600*x^4 - 
             35115*x^5 + 29430*x^6 - 10845*x^7 + 4428*x^8 - 57*x^9 + 
             18*x^10 + 5*x^11)*HPL[{0, 0, 0}, x])/(405*(-1 + x^2)^10) - 
          ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
             18*x^7 + 5*x^8)*HPL[{1, -1, 0}, x])/(405*(-1 + x^2)^7) + 
          ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
             18*x^7 + 5*x^8)*HPL[{1, 1, 0}, x])/(405*(-1 + x^2)^7) + 
          (-512555*x^12 - 363750*x^13 + 158695*x^14 - 
            36*Pi^2*(-75 - 178*x + 6587*x^2 - 148308*x^3 + 313775*x^4 - 
              583410*x^5 + 440505*x^6 - 440505*x^8 + 583410*x^9 - 
              313775*x^10 + 148308*x^11 - 6587*x^12 + 178*x^13 + 75*x^14) + 
            x^8*(42159877 - 248400000*Zeta[3]) + 
            x^6*(42159877 - 245073600*Zeta[3]) + 
            30*x*(-12125 + 5184*Zeta[3]) + 5*(31739 + 8640*Zeta[3]) + 
            324*x^11*(75157 + 72000*Zeta[3]) + 324*x^3*(75157 + 
              74880*Zeta[3]) - 5*x^2*(102511 + 98496*Zeta[3]) + 
            270*x^5*(70133 + 682560*Zeta[3]) + 270*x^9*(70133 + 
              691200*Zeta[3]) - 27*x^10*(1548371 + 2160000*Zeta[3]) - 
            27*x^4*(1548371 + 2174400*Zeta[3]) + 24*x^7*(-3576919 + 
              14256000*Zeta[3]))/(6998400*(-1 + x^2)^10)) + 
        NH*((x*(413248521600 + 1755103506768*x + 470910675292164*x^2 - 
             963328705662609*x^3 + 1977193939887810*x^4 - 1762170667632846*
              x^5 + 649824958324890*x^6 + 603299080135476*x^7 - 
             803120910602130*x^8 + 248886617940630*x^9 + 134738215856298*
              x^10 - 156418619879349*x^11 + 25630966127844*x^12 + 
             31335771699684*x^13 - 12066079139532*x^14 - 2602799976816*x^15 + 
             1850635288620*x^16 - 26703154004*x^17 - 146917690200*x^18 + 
             24433582725*x^19 + 6145805178*x^20 - 2150676022*x^21 - 
             104568750*x^22 + 85464188*x^23 - 760122*x^24 - 1380210*x^25 + 
             33930*x^26 + 385*x^27)*HPL[{0}, x])/(583200*(-9 + x^2)^6*
            (-1 + x^2)^11) + lm^2*((5 + 18*x - 115*x^2 + 1068*x^3 - 
              1990*x^4 + 2868*x^5 - 1990*x^6 + 1068*x^7 - 115*x^8 + 18*x^9 + 
              5*x^10)/(720*(-1 + x^2)^8) - (x^3*(6 - 15*x + 36*x^2 - 40*x^3 + 
               36*x^4 - 15*x^5 + 6*x^6)*HPL[{0}, x])/(6*(-1 + x^2)^9)) + 
          (x*(-11479125600 - 15942468924*x - 9572760862632*x^2 + 
             19491402723363*x^3 - 39341791697022*x^4 + 33677737348446*x^5 - 
             8773300507302*x^6 - 16804136226438*x^7 + 19905027698250*x^8 - 
             5319974331522*x^9 - 3669992980110*x^10 + 4068252313425*x^11 - 
             877907395596*x^12 - 792899520052*x^13 + 371544816132*x^14 + 
             41623264092*x^15 - 45272794956*x^16 + 6343692032*x^17 + 
             1461852380*x^18 - 1123613387*x^19 + 140358730*x^20 + 
             68147254*x^21 - 12800094*x^22 - 1565430*x^23 + 268194*x^24 - 
             3234*x^25 + 1626*x^26 + 375*x^27)*HPL[{0, 0}, x])/
           (16200*(-9 + x^2)^6*(-1 + x^2)^11) + 
          lm*((1252 + 2259*x - 18795*x^2 + 227844*x^3 - 418525*x^4 + 
              610722*x^5 - 418525*x^6 + 227844*x^7 - 18795*x^8 + 2259*x^9 + 
              1252*x^10 + 6*Pi^2*(-5 - 18*x + 47*x^2 - 144*x^3 + 144*x^4 - 
                144*x^6 + 144*x^7 - 47*x^8 + 18*x^9 + 5*x^10))/
             (58320*(-1 + x^2)^8) - (x^2*(10 + 7716*x - 18450*x^2 + 53154*
                x^3 - 64374*x^4 + 69354*x^5 - 35325*x^6 + 17166*x^7 - 1070*
                x^8 + 162*x^9 + 45*x^10)*HPL[{0}, x])/(1620*(-1 + x^2)^9) - 
            ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 18*
                x^7 + 5*x^8)*HPL[{-1, 0}, x])/(810*(-1 + x^2)^7) + 
            (x^3*(1080 - 2700*x + 13500*x^2 - 22000*x^3 + 39600*x^4 - 35115*
                x^5 + 29430*x^6 - 10845*x^7 + 4428*x^8 - 57*x^9 + 18*x^10 + 5*
                x^11)*HPL[{0, 0}, x])/(405*(-1 + x^2)^10) + 
            ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 18*
                x^7 + 5*x^8)*HPL[{1, 0}, x])/(810*(-1 + x^2)^7)) + 
          ((101 - 17929*x + 40390*x^2 - 106673*x^3 + 135081*x^4 - 
             151909*x^5 + 101052*x^6 - 61565*x^7 + 17723*x^8 - 5056*x^9 + 
             78*x^10 - 8*x^11 - 5*x^12)*HPL[{-1, 0, 0}, x])/
           (405*(-1 + x)^10*(1 + x)^8) + 
          (x^3*(354029591700 - 699240498831*x + 1433156115942*x^2 - 
             1197153873936*x^3 + 302134781538*x^4 + 630502061022*x^5 - 
             836784824526*x^6 + 264836959776*x^7 + 103180308642*x^8 - 
             170694833841*x^9 + 61733587284*x^10 + 27195063064*x^11 - 
             18662604948*x^12 - 104591716*x^13 + 1682896668*x^14 - 
             435648488*x^15 + 20582064*x^16 + 53137351*x^17 - 13127418*x^18 - 
             2844456*x^19 + 816114*x^20 + 79590*x^21 - 17550*x^22 - 
             1560*x^23 + 90*x^24 + 25*x^25)*HPL[{0, 0, 0}, x])/
           (2025*(-9 + x^2)^6*(-1 + x^2)^11) + 
          ((-641 + 17795*x - 37522*x^2 + 102883*x^3 - 110937*x^4 + 
             119363*x^5 - 55152*x^6 + 32803*x^7 - 4487*x^8 + 3908*x^9 - 
             6*x^10 + 28*x^11 + 5*x^12)*HPL[{1, 0, 0}, x])/
           (405*(-1 + x)^8*(1 + x)^10) + ((9188424621 + 1419421161078*x - 
             2881898457462*x^2 + 6012119012958*x^3 - 5508851357628*x^4 + 
             2590960630626*x^5 + 1036610225694*x^6 - 1857452561910*x^7 + 
             743163988401*x^8 + 196395988140*x^9 - 314937415116*x^10 + 
             59576629500*x^11 + 49649673504*x^12 - 20924512236*x^13 - 
             3113339828*x^14 + 2999904036*x^15 - 112490961*x^16 - 
             237238530*x^17 + 32989346*x^18 + 9753030*x^19 - 2256612*x^20 - 
             131478*x^21 + 64566*x^22 - 1614*x^23 - 525*x^24)*master3l8a[x])/
           (48600*(-9 + x^2)^6*(-1 + x^2)^11) - 
          ((1020936069 + 79040219742*x - 164710724859*x^2 + 
             358316333424*x^3 - 364361592735*x^4 + 260556377886*x^5 - 
             65417276565*x^6 + 8519273892*x^7 + 16452532476*x^8 - 
             160595028*x^9 + 4767198338*x^10 - 7116793344*x^11 + 
             2971746*x^12 + 1031544924*x^13 - 322353850*x^14 + 
             73961736*x^15 + 48494685*x^16 - 22715658*x^17 - 2754519*x^18 + 
             1476912*x^19 + 75309*x^20 - 31866*x^21 - 2145*x^22 + 180*x^23 + 
             50*x^24)*master3l9a[x])/(16200*(-9 + x^2)^5*(-1 + x^2)^11) + 
          (x^12*(532864317727828 - 91306377691200*Zeta[3]) + 
            x^15*(37172030949672 - 9167086656000*Zeta[3]) + 
            x^16*(17599116495503 - 7482350347200*Zeta[3]) + 
            x^19*(936988917132 - 283649212800*Zeta[3]) + 
            320*x^28*(-137 + 45*Zeta[3]) + 120*x^27*(-4711 + 432*Zeta[3]) - 
            15*x^26*(-734081 + 63744*Zeta[3]) - 6*x^25*(3591343 + 
              164160*Zeta[3]) - 15234642*x*(80990087 + 751680*Zeta[3]) + 
            1240029*(-8721347 + 2531520*Zeta[3]) - 108*x^23*
             (-20884019 + 2844480*Zeta[3]) + x^24*(-457429043 + 
              25721280*Zeta[3]) + 19683*x^2*(127403584793 + 256193280*Zeta[
                3]) + x^22*(7364701874 + 256296960*Zeta[3]) + 
            24*x^21*(-2644307081 + 619892640*Zeta[3]) + 131220*x^3*
             (-53340849793 + 1526094432*Zeta[3]) - 18*x^20*(1292357633 + 
              1629100960*Zeta[3]) - 118098*x^4*(-71567279447 + 
              3828593760*Zeta[3]) + 29160*x^5*(-324076931161 + 
              20616050016*Zeta[3]) + 54*x^17*(-150275435207 + 
              48075595200*Zeta[3]) - 192*x^13*(81657330119 + 
              121967836200*Zeta[3]) - 1458*x^6*(-3634516174841 + 
              129516871680*Zeta[3]) + 1296*x^11*(-552930619123 + 
              207183828600*Zeta[3]) - 972*x^7*(283660807369 + 
              561433446720*Zeta[3]) + x^18*(-985180325267 + 672726931200*Zeta[
                3]) - 81*x^10*(4998369064727 + 1963081939200*Zeta[3]) + 
            243*x^8*(-13450499534279 + 3487693060800*Zeta[3]) + 
            12*x^14*(-11604967223311 + 3537360115200*Zeta[3]) - 
            54*x^9*(-51480825262123 + 8935288459200*Zeta[3]))/
           (3499200*(-9 + x^2)^6*(-1 + x^2)^11)) + 
        NM*(-((34200 + 123120*x - 1909980*x^2 - 20366388*x^3 + 
              79738677*x^4 + 985943070*x^5 - 2770962178*x^6 - 
              17152990218*x^7 + 52320700980*x^8 + 65742495570*x^9 - 
              425658009506*x^10 + 1286336800710*x^11 + 23076510121*x^12 - 
              13925084929668*x^13 + 19759294210236*x^14 + 22264496035596*x^
                15 - 79136866926376*x^16 + 199400085648612*x^17 - 
              136002545806320*x^18 - 375735040810200*x^19 + 731268123570279*x^
                20 - 1365671521473210*x^21 + 1047691314795366*x^22 - 
              788303526012450*x^23 + 373699946404764*x^24 - 122278700172294*x^
                25 + 47684164802382*x^26 - 2321372669850*x^27 - 
              5361921120645*x^28 + 120*Pi^2*(1 - 9*x^2)^6*(-1 + x^2)^4*(5 + 
                18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
                18*x^7 + 5*x^8))*HPL[{0}, x])/(583200*(1 - 9*x^2)^6*
            (-1 + x^2)^11) + lm^2*((5 + 18*x - 115*x^2 + 1068*x^3 - 
              1990*x^4 + 2868*x^5 - 1990*x^6 + 1068*x^7 - 115*x^8 + 18*x^9 + 
              5*x^10)/(720*(-1 + x^2)^8) - (x^3*(6 - 15*x + 36*x^2 - 40*x^3 + 
               36*x^4 - 15*x^5 + 6*x^6)*HPL[{0}, x])/(6*(-1 + x^2)^9)) + 
          ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
             18*x^7 + 5*x^8)*HPL[{-2, 0}, x])/(405*(-1 + x^2)^7) - 
          ((-600 - 2160*x + 30440*x^2 + 469104*x^3 - 1490311*x^4 - 
             19503306*x^5 + 50698138*x^6 + 188045422*x^7 - 676920218*x^8 + 
             2890086878*x^9 - 1281308730*x^10 - 66784251330*x^11 + 
             113278125491*x^12 + 343625949852*x^13 - 921580615004*x^14 + 
             994200938988*x^15 + 1072098930636*x^16 - 11617064162388*x^17 + 
             14086047257172*x^18 + 5582375380908*x^19 - 29866503937905*x^20 + 
             77596738495470*x^21 - 67784647663134*x^22 + 58596227641638*
              x^23 - 30189092938938*x^24 + 11280962934054*x^25 - 
             3715280162082*x^26 + 135424748070*x^27 + 413000811045*x^28)*
            HPL[{0, 0}, x])/(16200*(1 - 9*x^2)^6*(-1 + x^2)^11) + 
          lm*((1252 + 2259*x - 18795*x^2 + 227844*x^3 - 418525*x^4 + 
              610722*x^5 - 418525*x^6 + 227844*x^7 - 18795*x^8 + 2259*x^9 + 
              1252*x^10 + 6*Pi^2*(-5 - 18*x + 47*x^2 - 144*x^3 + 144*x^4 - 
                144*x^6 + 144*x^7 - 47*x^8 + 18*x^9 + 5*x^10))/
             (58320*(-1 + x^2)^8) - (x^2*(10 + 7716*x - 18450*x^2 + 53154*
                x^3 - 64374*x^4 + 69354*x^5 - 35325*x^6 + 17166*x^7 - 1070*
                x^8 + 162*x^9 + 45*x^10)*HPL[{0}, x])/(1620*(-1 + x^2)^9) - 
            ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 18*
                x^7 + 5*x^8)*HPL[{-1, 0}, x])/(810*(-1 + x^2)^7) + 
            (x^3*(1080 - 2700*x + 13500*x^2 - 22000*x^3 + 39600*x^4 - 35115*
                x^5 + 29430*x^6 - 10845*x^7 + 4428*x^8 - 57*x^9 + 18*x^10 + 5*
                x^11)*HPL[{0, 0}, x])/(405*(-1 + x^2)^10) + 
            ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 18*
                x^7 + 5*x^8)*HPL[{1, 0}, x])/(810*(-1 + x^2)^7)) - 
          ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
             18*x^7 + 5*x^8)*HPL[{2, 0}, x])/(405*(-1 + x^2)^7) + 
          ((-15 - 24*x + 234*x^2 - 5568*x^3 + 18681*x^4 - 62429*x^5 + 
             101052*x^6 - 151045*x^7 + 134123*x^8 - 106161*x^9 + 40234*x^10 - 
             17913*x^11 + 111*x^12)*HPL[{-1, 0, 0}, x])/(405*(-1 + x)^10*
            (1 + x)^8) + ((-25 - 90*x + 860*x^2 + 25830*x^3 - 66285*x^4 - 
             550932*x^5 + 1764478*x^6 - 8934744*x^7 + 5517619*x^8 + 
             323693382*x^9 - 717497010*x^10 - 1274984166*x^11 + 
             7740626643*x^12 - 38243195232*x^13 + 9263597588*x^14 + 
             460682257848*x^15 - 604100128499*x^16 - 1441668696822*x^17 + 
             3172989323808*x^18 - 2517882556878*x^19 - 1918447031655*x^20 + 
             12940165353204*x^21 - 13965095530962*x^22 + 13781042850528*
              x^23 - 7569751754727*x^24 + 3298714801290*x^25 - 
             968388129162*x^26 + 127233943182*x^27 + 80644459329*x^28)*
            HPL[{0, 0, 0}, x])/(2025*(1 - 9*x^2)^6*(-1 + x^2)^11) + 
          ((15 + 84*x - 18*x^2 + 4044*x^3 - 4293*x^4 + 32515*x^5 - 
             55152*x^6 + 119651*x^7 - 111131*x^8 + 102747*x^9 - 37510*x^10 + 
             17739*x^11 - 651*x^12)*HPL[{1, 0, 0}, x])/(405*(-1 + x)^8*
            (1 + x)^10) - ((100 + 360*x - 5715*x^2 - 68586*x^3 + 253794*x^4 + 
             3395934*x^5 - 9121212*x^6 - 62262702*x^7 + 179560058*x^8 + 
             319566786*x^9 - 1630102991*x^10 + 3731682636*x^11 + 
             2694972964*x^12 - 53725907556*x^13 + 59130578752*x^14 + 
             187357719636*x^15 - 367841920248*x^16 + 216325246428*x^17 + 
             316183850703*x^18 - 1489686736194*x^19 + 1485398018394*x^20 - 
             1382421504474*x^21 + 720235861884*x^22 - 279494549190*x^23 + 
             84936462138*x^24 - 3302794278*x^25 - 9188424621*x^26)*
            master3l8b[x])/(48600*x^2*(1 - 9*x^2)^6*(-1 + x^2)^11) + 
          ((50 + 180*x - 2145*x^2 - 31866*x^3 + 75309*x^4 + 1476912*x^5 - 
             2754519*x^6 - 22715658*x^7 + 48494685*x^8 + 73961736*x^9 - 
             322353850*x^10 + 1031544924*x^11 + 2971746*x^12 - 
             7116793344*x^13 + 4767198338*x^14 - 160595028*x^15 + 
             16452532476*x^16 + 8519273892*x^17 - 65417276565*x^18 + 
             260556377886*x^19 - 364361592735*x^20 + 358316333424*x^21 - 
             164710724859*x^22 + 79040219742*x^23 + 1020936069*x^24)*
            master3l9b[x])/(48600*x^2*(-1 + x^2)^11*(-1 + 9*x^2)^5) + 
          (-6750 - 24300*x + x^6*(1120601558 - 25721280*Zeta[3]) + 
            x^3*(5474730 - 51840*Zeta[3]) + x^2*(502165 - 14400*Zeta[3]) + 
            96*x^5*(-3005897 + 10260*Zeta[3]) + 15*x^4*(-1953437 + 
              63744*Zeta[3]) - 4251528*x^30*(1249189 + 738360*Zeta[3]) + 
            216*x^7*(29427893 + 1422240*Zeta[3]) + 2125764*x^29*
             (-6861199 + 5387040*Zeta[3]) - 177147*x^28*(-428265143 + 
              28465920*Zeta[3]) - 4*x^8*(6126486341 + 64074240*Zeta[3]) - 
            2099520*x^25*(350303065 + 286334028*Zeta[3]) + 
            489888*x^24*(3310633339 + 385466880*Zeta[3]) - 
            24*x^9*(2033444809 + 619892640*Zeta[3]) - 196830*x^27*
             (294906583 + 1017396288*Zeta[3]) + 9*x^10*(30885992431 + 
              3258201920*Zeta[3]) + 768*x^15*(-104922689789 + 
              11936310750*Zeta[3]) - 108*x^13*(-107480418871 + 
              24037797600*Zeta[3]) + 6*x^11*(-74704672697 + 47274868800*Zeta[
                3]) + 6561*x^26*(33454293169 + 68914687680*Zeta[3]) + 
            1944*x^23*(-1681139904133 + 280716723360*Zeta[3]) - 
            x^12*(917285980813 + 672726931200*Zeta[3]) - 
            162*x^19*(-5095218485759 + 1657470628800*Zeta[3]) - 
            486*x^22*(-6086468610697 + 1743846530400*Zeta[3]) + 
            4*x^14*(-3324451085177 + 1870587586800*Zeta[3]) + 
            12*x^17*(10296111283499 + 1951485379200*Zeta[3]) + 
            81*x^20*(-1641821404093 + 1963081939200*Zeta[3]) + 
            216*x^21*(-9708732657937 + 2233822114800*Zeta[3]) - 
            6*x^16*(-26361138819827 + 7074720230400*Zeta[3]) + 
            x^18*(-552860529620653 + 91306377691200*Zeta[3]))/
           (3499200*x^2*(1 - 9*x^2)^6*(-1 + x^2)^11))) + 
      CA*CF*((Pi^2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 
           4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{-2}, x])/
         (1620*(-1 + x^2)^8) + lm^2*((-11*(5 + 18*x - 115*x^2 + 1068*x^3 - 
             1990*x^4 + 2868*x^5 - 1990*x^6 + 1068*x^7 - 115*x^8 + 18*x^9 + 
             5*x^10))/(1440*(-1 + x^2)^8) + 
          (11*x^3*(6 - 15*x + 36*x^2 - 40*x^3 + 36*x^4 - 15*x^5 + 6*x^6)*
            HPL[{0}, x])/(12*(-1 + x^2)^9)) - 
        (Pi^2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 
           4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{2}, x])/
         (1620*(-1 + x^2)^8) + (x*(-3725 + 23139*x - 108750*x^2 + 
           121566*x^3 - 1354365*x^4 + 1933295*x^5 - 2375400*x^6 + 
           1120945*x^7 - 2439075*x^8 + 1626432*x^9 + 1734126*x^10 - 
           2235843*x^11 - 1962739*x^12 + 2443138*x^13 + 1365120*x^14 - 
           1895490*x^15 - 548550*x^16 + 1026110*x^17 + 61180*x^18 - 
           368778*x^19 + 50598*x^20 + 79194*x^21 - 24312*x^22 - 7700*x^23 + 
           3500*x^24)*HPL[{-2, 0}, x])/(16200*(-1 + x^2)^10) + 
        ((-210000 + 462000*x + 1143720*x^2 - 4058640*x^3 - 1232800*x^4 + 
           15846220*x^5 - 5987800*x^6 - 36125420*x^7 + 24400520*x^8 + 
           (53380277 + 6000*Pi^2)*x^9 + (-39625658 + 21600*Pi^2)*x^10 - 
           16*(3703013 + 25800*Pi^2)*x^11 + (80551594 + 2498400*Pi^2)*x^12 - 
           3*(4823907 + 1578800*Pi^2)*x^13 + 8*(13629023 + 561600*Pi^2)*
            x^14 - 143529496*x^15 - 8*(-13629023 + 561600*Pi^2)*x^16 + 
           3*(-4823907 + 1578800*Pi^2)*x^17 + (80551594 - 2498400*Pi^2)*
            x^18 + 16*(-3703013 + 25800*Pi^2)*x^19 - 
           2*(19812829 + 10800*Pi^2)*x^20 + (53380277 - 6000*Pi^2)*x^21 + 
           24400520*x^22 - 36125420*x^23 - 5987800*x^24 + 15846220*x^25 - 
           1232800*x^26 - 4058640*x^27 + 1143720*x^28 + 462000*x^29 - 
           210000*x^30)*HPL[{-1, 0}, x])/(1944000*x^9*(-1 + x^2)^9) + 
        (x*(-712662381000 + 3956974030764*x - 7441803358740*x^2 - 
           74978240432409*x^3 + 1069615070003430*x^4 - 2252822389937109*x^5 - 
           16148408968378080*x^6 + 83142560858018796*x^7 - 
           29646916839335880*x^8 - 947448273849927660*x^9 + 
           2461728699767971296*x^10 + 3914968062653209728*x^11 - 
           18429893343453579552*x^12 + 2010863366346560880*x^13 + 
           15530301781121260608*x^14 - 8341332254024339316*x^15 + 
           277952439091879365816*x^16 - 418951887767902661612*x^17 - 
           503557935825975608120*x^18 + 1485786255853362502470*x^19 - 
           1483944415806824872308*x^20 + 312960076497259660094*x^21 + 
           330562083336445168416*x^22 - 362431173100935023308*x^23 + 
           224398352773041054296*x^24 - 18113855669686471820*x^25 - 
           131532763248651323088*x^26 + 92597292478366882968*x^27 + 
           36166445215319808960*x^28 - 54173333977664360600*x^29 - 
           4997561820508164064*x^30 + 20630504708276062020*x^31 - 
           1139612427104348112*x^32 - 5693723774463709392*x^33 + 
           936122543850678828*x^34 + 1128661104929225787*x^35 - 
           281032709074371234*x^36 - 156792971527415649*x^37 + 
           49196954861035200*x^38 + 14785830641131920*x^39 - 
           5370659412726960*x^40 - 898221102368760*x^41 + 
           360453864134160*x^42 + 31649054676480*x^43 - 13640729981040*x^44 - 
           491051484000*x^45 + 223205220000*x^46)*HPL[{0, 0}, x])/
         (1944000*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        ((210000 - 462000*x - 1143720*x^2 + 4058640*x^3 + 1232800*x^4 - 
           15846220*x^5 + 5987800*x^6 + 36125420*x^7 - 24400520*x^8 - 
           (53380277 + 6000*Pi^2)*x^9 + (39625658 - 21600*Pi^2)*x^10 + 
           16*(3703013 + 25800*Pi^2)*x^11 - 2*(40275797 + 1249200*Pi^2)*
            x^12 + 3*(4823907 + 1578800*Pi^2)*x^13 - 
           8*(13629023 + 561600*Pi^2)*x^14 + 143529496*x^15 + 
           8*(-13629023 + 561600*Pi^2)*x^16 + (14471721 - 4736400*Pi^2)*
            x^17 + (-80551594 + 2498400*Pi^2)*x^18 + (59248208 - 412800*Pi^2)*
            x^19 + (39625658 + 21600*Pi^2)*x^20 + (-53380277 + 6000*Pi^2)*
            x^21 - 24400520*x^22 + 36125420*x^23 + 5987800*x^24 - 
           15846220*x^25 + 1232800*x^26 + 4058640*x^27 - 1143720*x^28 - 
           462000*x^29 + 210000*x^30)*HPL[{1, 0}, x])/
         (1944000*x^9*(-1 + x^2)^9) + 
        lm*(-(19442 + 45261*x - 337155*x^2 + 3717396*x^3 - 6860435*x^4 + 
             9970254*x^5 - 6860435*x^6 + 3717396*x^7 - 337155*x^8 + 
             45261*x^9 + 19442*x^10 + 66*Pi^2*(-5 - 18*x + 47*x^2 - 144*x^3 + 
               144*x^4 - 144*x^6 + 144*x^7 - 47*x^8 + 18*x^9 + 5*x^10))/
           (116640*(-1 + x^2)^8) + (x^2*(110 + 107556*x - 259650*x^2 + 
             720774*x^3 - 859314*x^4 + 898974*x^5 - 445275*x^6 + 211506*x^7 - 
             11770*x^8 + 1782*x^9 + 495*x^10)*HPL[{0}, x])/
           (3240*(-1 + x^2)^9) + (11*(5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 
             162*x^5 - 42*x^6 + 18*x^7 + 5*x^8)*HPL[{-1, 0}, x])/
           (1620*(-1 + x^2)^7) - (11*x^3*(1080 - 2700*x + 13500*x^2 - 
             22000*x^3 + 39600*x^4 - 35115*x^5 + 29430*x^6 - 10845*x^7 + 
             4428*x^8 - 57*x^9 + 18*x^10 + 5*x^11)*HPL[{0, 0}, x])/
           (810*(-1 + x^2)^10) - (11*(5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 
             162*x^5 - 42*x^6 + 18*x^7 + 5*x^8)*HPL[{1, 0}, x])/
           (1620*(-1 + x^2)^7)) - (x*(-3725 + 23139*x - 108750*x^2 + 
           121566*x^3 - 1354365*x^4 + 1933295*x^5 - 2375400*x^6 + 
           1120945*x^7 - 2439075*x^8 + 1626432*x^9 + 1734126*x^10 - 
           2235843*x^11 - 1962739*x^12 + 2443138*x^13 + 1365120*x^14 - 
           1895490*x^15 - 548550*x^16 + 1026110*x^17 + 61180*x^18 - 
           368778*x^19 + 50598*x^20 + 79194*x^21 - 24312*x^22 - 7700*x^23 + 
           3500*x^24)*HPL[{2, 0}, x])/(16200*(-1 + x^2)^10) - 
        ((5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{-2, -1, 0}, x])/
         (135*(-1 + x^2)^8) + (4*x^2*(-146 + 978*x - 2071*x^2 + 2922*x^3 - 
           2215*x^4 + 1122*x^5 - 193*x^6 + 18*x^7 + 5*x^8)*
          HPL[{-2, 0, 0}, x])/(135*(-1 + x^2)^8) + 
        ((5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{-2, 1, 0}, x])/
         (135*(-1 + x^2)^8) + ((5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 
           5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*
          HPL[{-1, -2, 0}, x])/(135*(-1 + x^2)^8) + 
        ((-1750 + 3850*x + 6906*x^2 - 28047*x^3 + 669*x^4 + 88698*x^5 - 
           51051*x^6 - 158970*x^7 + 126021*x^8 + 176694*x^9 - 150675*x^10 - 
           126429*x^11 + 96388*x^12 + 67422*x^13 - 66108*x^14 + 10764*x^15 - 
           66108*x^16 + 67422*x^17 + 96388*x^18 - 126429*x^19 - 150675*x^20 + 
           176694*x^21 + 126021*x^22 - 158970*x^23 - 51051*x^24 + 
           88698*x^25 + 669*x^26 - 28047*x^27 + 6906*x^28 + 3850*x^29 - 
           1750*x^30)*HPL[{-1, -1, 0}, x])/(16200*x^11*(-1 + x^2)^7) + 
        ((-2707 + 24267*x - 139006*x^2 + 657723*x^3 - 1643743*x^4 + 
           2874538*x^5 - 3196590*x^6 + 2828678*x^7 - 2000548*x^8 + 
           904538*x^9 + 481552*x^10 - 554106*x^11 - 589740*x^12 + 
           770952*x^13 + 266148*x^14 - 620688*x^15 + 27483*x^16 + 
           291447*x^17 - 97322*x^18 - 66213*x^19 + 45359*x^20 + 794*x^21 - 
           7350*x^22 + 1750*x^23)*HPL[{-1, 0, 0}, x])/(8100*(-1 + x)^10*
          (1 + x)^8) - ((-1750 + 3850*x + 6906*x^2 - 28047*x^3 + 669*x^4 + 
           88698*x^5 - 51051*x^6 - 158970*x^7 + 126021*x^8 + 176694*x^9 - 
           150675*x^10 - 126429*x^11 + 96388*x^12 + 67422*x^13 - 66108*x^14 + 
           10764*x^15 - 66108*x^16 + 67422*x^17 + 96388*x^18 - 126429*x^19 - 
           150675*x^20 + 176694*x^21 + 126021*x^22 - 158970*x^23 - 
           51051*x^24 + 88698*x^25 + 669*x^26 - 28047*x^27 + 6906*x^28 + 
           3850*x^29 - 1750*x^30)*HPL[{-1, 1, 0}, x])/
         (16200*x^11*(-1 + x^2)^7) - ((5 + 18*x - 339*x^2 + 2100*x^3 - 
           4286*x^4 + 5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 
           5*x^10)*HPL[{-1, 2, 0}, x])/(135*(-1 + x^2)^8) + 
        (x*(9898088625 - 59890743495*x + 1297235999250*x^2 - 
           2155045438278*x^3 - 61504222952880*x^4 + 185664692541240*x^5 + 
           792905666049180*x^6 - 3936320730622602*x^7 + 421093876451130*x^8 + 
           35497646722053000*x^9 - 84218410255668000*x^10 - 
           115599630976536270*x^11 + 534377308564434490*x^12 - 
           34587127993123744*x^13 + 531939487922062660*x^14 - 
           2057953161295055670*x^15 - 12070950233975632480*x^16 + 
           27271180626578075854*x^17 + 5726637390365717860*x^18 - 
           66962102749388983070*x^19 + 104234025981717915670*x^20 - 
           43863003239111897060*x^21 - 41380611719120788060*x^22 + 
           50755055913175439246*x^23 + 10101728158597814170*x^24 - 
           28844977391690676700*x^25 - 8987753277263943480*x^26 + 
           18096338936700368514*x^27 + 6171992360730901530*x^28 - 
           11014452732588507740*x^29 - 2278162030964476660*x^30 + 
           5328029609647849110*x^31 + 309931551246409335*x^32 - 
           1938942282260103663*x^33 + 133248699756656490*x^34 + 
           519711394351625420*x^35 - 89305412187539150*x^36 - 
           100468846472608692*x^37 + 25429590295696800*x^38 + 
           13675955332010580*x^39 - 4321067434916580*x^40 - 
           1269360352630980*x^41 + 462479909792760*x^42 + 
           76167059062500*x^43 - 30604635724140*x^44 - 2657881701540*x^45 + 
           1146027715920*x^46 + 40920957000*x^47 - 18600435000*x^48)*
          HPL[{0, 0, 0}, x])/(81000*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) - 
        ((5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{1, -2, 0}, x])/
         (135*(-1 + x^2)^8) - ((-1750 + 3850*x + 6906*x^2 - 28047*x^3 + 
           669*x^4 + 88698*x^5 - 51051*x^6 - 158970*x^7 + 126021*x^8 + 
           176694*x^9 - 150675*x^10 - 126429*x^11 + 96388*x^12 + 67422*x^13 - 
           66108*x^14 + 10764*x^15 - 66108*x^16 + 67422*x^17 + 96388*x^18 - 
           126429*x^19 - 150675*x^20 + 176694*x^21 + 126021*x^22 - 
           158970*x^23 - 51051*x^24 + 88698*x^25 + 669*x^26 - 28047*x^27 + 
           6906*x^28 + 3850*x^29 - 1750*x^30)*HPL[{1, -1, 0}, x])/
         (16200*x^11*(-1 + x^2)^7) + ((2707 - 14639*x + 56874*x^2 - 
           345831*x^3 + 297167*x^4 - 311730*x^5 + 124806*x^6 - 619222*x^7 + 
           130708*x^8 + 141398*x^9 + 440408*x^10 - 644358*x^11 - 
           517044*x^12 + 571704*x^13 + 442140*x^14 - 369984*x^15 - 
           234363*x^16 + 175533*x^17 + 72374*x^18 - 61375*x^19 - 10735*x^20 + 
           14606*x^21 + 350*x^22 - 1750*x^23)*HPL[{1, 0, 0}, x])/
         (8100*(-1 + x)^8*(1 + x)^10) + 
        ((-1750 + 3850*x + 6906*x^2 - 28047*x^3 + 669*x^4 + 88698*x^5 - 
           51051*x^6 - 158970*x^7 + 126021*x^8 + 176694*x^9 - 150675*x^10 - 
           126429*x^11 + 96388*x^12 + 67422*x^13 - 66108*x^14 + 10764*x^15 - 
           66108*x^16 + 67422*x^17 + 96388*x^18 - 126429*x^19 - 150675*x^20 + 
           176694*x^21 + 126021*x^22 - 158970*x^23 - 51051*x^24 + 
           88698*x^25 + 669*x^26 - 28047*x^27 + 6906*x^28 + 3850*x^29 - 
           1750*x^30)*HPL[{1, 1, 0}, x])/(16200*x^11*(-1 + x^2)^7) + 
        ((5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{1, 2, 0}, x])/
         (135*(-1 + x^2)^8) + ((5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 
           5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*
          HPL[{2, -1, 0}, x])/(135*(-1 + x^2)^8) - 
        (4*x^2*(-146 + 978*x - 2071*x^2 + 2922*x^3 - 2215*x^4 + 1122*x^5 - 
           193*x^6 + 18*x^7 + 5*x^8)*HPL[{2, 0, 0}, x])/(135*(-1 + x^2)^8) - 
        ((5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{2, 1, 0}, x])/
         (135*(-1 + x^2)^8) - (2*(5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 
           162*x^5 - 42*x^6 + 18*x^7 + 5*x^8)*HPL[{-1, 0, 0, 0}, x])/
         (135*(-1 + x^2)^7) + (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 
           5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*
          HPL[{-1, 1, 0, 0}, x])/(135*(-1 + x^2)^8) + 
        (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{1, -1, 0, 0}, x])/
         (135*(-1 + x^2)^8) + (2*(5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 
           162*x^5 - 42*x^6 + 18*x^7 + 5*x^8)*HPL[{1, 0, 0, 0}, x])/
         (135*(-1 + x^2)^7) - ((5 + 40*x - 259*x^2 + 2838*x^3 - 5923*x^4 + 
           11104*x^5 - 9852*x^6 + 7360*x^7 - 1976*x^8 + 756*x^9 + 85*x^10 + 
           22*x^11)*master3l10a[x])/(1080*(-1 + x^2)^9) + 
        (x*(22 + 85*x + 756*x^2 - 1976*x^3 + 7360*x^4 - 9852*x^5 + 
           11104*x^6 - 5923*x^7 + 2838*x^8 - 259*x^9 + 40*x^10 + 5*x^11)*
          master3l10b[x])/(1080*(-1 + x^2)^9) + 
        ((-10976238072 + 124671826755*x - 2006610448095*x^2 + 
           5321363131530*x^3 - 5396289697584*x^4 + 2903131955115*x^5 + 
           2106400096719*x^6 - 1106003137320*x^7 - 725142880944*x^8 + 
           4788470790*x^9 + 421510114314*x^10 - 57475594020*x^11 - 
           135959798880*x^12 + 41609898030*x^13 + 22164880126*x^14 - 
           9218534760*x^15 - 1857169176*x^16 + 967823255*x^17 + 
           68215941*x^18 - 50001110*x^19 + 5456*x^20 + 1026375*x^21 - 
           46205*x^22)*master3l8a[x])/(1944000*(-9 + x^2)^6*(-1 + x^2)^10) + 
        ((74500 - 410575*x - 3897575*x^2 + 24733044*x^3 + 85548810*x^4 - 
           623485525*x^5 - 1120075015*x^6 + 8734263288*x^7 + 
           11185290480*x^8 - 77307121862*x^9 - 91730176750*x^10 + 
           477249952568*x^11 + 486783823020*x^12 - 2157025911834*x^13 - 
           794233538790*x^14 + 6212306154240*x^15 - 4454173859940*x^16 - 
           5379481848987*x^17 + 15124703422005*x^18 - 13441544301132*x^19 + 
           7526268401850*x^20 - 1299862807137*x^21 + 298982440845*x^22 + 
           1410300072*x^23)*master3l8b[x])/(1944000*x*(1 - 9*x^2)^6*
          (-1 + x^2)^10) + ((688141008 + 9683923005*x + 39340217943*x^2 + 
           123570728685*x^3 - 442587453759*x^4 + 692706273570*x^5 - 
           465058714068*x^6 - 109042120860*x^7 + 333740644836*x^8 - 
           56505902850*x^9 - 106169707582*x^10 + 23958200630*x^11 + 
           22270574238*x^12 - 4745759640*x^13 - 3051714084*x^14 + 
           606239220*x^15 + 249333572*x^16 - 48634435*x^17 - 10724129*x^18 + 
           2126725*x^19 + 182185*x^20 - 37250*x^21)*master3l9a[x])/
         (648000*(-9 + x^2)^5*(-1 + x^2)^10) + 
        ((-37250 + 182185*x + 2126725*x^2 - 10724129*x^3 - 48634435*x^4 + 
           249333572*x^5 + 606239220*x^6 - 3051714084*x^7 - 4745759640*x^8 + 
           22270574238*x^9 + 23958200630*x^10 - 106169707582*x^11 - 
           56505902850*x^12 + 333740644836*x^13 - 109042120860*x^14 - 
           465058714068*x^15 + 692706273570*x^16 - 442587453759*x^17 + 
           123570728685*x^18 + 39340217943*x^19 + 9683923005*x^20 + 
           688141008*x^21)*master3l9b[x])/(1944000*x*(-1 + x^2)^10*
          (-1 + 9*x^2)^5) + (HPL[{1}, x]*(Pi^2*(1750 - 3850*x - 8656*x^2 + 
             31897*x^3 + 6237*x^4 - 116745*x^5 + 51720*x^6 + 247668*x^7 - 
             177072*x^8 - 335664*x^9 + 276696*x^10 + 303123*x^11 - 
             247063*x^12 - 193851*x^13 + 162496*x^14 + 56658*x^15 - 
             56658*x^17 - 162496*x^18 + 193851*x^19 + 247063*x^20 - 
             303123*x^21 - 276696*x^22 + 335664*x^23 + 177072*x^24 - 
             247668*x^25 - 51720*x^26 + 116745*x^27 - 6237*x^28 - 
             31897*x^29 + 8656*x^30 + 3850*x^31 - 1750*x^32) - 
           1440*x^11*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 
             4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*Zeta[3]))/
         (194400*x^11*(-1 + x^2)^8) + 
        (HPL[{-1}, x]*(Pi^2*(-1750 + 3850*x + 8656*x^2 - 31897*x^3 - 
             6237*x^4 + 116745*x^5 - 51720*x^6 - 247668*x^7 + 177072*x^8 + 
             335664*x^9 - 276696*x^10 - 303123*x^11 + 247063*x^12 + 
             193851*x^13 - 162496*x^14 - 56658*x^15 + 56658*x^17 + 
             162496*x^18 - 193851*x^19 - 247063*x^20 + 303123*x^21 + 
             276696*x^22 - 335664*x^23 - 177072*x^24 + 247668*x^25 + 
             51720*x^26 - 116745*x^27 + 6237*x^28 + 31897*x^29 - 8656*x^30 - 
             3850*x^31 + 1750*x^32) + 1440*x^11*(5 + 18*x - 339*x^2 + 
             2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 
             18*x^9 + 5*x^10)*Zeta[3]))/(194400*x^11*(-1 + x^2)^8) + 
        (HPL[{0}, x]*(669615660000 - 1473154452000*x - 40587382113120*x^2 + 
           94210586803440*x^3 + 1061123702650920*x^4 - 2647680776575560*x^5 - 
           15584770768045680*x^6 + 43041441035906100*x^7 + 
           43740*(3198417313421 + 5431050*Pi^2)*x^8 - 
           87480*(5134337958280 + 16868331*Pi^2)*x^9 + 
           3600*(463058813042500839 + 997226195344738*Pi^2)*x^26 + 
           15*(29863289504086767 + 415780077216255592*Pi^2)*x^43 - 
           30*(4657484649737223 + 35723171383643948*Pi^2)*x^44 - 
           23895*(1801020218229 + 50455191276448*Pi^2)*x^45 + 
           6480*(2405057217291 + 47091833880920*Pi^2)*x^46 + 
           29160*(90798380541 + 5627965157206*Pi^2)*x^47 - 
           29160*(36389701737 + 1778217051406*Pi^2)*x^48 - 
           174960*(538469289 + 87061752581*Pi^2)*x^49 + 
           349920*(115990461 + 15860079211*Pi^2)*x^50 + 
           826686000*(1782 + 1105625*Pi^2)*x^51 - 
           4723920*(141750 + 77743829*Pi^2)*x^52 - 31894580418480*Pi^2*x^53 + 
           13752332591040*Pi^2*x^54 + 491051484000*Pi^2*x^55 - 
           223205220000*Pi^2*x^56 + 6*x^27*(-1048056971474601282491 + 
             9487597082259059380*Pi^2 - 30659695598763360000*Zeta[3]) + 
           48*x^24*(-55697086943724823939 + 410453952711366960*Pi^2 - 
             3081056039662968000*Zeta[3]) - 72*x^22*(-9337984586371086483 + 
             239956006754125180*Pi^2 - 861742699121952000*Zeta[3]) + 
           16*x^20*(-3765081621784830289 + 280183473400725240*Pi^2 - 
             350131120295400000*Zeta[3]) - 30*x^29*(95917810167524797435 + 
             4789117039005421836*Pi^2 - 344374141566816000*Zeta[3]) + 
           120*x^23*(7013171568453539011 + 338948800751186745*Pi^2 - 
             86093535391704000*Zeta[3]) - 24*x^34*(-10129235668023859601 + 
             6279258314732247000*Pi^2 - 65362857312672000*Zeta[3]) + 
           120*x^36*(-335526103623763831 + 675230772385701630*Pi^2 - 
             3780852672528000*Zeta[3]) + 72*x^14*(-45155504598830903 + 
             6233862003300*Pi^2 - 673493053536000*Zeta[3]) + 
           36*x^40*(-70773343724506751 + 103518811983074130*Pi^2 - 
             68415588576000*Zeta[3]) - 972*x^10*(798024983479657 + 
             6225295500*Pi^2 + 51018336000*Zeta[3]) + 
           243*x^11*(13045283946972499 + 300064973040*Pi^2 + 
             510183360000*Zeta[3]) - 144*x^41*(21705163869536568 + 
             161621495221164595*Pi^2 + 860934420000*Zeta[3]) + 
           180*x^39*(83743102311565501 + 355655252365696682*Pi^2 + 
             36503619408000*Zeta[3]) + 18*x^12*(137792302678704427 + 
             248111432100*Pi^2 + 136831177152000*Zeta[3]) - 
           45*x^13*(348479854970716183 + 34350732076536*Pi^2 + 
             146014477632000*Zeta[3]) + 240*x^16*(-16214491752480187 + 
             78663589070220*Pi^2 + 1890426336264000*Zeta[3]) + 
           72*x^15*(789896733075620099 + 273519843905565*Pi^2 + 
             1994625618840000*Zeta[3]) - 12*x^37*(4627257806233011999 + 
             11020005803842772510*Pi^2 + 11967753713040000*Zeta[3]) - 
           24*x^18*(-628546590913353799 + 20753505132332580*Pi^2 + 
             65362857312672000*Zeta[3]) - 24*x^17*(6843462822707662952 + 
             7957039714235235*Pi^2 + 68313119665320000*Zeta[3]) + 
           12*x^35*(17926718205809344219 + 17345230661834856630*Pi^2 + 
             136626239330640000*Zeta[3]) + 60*x^19*(6963241141684867583 + 
             26644081194857142*Pi^2 + 166671661105584000*Zeta[3]) - 
           40*x^33*(24530459759119366570 + 6290196098844199953*Pi^2 + 
             250007491658376000*Zeta[3]) + 8*x^32*(-44053291617943553797 + 
             25053338369399387550*Pi^2 + 700262240590800000*Zeta[3]) - 
           72*x^30*(35573410970487510683 + 2784415213769329300*Pi^2 + 
             861742699121952000*Zeta[3]) + 8*x^31*(388459160930994476156 + 
             28759498363149860745*Pi^2 + 3372409453834440000*Zeta[3]) - 
           4*x^21*(221058031068547327907 + 2570157147174349410*Pi^2 + 
             6744818907668880000*Zeta[3]) + 12*x^28*(681070974804100775581 + 
             10768169674149619800*Pi^2 + 12324224158651872000*Zeta[3]) + 
           36*x^42*(44437717300045180*Pi^2 + 27*(793942701119557 + 
               51018336000*Zeta[3])) + x^38*(-27825515150882377440*Pi^2 + 
             72*(90636966517399103 + 673493053536000*Zeta[3])) - 
           8*x^25*(9655965864044121225*Pi^2 - 4*(70665837652279342753 + 
               5748692924768130000*Zeta[3]))))/(23328000*x^7*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6) + (2880*Pi^4*x^9*(-1 + x^2)^2*
           (9 - 82*x^2 + 9*x^4)^6*(-15 - 54*x - 1319*x^2 + 9348*x^3 - 
            20278*x^4 + 29220*x^5 - 22582*x^6 + 11652*x^7 - 2071*x^8 + 
            234*x^9 + 65*x^10) + 12*Pi^2*(9 - 82*x^2 + 9*x^4)^6*
           (-210000 + 462000*x + 1353720*x^2 - 4520640*x^3 - 2376520*x^4 + 
            19904860*x^5 - 4755000*x^6 - 51971640*x^7 + 30388320*x^8 + 
            89505697*x^9 - 64026178*x^10 - 112628485*x^11 + 120177252*x^12 + 
            44776487*x^13 + 28480590*x^14 - 129057775*x^15 + 129057775*x^17 - 
            28480590*x^18 - 44776487*x^19 - 120177252*x^20 + 112628485*x^21 + 
            64026178*x^22 - 89505697*x^23 - 30388320*x^24 + 51971640*x^25 + 
            4755000*x^26 - 19904860*x^27 + 2376520*x^28 + 4520640*x^29 - 
            1353720*x^30 - 462000*x^31 + 210000*x^32) + 
          x^2*(-2008846980000 + 4419463356000*x + 122431761999360*x^2 - 
            284104914862320*x^3 - 3223707384193380*x^4 + 8036700483610620*
             x^5 + 47805700209615540*x^6 + x^21*(396629109312445729044 - 
              3642741358123290768000*Zeta[3]) + 
            x^25*(5299695982690758580086 - 203691870136406871360*Zeta[3]) + 
            x^17*(657297499894383928356 - 68825945596916142720*Zeta[3]) + 
            1148204895065280*x^53*Zeta[3] - 495083973277440*x^54*Zeta[3] - 
            17677853424000*x^55*Zeta[3] + 8035387920000*x^56*Zeta[3] - 
            14880348000*x^51*(-297 + 2211250*Zeta[3]) + 85030560*x^52*
             (-23625 + 155487658*Zeta[3]) - 19683*x^7*(6694944127141 + 
              329624640*Zeta[3]) - 65610*x^8*(6631736852165 + 
              2634571008*Zeta[3]) - 12597120*x^50*(-9719028 + 
              15860079211*Zeta[3]) + 6561*x^9*(212598522859829 + 
              200421112320*Zeta[3]) + 1574640*x^49*(-180425313 + 
              348247010324*Zeta[3]) + 2916*x^10*(841076084870659 + 
              1001428349760*Zeta[3]) + 131220*x^48*(-24567195429 + 
              14225736411248*Zeta[3]) - 131220*x^47*(-61246002771 + 
              45023721257648*Zeta[3]) - 729*x^11*(13921519034254453 + 
              66824092929600*Zeta[3]) - 29160*x^46*(-1639244006919 + 
              376734671047360*Zeta[3]) + 351*x^13*(152952086884647209 + 
              1872449076591360*Zeta[3]) + 54*x^12*(-140124000289026913 + 
              2338397878559040*Zeta[3]) - 288*x^15*(754426459536345631 + 
              3272552925691500*Zeta[3]) + 729*x^45*(-180757451402937 + 
              59537120270551360*Zeta[3]) - 72*x^14*(16561715200976627 + 
              65583283163718240*Zeta[3]) + 270*x^44*(-1611006743324205 + 
              142892110679806208*Zeta[3]) - 324*x^42*(-7559413276097331 + 
              177743894267740480*Zeta[3]) + 36*x^16*(4288791319770900949 + 
              1773919931769306000*Zeta[3]) - 54*x^40*(137485027890724363 + 
              2481957209858172480*Zeta[3]) - 144*x^18*(6157084010219262461 + 
              2870089207012473480*Zeta[3]) - 27*x^43*(-51576145250541057 + 
              8315560988971176320*Zeta[3]) + 120*x^22*(-8174262467756267447 + 
              9734027512062082752*Zeta[3]) + 81*x^41*(-123642521929082547 + 
              10343264843075790400*Zeta[3]) + 480*x^30*(6930653427065694367 + 
              16370493769946046456*Zeta[3]) + 36*x^38*(-123190505373073579 + 
              27693011222932733760*Zeta[3]) + 144*x^34*
             (-7179863509125408761 + 34709836997213961840*Zeta[3]) - 
            128*x^32*(-15450331459888937297 + 47071071280383346890*Zeta[3]) + 
            12*x^19*(-97688416713496332539 + 65559022013076717600*Zeta[3]) + 
            72*x^37*(-2327822164137410509 + 66126204600170309400*Zeta[3]) + 
            16*x^20*(139175585459491076251 + 66211786706339682540*Zeta[3]) - 
            36*x^36*(-5251912120453814449 + 79235598450228148800*Zeta[3]) - 
            27*x^39*(-1860411008865083627 + 85337701091092162560*Zeta[3]) - 
            36*x^35*(-6463159329470978951 + 210345097735125252720*Zeta[3]) - 
            18*x^27*(-731193378738201052237 + 266132691578486971680*Zeta[
                3]) - 36*x^31*(145206822363629052841 + 341266224132724889200*
               Zeta[3]) + 18*x^23*(-17127282755873258081 + 
              364155823411773979040*Zeta[3]) + 18*x^29*
             (231716365081365358609 + 726795029577560098400*Zeta[3]) + 
            12*x^33*(80078935454395394971 + 825882751960207791120*Zeta[3]) - 
            12*x^24*(57014840645885776729 + 829615969029341540160*Zeta[3]) - 
            12*x^28*(972851760602873164579 + 1167638671629341241120*Zeta[
                3]) + 8*x^26*(-1728302866437534334219 + 
              1450020566367258969600*Zeta[3])))/(279936000*x^9*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6)) + 
      CF^2*(-(Pi^2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 
            4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{-2}, x])/
         (810*(-1 + x^2)^8) + lm^2*((3*(5 + 18*x - 115*x^2 + 1068*x^3 - 
             1990*x^4 + 2868*x^5 - 1990*x^6 + 1068*x^7 - 115*x^8 + 18*x^9 + 
             5*x^10))/(80*(-1 + x^2)^8) - (9*x^3*(6 - 15*x + 36*x^2 - 
             40*x^3 + 36*x^4 - 15*x^5 + 6*x^6)*HPL[{0}, x])/
           (2*(-1 + x^2)^9)) + (Pi^2*(5 + 18*x - 339*x^2 + 2100*x^3 - 
           4286*x^4 + 5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 
           5*x^10)*HPL[{2}, x])/(810*(-1 + x^2)^8) + 
        (x*(3725 - 23139*x + 231630*x^2 - 325326*x^3 + 2109765*x^4 - 
           2839815*x^5 + 2104080*x^6 + 67655*x^7 + 6644615*x^8 - 
           6694772*x^9 - 10646458*x^10 + 12701665*x^11 + 16402899*x^12 - 
           18677612*x^13 - 16601904*x^14 + 19801836*x^15 + 11013486*x^16 - 
           15067284*x^17 - 4200704*x^18 + 8033134*x^19 + 372854*x^20 - 
           2852514*x^21 + 427592*x^22 + 606600*x^23 - 192500*x^24 - 
           58500*x^25 + 27000*x^26)*HPL[{-2, 0}, x])/(8100*(-1 + x^2)^10) + 
        ((-11340000 + 24570000*x + 63840000*x^2 - 217917000*x^3 - 
           79103640*x^4 + 860942880*x^5 - 301381640*x^6 - 1992726960*x^7 + 
           1342696320*x^8 + 2989147140*x^9 - 2483636680*x^10 - 
           (3036226469 + 42000*Pi^2)*x^11 - 70*(-38413039 + 2160*Pi^2)*x^12 + 
           8*(268241509 + 361200*Pi^2)*x^13 - 630*(3376279 + 27760*Pi^2)*
            x^14 + (-593839067 + 33154800*Pi^2)*x^15 - 
           280*(2532529 + 112320*Pi^2)*x^16 + 1878025048*x^17 + 
           280*(-2532529 + 112320*Pi^2)*x^18 - (593839067 + 33154800*Pi^2)*
            x^19 + 630*(-3376279 + 27760*Pi^2)*x^20 - 
           8*(-268241509 + 361200*Pi^2)*x^21 + 70*(38413039 + 2160*Pi^2)*
            x^22 + (-3036226469 + 42000*Pi^2)*x^23 - 2483636680*x^24 + 
           2989147140*x^25 + 1342696320*x^26 - 1992726960*x^27 - 
           301381640*x^28 + 860942880*x^29 - 79103640*x^30 - 217917000*x^31 + 
           63840000*x^32 + 24570000*x^33 - 11340000*x^34)*HPL[{-1, 0}, x])/
         (6804000*x^11*(-1 + x^2)^9) + (x*(4988636667000 - 28855021254948*x + 
           282272560225740*x^2 + 93694510241703*x^3 - 17381668501037610*x^4 + 
           37460932283851083*x^5 + 263274522671326320*x^6 - 
           978577065386296992*x^7 - 472541291310558960*x^8 + 
           9712650953886209280*x^9 - 22414254788197424880*x^10 - 
           31065014400696732708*x^11 + 186789286176476646600*x^12 - 
           98624274277682422284*x^13 - 132067848863252322720*x^14 + 
           404394982343161903080*x^15 - 3393275076419418850800*x^16 + 
           3678314852805211988824*x^17 + 8299139341992032044840*x^18 - 
           15923544136568362480670*x^19 + 7631291948208875779700*x^20 + 
           3519706129969139938178*x^21 + 3554625389931753482240*x^22 - 
           4986696003811609733912*x^23 - 9302715769353421787680*x^24 + 
           9161466056493319388896*x^25 + 7350696054883504169840*x^26 - 
           8800751322971027772996*x^27 - 3936946248789793003240*x^28 + 
           5916071491638378881700*x^29 + 1389713185454564787040*x^30 - 
           2975453294627566766952*x^31 - 204631434482322732360*x^32 + 
           1116920808693789988140*x^33 - 74234159736739496340*x^34 - 
           307412591746252677201*x^35 + 53660135895076252710*x^36 + 
           60715826133731261163*x^37 - 15697542224869853040*x^38 - 
           8404828802878876200*x^39 + 2712099643130802960*x^40 + 
           790365601866576960*x^41 - 293666205573750240*x^42 - 
           47910932321006160*x^43 + 19600844664930480*x^44 + 
           1685355654654000*x^45 - 738809278200000*x^46 - 
           26115010740000*x^47 + 12053081880000*x^48)*HPL[{0, 0}, x])/
         (6804000*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        ((11340000 - 24570000*x - 63840000*x^2 + 217917000*x^3 + 
           79103640*x^4 - 860942880*x^5 + 301381640*x^6 + 1992726960*x^7 - 
           1342696320*x^8 - 2989147140*x^9 + 2483636680*x^10 + 
           (3036226469 + 42000*Pi^2)*x^11 + 70*(-38413039 + 2160*Pi^2)*x^12 - 
           8*(268241509 + 361200*Pi^2)*x^13 + 630*(3376279 + 27760*Pi^2)*
            x^14 + (593839067 - 33154800*Pi^2)*x^15 + 
           280*(2532529 + 112320*Pi^2)*x^16 - 1878025048*x^17 - 
           280*(-2532529 + 112320*Pi^2)*x^18 + (593839067 + 33154800*Pi^2)*
            x^19 - 630*(-3376279 + 27760*Pi^2)*x^20 + 
           8*(-268241509 + 361200*Pi^2)*x^21 - 70*(38413039 + 2160*Pi^2)*
            x^22 + (3036226469 - 42000*Pi^2)*x^23 + 2483636680*x^24 - 
           2989147140*x^25 - 1342696320*x^26 + 1992726960*x^27 + 
           301381640*x^28 - 860942880*x^29 + 79103640*x^30 + 217917000*x^31 - 
           63840000*x^32 - 24570000*x^33 + 11340000*x^34)*HPL[{1, 0}, x])/
         (6804000*x^11*(-1 + x^2)^9) + 
        lm*((1649 + 1440*x - 17925*x^2 + 273060*x^3 - 496760*x^4 + 
            731016*x^5 - 496760*x^6 + 273060*x^7 - 17925*x^8 + 1440*x^9 + 
            1649*x^10 + 12*Pi^2*(-5 - 18*x + 47*x^2 - 144*x^3 + 144*x^4 - 
              144*x^6 + 144*x^7 - 47*x^8 + 18*x^9 + 5*x^10))/
           (4320*(-1 + x^2)^8) - (x^2*(10 + 6006*x - 14175*x^2 + 42894*x^3 - 
             52974*x^4 + 59094*x^5 - 31050*x^6 + 15456*x^7 - 1070*x^8 + 
             162*x^9 + 45*x^10)*HPL[{0}, x])/(60*(-1 + x^2)^9) - 
          ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
             18*x^7 + 5*x^8)*HPL[{-1, 0}, x])/(30*(-1 + x^2)^7) + 
          (x^3*(1080 - 2700*x + 13500*x^2 - 22000*x^3 + 39600*x^4 - 
             35115*x^5 + 29430*x^6 - 10845*x^7 + 4428*x^8 - 57*x^9 + 
             18*x^10 + 5*x^11)*HPL[{0, 0}, x])/(15*(-1 + x^2)^10) + 
          ((5 + 18*x - 42*x^2 + 162*x^3 - 186*x^4 + 162*x^5 - 42*x^6 + 
             18*x^7 + 5*x^8)*HPL[{1, 0}, x])/(30*(-1 + x^2)^7)) - 
        (x*(3725 - 23139*x + 231630*x^2 - 325326*x^3 + 2109765*x^4 - 
           2839815*x^5 + 2104080*x^6 + 67655*x^7 + 6644615*x^8 - 
           6694772*x^9 - 10646458*x^10 + 12701665*x^11 + 16402899*x^12 - 
           18677612*x^13 - 16601904*x^14 + 19801836*x^15 + 11013486*x^16 - 
           15067284*x^17 - 4200704*x^18 + 8033134*x^19 + 372854*x^20 - 
           2852514*x^21 + 427592*x^22 + 606600*x^23 - 192500*x^24 - 
           58500*x^25 + 27000*x^26)*HPL[{2, 0}, x])/(8100*(-1 + x^2)^10) + 
        (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{-2, -1, 0}, x])/
         (135*(-1 + x^2)^8) - (4*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 
           5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*
          HPL[{-2, 0, 0}, x])/(135*(-1 + x^2)^8) - 
        (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{-2, 1, 0}, x])/
         (135*(-1 + x^2)^8) - (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 
           5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*
          HPL[{-1, -2, 0}, x])/(135*(-1 + x^2)^8) + 
        ((-13500 + 29250*x + 28750*x^2 - 157050*x^3 + 64954*x^4 + 
           348507*x^5 - 284157*x^6 - 411032*x^7 + 385027*x^8 + 276662*x^9 - 
           247748*x^10 - 107718*x^11 + 74352*x^12 + 25041*x^13 - 9478*x^14 - 
           5120*x^15 - 9478*x^16 + 25041*x^17 + 74352*x^18 - 107718*x^19 - 
           247748*x^20 + 276662*x^21 + 385027*x^22 - 411032*x^23 - 
           284157*x^24 + 348507*x^25 + 64954*x^26 - 157050*x^27 + 
           28750*x^28 + 29250*x^29 - 13500*x^30)*HPL[{-1, -1, 0}, x])/
         (8100*x^13*(-1 + x^2)^5) + ((2012 - 26605*x + 167170*x^2 - 
           782023*x^3 + 1971953*x^4 - 3325504*x^5 + 3427776*x^6 - 
           3135500*x^7 + 3149630*x^8 - 1132856*x^9 - 3505714*x^10 + 
           2260112*x^11 + 5448474*x^12 - 4975194*x^13 - 4833530*x^14 + 
           6341302*x^15 + 2051844*x^16 - 4938247*x^17 + 291008*x^18 + 
           2255879*x^19 - 786199*x^20 - 497054*x^21 + 354050*x^22 + 
           2750*x^23 - 56250*x^24 + 13500*x^25)*HPL[{-1, 0, 0}, x])/
         (4050*(-1 + x)^10*(1 + x)^8) + 
        ((13500 - 29250*x - 28750*x^2 + 157050*x^3 - 64954*x^4 - 348507*x^5 + 
           284157*x^6 + 411032*x^7 - 385027*x^8 - 276662*x^9 + 247748*x^10 + 
           107718*x^11 - 74352*x^12 - 25041*x^13 + 9478*x^14 + 5120*x^15 + 
           9478*x^16 - 25041*x^17 - 74352*x^18 + 107718*x^19 + 247748*x^20 - 
           276662*x^21 - 385027*x^22 + 411032*x^23 + 284157*x^24 - 
           348507*x^25 - 64954*x^26 + 157050*x^27 - 28750*x^28 - 29250*x^29 + 
           13500*x^30)*HPL[{-1, 1, 0}, x])/(8100*x^13*(-1 + x^2)^5) + 
        (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{-1, 2, 0}, x])/
         (135*(-1 + x^2)^8) + (x*(9898088625 - 63079389495*x - 
           2053087638975*x^2 + 6439468900617*x^3 + 63382829205870*x^4 - 
           175233921354882*x^5 - 495840753844740*x^6 + 1313665039519758*x^7 - 
           5888653595017650*x^8 + 17692018694087202*x^9 + 120126861551584470*
            x^10 - 409722844696620870*x^11 - 539894125536866150*x^12 + 
           3040757419022971406*x^13 - 1804642115269044390*x^14 - 
           8936080493877023666*x^15 + 21234146246658656860*x^16 + 
           1181939029080023204*x^17 - 50131174056256926340*x^18 + 
           26499202059248001376*x^19 + 56956980131278238770*x^20 - 
           14713027303750192350*x^21 - 276973805423305021610*x^22 + 
           227685251454270573646*x^23 + 281965171854770443430*x^24 - 
           325385443774759221386*x^25 - 274547616275866477370*x^26 + 
           345765608177845001074*x^27 + 239331461282819676450*x^28 - 
           311412725386385377254*x^29 - 156421727533675657670*x^30 + 
           226227826098907725430*x^31 + 71520055330780124155*x^32 - 
           128966941460928955333*x^33 - 19770140412923920965*x^34 + 
           56852838325977410223*x^35 + 849794984348147720*x^36 - 
           19082516568176878632*x^37 + 1918449485587651670*x^38 + 
           4785170296520722572*x^39 - 932431486169597220*x^40 - 
           876790589663439720*x^41 + 236752941690308340*x^42 + 
           114407979404439060*x^43 - 37627802030073780*x^44 - 
           10273013616016800*x^45 + 3849700089983940*x^46 + 
           600593417350740*x^47 - 246596198805720*x^48 - 20530097271000*
            x^49 + 9010582155000*x^50 + 310892985000*x^51 - 
           143489070000*x^52)*HPL[{0, 0, 0}, x])/(40500*(-1 + x^2)^11*
          (9 - 82*x^2 + 9*x^4)^6) + (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 
           4286*x^4 + 5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 
           5*x^10)*HPL[{1, -2, 0}, x])/(135*(-1 + x^2)^8) + 
        ((13500 - 29250*x - 28750*x^2 + 157050*x^3 - 64954*x^4 - 348507*x^5 + 
           284157*x^6 + 411032*x^7 - 385027*x^8 - 276662*x^9 + 247748*x^10 + 
           107718*x^11 - 74352*x^12 - 25041*x^13 + 9478*x^14 + 5120*x^15 + 
           9478*x^16 - 25041*x^17 - 74352*x^18 + 107718*x^19 + 247748*x^20 - 
           276662*x^21 - 385027*x^22 + 411032*x^23 + 284157*x^24 - 
           348507*x^25 - 64954*x^26 + 157050*x^27 - 28750*x^28 - 29250*x^29 + 
           13500*x^30)*HPL[{1, -1, 0}, x])/(8100*x^13*(-1 + x^2)^5) + 
        ((-2012 + 19757*x - 70126*x^2 + 384519*x^3 - 314313*x^4 + 
           157596*x^5 - 73392*x^6 + 1171600*x^7 + 156010*x^8 - 1883364*x^9 - 
           1879342*x^10 + 4079092*x^11 + 3578862*x^12 - 5102034*x^13 - 
           4447486*x^14 + 4508014*x^15 + 3562596*x^16 - 2889565*x^17 - 
           1808084*x^18 + 1373749*x^19 + 539015*x^20 - 482146*x^21 - 
           77050*x^22 + 114250*x^23 + 2250*x^24 - 13500*x^25)*
          HPL[{1, 0, 0}, x])/(4050*(-1 + x)^8*(1 + x)^10) + 
        ((-13500 + 29250*x + 28750*x^2 - 157050*x^3 + 64954*x^4 + 
           348507*x^5 - 284157*x^6 - 411032*x^7 + 385027*x^8 + 276662*x^9 - 
           247748*x^10 - 107718*x^11 + 74352*x^12 + 25041*x^13 - 9478*x^14 - 
           5120*x^15 - 9478*x^16 + 25041*x^17 + 74352*x^18 - 107718*x^19 - 
           247748*x^20 + 276662*x^21 + 385027*x^22 - 411032*x^23 - 
           284157*x^24 + 348507*x^25 + 64954*x^26 - 157050*x^27 + 
           28750*x^28 + 29250*x^29 - 13500*x^30)*HPL[{1, 1, 0}, x])/
         (8100*x^13*(-1 + x^2)^5) - (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 
           4286*x^4 + 5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 
           5*x^10)*HPL[{1, 2, 0}, x])/(135*(-1 + x^2)^8) - 
        (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{2, -1, 0}, x])/
         (135*(-1 + x^2)^8) + (4*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 
           5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*
          HPL[{2, 0, 0}, x])/(135*(-1 + x^2)^8) + 
        (2*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{2, 1, 0}, x])/
         (135*(-1 + x^2)^8) - (4*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 
           5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*
          HPL[{-1, 1, 0, 0}, x])/(135*(-1 + x^2)^8) - 
        (4*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 
           2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*HPL[{1, -1, 0, 0}, x])/
         (135*(-1 + x^2)^8) + ((5 + 40*x - 259*x^2 + 2838*x^3 - 5923*x^4 + 
           11104*x^5 - 9852*x^6 + 7360*x^7 - 1976*x^8 + 756*x^9 + 85*x^10 + 
           22*x^11)*master3l10a[x])/(540*(-1 + x^2)^9) - 
        (x*(22 + 85*x + 756*x^2 - 1976*x^3 + 7360*x^4 - 9852*x^5 + 
           11104*x^6 - 5923*x^7 + 2838*x^8 - 259*x^9 + 40*x^10 + 5*x^11)*
          master3l10b[x])/(540*(-1 + x^2)^9) + 
        ((10976238072 - 124671826755*x + 2006610448095*x^2 - 
           5321363131530*x^3 + 5396289697584*x^4 - 2903131955115*x^5 - 
           2106400096719*x^6 + 1106003137320*x^7 + 725142880944*x^8 - 
           4788470790*x^9 - 421510114314*x^10 + 57475594020*x^11 + 
           135959798880*x^12 - 41609898030*x^13 - 22164880126*x^14 + 
           9218534760*x^15 + 1857169176*x^16 - 967823255*x^17 - 
           68215941*x^18 + 50001110*x^19 - 5456*x^20 - 1026375*x^21 + 
           46205*x^22)*master3l8a[x])/(972000*(-9 + x^2)^6*(-1 + x^2)^10) + 
        ((-74500 + 410575*x + 3897575*x^2 - 24733044*x^3 - 85548810*x^4 + 
           623485525*x^5 + 1120075015*x^6 - 8734263288*x^7 - 
           11185290480*x^8 + 77307121862*x^9 + 91730176750*x^10 - 
           477249952568*x^11 - 486783823020*x^12 + 2157025911834*x^13 + 
           794233538790*x^14 - 6212306154240*x^15 + 4454173859940*x^16 + 
           5379481848987*x^17 - 15124703422005*x^18 + 13441544301132*x^19 - 
           7526268401850*x^20 + 1299862807137*x^21 - 298982440845*x^22 - 
           1410300072*x^23)*master3l8b[x])/(972000*x*(1 - 9*x^2)^6*
          (-1 + x^2)^10) - ((688141008 + 9683923005*x + 39340217943*x^2 + 
           123570728685*x^3 - 442587453759*x^4 + 692706273570*x^5 - 
           465058714068*x^6 - 109042120860*x^7 + 333740644836*x^8 - 
           56505902850*x^9 - 106169707582*x^10 + 23958200630*x^11 + 
           22270574238*x^12 - 4745759640*x^13 - 3051714084*x^14 + 
           606239220*x^15 + 249333572*x^16 - 48634435*x^17 - 10724129*x^18 + 
           2126725*x^19 + 182185*x^20 - 37250*x^21)*master3l9a[x])/
         (324000*(-9 + x^2)^5*(-1 + x^2)^10) - 
        ((-37250 + 182185*x + 2126725*x^2 - 10724129*x^3 - 48634435*x^4 + 
           249333572*x^5 + 606239220*x^6 - 3051714084*x^7 - 4745759640*x^8 + 
           22270574238*x^9 + 23958200630*x^10 - 106169707582*x^11 - 
           56505902850*x^12 + 333740644836*x^13 - 109042120860*x^14 - 
           465058714068*x^15 + 692706273570*x^16 - 442587453759*x^17 + 
           123570728685*x^18 + 39340217943*x^19 + 9683923005*x^20 + 
           688141008*x^21)*master3l9b[x])/(972000*x*(-1 + x^2)^10*
          (-1 + 9*x^2)^5) + (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*
            (13500 - 29250*x - 28750*x^2 + 157050*x^3 - 64954*x^4 - 
             348507*x^5 + 284157*x^6 + 411032*x^7 - 385027*x^8 - 276662*x^9 + 
             247748*x^10 + 107718*x^11 - 74352*x^12 - 25041*x^13 + 
             9478*x^14 + 5120*x^15 + 9478*x^16 - 25041*x^17 - 74352*x^18 + 
             107718*x^19 + 247748*x^20 - 276662*x^21 - 385027*x^22 + 
             411032*x^23 + 284157*x^24 - 348507*x^25 - 64954*x^26 + 
             157050*x^27 - 28750*x^28 - 29250*x^29 + 13500*x^30) - 
           1440*x^13*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 5844*x^5 - 
             4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10)*Zeta[3]))/
         (97200*x^13*(-1 + x^2)^8) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(13500 - 29250*x - 28750*x^2 + 
              157050*x^3 - 64954*x^4 - 348507*x^5 + 284157*x^6 + 411032*x^7 - 
              385027*x^8 - 276662*x^9 + 247748*x^10 + 107718*x^11 - 
              74352*x^12 - 25041*x^13 + 9478*x^14 + 5120*x^15 + 9478*x^16 - 
              25041*x^17 - 74352*x^18 + 107718*x^19 + 247748*x^20 - 
              276662*x^21 - 385027*x^22 + 411032*x^23 + 284157*x^24 - 
              348507*x^25 - 64954*x^26 + 157050*x^27 - 28750*x^28 - 
              29250*x^29 + 13500*x^30)) + 1440*x^13*(5 + 18*x - 339*x^2 + 
             2100*x^3 - 4286*x^4 + 5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 
             18*x^9 + 5*x^10)*Zeta[3]))/(97200*x^13*(-1 + x^2)^8) + 
        (HPL[{0}, x]*(36159245640000 - 78345032220000*x - 2198348211780000*
            x^2 + 5016894447852000*x^3 + 57706373159371440*x^4 - 
           141230878491777480*x^5 - 852327119190645000*x^6 + 
           2300896176514820640*x^7 + 7714853590587192000*x^8 - 
           24075600590423222820*x^9 - 306180*(141433061679767 + 5431050*Pi^2)*
            x^10 + 87480*(1946687235501709 + 118078317*Pi^2)*x^11 + 
           5040*(-2340558037312852475 + 305416653542808746*Pi^2)*x^28 - 
           135*(1261390262475837393 + 9376537767487827496*Pi^2)*x^45 + 
           210*(206203779100377171 + 475503059172754076*Pi^2)*x^46 + 
           945*(25476776671386069 + 356719565300841808*Pi^2)*x^47 - 
           181440*(42520136632425 + 337821470150509*Pi^2)*x^48 - 
           816480*(2818068019443 + 79431610047526*Pi^2)*x^49 + 
           204120*(4175617867875 + 83430909730246*Pi^2)*x^50 + 
           1837080*(76877914131 + 4788081390100*Pi^2)*x^51 - 
           1224720*(47118013227 + 2333047396832*Pi^2)*x^52 - 
           11022480*(455151150 + 73865564723*Pi^2)*x^53 + 
           99202320*(22160250 + 3058452289*Pi^2)*x^54 + 
           297606960*(263250 + 163811471*Pi^2)*x^55 - 1190427840*
            (30375 + 16774847*Pi^2)*x^56 - 1698413160024000*Pi^2*x^57 + 
           744835819140000*Pi^2*x^58 + 26115010740000*Pi^2*x^59 - 
           12053081880000*Pi^2*x^60 - 600*x^25*(804701742705905205*Pi^2 + 
             64*(594839926165389911 - 1883296086693525*Zeta[3])) - 
           42*x^29*(-637329332381086970639 + 60983772627026334460*Pi^2 - 
             30659695598763360000*Zeta[3]) + 168*x^27*(8484670674432337609 + 
             8162882267794689105*Pi^2 - 7664923899690840000*Zeta[3]) + 
           30*x^31*(1238662047955596644017 + 198080919057341761196*Pi^2 - 
             2410618990967712000*Zeta[3]) + 280*x^24*(-67729445427564397009 + 
             956079684698841612*Pi^2 - 1551136858419513600*Zeta[3]) - 
           2240*x^22*(-6631659190229187347 + 21953778161003868*Pi^2 - 
             17506556014770000*Zeta[3]) + 840*x^36*(8914789832865361471 + 
             14005888600248235584*Pi^2 - 13072571462534400*Zeta[3]) - 
           840*x^38*(4074405039490877765 + 10328371015346525778*Pi^2 - 
             3780852672528000*Zeta[3]) + 840*x^40*(776025038565364167 + 
             5384092799543792804*Pi^2 - 404095832121600*Zeta[3]) + 
           8400*x^18*(444803572834111529 + 33594168088386*Pi^2 - 
             378085267252800*Zeta[3]) - 7560*x^16*(89341161527149223 + 
             7039655394660*Pi^2 - 44899536902400*Zeta[3]) - 
           2100*x^42*(-74698918310748399 + 709317325552546574*Pi^2 - 
             8209870629120*Zeta[3]) + 3150*x^14*(-49633280350340311 + 
             835001542620*Pi^2 - 5473247086080*Zeta[3]) - 
           170100*x^12*(-822724365063839 + 73474452*Pi^2 - 
             2040733440*Zeta[3]) + 1728*x^43*(485374798709150892 + 
             2031161799647600585*Pi^2 + 502211745000*Zeta[3]) - 
           81*x^13*(10358478913078793351 + 5178394171440*Pi^2 + 
             10713850560000*Zeta[3]) + 1215*x^15*(2424204600374788891 + 
             5146212571416*Pi^2 + 37855605312000*Zeta[3]) - 
           216*x^17*(34873146186782471279 + 216197068505985*Pi^2 + 
             4654126443960000*Zeta[3]) + 840*x^20*(-11091721109917061431 + 
             3563994599297568*Pi^2 + 13072571462534400*Zeta[3]) + 
           36*x^39*(209023211748556334019 + 324359542804122916370*Pi^2 + 
             27924758663760000*Zeta[3]) - 540*x^21*(39223247239907281379 + 
             15478174598865678*Pi^2 + 129633514193232000*Zeta[3]) - 
           280*x^34*(42533007300742872421 + 42029568960010291890*Pi^2 + 
             140052448118160000*Zeta[3]) + 72*x^19*(199667255993663411102 + 
             6577577274567915*Pi^2 + 159397279219080000*Zeta[3]) - 
           36*x^37*(409597411679011353739 + 399614561704042168890*Pi^2 + 
             318794558438160000*Zeta[3]) + 280*x^32*(114576286117444333849 + 
             31710714662564474484*Pi^2 + 1551136858419513600*Zeta[3]) - 
           140*x^30*(457675263447909782155 + 35416076453954881536*Pi^2 + 
             7394534495191123200*Zeta[3]) - 24*x^33*(1705671963684374076421 + 
             430578694144300171715*Pi^2 + 7868955392280360000*Zeta[3]) + 
           12*x^23*(2104694067724811794697 + 7386467782689773190*Pi^2 + 
             15737910784560720000*Zeta[3]) + 420*x^44*
            (407700239397101276*Pi^2 - 405*(822573601815227 + 2040733440*
                Zeta[3])) - 60*x^41*(122063728614821989814*Pi^2 + 
             729*(67244134479290057 + 1051544592000*Zeta[3])) + 
           120*x^35*(114998321113636235387*Pi^2 + 1185*(177086198361253067 + 
               492279167822400*Zeta[3])) - 560*x^26*
            (1257519688842712158*Pi^2 - 5*(9204214341377589767 + 
               369726724759556160*Zeta[3]))))/(81648000*x^9*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6) + (-33600*Pi^4*x^11*(-1 + x^2)^2*
           (9 - 82*x^2 + 9*x^4)^6*(5 + 18*x - 339*x^2 + 2100*x^3 - 4286*x^4 + 
            5844*x^5 - 4286*x^6 + 2100*x^7 - 339*x^8 + 18*x^9 + 5*x^10) + 
          4*Pi^2*(9 - 82*x^2 + 9*x^4)^6*(-11340000 + 24570000*x + 
            75180000*x^2 - 242487000*x^3 - 142943640*x^4 + 1078859880*x^5 - 
            222278000*x^6 - 2853669840*x^7 + 1644077960*x^8 + 
            4981874100*x^9 - 3826333000*x^10 - 6025373609*x^11 + 
            5172549410*x^12 + 5182158541*x^13 - 4815968500*x^14 - 
            2739771139*x^15 + 1417947650*x^16 + 2471864115*x^17 - 
            2471864115*x^19 - 1417947650*x^20 + 2739771139*x^21 + 
            4815968500*x^22 - 5182158541*x^23 - 5172549410*x^24 + 
            6025373609*x^25 + 3826333000*x^26 - 4981874100*x^27 - 
            1644077960*x^28 + 2853669840*x^29 + 222278000*x^30 - 
            1078859880*x^31 + 142943640*x^32 + 242487000*x^33 - 
            75180000*x^34 - 24570000*x^35 + 11340000*x^36) + 
          x^2*(-36159245640000 + 78345032220000*x + 2210401293660000*x^2 - 
            5043009458592000*x^3 - 58434635990926440*x^4 + 142893383512033980*
             x^5 + 871290294442687980*x^6 - 2347351464833335800*x^7 - 
            7991912819405852820*x^8 + x^35*(20273745446592116876556 - 
              167254734086786990266560*Zeta[3]) + 
            x^21*(25251231307293085246836 - 1508451004123878810240*Zeta[3]) + 
            20380957920288000*x^57*Zeta[3] - 8938029829680000*x^58*Zeta[3] - 
            313380128880000*x^59*Zeta[3] + 144636982560000*x^60*Zeta[3] + 
            137781*x^9*(180179659012757 + 28615680*Zeta[3]) + 
            3571283520*x^56*(-10125 + 67099388*Zeta[3]) - 1785641760*x^55*
             (-43875 + 327622942*Zeta[3]) + 153090*x^10*(298998217339907 + 
              2257217280*Zeta[3]) - 595213920*x^54*(-3713625 + 
              6116904578*Zeta[3]) + 132269760*x^53*(-38126700 + 
              73865564723*Zeta[3]) - 34020*x^12*(4510957281064519 + 
              175892396832*Zeta[3]) - 2187*x^11*(81415368160203493 + 
              1012636054080*Zeta[3]) + 1837080*x^52*(-31808432943 + 
              18664379174656*Zeta[3]) - 2755620*x^51*(-51855257079 + 
              38304651120800*Zeta[3]) - 3150*x^14*(-62527526441861419 + 
              77871101901696*Zeta[3]) - 306180*x^50*(-2845679974011 + 
              667447277841968*Zeta[3]) + 81*x^13*(11030059321128237827 + 
              1118317546221120*Zeta[3]) + 612360*x^49*(-3833286734655 + 
              1270905760760416*Zeta[3]) + 4200*x^16*(158311709952753125 + 
              2212774508743488*Zeta[3]) + 68040*x^48*(-117458852848533 + 
              10810287044816288*Zeta[3]) + 108*x^17*(78758670034416945493 + 
              21786231213437040*Zeta[3]) - 27*x^15*(119052490837843800191 + 
              47516536633587840*Zeta[3]) + 1296*x^19*(-13070950063665822767 + 
              99786684010080900*Zeta[3]) - 420*x^18*(10198710982554051271 + 
              299837609802221904*Zeta[3]) + 840*x^20*(14711695661652548495 + 
              964725908628731904*Zeta[3]) - 1260*x^44*(121789683696098853 + 
              1630803814568926688*Zeta[3]) - 630*x^46*(-72656061501845511 + 
              1902011802510805184*Zeta[3]) - 560*x^22*(40711800119077830883 + 
              3525312826453768044*Zeta[3]) + 3150*x^42*(62421967545929317 + 
              5674455741089577664*Zeta[3]) - 567*x^47*(-43783639020010341 + 
              7134391324572393920*Zeta[3]) - 8960*x^32*
             (-1675795696818889459 + 11982415619549873853*Zeta[3]) - 
            280*x^24*(-89522338474223507603 + 12448409655096574272*Zeta[3]) - 
            210*x^25*(-103150348091604709799 + 52973545327716320224*Zeta[
                3]) + 1120*x^34*(-19836802266859596179 + 
              123955176537156192576*Zeta[3]) - 420*x^40*
             (-1601130514521755315 + 129196743147864584256*Zeta[3]) - 
            280*x^28*(-211875689089983018325 + 161138264304825870528*Zeta[
                3]) - 840*x^36*(-15120807461215007015 + 167091541299483164928*
               Zeta[3]) + 81*x^45*(-2198148599144296341 + 
              187530741336017972480*Zeta[3]) + 140*x^26*
             (-172909418047751276629 + 187571663560535563584*Zeta[3]) + 
            28*x^23*(-937591119375267390583 + 246881381256769278720*Zeta[
                3]) + 420*x^38*(-10391335142690633971 + 247589475428699846208*
               Zeta[3]) - 30*x^27*(690596400064551622231 + 
              281514324163111156320*Zeta[3]) - 210*x^31*
             (-53381618524156986461 + 417157895256292354720*Zeta[3]) - 
            81*x^43*(-11026206639243420257 + 519976697623938101120*Zeta[3]) + 
            140*x^30*(10257965943646200941 + 556854490762968616992*Zeta[3]) + 
            216*x^37*(-73838715276695552647 + 799949158792806918840*Zeta[
                3]) + 30*x^29*(-1302068553866529650245 + 
              1245064255575257938464*Zeta[3]) - 108*x^39*
             (-77685517652626766803 + 1297457515308222852080*Zeta[3]) + 
            28*x^33*(-468918226508343087973 + 4711633832062027408080*Zeta[
                3]) + 9*x^41*(-356261709669084089943 + 9765010833620938141120*
               Zeta[3])))/(326592000*x^11*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^
           6)))
 
CbarData["v", 2, 4] = 
    NC*(CF*(NL*(-(Pi^2*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 
              1032*x^6 + 672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{-1}, x])/
           (17010*(-1 + x^2)^9) + (x^2*(-40734 + 630*(134051 + 7560*Pi^2)*x - 
             9*(26158271 + 1587600*Pi^2)*x^2 + 189*(4343957 + 315000*Pi^2)*
              x^3 - 30*(38136239 + 3339840*Pi^2)*x^4 + 
             21*(56400791 + 8589000*Pi^2)*x^5 - 35*(8506727 + 5102580*Pi^2)*
              x^6 + 588*(-1372717 + 305400*Pi^2)*x^7 + 
             (1234513758 - 99454320*Pi^2)*x^8 + 1134*(-976277 + 52360*Pi^2)*
              x^9 - 15*(-29153885 + 972552*Pi^2)*x^10 + 
             105*(-1666597 + 47544*Pi^2)*x^11 + (5685058 - 52080*Pi^2)*x^12 + 
             105*(-5983 + 168*Pi^2)*x^13 + 63*(-3481 + 60*Pi^2)*x^14)*
            HPL[{0}, x])/(7144200*(-1 + x^2)^12) + 
          lm^2*((3 + 14*x - 102*x^2 + 1428*x^3 - 3399*x^4 + 7378*x^5 - 
              8124*x^6 + 7378*x^7 - 3399*x^8 + 1428*x^9 - 102*x^10 + 
              14*x^11 + 3*x^12)/(630*(-1 + x^2)^10) - 
            (4*x^3*(1 - 3*x + 10*x^2 - 15*x^3 + 20*x^4 - 15*x^5 + 10*x^6 - 3*
                x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11)) + 
          (Pi^2*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 
             1032*x^6 + 672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{1}, x])/
           (17010*(-1 + x^2)^9) - (2*x^3*(11340 - 34020*x + 141750*x^2 - 
             238560*x^3 + 429450*x^4 - 425215*x^5 + 427560*x^6 - 236796*x^7 + 
             141372*x^8 - 34734*x^9 + 11886*x^10 - 124*x^11 + 42*x^12 + 
             9*x^13)*HPL[{-2, 0}, x])/(2835*(-1 + x^2)^12) + 
          ((2263 + 9464*x - 191285*x^2 + 4941496*x^3 - 12977163*x^4 + 
             39520180*x^5 - 54694615*x^6 + 73933720*x^7 - 54694615*x^8 + 
             39520180*x^9 - 12977163*x^10 + 4941496*x^11 - 191285*x^12 + 
             9464*x^13 + 2263*x^14)*HPL[{-1, 0}, x])/(396900*(-1 + x^2)^11) + 
          (x^3*(882000 - 2646000*x + 14420700*x^2 - 27400800*x^3 + 
             63185500*x^4 - 75248075*x^5 + 90821500*x^6 - 60984028*x^7 + 
             40870116*x^8 - 12007842*x^9 + 4403728*x^10 - 76092*x^11 + 
             25816*x^12 + 5297*x^13)*HPL[{0, 0}, x])/(198450*(-1 + x^2)^12) - 
          ((2263 + 9464*x - 191285*x^2 + 4941496*x^3 - 12977163*x^4 + 
             39520180*x^5 - 54694615*x^6 + 73933720*x^7 - 54694615*x^8 + 
             39520180*x^9 - 12977163*x^10 + 4941496*x^11 - 191285*x^12 + 
             9464*x^13 + 2263*x^14)*HPL[{1, 0}, x])/(396900*(-1 + x^2)^11) + 
          lm*((31329 + 89745*x - 743674*x^2 + 13113855*x^3 - 30359225*x^4 + 
              67008000*x^5 - 72892860*x^6 + 67008000*x^7 - 30359225*x^8 + 
              13113855*x^9 - 743674*x^10 + 89745*x^11 + 31329*x^12 + 
              60*Pi^2*(-9 - 42*x + 106*x^2 - 630*x^3 + 935*x^4 - 840*x^5 + 
                840*x^7 - 935*x^8 + 630*x^9 - 106*x^10 + 42*x^11 + 9*x^12))/
             (2041200*(-1 + x^2)^10) - (x^2*(18 + 35184*x - 100724*x^2 + 
               389451*x^3 - 612882*x^4 + 939762*x^5 - 782982*x^6 + 603651*
                x^7 - 219416*x^8 + 86088*x^9 - 3762*x^10 + 504*x^11 + 108*
                x^12)*HPL[{0}, x])/(5670*(-1 + x^2)^11) - 
            ((9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
               672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{-1, 0}, x])/
             (2835*(-1 + x^2)^9) + (2*x^3*(3780 - 11340*x + 73710*x^2 - 
               147840*x^3 + 353850*x^4 - 425215*x^5 + 503160*x^6 - 327516*
                x^7 + 209412*x^8 - 57414*x^9 + 19446*x^10 - 124*x^11 + 42*
                x^12 + 9*x^13)*HPL[{0, 0}, x])/(2835*(-1 + x^2)^12) + 
            ((9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
               672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{1, 0}, x])/
             (2835*(-1 + x^2)^9)) + (2*x^3*(11340 - 34020*x + 141750*x^2 - 
             238560*x^3 + 429450*x^4 - 425215*x^5 + 427560*x^6 - 236796*x^7 + 
             141372*x^8 - 34734*x^9 + 11886*x^10 - 124*x^11 + 42*x^12 + 
             9*x^13)*HPL[{2, 0}, x])/(2835*(-1 + x^2)^12) + 
          (2*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
             672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{-1, -1, 0}, x])/
           (2835*(-1 + x^2)^9) - (2*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 
             1512*x^5 - 1032*x^6 + 672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*
            HPL[{-1, 1, 0}, x])/(2835*(-1 + x^2)^9) - 
          (4*x^3*(3780 - 11340*x + 73710*x^2 - 147840*x^3 + 353850*x^4 - 
             425215*x^5 + 503160*x^6 - 327516*x^7 + 209412*x^8 - 57414*x^9 + 
             19446*x^10 - 124*x^11 + 42*x^12 + 9*x^13)*HPL[{0, 0, 0}, x])/
           (2835*(-1 + x^2)^12) - (2*(9 + 42*x - 97*x^2 + 672*x^3 - 
             1032*x^4 + 1512*x^5 - 1032*x^6 + 672*x^7 - 97*x^8 + 42*x^9 + 
             9*x^10)*HPL[{1, -1, 0}, x])/(2835*(-1 + x^2)^9) + 
          (2*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
             672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{1, 1, 0}, x])/
           (2835*(-1 + x^2)^9) + (-12572078*x^14 - 1805349*x^15 + 
            1509963*x^16 - 18*Pi^2*(-2263 - 9464*x + 193548*x^2 - 
              4932032*x^3 + 12785878*x^4 - 34578684*x^5 + 41717452*x^6 - 
              34413540*x^7 + 34413540*x^9 - 41717452*x^10 + 34578684*x^11 - 
              12785878*x^12 + 4932032*x^13 - 193548*x^14 + 9464*x^15 + 
              2263*x^16) + x^8*(3611042182 - 12858501600*Zeta[3]) + 
            21*(71903 + 12960*Zeta[3]) + 21*x*(-85969 + 60480*Zeta[3]) - 
            2*x^2*(6286039 + 1874880*Zeta[3]) + 147*x^13*(3733421 + 
              2332800*Zeta[3]) + 147*x^3*(3733421 + 2445120*Zeta[3]) + 
            189*x^5*(9463277 + 22619520*Zeta[3]) + 189*x^11*
             (9463277 + 22680000*Zeta[3]) - 30*x^12*(39983081 + 
              34292160*Zeta[3]) - 30*x^4*(39983081 + 35011872*Zeta[3]) - 
            162*x^6*(3672633 + 44201920*Zeta[3]) - 162*x^10*
             (3672633 + 44531200*Zeta[3]) + 21*x^7*(-111217471 + 
              615686400*Zeta[3]) + 21*x^9*(-111217471 + 618408000*Zeta[3]))/
           (85730400*(-1 + x^2)^12)) + 
        NH*((x*(820091691115200 + 4351033303725744*x + 1449795946756993164*
              x^2 - 3418903784653343271*x^3 + 9945690018891840738*x^4 - 
             12163711121442710271*x^5 + 10310588302931995428*x^6 - 
             1668258036091206063*x^7 - 5507300504318706954*x^8 + 
             5838994115638812729*x^9 - 1684804090081503132*x^10 - 
             1723134590476036227*x^11 + 1482185311080060258*x^12 - 
             101752941290566347*x^13 - 329785809460080372*x^14 + 
             154858481339629077*x^15 + 15585238273279878*x^16 - 
             38001484140700563*x^17 + 6490245374469108*x^18 + 
             4723278213207627*x^19 - 1531651658164362*x^20 - 
             303157761721437*x^21 + 164859158762844*x^22 + 3802758255923*
              x^23 - 10194699032910*x^24 + 931676345803*x^25 + 
             357214132380*x^26 - 75395309025*x^27 - 5651661498*x^28 + 
             2559653863*x^29 - 11966220*x^30 - 36138841*x^31 + 920850*x^32 + 
             59679*x^33)*HPL[{0}, x])/(14288400*(-9 + x^2)^8*(-1 + x^2)^13) + 
          lm^2*((3 + 14*x - 102*x^2 + 1428*x^3 - 3399*x^4 + 7378*x^5 - 
              8124*x^6 + 7378*x^7 - 3399*x^8 + 1428*x^9 - 102*x^10 + 
              14*x^11 + 3*x^12)/(630*(-1 + x^2)^10) - 
            (4*x^3*(1 - 3*x + 10*x^2 - 15*x^3 + 20*x^4 - 15*x^5 + 10*x^6 - 3*
                x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11)) + 
          (x*(-22780324753200 - 47223853637292*x - 29527615268405856*x^2 + 
             69498559759525263*x^3 - 200389695238911780*x^4 + 
             240808037734812987*x^5 - 190155579967846584*x^6 + 
             5489094336786369*x^7 + 145941413662897776*x^8 - 
             135605655652086783*x^9 + 35406015618866760*x^10 + 
             45739746378576567*x^11 - 38922245917417044*x^12 + 
             2899338636359115*x^13 + 8342385066477504*x^14 - 
             4427769642626679*x^15 + 8125560587424*x^16 + 1023931159235001*
              x^17 - 276262460611536*x^18 - 103663627420459*x^19 + 
             48390396059124*x^20 + 2314580247913*x^21 - 3563742599480*x^22 + 
             559086320283*x^23 + 63344456784*x^24 - 63015884821*x^25 + 
             7563900008*x^26 + 2864590117*x^27 - 491890812*x^28 - 
             54202671*x^29 + 8574384*x^30 + 88539*x^31 + 24528*x^32 + 
             4551*x^33)*HPL[{0, 0}, x])/(396900*(-9 + x^2)^8*(-1 + x^2)^13) + 
          lm*((31329 + 89745*x - 743674*x^2 + 13113855*x^3 - 30359225*x^4 + 
              67008000*x^5 - 72892860*x^6 + 67008000*x^7 - 30359225*x^8 + 
              13113855*x^9 - 743674*x^10 + 89745*x^11 + 31329*x^12 + 
              60*Pi^2*(-9 - 42*x + 106*x^2 - 630*x^3 + 935*x^4 - 840*x^5 + 
                840*x^7 - 935*x^8 + 630*x^9 - 106*x^10 + 42*x^11 + 9*x^12))/
             (2041200*(-1 + x^2)^10) - (x^2*(18 + 35184*x - 100724*x^2 + 
               389451*x^3 - 612882*x^4 + 939762*x^5 - 782982*x^6 + 603651*
                x^7 - 219416*x^8 + 86088*x^9 - 3762*x^10 + 504*x^11 + 108*
                x^12)*HPL[{0}, x])/(5670*(-1 + x^2)^11) - 
            ((9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
               672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{-1, 0}, x])/
             (2835*(-1 + x^2)^9) + (2*x^3*(3780 - 11340*x + 73710*x^2 - 
               147840*x^3 + 353850*x^4 - 425215*x^5 + 503160*x^6 - 327516*
                x^7 + 209412*x^8 - 57414*x^9 + 19446*x^10 - 124*x^11 + 42*
                x^12 + 9*x^13)*HPL[{0, 0}, x])/(2835*(-1 + x^2)^12) + 
            ((9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
               672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{1, 0}, x])/
             (2835*(-1 + x^2)^9)) - (2*(-1374 + 88071*x - 226584*x^2 + 
             793686*x^3 - 1209399*x^4 + 1849210*x^5 - 1695725*x^6 + 
             1462230*x^7 - 741360*x^8 + 374655*x^9 - 86406*x^10 + 
             21464*x^11 - 181*x^12 + 24*x^13 + 9*x^14)*HPL[{-1, 0, 0}, x])/
           (2835*(-1 + x)^12*(1 + x)^10) + 
          (2*x^3*(1111398435774900 - 2559323203238673*x + 7432308303986286*
              x^2 - 8741994552108567*x^3 + 6958713570187428*x^4 - 
             66706121069685*x^5 - 5985886029183018*x^6 + 5601774848594661*
              x^7 - 1986917418288684*x^8 - 1610717975636517*x^9 + 
             1745892528042978*x^10 - 318837624522579*x^11 - 
             264759365501820*x^12 + 226431299375199*x^13 - 42100589345598*
              x^14 - 43036342972383*x^15 + 18730871843964*x^16 + 
             3086667390125*x^17 - 2461527189534*x^18 + 119218036283*x^19 + 
             123554256588*x^20 - 39508229391*x^21 + 3042941034*x^22 + 
             3121322431*x^23 - 667231236*x^24 - 118872183*x^25 + 
             29870862*x^26 + 2267439*x^27 - 479220*x^28 - 26075*x^29 + 
             1470*x^30 + 315*x^31)*HPL[{0, 0, 0}, x])/(99225*(-9 + x^2)^8*
            (-1 + x^2)^13) + (2*(-3264 + 84465*x - 219822*x^2 + 777450*x^3 - 
             1142619*x^4 + 1726250*x^5 - 1352585*x^6 + 1070370*x^7 - 
             390870*x^8 + 209145*x^9 - 27816*x^10 + 17680*x^11 - 13*x^12 + 
             60*x^13 + 9*x^14)*HPL[{1, 0, 0}, x])/(2835*(-1 + x)^10*
            (1 + x)^12) + ((21903432754293 + 4408495244933724*x - 
             10309238258339007*x^2 + 30176502875162280*x^3 - 
             37129382999876115*x^4 + 33400367229778920*x^5 - 
             9034407342991431*x^6 - 11512964437247448*x^7 + 14746447481398641*
              x^8 - 5166439315686684*x^9 - 3213098028866547*x^10 + 
             3184774577012448*x^11 - 377573890927815*x^12 - 
             617827595420448*x^13 + 295700160590901*x^14 + 29586882031056*
              x^15 - 62413241242833*x^16 + 9912177993060*x^17 + 
             7034251137363*x^18 - 2382372291096*x^19 - 419657725129*x^20 + 
             258379405704*x^21 + 5428168987*x^22 - 15700455288*x^23 + 
             994158891*x^24 + 498239196*x^25 - 68019297*x^26 - 5290992*x^27 + 
             1652067*x^28 - 46032*x^29 - 10569*x^30)*master3l8a[x])/
           (1190700*(-9 + x^2)^8*(-1 + x^2)^13) - 
          ((2433714750477 + 242855374820436*x - 576462015234576*x^2 + 
             1728304626890016*x^3 - 2246872878988173*x^4 + 2356804968477120*
              x^5 - 1238651997760026*x^6 + 312845843288412*x^7 + 
             256027309605477*x^8 - 97750959535656*x^9 + 29373914667996*x^10 - 
             44973493178796*x^11 + 32163919198371*x^12 - 14809150843956*
              x^13 - 13888724329014*x^14 + 10997656653144*x^15 + 
             1085635596991*x^16 - 1839101004636*x^17 + 216283550456*x^18 + 
             77953453704*x^19 - 49090027471*x^20 + 9913816248*x^21 + 
             3928288922*x^22 - 1319169012*x^23 - 146688561*x^24 + 
             57059184*x^25 + 2559612*x^26 - 885948*x^27 - 35911*x^28 + 
             2940*x^29 + 630*x^30)*master3l9a[x])/(396900*(-9 + x^2)^7*
            (-1 + x^2)^13) + (x^18*(286233026343645970 - 73504813156588800*
               Zeta[3]) + x^26*(3386969948012 - 4062241935360*Zeta[3]) + 
            x^32*(531541319 - 31489920*Zeta[3]) + 42*x^33*
             (-587929 + 40320*Zeta[3]) + 3*x^34*(-601463 + 120960*Zeta[3]) + 
            1008*x^31*(-1757591 + 126000*Zeta[3]) - 420*x^29*
             (-487133215 + 74624256*Zeta[3]) + 4*x^30*(-6319161269 + 
              165090240*Zeta[3]) + 43046721*(-1177809209 + 330583680*Zeta[
                3]) - 66961566*x*(114435988517 + 1141983360*Zeta[3]) + 
            12*x^28*(32551936103 + 4985830080*Zeta[3]) + 
            168*x^27*(-43024637281 + 9445917600*Zeta[3]) + 
            1594323*x^2*(11224713982649 + 79632927360*Zeta[3]) + 
            9920232*x^3*(-6386280618829 + 109338919200*Zeta[3]) - 
            252*x^25*(-540670581967 + 150124141440*Zeta[3]) + 
            2688*x^23*(-569320166069 + 180130296150*Zeta[3]) - 
            2520*x^19*(4961668969037 + 258824210400*Zeta[3]) - 
            489888*x^7*(102865564004129 + 566397279000*Zeta[3]) + 
            1653372*x^5*(-79152413895017 + 4278840733440*Zeta[3]) - 
            236196*x^4*(-383303139885929 + 13601999960640*Zeta[3]) - 
            108*x^22*(-40811683318411 + 15780025024960*Zeta[3]) + 
            4*x^24*(-58822793588621 + 27873557832960*Zeta[3]) - 
            84*x^21*(-114116402126623 + 35630046869760*Zeta[3]) - 
            111132*x^12*(-137012223249413 + 40237393256640*Zeta[3]) - 
            15120*x^15*(-185252204356843 + 58791633339600*Zeta[3]) + 
            1680*x^17*(-191441152895669 + 83779406565120*Zeta[3]) - 
            102060*x^9*(-510760083639037 + 110285219737728*Zeta[3]) + 
            78732*x^8*(-248597658281983 + 111530683192320*Zeta[3]) - 
            26244*x^6*(-3944463739573807 + 249106122740160*Zeta[3]) + 
            4536*x^11*(715958788193563 + 529223498445600*Zeta[3]) + 
            90*x^16*(-9514549813039039 + 908002251354240*Zeta[3]) + 
            756*x^13*(-12373627926628967 + 2382653961596160*Zeta[3]) + 
            4*x^20*(-11549084872810729 + 3822780227676480*Zeta[3]) + 
            972*x^10*(-36815247680121287 + 4445489720689920*Zeta[3]) + 
            108*x^14*(-7833870653959097 + 8859170245141440*Zeta[3]))/
           (171460800*(-9 + x^2)^8*(-1 + x^2)^13)) + 
        NM*(-((430920 + 2010960*x - 31708188*x^2 - 525937860*x^3 + 
              2264852355*x^4 + 34857187218*x^5 - 120156777333*x^6 - 
              865577598900*x^7 + 3305019211219*x^8 + 6878256286230*x^9 - 
              44679358428325*x^10 + 77111450400516*x^11 + 203504385894063*x^
                12 - 1978777869609198*x^13 + 1904768338022087*x^14 + 
              14056277890684932*x^15 - 28745348455299377*x^16 - 
              13701259420901178*x^17 + 111326382391276863*x^18 - 
              284265306679941468*x^19 + 144674712711319113*x^20 + 
              943241251782170502*x^21 - 1722698571353895999*x^22 + 
              1600179352123154292*x^23 + 637760452989086073*x^24 - 
              6186421561279705326*x^25 + 7769225311592135121*x^26 - 
              8989275755343108708*x^27 + 5192628162555895749*x^28 - 
              2687399947304921898*x^29 + 980474840813323053*x^30 - 
              103342162780212804*x^31 + 37215449703854685*x^32 + 
              20936614927588290*x^33 - 12794627611150479*x^34 + 
              840*Pi^2*(1 - 9*x^2)^8*(-1 + x^2)^4*(9 + 42*x - 97*x^2 + 
                672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 672*x^7 - 97*x^8 + 
                42*x^9 + 9*x^10))*HPL[{0}, x])/(14288400*(1 - 9*x^2)^8*
            (-1 + x^2)^13) + lm^2*((3 + 14*x - 102*x^2 + 1428*x^3 - 
              3399*x^4 + 7378*x^5 - 8124*x^6 + 7378*x^7 - 3399*x^8 + 
              1428*x^9 - 102*x^10 + 14*x^11 + 3*x^12)/(630*(-1 + x^2)^10) - 
            (4*x^3*(1 - 3*x + 10*x^2 - 15*x^3 + 20*x^4 - 15*x^5 + 10*x^6 - 3*
                x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11)) + 
          (2*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
             672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{-2, 0}, x])/
           (2835*(-1 + x^2)^9) + ((7560 + 35280*x - 521784*x^2 - 
             12793032*x^3 + 47012011*x^4 + 739252080*x^5 - 2403836529*x^6 - 
             11904903752*x^7 + 51232405605*x^8 - 102915432228*x^9 - 
             245088995715*x^10 + 5529672084608*x^11 - 8106147142125*x^12 - 
             65333988931008*x^13 + 152503345091135*x^14 + 211783911552528*
              x^15 - 988021055565891*x^16 + 1736948718808044*x^17 + 
             642146975915613*x^18 - 15458216618464200*x^19 + 
             22097540271403017*x^20 + 18381200159293776*x^21 - 
             79259541772447035*x^22 + 147613433730568344*x^23 - 
             62000461681821081*x^24 - 252455383332749772*x^25 + 
             418824091357907103*x^26 - 576524421035693424*x^27 + 
             376258533309750393*x^28 - 225509416841786112*x^29 + 
             88211540713871277*x^30 - 16105823847705312*x^31 + 
             2997484052827311*x^32 + 1695250118851380*x^33 - 
             985003607521665*x^34)*HPL[{0, 0}, x])/(396900*(1 - 9*x^2)^8*
            (-1 + x^2)^13) + lm*((31329 + 89745*x - 743674*x^2 + 
              13113855*x^3 - 30359225*x^4 + 67008000*x^5 - 72892860*x^6 + 
              67008000*x^7 - 30359225*x^8 + 13113855*x^9 - 743674*x^10 + 
              89745*x^11 + 31329*x^12 + 60*Pi^2*(-9 - 42*x + 106*x^2 - 
                630*x^3 + 935*x^4 - 840*x^5 + 840*x^7 - 935*x^8 + 630*x^9 - 
                106*x^10 + 42*x^11 + 9*x^12))/(2041200*(-1 + x^2)^10) - 
            (x^2*(18 + 35184*x - 100724*x^2 + 389451*x^3 - 612882*x^4 + 
               939762*x^5 - 782982*x^6 + 603651*x^7 - 219416*x^8 + 86088*
                x^9 - 3762*x^10 + 504*x^11 + 108*x^12)*HPL[{0}, x])/
             (5670*(-1 + x^2)^11) - ((9 + 42*x - 97*x^2 + 672*x^3 - 1032*
                x^4 + 1512*x^5 - 1032*x^6 + 672*x^7 - 97*x^8 + 42*x^9 + 9*
                x^10)*HPL[{-1, 0}, x])/(2835*(-1 + x^2)^9) + 
            (2*x^3*(3780 - 11340*x + 73710*x^2 - 147840*x^3 + 353850*x^4 - 
               425215*x^5 + 503160*x^6 - 327516*x^7 + 209412*x^8 - 57414*
                x^9 + 19446*x^10 - 124*x^11 + 42*x^12 + 9*x^13)*
              HPL[{0, 0}, x])/(2835*(-1 + x^2)^12) + 
            ((9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
               672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{1, 0}, x])/
             (2835*(-1 + x^2)^9)) - (2*(9 + 42*x - 97*x^2 + 672*x^3 - 
             1032*x^4 + 1512*x^5 - 1032*x^6 + 672*x^7 - 97*x^8 + 42*x^9 + 
             9*x^10)*HPL[{2, 0}, x])/(2835*(-1 + x^2)^9) + 
          (2*(-27 - 72*x + 543*x^2 - 23232*x^3 + 91008*x^4 - 381335*x^5 + 
             746590*x^6 - 1462230*x^7 + 1690495*x^8 - 1842530*x^9 + 
             1204797*x^10 - 791918*x^11 + 226222*x^12 - 88023*x^13 + 
             1392*x^14)*HPL[{-1, 0, 0}, x])/(2835*(-1 + x)^12*(1 + x)^10) + 
          (2*(-315 - 1470*x + 17255*x^2 + 702660*x^3 - 2401342*x^4 - 
             22578486*x^5 + 92300256*x^6 - 151445196*x^7 - 519337644*x^8 + 
             13837378674*x^9 - 33791581538*x^10 - 105614253108*x^11 + 
             681572840462*x^12 - 2912137311426*x^13 - 1975703943364*x^14 + 
             65969205226764*x^15 - 75897471543486*x^16 - 527325998606862*
              x^17 + 1017350522733360*x^18 + 1367756017427772*x^19 - 
             5036424843438594*x^20 + 5055897075629526*x^21 + 
             5622113660709672*x^22 - 33358950640188180*x^23 + 
             32478283736498700*x^24 + 17387204046501870*x^25 - 
             64136782301115222*x^26 + 114258463745163444*x^27 - 
             86818197760318926*x^28 + 59403437488138338*x^29 - 
             24613016262199236*x^30 + 7135025459735124*x^31 - 
             1301728195588455*x^32 - 68622257477844*x^33 + 190061762266017*
              x^34)*HPL[{0, 0, 0}, x])/(99225*(1 - 9*x^2)^8*(-1 + x^2)^13) - 
          (2*(-27 - 180*x + 39*x^2 - 18600*x^3 + 27378*x^4 - 208345*x^5 + 
             389380*x^6 - 1070370*x^7 + 1354075*x^8 - 1727050*x^9 + 
             1143057*x^10 - 776530*x^11 + 219796*x^12 - 84345*x^13 + 
             3282*x^14)*HPL[{1, 0, 0}, x])/(2835*(-1 + x)^10*(1 + x)^12) + 
          ((-1260 - 5880*x + 93731*x^2 + 1870848*x^3 - 7417689*x^4 - 
             124774440*x^5 + 407469435*x^6 + 3167164140*x^7 - 
             11491130833*x^8 - 27872219424*x^9 + 163461086551*x^10 - 
             235837620648*x^11 - 896529870261*x^12 + 7463736467040*x^13 - 
             5312418423137*x^14 - 65011309382796*x^15 + 109732130646699*
              x^16 + 197989239413448*x^17 - 610025036909895*x^18 + 
             441209866586832*x^19 + 897776607162501*x^20 - 3798795535159464*
              x^21 + 3229773873679521*x^22 + 2781230357468052*x^23 - 
             7660651912980003*x^24 + 12430579679484624*x^25 - 
             8767582858712691*x^26 + 5565512949029208*x^27 - 
             2161404791441847*x^28 + 447269659217136*x^29 - 
             71945445384315*x^30 - 37098498165876*x^31 + 21903432754293*x^32)*
            master3l8b[x])/(1190700*x^2*(1 - 9*x^2)^8*(-1 + x^2)^13) + 
          ((630 + 2940*x - 35911*x^2 - 885948*x^3 + 2559612*x^4 + 
             57059184*x^5 - 146688561*x^6 - 1319169012*x^7 + 3928288922*x^8 + 
             9913816248*x^9 - 49090027471*x^10 + 77953453704*x^11 + 
             216283550456*x^12 - 1839101004636*x^13 + 1085635596991*x^14 + 
             10997656653144*x^15 - 13888724329014*x^16 - 14809150843956*
              x^17 + 32163919198371*x^18 - 44973493178796*x^19 + 
             29373914667996*x^20 - 97750959535656*x^21 + 256027309605477*
              x^22 + 312845843288412*x^23 - 1238651997760026*x^24 + 
             2356804968477120*x^25 - 2246872878988173*x^26 + 
             1728304626890016*x^27 - 576462015234576*x^28 + 
             242855374820436*x^29 + 2433714750477*x^30)*master3l9b[x])/
           (1190700*x^2*(-1 + x^2)^13*(-1 + 9*x^2)^7) + 
          (-170100 - 793800*x + x^16*(51175140127946116 - 15291120910705920*
               Zeta[3]) + x^6*(83410207916 - 660360960*Zeta[3]) + 
            x^2*(15752859 - 362880*Zeta[3]) - 7056*x^5*(2794567 + 
              18000*Zeta[3]) - 42*x^3*(-6755809 + 40320*Zeta[3]) + 
            x^4*(-1487318909 + 31489920*Zeta[3]) + 420*x^7*(1352314955 + 
              74624256*Zeta[3]) - 129140163*x^36*(202727207 + 
              110194560*Zeta[3]) + 200884698*x^35*(-44743541 + 
              380661120*Zeta[3]) - 238085568*x^33*(-699108251 + 
              4555788300*Zeta[3]) - 12*x^8*(210900673073 + 4985830080*Zeta[
                3]) - 14348907*x^34*(-15926990089 + 8848103040*Zeta[3]) - 
            168*x^9*(37757014259 + 9445917600*Zeta[3]) + 
            3276*x^11*(-13895497909 + 11548010880*Zeta[3]) - 
            18816*x^13*(-119265335807 + 25732899450*Zeta[3]) + 
            1469664*x^29*(-21263296389757 + 188799093000*Zeta[3]) + 
            2520*x^17*(60842266615091 + 258824210400*Zeta[3]) + 
            2834352*x^32*(299869201903 + 1133499996720*Zeta[3]) + 
            756*x^14*(-2154298702903 + 2254289289280*Zeta[3]) + 
            x^10*(41490803952148 + 4062241935360*Zeta[3]) - 
            1653372*x^31*(1859197422493 + 4278840733440*Zeta[3]) + 
            236196*x^30*(47378568019187 + 27678458082240*Zeta[3]) - 
            4*x^12*(72193189306759 + 27873557832960*Zeta[3]) - 
            4200*x^19*(23116119823561 + 33511762626048*Zeta[3]) + 
            84*x^15*(-333803190107893 + 35630046869760*Zeta[3]) + 
            15120*x^21*(-191918515746019 + 58791633339600*Zeta[3]) + 
            102060*x^27*(-437622844538699 + 110285219737728*Zeta[3]) - 
            61236*x^28*(-657865668775481 + 143396592675840*Zeta[3]) - 
            5292*x^23*(-2016006970308491 + 340379137370880*Zeta[3]) - 
            4536*x^25*(-684732611498297 + 529223498445600*Zeta[3]) - 
            90*x^20*(-16915932575671537 + 908002251354240*Zeta[3]) - 
            756*x^22*(-365491482209321 + 1265595749305920*Zeta[3]) + 
            50*x^18*(-8677950043450547 + 1470096263131776*Zeta[3]) - 
            972*x^26*(-18566427502486427 + 4445489720689920*Zeta[3]) + 
            324*x^24*(-46971714766065269 + 13801425887027520*Zeta[3]))/
           (171460800*x^2*(1 - 9*x^2)^8*(-1 + x^2)^13))) + 
      CA*CF*((Pi^2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{-2}, x])/(5670*(-1 + x^2)^10) + 
        lm^2*((-11*(3 + 14*x - 102*x^2 + 1428*x^3 - 3399*x^4 + 7378*x^5 - 
             8124*x^6 + 7378*x^7 - 3399*x^8 + 1428*x^9 - 102*x^10 + 14*x^11 + 
             3*x^12))/(1260*(-1 + x^2)^10) + 
          (22*x^3*(1 - 3*x + 10*x^2 - 15*x^3 + 20*x^4 - 15*x^5 + 10*x^6 - 
             3*x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11)) - 
        (Pi^2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{2}, x])/(5670*(-1 + x^2)^10) + 
        (x*(-39095 + 326620*x - 2127335*x^2 + 4089330*x^3 - 32250960*x^4 + 
           52944150*x^5 - 103939290*x^6 + 95963350*x^7 - 139699770*x^8 + 
           84512246*x^9 + 24627456*x^10 - 61851594*x^11 - 84604807*x^12 + 
           96539820*x^13 + 87236441*x^14 - 105146822*x^15 - 64157940*x^16 + 
           85614760*x^17 + 30816940*x^18 - 51370088*x^19 - 7513352*x^20 + 
           22087296*x^21 - 836136*x^22 - 6447028*x^23 + 1275428*x^24 + 
           1145480*x^25 - 387100*x^26 - 93600*x^27 + 43200*x^28)*
          HPL[{-2, 0}, x])/(198450*(-1 + x^2)^12) + 
        ((-18144000 + 39312000*x + 135366000*x^2 - 422133600*x^3 - 
           325070760*x^4 + 2058171360*x^5 - 192075520*x^6 - 6015156280*x^7 + 
           2997577660*x^8 + 11712119440*x^9 - 8355101720*x^10 + 
           2*(-7974470951 + 132300*Pi^2)*x^11 + 3*(4469503963 + 411600*Pi^2)*
            x^12 - 40*(-374091149 + 863625*Pi^2)*x^13 + 
           4*(-2116218931 + 70074900*Pi^2)*x^14 - 
           8*(2489316686 + 91547925*Pi^2)*x^15 + 
           5*(8017295239 + 250170480*Pi^2)*x^16 - 
           30*(1077280223 + 33844300*Pi^2)*x^17 + 43908326360*x^18 + 
           30*(-1077280223 + 33844300*Pi^2)*x^19 - 
           5*(-8017295239 + 250170480*Pi^2)*x^20 + 
           8*(-2489316686 + 91547925*Pi^2)*x^21 - 
           4*(2116218931 + 70074900*Pi^2)*x^22 + 40*(374091149 + 863625*Pi^2)*
            x^23 - 3*(-4469503963 + 411600*Pi^2)*x^24 - 
           2*(7974470951 + 132300*Pi^2)*x^25 - 8355101720*x^26 + 
           11712119440*x^27 + 2997577660*x^28 - 6015156280*x^29 - 
           192075520*x^30 + 2058171360*x^31 - 325070760*x^32 - 
           422133600*x^33 + 135366000*x^34 + 39312000*x^35 - 18144000*x^36)*
          HPL[{-1, 0}, x])/(166698000*x^11*(-1 + x^2)^11) + 
        (x*(-4240937124887400 + 33640999260505560*x + 68152078657983600*x^2 - 
           1439033628552462180*x^3 + 1847188532808158085*x^4 + 
           13450669887999917790*x^5 + 30816995883391002285*x^6 + 
           251855983806854962500*x^7 - 4022084426927273862750*x^8 - 
           5295080710661780592036*x^9 + 94602175618185783319842*x^10 - 
           421133178232873576260*x^11 - 1020554099115296352638787*x^12 + 
           756076468175457092265222*x^13 + 4871180323137804360375933*x^14 - 
           6870451646867957814716460*x^15 + 1854336114849775281990192*x^16 + 
           10080420386398254622893264*x^17 - 115389986949562782618886560*
            x^18 + 163926378333082055317555752*x^19 + 
           318876242465636653379315706*x^20 - 865383828527303309564375140*
            x^21 + 511080741641162523622016554*x^22 + 
           810040883046010460150267976*x^23 - 2321977980240845126558308916*
            x^24 + 2224836750455186784849744840*x^25 - 
           1060384349982960467637066804*x^26 - 722133789145183794503189928*
            x^27 + 1548262274549933490151055330*x^28 - 
           613626005607037570535915748*x^29 - 684707986276786005345406654*
            x^30 + 642126752452202930797693000*x^31 + 
           256309382071036834477262784*x^32 - 394879107012750290405704504*
            x^33 - 106507585403831277298376296*x^34 + 
           209777130839272933348567820*x^35 + 34691399789547167156295281*
            x^36 - 94520463209430614398869498*x^37 - 
           4778031923172387137988135*x^38 + 34196214144773655798388404*x^39 - 
           1883815844161579630986558*x^40 - 9668023619759055900732420*x^41 + 
           1397928410484852561693858*x^42 + 2105042019253825241891052*x^43 - 
           459241451890231925447487*x^44 - 348529934077718601921570*x^45 + 
           96827968396511178187617*x^46 + 43228390756347695337444*x^47 - 
           14090152397816201981400*x^48 - 3933039089361603004560*x^49 + 
           1434861938096249047560*x^50 + 253994438059127987760*x^51 - 
           100684045609131393360*x^52 - 11003063477599509120*x^53 + 
           4646264196924367920*x^54 + 286420277454091200*x^55 - 
           127074436952652000*x^56 - 3384505391904000*x^57 + 
           1562079411648000*x^58)*HPL[{0, 0}, x])/(166698000*(-1 + x^2)^12*
          (9 - 82*x^2 + 9*x^4)^8) + ((18144000 - 39312000*x - 135366000*x^2 + 
           422133600*x^3 + 325070760*x^4 - 2058171360*x^5 + 192075520*x^6 + 
           6015156280*x^7 - 2997577660*x^8 - 11712119440*x^9 + 
           8355101720*x^10 + (15948941902 - 264600*Pi^2)*x^11 - 
           3*(4469503963 + 411600*Pi^2)*x^12 + 40*(-374091149 + 863625*Pi^2)*
            x^13 + (8464875724 - 280299600*Pi^2)*x^14 + 
           8*(2489316686 + 91547925*Pi^2)*x^15 - 
           5*(8017295239 + 250170480*Pi^2)*x^16 + 
           30*(1077280223 + 33844300*Pi^2)*x^17 - 43908326360*x^18 - 
           30*(-1077280223 + 33844300*Pi^2)*x^19 + 
           5*(-8017295239 + 250170480*Pi^2)*x^20 - 
           8*(-2489316686 + 91547925*Pi^2)*x^21 + 
           4*(2116218931 + 70074900*Pi^2)*x^22 - 40*(374091149 + 863625*Pi^2)*
            x^23 + 3*(-4469503963 + 411600*Pi^2)*x^24 + 
           2*(7974470951 + 132300*Pi^2)*x^25 + 8355101720*x^26 - 
           11712119440*x^27 - 2997577660*x^28 + 6015156280*x^29 + 
           192075520*x^30 - 2058171360*x^31 + 325070760*x^32 + 
           422133600*x^33 - 135366000*x^34 - 39312000*x^35 + 18144000*x^36)*
          HPL[{1, 0}, x])/(166698000*x^11*(-1 + x^2)^11) + 
        lm*(-(480699 + 1622235*x - 12807134*x^2 + 209026485*x^3 - 
             488130115*x^4 + 1071754080*x^5 - 1170326100*x^6 + 
             1071754080*x^7 - 488130115*x^8 + 209026485*x^9 - 12807134*x^10 + 
             1622235*x^11 + 480699*x^12 + 660*Pi^2*(-9 - 42*x + 106*x^2 - 630*
                x^3 + 935*x^4 - 840*x^5 + 840*x^7 - 935*x^8 + 630*x^9 - 106*
                x^10 + 42*x^11 + 9*x^12))/(4082400*(-1 + x^2)^10) + 
          (x^2*(198 + 492864*x - 1425484*x^2 + 5342361*x^3 - 8329302*x^4 + 
             12454182*x^5 - 10200402*x^6 + 7698561*x^7 - 2731096*x^8 + 
             1052808*x^9 - 41382*x^10 + 5544*x^11 + 1188*x^12)*HPL[{0}, x])/
           (11340*(-1 + x^2)^11) + (11*(9 + 42*x - 97*x^2 + 672*x^3 - 
             1032*x^4 + 1512*x^5 - 1032*x^6 + 672*x^7 - 97*x^8 + 42*x^9 + 
             9*x^10)*HPL[{-1, 0}, x])/(5670*(-1 + x^2)^9) - 
          (11*x^3*(3780 - 11340*x + 73710*x^2 - 147840*x^3 + 353850*x^4 - 
             425215*x^5 + 503160*x^6 - 327516*x^7 + 209412*x^8 - 57414*x^9 + 
             19446*x^10 - 124*x^11 + 42*x^12 + 9*x^13)*HPL[{0, 0}, x])/
           (2835*(-1 + x^2)^12) - (11*(9 + 42*x - 97*x^2 + 672*x^3 - 
             1032*x^4 + 1512*x^5 - 1032*x^6 + 672*x^7 - 97*x^8 + 42*x^9 + 
             9*x^10)*HPL[{1, 0}, x])/(5670*(-1 + x^2)^9)) + 
        (x*(39095 - 326620*x + 2127335*x^2 - 4089330*x^3 + 32250960*x^4 - 
           52944150*x^5 + 103939290*x^6 - 95963350*x^7 + 139699770*x^8 - 
           84512246*x^9 - 24627456*x^10 + 61851594*x^11 + 84604807*x^12 - 
           96539820*x^13 - 87236441*x^14 + 105146822*x^15 + 64157940*x^16 - 
           85614760*x^17 - 30816940*x^18 + 51370088*x^19 + 7513352*x^20 - 
           22087296*x^21 + 836136*x^22 + 6447028*x^23 - 1275428*x^24 - 
           1145480*x^25 + 387100*x^26 + 93600*x^27 - 43200*x^28)*
          HPL[{2, 0}, x])/(198450*(-1 + x^2)^12) - 
        (2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{-2, -1, 0}, x])/(945*(-1 + x^2)^10) + 
        (8*x^2*(-530 + 4473*x - 12571*x^2 + 25641*x^3 - 30306*x^4 + 
           26481*x^5 - 13506*x^6 + 5103*x^7 - 636*x^8 + 42*x^9 + 9*x^10)*
          HPL[{-2, 0, 0}, x])/(945*(-1 + x^2)^10) + 
        (2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{-2, 1, 0}, x])/(945*(-1 + x^2)^10) + 
        (2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{-1, -2, 0}, x])/(945*(-1 + x^2)^10) + 
        ((-10800 + 23400*x + 64375*x^2 - 216170*x^3 - 93332*x^4 + 
           893047*x^5 - 274887*x^6 - 2170773*x^7 + 1398048*x^8 + 
           3434892*x^9 - 2778762*x^10 - 3693648*x^11 + 3234168*x^12 + 
           2728580*x^13 - 2390131*x^14 - 1327854*x^15 + 862604*x^16 + 
           759726*x^17 - 1154466*x^18 + 759726*x^19 + 862604*x^20 - 
           1327854*x^21 - 2390131*x^22 + 2728580*x^23 + 3234168*x^24 - 
           3693648*x^25 - 2778762*x^26 + 3434892*x^27 + 1398048*x^28 - 
           2170773*x^29 - 274887*x^30 + 893047*x^31 - 93332*x^32 - 
           216170*x^33 + 64375*x^34 + 23400*x^35 - 10800*x^36)*
          HPL[{-1, -1, 0}, x])/(99225*x^13*(-1 + x^2)^9) - 
        ((39723 - 535016*x + 3898405*x^2 - 23201144*x^3 + 69626167*x^4 - 
           159051728*x^5 + 239008977*x^6 - 291332968*x^7 + 259468757*x^8 - 
           165666108*x^9 + 32185331*x^10 + 1125432*x^11 + 58077233*x^12 - 
           50321356*x^13 - 50875105*x^14 + 64372800*x^15 + 27322980*x^16 - 
           54860820*x^17 - 3216100*x^18 + 30476080*x^19 - 6365972*x^20 - 
           10230784*x^21 + 4740244*x^22 + 1586432*x^23 - 1466080*x^24 + 
           70300*x^25 + 180000*x^26 - 43200*x^27)*HPL[{-1, 0, 0}, x])/
         (198450*(-1 + x)^12*(1 + x)^10) + 
        ((10800 - 23400*x - 64375*x^2 + 216170*x^3 + 93332*x^4 - 893047*x^5 + 
           274887*x^6 + 2170773*x^7 - 1398048*x^8 - 3434892*x^9 + 
           2778762*x^10 + 3693648*x^11 - 3234168*x^12 - 2728580*x^13 + 
           2390131*x^14 + 1327854*x^15 - 862604*x^16 - 759726*x^17 + 
           1154466*x^18 - 759726*x^19 - 862604*x^20 + 1327854*x^21 + 
           2390131*x^22 - 2728580*x^23 - 3234168*x^24 + 3693648*x^25 + 
           2778762*x^26 - 3434892*x^27 - 1398048*x^28 + 2170773*x^29 + 
           274887*x^30 - 893047*x^31 + 93332*x^32 + 216170*x^33 - 
           64375*x^34 - 23400*x^35 + 10800*x^36)*HPL[{-1, 1, 0}, x])/
         (99225*x^13*(-1 + x^2)^9) - (2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 
           26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 26077*x^8 + 
           9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*HPL[{-1, 2, 0}, x])/
         (945*(-1 + x^2)^10) + (x*(1682911557495 - 13897203407640*x + 
           200907198326205*x^2 - 212696080395102*x^3 - 11795079698921358*
            x^4 + 43229803650842754*x^5 + 154127929731455115*x^6 - 
           1312810092330682986*x^7 + 2050905302899019199*x^8 + 
           17492354119002202542*x^9 - 80361374995033567371*x^10 - 
           98676406817179302816*x^11 + 913977932397443351064*x^12 + 
           4334250671988551028*x^13 - 4009433589192073906473*x^14 + 
           431086004040250990716*x^15 - 4963818043500625676170*x^16 + 
           34466727049337403844632*x^17 + 91439184494303683996402*x^18 - 
           345720858331328257138868*x^19 - 2816906895018531909284*x^20 + 
           1124705946757199978302476*x^21 - 1858701377887777911298682*x^22 - 
           87674402947120093489780*x^23 + 4598423346851065557800430*x^24 - 
           5043932903621867132452300*x^25 + 166250832516375537757754*x^26 + 
           3144808406209901985517912*x^27 - 404842664840083393365768*x^28 - 
           1515569410700368913522576*x^29 - 935624938344844284898426*x^30 + 
           1514965655534455673986384*x^31 + 1126461924497580576183915*x^32 - 
           1455932342616498111158048*x^33 - 720381957259915465365527*x^34 + 
           1051053571079927678230354*x^35 + 321662749900705659702322*x^36 - 
           590914318824060545777886*x^37 - 94439587491881901988641*x^38 + 
           263144007621252099625670*x^39 + 9955717681519490487611*x^40 - 
           92546112230058678862114*x^41 + 6037676269281983703737*x^42 + 
           25463778704420507376696*x^43 - 3856726518208400340576*x^44 - 
           5418943085484021470868*x^45 + 1206060274586036582307*x^46 + 
           880544694191961714660*x^47 - 247042389577272864120*x^48 - 
           107557631646220005264*x^49 + 35236626904779910344*x^50 + 
           9664598169760930704*x^51 - 3535290537534295344*x^52 - 
           617791053482217216*x^53 + 245230126804340496*x^54 + 
           26538075176691816*x^55 - 11213502957419976*x^56 - 
           685982214642960*x^57 + 304417801567800*x^58 + 8058346171200*x^59 - 
           3719236694400*x^60)*HPL[{0, 0, 0}, x])/(198450*(-1 + x^2)^12*
          (9 - 82*x^2 + 9*x^4)^8) - (2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 
           26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 26077*x^8 + 
           9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*HPL[{1, -2, 0}, x])/
         (945*(-1 + x^2)^10) + ((10800 - 23400*x - 64375*x^2 + 216170*x^3 + 
           93332*x^4 - 893047*x^5 + 274887*x^6 + 2170773*x^7 - 1398048*x^8 - 
           3434892*x^9 + 2778762*x^10 + 3693648*x^11 - 3234168*x^12 - 
           2728580*x^13 + 2390131*x^14 + 1327854*x^15 - 862604*x^16 - 
           759726*x^17 + 1154466*x^18 - 759726*x^19 - 862604*x^20 + 
           1327854*x^21 + 2390131*x^22 - 2728580*x^23 - 3234168*x^24 + 
           3693648*x^25 + 2778762*x^26 - 3434892*x^27 - 1398048*x^28 + 
           2170773*x^29 + 274887*x^30 - 893047*x^31 + 93332*x^32 + 
           216170*x^33 - 64375*x^34 - 23400*x^35 + 10800*x^36)*
          HPL[{1, -1, 0}, x])/(99225*x^13*(-1 + x^2)^9) + 
        ((39723 - 391244*x + 1975325*x^2 - 14082176*x^3 + 20996527*x^4 - 
           40327692*x^5 + 24717185*x^6 - 45554296*x^7 + 18078245*x^8 - 
           19300392*x^9 + 39480251*x^10 - 55311504*x^11 - 33575911*x^12 + 
           52633504*x^13 + 45331775*x^14 - 49683840*x^15 - 39505980*x^16 + 
           34829820*x^17 + 23550860*x^18 - 18545040*x^19 - 9270852*x^20 + 
           7516688*x^21 + 2216932*x^22 - 2246688*x^23 - 263280*x^24 + 
           444700*x^25 + 7200*x^26 - 43200*x^27)*HPL[{1, 0, 0}, x])/
         (198450*(-1 + x)^10*(1 + x)^12) + 
        ((-10800 + 23400*x + 64375*x^2 - 216170*x^3 - 93332*x^4 + 
           893047*x^5 - 274887*x^6 - 2170773*x^7 + 1398048*x^8 + 
           3434892*x^9 - 2778762*x^10 - 3693648*x^11 + 3234168*x^12 + 
           2728580*x^13 - 2390131*x^14 - 1327854*x^15 + 862604*x^16 + 
           759726*x^17 - 1154466*x^18 + 759726*x^19 + 862604*x^20 - 
           1327854*x^21 - 2390131*x^22 + 2728580*x^23 + 3234168*x^24 - 
           3693648*x^25 - 2778762*x^26 + 3434892*x^27 + 1398048*x^28 - 
           2170773*x^29 - 274887*x^30 + 893047*x^31 - 93332*x^32 - 
           216170*x^33 + 64375*x^34 + 23400*x^35 - 10800*x^36)*
          HPL[{1, 1, 0}, x])/(99225*x^13*(-1 + x^2)^9) + 
        (2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{1, 2, 0}, x])/(945*(-1 + x^2)^10) + 
        (2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{2, -1, 0}, x])/(945*(-1 + x^2)^10) - 
        (8*x^2*(-530 + 4473*x - 12571*x^2 + 25641*x^3 - 30306*x^4 + 
           26481*x^5 - 13506*x^6 + 5103*x^7 - 636*x^8 + 42*x^9 + 9*x^10)*
          HPL[{2, 0, 0}, x])/(945*(-1 + x^2)^10) - 
        (2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{2, 1, 0}, x])/(945*(-1 + x^2)^10) - 
        (4*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
           672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{-1, 0, 0, 0}, x])/
         (945*(-1 + x^2)^9) + (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 
           26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 26077*x^8 + 
           9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*HPL[{-1, 1, 0, 0}, x])/
         (945*(-1 + x^2)^10) + (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 
           26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 26077*x^8 + 
           9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*HPL[{1, -1, 0, 0}, x])/
         (945*(-1 + x^2)^10) + (4*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 
           1512*x^5 - 1032*x^6 + 672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*
          HPL[{1, 0, 0, 0}, x])/(945*(-1 + x^2)^9) - 
        ((9 + 104*x - 875*x^2 + 12709*x^3 - 33740*x^4 + 89488*x^5 - 
           115400*x^6 + 132280*x^7 - 80865*x^8 + 46942*x^9 - 8829*x^10 + 
           3175*x^11 + 300*x^12 + 62*x^13)*master3l10a[x])/
         (3780*(-1 + x^2)^11) + (x*(62 + 300*x + 3175*x^2 - 8829*x^3 + 
           46942*x^4 - 80865*x^5 + 132280*x^6 - 115400*x^7 + 89488*x^8 - 
           33740*x^9 + 12709*x^10 - 875*x^11 + 104*x^12 + 9*x^13)*
          master3l10b[x])/(3780*(-1 + x^2)^11) - 
        ((2479730278050 + 107524867458528*x + 272739750997968*x^2 - 
           1519550082742725*x^3 + 3255603196706424*x^4 - 4015435464536598*
            x^5 + 1173310093442790*x^6 + 988180886879388*x^7 - 
           1594643283954900*x^8 + 369202880391318*x^9 + 568578633023466*
            x^10 - 99950433863625*x^11 - 170075101414770*x^12 - 
           10526799805596*x^13 + 55398491076924*x^14 + 2635986284112*x^15 - 
           13722197311446*x^16 + 1079226908556*x^17 + 2169689517476*x^18 - 
           399787073607*x^19 - 211457735644*x^20 + 56160929682*x^21 + 
           12122806782*x^22 - 4139873196*x^23 - 350173720*x^24 + 
           159525150*x^25 + 2003074*x^26 - 2540907*x^27 + 84726*x^28)*
          master3l8a[x])/(4762800*(-9 + x^2)^8*(-1 + x^2)^12) + 
        ((156380 - 1214194*x - 10638647*x^2 + 96499398*x^3 + 311015182*x^4 - 
           3370020040*x^5 - 5394532284*x^6 + 68844209374*x^7 + 
           66713110046*x^8 - 924826205116*x^9 - 649191555475*x^10 + 
           8711417399528*x^11 + 4494848374108*x^12 - 59272377822830*x^13 - 
           12206920527600*x^14 + 284827641450396*x^15 - 104847499396392*
            x^16 - 842880359812698*x^17 + 1146422927274579*x^18 + 
           740616719699574*x^19 - 3927496519311930*x^20 + 3498609688771212*
            x^21 + 2464873800625260*x^22 - 7679846810516058*x^23 + 
           8543737901732238*x^24 - 4607477135054424*x^25 + 
           1964675498417847*x^26 - 269931963725892*x^27 + 
           50888378126448*x^28 + 1503430645770*x^29)*master3l8b[x])/
         (4762800*x*(1 - 9*x^2)^8*(-1 + x^2)^12) + 
        ((221286717990 + 8800735865832*x + 180575594892*x^2 + 
           25707049300377*x^3 - 75084043731012*x^4 + 254428696433133*x^5 - 
           369816933585294*x^6 + 220106226687273*x^7 + 64685140980318*x^8 - 
           173226732530337*x^9 + 79920313037982*x^10 + 38889946019460*x^11 - 
           47395268619528*x^12 - 2088578175726*x^13 + 13635310849348*x^14 - 
           763782810830*x^15 - 2540219635310*x^16 + 224806092278*x^17 + 
           322259313688*x^18 - 33298135807*x^19 - 27320295188*x^20 + 
           3126542673*x^21 + 1462579210*x^22 - 182295563*x^23 - 
           44168630*x^24 + 5886067*x^25 + 564734*x^26 - 78190*x^27)*
          master3l9a[x])/(1587600*(-9 + x^2)^7*(-1 + x^2)^12) + 
        ((-78190 + 564734*x + 5886067*x^2 - 44168630*x^3 - 182295563*x^4 + 
           1462579210*x^5 + 3126542673*x^6 - 27320295188*x^7 - 
           33298135807*x^8 + 322259313688*x^9 + 224806092278*x^10 - 
           2540219635310*x^11 - 763782810830*x^12 + 13635310849348*x^13 - 
           2088578175726*x^14 - 47395268619528*x^15 + 38889946019460*x^16 + 
           79920313037982*x^17 - 173226732530337*x^18 + 64685140980318*x^19 + 
           220106226687273*x^20 - 369816933585294*x^21 + 254428696433133*
            x^22 - 75084043731012*x^23 + 25707049300377*x^24 + 
           180575594892*x^25 + 8800735865832*x^26 + 221286717990*x^27)*
          master3l9b[x])/(4762800*x*(-1 + x^2)^12*(-1 + 9*x^2)^7) + 
        (HPL[{1}, x]*(Pi^2*(10800 - 23400*x - 75175*x^2 + 239570*x^3 + 
             157707*x^4 - 1109217*x^5 + 181555*x^6 + 3063820*x^7 - 
             1672935*x^8 - 5605665*x^9 + 4176810*x^10 + 7128540*x^11 - 
             6012930*x^12 - 6422228*x^13 + 5624299*x^14 + 4056434*x^15 - 
             3252735*x^16 - 2087580*x^17 + 2017070*x^18 - 2017070*x^20 + 
             2087580*x^21 + 3252735*x^22 - 4056434*x^23 - 5624299*x^24 + 
             6422228*x^25 + 6012930*x^26 - 7128540*x^27 - 4176810*x^28 + 
             5605665*x^29 + 1672935*x^30 - 3063820*x^31 - 181555*x^32 + 
             1109217*x^33 - 157707*x^34 - 239570*x^35 + 75175*x^36 + 
             23400*x^37 - 10800*x^38) - 2520*x^13*(9 + 42*x - 1166*x^2 + 
             9576*x^3 - 26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 
             26077*x^8 + 9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*Zeta[3]))/
         (1190700*x^13*(-1 + x^2)^10) + 
        (HPL[{-1}, x]*(Pi^2*(-10800 + 23400*x + 75175*x^2 - 239570*x^3 - 
             157707*x^4 + 1109217*x^5 - 181555*x^6 - 3063820*x^7 + 
             1672935*x^8 + 5605665*x^9 - 4176810*x^10 - 7128540*x^11 + 
             6012930*x^12 + 6422228*x^13 - 5624299*x^14 - 4056434*x^15 + 
             3252735*x^16 + 2087580*x^17 - 2017070*x^18 + 2017070*x^20 - 
             2087580*x^21 - 3252735*x^22 + 4056434*x^23 + 5624299*x^24 - 
             6422228*x^25 - 6012930*x^26 + 7128540*x^27 + 4176810*x^28 - 
             5605665*x^29 - 1672935*x^30 + 3063820*x^31 + 181555*x^32 - 
             1109217*x^33 + 157707*x^34 + 239570*x^35 - 75175*x^36 - 
             23400*x^37 + 10800*x^38) + 2520*x^13*(9 + 42*x - 1166*x^2 + 
             9576*x^3 - 26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 
             26077*x^8 + 9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*Zeta[3]))/
         (1190700*x^13*(-1 + x^2)^10) + (HPL[{0}, x]*(4686238234944000 - 
           10153516175712000*x - 378880191740484000*x^2 + 854184074274417600*
            x^3 + 13749743014755773760*x^4 - 32582944522009294560*x^5 - 
           295208643409401544200*x^6 + 745762600859394862800*x^7 + 
           4158111641491906920360*x^8 - 11428915889968861115160*x^9 + 
           115736040*(-347474810090122 + 12214395*Pi^2)*x^10 - 
           38263752*(-3241472441625937 + 308655900*Pi^2)*x^11 + 
           1960*(-1211738113803029625482495 + 14433044114554743432696*Pi^2)*
            x^33 - 4374*(28358775921974525361 + 520337134551299597840*Pi^2)*
            x^55 + 8505*(4728557488915486791 + 59558511238393924280*Pi^2)*
            x^56 + 918540*(12442542181809957 + 402626738019177412*Pi^2)*
            x^57 - 612360*(6790305770285301 + 169439224675770140*Pi^2)*x^58 - 
           2678462640*(278429345895 + 16865721633292*Pi^2)*x^59 + 
           5511240*(53564831763705 + 2685309168174052*Pi^2)*x^60 + 
           12499492320*(2606741433 + 324743687774*Pi^2)*x^61 - 
           2777664960*(4950108531 + 534557640013*Pi^2)*x^62 - 
           10713850560*(79727085 + 24218392912*Pi^2)*x^63 + 
           1785641760*(212181525 + 57680468482*Pi^2)*x^64 + 
           433910947680*(23400 + 25687279*Pi^2)*x^65 - 16070775840*
            (291600 + 293058113*Pi^2)*x^66 - 288112530150043200*Pi^2*x^67 + 
           127855476658476000*Pi^2*x^68 + 3384505391904000*Pi^2*x^69 - 
           1562079411648000*Pi^2*x^70 + 6*x^52*(422656208858721607649600*
              Pi^2 + 243*(853196022613496855807 - 15093136976400000*
                Zeta[3])) + 588*x^49*(187957352571838179813340*Pi^2 + 
             2187*(20322341482942312993 - 1639854030528000*Zeta[3])) + 
           8*x^29*(-327880091902554599643562367 + 4941237788495503198622100*
              Pi^2 - 14698346468908950619128000*Zeta[3]) - 
           28*x^31*(-221265885593123189155979939 + 1168675772350453149134520*
              Pi^2 - 7712233998878843542080000*Zeta[3]) + 
           50*x^38*(-91952104674827736021082093 + 11774229026359704526583304*
              Pi^2 - 1232259948318484285804800*Zeta[3]) + 
           112*x^26*(2278629066382316954165924 + 49745803993578972210705*
              Pi^2 - 206946393610008178224000*Zeta[3]) - 
           36*x^36*(-69024443493835606152337813 + 13980157839585360011455440*
              Pi^2 - 153485133864211567152000*Zeta[3]) - 
           45*x^24*(6393533493673672177397809 + 30968958602548795288488*
              Pi^2 - 78154137465273247795200*Zeta[3]) - 
           24*x^43*(10961809872889925981569271 + 26712566735323554600574220*
              Pi^2 - 75481000808260912704000*Zeta[3]) + 
           3*x^22*(37314370585648516876063489 + 56042253414865206011880*
              Pi^2 - 32898328863454351584000*Zeta[3]) + 
           360*x^42*(655418318972039249828213 + 1337676578994781594178883*
              Pi^2 - 9769267183159155974400*Zeta[3]) - 
           24*x^44*(6232823594820630507680558 + 12351789729156928517252555*
              Pi^2 - 4112291107931793948000*Zeta[3]) + 
           84*x^45*(2470399530806774725232757 + 5300670283104910316395100*
              Pi^2 - 4000139520759831960000*Zeta[3]) - 
           126*x^47*(696498963541169839693273 + 1971503237098847717654760*
              Pi^2 - 275055333338939328000*Zeta[3]) - 
           90*x^18*(40510443688862907070981 + 1606823294056966440*Pi^2 - 
             86541107542083936000*Zeta[3]) + 81*x^16*
            (44116578234835761107891 + 463855004135082000*Pi^2 - 
             7170893746623936000*Zeta[3]) - 729*x^14*
            (1707656881622750558989 + 1568640163204800*Pi^2 - 
             30186273952800000*Zeta[3]) + 2916*x^53*(337757010934515955353 + 
             3667600184198374493300*Pi^2 - 354360607272000*Zeta[3]) - 
           52488*x^12*(-5157333220283556079 + 497565846225*Pi^2 + 
             6562233468000*Zeta[3]) + 78732*x^13*(-12503618468028139889 + 
             9055720012500*Pi^2 + 13124466936000*Zeta[3]) - 
           65610*x^15*(-88860576721566395737 + 284748231652920*Pi^2 + 
             1084955933376000*Zeta[3]) + 61236*x^17*(-426221897052430206823 + 
             4857312198910500*Pi^2 + 34436934641088000*Zeta[3]) + 
           6*x^50*(-587179085454114314584491 + 695655802048886635758200*
              Pi^2 + 96807065579423136000*Zeta[3]) - 
           252*x^19*(-352862024926611390167219 + 14837050154686847220*Pi^2 + 
             137527666669469664000*Zeta[3]) - 45*x^48*
            (-59841818098048326367667 + 878164454902074830980560*Pi^2 + 
             173082215084167872000*Zeta[3]) + 252*x^21*
            (-910756226724728164309709 + 177951833441351248860*Pi^2 + 
             1333379840253277320000*Zeta[3]) - 18*x^20*
            (1058458835751957823677217 + 482363294441180730480*Pi^2 + 
             2575753198497008208000*Zeta[3]) + 
           3*x^46*(9364580477654836547683077 + 44555386331761549147967840*
              Pi^2 + 15454519190982049248000*Zeta[3]) + 
           36*x^25*(-16867946527176620360034049 + 97686374036616597741180*
              Pi^2 + 92815840127357504640000*Zeta[3]) - 
           6*x^23*(-72922370990093607995512859 + 78284036509092559761840*
              Pi^2 + 301924003233043650816000*Zeta[3]) - 
           18*x^30*(38510807201816412782310701 + 555553159842551550172080*
              Pi^2 + 306970267728423134304000*Zeta[3]) - 
           36*x^39*(12202040586395557821771991 + 19773851175953973917087360*
              Pi^2 + 496977184782127050624000*Zeta[3]) - 
           56*x^35*(237433188464398543493499907 + 5347770135745537538924340*
              Pi^2 + 3856116999439421771040000*Zeta[3]) + 
           36*x^34*(386914401051308140595512461 + 9837743932814674249991240*
              Pi^2 + 7052983723389082604832000*Zeta[3]) + 
           8*x^37*(817197063737294644940492717 + 69347172387353299851891780*
              Pi^2 + 14698346468908950619128000*Zeta[3]) + 
           x^27*(885921940359007341456877136 - 16290797016102598481056320*
              Pi^2 + 17891178652156573822464000*Zeta[3]) + 
           x^40*(922354234977084667030584262 - 597503427205838449307711280*
              Pi^2 + 23177996084320915961088000*Zeta[3]) - 
           6*x^32*(1074051311293803699602946191 + 7544742763929630668760960*
              Pi^2 + 42317902340334495628992000*Zeta[3]) - 
           27*x^54*(59993335625725760850200*Pi^2 - 
             243*(-41262502770044967857 + 52497867744000*Zeta[3])) - 
           60*x^51*(647804543129322282961684*Pi^2 - 
             2187*(-44493980286619166239 + 542477966688000*Zeta[3])) + 
           96*x^41*(7780228675429914187378825*Pi^2 - 
             384*(1133791801120381598029 + 90640468874372563125*Zeta[3])) - 
           400*x^28*(17475799158861274043589*Pi^2 - 
             2*(773549918668352697072709 + 77016246769905267862800*
                Zeta[3]))))/(2000376000*x^9*(-1 + x^2)^12*
          (9 - 82*x^2 + 9*x^4)^8) + (70560*Pi^4*x^11*(-1 + x^2)^2*
           (9 - 82*x^2 + 9*x^4)^8*(-27 - 126*x - 4982*x^2 + 42840*x^3 - 
            122905*x^4 + 253890*x^5 - 303060*x^6 + 267330*x^7 - 137865*x^8 + 
            52920*x^9 - 6678*x^10 + 546*x^11 + 117*x^12) + 
          12*Pi^2*(9 - 82*x^2 + 9*x^4)^8*(-18144000 + 39312000*x + 
            153510000*x^2 - 461445600*x^3 - 460436760*x^4 + 2480304960*x^5 + 
            132995240*x^6 - 8073327640*x^7 + 3189653180*x^8 + 
            17727275720*x^9 - 11352679380*x^10 - 27661061342*x^11 + 
            21763613609*x^12 + 30912587862*x^13 - 21873387613*x^14 - 
            34878179448*x^15 + 48551351919*x^16 - 12403873202*x^17 + 
            3821850165*x^18 - 3821850165*x^20 + 12403873202*x^21 - 
            48551351919*x^22 + 34878179448*x^23 + 21873387613*x^24 - 
            30912587862*x^25 - 21763613609*x^26 + 27661061342*x^27 + 
            11352679380*x^28 - 17727275720*x^29 - 3189653180*x^30 + 
            8073327640*x^31 - 132995240*x^32 - 2480304960*x^33 + 
            460436760*x^34 + 461445600*x^35 - 153510000*x^36 - 
            39312000*x^37 + 18144000*x^38) + x^2*(-14058714704832000 + 
            30460548527136000*x + 1141326813456396000*x^2 - 
            2572705738998964800*x^3 - 41626351896669701280*x^4 + 
            98599210071736409280*x^5 + 899234569470690004860*x^6 - 
            2269552543388210916360*x^7 - 12764433899496006304920*x^8 + 
            x^41*(5372631973308210530172340762 - 
              25539619557458079573655397760*Zeta[3]) + 
            x^29*(1875786515475674901631062544 - 3057258981140424743008112640*
               Zeta[3]) + x^52*(4000733134451335113128019 - 
              91291824087221022450353280*Zeta[3]) + 10372051085401555200*x^67*
             Zeta[3] - 4602797159705136000*x^68*Zeta[3] - 121842194108544000*
             x^69*Zeta[3] + 56234858819328000*x^70*Zeta[3] - 
            15620794116480*x^65*(-1950 + 25687279*Zeta[3]) - 
            1004423490*x^9*(-34866026029027 + 70137792*Zeta[3]) + 
            578547930240*x^66*(-24300 + 293058113*Zeta[3]) + 
            96424655040*x^63*(-26680995 + 96873571648*Zeta[3]) - 
            6200145*x^10*(-20112821636615333 + 165375971136*Zeta[3]) - 
            16070775840*x^64*(-71018775 + 230721873928*Zeta[3]) + 
            3188646*x^11*(-120182152659595819 + 3743256041280*Zeta[3]) - 
            32141551680*x^61*(-3067655571 + 4546411628836*Zeta[3]) + 
            84371573160*x^59*(-26899493021 + 19275110438048*Zeta[3]) + 
            1785641760*x^62*(-23311703853 + 29935227840728*Zeta[3]) - 
            1417176*x^13*(-2167630260525433679 + 358661668493520*Zeta[3]) + 
            19683*x^12*(-43258615574569828289 + 583094007599040*Zeta[3]) - 
            173604060*x^60*(-5179801494681 + 3068924763627488*Zeta[3]) + 
            170586*x^15*(-107905875028462545473 + 47737331717483520*Zeta[
                3]) + 26244*x^17*(3188014669160108159707 + 158365884079569600*
               Zeta[3]) + 2187*x^14*(1836635808922635439687 + 
              868896016205333760*Zeta[3]) + 2755620*x^58*(-4632157447879041 + 
              1355513797406161120*Zeta[3]) - 4133430*x^57*
             (-8472440711429721 + 3221013919014451712*Zeta[3]) - 
            11907*x^16*(1043777474425855878929 + 6769397416843330560*Zeta[
                3]) - 76545*x^56*(-1629053469505135503 + 
              238234057134197748416*Zeta[3]) + 39366*x^55*
             (-9734926405262658489 + 2081348810748146018240*Zeta[3]) - 
            52488*x^53*(-58538542621057619733 + 7335209003434220075440*Zeta[
                3]) + 5103*x^22*(-12037353101809601092479 + 
              13747142527940811465280*Zeta[3]) - 54*x^19*
             (5435151920763496877370193 + 39409560420304375728000*Zeta[3]) - 
            405*x^24*(-1017448614735900120851663 + 41862805411023123846592*
               Zeta[3]) + 27*x^18*(796255197756863439034501 + 
              54742914984738881174400*Zeta[3]) + 360*x^21*
             (2290283565196279170555221 + 97984484413218708079824*Zeta[3]) + 
            243*x^54*(-3501806909633466735159 + 239973375489117043538240*Zeta[
                3]) - 189*x^50*(64318658428420190268777 + 
              795457175831682748343680*Zeta[3]) - 
            9*x^20*(740477328569539001007097 + 1612676705196240524050560*Zeta[
                3]) + 2646*x^36*(-3673984480400447169179219 + 
              1649124752522793960989120*Zeta[3]) - 18*x^23*
             (110604733992767547453860263 + 15929444466231623176409280*Zeta[
                3]) + 54*x^51*(-341352929783294329308957 + 
              25912308542165701635226240*Zeta[3]) - 378*x^30*
             (8605961069905166187089883 + 35628440595690236510056960*Zeta[
                3]) - 108*x^49*(-779959851740802391364001 + 
              36839429333340650710637440*Zeta[3]) - 360*x^45*
             (-2481466889569937270746901 + 44422620282267090201434544*Zeta[
                3]) + 27*x^48*(689157274267254009239251 + 
              52744294895738462348371200*Zeta[3]) + 189*x^44*
             (-927540791413999069682883 + 56861185976039001701972800*Zeta[
                3]) - 135*x^42*(-7153810976278770731761079 + 
              128854789917629954962768320*Zeta[3]) + 
            54*x^47*(-5579907085452817087144243 + 165563248742045223121140480*
               Zeta[3]) - 4*x^27*(1545472771187833603642862959 + 
              525369645516855632957331840*Zeta[3]) - 
            9*x^46*(-1570845686172618410067353 + 536298006397188319522022400*
               Zeta[3]) + 2*x^25*(2114072919659475620978035181 + 
              617172109796691631204606080*Zeta[3]) - 
            2*x^26*(1277331935017671104880796177 + 
              806416103152641652200472320*Zeta[3]) + 
            18*x^43*(-131646173850138367365268213 + 
              1265380588449398196145809600*Zeta[3]) - 
            16*x^37*(217377917664453793372720991 + 
              1359041063837840016283727280*Zeta[3]) - 
            8*x^33*(-1915295486451479627185831453 + 
              2349593244639359297096711760*Zeta[3]) + 
            2*x^32*(-5058538992250073946526127167 + 
              3138106488452224724530045440*Zeta[3]) + 
            4*x^31*(455518065525412761832869151 + 
              4017735859796771475574592640*Zeta[3]) - 
            2*x^34*(9381173938356606926433728617 + 
              4160344720655069995736237760*Zeta[3]) + 
            4*x^39*(-1749359550125975316958364209 + 
              5749204751199572195084771520*Zeta[3]) + 
            4*x^35*(3639685567995935301048854101 + 
              6455212431300719899616784960*Zeta[3]) - 
            2*x^38*(-6948200052967688802473393453 + 
              6823039203800442568745956800*Zeta[3]) + 
            x^28*(7360175074463060302368459406 + 7777235784697872210325843200*
               Zeta[3]) + x^40*(-4903715957460426777691385954 + 
              20073687684486310732047523200*Zeta[3])))/(24004512000*x^11*
          (-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8)) + 
      CF^2*(-(Pi^2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
            60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
            42*x^11 + 9*x^12)*HPL[{-2}, x])/(2835*(-1 + x^2)^10) + 
        lm^2*((2*(3 + 14*x - 102*x^2 + 1428*x^3 - 3399*x^4 + 7378*x^5 - 
             8124*x^6 + 7378*x^7 - 3399*x^8 + 1428*x^9 - 102*x^10 + 14*x^11 + 
             3*x^12))/(35*(-1 + x^2)^10) - (48*x^3*(1 - 3*x + 10*x^2 - 
             15*x^3 + 20*x^4 - 15*x^5 + 10*x^6 - 3*x^7 + x^8)*HPL[{0}, x])/
           (-1 + x^2)^11) + (Pi^2*(9 + 42*x - 1166*x^2 + 9576*x^3 - 
           26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 26077*x^8 + 
           9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*HPL[{2}, x])/
         (2835*(-1 + x^2)^10) + (x*(39095 - 326620*x + 4055765*x^2 - 
           8269380*x^3 + 51904440*x^4 - 81820620*x^5 + 121853760*x^6 - 
           92976240*x^7 + 264730550*x^8 - 224881944*x^9 - 299131287*x^10 + 
           392247345*x^11 + 696903382*x^12 - 769582684*x^13 - 
           982396957*x^14 + 1095683448*x^15 + 1000256202*x^16 - 
           1173557010*x^17 - 714379413*x^18 + 942174727*x^19 + 
           333083927*x^20 - 559212538*x^21 - 76891716*x^22 + 238370276*x^23 - 
           11233998*x^24 - 69088470*x^25 + 14260450*x^26 + 12203550*x^27 - 
           4210650*x^28 - 992250*x^29 + 463050*x^30)*HPL[{-2, 0}, x])/
         (99225*(-1 + x^2)^12) + ((-194481000 + 416745000*x + 
           1476751500*x^2 - 4500373500*x^3 - 3693228000*x^4 + 
           22092953400*x^5 - 1428772590*x^6 - 65118294570*x^7 + 
           31631646760*x^8 + 128167575480*x^9 - 91719648650*x^10 - 
           177184366870*x^11 + 149385574870*x^12 - 
           8*(-22014192626 + 33075*Pi^2)*x^13 - 63*(2527743929 + 19600*Pi^2)*
            x^14 + 30*(-4205988011 + 1151500*Pi^2)*x^15 - 
           112*(-976456421 + 2502675*Pi^2)*x^16 + 
           (76456443502 + 732383400*Pi^2)*x^17 - 
           35*(2865242327 + 35738640*Pi^2)*x^18 + 
           20*(1637069149 + 50766450*Pi^2)*x^19 - 38287998140*x^20 - 
           20*(-1637069149 + 50766450*Pi^2)*x^21 + 
           35*(-2865242327 + 35738640*Pi^2)*x^22 + 
           (76456443502 - 732383400*Pi^2)*x^23 + 
           112*(976456421 + 2502675*Pi^2)*x^24 - 
           30*(4205988011 + 1151500*Pi^2)*x^25 + 
           63*(-2527743929 + 19600*Pi^2)*x^26 + 8*(22014192626 + 33075*Pi^2)*
            x^27 + 149385574870*x^28 - 177184366870*x^29 - 91719648650*x^30 + 
           128167575480*x^31 + 31631646760*x^32 - 65118294570*x^33 - 
           1428772590*x^34 + 22092953400*x^35 - 3693228000*x^36 - 
           4500373500*x^37 + 1476751500*x^38 + 416745000*x^39 - 
           194481000*x^40)*HPL[{-1, 0}, x])/(83349000*x^13*(-1 + x^2)^11) + 
        (x*(4240937124887400 - 34299422964364320*x + 277114912246504080*x^2 + 
           569906647583812560*x^3 - 20613853625097294765*x^4 + 
           40080536533186548210*x^5 + 341715654682309811295*x^6 - 
           1543909830341468478210*x^7 + 1736679222969298582590*x^8 + 
           19686475703329861083084*x^9 - 122189224198824606675726*x^10 - 
           38485237127079879627120*x^11 + 1567102570335594112001391*x^12 - 
           1546493912163466453310598*x^13 - 7643316926869970266889829*x^14 + 
           15663956116971226816440180*x^15 - 9941815437959423874249576*x^16 - 
           37527737069362389761122356*x^17 + 264362116439715058113316380*
            x^18 - 245536097858333473926625428*x^19 - 
           925434032716370259344324118*x^20 + 1641116645938706266547471240*
            x^21 + 326215718294513125332658698*x^22 - 
           2534467697725844686906997764*x^23 + 1949800638083036869808760908*
            x^24 - 922926116315963704383569760*x^25 + 
           3878701331023873114949310612*x^26 - 2137924135915326056426300528*
            x^27 - 6055230978088564059120435130*x^28 + 
           5321009841937051733807609492*x^29 + 5449129257653680773186488462*
            x^30 - 6109660578066639111744583600*x^31 - 
           4231953672613633574824173552*x^32 + 5381003346709020139945746296*
            x^33 + 2676595174458201795178654848*x^34 - 
           3855748605243164155649359320*x^35 - 1257121589590167638065793393*
            x^36 + 2224316045952389046615221922*x^37 + 
           390035861144408002313721435*x^38 - 1020726047356677000177233346*
            x^39 - 47413605613290654675909426*x^40 + 
           368867732224435147370969100*x^41 - 22856810275630835297439534*
            x^42 - 103884103389082831414863408*x^43 + 
           15771237778988954519445531*x^44 + 22543706768332281419558610*
            x^45 - 5077459142627181262541001*x^46 - 3722875578514168759586196*
            x^47 + 1059499452447941147052480*x^48 + 460813192726268815983900*
            x^49 - 153172621527804863476380*x^50 - 41858400769313190112260*
            x^51 + 15527611963600035141780*x^52 + 2699696589341440775940*
            x^53 - 1085932038284269277220*x^54 - 116827942519867357800*x^55 + 
           49984232103574839000*x^56 + 3038512938054237000*x^57 - 
           1364300089752033000*x^58 - 35879011486290000*x^59 + 
           16743538693602000*x^60)*HPL[{0, 0}, x])/(83349000*(-1 + x^2)^12*
          (9 - 82*x^2 + 9*x^4)^8) + ((194481000 - 416745000*x - 
           1476751500*x^2 + 4500373500*x^3 + 3693228000*x^4 - 
           22092953400*x^5 + 1428772590*x^6 + 65118294570*x^7 - 
           31631646760*x^8 - 128167575480*x^9 + 91719648650*x^10 + 
           177184366870*x^11 - 149385574870*x^12 + 
           8*(-22014192626 + 33075*Pi^2)*x^13 + 63*(2527743929 + 19600*Pi^2)*
            x^14 - 30*(-4205988011 + 1151500*Pi^2)*x^15 + 
           112*(-976456421 + 2502675*Pi^2)*x^16 - 
           2*(38228221751 + 366191700*Pi^2)*x^17 + 
           35*(2865242327 + 35738640*Pi^2)*x^18 - 
           20*(1637069149 + 50766450*Pi^2)*x^19 + 38287998140*x^20 + 
           20*(-1637069149 + 50766450*Pi^2)*x^21 - 
           35*(-2865242327 + 35738640*Pi^2)*x^22 + 
           (-76456443502 + 732383400*Pi^2)*x^23 - 
           112*(976456421 + 2502675*Pi^2)*x^24 + 
           30*(4205988011 + 1151500*Pi^2)*x^25 - 
           63*(-2527743929 + 19600*Pi^2)*x^26 - 8*(22014192626 + 33075*Pi^2)*
            x^27 - 149385574870*x^28 + 177184366870*x^29 + 91719648650*x^30 - 
           128167575480*x^31 - 31631646760*x^32 + 65118294570*x^33 + 
           1428772590*x^34 - 22092953400*x^35 + 3693228000*x^36 + 
           4500373500*x^37 - 1476751500*x^38 - 416745000*x^39 + 
           194481000*x^40)*HPL[{1, 0}, x])/(83349000*x^13*(-1 + x^2)^11) + 
        lm*((19584 + 34935*x - 344344*x^2 + 7523235*x^3 - 17052140*x^4 + 
            38123130*x^5 - 41087400*x^6 + 38123130*x^7 - 17052140*x^8 + 
            7523235*x^9 - 344344*x^10 + 34935*x^11 + 19584*x^12 + 
            60*Pi^2*(-9 - 42*x + 106*x^2 - 630*x^3 + 935*x^4 - 840*x^5 + 
              840*x^7 - 935*x^8 + 630*x^9 - 106*x^10 + 42*x^11 + 9*x^12))/
           (56700*(-1 + x^2)^10) - (2*x^2*(18 + 26049*x - 73319*x^2 + 
             298101*x^3 - 475857*x^4 + 757062*x^5 - 645957*x^6 + 512301*x^7 - 
             192011*x^8 + 76953*x^9 - 3762*x^10 + 504*x^11 + 108*x^12)*
            HPL[{0}, x])/(315*(-1 + x^2)^11) - 
          (4*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
             672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{-1, 0}, x])/
           (315*(-1 + x^2)^9) + (8*x^3*(3780 - 11340*x + 73710*x^2 - 
             147840*x^3 + 353850*x^4 - 425215*x^5 + 503160*x^6 - 327516*x^7 + 
             209412*x^8 - 57414*x^9 + 19446*x^10 - 124*x^11 + 42*x^12 + 
             9*x^13)*HPL[{0, 0}, x])/(315*(-1 + x^2)^12) + 
          (4*(9 + 42*x - 97*x^2 + 672*x^3 - 1032*x^4 + 1512*x^5 - 1032*x^6 + 
             672*x^7 - 97*x^8 + 42*x^9 + 9*x^10)*HPL[{1, 0}, x])/
           (315*(-1 + x^2)^9)) + (x*(-39095 + 326620*x - 4055765*x^2 + 
           8269380*x^3 - 51904440*x^4 + 81820620*x^5 - 121853760*x^6 + 
           92976240*x^7 - 264730550*x^8 + 224881944*x^9 + 299131287*x^10 - 
           392247345*x^11 - 696903382*x^12 + 769582684*x^13 + 
           982396957*x^14 - 1095683448*x^15 - 1000256202*x^16 + 
           1173557010*x^17 + 714379413*x^18 - 942174727*x^19 - 
           333083927*x^20 + 559212538*x^21 + 76891716*x^22 - 238370276*x^23 + 
           11233998*x^24 + 69088470*x^25 - 14260450*x^26 - 12203550*x^27 + 
           4210650*x^28 + 992250*x^29 - 463050*x^30)*HPL[{2, 0}, x])/
         (99225*(-1 + x^2)^12) + (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 
           26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 26077*x^8 + 
           9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*HPL[{-2, -1, 0}, x])/
         (945*(-1 + x^2)^10) - (8*(9 + 42*x - 1166*x^2 + 9576*x^3 - 
           26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 26077*x^8 + 
           9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*HPL[{-2, 0, 0}, x])/
         (945*(-1 + x^2)^10) - (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 
           26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 26077*x^8 + 
           9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*HPL[{-2, 1, 0}, x])/
         (945*(-1 + x^2)^10) - (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 
           26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 26077*x^8 + 
           9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*HPL[{-1, -2, 0}, x])/
         (945*(-1 + x^2)^10) + ((-463050 + 992250*x + 1895400*x^2 - 
           7242300*x^3 - 152950*x^4 + 22954470*x^5 - 13115252*x^6 - 
           41252426*x^7 + 34114206*x^8 + 46021458*x^9 - 42829927*x^10 - 
           32794727*x^11 + 30595348*x^12 + 14829885*x^13 - 12414822*x^14 - 
           4132893*x^15 + 2528750*x^16 + 673283*x^17 - 462406*x^18 + 
           673283*x^19 + 2528750*x^20 - 4132893*x^21 - 12414822*x^22 + 
           14829885*x^23 + 30595348*x^24 - 32794727*x^25 - 42829927*x^26 + 
           46021458*x^27 + 34114206*x^28 - 41252426*x^29 - 13115252*x^30 + 
           22954470*x^31 - 152950*x^32 - 7242300*x^33 + 1895400*x^34 + 
           992250*x^35 - 463050*x^36)*HPL[{-1, -1, 0}, x])/
         (198450*x^15*(-1 + x^2)^7) + ((29074 - 584676*x + 4490242*x^2 - 
           26624323*x^3 + 81143531*x^4 - 180383930*x^5 + 261901825*x^6 - 
           324614446*x^7 + 325131435*x^8 - 168729160*x^9 - 144011663*x^10 + 
           60043008*x^11 + 455028219*x^12 - 294104424*x^13 - 633037951*x^14 + 
           577323586*x^15 + 574125981*x^16 - 725319346*x^17 - 
           297044299*x^18 + 605028531*x^19 + 29161964*x^20 - 330268532*x^21 + 
           72162562*x^22 + 109051692*x^23 - 51895670*x^24 - 16494350*x^25 + 
           15795900*x^26 - 837000*x^27 - 1918350*x^28 + 463050*x^29)*
          HPL[{-1, 0, 0}, x])/(99225*(-1 + x)^12*(1 + x)^10) + 
        ((463050 - 992250*x - 1895400*x^2 + 7242300*x^3 + 152950*x^4 - 
           22954470*x^5 + 13115252*x^6 + 41252426*x^7 - 34114206*x^8 - 
           46021458*x^9 + 42829927*x^10 + 32794727*x^11 - 30595348*x^12 - 
           14829885*x^13 + 12414822*x^14 + 4132893*x^15 - 2528750*x^16 - 
           673283*x^17 + 462406*x^18 - 673283*x^19 - 2528750*x^20 + 
           4132893*x^21 + 12414822*x^22 - 14829885*x^23 - 30595348*x^24 + 
           32794727*x^25 + 42829927*x^26 - 46021458*x^27 - 34114206*x^28 + 
           41252426*x^29 + 13115252*x^30 - 22954470*x^31 + 152950*x^32 + 
           7242300*x^33 - 1895400*x^34 - 992250*x^35 + 463050*x^36)*
          HPL[{-1, 1, 0}, x])/(198450*x^15*(-1 + x^2)^7) + 
        (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{-1, 2, 0}, x])/(945*(-1 + x^2)^10) + 
        (x*(1682911557495 - 14222636618400*x - 462923819390970*x^2 + 
           1811456304745518*x^3 + 19003563398480157*x^4 - 65344537349425764*
            x^5 - 243296575936648407*x^6 + 786077275127639580*x^7 - 
           1284784548626459376*x^8 + 6745150387285830648*x^9 + 
           61660721031918404310*x^10 - 314805576718917671130*x^11 - 
           454287950699239643697*x^12 + 4000941841070265810732*x^13 - 
           2304924290844645819417*x^14 - 24244475729071848377646*x^15 + 
           56729601345557007989807*x^16 + 52405830748827799031118*x^17 - 
           366283263053641804988866*x^18 + 166456564647677981809534*x^19 + 
           1063905953253132647210970*x^20 - 1086217246511861780163706*x^21 - 
           1651599358604680160950812*x^22 + 1809866049301500109913996*x^23 + 
           5321362778204134242472372*x^24 - 4162509919128844106295628*x^25 - 
           18636893290412900299922220*x^26 + 19314666442257617494139052*
            x^27 + 20524438594658094760012774*x^28 - 
           27026031272216991421279136*x^29 - 27051525971671409558019090*
            x^30 + 33701368474354451815378032*x^31 + 
           32181709492401904265710641*x^32 - 38479505804521124662734764*
            x^33 - 29438917130128807809953382*x^34 + 
           36653138773175038354354802*x^35 + 20827986028983711856619713*
            x^36 - 28522740757888058967937552*x^37 - 
           11282869688850467920215607*x^38 + 18081785632767721555276668*
            x^39 + 4443108558378102096042240*x^40 - 9296431590393193432425928*
            x^41 - 1077531409673501751622810*x^42 + 3848617880675385044952342*
            x^43 + 16122890896058919319507*x^44 - 1271286312563892315099276*
            x^45 + 115683262208197562785059*x^46 + 331505677675303971805242*
            x^47 - 56720800627339494135555*x^48 - 67424581762718752981170*
            x^49 + 16023570818504992965810*x^50 + 10551013465629030715314*
            x^51 - 3084961259978170805736*x^52 - 1249335347085338572962*
            x^53 + 421224879035850653610*x^54 + 109420233109891527276*x^55 - 
           40898286177071235588*x^56 - 6848102512428458292*x^57 + 
           2765419398006942816*x^58 + 289049194083495240*x^59 - 
           123899187411091800*x^60 - 7362693941151600*x^61 + 
           3308131899505800*x^62 + 85426217824500*x^63 - 39865568318100*x^64)*
          HPL[{0, 0, 0}, x])/(99225*(-1 + x^2)^13*(9 - 82*x^2 + 9*x^4)^8) + 
        (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{1, -2, 0}, x])/(945*(-1 + x^2)^10) + 
        ((463050 - 992250*x - 1895400*x^2 + 7242300*x^3 + 152950*x^4 - 
           22954470*x^5 + 13115252*x^6 + 41252426*x^7 - 34114206*x^8 - 
           46021458*x^9 + 42829927*x^10 + 32794727*x^11 - 30595348*x^12 - 
           14829885*x^13 + 12414822*x^14 + 4132893*x^15 - 2528750*x^16 - 
           673283*x^17 + 462406*x^18 - 673283*x^19 - 2528750*x^20 + 
           4132893*x^21 + 12414822*x^22 - 14829885*x^23 - 30595348*x^24 + 
           32794727*x^25 + 42829927*x^26 - 46021458*x^27 - 34114206*x^28 + 
           41252426*x^29 + 13115252*x^30 - 22954470*x^31 + 152950*x^32 + 
           7242300*x^33 - 1895400*x^34 - 992250*x^35 + 463050*x^36)*
          HPL[{1, -1, 0}, x])/(198450*x^15*(-1 + x^2)^7) - 
        ((29074 - 483500*x + 2283330*x^2 - 15663075*x^3 + 22789567*x^4 - 
           36881366*x^5 + 21562605*x^6 - 64137766*x^7 + 6058455*x^8 + 
           70224324*x^9 + 113889053*x^10 - 292558080*x^11 - 243888721*x^12 + 
           478290940*x^13 + 434181461*x^14 - 592799878*x^15 - 
           524046015*x^16 + 544964050*x^17 + 440417105*x^18 - 
           378509253*x^19 - 255260884*x^20 + 201071412*x^21 + 98191170*x^22 - 
           81580788*x^23 - 22982470*x^24 + 24381850*x^25 + 2657700*x^26 - 
           4806000*x^27 - 66150*x^28 + 463050*x^29)*HPL[{1, 0, 0}, x])/
         (99225*(-1 + x)^10*(1 + x)^12) + 
        ((-463050 + 992250*x + 1895400*x^2 - 7242300*x^3 - 152950*x^4 + 
           22954470*x^5 - 13115252*x^6 - 41252426*x^7 + 34114206*x^8 + 
           46021458*x^9 - 42829927*x^10 - 32794727*x^11 + 30595348*x^12 + 
           14829885*x^13 - 12414822*x^14 - 4132893*x^15 + 2528750*x^16 + 
           673283*x^17 - 462406*x^18 + 673283*x^19 + 2528750*x^20 - 
           4132893*x^21 - 12414822*x^22 + 14829885*x^23 + 30595348*x^24 - 
           32794727*x^25 - 42829927*x^26 + 46021458*x^27 + 34114206*x^28 - 
           41252426*x^29 - 13115252*x^30 + 22954470*x^31 - 152950*x^32 - 
           7242300*x^33 + 1895400*x^34 + 992250*x^35 - 463050*x^36)*
          HPL[{1, 1, 0}, x])/(198450*x^15*(-1 + x^2)^7) - 
        (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{1, 2, 0}, x])/(945*(-1 + x^2)^10) - 
        (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{2, -1, 0}, x])/(945*(-1 + x^2)^10) + 
        (8*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{2, 0, 0}, x])/(945*(-1 + x^2)^10) + 
        (4*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{2, 1, 0}, x])/(945*(-1 + x^2)^10) - 
        (8*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{-1, 1, 0, 0}, x])/(945*(-1 + x^2)^10) - 
        (8*(9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
           60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
           42*x^11 + 9*x^12)*HPL[{1, -1, 0, 0}, x])/(945*(-1 + x^2)^10) + 
        ((9 + 104*x - 875*x^2 + 12709*x^3 - 33740*x^4 + 89488*x^5 - 
           115400*x^6 + 132280*x^7 - 80865*x^8 + 46942*x^9 - 8829*x^10 + 
           3175*x^11 + 300*x^12 + 62*x^13)*master3l10a[x])/
         (1890*(-1 + x^2)^11) - (x*(62 + 300*x + 3175*x^2 - 8829*x^3 + 
           46942*x^4 - 80865*x^5 + 132280*x^6 - 115400*x^7 + 89488*x^8 - 
           33740*x^9 + 12709*x^10 - 875*x^11 + 104*x^12 + 9*x^13)*
          master3l10b[x])/(1890*(-1 + x^2)^11) + 
        ((2479730278050 + 107524867458528*x + 272739750997968*x^2 - 
           1519550082742725*x^3 + 3255603196706424*x^4 - 4015435464536598*
            x^5 + 1173310093442790*x^6 + 988180886879388*x^7 - 
           1594643283954900*x^8 + 369202880391318*x^9 + 568578633023466*
            x^10 - 99950433863625*x^11 - 170075101414770*x^12 - 
           10526799805596*x^13 + 55398491076924*x^14 + 2635986284112*x^15 - 
           13722197311446*x^16 + 1079226908556*x^17 + 2169689517476*x^18 - 
           399787073607*x^19 - 211457735644*x^20 + 56160929682*x^21 + 
           12122806782*x^22 - 4139873196*x^23 - 350173720*x^24 + 
           159525150*x^25 + 2003074*x^26 - 2540907*x^27 + 84726*x^28)*
          master3l8a[x])/(2381400*(-9 + x^2)^8*(-1 + x^2)^12) - 
        ((156380 - 1214194*x - 10638647*x^2 + 96499398*x^3 + 311015182*x^4 - 
           3370020040*x^5 - 5394532284*x^6 + 68844209374*x^7 + 
           66713110046*x^8 - 924826205116*x^9 - 649191555475*x^10 + 
           8711417399528*x^11 + 4494848374108*x^12 - 59272377822830*x^13 - 
           12206920527600*x^14 + 284827641450396*x^15 - 104847499396392*
            x^16 - 842880359812698*x^17 + 1146422927274579*x^18 + 
           740616719699574*x^19 - 3927496519311930*x^20 + 3498609688771212*
            x^21 + 2464873800625260*x^22 - 7679846810516058*x^23 + 
           8543737901732238*x^24 - 4607477135054424*x^25 + 
           1964675498417847*x^26 - 269931963725892*x^27 + 
           50888378126448*x^28 + 1503430645770*x^29)*master3l8b[x])/
         (2381400*x*(1 - 9*x^2)^8*(-1 + x^2)^12) - 
        ((221286717990 + 8800735865832*x + 180575594892*x^2 + 
           25707049300377*x^3 - 75084043731012*x^4 + 254428696433133*x^5 - 
           369816933585294*x^6 + 220106226687273*x^7 + 64685140980318*x^8 - 
           173226732530337*x^9 + 79920313037982*x^10 + 38889946019460*x^11 - 
           47395268619528*x^12 - 2088578175726*x^13 + 13635310849348*x^14 - 
           763782810830*x^15 - 2540219635310*x^16 + 224806092278*x^17 + 
           322259313688*x^18 - 33298135807*x^19 - 27320295188*x^20 + 
           3126542673*x^21 + 1462579210*x^22 - 182295563*x^23 - 
           44168630*x^24 + 5886067*x^25 + 564734*x^26 - 78190*x^27)*
          master3l9a[x])/(793800*(-9 + x^2)^7*(-1 + x^2)^12) - 
        ((-78190 + 564734*x + 5886067*x^2 - 44168630*x^3 - 182295563*x^4 + 
           1462579210*x^5 + 3126542673*x^6 - 27320295188*x^7 - 
           33298135807*x^8 + 322259313688*x^9 + 224806092278*x^10 - 
           2540219635310*x^11 - 763782810830*x^12 + 13635310849348*x^13 - 
           2088578175726*x^14 - 47395268619528*x^15 + 38889946019460*x^16 + 
           79920313037982*x^17 - 173226732530337*x^18 + 64685140980318*x^19 + 
           220106226687273*x^20 - 369816933585294*x^21 + 254428696433133*
            x^22 - 75084043731012*x^23 + 25707049300377*x^24 + 
           180575594892*x^25 + 8800735865832*x^26 + 221286717990*x^27)*
          master3l9b[x])/(2381400*x*(-1 + x^2)^12*(-1 + 9*x^2)^7) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(463050 - 992250*x - 1895400*x^2 + 
             7242300*x^3 + 152950*x^4 - 22954470*x^5 + 13115252*x^6 + 
             41252426*x^7 - 34114206*x^8 - 46021458*x^9 + 42829927*x^10 + 
             32794727*x^11 - 30595348*x^12 - 14829885*x^13 + 12414822*x^14 + 
             4132893*x^15 - 2528750*x^16 - 673283*x^17 + 462406*x^18 - 
             673283*x^19 - 2528750*x^20 + 4132893*x^21 + 12414822*x^22 - 
             14829885*x^23 - 30595348*x^24 + 32794727*x^25 + 42829927*x^26 - 
             46021458*x^27 - 34114206*x^28 + 41252426*x^29 + 13115252*x^30 - 
             22954470*x^31 + 152950*x^32 + 7242300*x^33 - 1895400*x^34 - 
             992250*x^35 + 463050*x^36) - 10080*x^15*(9 + 42*x - 1166*x^2 + 
             9576*x^3 - 26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 
             26077*x^8 + 9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*Zeta[3]))/
         (2381400*x^15*(-1 + x^2)^10) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(463050 - 992250*x - 1895400*x^2 + 
              7242300*x^3 + 152950*x^4 - 22954470*x^5 + 13115252*x^6 + 
              41252426*x^7 - 34114206*x^8 - 46021458*x^9 + 42829927*x^10 + 
              32794727*x^11 - 30595348*x^12 - 14829885*x^13 + 12414822*x^14 + 
              4132893*x^15 - 2528750*x^16 - 673283*x^17 + 462406*x^18 - 
              673283*x^19 - 2528750*x^20 + 4132893*x^21 + 12414822*x^22 - 
              14829885*x^23 - 30595348*x^24 + 32794727*x^25 + 42829927*x^26 - 
              46021458*x^27 - 34114206*x^28 + 41252426*x^29 + 13115252*x^30 - 
              22954470*x^31 + 152950*x^32 + 7242300*x^33 - 1895400*x^34 - 
              992250*x^35 + 463050*x^36)) + 10080*x^15*(9 + 42*x - 1166*x^2 + 
             9576*x^3 - 26077*x^4 + 52122*x^5 - 60612*x^6 + 52122*x^7 - 
             26077*x^8 + 9576*x^9 - 1166*x^10 + 42*x^11 + 9*x^12)*Zeta[3]))/
         (2381400*x^15*(-1 + x^2)^10) + (HPL[{0}, x]*(50230616080806000 - 
           107637034458870000*x - 4067784961215696000*x^2 + 
           9061720296933276000*x^3 + 147922989714790069500*x^4 - 
           345961937164007007900*x^5 - 3184171509133177404660*x^6 + 
           7926859457923960810620*x^7 + 45002908886533178484960*x^8 - 
           121640228009150627626920*x^9 - 437275700710505630283240*x^10 + 
           1322265857825545292438100*x^11 - 688905*(-4301727847779036547 + 
             2052018360*Pi^2)*x^12 + 531441*(-19790171526539773591 + 
             22223224800*Pi^2)*x^13 - 10080*(-169396394385736463853565 + 
             67651563150560448271223*Pi^2)*x^35 + 
           729*(14427050241244899292749 + 157563734169644375847680*Pi^2)*
            x^57 - 5670*(522660111202465164333 + 3214756982142347287892*Pi^2)*
            x^58 - 918540*(1439530041255234093 + 26529515190540504128*Pi^2)*
            x^59 + 204120*(2142248190821603127 + 27410660370087507442*Pi^2)*
            x^60 + 49601160*(2452366598062437 + 79633287786986362*Pi^2)*
            x^61 - 1837080*(24496978295193012 + 617738884006050377*Pi^2)*
            x^62 - 74401740*(106541318226213 + 6471921311461754*Pi^2)*x^63 + 
           8266860*(385173029316231 + 19456961913108086*Pi^2)*x^64 + 
           669615660*(516657476565 + 64512587802988*Pi^2)*x^65 - 
           74401740*(1988165729925 + 215942114177176*Pi^2)*x^66 - 
           48212327520*(187954425 + 57202358567*Pi^2)*x^67 + 
           2678462640*(1518701400 + 414719676773*Pi^2)*x^68 + 
           1084777369200*(99225 + 109095389*Pi^2)*x^69 - 
           602654094000*(83349 + 84069763*Pi^2)*x^70 - 3056452443797382000*
            Pi^2*x^71 + 1372671859098834000*Pi^2*x^72 + 35879011486290000*
            Pi^2*x^73 - 16743538693602000*Pi^2*x^74 + 
           45*x^53*(26607612498686123969207584*Pi^2 + 
             243*(25719588830707459867873 - 6509735600256000*Zeta[3])) - 
           2*x^31*(-5717869941546180460612290157 + 54995569687328271338767500*
              Pi^2 - 58793385875635802476512000*Zeta[3]) + 
           14*x^33*(-752368879112560375143019037 + 19005998915930706701209080*
              Pi^2 - 15424467997757687084160000*Zeta[3]) + 
           6*x^29*(-2027576852767456842849878869 + 5099842094877495938409080*
              Pi^2 - 2981863108692762303744000*Zeta[3]) - 
           14*x^28*(668111250050527078386800191 + 1070381553262648225251600*
              Pi^2 - 1655571148880065425792000*Zeta[3]) + 
           28*x^42*(291068652368957594445122783 + 246440832372191939358510120*
              Pi^2 - 827785574440032712896000*Zeta[3]) + 
           210*x^30*(46105017617080066199338405 + 237313669421902679658124*
              Pi^2 - 293395225790115306144000*Zeta[3]) - 
           12*x^43*(908251935646340552985963883 + 661997322519138402980484000*
              Pi^2 - 278447520382072513920000*Zeta[3]) + 
           9*x^45*(972618854225426164162214469 + 926057510428880228249226880*
              Pi^2 - 201282668822029100544000*Zeta[3]) + 
           42*x^38*(150860479534800450479500223 + 81858018900020710043415360*
              Pi^2 - 131558686169324200416000*Zeta[3]) - 
           840*x^40*(6415505458532397730442515 + 6461987861048287049807302*
              Pi^2 - 73348806447528826536000*Zeta[3]) - 
           105*x^44*(61790775994491795331280873 + 66083414859660553159494744*
              Pi^2 - 33494630342259963340800*Zeta[3]) - 
           168*x^32*(53132848512656347038551387 + 842738607657222704814915*
              Pi^2 - 32889671542331050104000*Zeta[3]) + 
           210*x^26*(31066143186725841751942009 + 12795382403690283849780*
              Pi^2 - 16747315171129981670400*Zeta[3]) - 
           21*x^47*(257579300635642435625834577 + 337974882232808482891066000*
              Pi^2 - 16000558083039327840000*Zeta[3]) + 
           21*x^46*(157449151441036271850389461 + 259816867010171450890367880*
              Pi^2 - 4699761266207764512000*Zeta[3]) + 
           21*x^49*(123595618681565635897579347 + 232742480702729933270458240*
              Pi^2 - 1650332000033635968000*Zeta[3]) - 
           336*x^24*(9710654288979162766860346 + 727195908737904525675*Pi^2 - 
             293735079137985282000*Zeta[3]) - 189*x^21*
            (13739978873352804785667593 + 1543509911313236160*Pi^2 - 
             183370222225959552000*Zeta[3]) + 315*x^20*
            (-521643750653448218197111 + 4821632084370986640*Pi^2 - 
             24726030726309696000*Zeta[3]) - 168*x^51*
            (5778266437646336646026019 + 16114099070049239495994760*Pi^2 - 
             12552262676676576000*Zeta[3]) - 2268*x^18*
            (21720453654768561651971 + 65721771625734000*Pi^2 - 
             256103348093712000*Zeta[3]) + 23814*x^16*
            (1706990263834230425737 + 231606102859200*Pi^2 - 
             924069610800000*Zeta[3]) + 1512*x^56*(9117256115149119200493 + 
             20078898809326458541690*Pi^2 - 227803247532000*Zeta[3]) - 
           107163*x^14*(128638334413764266857 + 406990639800*Pi^2 - 
             3214155168000*Zeta[3]) - 19683*x^15*(-3174197522008522739869 + 
             28543793796000*Pi^2 + 52497867744000*Zeta[3]) + 
           10935*x^17*(-25718822398386197491027 + 796480367306400*Pi^2 + 
             6509735600256000*Zeta[3]) - 31752*x^19*
            (-30572018259905879869931 + 665447903722800*Pi^2 + 
             66414088236384000*Zeta[3]) - 189*x^52*
            (-260345827281655600344627 + 2197998177251956128418000*Pi^2 + 
             3073240177124544000*Zeta[3]) + 1260*x^50*
            (131248771975811101983949 + 1151185671133684413373992*Pi^2 + 
             6181507681577424000*Zeta[3]) + 441*x^22*
            (2468681979151398268361713 + 7625325639306421080*Pi^2 + 
             105132783612122784000*Zeta[3]) - 42*x^48*
            (26160828823386313265242149 + 78254128098531236163228520*Pi^2 + 
             1103894227927289232000*Zeta[3]) - 63*x^23*
            (-86245913860344619077094019 + 241484665951249834680*Pi^2 + 
             5333519361013109280000*Zeta[3]) + 27*x^25*
            (-331315221297178998532242773 + 16357763406147957874080*Pi^2 + 
             67094222940676366848000*Zeta[3]) - 12*x^27*
            (-968860843607631684381376993 + 416134474298052325210080*Pi^2 + 
             278447520382072513920000*Zeta[3]) + 
           6*x^41*(1923409840292394595118339959 + 
             1027350275305830208865880440*Pi^2 + 2981863108692762303744000*
              Zeta[3]) + 28*x^34*(524031697118489524767291191 + 
             19456171946736451934285520*Pi^2 + 9068121930071677634784000*
              Zeta[3]) + 14*x^37*(1313439504891521624825608787 + 
             140235451893448164840973320*Pi^2 + 15424467997757687084160000*
              Zeta[3]) - 14*x^36*(1545455303219733955383908557 + 
             126062538895585225573014360*Pi^2 + 18136243860143355269568000*
              Zeta[3]) - 2*x^39*(7660766159651907946398581557 + 
             1951213848390816996523632480*Pi^2 + 58793385875635802476512000*
              Zeta[3]) - 27*x^55*(15521341785040547351455000*Pi^2 - 
             19683*(-117563777049033446447 + 1944365472000*Zeta[3])) + 
           21*x^54*(1768126827208190521384280*Pi^2 + 
             81*(-23897191863604641334943 + 12936974551200000*Zeta[3]))))/
         (1000188000*x^11*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        (-1411200*Pi^4*x^13*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^8*
           (9 + 42*x - 1166*x^2 + 9576*x^3 - 26077*x^4 + 52122*x^5 - 
            60612*x^6 + 52122*x^7 - 26077*x^8 + 9576*x^9 - 1166*x^10 + 
            42*x^11 + 9*x^12) + 48*Pi^2*(9 - 82*x^2 + 9*x^4)^8*
           (-194481000 + 416745000*x + 1671232500*x^2 - 4917118500*x^3 - 
            5169979500*x^4 + 26593326900*x^5 + 2264455410*x^6 - 
            87211247970*x^7 + 33060419350*x^8 + 193285870050*x^9 - 
            123351295410*x^10 - 305351942350*x^11 + 241105223520*x^12 + 
            353297907878*x^13 - 308633442397*x^14 - 302293181338*x^15 + 
            268610986679*x^16 + 202636083832*x^17 - 209646600597*x^18 - 
            43715060522*x^19 + 61995483305*x^20 - 61995483305*x^22 + 
            43715060522*x^23 + 209646600597*x^24 - 202636083832*x^25 - 
            268610986679*x^26 + 302293181338*x^27 + 308633442397*x^28 - 
            353297907878*x^29 - 241105223520*x^30 + 305351942350*x^31 + 
            123351295410*x^32 - 193285870050*x^33 - 33060419350*x^34 + 
            87211247970*x^35 - 2264455410*x^36 - 26593326900*x^37 + 
            5169979500*x^38 + 4917118500*x^39 - 1671232500*x^40 - 
            416745000*x^41 + 194481000*x^42) + x^2*(-602767392969672000 + 
            1291644413506440000*x + 49014341998911576000*x^2 - 
            109171191701034792000*x^3 - 1791271670498222409000*x^4 + 
            4187628671604128893800*x^5 + 38795690249862199594920*x^6 - 
            96492658360826873570040*x^7 - 552553070523850324083960*x^8 + 
            1490878723567960951990920*x^9 + 5422664722569343878507480*x^10 + 
            x^41*(199741694613273401219725665656 - 
              877984762038746317571082620160*Zeta[3]) + 
            x^33*(127443712481883437296050899416 - 
              89339629042416052566057012480*Zeta[3]) + 440129151906823008000*
             x^71*Zeta[3] - 197664747710232096000*x^72*Zeta[3] - 
            5166577654025760000*x^73*Zeta[3] + 2411069571878688000*x^74*
             Zeta[3] + 21695547384000*x^70*(-27783 + 336279052*Zeta[3]) - 
            39051985291200*x^69*(-33075 + 436381556*Zeta[3]) + 
            167403915*x^11*(-97621035537430805 + 1256840064*Zeta[3]) + 
            32109410128320*x^67*(-3399975 + 12368077528*Zeta[3]) + 
            8266860*x^12*(-4505456438211822433 + 437915362176*Zeta[3]) - 
            96424655040*x^68*(-508317525 + 1658878707092*Zeta[3]) - 
            12754584*x^13*(-10295953674002442881 + 3159895959360*Zeta[3]) - 
            183708*x^14*(-961632388772568097903 + 251212744366560*Zeta[3]) - 
            12053081880*x^65*(-347432193135 + 516100702423904*Zeta[3]) + 
            1339231320*x^66*(-1337537170575 + 1727536913417408*Zeta[3]) + 
            472392*x^15*(-1672150278790364799157 + 3781128550888080*Zeta[
                3]) + 1339231320*x^63*(-72050777875197 + 51775370491694032*
               Zeta[3]) - 4910514840*x^61*(-303609452805963 + 
              115830236781071072*Zeta[3]) - 148803480*x^64*
             (-260717627369079 + 155655695304864688*Zeta[3]) - 
            157464*x^17*(-22925193352692991379507 + 191279374325303040*Zeta[
                3]) - 20412*x^16*(26403047780406113217869 + 
              310851429797953440*Zeta[3]) + 16533720*x^62*
             (-33419767029068493 + 9883822144096806032*Zeta[3]) + 
            6804*x^18*(108388422516649249489369 + 40348880777613899520*Zeta[
                3]) + 486*x^19*(-26105421819383149812132113 + 
              63393672689067530880*Zeta[3]) - 1837080*x^60*
             (-2951784816010983531 + 438570565921400119072*Zeta[3]) + 
            5832*x^21*(5945936781723844283106761 + 1161839701935392880960*
               Zeta[3]) + 2066715*x^59*(-7907303849622904485 + 
              1697888972239255773056*Zeta[3]) - 756*x^20*
             (-2376677387326684204160771 + 6698290199163709296960*Zeta[3]) - 
            3780*x^26*(23035561364186003841966797 + 7146469947174295766784*
               Zeta[3]) + 102060*x^58*(-364941716245975497663 + 
              25718055885215580111232*Zeta[3]) - 1080*x^23*
             (69004556048134783789032865 + 108481042061262325403424*Zeta[
                3]) + 252*x^22*(-53670255405272915155426247 + 
              197396933958002695619520*Zeta[3]) - 52488*x^57*
             (-2501917258902099811533 + 315127468879749927869440*Zeta[3]) - 
            6804*x^56*(-25963768646586954449631 + 642524764753442562752000*
               Zeta[3]) - 252*x^24*(-166766561904448023998368277 + 
              938971482273630603538560*Zeta[3]) + 216*x^25*
             (590672699973741623594856169 + 4453328867645703801201600*Zeta[
                3]) - 756*x^54*(712797690178571043160413 + 
              7072515654166349807854400*Zeta[3]) + 6804*x^52*
             (108228497798826057255619 + 8792030869815527979737920*Zeta[3]) + 
            3024*x^32*(37449016410682157706030977 + 
              23939004862823546987155400*Zeta[3]) + 1944*x^55*
             (-406333870509440704518351 + 31042684249408017930695840*Zeta[
                3]) + 112*x^28*(1218286847406869325734209429 + 
              57568529691981780960236400*Zeta[3]) - 6048*x^38*
             (-23002490778565569852306651 + 73417151695388409731097320*Zeta[
                3]) - 448*x^34*(-10934423916207559055626291 + 
              230378101865478200308319640*Zeta[3]) + 3780*x^44*
             (-23621484954481871037567667 + 264401115078937828304404992*Zeta[
                3]) - 648*x^53*(-5570981408227190621273451 + 
              266076156953737799769842560*Zeta[3]) - 756*x^50*
             (-2391977090682342694131521 + 276290912794167227361104640*Zeta[
                3]) - 112*x^30*(1476114857420636154990256781 + 
              291907616160217422767521320*Zeta[3]) + 
            8*x^29*(24559938268782891725834705707 + 
              749623604427147290412670560*Zeta[3]) + 1080*x^47*
             (-69259467147299661255955105 + 946216799028652648957952464*Zeta[
                3]) + 252*x^48*(-54000444407378937642722597 + 
              1878291830386373114422793760*Zeta[3]) + 
            112*x^36*(352497334672439734787333839 + 
              2073460113890506807842842640*Zeta[3]) + 
            8*x^31*(-20410615382388573145305610813 + 
              2288812006495797167586050640*Zeta[3]) - 
            252*x^46*(-168574158677443443518926127 + 
              3118808976013141065949612320*Zeta[3]) - 
            216*x^49*(-160685048271233115853656597 + 
              3258359885955895548169227200*Zeta[3]) + 
            224*x^40*(-854775732843752315041169953 + 
              3374274215586969791575517160*Zeta[3]) - 
            x^27*(176654831086735640987269980617 + 
              4086892228822412838022615680*Zeta[3]) - 
            216*x^45*(-597686513259531896898658819 + 
              5551647735482370430683479040*Zeta[3]) + 
            54*x^51*(-234990974671527517177630617 + 
              7219114956450537614847721600*Zeta[3]) - 
            112*x^42*(-1302181564814908060303130629 + 
              8830742237004794600218263120*Zeta[3]) - 
            8*x^37*(-9562129055294384583574392527 + 
              41957537932988846227109363040*Zeta[3]) + 
            4*x^35*(-47011626734075294085116244901 + 
              42234831525753706719573953280*Zeta[3]) + 
            8*x^39*(-17733698783335105347508311613 + 
              70779288200211524134697317920*Zeta[3]) + 
            x^43*(-181232775622692678140135062217 + 
              1139283735461249655838150558080*Zeta[3])))/
         (48009024000*x^13*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8)))
 
CbarLData["v", 2, -1] = 
    NC*(CF^2*((lm^3*(-1 + x)^2)/4 + (Pi^2*(1 + x^2)*HPL[{-2}, x])/9 + 
        lm^2*((-7 + 2*x - 7*x^2)/16 - (3*(-2 + x)*x^3*HPL[{0}, x])/
           (2*(-1 + x^2))) - (Pi^2*(1 + x^2)*HPL[{2}, x])/9 + 
        (x^2*(6 + 12*x - 57*x^2 - 39*x^3 + 46*x^4 + 22*x^5 - 22*x^6 + x^7 + 
           5*x^8 - 2*x^9)*HPL[{-2, 0}, x])/(9*(-1 + x^2)^2) + 
        ((12 - 30*x + 12*x^2 + (-181 + 12*Pi^2)*x^3 - 6*x^4 + 554*x^5 - 
           6*x^6 - (181 + 12*Pi^2)*x^7 + 12*x^8 - 30*x^9 + 12*x^10)*
          HPL[{-1, 0}, x])/(108*x^3*(-1 + x^2)) - 
        (x^2*(384 + 747*x - 99*x^2 + 1746*x^3 - 3923*x^4 - 15*x^6 + 6*x^7)*
          HPL[{0, 0}, x])/(27*(-1 + x^2)^2) + 
        ((-12 + 30*x - 12*x^2 + (181 - 12*Pi^2)*x^3 + 6*x^4 - 554*x^5 + 
           6*x^6 + (181 + 12*Pi^2)*x^7 - 12*x^8 + 30*x^9 - 12*x^10)*
          HPL[{1, 0}, x])/(108*x^3*(-1 + x^2)) + 
        (x^2*(-6 - 12*x + 57*x^2 + 39*x^3 - 46*x^4 - 22*x^5 + 22*x^6 - x^7 - 
           5*x^8 + 2*x^9)*HPL[{2, 0}, x])/(9*(-1 + x^2)^2) - 
        (4*(1 + x^2)*HPL[{-2, -1, 0}, x])/3 + 
        (8*(1 + x^2)*HPL[{-2, 0, 0}, x])/3 + (4*(1 + x^2)*HPL[{-2, 1, 0}, x])/
         3 + (4*(1 + x^2)*HPL[{-1, -2, 0}, x])/3 + 
        ((-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 11*x^6 + x^8 + 2*x^9)*
          HPL[{-1, -1, 0}, x])/(18*x^5) - 
        ((56 - 91*x + 51*x^2 - 39*x^3 + 69*x^4 - 39*x^5 + x^6 + 15*x^7 - 
           9*x^8 + 2*x^9)*HPL[{-1, 0, 0}, x])/(9*(-1 + x)^2) - 
        ((-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 11*x^6 + x^8 + 2*x^9)*
          HPL[{-1, 1, 0}, x])/(18*x^5) - (4*(1 + x^2)*HPL[{-1, 2, 0}, x])/3 + 
        (2*x^2*(3 + 366*x - 309*x^2 - 828*x^3 + 1415*x^4 + 652*x^5 - 
           1155*x^6 - 21*x^7 + 27*x^8 - 3*x^9 - 5*x^10 + 2*x^11)*
          HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) - 
        (4*(1 + x^2)*HPL[{1, -2, 0}, x])/3 - 
        ((-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 11*x^6 + x^8 + 2*x^9)*
          HPL[{1, -1, 0}, x])/(18*x^5) + 
        ((56 + 85*x + 39*x^2 - 3*x^3 - 3*x^4 + 9*x^5 + 13*x^6 - 5*x^7 - x^8 + 
           2*x^9)*HPL[{1, 0, 0}, x])/(9*(1 + x)^2) + 
        ((-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 11*x^6 + x^8 + 2*x^9)*
          HPL[{1, 1, 0}, x])/(18*x^5) + (4*(1 + x^2)*HPL[{1, 2, 0}, x])/3 + 
        (4*(1 + x^2)*HPL[{2, -1, 0}, x])/3 - (8*(1 + x^2)*HPL[{2, 0, 0}, x])/
         3 - (4*(1 + x^2)*HPL[{2, 1, 0}, x])/3 + 
        (8*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/3 + 
        (8*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/3 + 
        ((1 + x*(-1 - 4/(-1 + x^2)))*master3l10a[x])/12 + 
        (x*(1 - x + 3*x^2 + x^3)*master3l10b[x])/(12*(-1 + x^2)) + 
        ((11 + 6*x - x^2)*master3l8a[x])/(12*(-1 + x^2)^2) + 
        ((5 + 18*x - 39*x^2)*master3l8b[x])/(36*(-1 + x^2)^2) - 
        ((-9 + x^2)*master3l9a[x])/(3*(-1 + x^2)^2) + 
        ((1 - 9*x^2)*master3l9b[x])/(9*(-1 + x^2)^2) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 
             11*x^6 + x^8 + 2*x^9) - 288*x^5*(1 + x^2)*Zeta[3]))/(216*x^5) + 
        (HPL[{-1}, x]*(-(Pi^2*(-1 + x)^3*(2 + x + 11*x^3 + 16*x^4 + 16*x^5 + 
              11*x^6 + x^8 + 2*x^9)) + 288*x^5*(1 + x^2)*Zeta[3]))/
         (216*x^5) + (HPL[{0}, x]*(-24 + 60*x - 12*x^2 - 4*(-2947 + 6*Pi^2)*
            x^3 + (24 - 88*Pi^2)*x^8 + 88*Pi^2*x^9 - 4*Pi^2*x^10 - 
           20*Pi^2*x^11 + 8*Pi^2*x^12 - 6*x^4*(-2283 + 8*Pi^2 + 
             576*Zeta[3]) + 6*x^6*(1499 + 26*Pi^2 + 576*Zeta[3]) - 
           x^7*(21885 + 184*Pi^2 + 1728*Zeta[3]) + 
           x^5*(-12643 + 228*Pi^2 + 1728*Zeta[3])))/(432*x*(-1 + x^2)^2) + 
        lm*((x^2*(-4 - 2*x + 7*x^2)*HPL[{0}, x])/(4*(-1 + x^2)) + 
          (1 - x^2)*HPL[{-1, 0}, x] + (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
            HPL[{0, 0}, x])/(-1 + x^2)^2 + (-1 + x^2)*HPL[{1, 0}, x] + 
          (-95 + 8*Pi^2*(-1 + x^2) + x*(82 - 288*Zeta[3]) + 144*Zeta[3] + 
            x^2*(-95 + 144*Zeta[3]))/96) - 
        (24*Pi^4*x^3*(-1 + x^2)^2*(39 - 88*x + 39*x^2) + 10*Pi^2*(-1 + x^2)*
           (12 - 30*x + 12*x^2 + 554*x^5 + 12*x^8 - 30*x^9 + 12*x^10 + 
            6*x^4*(-1 + 192*Log[2]^2) - 6*x^6*(1 + 192*Log[2]^2) + 
            x^7*(-181 + 576*Log[2]^2) - x^3*(181 + 576*Log[2]^2)) + 
          15*x^2*(-12 + 528*x^9*Zeta[3] - 24*x^10*Zeta[3] - 
            120*x^11*Zeta[3] + 48*x^12*Zeta[3] - 12*x^8*(1 + 44*Zeta[3]) + 
            3*x^2*(377 + 256*Log[2]^4 + 6144*PolyLog[4, 1/2] + 
              4072*Zeta[3]) - 6*x^4*(-2927 + 256*Log[2]^4 + 6144*PolyLog[4, 
                1/2] + 4192*Zeta[3]) + 3*x^6*(377 + 256*Log[2]^4 + 
              6144*PolyLog[4, 1/2] + 4384*Zeta[3]) + 
            x^3*(10405 + 384*Log[2]^4 + 9216*PolyLog[4, 1/2] + 
              6288*Zeta[3]) + x^5*(-17675 + 384*Log[2]^4 + 9216*PolyLog[4, 
                1/2] + 6504*Zeta[3]) - x*(-14255 + 384*Log[2]^4 + 
              9216*PolyLog[4, 1/2] + 9096*Zeta[3]) - 
            x^7*(6625 + 384*Log[2]^4 + 9216*PolyLog[4, 1/2] + 9768*Zeta[3])))/
         (12960*x^3*(-1 + x^2)^2)) + CA*CF*((11*lm^3*(-1 + x)^2)/72 - 
        (Pi^2*(1 + x^2)*HPL[{-2}, x])/18 + 
        lm^2*((119 - 304*x + 119*x^2)/144 - (11*(-2 + x)*x^3*HPL[{0}, x])/
           (12*(-1 + x^2))) + (Pi^2*(1 + x^2)*HPL[{2}, x])/18 - 
        (x^2*(6 + 6*x - 42*x^2 - 21*x^3 + 31*x^4 + 6*x^5 - 9*x^6 + 3*x^7)*
          HPL[{-2, 0}, x])/(18*(-1 + x^2)^2) + 
        ((6 - (161 + 4*Pi^2)*x - 12*x^2 + 294*x^3 - 12*x^4 + 
           (-161 + 4*Pi^2)*x^5 + 6*x^6)*HPL[{-1, 0}, x])/(72*x*(-1 + x^2)) + 
        (x^2*(326 + 1666*x - 711*x^2 + 598*x^3 - 2229*x^4 - 6*x^5)*
          HPL[{0, 0}, x])/(36*(-1 + x^2)^2) + 
        ((-6 + (161 + 4*Pi^2)*x + 12*x^2 - 294*x^3 + 12*x^4 + 
           (161 - 4*Pi^2)*x^5 - 6*x^6)*HPL[{1, 0}, x])/(72*x*(-1 + x^2)) + 
        (x^2*(6 + 6*x - 42*x^2 - 21*x^3 + 31*x^4 + 6*x^5 - 9*x^6 + 3*x^7)*
          HPL[{2, 0}, x])/(18*(-1 + x^2)^2) + 
        (2*(1 + x^2)*HPL[{-2, -1, 0}, x])/3 - (8*x^2*HPL[{-2, 0, 0}, x])/3 - 
        (2*(1 + x^2)*HPL[{-2, 1, 0}, x])/3 - 
        (2*(1 + x^2)*HPL[{-1, -2, 0}, x])/3 + 
        ((-3 + 9*x - 12*x^2 - 35*x^3 + 35*x^5 + 12*x^6 - 9*x^7 + 3*x^8)*
          HPL[{-1, -1, 0}, x])/(36*x^3) + 
        ((67 - 119*x + 129*x^2 - 149*x^3 + 109*x^4 - 33*x^5 + 15*x^6 - 3*x^7)*
          HPL[{-1, 0, 0}, x])/(18*(-1 + x)^2) + 
        ((3 - 9*x + 12*x^2 + 35*x^3 - 35*x^5 - 12*x^6 + 9*x^7 - 3*x^8)*
          HPL[{-1, 1, 0}, x])/(36*x^3) + (2*(1 + x^2)*HPL[{-1, 2, 0}, x])/3 + 
        (x^2*(-9 - 330*x + 72*x^2 - 366*x^3 + 907*x^4 + 6*x^5 - 9*x^6 + 
           3*x^7)*HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^2) + 
        (2*(1 + x^2)*HPL[{1, -2, 0}, x])/3 + 
        ((3 - 9*x + 12*x^2 + 35*x^3 - 35*x^5 - 12*x^6 + 9*x^7 - 3*x^8)*
          HPL[{1, -1, 0}, x])/(36*x^3) - 
        ((67 + 101*x + 93*x^2 + 107*x^3 + 61*x^4 + 3*x^5 + 3*x^6 - 3*x^7)*
          HPL[{1, 0, 0}, x])/(18*(1 + x)^2) + 
        ((-3 + 9*x - 12*x^2 - 35*x^3 + 35*x^5 + 12*x^6 - 9*x^7 + 3*x^8)*
          HPL[{1, 1, 0}, x])/(36*x^3) - (2*(1 + x^2)*HPL[{1, 2, 0}, x])/3 - 
        (2*(1 + x^2)*HPL[{2, -1, 0}, x])/3 + (8*x^2*HPL[{2, 0, 0}, x])/3 + 
        (2*(1 + x^2)*HPL[{2, 1, 0}, x])/3 + 
        (4*(-1 + x^2)*HPL[{-1, 0, 0, 0}, x])/3 - 
        (4*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/3 - 
        (4*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/3 - 
        (4*(-1 + x^2)*HPL[{1, 0, 0, 0}, x])/3 + 
        ((-1 + x + (4*x)/(-1 + x^2))*master3l10a[x])/24 + 
        ((x - x^2 + 3*x^3 + x^4)*master3l10b[x])/(24 - 24*x^2) + 
        ((-11 - 6*x + x^2)*master3l8a[x])/(24*(-1 + x^2)^2) + 
        ((-5 - 18*x + 39*x^2)*master3l8b[x])/(72*(-1 + x^2)^2) + 
        ((-9 + x^2)*master3l9a[x])/(6*(-1 + x^2)^2) + 
        ((-1 + 9*x^2)*master3l9b[x])/(18*(-1 + x^2)^2) + 
        (HPL[{-1}, x]*(Pi^2*(3 - 9*x + 12*x^2 + 35*x^3 - 35*x^5 - 12*x^6 + 
             9*x^7 - 3*x^8) - 288*x^3*(1 + x^2)*Zeta[3]))/(432*x^3) + 
        (HPL[{1}, x]*(Pi^2*(-3 + 9*x - 12*x^2 - 35*x^3 + 35*x^5 + 12*x^6 - 
             9*x^7 + 3*x^8) + 288*x^3*(1 + x^2)*Zeta[3]))/(432*x^3) + 
        (x*HPL[{0}, x]*(-18 + 12*(-426 + Pi^2)*x + 12*Pi^2*x^6 - 
           18*Pi^2*x^7 + 6*Pi^2*x^8 + x^3*(6345 - 84*Pi^2 - 864*Zeta[3]) + 
           6*x^2*(-1905 + 2*Pi^2 + 288*Zeta[3]) - 6*x^4*(-18 + 7*Pi^2 + 
             288*Zeta[3]) + x^5*(10107 + 62*Pi^2 + 864*Zeta[3])))/
         (432*(-1 + x^2)^2) + (8*Pi^4*x*(-1 + x^2)^2*(47 - 88*x + 31*x^2) - 
          10*Pi^2*(-1 + x^2)*(6 + 294*x^3 + 6*x^6 + 
            12*x^4*(-1 + 32*Log[2]^2) - 12*x^2*(1 + 32*Log[2]^2) + 
            x*(-161 + 192*Log[2]^2) - x^5*(161 + 192*Log[2]^2)) - 
          15*x*(-5269 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 2256*Zeta[3] + 
            48*x^7*Zeta[3] - 72*x^8*Zeta[3] + 24*x^9*Zeta[3] + 
            16*x^3*(-878 + 32*Log[2]^4 + 768*PolyLog[4, 1/2] + 415*Zeta[3]) - 
            4*x*(-931 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 806*Zeta[3]) - 
            4*x^5*(-931 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 848*Zeta[3]) - 
            x^2*(2951 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 1096*Zeta[3]) - 
            x^4*(-6409 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 
              2008*Zeta[3]) + x^6*(1691 + 128*Log[2]^4 + 3072*PolyLog[4, 
                1/2] + 2680*Zeta[3])))/(8640*x*(-1 + x^2)^2) + 
        lm*(-(x^2*(22 - 304*x + 119*x^2)*HPL[{0}, x])/(36*(-1 + x^2)) - 
          (11*(-1 + x^2)*HPL[{-1, 0}, x])/18 + 
          (22*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
           (9*(-1 + x^2)^2) + (11*(-1 + x^2)*HPL[{1, 0}, x])/18 + 
          (44*Pi^2*(-1 + x^2) - 9*(-137 + x*(550 - 144*Zeta[3]) + 
              72*Zeta[3] + x^2*(-137 + 72*Zeta[3])))/864)) + 
      CF*(NH*(-(lm^3*(-1 + x)^2)/36 + (x*(-48 + 472*x - 2985*x^2 + 
             1552*x^3 + 807*x^4 - 521*x^5 - 102*x^6 + 49*x^7)*HPL[{0}, x])/
           (36*(-1 + x^2)^3) + lm^2*((-7 + 20*x - 7*x^2)/72 + 
            ((-2 + x)*x^3*HPL[{0}, x])/(6*(-1 + x^2))) + 
          (x*(24 - 136*x + 1016*x^2 - 523*x^3 - 378*x^4 + 208*x^5 + 58*x^6 - 
             29*x^7)*HPL[{0, 0}, x])/(18*(-1 + x^2)^3) + 
          lm*((-4*Pi^2*(-1 + x^2) - 9*(9 - 38*x + 9*x^2))/432 + 
            (x^2*(2 - 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((-1 + x^2)*HPL[{-1, 0}, x])/9 - (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
              HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + ((1 - x^2)*HPL[{1, 0}, x])/
             9) + ((14 + 5*x - 19*x^3 + 8*x^4)*HPL[{-1, 0, 0}, x])/
           (9*(-1 + x)^2) - (2*x^3*(54 - 33*x - 6*x^2 + x^5)*
            HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
          ((-2 - 43*x + 12*x^2 + 5*x^3 - 8*x^4)*HPL[{1, 0, 0}, x])/
           (9*(1 + x)^2) + ((9 - 54*x + 28*x^2 + 6*x^3 - 5*x^4)*
            master3l8a[x])/(18*(-1 + x^2)^3) + 
          ((27 - 108*x + 51*x^2 + 12*x^3 - 15*x^4 + x^6)*master3l9a[x])/
           (18*(-1 + x^2)^3) + (x*(16923 - 768*Zeta[3]) + 
            39*(-99 + 32*Zeta[3]) - 4*x^8*(113 + 32*Zeta[3]) - 
            3*x^3*(-6687 + 64*Zeta[3]) + 3*x^7*(309 + 64*Zeta[3]) - 
            3*x^4*(3253 + 96*Zeta[3]) + x^6*(4517 + 320*Zeta[3]) - 
            3*x^2*(3535 + 384*Zeta[3]) + x^5*(-7671 + 768*Zeta[3]))/
           (432*(-1 + x^2)^3)) + NM*(-(lm^3*(-1 + x)^2)/36 + 
          ((2*Pi^2*(-1 + x^2)^4 + 3*(38 - 219*x^2 - 9*x^3 - 188*x^4 - 459*
                x^5 + 1030*x^6 - 1860*x^7 + 891*x^8))*HPL[{0}, x])/
           (108*(-1 + x^2)^3) + lm^2*((-7 + 20*x - 7*x^2)/72 + 
            ((-2 + x)*x^3*HPL[{0}, x])/(6*(-1 + x^2))) - 
          (2*(-1 + x^2)*HPL[{-2, 0}, x])/9 - 
          ((12 + 14*x^2 - 32*x^3 - 601*x^4 + 30*x^5 + 978*x^6 - 2446*x^7 + 
             1229*x^8)*HPL[{0, 0}, x])/(18*(-1 + x^2)^3) + 
          lm*((-4*Pi^2*(-1 + x^2) - 9*(9 - 38*x + 9*x^2))/432 + 
            (x^2*(2 - 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((-1 + x^2)*HPL[{-1, 0}, x])/9 - (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
              HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + ((1 - x^2)*HPL[{1, 0}, x])/
             9) + (2*(-1 + x^2)*HPL[{2, 0}, x])/9 + 
          ((12 - 27*x + 13*x^3 + 10*x^4)*HPL[{-1, 0, 0}, x])/(9*(-1 + x)^2) + 
          (2*(1 + 28*x^2 - 30*x^3 - 243*x^4 + 138*x^5 + 332*x^6 - 1020*x^7 + 
             490*x^8)*HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
          ((-12 - 3*x + 12*x^2 - 35*x^3 + 2*x^4)*HPL[{1, 0, 0}, x])/
           (9*(1 + x)^2) + ((2 - 15*x^2 + 6*x^3 + 18*x^4 - 54*x^5 + 27*x^6)*
            master3l8b[x])/(54*x^2*(-1 + x^2)^3) + 
          ((1 - 15*x^2 + 12*x^3 + 51*x^4 - 108*x^5 + 27*x^6)*master3l9b[x])/
           (54*x^2*(-1 + x^2)^3) + (15 + x^5*(3171 - 768*Zeta[3]) - 
            156*x^10*(9 + 8*Zeta[3]) - 3*x^3*(249 + 64*Zeta[3]) + 
            3*x^7*(1173 + 64*Zeta[3]) + 12*x^8*(-485 + 96*Zeta[3]) + 
            3*x^6*(283 + 96*Zeta[3]) + x^2*(-13 + 128*Zeta[3]) - 
            x^4*(347 + 320*Zeta[3]) + x^9*(4137 + 768*Zeta[3]))/
           (432*x^2*(-1 + x^2)^3)) + NL*(-(lm^3*(-1 + x)^2)/36 + 
          (Pi^2*(-1 + x^2)*HPL[{-1}, x])/54 - 
          (x^2*(84 + 6*(-57 + 4*Pi^2)*x - 3*(1 + 4*Pi^2)*x^2 + 342*x^3 + 
             (-81 + 4*Pi^2)*x^4)*HPL[{0}, x])/(216*(-1 + x^2)^2) + 
          lm^2*((-7 + 20*x - 7*x^2)/72 + ((-2 + x)*x^3*HPL[{0}, x])/
             (6*(-1 + x^2))) - (Pi^2*(-1 + x^2)*HPL[{1}, x])/54 + 
          (2*x^3*(6 - 3*x + x^3)*HPL[{-2, 0}, x])/(9*(-1 + x^2)^2) + 
          ((7 - 6*x - 10*x^2 - 6*x^3 + 7*x^4)*HPL[{-1, 0}, x])/
           (18*(-1 + x^2)) + (2*x^3*(-20 + 10*x + 13*x^2 - 7*x^3)*
            HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + 
          ((-7 + 6*x + 10*x^2 + 6*x^3 - 7*x^4)*HPL[{1, 0}, x])/
           (18*(-1 + x^2)) + lm*((-4*Pi^2*(-1 + x^2) - 9*(9 - 38*x + 9*x^2))/
             432 + (x^2*(2 - 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((-1 + x^2)*HPL[{-1, 0}, x])/9 - (4*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*
              HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + ((1 - x^2)*HPL[{1, 0}, x])/
             9) - (2*x^3*(6 - 3*x + x^3)*HPL[{2, 0}, x])/(9*(-1 + x^2)^2) - 
          (2*(-1 + x^2)*HPL[{-1, -1, 0}, x])/9 + 
          (2*(-1 + x^2)*HPL[{-1, 1, 0}, x])/9 + 
          (8*x^3*(6 - 3*x - 3*x^2 + 2*x^3)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x^2)^2) + (2*(-1 + x^2)*HPL[{1, -1, 0}, x])/9 - 
          (2*(-1 + x^2)*HPL[{1, 1, 0}, x])/9 - 
          (4*Pi^2*(-7 + 6*x + 17*x^2 - 17*x^4 - 6*x^5 + 7*x^6) + 
            3*(73 + 96*Zeta[3] - 8*x*(41 + 16*Zeta[3]) - 8*x^5*(41 + 
                16*Zeta[3]) + 16*x^3*(41 + 28*Zeta[3]) - x^4*(73 + 
                64*Zeta[3]) + x^6*(73 + 64*Zeta[3]) - x^2*(73 + 
                160*Zeta[3])))/(864*(-1 + x^2)^2))))
 
CbarLData["v", 2, 0] = 
    NC*(CA*CF*((Pi^2*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2}, x])/
         (27*(-1 + x^2)^2) - (Pi^2*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{2}, x])/(27*(-1 + x^2)^2) + 
        (x^2*(18 - 36*x + 54*x^2 + 309*x^3 - 96*x^4 - 171*x^5 + 134*x^6 + 
           27*x^7 - 78*x^8 + 15*x^9 + 20*x^10 - 8*x^11)*HPL[{-2, 0}, x])/
         (27*(-1 + x^2)^4) + ((24 - 60*x - 9*x^2 + (293 + 6*Pi^2)*x^3 - 
           2*(374 + 9*Pi^2)*x^4 - (311 + 30*Pi^2)*x^5 + 1058*x^6 + 
           (-311 + 30*Pi^2)*x^7 + 2*(-374 + 9*Pi^2)*x^8 + 
           (293 - 6*Pi^2)*x^9 - 9*x^10 - 60*x^11 + 24*x^12)*HPL[{-1, 0}, x])/
         (162*x^3*(-1 + x^2)^3) + (x^2*(486 + 84942*x + 37827*x^2 - 
           699990*x^3 - 298536*x^4 - 978312*x^5 + 1600633*x^6 + 160972*x^7 - 
           462668*x^8 - 10686*x^9 + 22362*x^10 + 4530*x^11 + 1080*x^12 - 
           432*x^13)*HPL[{0, 0}, x])/(162*(-1 + x^2)^4*(9 - 82*x^2 + 
           9*x^4)) + ((-24 + 60*x + 9*x^2 - (293 + 6*Pi^2)*x^3 + 
           2*(374 + 9*Pi^2)*x^4 + (311 + 30*Pi^2)*x^5 - 1058*x^6 + 
           (311 - 30*Pi^2)*x^7 + (748 - 18*Pi^2)*x^8 + (-293 + 6*Pi^2)*x^9 + 
           9*x^10 + 60*x^11 - 24*x^12)*HPL[{1, 0}, x])/
         (162*x^3*(-1 + x^2)^3) + 
        lm*((-11*(-3*(1 - 36*x - 22*x^2 - 36*x^3 + x^4) + 
             4*Pi^2*(-1 + 3*x - 3*x^3 + x^4)))/(1296*(-1 + x^2)^2) + 
          (11*x^2*(1 - 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x^2)^3) + 
          (11*(1 - 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x^2)) - 
          (22*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0}, x])/
           (27*(-1 + x^2)^4) - (11*(1 - 3*x + x^2)*HPL[{1, 0}, x])/
           (27*(-1 + x^2))) + (x^2*(-18 + 36*x - 54*x^2 - 309*x^3 + 96*x^4 + 
           171*x^5 - 134*x^6 - 27*x^7 + 78*x^8 - 15*x^9 - 20*x^10 + 8*x^11)*
          HPL[{2, 0}, x])/(27*(-1 + x^2)^4) - 
        (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2, -1, 0}, x])/
         (9*(-1 + x^2)^2) + (16*x^2*(-2 - 3*x + x^2)*HPL[{-2, 0, 0}, x])/
         (9*(-1 + x^2)^2) + (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-2, 1, 0}, x])/(9*(-1 + x^2)^2) + 
        (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-1, -2, 0}, x])/
         (9*(-1 + x^2)^2) + ((8 - 20*x + 9*x^2 + 18*x^3 - 24*x^4 - 42*x^5 + 
           146*x^6 - 42*x^7 - 24*x^8 + 18*x^9 + 9*x^10 - 20*x^11 + 8*x^12)*
          HPL[{-1, -1, 0}, x])/(54*x^5*(-1 + x^2)) + 
        ((-51 + 157*x + 7*x^2 - 200*x^3 + 99*x^4 + 120*x^5 - 139*x^6 + 
           108*x^7 - 16*x^8 - 49*x^9 + 36*x^10 - 8*x^11)*HPL[{-1, 0, 0}, x])/
         (27*(-1 + x)^4*(1 + x)^2) + ((8 - 20*x + 9*x^2 + 18*x^3 - 24*x^4 - 
           42*x^5 + 146*x^6 - 42*x^7 - 24*x^8 + 18*x^9 + 9*x^10 - 20*x^11 + 
           8*x^12)*HPL[{-1, 1, 0}, x])/(54*x^5 - 54*x^7) - 
        (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-1, 2, 0}, x])/
         (9*(-1 + x^2)^2) + (2*x^2*(-27 - 5049*x - 2679*x^2 + 34182*x^3 + 
           35826*x^4 + 123906*x^5 - 208865*x^6 - 30821*x^7 + 72525*x^8 + 
           3906*x^9 - 12030*x^10 + 1059*x^11 + 2342*x^12 - 791*x^13 - 
           180*x^14 + 72*x^15)*HPL[{0, 0, 0}, x])/(27*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4)) - (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x^2)^2) + 
        ((8 - 20*x + 9*x^2 + 18*x^3 - 24*x^4 - 42*x^5 + 146*x^6 - 42*x^7 - 
           24*x^8 + 18*x^9 + 9*x^10 - 20*x^11 + 8*x^12)*HPL[{1, -1, 0}, x])/
         (54*x^5 - 54*x^7) - ((-51 + x + 179*x^2 + 152*x^3 + 119*x^4 + 
           28*x^5 - 7*x^6 - 44*x^7 - 20*x^8 + 31*x^9 + 4*x^10 - 8*x^11)*
          HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*(1 + x)^4) + 
        ((8 - 20*x + 9*x^2 + 18*x^3 - 24*x^4 - 42*x^5 + 146*x^6 - 42*x^7 - 
           24*x^8 + 18*x^9 + 9*x^10 - 20*x^11 + 8*x^12)*HPL[{1, 1, 0}, x])/
         (54*x^5*(-1 + x^2)) + (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x^2)^2) + 
        (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{2, -1, 0}, x])/
         (9*(-1 + x^2)^2) - (16*x^2*(-2 - 3*x + x^2)*HPL[{2, 0, 0}, x])/
         (9*(-1 + x^2)^2) - (4*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{2, 1, 0}, x])/(9*(-1 + x^2)^2) - 
        (8*(1 - 3*x + x^2)*HPL[{-1, 0, 0, 0}, x])/(9*(-1 + x^2)) + 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-1, 1, 0, 0}, x])/
         (9*(-1 + x^2)^2) + (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x^2)^2) + 
        (8*(1 - 3*x + x^2)*HPL[{1, 0, 0, 0}, x])/(9*(-1 + x^2)) + 
        ((-2 + 7*x + 8*x^2 + 12*x^3 - 2*x^4 + x^5)*master3l10a[x])/
         (36*(-1 + x^2)^3) + (x*(-1 + 2*x - 12*x^2 - 8*x^3 - 7*x^4 + 2*x^5)*
          master3l10b[x])/(36*(-1 + x^2)^3) + 
        ((-81 + 819*x + 795*x^2 + 264*x^3 - 129*x^4 - 43*x^5 + 7*x^6)*
          master3l8a[x])/(108*(-9 + x^2)*(-1 + x^2)^4) + 
        ((15 + 31*x - 169*x^2 - 384*x^3 + 903*x^4 + 81*x^5 - 189*x^6)*
          master3l8b[x])/(108*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        ((-135 + 450*x + 849*x^2 - 60*x^3 - 149*x^4 - 6*x^5 + 11*x^6)*
          master3l9a[x])/(36*(-9 + x^2)*(-1 + x^2)^4) + 
        ((11 - 6*x - 149*x^2 - 60*x^3 + 849*x^4 + 450*x^5 - 135*x^6)*
          master3l9b[x])/(108*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(-8 + 20*x - x^2 - 38*x^3 + 33*x^4 + 60*x^5 - 
             170*x^6 + 170*x^8 - 60*x^9 - 33*x^10 + 38*x^11 + x^12 - 
             20*x^13 + 8*x^14) - 288*x^5*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
            Zeta[3]))/(648*x^5*(-1 + x^2)^2) + 
        (HPL[{-1}, x]*(Pi^2*(8 - 20*x + x^2 + 38*x^3 - 33*x^4 - 60*x^5 + 
             170*x^6 - 170*x^8 + 60*x^9 + 33*x^10 - 38*x^11 - x^12 + 
             20*x^13 - 8*x^14) + 288*x^5*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
            Zeta[3]))/(648*x^5*(-1 + x^2)^2) + 
        (HPL[{0}, x]*(-432 + 1080*x + 4314*x^2 - 12*(2230 + 27*Pi^2)*x^3 + 
           (27611 + 1980*Pi^2)*x^5 + 12*(30898 + 855*Pi^2)*x^7 - 
           2*(1238827 + 9564*Pi^2)*x^9 + 4*(198036 + 6277*Pi^2)*x^11 + 
           6*(6463 + 1206*Pi^2)*x^12 - 3*(19359 + 5188*Pi^2)*x^13 + 
           6*(72 + 353*Pi^2)*x^14 + 4684*Pi^2*x^15 - 1582*Pi^2*x^16 - 
           360*Pi^2*x^17 + 144*Pi^2*x^18 + 6*x^4*(-25021 + 108*Pi^2 + 
             3888*Zeta[3]) - 6*x^10*(98447 + 5682*Pi^2 + 3888*Zeta[3]) - 
           2*x^6*(-651148 + 5733*Pi^2 + 117936*Zeta[3]) + 
           2*x^8*(866990 + 27201*Pi^2 + 117936*Zeta[3])))/
         (648*x*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4)) + 
        (48*Pi^4*x^3*(-1 + x^2)^2*(-27 + 81*x + 66*x^2 - 1089*x^3 + 
            1730*x^4 + 3279*x^5 - 1246*x^6 - 351*x^7 + 117*x^8) - 
          40*Pi^2*(-216 + 540*x + 2265*x^2 - 8097*x^3 + 3729*x^4 + 
            34922*x^5 - 76555*x^6 - 52705*x^7 + 170997*x^8 - 170997*x^10 + 
            52705*x^11 + 76555*x^12 - 34922*x^13 - 3729*x^14 + 8097*x^15 - 
            2265*x^16 - 540*x^17 + 216*x^18) - 
          15*x^2*(-864 + x^6*(9692024 - 1586256*Zeta[3]) + 
            x^5*(4770255 - 1207296*Zeta[3]) + x^7*(275932 - 717216*Zeta[3]) + 
            112416*x^15*Zeta[3] - 37968*x^16*Zeta[3] - 8640*x^17*Zeta[3] + 
            3456*x^18*Zeta[3] + 144*x^14*(-6 + 353*Zeta[3]) - 
            45*x*(-1817 + 576*Zeta[3]) - 48*x^2*(6253 + 639*Zeta[3]) + 
            48*x^12*(4817 + 3573*Zeta[3]) - 45*x^13*(1891 + 9088*Zeta[3]) + 
            24*x^4*(71881 + 18430*Zeta[3]) - 24*x^10*(102719 + 
              30698*Zeta[3]) + 8*x^8*(394483 + 110994*Zeta[3]) + 
            2*x^3*(-654203 + 189360*Zeta[3]) + 2*x^11*(588157 + 
              547344*Zeta[3]) - 3*x^9*(1297295 + 632192*Zeta[3])))/
         (77760*x^3*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4))) + 
      CF^2*((-2*Pi^2*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2}, x])/
         (27*(-1 + x^2)^2) + (2*Pi^2*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{2}, x])/(27*(-1 + x^2)^2) + 
        (x^2*(-36 + 24*x - 132*x^2 - 786*x^3 + 204*x^4 + 658*x^5 - 486*x^6 - 
           337*x^7 + 519*x^8 + 23*x^9 - 285*x^10 + 73*x^11 + 63*x^12 - 
           27*x^13)*HPL[{-2, 0}, x])/(27*(-1 + x^2)^4) + 
        ((108 - 252*x - 130*x^2 + 762*x^3 - 332*x^4 - (735 + 16*Pi^2)*x^5 + 
           (214 + 48*Pi^2)*x^6 + (531 + 80*Pi^2)*x^7 + 1768*x^8 + 
           (531 - 80*Pi^2)*x^9 + (214 - 48*Pi^2)*x^10 + (-735 + 16*Pi^2)*
            x^11 - 332*x^12 + 762*x^13 - 130*x^14 - 252*x^15 + 108*x^16)*
          HPL[{-1, 0}, x])/(216*x^5*(-1 + x^2)^3) + 
        (x^2*(-2412 - 69444*x - 22538*x^2 + 539634*x^3 + 286706*x^4 + 
           1311030*x^5 - 2100677*x^6 - 323352*x^7 + 561810*x^8 + 4856*x^9 + 
           47481*x^10 - 18670*x^11 - 29790*x^12 + 10998*x^13 + 2268*x^14 - 
           972*x^15)*HPL[{0, 0}, x])/(108*(-1 + x^2)^4*(9 - 82*x^2 + 
           9*x^4)) + ((-108 + 252*x + 130*x^2 - 762*x^3 + 332*x^4 + 
           (735 + 16*Pi^2)*x^5 - 2*(107 + 24*Pi^2)*x^6 - (531 + 80*Pi^2)*
            x^7 - 1768*x^8 + (-531 + 80*Pi^2)*x^9 + (-214 + 48*Pi^2)*x^10 + 
           (735 - 16*Pi^2)*x^11 + 332*x^12 - 762*x^13 + 130*x^14 + 252*x^15 - 
           108*x^16)*HPL[{1, 0}, x])/(216*x^5*(-1 + x^2)^3) + 
        (x^2*(36 - 24*x + 132*x^2 + 786*x^3 - 204*x^4 - 658*x^5 + 486*x^6 + 
           337*x^7 - 519*x^8 - 23*x^9 + 285*x^10 - 73*x^11 - 63*x^12 + 
           27*x^13)*HPL[{2, 0}, x])/(27*(-1 + x^2)^4) + 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2, -1, 0}, x])/
         (9*(-1 + x^2)^2) - (16*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x^2)^2) - 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{-2, 1, 0}, x])/
         (9*(-1 + x^2)^2) - (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x^2)^2) + 
        ((-27 + 63*x - 35*x^2 - 33*x^3 + 45*x^4 + 9*x^5 - 55*x^6 + 55*x^8 - 
           9*x^9 - 45*x^10 + 33*x^11 + 35*x^12 - 63*x^13 + 27*x^14)*
          HPL[{-1, -1, 0}, x])/(54*x^7) - 
        ((-101 + 253*x - 2*x^2 - 382*x^3 + 469*x^4 + 121*x^5 - 548*x^6 + 
           368*x^7 + 197*x^8 - 425*x^9 + 134*x^10 + 134*x^11 - 117*x^12 + 
           27*x^13)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^2) + 
        ((27 - 63*x + 35*x^2 + 33*x^3 - 45*x^4 - 9*x^5 + 55*x^6 - 55*x^8 + 
           9*x^9 + 45*x^10 - 33*x^11 - 35*x^12 + 63*x^13 - 27*x^14)*
          HPL[{-1, 1, 0}, x])/(54*x^7) + (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x^2)^2) + 
        (2*x^2*(-270 + 9342*x - 2796*x^2 - 89910*x^3 + 78174*x^4 + 
           130956*x^5 - 552146*x^6 - 416260*x^7 + 628902*x^8 + 159854*x^9 - 
           235426*x^10 - 41508*x^11 + 87402*x^12 - 1760*x^13 - 36339*x^14 + 
           8893*x^15 + 8298*x^16 - 3114*x^17 - 567*x^18 + 243*x^19)*
          HPL[{0, 0, 0}, x])/(27*(-1 + x^2)^5*(9 - 82*x^2 + 9*x^4)) + 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{1, -2, 0}, x])/
         (9*(-1 + x^2)^2) + ((27 - 63*x + 35*x^2 + 33*x^3 - 45*x^4 - 9*x^5 + 
           55*x^6 - 55*x^8 + 9*x^9 + 45*x^10 - 33*x^11 - 35*x^12 + 63*x^13 - 
           27*x^14)*HPL[{1, -1, 0}, x])/(54*x^7) - 
        ((101 + 55*x - 106*x^2 + 218*x^3 + 263*x^4 - 17*x^5 - 172*x^6 + 
           184*x^7 + 155*x^8 - 211*x^9 - 58*x^10 + 118*x^11 + 9*x^12 - 
           27*x^13)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*(1 + x)^4) + 
        ((-27 + 63*x - 35*x^2 - 33*x^3 + 45*x^4 + 9*x^5 - 55*x^6 + 55*x^8 - 
           9*x^9 - 45*x^10 + 33*x^11 + 35*x^12 - 63*x^13 + 27*x^14)*
          HPL[{1, 1, 0}, x])/(54*x^7) - (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x^2)^2) - 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{2, -1, 0}, x])/
         (9*(-1 + x^2)^2) + (16*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{2, 0, 0}, x])/(9*(-1 + x^2)^2) + 
        (8*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{2, 1, 0}, x])/
         (9*(-1 + x^2)^2) - (16*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x^2)^2) - 
        (16*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*HPL[{1, -1, 0, 0}, x])/
         (9*(-1 + x^2)^2) - ((-2 + 7*x + 8*x^2 + 12*x^3 - 2*x^4 + x^5)*
          master3l10a[x])/(18*(-1 + x^2)^3) + 
        ((x - 2*x^2 + 12*x^3 + 8*x^4 + 7*x^5 - 2*x^6)*master3l10b[x])/
         (18*(-1 + x^2)^3) + ((81 - 819*x - 795*x^2 - 264*x^3 + 129*x^4 + 
           43*x^5 - 7*x^6)*master3l8a[x])/(54*(-9 + x^2)*(-1 + x^2)^4) + 
        ((-15 - 31*x + 169*x^2 + 384*x^3 - 903*x^4 - 81*x^5 + 189*x^6)*
          master3l8b[x])/(54*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        ((135 - 450*x - 849*x^2 + 60*x^3 + 149*x^4 + 6*x^5 - 11*x^6)*
          master3l9a[x])/(18*(-9 + x^2)*(-1 + x^2)^4) + 
        ((-11 + 6*x + 149*x^2 + 60*x^3 - 849*x^4 - 450*x^5 + 135*x^6)*
          master3l9b[x])/(54*(-1 + x^2)^4*(-1 + 9*x^2)) - 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(27 - 63*x + 62*x^2 - 30*x^3 + 
             17*x^4 - 39*x^5 + 72*x^6 - 39*x^7 + 17*x^8 - 30*x^9 + 62*x^10 - 
             63*x^11 + 27*x^12) + 576*x^7*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
            Zeta[3]))/(648*x^7*(-1 + x^2)^2) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(27 - 63*x + 62*x^2 - 30*x^3 + 
             17*x^4 - 39*x^5 + 72*x^6 - 39*x^7 + 17*x^8 - 30*x^9 + 62*x^10 - 
             63*x^11 + 27*x^12) + 576*x^7*(1 - 3*x - 4*x^2 - 3*x^3 + x^4)*
            Zeta[3]))/(648*x^7*(-1 + x^2)^2) + 
        (HPL[{0}, x]*(-2916 + 6804*x + 31536*x^2 - 85968*x^3 - 40485*x^4 + 
           9*(33467 + 144*Pi^2)*x^5 - 6*(38797 + 1176*Pi^2)*x^7 - 
           24*(50235 + 2056*Pi^2)*x^9 + (9717342 + 89160*Pi^2)*x^11 - 
           27*(123089 + 6868*Pi^2)*x^13 - (89115 + 135052*Pi^2)*x^14 + 
           12*(26064 + 16499*Pi^2)*x^15 + 8*(-3942 + 2131*Pi^2)*x^16 - 
           12*(567 + 9536*Pi^2)*x^17 + 4*(729 + 6022*Pi^2)*x^18 + 
           30924*Pi^2*x^19 - 11484*Pi^2*x^20 - 2268*Pi^2*x^21 + 
           972*Pi^2*x^22 - 9*x^6*(-62581 + 96*Pi^2 + 10368*Zeta[3]) + 
           6*x^8*(-946879 + 6028*Pi^2 + 157248*Zeta[3]) - 
           6*x^10*(1012361 + 47060*Pi^2 + 157248*Zeta[3]) + 
           x^12*(256252*Pi^2 + 729*(2699 + 128*Zeta[3]))))/
         (1296*x^3*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4)) - 
        (64*Pi^4*x^5*(-1 + x^2)^2*(9 - 27*x - 118*x^2 + 219*x^3 + 346*x^4 + 
            219*x^5 - 118*x^6 - 27*x^7 + 9*x^8) + 
          4*Pi^2*(-972 + 2268*x + 10998*x^2 - 29790*x^3 - 18670*x^4 + 
            98889*x^5 - 19336*x^6 - 143274*x^7 + 32604*x^8 + 117285*x^9 + 
            136500*x^10 - 136500*x^12 - 117285*x^13 - 32604*x^14 + 
            143274*x^15 + 19336*x^16 - 98889*x^17 + 18670*x^18 + 29790*x^19 - 
            10998*x^20 - 2268*x^21 + 972*x^22) + 
          x^2*(-5832 + 13608*x + 65016*x^2 + x^5*(6251894 - 2213856*Zeta[
                3]) + 742176*x^19*Zeta[3] - 275616*x^20*Zeta[3] - 
            54432*x^21*Zeta[3] + 23328*x^22*Zeta[3] - 
            48*x^4*(-36811 + 1782*Zeta[3]) + 24*x^16*(2709 + 17048*Zeta[3]) + 
            9*x^3*(-56615 + 17568*Zeta[3]) + 16*x^6*(-841013 + 
              22626*Zeta[3]) + 24*x^18*(-243 + 24088*Zeta[3]) - 
            72*x^17*(-189 + 38144*Zeta[3]) - 48*x^14*(7469 + 69308*Zeta[3]) - 
            48*x^10*(139373 + 75948*Zeta[3]) + 48*x^8*(-684053 + 
              83316*Zeta[3]) + 12*x^9*(634843 + 94592*Zeta[3]) + 
            39*x^7*(-622855 + 176576*Zeta[3]) + 33*x^11*(313855 + 
              278656*Zeta[3]) + 16*x^12*(206587 + 408300*Zeta[3]) + 
            9*x^15*(17545 + 545536*Zeta[3]) - 2*x^13*(1843493 + 
              3347712*Zeta[3])))/(10368*x^5*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4))) + 
      CF*(NH*((x*(2592 - 19728*x + 430128*x^2 - 114871*x^3 - 64570*x^4 + 
             6624*x^5 + 4322*x^6 + 4382*x^7 + 74*x^8 - 592*x^9 - 66*x^10 + 
             25*x^11)*HPL[{0}, x])/(216*(-9 + x^2)*(-1 + x^2)^5) - 
          (x*(648 - 3060*x + 77256*x^2 - 18407*x^3 - 19194*x^4 + 1708*x^5 - 
             1278*x^6 + 640*x^7 + 162*x^8 - 84*x^9 + 6*x^10 + 3*x^11)*
            HPL[{0, 0}, x])/(54*(-9 + x^2)*(-1 + x^2)^5) + 
          lm*((-3*(1 - 36*x - 22*x^2 - 36*x^3 + x^4) + 4*Pi^2*(-1 + 3*x - 
                3*x^3 + x^4))/(648*(-1 + x^2)^2) - (2*x^2*(1 - 6*x + x^2)*
              HPL[{0}, x])/(27*(-1 + x^2)^3) - (2*(1 - 3*x + x^2)*
              HPL[{-1, 0}, x])/(27*(-1 + x^2)) + 
            (4*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x^2)^4) + (2*(1 - 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x^2))) + ((62 + 200*x - 130*x^2 + 40*x^3 - 28*x^4 + 
             20*x^5 - 4*x^6)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^2) + 
          (4*x^3*(2646 - 549*x - 549*x^2 - 108*x^3 - 219*x^4 + 24*x^5 + 
             45*x^6 - 8*x^7 - 3*x^8 + x^9)*HPL[{0, 0, 0}, x])/
           (27*(-9 + x^2)*(-1 + x^2)^5) + (2*(-13 - 188*x - 61*x^2 - 52*x^3 - 
             10*x^4 - 2*x^5 + 2*x^6)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*
            (1 + x)^4) - ((189 - 3798*x + 1044*x^2 - 18*x^3 + 66*x^4 - 
             26*x^5 - 20*x^6 + 2*x^7 + x^8)*master3l8a[x])/
           (54*(-9 + x^2)*(-1 + x^2)^5) + ((-567 + 6102*x - 2034*x^2 + 
             1152*x^3 + 18*x^4 + 516*x^5 + 12*x^6 - 96*x^7 + 13*x^8 + 6*x^9 - 
             2*x^10)*master3l9a[x])/(54*(-9 + x^2)*(-1 + x^2)^5) + 
          (76302 + x^2*(395631 - 19968*Zeta[3]) + x^10*(3255 - 768*Zeta[3]) + 
            x^11*(515 - 192*Zeta[3]) - 22464*Zeta[3] + 
            x^12*(-135 + 64*Zeta[3]) + 4*x^8*(-5643 + 752*Zeta[3]) - 
            27*x*(40457 + 832*Zeta[3]) - 6*x^6*(5841 + 2944*Zeta[3]) - 
            6*x^7*(5683 + 2976*Zeta[3]) + x^9*(-1271 + 5376*Zeta[3]) - 
            6*x^5*(-63735 + 25952*Zeta[3]) + x^4*(388965 + 57792*Zeta[3]) + 
            3*x^3*(-558139 + 63616*Zeta[3]))/(1296*(-9 + x^2)*
            (-1 + x^2)^5)) + 
        NM*(((-8*Pi^2*(-1 + x^2)^4*(-1 + 3*x + 8*x^2 - 27*x^3 + 9*x^4) + 
             3*(152 - 456*x - 796*x^2 + 6748*x^3 - 847*x^4 - 28838*x^5 - 7304*
                x^6 - 142394*x^7 + 15966*x^8 - 151650*x^9 + 80116*x^10 - 
               55890*x^11 + 36873*x^12))*HPL[{0}, x])/(648*(-1 + x^2)^5*
            (-1 + 9*x^2)) + (4*(1 - 3*x + x^2)*HPL[{-2, 0}, x])/
           (27*(-1 + x^2)) + ((-24 + 72*x - 16*x^2 - 756*x^3 + 1167*x^4 - 
             2010*x^5 - 108*x^6 + 66378*x^7 + 4936*x^8 + 96354*x^9 - 
             45720*x^10 + 35802*x^11 - 25515*x^12)*HPL[{0, 0}, x])/
           (54*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          lm*((-3*(1 - 36*x - 22*x^2 - 36*x^3 + x^4) + 4*Pi^2*(-1 + 3*x - 
                3*x^3 + x^4))/(648*(-1 + x^2)^2) - (2*x^2*(1 - 6*x + x^2)*
              HPL[{0}, x])/(27*(-1 + x^2)^3) - (2*(1 - 3*x + x^2)*
              HPL[{-1, 0}, x])/(27*(-1 + x^2)) + 
            (4*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x^2)^4) + (2*(1 - 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x^2))) - (4*(1 - 3*x + x^2)*HPL[{2, 0}, x])/
           (27*(-1 + x^2)) + (2*(-6 + 30*x - 42*x^2 + 20*x^3 - 37*x^4 + 
             80*x^5 + 35*x^6)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^2) + 
          (4*(1 - 3*x + 20*x^2 - 3*x^3 - 191*x^4 + 939*x^5 + 116*x^6 - 
             7371*x^7 - 2061*x^8 - 21456*x^9 + 9424*x^10 - 8586*x^11 + 
             4851*x^12)*HPL[{0, 0, 0}, x])/(27*(-1 + x^2)^5*(-1 + 9*x^2)) - 
          (2*(-6 + 6*x + 30*x^2 + 52*x^3 + 41*x^4 + 184*x^5 + 17*x^6)*
            HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*(1 + x)^4) + 
          ((4 - 12*x - 29*x^2 + 186*x^3 + 36*x^4 - 954*x^5 - 234*x^6 - 
             2250*x^7 + 936*x^8 - 810*x^9 + 567*x^10)*master3l8b[x])/
           (162*x^2*(-1 + x^2)^5*(-1 + 9*x^2)) - 
          ((-2 + 6*x + 13*x^2 - 96*x^3 + 12*x^4 + 516*x^5 + 18*x^6 + 
             1152*x^7 - 2034*x^8 + 6102*x^9 - 567*x^10)*master3l9b[x])/
           (162*x^2*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          (30 - 90*x + x^9*(667980 - 155712*Zeta[3]) + 
            x^8*(2124 - 17664*Zeta[3]) + x^4*(5805 - 768*Zeta[3]) + 
            x^3*(3395 - 192*Zeta[3]) + x^2*(-810 + 64*Zeta[3]) - 
            27*x^13*(-3613 + 832*Zeta[3]) - 27*x^14*(1269 + 832*Zeta[3]) - 
            6*x^7*(-8957 + 2976*Zeta[3]) + x^6*(-17427 + 3008*Zeta[3]) + 
            12*x^10*(-7265 + 4816*Zeta[3]) + x^5*(-30881 + 5376*Zeta[3]) - 
            3*x^12*(45693 + 6656*Zeta[3]) + 3*x^11*(4901 + 63616*Zeta[3]))/
           (1296*x^2*(-1 + x^2)^5*(-1 + 9*x^2))) + 
        NL*(-(Pi^2*(1 - 3*x + x^2)*HPL[{-1}, x])/(81*(-1 + x^2)) + 
          (x^2*(18 - 12*(29 + 6*Pi^2)*x + 69*x^2 + (456 - 36*Pi^2)*x^3 - 
             2*(45 + 4*Pi^2)*x^4 - 12*(9 + Pi^2)*x^5 + (3 + 4*Pi^2)*x^6)*
            HPL[{0}, x])/(324*(-1 + x^2)^4) + (Pi^2*(1 - 3*x + x^2)*
            HPL[{1}, x])/(81*(-1 + x^2)) + (4*x^3*(18 + 9*x^2 + 2*x^3 + 
             3*x^4 - x^5)*HPL[{-2, 0}, x])/(27*(-1 + x^2)^4) + 
          ((-3 + 14*x + x^2 - 148*x^3 + x^4 + 14*x^5 - 3*x^6)*
            HPL[{-1, 0}, x])/(54*(-1 + x^2)^3) + 
          (x^3*(-120 - 6*x^2 + 4*x^3 - 14*x^4 + 3*x^5)*HPL[{0, 0}, x])/
           (27*(-1 + x^2)^4) - ((-3 + 14*x + x^2 - 148*x^3 + x^4 + 14*x^5 - 
             3*x^6)*HPL[{1, 0}, x])/(54*(-1 + x^2)^3) + 
          lm*((-3*(1 - 36*x - 22*x^2 - 36*x^3 + x^4) + 4*Pi^2*(-1 + 3*x - 
                3*x^3 + x^4))/(648*(-1 + x^2)^2) - (2*x^2*(1 - 6*x + x^2)*
              HPL[{0}, x])/(27*(-1 + x^2)^3) - (2*(1 - 3*x + x^2)*
              HPL[{-1, 0}, x])/(27*(-1 + x^2)) + 
            (4*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x^2)^4) + (2*(1 - 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x^2))) + (4*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*
            HPL[{2, 0}, x])/(27*(-1 + x^2)^4) + 
          (4*(1 - 3*x + x^2)*HPL[{-1, -1, 0}, x])/(27*(-1 + x^2)) - 
          (4*(1 - 3*x + x^2)*HPL[{-1, 1, 0}, x])/(27*(-1 + x^2)) - 
          (8*x^3*(-18 - 9*x^2 - 2*x^3 - 3*x^4 + x^5)*HPL[{0, 0, 0}, x])/
           (27*(-1 + x^2)^4) - (4*(1 - 3*x + x^2)*HPL[{1, -1, 0}, x])/
           (27*(-1 + x^2)) + (4*(1 - 3*x + x^2)*HPL[{1, 1, 0}, x])/
           (27*(-1 + x^2)) + (4*Pi^2*(-3 + 14*x + 4*x^2 - 162*x^3 + 162*x^5 - 
              4*x^6 - 14*x^7 + 3*x^8) - 3*(15 + 338*x^4 - 184*x^6 - 360*x^7 + 
              15*x^8 - 64*Zeta[3] + 24*x*(-15 + 8*Zeta[3]) + 
              72*x^3*(5 + 8*Zeta[3]) + 8*x^2*(-23 + 16*Zeta[3]) + 
              72*x^5*(5 + 16*Zeta[3])))/(2592*(-1 + x^2)^4))))
 
CbarLData["v", 2, 1] = 
    NC*(CA*CF*((Pi^2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{-2}, x])/(108*(-1 + x^2)^4) + 
        lm^2*((-11*(1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6))/
           (288*(-1 + x^2)^4) - (11*x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
           (12*(-1 + x^2)^5)) + (Pi^2*(-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 
           4*x^5 - x^6)*HPL[{2}, x])/(108*(-1 + x^2)^4) + 
        (x*(3 + 165*x - 6*x^2 + 789*x^3 + 5754*x^4 + 461*x^5 - 1310*x^6 + 
           2175*x^7 + 1582*x^8 - 3313*x^9 - 540*x^10 + 2682*x^11 - 372*x^12 - 
           1110*x^13 + 348*x^14 + 189*x^15 - 81*x^16)*HPL[{-2, 0}, x])/
         (216*(-1 + x^2)^6) + ((1620 - 3780*x - 4530*x^2 + 16530*x^3 - 
           30*x^4 + (-24331 + 80*Pi^2)*x^5 - 80*(69 + 4*Pi^2)*x^6 + 
           (8784 - 1600*Pi^2)*x^7 - 40*(1133 + 104*Pi^2)*x^8 - 35166*x^9 + 
           40*(-1133 + 104*Pi^2)*x^10 + 16*(549 + 100*Pi^2)*x^11 + 
           80*(-69 + 4*Pi^2)*x^12 - (24331 + 80*Pi^2)*x^13 - 30*x^14 + 
           16530*x^15 - 4530*x^16 - 3780*x^17 + 1620*x^18)*HPL[{-1, 0}, x])/
         (8640*x^5*(-1 + x^2)^5) + (x*(14580 + 2165292*x + 19896030*x^2 - 
           21856833*x^3 - 294211440*x^4 - 82997683*x^5 + 376333390*x^6 + 
           1348334612*x^7 + 5464656740*x^8 - 3527388452*x^9 + 
           2746622870*x^10 + 1456475729*x^11 + 454371390*x^12 - 
           661341095*x^13 - 271517850*x^14 - 27492126*x^15 + 66953460*x^16 + 
           49956750*x^17 - 20597220*x^18 - 7224390*x^19 + 2889270*x^20 + 
           306180*x^21 - 131220*x^22)*HPL[{0, 0}, x])/(4320*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) + ((-1620 + 3780*x + 4530*x^2 - 16530*x^3 + 
           30*x^4 + (24331 - 80*Pi^2)*x^5 + 80*(69 + 4*Pi^2)*x^6 + 
           16*(-549 + 100*Pi^2)*x^7 + 40*(1133 + 104*Pi^2)*x^8 + 35166*x^9 + 
           (45320 - 4160*Pi^2)*x^10 - 16*(549 + 100*Pi^2)*x^11 - 
           80*(-69 + 4*Pi^2)*x^12 + (24331 + 80*Pi^2)*x^13 + 30*x^14 - 
           16530*x^15 + 4530*x^16 + 3780*x^17 - 1620*x^18)*HPL[{1, 0}, x])/
         (8640*x^5*(-1 + x^2)^5) + 
        lm*(-(44*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 
             3*(161 + 16*x + 39*x^2 - 6528*x^3 + 39*x^4 + 16*x^5 + 161*x^6))/
           (5184*(-1 + x^2)^4) + (x^2*(22 - 2506*x - 879*x^2 - 3694*x^3 - 
             242*x^4 - 132*x^5 + 33*x^6)*HPL[{0}, x])/(216*(-1 + x^2)^5) + 
          (11*(1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0}, x])/(108*(-1 + x^2)^3) - 
          (11*x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 136*x^4 - 3*x^5 - 4*x^6 + 
             x^7)*HPL[{0, 0}, x])/(54*(-1 + x^2)^6) - 
          (11*(1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/(108*(-1 + x^2)^3)) + 
        (x*(-3 - 165*x + 6*x^2 - 789*x^3 - 5754*x^4 - 461*x^5 + 1310*x^6 - 
           2175*x^7 - 1582*x^8 + 3313*x^9 + 540*x^10 - 2682*x^11 + 372*x^12 + 
           1110*x^13 - 348*x^14 - 189*x^15 + 81*x^16)*HPL[{2, 0}, x])/
         (216*(-1 + x^2)^6) + ((-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - 
           x^6)*HPL[{-2, -1, 0}, x])/(9*(-1 + x^2)^4) + 
        (4*x^2*(-9 - 28*x - 10*x^2 - 4*x^3 + x^4)*HPL[{-2, 0, 0}, x])/
         (9*(-1 + x^2)^4) + ((1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + 
           x^6)*HPL[{-2, 1, 0}, x])/(9*(-1 + x^2)^4) + 
        ((1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x^2)^4) + 
        ((81 - 189*x - 105*x^2 + 543*x^3 - 186*x^4 - 486*x^5 + 378*x^6 - 
           7*x^7 + 184*x^8 + 102*x^9 + 184*x^10 - 7*x^11 + 378*x^12 - 
           486*x^13 - 186*x^14 + 543*x^15 - 105*x^16 - 189*x^17 + 81*x^18)*
          HPL[{-1, -1, 0}, x])/(432*x^7*(-1 + x^2)^3) + 
        ((797 - 2859*x + 3721*x^2 - 4203*x^3 + 9015*x^4 - 1263*x^5 - 
           4679*x^6 + 2721*x^7 + 8747*x^8 - 12705*x^9 + 675*x^10 + 
           8655*x^11 - 4575*x^12 - 1365*x^13 + 1755*x^14 - 405*x^15)*
          HPL[{-1, 0, 0}, x])/(1080*(-1 + x)^6*(1 + x)^4) + 
        ((-81 + 189*x + 105*x^2 - 543*x^3 + 186*x^4 + 486*x^5 - 378*x^6 + 
           7*x^7 - 184*x^8 - 102*x^9 - 184*x^10 + 7*x^11 - 378*x^12 + 
           486*x^13 + 186*x^14 - 543*x^15 + 105*x^16 + 189*x^17 - 81*x^18)*
          HPL[{-1, 1, 0}, x])/(432*x^7*(-1 + x^2)^3) + 
        ((-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x^2)^4) + 
        (x*(-1215 - 57105*x - 3662550*x^2 - 3206655*x^3 + 45744330*x^4 + 
           80230173*x^5 + 70296690*x^6 - 612033039*x^7 - 1595727840*x^8 + 
           1810115311*x^9 - 498635290*x^10 - 1016478681*x^11 - 
           439968730*x^12 + 715901371*x^13 + 154641870*x^14 - 
           323189703*x^15 + 15419505*x^16 + 125149782*x^17 - 30212160*x^18 - 
           31570560*x^19 + 11015460*x^20 + 3688740*x^21 - 1477440*x^22 - 
           153090*x^23 + 65610*x^24)*HPL[{0, 0, 0}, x])/(1080*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) + ((-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 
           4*x^5 - x^6)*HPL[{1, -2, 0}, x])/(9*(-1 + x^2)^4) + 
        ((-81 + 189*x + 105*x^2 - 543*x^3 + 186*x^4 + 486*x^5 - 378*x^6 + 
           7*x^7 - 184*x^8 - 102*x^9 - 184*x^10 + 7*x^11 - 378*x^12 + 
           486*x^13 + 186*x^14 - 543*x^15 + 105*x^16 + 189*x^17 - 81*x^18)*
          HPL[{1, -1, 0}, x])/(432*x^7*(-1 + x^2)^3) + 
        ((-797 - 809*x + 2299*x^2 + 7267*x^3 + 865*x^4 + 4747*x^5 - 221*x^6 + 
           4951*x^7 + 2533*x^8 - 7875*x^9 - 2295*x^10 + 5985*x^11 + 
           855*x^12 - 2415*x^13 - 135*x^14 + 405*x^15)*HPL[{1, 0, 0}, x])/
         (1080*(-1 + x)^4*(1 + x)^6) + ((81 - 189*x - 105*x^2 + 543*x^3 - 
           186*x^4 - 486*x^5 + 378*x^6 - 7*x^7 + 184*x^8 + 102*x^9 + 
           184*x^10 - 7*x^11 + 378*x^12 - 486*x^13 - 186*x^14 + 543*x^15 - 
           105*x^16 - 189*x^17 + 81*x^18)*HPL[{1, 1, 0}, x])/
         (432*x^7*(-1 + x^2)^3) + ((1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 
           4*x^5 + x^6)*HPL[{1, 2, 0}, x])/(9*(-1 + x^2)^4) + 
        ((1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x^2)^4) + 
        (4*x^2*(9 + 28*x + 10*x^2 + 4*x^3 - x^4)*HPL[{2, 0, 0}, x])/
         (9*(-1 + x^2)^4) + ((-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - 
           x^6)*HPL[{2, 1, 0}, x])/(9*(-1 + x^2)^4) - 
        (2*(1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
        (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x^2)^4) + 
        (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x^2)^4) + 
        (2*(1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
        ((-2 + 11*x + 31*x^2 + 177*x^3 + 76*x^4 + 73*x^5 - 9*x^6 + 3*x^7)*
          master3l10a[x])/(144*(-1 + x^2)^5) + 
        (x*(-3 + 9*x - 73*x^2 - 76*x^3 - 177*x^4 - 31*x^5 - 11*x^6 + 2*x^7)*
          master3l10b[x])/(144*(-1 + x^2)^5) - 
        ((78489 + 266355*x + 335988*x^2 + 795960*x^3 + 323646*x^4 - 
           63690*x^5 - 88764*x^6 - 17120*x^7 + 6641*x^8 + 1535*x^9 - 
           128*x^10)*master3l8a[x])/(4320*(-9 + x^2)^2*(-1 + x^2)^6) - 
        ((10 + 638*x + 1425*x^2 - 13729*x^3 - 29180*x^4 + 124352*x^5 + 
           127290*x^6 - 475446*x^7 + 85770*x^8 + 105786*x^9 + 111645*x^10 - 
           68769*x^11)*master3l8b[x])/(4320*x*(1 - 9*x^2)^2*(-1 + x^2)^6) + 
        ((8181 + 8595*x + 13698*x^2 + 40410*x^3 + 45916*x^4 - 6120*x^5 - 
           6738*x^6 - 10*x^7 + 383*x^8 + 5*x^9)*master3l9a[x])/
         (1440*(-9 + x^2)*(-1 + x^2)^6) + 
        ((5 + 383*x - 10*x^2 - 6738*x^3 - 6120*x^4 + 45916*x^5 + 40410*x^6 + 
           13698*x^7 + 8595*x^8 + 8181*x^9)*master3l9b[x])/
         (4320*x*(-1 + x^2)^6*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(-81 + 189*x + 186*x^2 - 732*x^3 + 81*x^4 + 
             1029*x^5 - 564*x^6 - 479*x^7 + 194*x^8 - 109*x^9 + 109*x^11 - 
             194*x^12 + 479*x^13 + 564*x^14 - 1029*x^15 - 81*x^16 + 
             732*x^17 - 186*x^18 - 189*x^19 + 81*x^20) - 
           576*x^7*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
            Zeta[3]))/(5184*x^7*(-1 + x^2)^4) + 
        (HPL[{-1}, x]*(Pi^2*(81 - 189*x - 186*x^2 + 732*x^3 - 81*x^4 - 
             1029*x^5 + 564*x^6 + 479*x^7 - 194*x^8 + 109*x^9 - 109*x^11 + 
             194*x^12 - 479*x^13 - 564*x^14 + 1029*x^15 + 81*x^16 - 
             732*x^17 + 186*x^18 + 189*x^19 - 81*x^20) + 
           576*x^7*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
            Zeta[3]))/(5184*x^7*(-1 + x^2)^4) + 
        (HPL[{0}, x]*(-393660 + 918540*x + 8470980*x^2 - 21213900*x^3 - 
           405*(142879 + 12*Pi^2)*x^4 - 243*(-513079 + 1100*Pi^2)*x^5 - 
           150*(186761105 + 5559046*Pi^2)*x^12 - 216*(4261087 + 2332230*Pi^2)*
            x^19 + 15*(-137673 + 2875492*Pi^2)*x^20 + 
           15*(4117311 + 16199212*Pi^2)*x^21 - 60*(141183 + 1007072*Pi^2)*
            x^22 - 34020*(27 + 1856*Pi^2)*x^23 + 540*(729 + 40798*Pi^2)*
            x^24 + 7377480*Pi^2*x^25 - 2954880*Pi^2*x^26 - 306180*Pi^2*x^27 + 
           131220*Pi^2*x^28 + 10*x^13*(882854985 + 2910812*Pi^2 - 
             86697216*Zeta[3]) - 20*x^16*(52902375 + 14060194*Pi^2 - 
             15303168*Zeta[3]) - 12*x^15*(375783054 + 32446255*Pi^2 - 
             13452480*Zeta[3]) + 20*x^17*(217112874 + 30034819*Pi^2 - 
             419904*Zeta[3]) + 90*x^18*(8028935 + 1240516*Pi^2 - 
             186624*Zeta[3]) + 180*x^7*(882815 + 19959*Pi^2 + 
             46656*Zeta[3]) + 90*x^6*(923281 + 1092*Pi^2 + 186624*Zeta[3]) - 
           60*x^8*(-7921179 + 165196*Pi^2 + 5101056*Zeta[3]) - 
           12*x^9*(192759431 + 14945*Pi^2 + 13452480*Zeta[3]) + 
           30*x^10*(72129745 + 5763172*Pi^2 + 47036160*Zeta[3]) + 
           x^11*(812707740 - 93705060*Pi^2 + 866972160*Zeta[3]) + 
           10*x^14*(39785644*Pi^2 - 3*(403031513 + 47036160*Zeta[3]))))/
         (51840*x^3*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        (64*Pi^4*x^5*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(-3 + 12*x - 87*x^2 - 
            280*x^3 - 103*x^4 - 52*x^5 + 13*x^6) - 
          4*Pi^2*(9 - 82*x^2 + 9*x^4)^2*(-1620 + 3780*x + 6150*x^2 - 
            20310*x^3 - 4500*x^4 + 40861*x^5 + 5490*x^6 - 33115*x^7 + 
            39800*x^8 + 43950*x^9 - 43950*x^11 - 39800*x^12 + 33115*x^13 - 
            5490*x^14 - 40861*x^15 + 4500*x^16 + 20310*x^17 - 6150*x^18 - 
            3780*x^19 + 1620*x^20) + x^2*(787320 - 1837080*x - 17277300*x^2 + 
            x^7*(3482676640 - 4766682432*Zeta[3]) - 177059520*x^25*Zeta[3] + 
            70917120*x^26*Zeta[3] + 7348320*x^27*Zeta[3] - 
            3149280*x^28*Zeta[3] + 204120*x^23*(-9 + 7424*Zeta[3]) + 
            810*x^4*(380303 + 69456*Zeta[3]) - 3240*x^24*
             (-243 + 163192*Zeta[3]) - 81*x^3*(-1934245 + 387552*Zeta[3]) + 
            720*x^22*(-23895 + 2014144*Zeta[3]) - 1620*x^18*
             (21251 + 2194784*Zeta[3]) + 440*x^14*(-884767 + 2322768*Zeta[
                3]) - 360*x^6*(6009217 + 2824368*Zeta[3]) - 
            90*x^20*(-1389447 + 10954192*Zeta[3]) + 
            320*x^8*(-31792037 + 13526943*Zeta[3]) + 320*x^16*
             (-11961617 + 31276620*Zeta[3]) + 80*x^10*(1217950169 + 
              64332792*Zeta[3]) + 9*x^5*(-218927495 + 73606848*Zeta[3]) - 
            224*x^17*(-3789035 + 84157938*Zeta[3]) + 
            64*x^9*(347633345 + 250085748*Zeta[3]) + 
            64*x^15*(-385627570 + 386667183*Zeta[3]) - 
            60*x^12*(-1766691143 + 417676856*Zeta[3]) - 
            9*x^21*(1114875 + 651266368*Zeta[3]) + 
            9*x^19*(45603745 + 1412224608*Zeta[3]) - 
            6*x^11*(-5283157295 + 5244788752*Zeta[3]) - 
            6*x^13*(-4027677815 + 5601577472*Zeta[3])))/
         (414720*x^5*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF^2*((Pi^2*(-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{-2}, x])/(54*(-1 + x^2)^4) + 
        lm^2*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6)/
           (16*(-1 + x^2)^4) + (3*x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
           (2*(-1 + x^2)^5)) + (Pi^2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 
           4*x^5 + x^6)*HPL[{2}, x])/(54*(-1 + x^2)^4) - 
        (x*(15 + 825*x + 2730*x^2 + 5085*x^3 + 38610*x^4 + 4885*x^5 - 
           22950*x^6 + 22695*x^7 + 38830*x^8 - 53827*x^9 - 28334*x^10 + 
           66964*x^11 + 4306*x^12 - 47356*x^13 + 8706*x^14 + 18099*x^15 - 
           6129*x^16 - 2916*x^17 + 1296*x^18)*HPL[{-2, 0}, x])/
         (540*(-1 + x^2)^6) + ((77760 - 174960*x - 251100*x^2 + 823500*x^3 + 
           113310*x^4 - 1533210*x^5 + 529710*x^6 + (1396573 - 1200*Pi^2)*
            x^7 + 30*(-33893 + 160*Pi^2)*x^8 + 4*(-132403 + 6000*Pi^2)*x^9 + 
           30*(55317 + 2080*Pi^2)*x^10 + 902658*x^11 - 
           30*(-55317 + 2080*Pi^2)*x^12 - 4*(132403 + 6000*Pi^2)*x^13 - 
           30*(33893 + 160*Pi^2)*x^14 + (1396573 + 1200*Pi^2)*x^15 + 
           529710*x^16 - 1533210*x^17 + 113310*x^18 + 823500*x^19 - 
           251100*x^20 - 174960*x^21 + 77760*x^22)*HPL[{-1, 0}, x])/
         (64800*x^7*(-1 + x^2)^5) - (x*(218700 + 34442820*x + 268201530*x^2 - 
           422417295*x^3 - 3936086460*x^4 - 34005585*x^5 + 4471314990*x^6 + 
           15570856200*x^7 + 75196130610*x^8 - 51845369792*x^9 + 
           49208866590*x^10 + 8825980267*x^11 - 6172209750*x^12 + 
           11251412923*x^13 + 1308159510*x^14 - 19488145758*x^15 + 
           2486885130*x^16 + 10709350038*x^17 - 2883444480*x^18 - 
           2869395030*x^19 + 1050369930*x^20 + 339116220*x^21 - 
           141411420*x^22 - 14171760*x^23 + 6298560*x^24)*HPL[{0, 0}, x])/
         (32400*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        ((-77760 + 174960*x + 251100*x^2 - 823500*x^3 - 113310*x^4 + 
           1533210*x^5 - 529710*x^6 + (-1396573 + 1200*Pi^2)*x^7 - 
           30*(-33893 + 160*Pi^2)*x^8 + (529612 - 24000*Pi^2)*x^9 - 
           30*(55317 + 2080*Pi^2)*x^10 - 902658*x^11 + 
           30*(-55317 + 2080*Pi^2)*x^12 + 4*(132403 + 6000*Pi^2)*x^13 + 
           30*(33893 + 160*Pi^2)*x^14 - (1396573 + 1200*Pi^2)*x^15 - 
           529710*x^16 + 1533210*x^17 - 113310*x^18 - 823500*x^19 + 
           251100*x^20 + 174960*x^21 - 77760*x^22)*HPL[{1, 0}, x])/
         (64800*x^7*(-1 + x^2)^5) + 
        lm*((2*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 
            3*(4 + 14*x + 25*x^2 - 164*x^3 + 25*x^4 + 14*x^5 + 4*x^6))/
           (144*(-1 + x^2)^4) + (x^2*(-2 + 188*x + 60*x^2 + 296*x^3 + 
             22*x^4 + 12*x^5 - 3*x^6)*HPL[{0}, x])/(12*(-1 + x^2)^5) - 
          ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0}, x])/(6*(-1 + x^2)^3) + 
          (x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 136*x^4 - 3*x^5 - 4*x^6 + 
             x^7)*HPL[{0, 0}, x])/(3*(-1 + x^2)^6) + 
          ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/(6*(-1 + x^2)^3)) + 
        (x*(15 + 825*x + 2730*x^2 + 5085*x^3 + 38610*x^4 + 4885*x^5 - 
           22950*x^6 + 22695*x^7 + 38830*x^8 - 53827*x^9 - 28334*x^10 + 
           66964*x^11 + 4306*x^12 - 47356*x^13 + 8706*x^14 + 18099*x^15 - 
           6129*x^16 - 2916*x^17 + 1296*x^18)*HPL[{2, 0}, x])/
         (540*(-1 + x^2)^6) + (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 
           4*x^5 + x^6)*HPL[{-2, -1, 0}, x])/(9*(-1 + x^2)^4) + 
        (4*(-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x^2)^4) + 
        ((-2 + 8*x + 38*x^2 + 112*x^3 + 38*x^4 + 8*x^5 - 2*x^6)*
          HPL[{-2, 1, 0}, x])/(9*(-1 + x^2)^4) + 
        ((-2 + 8*x + 38*x^2 + 112*x^3 + 38*x^4 + 8*x^5 - 2*x^6)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x^2)^4) + 
        ((1296 - 2916*x + 351*x^2 + 3519*x^3 - 2499*x^4 - 601*x^5 + 
           1261*x^6 - 391*x^7 - 9*x^8 + 178*x^9 - 9*x^10 - 391*x^11 + 
           1261*x^12 - 601*x^13 - 2499*x^14 + 3519*x^15 + 351*x^16 - 
           2916*x^17 + 1296*x^18)*HPL[{-1, -1, 0}, x])/
         (1080*x^9*(-1 + x^2)) - ((961 - 4369*x + 3039*x^2 - 6471*x^3 + 
           16575*x^4 + 3543*x^5 - 17909*x^6 + 393*x^7 + 34795*x^8 - 
           32895*x^9 - 22051*x^10 + 48663*x^11 - 8311*x^12 - 27735*x^13 + 
           16425*x^14 + 3591*x^15 - 5508*x^16 + 1296*x^17)*
          HPL[{-1, 0, 0}, x])/(540*(-1 + x)^6*(1 + x)^4) + 
        ((-1296 + 2916*x - 351*x^2 - 3519*x^3 + 2499*x^4 + 601*x^5 - 
           1261*x^6 + 391*x^7 + 9*x^8 - 178*x^9 + 9*x^10 + 391*x^11 - 
           1261*x^12 + 601*x^13 + 2499*x^14 - 3519*x^15 - 351*x^16 + 
           2916*x^17 - 1296*x^18)*HPL[{-1, 1, 0}, x])/(1080*x^9*(-1 + x^2)) + 
        (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x^2)^4) + 
        (x*(-1215 - 76545*x + 3181545*x^2 + 655290*x^3 - 47253120*x^4 + 
           31166748*x^5 + 129241320*x^6 - 620025492*x^7 - 26451570*x^8 + 
           3373313510*x^9 + 3535336414*x^10 - 3028346856*x^11 - 
           986161904*x^12 + 2610887716*x^13 + 1542414584*x^14 - 
           2708218538*x^15 - 738676569*x^16 + 2213587489*x^17 + 
           7544639*x^18 - 1324611878*x^19 + 234137292*x^20 + 509769612*x^21 - 
           150588612*x^22 - 112799142*x^23 + 42170382*x^24 + 12012462*x^25 - 
           5028642*x^26 - 472392*x^27 + 209952*x^28)*HPL[{0, 0, 0}, x])/
         (540*(-1 + x^2)^7*(9 - 82*x^2 + 9*x^4)^2) + 
        (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x^2)^4) + 
        ((-1296 + 2916*x - 351*x^2 - 3519*x^3 + 2499*x^4 + 601*x^5 - 
           1261*x^6 + 391*x^7 + 9*x^8 - 178*x^9 + 9*x^10 + 391*x^11 - 
           1261*x^12 + 601*x^13 + 2499*x^14 - 3519*x^15 - 351*x^16 + 
           2916*x^17 - 1296*x^18)*HPL[{1, -1, 0}, x])/(1080*x^9*(-1 + x^2)) - 
        ((-961 + 45*x + 7709*x^2 + 22375*x^3 + 23329*x^4 + 16909*x^5 - 
           2303*x^6 + 12607*x^7 + 11765*x^8 - 26645*x^9 - 12009*x^10 + 
           30961*x^11 + 6967*x^12 - 21333*x^13 - 2277*x^14 + 8073*x^15 + 
           324*x^16 - 1296*x^17)*HPL[{1, 0, 0}, x])/(540*(-1 + x)^4*
          (1 + x)^6) + ((1296 - 2916*x + 351*x^2 + 3519*x^3 - 2499*x^4 - 
           601*x^5 + 1261*x^6 - 391*x^7 - 9*x^8 + 178*x^9 - 9*x^10 - 
           391*x^11 + 1261*x^12 - 601*x^13 - 2499*x^14 + 3519*x^15 + 
           351*x^16 - 2916*x^17 + 1296*x^18)*HPL[{1, 1, 0}, x])/
         (1080*x^9*(-1 + x^2)) + ((-2 + 8*x + 38*x^2 + 112*x^3 + 38*x^4 + 
           8*x^5 - 2*x^6)*HPL[{1, 2, 0}, x])/(9*(-1 + x^2)^4) + 
        ((-2 + 8*x + 38*x^2 + 112*x^3 + 38*x^4 + 8*x^5 - 2*x^6)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x^2)^4) + 
        (4*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{2, 0, 0}, x])/(9*(-1 + x^2)^4) + 
        (2*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
          HPL[{2, 1, 0}, x])/(9*(-1 + x^2)^4) + 
        (4*(-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x^2)^4) + 
        (4*(-1 + 4*x + 19*x^2 + 56*x^3 + 19*x^4 + 4*x^5 - x^6)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x^2)^4) - 
        ((-2 + 11*x + 31*x^2 + 177*x^3 + 76*x^4 + 73*x^5 - 9*x^6 + 3*x^7)*
          master3l10a[x])/(72*(-1 + x^2)^5) + 
        (x*(3 - 9*x + 73*x^2 + 76*x^3 + 177*x^4 + 31*x^5 + 11*x^6 - 2*x^7)*
          master3l10b[x])/(72*(-1 + x^2)^5) + 
        ((78489 + 266355*x + 335988*x^2 + 795960*x^3 + 323646*x^4 - 
           63690*x^5 - 88764*x^6 - 17120*x^7 + 6641*x^8 + 1535*x^9 - 
           128*x^10)*master3l8a[x])/(2160*(-9 + x^2)^2*(-1 + x^2)^6) + 
        ((10 + 638*x + 1425*x^2 - 13729*x^3 - 29180*x^4 + 124352*x^5 + 
           127290*x^6 - 475446*x^7 + 85770*x^8 + 105786*x^9 + 111645*x^10 - 
           68769*x^11)*master3l8b[x])/(2160*x*(1 - 9*x^2)^2*(-1 + x^2)^6) - 
        ((8181 + 8595*x + 13698*x^2 + 40410*x^3 + 45916*x^4 - 6120*x^5 - 
           6738*x^6 - 10*x^7 + 383*x^8 + 5*x^9)*master3l9a[x])/
         (720*(-9 + x^2)*(-1 + x^2)^6) - 
        ((5 + 383*x - 10*x^2 - 6738*x^3 - 6120*x^4 + 45916*x^5 + 40410*x^6 + 
           13698*x^7 + 8595*x^8 + 8181*x^9)*master3l9b[x])/
         (2160*x*(-1 + x^2)^6*(-1 + 9*x^2)) - 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(1296 - 2916*x + 351*x^2 + 
             3519*x^3 - 2499*x^4 - 601*x^5 + 1261*x^6 - 391*x^7 - 9*x^8 + 
             178*x^9 - 9*x^10 - 391*x^11 + 1261*x^12 - 601*x^13 - 2499*x^14 + 
             3519*x^15 + 351*x^16 - 2916*x^17 + 1296*x^18) + 
           2880*x^9*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
            Zeta[3]))/(12960*x^9*(-1 + x^2)^4) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(1296 - 2916*x + 351*x^2 + 3519*x^3 - 
             2499*x^4 - 601*x^5 + 1261*x^6 - 391*x^7 - 9*x^8 + 178*x^9 - 
             9*x^10 - 391*x^11 + 1261*x^12 - 601*x^13 - 2499*x^14 + 
             3519*x^15 + 351*x^16 - 2916*x^17 + 1296*x^18) + 
           2880*x^9*(1 - 4*x - 19*x^2 - 56*x^3 - 19*x^4 - 4*x^5 + x^6)*
            Zeta[3]))/(12960*x^9*(-1 + x^2)^4) + 
        (HPL[{0}, x]*(-6298560 + 14171760*x + 138262140*x^2 - 332030340*x^3 - 
           981763740*x^4 + 2704560840*x^5 + 405*(5938783 + 60*Pi^2)*x^6 + 
           81*(-114940631 + 16500*Pi^2)*x^7 + 450*(329642927 + 13282650*Pi^2)*
            x^14 + 2*(6617526093 + 6137645260*Pi^2)*x^21 + 
           5*(-422257293 + 245083300*Pi^2)*x^22 - 
           5*(581025393 + 1824970348*Pi^2)*x^23 + 
           60*(16362729 + 20150062*Pi^2)*x^24 + 1620*(204957 + 2521670*Pi^2)*
            x^25 - 540*(256041 + 2096980*Pi^2)*x^26 - 
           19440*(729 + 52088*Pi^2)*x^27 + 3240*(1944 + 115283*Pi^2)*x^28 + 
           115400700*Pi^2*x^29 - 48186900*Pi^2*x^30 - 4723920*Pi^2*x^31 + 
           2099520*Pi^2*x^32 - 4*x^15*(14719840269 + 58291660*Pi^2 - 
             1083715200*Zeta[3]) + 6*x^13*(1955538721 + 94752150*Pi^2 - 
             722476800*Zeta[3]) - 10*x^11*(413940491 + 2857650*Pi^2 - 
             80714880*Zeta[3]) + 10*x^17*(3678653861 + 468704262*Pi^2 - 
             80714880*Zeta[3]) - 2*x^19*(18123623319 + 5064295570*Pi^2 - 
             20995200*Zeta[3]) + 100*x^18*(146845419 + 69310952*Pi^2 - 
             15303168*Zeta[3]) - 300*x^10*(35738039 + 53252*Pi^2 - 
             5101056*Zeta[3]) - 160*x^20*(20297529 + 32491303*Pi^2 - 
             524880*Zeta[3]) + 360*x^8*(-2088386 + 11055*Pi^2 - 
             233280*Zeta[3]) - 6*x^9*(-2366373523 + 2686050*Pi^2 + 
             6998400*Zeta[3]) - 300*x^12*(-37570841 + 2671378*Pi^2 + 
             23518080*Zeta[3]) - 60*x^16*(91469688*Pi^2 - 
             5*(96743131 + 23518080*Zeta[3]))))/(129600*x^5*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) - 
        (4800*Pi^4*x^7*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(1 - 4*x - 19*x^2 - 
            56*x^3 - 19*x^4 - 4*x^5 + x^6) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^2*
           (-77760 + 174960*x + 328860*x^2 - 998460*x^3 - 364410*x^4 + 
            2356710*x^5 - 416400*x^6 - 2929783*x^7 + 1546500*x^8 + 
            1926185*x^9 - 2676300*x^10 - 1432270*x^11 + 1432270*x^13 + 
            2676300*x^14 - 1926185*x^15 - 1546500*x^16 + 2929783*x^17 + 
            416400*x^18 - 2356710*x^19 + 364410*x^20 + 998460*x^21 - 
            328860*x^22 - 174960*x^23 + 77760*x^24) + 
          3*x^2*(-12597120 + 28343520*x + 280723320*x^2 - 673508520*x^3 - 
            2054492100*x^4 + x^23*(5356932165 - 219131005440*Zeta[3]) + 
            x^15*(91503052690 - 176505325440*Zeta[3]) + 
            x^13*(129167437090 - 160565496480*Zeta[3]) + 2769616800*x^29*
             Zeta[3] - 1156485600*x^30*Zeta[3] - 113374080*x^31*Zeta[3] + 
            50388480*x^32*Zeta[3] + 77760*x^28*(-162 + 115283*Zeta[3]) + 
            1620*x^6*(4131611 + 122904*Zeta[3]) - 116640*x^27*
             (-243 + 208352*Zeta[3]) - 405*x^5*(-15285113 + 349536*Zeta[3]) - 
            3600*x^8*(5203229 + 1118340*Zeta[3]) - 3240*x^26*
             (-86643 + 8387920*Zeta[3]) + 9720*x^25*(-69291 + 
              10086680*Zeta[3]) + 720*x^24*(-2852955 + 40300124*Zeta[3]) + 
            9*x^7*(-3140185031 + 321283200*Zeta[3]) - 
            120*x^14*(-3207606931 + 461701996*Zeta[3]) + 
            60*x^22*(96303897 + 493008728*Zeta[3]) - 
            40*x^12*(-13835275103 + 493167000*Zeta[3]) + 
            40*x^10*(-1002124325 + 578262672*Zeta[3]) - 
            160*x^16*(-401777807 + 793721172*Zeta[3]) - 
            60*x^20*(134786115 + 2138700832*Zeta[3]) - 
            8*x^9*(-5223864701 + 2505966960*Zeta[3]) + 
            40*x^18*(-208907525 + 4661504832*Zeta[3]) + 
            8*x^11*(16228902977 + 8652628200*Zeta[3]) + 
            8*x^17*(-13101533623 + 22493175960*Zeta[3]) - 
            8*x^19*(-3577656701 + 32717701080*Zeta[3]) + 
            3*x^21*(-5452586493 + 99105974560*Zeta[3])))/
         (3110400*x^7*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF*(NH*((x*(-466560 + 3873744*x - 172225440*x^2 - 9453555*x^3 - 
             90194760*x^4 + 32261800*x^5 + 38253440*x^6 - 6593175*x^7 - 
             3974640*x^8 - 380392*x^9 + 153280*x^10 + 167455*x^11 + 
             760*x^12 - 10352*x^13 - 480*x^14 + 75*x^15)*HPL[{0}, x])/
           (4320*(-9 + x^2)^2*(-1 + x^2)^7) + 
          lm^2*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6)/
             (144*(-1 + x^2)^4) + (x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x^2)^5)) + (x*(116640 - 598428*x + 31298400*x^2 + 
             2336427*x^3 + 14110200*x^4 - 5818448*x^5 - 10848640*x^6 + 
             949125*x^7 + 528320*x^8 + 78880*x^9 + 129680*x^10 - 19991*x^11 - 
             6360*x^12 + 396*x^13 - 240*x^14 + 39*x^15)*HPL[{0, 0}, x])/
           (1080*(-9 + x^2)^2*(-1 + x^2)^7) + 
          lm*((4*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 3*(7 + 32*x + 
                57*x^2 - 288*x^3 + 57*x^4 + 32*x^5 + 7*x^6))/
             (2592*(-1 + x^2)^4) + (x^2*(-2 + 182*x + 57*x^2 + 290*x^3 + 22*
                x^4 + 12*x^5 - 3*x^6)*HPL[{0}, x])/(108*(-1 + x^2)^5) - 
            ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0}, x])/(54*(-1 + x^2)^3) + 
            (x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 136*x^4 - 3*x^5 - 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x^2)^6) + 
            ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x^2)^3)) + 
          ((77 + 471*x - 26*x^2 + 423*x^3 - 216*x^4 + 114*x^5 - 8*x^6 + 
             6*x^7 - x^8)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^6*(1 + x)^4) + 
          (x^3*(-1132380 - 130707*x - 558360*x^2 + 226062*x^3 + 521820*x^4 + 
             17331*x^5 + 2760*x^6 - 11412*x^7 - 12300*x^8 + 1211*x^9 + 
             880*x^10 - 90*x^11 - 20*x^12 + 5*x^13)*HPL[{0, 0, 0}, x])/
           (135*(-9 + x^2)^2*(-1 + x^2)^7) - 
          ((41 + 689*x + 494*x^2 + 977*x^3 + 308*x^4 + 182*x^5 + 8*x^6 + 
             2*x^7 - x^8)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^6) - 
          ((-38799 + 1532520*x + 73116*x^2 + 974880*x^3 - 263763*x^4 - 
             164880*x^5 + 19360*x^6 + 13600*x^7 + 5915*x^8 - 920*x^9 - 
             636*x^10 + 7*x^12)*master3l8a[x])/(1080*(-9 + x^2)^2*
            (-1 + x^2)^7) + ((-12933 + 259200*x - 6111*x^2 + 229680*x^3 - 
             38364*x^4 + 86520*x^5 + 6042*x^6 + 14760*x^7 + 107*x^8 - 
             1400*x^9 + 69*x^10 + 40*x^11 - 10*x^12)*master3l9a[x])/
           (1080*(-9 + x^2)*(-1 + x^2)^7) + 
          (x^10*(1345891 - 901760*Zeta[3]) + x^14*(67707 - 7040*Zeta[3]) - 
            40*x^15*(-167 + 32*Zeta[3]) + 5*x^16*(-143 + 64*Zeta[3]) + 
            200*x^11*(-12577 + 160*Zeta[3]) + 60*x^13*(599 + 1024*Zeta[3]) + 
            4860*x*(90497 + 1792*Zeta[3]) - 300*x^5*(-855625 + 
              2176*Zeta[3]) + 1458*(-10473 + 3040*Zeta[3]) + 
            19*x^12*(-49467 + 5120*Zeta[3]) + 405*x^2*(-17675 + 
              34432*Zeta[3]) - 1080*x^3*(-857527 + 60832*Zeta[3]) - 
            180*x^9*(-157913 + 66432*Zeta[3]) + 120*x^7*(-1373397 + 
              579232*Zeta[3]) - 45*x^4*(446239 + 717056*Zeta[3]) + 
            3*x^8*(11157259 + 755200*Zeta[3]) + 9*x^6*(-13384447 + 
              1381760*Zeta[3]))/(25920*(-9 + x^2)^2*(-1 + x^2)^7)) + 
        NM*(((-40*Pi^2*(1 - 9*x^2)^2*(-1 + x^2)^4*(1 - 4*x - 4*x^3 + x^4) + 
             3*(-760 + 3040*x + 11388*x^2 - 130640*x^3 - 94735*x^4 + 1793440*
                x^5 + 1010188*x^6 + 934840*x^7 - 3670395*x^8 - 62244640*x^9 - 
               13303220*x^10 - 128239520*x^11 + 4780955*x^12 - 35655840*
                x^13 + 23572044*x^14 - 4915080*x^15 + 7560135*x^16))*
            HPL[{0}, x])/(12960*(1 - 9*x^2)^2*(-1 + x^2)^7) + 
          lm^2*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 4*x^5 + x^6)/
             (144*(-1 + x^2)^4) + (x^3*(2 + x + 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x^2)^5)) + ((1 - 4*x - 4*x^3 + x^4)*HPL[{-2, 0}, x])/
           (27*(-1 + x^2)^3) + ((120 - 480*x - 1096*x^2 + 22000*x^3 + 
             5959*x^4 - 189360*x^5 - 78588*x^6 - 2698200*x^7 - 484687*x^8 + 
             17415440*x^9 + 7591900*x^10 + 75562320*x^11 + 2252733*x^12 + 
             27077760*x^13 - 14498136*x^14 + 2925720*x^15 - 5233005*x^16)*
            HPL[{0, 0}, x])/(1080*(1 - 9*x^2)^2*(-1 + x^2)^7) + 
          lm*((4*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 3*(7 + 32*x + 
                57*x^2 - 288*x^3 + 57*x^4 + 32*x^5 + 7*x^6))/
             (2592*(-1 + x^2)^4) + (x^2*(-2 + 182*x + 57*x^2 + 290*x^3 + 22*
                x^4 + 12*x^5 - 3*x^6)*HPL[{0}, x])/(108*(-1 + x^2)^5) - 
            ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0}, x])/(54*(-1 + x^2)^3) + 
            (x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 136*x^4 - 3*x^5 - 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x^2)^6) + 
            ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x^2)^3)) - 
          ((1 - 4*x - 4*x^3 + x^4)*HPL[{2, 0}, x])/(27*(-1 + x^2)^3) + 
          ((-3 + 18*x - 24*x^2 + 118*x^3 - 216*x^4 + 419*x^5 - 10*x^6 + 
             459*x^7 + 79*x^8)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^6*
            (1 + x)^4) - ((5 - 20*x + 50*x^2 + 1040*x^3 - 862*x^4 + 
             7540*x^5 + 3336*x^6 - 347200*x^7 - 165088*x^8 + 194580*x^9 + 
             1203214*x^10 + 14289040*x^11 + 750338*x^12 + 7127820*x^13 - 
             2739240*x^14 + 1101600*x^15 - 997353*x^16)*HPL[{0, 0, 0}, x])/
           (135*(1 - 9*x^2)^2*(-1 + x^2)^7) - 
          ((-3 + 6*x + 24*x^2 + 194*x^3 + 308*x^4 + 965*x^5 + 478*x^6 + 
             685*x^7 + 43*x^8)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^6) - 
          ((20 - 80*x - 339*x^2 + 3520*x^3 + 2936*x^4 - 51960*x^5 - 
             27903*x^6 + 51840*x^7 + 127404*x^8 + 1592640*x^9 + 112959*x^10 + 
             691200*x^11 - 303480*x^12 + 68040*x^13 - 116397*x^14)*
            master3l8b[x])/(3240*(-1 + x^2)^7*(x - 9*x^3)^2) - 
          ((-10 + 40*x + 69*x^2 - 1400*x^3 + 107*x^4 + 14760*x^5 + 6042*x^6 + 
             86520*x^7 - 38364*x^8 + 229680*x^9 - 6111*x^10 + 259200*x^11 - 
             12933*x^12)*master3l9b[x])/(3240*x^2*(-1 + x^2)^7*
            (-1 + 9*x^2)) + (-150 + 600*x + x^6*(1108413 - 97280*Zeta[3]) + 
            x^5*(789060 - 61440*Zeta[3]) + x^2*(5500 - 320*Zeta[3]) + 
            40*x^3*(-1067 + 32*Zeta[3]) - 200*x^7*(22013 + 160*Zeta[3]) - 
            4860*x^17*(-3103 + 1792*Zeta[3]) + 300*x^13*(830921 + 
              2176*Zeta[3]) - 729*x^18*(10189 + 6080*Zeta[3]) + 
            x^4*(-111627 + 7040*Zeta[3]) + 540*x^9*(-57181 + 22144*Zeta[3]) - 
            2760*x^11*(-100899 + 25184*Zeta[3]) - 405*x^16*
             (71555 + 34432*Zeta[3]) + 1080*x^15*(-12697 + 60832*Zeta[3]) + 
            45*x^14*(-1209029 + 717056*Zeta[3]) - 3*x^10*(2372209 + 
              755200*Zeta[3]) + x^8*(-3855751 + 901760*Zeta[3]) - 
            9*x^12*(-6419567 + 1381760*Zeta[3]))/(25920*(-1 + x^2)^7*
            (x - 9*x^3)^2)) + NL*(-(Pi^2*(1 - 4*x - 4*x^3 + x^4)*
             HPL[{-1}, x])/(324*(-1 + x^2)^3) + 
          (x^2*(78 - 240*(89 + 9*Pi^2)*x - 3*(1777 + 360*Pi^2)*x^2 - 
             480*(10 + 9*Pi^2)*x^3 + (6081 - 1000*Pi^2)*x^4 - 
             80*(-333 + 25*Pi^2)*x^5 - 3*(241 + 20*Pi^2)*x^6 - 
             80*(6 + Pi^2)*x^7 + 5*(-21 + 4*Pi^2)*x^8)*HPL[{0}, x])/
           (6480*(-1 + x^2)^6) + lm^2*((1 - 4*x - 7*x^2 - 40*x^3 - 7*x^4 - 
              4*x^5 + x^6)/(144*(-1 + x^2)^4) + (x^3*(2 + x + 2*x^2)*
              HPL[{0}, x])/(6*(-1 + x^2)^5)) + (Pi^2*(1 - 4*x - 4*x^3 + x^4)*
            HPL[{1}, x])/(324*(-1 + x^2)^3) + 
          (x^3*(108 + 54*x + 216*x^2 + 50*x^3 + 100*x^4 + 3*x^5 + 4*x^6 - 
             x^7)*HPL[{-2, 0}, x])/(27*(-1 + x^2)^6) - 
          ((13 - 80*x + 198*x^2 + 4360*x^3 + 1698*x^4 + 4360*x^5 + 198*x^6 - 
             80*x^7 + 13*x^8)*HPL[{-1, 0}, x])/(1080*(-1 + x^2)^5) + 
          (x^3*(-2400 - 1200*x - 5040*x^2 - 640*x^3 - 2560*x^4 - 45*x^5 - 
             200*x^6 + 43*x^7)*HPL[{0, 0}, x])/(540*(-1 + x^2)^6) + 
          ((13 - 80*x + 198*x^2 + 4360*x^3 + 1698*x^4 + 4360*x^5 + 198*x^6 - 
             80*x^7 + 13*x^8)*HPL[{1, 0}, x])/(1080*(-1 + x^2)^5) + 
          lm*((4*Pi^2*(-1 + 4*x + x^2 - x^4 - 4*x^5 + x^6) + 3*(7 + 32*x + 
                57*x^2 - 288*x^3 + 57*x^4 + 32*x^5 + 7*x^6))/
             (2592*(-1 + x^2)^4) + (x^2*(-2 + 182*x + 57*x^2 + 290*x^3 + 22*
                x^4 + 12*x^5 - 3*x^6)*HPL[{0}, x])/(108*(-1 + x^2)^5) - 
            ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 0}, x])/(54*(-1 + x^2)^3) + 
            (x^3*(-72 - 36*x - 216*x^2 - 68*x^3 - 136*x^4 - 3*x^5 - 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x^2)^6) + 
            ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x^2)^3)) + 
          (x^3*(-108 - 54*x - 216*x^2 - 50*x^3 - 100*x^4 - 3*x^5 - 4*x^6 + 
             x^7)*HPL[{2, 0}, x])/(27*(-1 + x^2)^6) + 
          ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, -1, 0}, x])/(27*(-1 + x^2)^3) - 
          ((1 - 4*x - 4*x^3 + x^4)*HPL[{-1, 1, 0}, x])/(27*(-1 + x^2)^3) + 
          (2*x^3*(72 + 36*x + 216*x^2 + 68*x^3 + 136*x^4 + 3*x^5 + 4*x^6 - 
             x^7)*HPL[{0, 0, 0}, x])/(27*(-1 + x^2)^6) - 
          ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, -1, 0}, x])/(27*(-1 + x^2)^3) + 
          ((1 - 4*x - 4*x^3 + x^4)*HPL[{1, 1, 0}, x])/(27*(-1 + x^2)^3) + 
          (4*Pi^2*(-13 + 80*x - 185*x^2 - 4440*x^3 - 1500*x^4 + 1500*x^6 + 
              4440*x^7 + 185*x^8 - 80*x^9 + 13*x^10) - 
            3*(5 - 5111*x^8 - 3920*x^9 + 5*x^10 - 320*Zeta[3] + 
              80*x*(-49 + 16*Zeta[3]) + 480*x^7*(7 + 72*Zeta[3]) + 
              160*x^3*(21 + 200*Zeta[3]) + 160*x^5*(7 + 432*Zeta[3]) + 
              x^2*(-5111 + 960*Zeta[3]) + 6*x^6*(851 + 2880*Zeta[3]) + 
              2*x^4*(2553 + 8000*Zeta[3])))/(51840*(-1 + x^2)^6))))
 
CbarLData["v", 2, 2] = 
    NC*(CF*(NL*((Pi^2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*
            HPL[{-1}, x])/(810*(-1 + x^2)^5) + 
          (x^2*(-6 - 90*(1047 + 80*Pi^2)*x - 3*(23143 + 2400*Pi^2)*x^2 - 
             45*(5027 + 720*Pi^2)*x^3 - 20*(1033 + 800*Pi^2)*x^4 - 
             25*(-7029 + 1264*Pi^2)*x^5 + (88824 - 7100*Pi^2)*x^6 + 
             (144315 - 7300*Pi^2)*x^7 + (1626 - 80*Pi^2)*x^8 - 
             5*(-81 + 20*Pi^2)*x^9 + 5*(-71 + 4*Pi^2)*x^10)*HPL[{0}, x])/
           (16200*(-1 + x^2)^8) + lm^2*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*
                x^4 + 145*x^5 + 14*x^6 + 5*x^7 - x^8)/(180*(-1 + x^2)^6) + 
            (2*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x^2)^7)) + (Pi^2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 
             5*x^5 + x^6)*HPL[{1}, x])/(810*(-1 + x^2)^5) + 
          (2*x^3*(360 + 360*x + 1620*x^2 + 800*x^3 + 1580*x^4 + 355*x^5 + 
             365*x^6 + 4*x^7 + 5*x^8 - x^9)*HPL[{-2, 0}, x])/
           (135*(-1 + x^2)^8) + ((1 + 25*x - 803*x^2 - 17070*x^3 - 
             14378*x^4 - 44510*x^5 - 14378*x^6 - 17070*x^7 - 803*x^8 + 
             25*x^9 + x^10)*HPL[{-1, 0}, x])/(2700*(-1 + x^2)^7) + 
          (x^3*(-6000 - 6000*x - 33000*x^2 - 16000*x^3 - 43000*x^4 - 
             9725*x^5 - 13525*x^6 - 116*x^7 - 325*x^8 + 59*x^9)*
            HPL[{0, 0}, x])/(1350*(-1 + x^2)^8) + 
          ((-1 - 25*x + 803*x^2 + 17070*x^3 + 14378*x^4 + 44510*x^5 + 
             14378*x^6 + 17070*x^7 + 803*x^8 - 25*x^9 - x^10)*HPL[{1, 0}, x])/
           (2700*(-1 + x^2)^7) + lm*(-(-71 + 81*x + 182*x^2 + 10179*x^3 + 
               4314*x^4 + 10179*x^5 + 182*x^6 + 81*x^7 - 71*x^8 - 4*Pi^2*
                (-1 + 5*x + 2*x^2 + 15*x^3 - 15*x^5 - 2*x^6 - 5*x^7 + x^8))/
             (6480*(-1 + x^2)^6) + (x^2*(-1 + 413*x + 334*x^2 + 1559*x^3 + 
               574*x^4 + 833*x^5 + 44*x^6 + 15*x^7 - 3*x^8)*HPL[{0}, x])/
             (135*(-1 + x^2)^7) + ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^
                6)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^5) + 
            (2*x^3*(-180 - 180*x - 1260*x^2 - 800*x^3 - 1940*x^4 - 535*x^5 - 
               545*x^6 - 4*x^7 - 5*x^8 + x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x^2)^8) - ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^
                6)*HPL[{1, 0}, x])/(135*(-1 + x^2)^5)) + 
          (2*x^3*(-360 - 360*x - 1620*x^2 - 800*x^3 - 1580*x^4 - 355*x^5 - 
             365*x^6 - 4*x^7 - 5*x^8 + x^9)*HPL[{2, 0}, x])/
           (135*(-1 + x^2)^8) + (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + 
             x^6)*HPL[{-1, -1, 0}, x])/(135*(-1 + x^2)^5) + 
          (2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*
            HPL[{-1, 1, 0}, x])/(135*(-1 + x^2)^5) + 
          (4*x^3*(180 + 180*x + 1260*x^2 + 800*x^3 + 1940*x^4 + 535*x^5 + 
             545*x^6 + 4*x^7 + 5*x^8 - x^9)*HPL[{0, 0, 0}, x])/
           (135*(-1 + x^2)^8) + (2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - 
             x^6)*HPL[{1, -1, 0}, x])/(135*(-1 + x^2)^5) + 
          (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*HPL[{1, 1, 0}, x])/
           (135*(-1 + x^2)^5) - (-96972*x^10 - 48285*x^11 - 2365*x^12 + 
            12*Pi^2*(-1 - 25*x + 804*x^2 + 17095*x^3 + 13575*x^4 + 
              27440*x^5 - 27440*x^7 - 13575*x^8 - 17095*x^9 - 804*x^10 + 
              25*x^11 + x^12) + 45*x*(-1073 + 320*Zeta[3]) - 
            5*(473 + 576*Zeta[3]) + 12*x^2*(-8081 + 960*Zeta[3]) + 
            135*x^9*(2693 + 7680*Zeta[3]) + 45*x^3*(8079 + 23360*Zeta[3]) + 
            90*x^5*(-3503 + 50560*Zeta[3]) + 90*x^7*(-3503 + 51840*Zeta[3]) + 
            15*x^4*(6499 + 68160*Zeta[3]) + 15*x^8*(6499 + 69120*Zeta[3]) + 
            8*x^6*(463 + 288000*Zeta[3]))/(388800*(-1 + x^2)^8)) + 
        NM*(-((2280 - 11400*x - 73452*x^2 + 1081140*x^3 + 1828239*x^4 - 
              32627445*x^5 - 38392273*x^6 + 278469990*x^7 + 405309622*x^8 + 
              1048381530*x^9 - 1130622306*x^10 - 19689020010*x^11 - 
              7281803612*x^12 + 16827011280*x^13 + 27485371124*x^14 + 
              232524544050*x^15 + 65392370802*x^16 + 204095829870*x^17 - 
              13529755458*x^18 + 7817020830*x^19 - 25940545731*x^20 - 
              2331134235*x^21 - 5314639635*x^22 + 40*Pi^2*(1 - 10*x^2 + 
                 9*x^4)^4*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6))*
             HPL[{0}, x])/(32400*(1 - 9*x^2)^4*(-1 + x^2)^9) + 
          lm^2*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 5*
                x^7 - x^8)/(180*(-1 + x^2)^6) + 
            (2*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x^2)^7)) + (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + 
             x^6)*HPL[{-2, 0}, x])/(135*(-1 + x^2)^5) + 
          ((120 - 600*x - 3208*x^2 + 68600*x^3 + 90533*x^4 - 1696515*x^5 - 
             1792587*x^6 + 783270*x^7 + 9734400*x^8 + 276847440*x^9 + 
             120564172*x^10 - 1752361370*x^11 - 1334871578*x^12 - 
             4293282030*x^13 + 1240110138*x^14 + 34742728530*x^15 + 
             14251168728*x^16 + 44722497600*x^17 - 462919860*x^18 + 
             4142068650*x^19 - 5576432283*x^20 - 629691975*x^21 - 
             1226742975*x^22)*HPL[{0, 0}, x])/(2700*(1 - 9*x^2)^4*
            (-1 + x^2)^9) + lm*(-(-71 + 81*x + 182*x^2 + 10179*x^3 + 4314*
                x^4 + 10179*x^5 + 182*x^6 + 81*x^7 - 71*x^8 - 4*Pi^2*
                (-1 + 5*x + 2*x^2 + 15*x^3 - 15*x^5 - 2*x^6 - 5*x^7 + x^8))/
             (6480*(-1 + x^2)^6) + (x^2*(-1 + 413*x + 334*x^2 + 1559*x^3 + 
               574*x^4 + 833*x^5 + 44*x^6 + 15*x^7 - 3*x^8)*HPL[{0}, x])/
             (135*(-1 + x^2)^7) + ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^
                6)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^5) + 
            (2*x^3*(-180 - 180*x - 1260*x^2 - 800*x^3 - 1940*x^4 - 535*x^5 - 
               545*x^6 - 4*x^7 - 5*x^8 + x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x^2)^8) - ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^
                6)*HPL[{1, 0}, x])/(135*(-1 + x^2)^5)) + 
          (2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*HPL[{2, 0}, x])/
           (135*(-1 + x^2)^5) + (2*(-3 + 21*x - 27*x^2 + 508*x^3 - 589*x^4 + 
             2295*x^5 - 276*x^6 + 4812*x^7 + 1107*x^8 + 1994*x^9 + 238*x^10)*
            HPL[{-1, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^6) + 
          (2*(-5 + 25*x + 45*x^2 - 3700*x^3 - 2879*x^4 + 32075*x^5 + 
             52445*x^6 + 1425030*x^7 + 946068*x^8 - 18388770*x^9 - 
             24935088*x^10 - 78965010*x^11 + 127888324*x^12 + 
             1785206170*x^13 + 303221596*x^14 - 4552985070*x^15 - 
             2696106015*x^16 - 9675214695*x^17 - 245293677*x^18 - 
             1804632210*x^19 + 994008267*x^20 - 38349045*x^21 + 
             232777719*x^22)*HPL[{0, 0, 0}, x])/(675*(1 - 9*x^2)^4*
            (-1 + x^2)^9) - (2*(-3 + 9*x + 33*x^2 + 692*x^3 + 1461*x^4 + 
             5405*x^5 + 4504*x^6 + 8648*x^7 + 2887*x^8 + 2676*x^9 + 148*x^10)*
            HPL[{1, 0, 0}, x])/(135*(-1 + x)^6*(1 + x)^8) + 
          ((-20 + 100*x + 677*x^2 - 10175*x^3 - 16927*x^4 + 319510*x^5 + 
             354946*x^6 - 3089550*x^7 - 4007742*x^8 - 5099130*x^9 + 
             15884316*x^10 + 198305460*x^11 + 38331132*x^12 - 
             548521470*x^13 - 307774962*x^14 - 1037858850*x^15 - 
             27042174*x^16 - 131308290*x^17 + 119366703*x^18 + 
             13380795*x^19 + 27278451*x^20)*master3l8b[x])/
           (8100*x^2*(1 - 9*x^2)^4*(-1 + x^2)^9) - 
          ((-10 + 50*x + 217*x^2 - 4525*x^3 - 3218*x^4 + 125585*x^5 + 
             81860*x^6 - 715605*x^7 - 971994*x^8 - 4605915*x^9 + 
             3343890*x^10 + 25139745*x^11 + 1347762*x^12 + 63294795*x^13 + 
             4941612*x^14 + 197741025*x^15 + 28697220*x^16 + 97495245*x^17 - 
             3030939*x^18)*master3l9b[x])/(8100*x^2*(-1 + x^2)^9*
            (-1 + 9*x^2)^3) + (-450 + 2250*x + x^6*(22682778 - 
              993600*Zeta[3]) - 40*x^2*(-625 + 24*Zeta[3]) + 
            30*x^3*(-10111 + 160*Zeta[3]) + 31744*x^10*(32942 + 
              375*Zeta[3]) - 15*x^5*(-693941 + 17280*Zeta[3]) + 
            x^4*(-1014583 + 39360*Zeta[3]) - 98415*x^23*(-50041 + 
              93120*Zeta[3]) - 15*x^7*(9282743 + 360000*Zeta[3]) - 
            6561*x^24*(825139 + 452160*Zeta[3]) + 17*x^8*(-14902651 + 
              724800*Zeta[3]) - 2160*x^11*(-6037489 + 2033440*Zeta[3]) + 
            120*x^9*(1536061 + 2653280*Zeta[3]) + 10935*x^21*
             (-3585523 + 5919360*Zeta[3]) - 1458*x^22*(17315719 + 
              13286880*Zeta[3]) + 2430*x^19*(94107691 + 40065120*Zeta[3]) + 
            72*x^18*(1611206789 + 131067000*Zeta[3]) - 
            90*x^15*(-1422197881 + 173735680*Zeta[3]) + 
            243*x^20*(-340442729 + 183672000*Zeta[3]) - 
            810*x^17*(-893865471 + 192368000*Zeta[3]) + 
            90*x^13*(-1175315371 + 251241600*Zeta[3]) - 
            6*x^12*(-758669363 + 296812800*Zeta[3]) - 
            16*x^16*(-8521779803 + 2853572400*Zeta[3]) + 
            4*x^14*(-14407418483 + 3921134400*Zeta[3]))/
           (194400*x^2*(1 - 9*x^2)^4*(-1 + x^2)^9)) + 
        NH*((x*(-283435200 + 2636052336*x - 196662563280*x^2 - 
             73189006947*x^3 - 345787606395*x^4 + 7855418313*x^5 + 
             82125137250*x^6 + 36080629506*x^7 + 31408549470*x^8 - 
             15667801998*x^9 - 13035465990*x^10 + 2298151356*x^11 + 
             1812974520*x^12 - 41658812*x^13 - 120645690*x^14 - 
             23162002*x^15 + 3491970*x^16 + 2409006*x^17 + 20910*x^18 - 
             80713*x^19 - 3165*x^20 + 355*x^21)*HPL[{0}, x])/
           (32400*(-9 + x^2)^4*(-1 + x^2)^9) + 
          lm^2*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 5*
                x^7 - x^8)/(180*(-1 + x^2)^6) + 
            (2*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x^2)^7)) + (x*(23619600 - 135620244*x + 
             11978913420*x^2 + 4633602489*x^3 + 20372261805*x^4 - 
             532364643*x^5 - 7795632330*x^6 - 2772998208*x^7 - 
             2996508960*x^8 + 960603844*x^9 + 1234599070*x^10 - 
             82937602*x^11 - 104931950*x^12 - 7532486*x^13 - 5059230*x^14 + 
             1726192*x^15 + 990280*x^16 - 96128*x^17 - 27330*x^18 + 
             729*x^19 - 375*x^20 + 57*x^21)*HPL[{0, 0}, x])/
           (2700*(-9 + x^2)^4*(-1 + x^2)^9) + 
          lm*(-(-71 + 81*x + 182*x^2 + 10179*x^3 + 4314*x^4 + 10179*x^5 + 182*
                x^6 + 81*x^7 - 71*x^8 - 4*Pi^2*(-1 + 5*x + 2*x^2 + 15*x^3 - 
                 15*x^5 - 2*x^6 - 5*x^7 + x^8))/(6480*(-1 + x^2)^6) + 
            (x^2*(-1 + 413*x + 334*x^2 + 1559*x^3 + 574*x^4 + 833*x^5 + 44*
                x^6 + 15*x^7 - 3*x^8)*HPL[{0}, x])/(135*(-1 + x^2)^7) + 
            ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*HPL[{-1, 0}, x])/
             (135*(-1 + x^2)^5) + (2*x^3*(-180 - 180*x - 1260*x^2 - 800*x^3 - 
               1940*x^4 - 535*x^5 - 545*x^6 - 4*x^7 - 5*x^8 + x^9)*
              HPL[{0, 0}, x])/(135*(-1 + x^2)^8) - 
            ((-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*HPL[{1, 0}, x])/
             (135*(-1 + x^2)^5)) + (2*(236 + 2008*x + 1089*x^2 + 4844*x^3 - 
             332*x^4 + 2295*x^5 - 533*x^6 + 476*x^7 - 9*x^8 + 7*x^9 - x^10)*
            HPL[{-1, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^6) + 
          (2*x^3*(-445419000 - 190336311*x - 775432845*x^2 + 5632443*x^3 + 
             332973360*x^4 + 150293358*x^5 + 192779280*x^6 - 33539190*x^7 - 
             65856240*x^8 - 1896240*x^9 + 3466830*x^10 + 1149504*x^11 + 
             621840*x^12 - 122062*x^13 - 76600*x^14 + 5878*x^15 + 2600*x^16 - 
             185*x^17 - 25*x^18 + 5*x^19)*HPL[{0, 0, 0}, x])/
           (675*(-9 + x^2)^4*(-1 + x^2)^9) + 
          (2*(-146 - 2682*x - 2909*x^2 - 8696*x^3 - 4568*x^4 - 5405*x^5 - 
             1397*x^6 - 644*x^7 - 11*x^8 - 3*x^9 + x^10)*HPL[{1, 0, 0}, x])/
           (135*(-1 + x)^6*(1 + x)^8) + ((9092817 - 589431735*x - 
             213992847*x^2 - 1077679890*x^3 - 1504134*x^4 + 98011530*x^5 + 
             97799490*x^6 + 74198550*x^7 - 31941876*x^8 - 21706500*x^9 + 
             2766452*x^10 + 2922730*x^11 + 196758*x^12 - 200730*x^13 - 
             44434*x^14 + 4370*x^15 + 2195*x^16 + 75*x^17 - 21*x^18)*
            master3l8a[x])/(2700*(-9 + x^2)^4*(-1 + x^2)^9) + 
          ((-3030939 + 97495245*x + 28697220*x^2 + 197741025*x^3 + 
             4941612*x^4 + 63294795*x^5 + 1347762*x^6 + 25139745*x^7 + 
             3343890*x^8 - 4605915*x^9 - 971994*x^10 - 715605*x^11 + 
             81860*x^12 + 125585*x^13 - 3218*x^14 - 4525*x^15 + 217*x^16 + 
             50*x^17 - 10*x^18)*master3l9a[x])/(2700*(-9 + x^2)^3*
            (-1 + x^2)^9) + (x^10*(70930497362 - 15684537600*Zeta[3]) + 
            x^14*(663879382 - 11904000*Zeta[3]) + 
            x^20*(566698 - 39360*Zeta[3]) + x^21*(43455 - 4800*Zeta[3]) + 
            5*x^22*(-797 + 192*Zeta[3]) + 590490*x*(860959 + 15520*Zeta[3]) + 
            15*x^19*(41839 + 17280*Zeta[3]) + 52488*(-200887 + 
              56520*Zeta[3]) + 30*x^17*(-2021861 + 180000*Zeta[3]) + 
            3*x^18*(-4717421 + 331200*Zeta[3]) - 16*x^16*(-6230327 + 
              770100*Zeta[3]) - 60*x^15*(-18832693 + 5306560*Zeta[3]) + 
            270*x^13*(-38093777 + 16267520*Zeta[3]) - 
            3645*x^3*(-454059989 + 17758080*Zeta[3]) + 
            729*x^2*(217379693 + 26573760*Zeta[3]) + 
            360*x^9*(-184326259 + 43433920*Zeta[3]) - 
            486*x^4*(-578858207 + 91836000*Zeta[3]) + 
            1620*x^7*(-269517793 + 96184000*Zeta[3]) + 
            12*x^12*(-1129346239 + 148406400*Zeta[3]) - 
            405*x^5*(-2865596539 + 240390720*Zeta[3]) - 
            90*x^11*(-549165631 + 251241600*Zeta[3]) - 
            9*x^6*(12466764877 + 1048536000*Zeta[3]) + 
            8*x^8*(-14383222201 + 5707144800*Zeta[3]))/(194400*(-9 + x^2)^4*
            (-1 + x^2)^9))) + 
      CA*CF*((Pi^2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 
           5*x^7 + x^8)*HPL[{-2}, x])/(270*(-1 + x^2)^6) + 
        lm^2*((-11*(1 - 5*x - 14*x^2 - 145*x^3 - 94*x^4 - 145*x^5 - 14*x^6 - 
             5*x^7 + x^8))/(360*(-1 + x^2)^6) - 
          (11*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/
           (3*(-1 + x^2)^7)) + (Pi^2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 
           245*x^5 + 50*x^6 + 5*x^7 - x^8)*HPL[{2}, x])/(270*(-1 + x^2)^6) + 
        (x*(30 + 1290*x + 2475*x^2 + 9840*x^3 + 75135*x^4 + 35780*x^5 + 
           50015*x^6 + 37750*x^7 + 38600*x^8 - 61052*x^9 - 31597*x^10 + 
           82454*x^11 + 9660*x^12 - 68520*x^13 + 7500*x^14 + 35160*x^15 - 
           9105*x^16 - 10230*x^17 + 3735*x^18 + 1296*x^19 - 576*x^20)*
          HPL[{-2, 0}, x])/(1350*(-1 + x^2)^8) + 
        ((5760 - 12960*x - 28710*x^2 + 82860*x^3 + 45585*x^4 - 221910*x^5 + 
           5100*x^6 + 4*(80718 + 25*Pi^2)*x^7 - (145569 + 500*Pi^2)*x^8 - 
           2*(147523 + 2550*Pi^2)*x^9 - 2*(77257 + 12000*Pi^2)*x^10 - 
           32*(6083 + 600*Pi^2)*x^11 - 914024*x^12 + 32*(-6083 + 600*Pi^2)*
            x^13 + 2*(-77257 + 12000*Pi^2)*x^14 + (-295046 + 5100*Pi^2)*
            x^15 + (-145569 + 500*Pi^2)*x^16 - 4*(-80718 + 25*Pi^2)*x^17 + 
           5100*x^18 - 221910*x^19 + 45585*x^20 + 82860*x^21 - 28710*x^22 - 
           12960*x^23 + 5760*x^24)*HPL[{-1, 0}, x])/
         (27000*x^7*(-1 + x^2)^7) + (x*(11809800 + 520637220*x + 
           10141162740*x^2 - 547327125*x^3 - 303619643865*x^4 - 
           323011723050*x^5 + 2599762873275*x^6 + 5368484145330*x^7 + 
           1054252087425*x^8 - 33864946932034*x^9 - 95235525626947*x^10 + 
           87203138478249*x^11 + 193499362766224*x^12 - 98497791861664*x^13 + 
           589685341071424*x^14 + 217859066411444*x^15 + 271223390649598*
            x^16 - 71406459566864*x^17 - 175121593852890*x^18 - 
           50666613438579*x^19 + 33777658550463*x^20 + 55787234655174*x^21 - 
           11899592917101*x^22 - 26407866755694*x^23 + 7076793104109*x^24 + 
           7543074059694*x^25 - 2519461764567*x^26 - 1317043155969*x^27 + 
           500083749450*x^28 + 135205894980*x^29 - 55407404430*x^30 - 
           7455133080*x^31 + 3206885580*x^32 + 170061120*x^33 - 
           75582720*x^34)*HPL[{0, 0}, x])/(27000*(-1 + x^2)^8*
          (9 - 82*x^2 + 9*x^4)^4) + ((-5760 + 12960*x + 28710*x^2 - 
           82860*x^3 - 45585*x^4 + 221910*x^5 - 5100*x^6 - 
           4*(80718 + 25*Pi^2)*x^7 + (145569 + 500*Pi^2)*x^8 + 
           (295046 + 5100*Pi^2)*x^9 + 2*(77257 + 12000*Pi^2)*x^10 + 
           32*(6083 + 600*Pi^2)*x^11 + 914024*x^12 - 32*(-6083 + 600*Pi^2)*
            x^13 + (154514 - 24000*Pi^2)*x^14 + (295046 - 5100*Pi^2)*x^15 + 
           (145569 - 500*Pi^2)*x^16 + 4*(-80718 + 25*Pi^2)*x^17 - 5100*x^18 + 
           221910*x^19 - 45585*x^20 - 82860*x^21 + 28710*x^22 + 12960*x^23 - 
           5760*x^24)*HPL[{1, 0}, x])/(27000*x^7*(-1 + x^2)^7) + 
        lm*((-1285 + 3411*x + 9058*x^2 + 185049*x^3 + 94830*x^4 + 
            185049*x^5 + 9058*x^6 + 3411*x^7 - 1285*x^8 - 
            44*Pi^2*(-1 + 5*x + 2*x^2 + 15*x^3 - 15*x^5 - 2*x^6 - 5*x^7 + 
              x^8))/(12960*(-1 + x^2)^6) + (x^2*(11 - 5803*x - 4934*x^2 - 
             20929*x^3 - 7574*x^4 - 10423*x^5 - 484*x^6 - 165*x^7 + 33*x^8)*
            HPL[{0}, x])/(270*(-1 + x^2)^7) + 
          (11*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*HPL[{-1, 0}, x])/
           (270*(-1 + x^2)^5) - (11*x^3*(-180 - 180*x - 1260*x^2 - 800*x^3 - 
             1940*x^4 - 535*x^5 - 545*x^6 - 4*x^7 - 5*x^8 + x^9)*
            HPL[{0, 0}, x])/(135*(-1 + x^2)^8) - 
          (11*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*HPL[{1, 0}, x])/
           (270*(-1 + x^2)^5)) + (x*(-30 - 1290*x - 2475*x^2 - 9840*x^3 - 
           75135*x^4 - 35780*x^5 - 50015*x^6 - 37750*x^7 - 38600*x^8 + 
           61052*x^9 + 31597*x^10 - 82454*x^11 - 9660*x^12 + 68520*x^13 - 
           7500*x^14 - 35160*x^15 + 9105*x^16 + 10230*x^17 - 3735*x^18 - 
           1296*x^19 + 576*x^20)*HPL[{2, 0}, x])/(1350*(-1 + x^2)^8) + 
        (2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{-2, -1, 0}, x])/(45*(-1 + x^2)^6) + 
        (8*x^2*(-24 - 115*x - 121*x^2 - 130*x^3 - 26*x^4 - 5*x^5 + x^6)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x^2)^6) + 
        (2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{-2, 1, 0}, x])/(45*(-1 + x^2)^6) + 
        (2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{-1, -2, 0}, x])/(45*(-1 + x^2)^6) + 
        ((576 - 1296*x - 2007*x^2 + 6342*x^3 + 1356*x^4 - 12246*x^5 + 
           3165*x^6 + 11460*x^7 - 6240*x^8 - 5104*x^9 + 5318*x^10 + 
           844*x^11 + 2264*x^12 + 844*x^13 + 5318*x^14 - 5104*x^15 - 
           6240*x^16 + 11460*x^17 + 3165*x^18 - 12246*x^19 + 1356*x^20 + 
           6342*x^21 - 2007*x^22 - 1296*x^23 + 576*x^24)*HPL[{-1, -1, 0}, x])/
         (2700*x^9*(-1 + x^2)^5) - ((203 + 10*x - 1053*x^2 + 28376*x^3 - 
           32774*x^4 + 10266*x^5 - 14558*x^6 + 21464*x^7 - 32805*x^8 + 
           33751*x^9 + 26375*x^10 - 55008*x^11 + 1500*x^12 + 42348*x^13 - 
           17676*x^14 - 14496*x^15 + 11508*x^16 + 585*x^17 - 2448*x^18 + 
           576*x^19)*HPL[{-1, 0, 0}, x])/(1350*(-1 + x)^8*(1 + x)^6) - 
        ((576 - 1296*x - 2007*x^2 + 6342*x^3 + 1356*x^4 - 12246*x^5 + 
           3165*x^6 + 11460*x^7 - 6240*x^8 - 5104*x^9 + 5318*x^10 + 
           844*x^11 + 2264*x^12 + 844*x^13 + 5318*x^14 - 5104*x^15 - 
           6240*x^16 + 11460*x^17 + 3165*x^18 - 12246*x^19 + 1356*x^20 + 
           6342*x^21 - 2007*x^22 - 1296*x^23 + 576*x^24)*HPL[{-1, 1, 0}, x])/
         (2700*x^9*(-1 + x^2)^5) + (2*(-1 + 5*x + 50*x^2 + 245*x^3 + 
           242*x^4 + 245*x^5 + 50*x^6 + 5*x^7 - x^8)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x^2)^6) + (x*(-196830 - 8070030*x - 356513805*x^2 - 
           370005651*x^3 + 9139532535*x^4 + 19576634256*x^5 - 
           42301223811*x^6 - 306290660436*x^7 - 638260657491*x^8 + 
           2261731865694*x^9 + 6554153714892*x^10 - 8665747640091*x^11 - 
           12546516066138*x^12 + 18271448612816*x^13 - 21126767941126*x^14 - 
           25328170972448*x^15 - 30430975020202*x^16 + 22842828791530*x^17 + 
           18465495677669*x^18 - 17527820957353*x^19 - 4294376328381*x^20 + 
           12886004067648*x^21 - 430808558487*x^22 - 7497482831004*x^23 + 
           1329704954265*x^24 + 3052037815194*x^25 - 829593175014*x^26 - 
           820531553769*x^27 + 276736945680*x^28 + 138419510688*x^29 - 
           52752336048*x^30 - 13891928976*x^31 + 5700454866*x^32 + 
           754016364*x^33 - 324467694*x^34 - 17006112*x^35 + 7558272*x^36)*
          HPL[{0, 0, 0}, x])/(1350*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        (2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{1, -2, 0}, x])/(45*(-1 + x^2)^6) - 
        ((576 - 1296*x - 2007*x^2 + 6342*x^3 + 1356*x^4 - 12246*x^5 + 
           3165*x^6 + 11460*x^7 - 6240*x^8 - 5104*x^9 + 5318*x^10 + 
           844*x^11 + 2264*x^12 + 844*x^13 + 5318*x^14 - 5104*x^15 - 
           6240*x^16 + 11460*x^17 + 3165*x^18 - 12246*x^19 + 1356*x^20 + 
           6342*x^21 - 2007*x^22 - 1296*x^23 + 576*x^24)*HPL[{1, -1, 0}, x])/
         (2700*x^9*(-1 + x^2)^5) + ((203 + 582*x + 1331*x^2 + 26360*x^3 + 
           44714*x^4 + 74114*x^5 + 37514*x^6 + 41480*x^7 + 11411*x^8 - 
           31053*x^9 - 11245*x^10 + 39816*x^11 + 8736*x^12 - 32004*x^13 - 
           4224*x^14 + 16056*x^15 + 1176*x^16 - 4599*x^17 - 144*x^18 + 
           576*x^19)*HPL[{1, 0, 0}, x])/(1350*(-1 + x)^6*(1 + x)^8) + 
        ((576 - 1296*x - 2007*x^2 + 6342*x^3 + 1356*x^4 - 12246*x^5 + 
           3165*x^6 + 11460*x^7 - 6240*x^8 - 5104*x^9 + 5318*x^10 + 
           844*x^11 + 2264*x^12 + 844*x^13 + 5318*x^14 - 5104*x^15 - 
           6240*x^16 + 11460*x^17 + 3165*x^18 - 12246*x^19 + 1356*x^20 + 
           6342*x^21 - 2007*x^22 - 1296*x^23 + 576*x^24)*HPL[{1, 1, 0}, x])/
         (2700*x^9*(-1 + x^2)^5) + (2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
           245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x^2)^6) + (2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
           245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{2, -1, 0}, x])/
         (45*(-1 + x^2)^6) + (8*x^2*(24 + 115*x + 121*x^2 + 130*x^3 + 
           26*x^4 + 5*x^5 - x^6)*HPL[{2, 0, 0}, x])/(45*(-1 + x^2)^6) + 
        (2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{2, 1, 0}, x])/(45*(-1 + x^2)^6) + 
        (4*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*HPL[{-1, 0, 0, 0}, 
           x])/(45*(-1 + x^2)^5) + (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
           245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{-1, 1, 0, 0}, x])/
         (45*(-1 + x^2)^6) + (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
           245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{1, -1, 0, 0}, x])/
         (45*(-1 + x^2)^6) + (4*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*
          HPL[{1, 0, 0, 0}, x])/(45*(-1 + x^2)^5) + 
        ((-1 + 8*x + 39*x^2 + 359*x^3 + 353*x^4 + 651*x^5 + 161*x^6 + 
           119*x^7 - 12*x^8 + 3*x^9)*master3l10a[x])/(180*(-1 + x^2)^7) + 
        (x*(-3 + 12*x - 119*x^2 - 161*x^3 - 651*x^4 - 353*x^5 - 359*x^6 - 
           39*x^7 - 8*x^8 + x^9)*master3l10b[x])/(180*(-1 + x^2)^7) - 
        ((22599 + 62421354*x + 196915212*x^2 + 366482556*x^3 + 
           205839180*x^4 + 149609106*x^5 - 9454680*x^6 - 88567884*x^7 - 
           25698522*x^8 + 10580814*x^9 + 6134716*x^10 + 118580*x^11 - 
           550620*x^12 - 84170*x^13 + 19792*x^14 + 3612*x^15 - 157*x^16)*
          master3l8a[x])/(10800*(-9 + x^2)^4*(-1 + x^2)^8) - 
        ((40 + 1837*x + 2848*x^2 - 72224*x^3 - 125038*x^4 + 1250220*x^5 + 
           1582952*x^6 - 11916132*x^7 - 7274646*x^8 + 61801058*x^9 + 
           4353216*x^10 - 139324296*x^11 + 6170022*x^12 + 29581524*x^13 + 
           173969208*x^14 - 26955828*x^15 + 5346486*x^16 + 764721*x^17)*
          master3l8b[x])/(10800*x*(1 - 9*x^2)^4*(-1 + x^2)^8) + 
        ((-41229 + 3170826*x + 12432699*x^2 + 11047500*x^3 + 11173503*x^4 + 
           9196338*x^5 + 8456479*x^6 - 4140468*x^7 - 3921479*x^8 + 
           531918*x^9 + 567105*x^10 - 22252*x^11 - 37035*x^12 - 202*x^13 + 
           997*x^14 + 20*x^15)*master3l9a[x])/(3600*(-9 + x^2)^3*
          (-1 + x^2)^8) + ((20 + 997*x - 202*x^2 - 37035*x^3 - 22252*x^4 + 
           567105*x^5 + 531918*x^6 - 3921479*x^7 - 4140468*x^8 + 
           8456479*x^9 + 9196338*x^10 + 11173503*x^11 + 11047500*x^12 + 
           12432699*x^13 + 3170826*x^14 - 41229*x^15)*master3l9b[x])/
         (10800*x*(-1 + x^2)^8*(-1 + 9*x^2)^3) + 
        (HPL[{1}, x]*(Pi^2*(-576 + 1296*x + 2583*x^2 - 7638*x^3 - 3363*x^4 + 
             18588*x^5 - 1809*x^6 - 23706*x^7 + 9405*x^8 + 16564*x^9 - 
             11558*x^10 - 5948*x^11 + 3054*x^12 - 3054*x^14 + 5948*x^15 + 
             11558*x^16 - 16564*x^17 - 9405*x^18 + 23706*x^19 + 1809*x^20 - 
             18588*x^21 + 3363*x^22 + 7638*x^23 - 2583*x^24 - 1296*x^25 + 
             576*x^26) - 1440*x^9*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
             245*x^5 - 50*x^6 - 5*x^7 + x^8)*Zeta[3]))/
         (32400*x^9*(-1 + x^2)^6) + 
        (HPL[{-1}, x]*(Pi^2*(576 - 1296*x - 2583*x^2 + 7638*x^3 + 3363*x^4 - 
             18588*x^5 + 1809*x^6 + 23706*x^7 - 9405*x^8 - 16564*x^9 + 
             11558*x^10 + 5948*x^11 - 3054*x^12 + 3054*x^14 - 5948*x^15 - 
             11558*x^16 + 16564*x^17 + 9405*x^18 - 23706*x^19 - 1809*x^20 + 
             18588*x^21 - 3363*x^22 - 7638*x^23 + 2583*x^24 + 1296*x^25 - 
             576*x^26) + 1440*x^9*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
             245*x^5 - 50*x^6 - 5*x^7 + x^8)*Zeta[3]))/
         (32400*x^9*(-1 + x^2)^6) - (HPL[{0}, x]*(226748160 - 510183360*x - 
           9507282660*x^2 + 22110307560*x^3 + 161487467640*x^4 - 
           394605046440*x^5 + 1215*(-1168778563 + 3240*Pi^2)*x^6 + 
           4374*(861149891 + 38700*Pi^2)*x^7 + 20*(-9377207229065 + 
             657157005176*Pi^2)*x^19 - 24*(159633707391 + 1271156451320*Pi^2)*
            x^31 + 180*(7925412789 + 46079914813*Pi^2)*x^32 + 
           135*(2929020669 + 60778996808*Pi^2)*x^33 - 
           360*(448576299 + 7687137380*Pi^2)*x^34 - 
           29160*(758241 + 47468968*Pi^2)*x^35 + 
           1620*(5868693 + 325631704*Pi^2)*x^36 + 349920*(1458 + 397003*Pi^2)*
            x^37 - 43740*(5184 + 1303259*Pi^2)*x^38 - 7540163640*Pi^2*x^39 + 
           3244676940*Pi^2*x^40 + 170061120*Pi^2*x^41 - 75582720*Pi^2*x^42 + 
           30*x^18*(10007221817567 + 1964244353636*Pi^2 - 5220591091200*
              Zeta[3]) + 3*x^28*(2435097086541 + 1842971916740*Pi^2 - 
             97627680000*Zeta[3]) - 81*x^10*(214085735633 + 4500*Pi^2 - 
             3615840000*Zeta[3]) - 6*x^30*(1116927497007 + 2216188370180*
              Pi^2 - 1417176000*Zeta[3]) + 27*x^8*(253885802771 + 
             6714900*Pi^2 - 314928000*Zeta[3]) - 81*x^9*(260701084897 + 
             60220800*Pi^2 + 104976000*Zeta[3]) + 450*x^11*
            (162555269027 + 94723992*Pi^2 + 688642560*Zeta[3]) + 
           6*x^29*(3840147140247 + 12437287972580*Pi^2 + 1417176000*
              Zeta[3]) - 30*x^27*(3372238047255 + 4140862781336*Pi^2 + 
             10329638400*Zeta[3]) - 18*x^13*(8962990419283 + 
             2694022500*Pi^2 + 236703384000*Zeta[3]) + 
           60*x^14*(2200981212237 + 62149398400*Pi^2 + 291744828000*
              Zeta[3]) - 9*x^12*(-1036110693347 + 22448026500*Pi^2 + 
             403597728000*Zeta[3]) - 6*x^16*(101178006747923 + 
             4207986708690*Pi^2 + 929879568000*Zeta[3]) + 
           3*x^26*(44423908626009 + 7204364199380*Pi^2 + 1210793184000*
              Zeta[3]) - 5*x^24*(173931429546279 + 9820611655840*Pi^2 + 
             3500937936000*Zeta[3]) + x^25*(373899649098169 + 
             143381162972080*Pi^2 + 4260660912000*Zeta[3]) + 
           x^22*(1198090137251163 + 37941449649460*Pi^2 + 5579277408000*
              Zeta[3]) - 2*x^23*(508827579850707 + 57525698624360*Pi^2 + 
             13172201856000*Zeta[3]) + 4*x^21*(338470872522069 + 
             13975303708100*Pi^2 + 15711784488000*Zeta[3]) - 
           3*x^17*(57129955100017 + 755498057080*Pi^2 + 20949045984000*
              Zeta[3]) + x^15*(218917948040364 - 542669283840*Pi^2 + 
             26344403712000*Zeta[3]) + 10*x^20*(305602153708*Pi^2 + 
             51*(6096140591399 + 307093593600*Zeta[3]))))/
         (324000*x^5*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        (240*Pi^4*x^7*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (-3 + 15*x - 234*x^2 - 1105*x^3 - 1210*x^4 - 1345*x^5 - 266*x^6 - 
            65*x^7 + 13*x^8) - 12*Pi^2*(9 - 82*x^2 + 9*x^4)^4*
           (-5760 + 12960*x + 34470*x^2 - 95820*x^3 - 74295*x^4 + 
            304770*x^5 + 40485*x^6 - 544782*x^7 + 150669*x^8 + 617918*x^9 + 
            8945*x^10 - 100390*x^11 + 759510*x^12 - 759510*x^14 + 
            100390*x^15 - 8945*x^16 - 617918*x^17 - 150669*x^18 + 
            544782*x^19 - 40485*x^20 - 304770*x^21 + 74295*x^22 + 
            95820*x^23 - 34470*x^24 - 12960*x^25 + 5760*x^26) + 
          x^2*(680244480 - 1530550080*x - 28748596140*x^2 + 66841106040*x^3 + 
            493796081520*x^4 + x^20*(9189104741491476 - 4213260023906880*Zeta[
                3]) - 271445891040*x^39*Zeta[3] + 116808369840*x^40*Zeta[3] + 
            6122200320*x^41*Zeta[3] - 2720977920*x^42*Zeta[3] + 
            32805*x^5*(-36950231 + 35712*Zeta[3]) + 29160*x^6*
             (-143812181 + 373734*Zeta[3]) + 6298560*x^37*
             (-243 + 794006*Zeta[3]) - 1574640*x^38*(-432 + 1303259*Zeta[
                3]) - 2916*x^7*(-4377968929 + 22298040*Zeta[3]) - 
            324*x^8*(-48848934413 + 50043420*Zeta[3]) - 262440*x^35*
             (-254691 + 189875872*Zeta[3]) + 14580*x^36*(-1971783 + 
              1302526816*Zeta[3]) + 243*x^9*(-409374449101 + 5484234240*Zeta[
                3]) + 3888*x^12*(63319044551 + 43904811430*Zeta[3]) - 
            1620*x^34*(-304867071 + 61497099040*Zeta[3]) + 
            2376*x^28*(-39647528981 + 79567955540*Zeta[3]) - 
            108*x^10*(158282931857 + 81467820360*Zeta[3]) + 
            3240*x^32*(-1372570209 + 92162347592*Zeta[3]) - 
            72*x^11*(-8741359875197 + 191986282800*Zeta[3]) + 
            1215*x^33*(-991342287 + 243117379136*Zeta[3]) - 
            180*x^15*(-20146975664831 + 3888368468320*Zeta[3]) - 
            108*x^30*(-218759101089 + 4431734617720*Zeta[3]) + 
            108*x^26*(3544925516111 + 8908407494360*Zeta[3]) - 
            108*x^31*(-105503235183 + 10170104676640*Zeta[3]) - 
            108*x^14*(24738394306711 + 11888060251000*Zeta[3]) + 
            5*x^13*(-508973095636355 + 19571874780096*Zeta[3]) - 
            180*x^23*(5148170516389 + 26935017844496*Zeta[3]) + 
            96*x^16*(45015231369733 + 40838011131840*Zeta[3]) - 
            256*x^19*(-39778711073069 + 45761028781590*Zeta[3]) - 
            72*x^27*(-1528442446997 + 62364673334640*Zeta[3]) - 
            36*x^24*(25186501622883 + 88528634951200*Zeta[3]) + 
            27*x^29*(-2124046149759 + 99566730260800*Zeta[3]) - 
            24*x^18*(-645092073920849 + 101631649404120*Zeta[3]) + 
            48*x^22*(-42754999128709 + 127233754812630*Zeta[3]) + 
            5*x^25*(48848328816415 + 1054649176336512*Zeta[3]) + 
            3*x^17*(931574668022351 + 1384278704792640*Zeta[3]) + 
            x^21*(-3111682800853497 + 6272777047512960*Zeta[3])))/
         (3888000*x^7*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4)) + 
      CF^2*((Pi^2*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{-2}, x])/(135*(-1 + x^2)^6) + 
        lm^2*(-(-1 + 5*x + 14*x^2 + 145*x^3 + 94*x^4 + 145*x^5 + 14*x^6 + 
             5*x^7 - x^8)/(10*(-1 + x^2)^6) + 
          (12*x^3*(1 + x + 3*x^2 + x^3 + x^4)*HPL[{0}, x])/(-1 + x^2)^7) + 
        (Pi^2*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 
           5*x^7 + x^8)*HPL[{2}, x])/(135*(-1 + x^2)^6) - 
        (x*(60 + 2580*x + 16890*x^2 + 28500*x^3 + 216150*x^4 + 102320*x^5 + 
           43190*x^6 + 147130*x^7 + 325660*x^8 - 412803*x^9 - 418722*x^10 + 
           812413*x^11 + 317296*x^12 - 989548*x^13 - 61264*x^14 + 
           773847*x^15 - 109254*x^16 - 379803*x^17 + 106026*x^18 + 
           106896*x^19 - 40512*x^20 - 13200*x^21 + 6000*x^22)*
          HPL[{-2, 0}, x])/(1350*(-1 + x^2)^8) + 
        ((360000 - 792000*x - 1890720*x^2 + 5225760*x^3 + 3375480*x^4 - 
           14619540*x^5 - 719220*x^6 + 22357110*x^7 - 6087840*x^8 - 
           (19946173 + 1200*Pi^2)*x^9 + 20*(505147 + 300*Pi^2)*x^10 + 
           3*(3422023 + 20400*Pi^2)*x^11 + 40*(-90929 + 7200*Pi^2)*x^12 + 
           (2858734 + 230400*Pi^2)*x^13 + 21084240*x^14 + 
           (2858734 - 230400*Pi^2)*x^15 - 40*(90929 + 7200*Pi^2)*x^16 + 
           (10266069 - 61200*Pi^2)*x^17 - 20*(-505147 + 300*Pi^2)*x^18 + 
           (-19946173 + 1200*Pi^2)*x^19 - 6087840*x^20 + 22357110*x^21 - 
           719220*x^22 - 14619540*x^23 + 3375480*x^24 + 5225760*x^25 - 
           1890720*x^26 - 792000*x^27 + 360000*x^28)*HPL[{-1, 0}, x])/
         (162000*x^9*(-1 + x^2)^7) - (x*(70858800 + 3317897700*x + 
           71883628200*x^2 - 12478132620*x^3 - 2150931959550*x^4 - 
           1738112221170*x^5 + 18679600823850*x^6 + 29584605691575*x^7 + 
           1022929740630*x^8 - 180954915419358*x^9 - 610476981434370*x^10 + 
           403923962550363*x^11 + 1044673618325640*x^12 - 
           193054704625498*x^13 + 5107315230871640*x^14 + 
           354355949021818*x^15 + 315663050111780*x^16 + 1743757818268912*
            x^17 + 67099971371540*x^18 - 3401247748578478*x^19 - 
           349345453104030*x^20 + 3278082703495218*x^21 - 
           174097018768470*x^22 - 2058560083476093*x^23 + 
           382888271550270*x^24 + 868106451224538*x^25 - 244356928116570*
            x^26 - 239270788678113*x^27 + 83224339080660*x^28 + 
           41099739060330*x^29 - 16104161938860*x^30 - 4178057178420*x^31 + 
           1758604578840*x^32 + 228859227360*x^33 - 100847293920*x^34 - 
           5196312000*x^35 + 2361960000*x^36)*HPL[{0, 0}, x])/
         (81000*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        ((-360000 + 792000*x + 1890720*x^2 - 5225760*x^3 - 3375480*x^4 + 
           14619540*x^5 + 719220*x^6 - 22357110*x^7 + 6087840*x^8 + 
           (19946173 + 1200*Pi^2)*x^9 - 20*(505147 + 300*Pi^2)*x^10 - 
           3*(3422023 + 20400*Pi^2)*x^11 - 40*(-90929 + 7200*Pi^2)*x^12 - 
           2*(1429367 + 115200*Pi^2)*x^13 - 21084240*x^14 + 
           (-2858734 + 230400*Pi^2)*x^15 + 40*(90929 + 7200*Pi^2)*x^16 + 
           3*(-3422023 + 20400*Pi^2)*x^17 + 20*(-505147 + 300*Pi^2)*x^18 + 
           (19946173 - 1200*Pi^2)*x^19 + 6087840*x^20 - 22357110*x^21 + 
           719220*x^22 + 14619540*x^23 - 3375480*x^24 - 5225760*x^25 + 
           1890720*x^26 + 792000*x^27 - 360000*x^28)*HPL[{1, 0}, x])/
         (162000*x^9*(-1 + x^2)^7) + 
        lm*((22 + 27*x + 98*x^2 - 3132*x^3 - 888*x^4 - 3132*x^5 + 98*x^6 + 
            27*x^7 + 22*x^8 + 2*Pi^2*(-1 + 5*x + 2*x^2 + 15*x^3 - 15*x^5 - 
              2*x^6 - 5*x^7 + x^8))/(180*(-1 + x^2)^6) + 
          (x^2*(-2 + 691*x + 533*x^2 + 2713*x^3 + 1013*x^4 + 1531*x^5 + 
             88*x^6 + 30*x^7 - 6*x^8)*HPL[{0}, x])/(15*(-1 + x^2)^7) + 
          (2*(-1 + 5*x + x^2 + 20*x^3 + x^4 + 5*x^5 - x^6)*HPL[{-1, 0}, x])/
           (15*(-1 + x^2)^5) + (4*x^3*(-180 - 180*x - 1260*x^2 - 800*x^3 - 
             1940*x^4 - 535*x^5 - 545*x^6 - 4*x^7 - 5*x^8 + x^9)*
            HPL[{0, 0}, x])/(15*(-1 + x^2)^8) + 
          (2*(1 - 5*x - x^2 - 20*x^3 - x^4 - 5*x^5 + x^6)*HPL[{1, 0}, x])/
           (15*(-1 + x^2)^5)) + (x*(60 + 2580*x + 16890*x^2 + 28500*x^3 + 
           216150*x^4 + 102320*x^5 + 43190*x^6 + 147130*x^7 + 325660*x^8 - 
           412803*x^9 - 418722*x^10 + 812413*x^11 + 317296*x^12 - 
           989548*x^13 - 61264*x^14 + 773847*x^15 - 109254*x^16 - 
           379803*x^17 + 106026*x^18 + 106896*x^19 - 40512*x^20 - 
           13200*x^21 + 6000*x^22)*HPL[{2, 0}, x])/(1350*(-1 + x^2)^8) + 
        (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{-2, -1, 0}, x])/(45*(-1 + x^2)^6) - 
        (8*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{-2, 0, 0}, x])/(45*(-1 + x^2)^6) + 
        (4*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{-2, 1, 0}, x])/(45*(-1 + x^2)^6) + 
        (4*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 245*x^5 + 50*x^6 + 
           5*x^7 - x^8)*HPL[{-1, -2, 0}, x])/(45*(-1 + x^2)^6) + 
        ((6000 - 13200*x - 10512*x^2 + 40896*x^3 - 6534*x^4 - 43323*x^5 + 
           23196*x^6 + 16272*x^7 - 15064*x^8 + 2*x^9 + 3236*x^10 - 847*x^11 + 
           356*x^12 - 847*x^13 + 3236*x^14 + 2*x^15 - 15064*x^16 + 
           16272*x^17 + 23196*x^18 - 43323*x^19 - 6534*x^20 + 40896*x^21 - 
           10512*x^22 - 13200*x^23 + 6000*x^24)*HPL[{-1, -1, 0}, x])/
         (2700*x^11*(-1 + x^2)^3) + ((153 + 2670*x + 1302*x^2 + 73598*x^3 - 
           84254*x^4 - 12390*x^5 + 4358*x^6 + 83734*x^7 - 224412*x^8 + 
           133392*x^9 + 378366*x^10 - 470166*x^11 - 249934*x^12 + 
           652738*x^13 - 65994*x^14 - 459486*x^15 + 211119*x^16 + 
           146502*x^17 - 124320*x^18 - 3888*x^19 + 25200*x^20 - 6000*x^21)*
          HPL[{-1, 0, 0}, x])/(1350*(-1 + x)^8*(1 + x)^6) + 
        ((-6000 + 13200*x + 10512*x^2 - 40896*x^3 + 6534*x^4 + 43323*x^5 - 
           23196*x^6 - 16272*x^7 + 15064*x^8 - 2*x^9 - 3236*x^10 + 847*x^11 - 
           356*x^12 + 847*x^13 - 3236*x^14 - 2*x^15 + 15064*x^16 - 
           16272*x^17 - 23196*x^18 + 43323*x^19 + 6534*x^20 - 40896*x^21 + 
           10512*x^22 + 13200*x^23 - 6000*x^24)*HPL[{-1, 1, 0}, x])/
         (2700*x^11*(-1 + x^2)^3) + (4*(1 - 5*x - 50*x^2 - 245*x^3 - 
           242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x^2)^6) + (x*(-196830 - 8857350*x + 332588025*x^2 + 
           355269159*x^3 - 9018876960*x^4 - 562710753*x^5 + 71409011454*x^6 - 
           152761356072*x^7 - 64358188680*x^8 + 2674235367660*x^9 + 
           300284572803*x^10 - 18039998897457*x^11 - 19094877285798*x^12 + 
           46282689270877*x^13 + 83161616473588*x^14 - 24387812783387*x^15 - 
           12282103060040*x^16 + 86774374448164*x^17 + 88623403078063*x^18 - 
           135012094617754*x^19 - 77789478865834*x^20 + 164926038657617*
            x^21 + 38199573272414*x^22 - 158484501831526*x^23 - 
           3152853262384*x^24 + 112692046835100*x^25 - 13874744389707*x^26 - 
           57693941276433*x^27 + 13055621594886*x^28 + 20734392938211*x^29 - 
           6264061915392*x^30 - 5044216698951*x^31 + 1801819466862*x^32 + 
           791032772106*x^33 - 313066501632*x^34 - 75391852491*x^35 + 
           31847661162*x^36 + 3944228256*x^37 - 1739837232*x^38 - 
           86605200*x^39 + 39366000*x^40)*HPL[{0, 0, 0}, x])/
         (675*(-1 + x^2)^9*(9 - 82*x^2 + 9*x^4)^4) + 
        (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
           x^8)*HPL[{1, -2, 0}, x])/(45*(-1 + x^2)^6) + 
        ((-6000 + 13200*x + 10512*x^2 - 40896*x^3 + 6534*x^4 + 43323*x^5 - 
           23196*x^6 - 16272*x^7 + 15064*x^8 - 2*x^9 - 3236*x^10 + 847*x^11 - 
           356*x^12 + 847*x^13 - 3236*x^14 - 2*x^15 + 15064*x^16 - 
           16272*x^17 - 23196*x^18 + 43323*x^19 + 6534*x^20 - 40896*x^21 + 
           10512*x^22 + 13200*x^23 - 6000*x^24)*HPL[{1, -1, 0}, x])/
         (2700*x^11*(-1 + x^2)^3) - ((153 + 2802*x + 14646*x^2 + 101362*x^3 + 
           193122*x^4 + 253486*x^5 + 130774*x^6 + 164026*x^7 + 85492*x^8 - 
           228740*x^9 - 119834*x^10 + 408550*x^11 + 125034*x^12 - 
           475778*x^13 - 87042*x^14 + 362958*x^15 + 39111*x^16 - 
           175482*x^17 - 10272*x^18 + 48912*x^19 + 1200*x^20 - 6000*x^21)*
          HPL[{1, 0, 0}, x])/(1350*(-1 + x)^6*(1 + x)^8) + 
        ((6000 - 13200*x - 10512*x^2 + 40896*x^3 - 6534*x^4 - 43323*x^5 + 
           23196*x^6 + 16272*x^7 - 15064*x^8 + 2*x^9 + 3236*x^10 - 847*x^11 + 
           356*x^12 - 847*x^13 + 3236*x^14 + 2*x^15 - 15064*x^16 + 
           16272*x^17 + 23196*x^18 - 43323*x^19 - 6534*x^20 + 40896*x^21 - 
           10512*x^22 - 13200*x^23 + 6000*x^24)*HPL[{1, 1, 0}, x])/
         (2700*x^11*(-1 + x^2)^3) + (4*(-1 + 5*x + 50*x^2 + 245*x^3 + 
           242*x^4 + 245*x^5 + 50*x^6 + 5*x^7 - x^8)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x^2)^6) + (4*(-1 + 5*x + 50*x^2 + 245*x^3 + 242*x^4 + 
           245*x^5 + 50*x^6 + 5*x^7 - x^8)*HPL[{2, -1, 0}, x])/
         (45*(-1 + x^2)^6) + (8*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
           245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{2, 0, 0}, x])/
         (45*(-1 + x^2)^6) + (4*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
           245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{2, 1, 0}, x])/
         (45*(-1 + x^2)^6) - (8*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
           245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{-1, 1, 0, 0}, x])/
         (45*(-1 + x^2)^6) - (8*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
           245*x^5 - 50*x^6 - 5*x^7 + x^8)*HPL[{1, -1, 0, 0}, x])/
         (45*(-1 + x^2)^6) - ((-1 + 8*x + 39*x^2 + 359*x^3 + 353*x^4 + 
           651*x^5 + 161*x^6 + 119*x^7 - 12*x^8 + 3*x^9)*master3l10a[x])/
         (90*(-1 + x^2)^7) + (x*(3 - 12*x + 119*x^2 + 161*x^3 + 651*x^4 + 
           353*x^5 + 359*x^6 + 39*x^7 + 8*x^8 - x^9)*master3l10b[x])/
         (90*(-1 + x^2)^7) + ((22599 + 62421354*x + 196915212*x^2 + 
           366482556*x^3 + 205839180*x^4 + 149609106*x^5 - 9454680*x^6 - 
           88567884*x^7 - 25698522*x^8 + 10580814*x^9 + 6134716*x^10 + 
           118580*x^11 - 550620*x^12 - 84170*x^13 + 19792*x^14 + 3612*x^15 - 
           157*x^16)*master3l8a[x])/(5400*(-9 + x^2)^4*(-1 + x^2)^8) + 
        ((40 + 1837*x + 2848*x^2 - 72224*x^3 - 125038*x^4 + 1250220*x^5 + 
           1582952*x^6 - 11916132*x^7 - 7274646*x^8 + 61801058*x^9 + 
           4353216*x^10 - 139324296*x^11 + 6170022*x^12 + 29581524*x^13 + 
           173969208*x^14 - 26955828*x^15 + 5346486*x^16 + 764721*x^17)*
          master3l8b[x])/(5400*x*(1 - 9*x^2)^4*(-1 + x^2)^8) - 
        ((-41229 + 3170826*x + 12432699*x^2 + 11047500*x^3 + 11173503*x^4 + 
           9196338*x^5 + 8456479*x^6 - 4140468*x^7 - 3921479*x^8 + 
           531918*x^9 + 567105*x^10 - 22252*x^11 - 37035*x^12 - 202*x^13 + 
           997*x^14 + 20*x^15)*master3l9a[x])/(1800*(-9 + x^2)^3*
          (-1 + x^2)^8) - ((20 + 997*x - 202*x^2 - 37035*x^3 - 22252*x^4 + 
           567105*x^5 + 531918*x^6 - 3921479*x^7 - 4140468*x^8 + 
           8456479*x^9 + 9196338*x^10 + 11173503*x^11 + 11047500*x^12 + 
           12432699*x^13 + 3170826*x^14 - 41229*x^15)*master3l9b[x])/
         (5400*x*(-1 + x^2)^8*(-1 + 9*x^2)^3) - 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(6000 - 13200*x - 10512*x^2 + 
             40896*x^3 - 6534*x^4 - 43323*x^5 + 23196*x^6 + 16272*x^7 - 
             15064*x^8 + 2*x^9 + 3236*x^10 - 847*x^11 + 356*x^12 - 847*x^13 + 
             3236*x^14 + 2*x^15 - 15064*x^16 + 16272*x^17 + 23196*x^18 - 
             43323*x^19 - 6534*x^20 + 40896*x^21 - 10512*x^22 - 13200*x^23 + 
             6000*x^24) + 2880*x^11*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
             245*x^5 - 50*x^6 - 5*x^7 + x^8)*Zeta[3]))/
         (32400*x^11*(-1 + x^2)^6) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(6000 - 13200*x - 10512*x^2 + 
             40896*x^3 - 6534*x^4 - 43323*x^5 + 23196*x^6 + 16272*x^7 - 
             15064*x^8 + 2*x^9 + 3236*x^10 - 847*x^11 + 356*x^12 - 847*x^13 + 
             3236*x^14 + 2*x^15 - 15064*x^16 + 16272*x^17 + 23196*x^18 - 
             43323*x^19 - 6534*x^20 + 40896*x^21 - 10512*x^22 - 13200*x^23 + 
             6000*x^24) + 2880*x^11*(1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 
             245*x^5 - 50*x^6 - 5*x^7 + x^8)*Zeta[3]))/
         (32400*x^11*(-1 + x^2)^6) + (HPL[{0}, x]*(-2361960000 + 
           5196312000*x + 99666313920*x^2 - 226261071360*x^3 - 
           1708968251880*x^4 + 4065359668740*x^5 + 15257884924080*x^6 - 
           39085697802240*x^7 + 90*(-841480793707 + 87480*Pi^2)*x^8 + 
           9*(24453266583499 + 37616400*Pi^2)*x^9 + 
           40*(-1067590990125 + 67347665356*Pi^2)*x^21 - 
           3*(73409723590197 + 275219744708300*Pi^2)*x^33 + 
           120*(631195103694 + 1385051667943*Pi^2)*x^34 + 
           30*(1302921558243 + 10939773241478*Pi^2)*x^35 - 
           240*(63574520517 + 395430146686*Pi^2)*x^36 - 
           60*(67755994479 + 1441572718760*Pi^2)*x^37 + 
           120*(14241402099 + 253150025860*Pi^2)*x^38 + 
           540*(419001984 + 26648094173*Pi^2)*x^39 - 
           1080*(92283624 + 5239246513*Pi^2)*x^40 - 
           72900*(71280 + 19625303*Pi^2)*x^41 + 145800*(16200 + 4135417*Pi^2)*
            x^42 + 77152461120*Pi^2*x^43 - 34009424640*Pi^2*x^44 - 
           1732104000*Pi^2*x^45 + 787320000*Pi^2*x^46 + 
           20*x^20*(159989558716117 + 11133338135460*Pi^2 - 
             15661773273600*Zeta[3]) + 18*x^15*(-139526265847877 + 
             19244079300*Pi^2 - 473406768000*Zeta[3]) + 
           270*x^14*(99360124033 + 222429620*Pi^2 - 26906515200*Zeta[3]) - 
           30*x^12*(9506002496831 + 1615196700*Pi^2 - 19525536000*Zeta[3]) + 
           90*x^10*(2308101097681 + 21437460*Pi^2 - 188956800*Zeta[3]) - 
           120*x^32*(1727993960877 + 927664667132*Pi^2 - 141717600*Zeta[3]) - 
           144*x^11*(5290119729517 + 59711175*Pi^2 + 118098000*Zeta[3]) + 
           18*x^31*(42560441575511 + 79299363083680*Pi^2 + 
             944784000*Zeta[3]) - 160*x^29*(11007900948687 + 
             10817628087980*Pi^2 + 3873614400*Zeta[3]) + 
           120*x^13*(14172502601531 + 392571360*Pi^2 + 5164819200*Zeta[3]) - 
           10*x^30*(-26522862153783 + 17098645091924*Pi^2 + 
             58576608000*Zeta[3]) - 20*x^18*(119461452102271 + 
             3510358060782*Pi^2 + 557927740800*Zeta[3]) + 
           10*x^28*(24487340011839 + 53963807540636*Pi^2 + 726475910400*
              Zeta[3]) + 10*x^24*(313548979755737 + 52711150882220*Pi^2 + 
             1115855481600*Zeta[3]) + 20*x^16*(37809675891739 + 
             359568484620*Pi^2 + 1750468968000*Zeta[3]) + 
           4*x^27*(738097172779509 + 370076282866310*Pi^2 + 
             2130330456000*Zeta[3]) - 10*x^26*(210272084631443 + 
             69984338447424*Pi^2 + 3500937936000*Zeta[3]) - 
           9*x^25*(435695304656879 + 98287583861140*Pi^2 + 5854311936000*
              Zeta[3]) - 6*x^19*(204125831035669 + 309329879770*Pi^2 + 
             20949045984000*Zeta[3]) + 4*x^23*(801613783049991 + 
             85080835391795*Pi^2 + 31423568976000*Zeta[3]) + 
           x^22*(3939132467387860 - 206129045451440*Pi^2 + 313235465472000*
              Zeta[3]) + x^17*(-3067446117660*Pi^2 + 
             99*(23868572330689 + 532210176000*Zeta[3]))))/
         (324000*x^7*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) - 
        (4800*Pi^4*x^9*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (1 - 5*x - 50*x^2 - 245*x^3 - 242*x^4 - 245*x^5 - 50*x^6 - 5*x^7 + 
            x^8) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^4*(-360000 + 792000*x + 
            2250720*x^2 - 6017760*x^3 - 5266200*x^4 + 19845300*x^5 + 
            4094700*x^6 - 36976650*x^7 + 5368620*x^8 + 42303283*x^9 - 
            16190780*x^10 - 30212242*x^11 + 13740100*x^12 + 7407335*x^13 - 
            24721400*x^14 + 24721400*x^16 - 7407335*x^17 - 13740100*x^18 + 
            30212242*x^19 + 16190780*x^20 - 42303283*x^21 - 5368620*x^22 + 
            36976650*x^23 - 4094700*x^24 - 19845300*x^25 + 5266200*x^26 + 
            6017760*x^27 - 2250720*x^28 - 792000*x^29 + 360000*x^30) + 
          x^2*(-14171760000 + 31177872000*x + 602721803520*x^2 - 
            1367959052160*x^3 - 10451370669120*x^4 + 24840782921160*x^5 + 
            94891126168800*x^6 + 5554977200640*x^43*Zeta[3] - 
            2448678574080*x^44*Zeta[3] - 124711488000*x^45*Zeta[3] + 
            56687040000*x^46*Zeta[3] + 10497600*x^42*(-1350 + 
              4135417*Zeta[3]) + 1215*x^7*(-199590778795 + 7177248*Zeta[3]) + 
            1080*x^8*(-446908487201 + 13629384*Zeta[3]) - 
            5248800*x^41*(-5940 + 19625303*Zeta[3]) + 
            360*x^10*(3773725899173 + 1227315240*Zeta[3]) - 
            77760*x^40*(-7751052 + 5239246513*Zeta[3]) - 
            4320*x^12*(429641255719 + 6961503204*Zeta[3]) - 
            54*x^9*(-25931427110713 + 8880833520*Zeta[3]) + 
            38880*x^39*(-35184132 + 26648094173*Zeta[3]) + 
            8640*x^38*(-1209649383 + 253150025860*Zeta[3]) + 
            720*x^14*(1581331416599 + 705169925640*Zeta[3]) + 
            9*x^11*(-569335714570631 + 1062652841280*Zeta[3]) - 
            36*x^13*(-369257561718367 + 2458956703680*Zeta[3]) - 
            2160*x^36*(-43931240955 + 3163441173488*Zeta[3]) - 
            8640*x^22*(-4243906014317 + 3959111613024*Zeta[3]) - 
            1080*x^37*(-23000724927 + 5766290875040*Zeta[3]) - 
            720*x^20*(-85888566797409 + 6786728434624*Zeta[3]) + 
            1080*x^34*(-447847614161 + 11080410701648*Zeta[3]) + 
            2880*x^28*(585148840991 + 13679519349434*Zeta[3]) - 
            720*x^30*(3006225157749 + 17146377549848*Zeta[3]) - 
            360*x^32*(-3860380656593 + 22261436203008*Zeta[3]) - 
            90*x^17*(-357958617378017 + 22526303064672*Zeta[3]) - 
            120*x^16*(64394914339355 + 31126677591264*Zeta[3]) + 
            675*x^35*(-359217941391 + 35007292330624*Zeta[3]) + 
            5*x^15*(-5393814643684217 + 86519143468224*Zeta[3]) + 
            120*x^18*(126138856679801 + 96215483140752*Zeta[3]) + 
            120*x^24*(-86317882309279 + 449804167666656*Zeta[3]) - 
            120*x^26*(5560496782655 + 455411214775248*Zeta[3]) - 
            90*x^25*(-155597447928257 + 729639872223552*Zeta[3]) - 
            54*x^33*(-25829811703513 + 1100890858481120*Zeta[3]) - 
            36*x^29*(-311554222292767 + 3464697277478080*Zeta[3]) + 
            3*x^19*(746549604115883 + 4520600529945600*Zeta[3]) - 
            8*x^21*(-5300158343875999 + 5946737595334560*Zeta[3]) + 
            9*x^31*(-550611827864831 + 11420486445758400*Zeta[3]) + 
            3*x^23*(-7128659469111517 + 12789420758980800*Zeta[3]) + 
            5*x^27*(-3162528945873137 + 21413527913448000*Zeta[3])))/
         (7776000*x^9*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4)))
 
CbarLData["v", 2, 3] = 
    NC*(CF*(NL*((Pi^2*(-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 
             6*x^7 - x^8)*HPL[{-1}, x])/(1620*(-1 + x^2)^7) + 
          (x^2*(-1233 - 63*(45809 + 3000*Pi^2)*x - 18*(195203 + 15750*Pi^2)*
              x^2 - 63*(254581 + 24000*Pi^2)*x^3 - 4*(1953451 + 301875*Pi^2)*
              x^4 - 210*(18871 + 13200*Pi^2)*x^5 + (5742014 - 1198050*Pi^2)*
              x^6 - 252*(-70094 + 5925*Pi^2)*x^7 + (5504139 - 285390*Pi^2)*
              x^8 - 63*(-82579 + 3120*Pi^2)*x^9 + (89398 - 1050*Pi^2)*x^10 - 
             105*(-203 + 12*Pi^2)*x^11 + 70*(-98 + 3*Pi^2)*x^12)*HPL[{0}, x])/
           (340200*(-1 + x^2)^10) + lm^2*(-(-1 + 6*x + 23*x^2 + 356*x^3 + 398*
                x^4 + 956*x^5 + 398*x^6 + 356*x^7 + 23*x^8 + 6*x^9 - x^10)/
             (240*(-1 + x^2)^8) + (x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*
                x^5 + 2*x^6)*HPL[{0}, x])/(2*(-1 + x^2)^9)) + 
          (Pi^2*(1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + 
             x^8)*HPL[{1}, x])/(1620*(-1 + x^2)^7) + 
          (x^3*(900 + 1350*x + 7200*x^2 + 5750*x^3 + 13200*x^4 + 5705*x^5 + 
             7110*x^6 + 1359*x^7 + 936*x^8 + 5*x^9 + 6*x^10 - x^11)*
            HPL[{-2, 0}, x])/(135*(-1 + x^2)^10) - 
          ((-137 + 602*x + 13968*x^2 + 347774*x^3 + 454821*x^4 + 
             1706264*x^5 + 1046216*x^6 + 1706264*x^7 + 454821*x^8 + 
             347774*x^9 + 13968*x^10 + 602*x^11 - 137*x^12)*HPL[{-1, 0}, x])/
           (37800*(-1 + x^2)^9) + (x^3*(-84000 - 126000*x - 861000*x^2 - 
             721000*x^3 - 2212000*x^4 - 1045275*x^5 - 1668450*x^6 - 
             344757*x^7 - 291228*x^8 - 1365*x^9 - 3178*x^10 + 493*x^11)*
            HPL[{0, 0}, x])/(18900*(-1 + x^2)^10) + 
          ((-137 + 602*x + 13968*x^2 + 347774*x^3 + 454821*x^4 + 
             1706264*x^5 + 1046216*x^6 + 1706264*x^7 + 454821*x^8 + 
             347774*x^9 + 13968*x^10 + 602*x^11 - 137*x^12)*HPL[{1, 0}, x])/
           (37800*(-1 + x^2)^9) + lm*(-(-196 + 609*x + 2127*x^2 + 67404*x^3 + 
               61321*x^4 + 180630*x^5 + 61321*x^6 + 67404*x^7 + 2127*x^8 + 
               609*x^9 - 196*x^10 - 6*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 
                 16*x^4 - 16*x^6 - 48*x^7 - 3*x^8 - 6*x^9 + x^10))/
             (19440*(-1 + x^2)^8) + (x^2*(-2 + 2412*x + 3130*x^2 + 16758*
                x^3 + 11358*x^4 + 22158*x^5 + 6505*x^6 + 5562*x^7 + 214*x^8 + 
               54*x^9 - 9*x^10)*HPL[{0}, x])/(540*(-1 + x^2)^9) + 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{-1, 0}, x])/(270*(-1 + x^2)^7) + 
            (x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 13200*x^4 - 7055*x^5 - 
               9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 6*x^10 + x^11)*
              HPL[{0, 0}, x])/(135*(-1 + x^2)^10) - 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{1, 0}, x])/(270*(-1 + x^2)^7)) + 
          (x^3*(-900 - 1350*x - 7200*x^2 - 5750*x^3 - 13200*x^4 - 5705*x^5 - 
             7110*x^6 - 1359*x^7 - 936*x^8 - 5*x^9 - 6*x^10 + x^11)*
            HPL[{2, 0}, x])/(135*(-1 + x^2)^10) - 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{-1, -1, 0}, x])/(135*(-1 + x^2)^7) + 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{-1, 1, 0}, x])/(135*(-1 + x^2)^7) + 
          (2*x^3*(360 + 540*x + 4500*x^2 + 4400*x^3 + 13200*x^4 + 7055*x^5 + 
             9810*x^6 + 2169*x^7 + 1476*x^8 + 5*x^9 + 6*x^10 - x^11)*
            HPL[{0, 0, 0}, x])/(135*(-1 + x^2)^10) + 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{1, -1, 0}, x])/(135*(-1 + x^2)^7) - 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{1, 1, 0}, x])/(135*(-1 + x^2)^7) - 
          (-2759767*x^12 - 1083390*x^13 - 131005*x^14 + 
            36*Pi^2*(-137 + 602*x + 14105*x^2 + 347172*x^3 + 440853*x^4 + 
              1358490*x^5 + 591395*x^6 - 591395*x^8 - 1358490*x^9 - 
              440853*x^10 - 347172*x^11 - 14105*x^12 - 602*x^13 + 137*x^14) + 
            210*x*(-5159 + 1728*Zeta[3]) - 35*(3743 + 1728*Zeta[3]) + 
            252*x^11*(174391 + 216000*Zeta[3]) + 252*x^3*
             (174391 + 224640*Zeta[3]) + x^2*(-2759767 + 302400*Zeta[3]) + 
            630*x^5*(56909 + 682560*Zeta[3]) + 630*x^9*(56909 + 
              691200*Zeta[3]) + 27*x^10*(1007201 + 3024000*Zeta[3]) + 
            27*x^4*(1007201 + 3044160*Zeta[3]) + 168*x^7*(-937093 + 
              4752000*Zeta[3]) + 5*x^6*(-4860731 + 69007680*Zeta[3]) + 
            5*x^8*(-4860731 + 69552000*Zeta[3]))/(16329600*(-1 + x^2)^10)) + 
        NH*((x*(-964246550400 + 9949254819696*x - 1126512716072436*x^2 - 
             769700029364811*x^3 - 4117798490348970*x^4 - 1013461146341658*
              x^5 - 789271041204450*x^6 + 786249767764188*x^7 + 
             1542223615448250*x^8 - 13589688309966*x^9 - 349982760245202*
              x^10 - 107396456038263*x^11 - 17631537296436*x^12 + 
             36590998182732*x^13 + 18664867884348*x^14 - 5538763746576*x^15 - 
             3349681943580*x^16 + 377572057828*x^17 + 303704730840*x^18 + 
             2089773639*x^19 - 15103115202*x^20 - 2192465554*x^21 + 
             348743430*x^22 + 143855348*x^23 + 478338*x^24 - 3447078*x^25 - 
             124530*x^26 + 12475*x^27)*HPL[{0}, x])/(1360800*(-9 + x^2)^6*
            (-1 + x^2)^11) + lm^2*(-(-1 + 6*x + 23*x^2 + 356*x^3 + 398*x^4 + 
               956*x^5 + 398*x^6 + 356*x^7 + 23*x^8 + 6*x^9 - x^10)/
             (240*(-1 + x^2)^8) + (x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*
                x^5 + 2*x^6)*HPL[{0}, x])/(2*(-1 + x^2)^9)) + 
          (x*(26784626400 - 170660454228*x + 22931072966088*x^2 + 
             15945043536945*x^3 + 82825302376278*x^4 + 20448773578314*x^5 + 
             7938559171998*x^6 - 19190717670402*x^7 - 40133549561490*x^8 - 
             869188316886*x^9 + 8907586415910*x^10 + 3067531468587*x^11 + 
             1356306125244*x^12 - 811715479484*x^13 - 701210282388*x^14 + 
             77603957236*x^15 + 88091577084*x^16 + 961382592*x^17 - 
             2699426380*x^18 - 816897961*x^19 - 307758290*x^20 + 
             67738770*x^21 + 27222006*x^22 - 2218834*x^23 - 569226*x^24 + 
             14922*x^25 - 3234*x^26 + 429*x^27)*HPL[{0, 0}, x])/
           (37800*(-9 + x^2)^6*(-1 + x^2)^11) + 
          lm*(-(-196 + 609*x + 2127*x^2 + 67404*x^3 + 61321*x^4 + 180630*
                x^5 + 61321*x^6 + 67404*x^7 + 2127*x^8 + 609*x^9 - 196*x^10 - 
               6*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 16*x^4 - 16*x^6 - 48*x^7 - 
                 3*x^8 - 6*x^9 + x^10))/(19440*(-1 + x^2)^8) + 
            (x^2*(-2 + 2412*x + 3130*x^2 + 16758*x^3 + 11358*x^4 + 22158*
                x^5 + 6505*x^6 + 5562*x^7 + 214*x^8 + 54*x^9 - 9*x^10)*
              HPL[{0}, x])/(540*(-1 + x^2)^9) + 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{-1, 0}, x])/(270*(-1 + x^2)^7) + 
            (x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 13200*x^4 - 7055*x^5 - 
               9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 6*x^10 + x^11)*
              HPL[{0, 0}, x])/(135*(-1 + x^2)^10) - 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{1, 0}, x])/(270*(-1 + x^2)^7)) + 
          ((561 + 6027*x + 6750*x^2 + 28387*x^3 + 10357*x^4 + 29839*x^5 + 
             220*x^6 + 9591*x^7 - 657*x^8 + 1328*x^9 - 10*x^10 + 8*x^11 - 
             x^12)*HPL[{-1, 0, 0}, x])/(135*(-1 + x)^10*(1 + x)^8) + 
          (x^3*(-867831999300 - 638448236757*x - 3157253788878*x^2 - 
             832176116496*x^3 - 277665815322*x^4 + 829097131050*x^5 + 
             1916783213814*x^6 + 172454857920*x^7 - 295176047418*x^8 - 
             180985589163*x^9 - 133513748676*x^10 + 34850023624*x^11 + 
             44483948292*x^12 - 935467276*x^13 - 4389159852*x^14 - 
             484600760*x^15 + 5063184*x^16 + 69255485*x^17 + 28060242*x^18 - 
             4059928*x^19 - 1862826*x^20 + 116226*x^21 + 40950*x^22 - 
             1960*x^23 - 210*x^24 + 35*x^25)*HPL[{0, 0, 0}, x])/
           (4725*(-9 + x^2)^6*(-1 + x^2)^11) - 
          ((381 + 7641*x + 11226*x^2 + 43865*x^3 + 32485*x^4 + 57545*x^5 + 
             24160*x^6 + 20745*x^7 + 4395*x^8 + 1660*x^9 + 14*x^10 + 4*x^11 - 
             x^12)*HPL[{1, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^10) + 
          ((35187738687 - 3409851309102*x - 2289614951250*x^2 - 
             12551343804342*x^3 - 3201193243764*x^4 - 3618822460554*x^5 + 
             1866748472586*x^6 + 3595112653230*x^7 + 81885700683*x^8 - 
             661450533660*x^9 - 256118713668*x^10 - 25571691180*x^11 + 
             72060163104*x^12 + 29801473884*x^13 - 8702743100*x^14 - 
             5557322484*x^15 + 349712181*x^16 + 513303210*x^17 + 
             24773558*x^18 - 23212350*x^19 - 3145260*x^20 + 323022*x^21 + 
             109074*x^22 + 4326*x^23 - 831*x^24)*master3l8a[x])/
           (113400*(-9 + x^2)^6*(-1 + x^2)^11) + 
          ((-3909748743 + 186020812278*x + 112089858777*x^2 + 
             713650782096*x^3 + 183214541061*x^4 + 419682401334*x^5 - 
             2815518825*x^6 + 73126241748*x^7 + 28912055148*x^8 + 
             16024964508*x^9 - 8548934390*x^10 - 25047871296*x^11 - 
             1212116694*x^12 + 3790950156*x^13 + 624410206*x^14 + 
             63328104*x^15 - 77167055*x^16 - 48872082*x^17 + 4063373*x^18 + 
             3384528*x^19 - 101247*x^20 - 73794*x^21 + 2459*x^22 + 420*x^23 - 
             70*x^24)*master3l9a[x])/(37800*(-9 + x^2)^5*(-1 + x^2)^11) + 
          (x^16*(31427468457173 - 7395694689600*Zeta[3]) + 
            x^20*(89645769594 - 20287834560*Zeta[3]) + 
            x^22*(8131736582 - 209664000*Zeta[3]) + 160*x^28*
             (-799 + 126*Zeta[3]) - 840*x^27*(-1855 + 144*Zeta[3]) + 
            42*x^25*(1306741 + 54720*Zeta[3]) - 3*x^26*(-8111431 + 
              403200*Zeta[3]) + 252*x^23*(-22625159 + 2940480*Zeta[3]) + 
            5*x^24*(-164879341 + 7640640*Zeta[3]) + 2480058*x*
             (1188166087 + 19414080*Zeta[3]) + 177147*(-227381303 + 
              62354880*Zeta[3]) - 168*x^21*(-892430297 + 215952480*Zeta[3]) - 
            918540*x^3*(-16298018147 + 329228064*Zeta[3]) - 
            653184*x^11*(-2465847488 + 879682925*Zeta[3]) + 
            19683*x^2*(93915887267 + 6383059200*Zeta[3]) - 
            204120*x^5*(-88204117829 + 6530650272*Zeta[3]) - 
            39366*x^4*(-141045318583 + 6768367200*Zeta[3]) + 
            84*x^19*(-23640974107 + 8390152800*Zeta[3]) - 
            567*x^10*(-846489483349 + 34079366400*Zeta[3]) + 
            672*x^13*(-140512977119 + 41770148400*Zeta[3]) - 
            126*x^17*(-116399370607 + 53165937600*Zeta[3]) - 
            7290*x^6*(-293560885831 + 68994938880*Zeta[3]) + 
            6804*x^7*(-140830579657 + 135498536640*Zeta[3]) + 
            168*x^15*(-296857672441 + 160371432000*Zeta[3]) + 
            84*x^14*(-1925198681443 + 562126118400*Zeta[3]) + 
            x^18*(-2990523728897 + 591327878400*Zeta[3]) + 
            243*x^8*(-13115632192829 + 3065320802880*Zeta[3]) + 
            378*x^9*(-13172226917561 + 3150735278400*Zeta[3]) - 
            28*x^12*(-11836691874121 + 4757528840400*Zeta[3]))/
           (8164800*(-9 + x^2)^6*(-1 + x^2)^11)) + 
        NM*(((-47880 + 287280*x + 2339892*x^2 - 48039012*x^3 - 
             114690807*x^4 + 2288301750*x^5 + 4125733846*x^6 - 
             37885939602*x^7 - 76121183196*x^8 + 93818078970*x^9 + 
             619748750198*x^10 + 3735043460190*x^11 - 446080343251*x^12 - 
             36646840032852*x^13 - 23947565715348*x^14 + 56658458220924*
              x^15 + 107959083615352*x^16 + 518539707710388*x^17 + 
             102681631474704*x^18 - 1043595489588120*x^19 - 
             900844778821437*x^20 - 3354795372249090*x^21 - 
             777493194172578*x^22 - 1196783585624970*x^23 + 
             229749460520364*x^24 + 173451939151554*x^25 + 164705104901286*
              x^26 + 35044926646590*x^27 + 20570244390855*x^28 - 
             840*Pi^2*(1 - 9*x^2)^6*(-1 + x^2)^4*(1 - 6*x - 2*x^2 - 54*x^3 - 
               18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + x^8))*HPL[{0}, x])/
           (1360800*(1 - 9*x^2)^6*(-1 + x^2)^11) + 
          lm^2*(-(-1 + 6*x + 23*x^2 + 356*x^3 + 398*x^4 + 956*x^5 + 398*x^6 + 
               356*x^7 + 23*x^8 + 6*x^9 - x^10)/(240*(-1 + x^2)^8) + 
            (x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 3*x^5 + 2*x^6)*
              HPL[{0}, x])/(2*(-1 + x^2)^9)) - 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{-2, 0}, x])/(135*(-1 + x^2)^7) + 
          ((840 - 5040*x - 36856*x^2 + 1092336*x^3 + 2220125*x^4 - 
             44783634*x^5 - 75086814*x^6 + 373807238*x^7 + 1001744606*x^8 + 
             8365811062*x^9 + 207313406*x^10 - 172810817130*x^11 - 
             129292238241*x^12 + 856889383308*x^13 + 1085477324404*x^14 + 
             2666798430492*x^15 - 1362416357700*x^16 - 30116700228132*x^17 - 
             16761322434204*x^18 + 16475984895132*x^19 + 42845516091531*
              x^20 + 202848684308550*x^21 + 61118586897930*x^22 + 
             100150586849502*x^23 - 10168351607106*x^24 - 6918601666914*
              x^25 - 12157161030666*x^26 - 2797253284770*x^27 - 
             1582778625255*x^28)*HPL[{0, 0}, x])/(37800*(1 - 9*x^2)^6*
            (-1 + x^2)^11) + lm*(-(-196 + 609*x + 2127*x^2 + 67404*x^3 + 
               61321*x^4 + 180630*x^5 + 61321*x^6 + 67404*x^7 + 2127*x^8 + 
               609*x^9 - 196*x^10 - 6*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 
                 16*x^4 - 16*x^6 - 48*x^7 - 3*x^8 - 6*x^9 + x^10))/
             (19440*(-1 + x^2)^8) + (x^2*(-2 + 2412*x + 3130*x^2 + 16758*
                x^3 + 11358*x^4 + 22158*x^5 + 6505*x^6 + 5562*x^7 + 214*x^8 + 
               54*x^9 - 9*x^10)*HPL[{0}, x])/(540*(-1 + x^2)^9) + 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{-1, 0}, x])/(270*(-1 + x^2)^7) + 
            (x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 13200*x^4 - 7055*x^5 - 
               9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 6*x^10 + x^11)*
              HPL[{0, 0}, x])/(135*(-1 + x^2)^10) - 
            ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - x^
                8)*HPL[{1, 0}, x])/(270*(-1 + x^2)^7)) + 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{2, 0}, x])/(135*(-1 + x^2)^7) + 
          ((-3 + 24*x - 30*x^2 + 1424*x^3 - 811*x^4 + 9623*x^5 + 220*x^6 + 
             29807*x^7 + 10511*x^8 + 28291*x^9 + 6770*x^10 + 6011*x^11 + 
             563*x^12)*HPL[{-1, 0, 0}, x])/(135*(-1 + x)^10*(1 + x)^8) + 
          ((-35 + 210*x + 980*x^2 - 60270*x^3 - 104543*x^4 + 1247988*x^5 + 
             2950602*x^6 + 20801256*x^7 + 5059073*x^8 - 680091678*x^9 - 
             1137659238*x^10 + 668975454*x^11 + 14399514113*x^12 + 
             120887950848*x^13 - 30013517540*x^14 - 1300332630072*x^15 - 
             588303062241*x^16 + 4104391691358*x^17 + 4019345188416*x^18 + 
             5793750622422*x^19 - 5086246984893*x^20 - 35572598168436*x^21 - 
             13033331718822*x^22 - 25093047136752*x^23 + 575824989123*x^24 - 
             1062205932690*x^25 + 2115707837202*x^26 + 293032906362*x^27 + 
             299056435803*x^28)*HPL[{0, 0, 0}, x])/(4725*(1 - 9*x^2)^6*
            (-1 + x^2)^11) - ((-3 + 12*x + 42*x^2 + 1780*x^3 + 4625*x^4 + 
             20905*x^5 + 24160*x^6 + 57385*x^7 + 32255*x^8 + 43745*x^9 + 
             11198*x^10 + 7633*x^11 + 383*x^12)*HPL[{1, 0, 0}, x])/
           (135*(-1 + x)^8*(1 + x)^10) + ((-140 + 840*x + 7009*x^2 - 
             159474*x^3 - 355830*x^4 + 7774326*x^5 + 13094452*x^6 - 
             135453318*x^7 - 252248382*x^8 + 493050474*x^9 + 
             2288115221*x^10 + 11999316924*x^11 - 4960873996*x^12 - 
             148134319284*x^13 - 67339931392*x^14 + 508483303524*x^15 + 
             467823642984*x^16 + 519253656012*x^17 - 607933730997*x^18 - 
             4072020202026*x^19 - 1449640051614*x^20 - 2508159199266*x^21 + 
             127511222220*x^22 + 77671351170*x^23 + 264177995778*x^24 + 
             61476688098*x^25 + 35187738687*x^26)*master3l8b[x])/
           (113400*x^2*(1 - 9*x^2)^6*(-1 + x^2)^11) - 
          ((-70 + 420*x + 2459*x^2 - 73794*x^3 - 101247*x^4 + 3384528*x^5 + 
             4063373*x^6 - 48872082*x^7 - 77167055*x^8 + 63328104*x^9 + 
             624410206*x^10 + 3790950156*x^11 - 1212116694*x^12 - 
             25047871296*x^13 - 8548934390*x^14 + 16024964508*x^15 + 
             28912055148*x^16 + 73126241748*x^17 - 2815518825*x^18 + 
             419682401334*x^19 + 183214541061*x^20 + 713650782096*x^21 + 
             112089858777*x^22 + 186020812278*x^23 - 3909748743*x^24)*
            master3l9b[x])/(113400*x^2*(-1 + x^2)^11*(-1 + 9*x^2)^5) + 
          (-9450 + 56700*x + x^2*(696055 - 20160*Zeta[3]) + 
            210*x^3*(-61609 + 576*Zeta[3]) - 336*x^5*(-1959853 + 
              6840*Zeta[3]) + 3*x^4*(-15846571 + 403200*Zeta[3]) - 
            50*x^6*(-35140849 + 764064*Zeta[3]) - 504*x^7*(27018623 + 
              1470240*Zeta[3]) - 4251528*x^30*(5051023 + 2598120*Zeta[3]) - 
            14880348*x^29*(572707 + 3235680*Zeta[3]) + 
            4*x^8*(-8503721543 + 52416000*Zeta[3]) + 
            168*x^9*(489607633 + 215952480*Zeta[3]) + 1377810*x^27*
             (-296477323 + 219485376*Zeta[3]) + 3674160*x^25*
             (168134441 + 362813904*Zeta[3]) + 1049760*x^24*
             (644707449 + 479131520*Zeta[3]) - 177147*x^28*(831123283 + 
              709228800*Zeta[3]) - 714*x^11*(-2063086267 + 987076800*Zeta[
                3]) + 9*x^10*(36149997109 + 2254203840*Zeta[3]) + 
            45927*x^26*(-14436209219 + 5801457600*Zeta[3]) + 
            252*x^13*(-121008798071 + 26582968800*Zeta[3]) - 
            672*x^15*(-304486972789 + 40092858000*Zeta[3]) + 
            10206*x^19*(-187441279357 + 56299707200*Zeta[3]) - 
            13608*x^23*(-525563267201 + 67749268320*Zeta[3]) + 
            81*x^20*(-857332362703 + 238555564800*Zeta[3]) - 
            84*x^17*(3962869501313 + 334161187200*Zeta[3]) - 
            x^12*(581014861183 + 591327878400*Zeta[3]) - 
            1512*x^21*(-3442703985209 + 787683819600*Zeta[3]) - 
            486*x^22*(-6153817157107 + 1532660401440*Zeta[3]) + 
            4*x^14*(-4666709974547 + 1848923672400*Zeta[3]) - 
            6*x^16*(-30483124287137 + 7869765657600*Zeta[3]) + 
            7*x^18*(-85674134501449 + 19030115361600*Zeta[3]))/
           (8164800*x^2*(1 - 9*x^2)^6*(-1 + x^2)^11))) + 
      CA*CF*((Pi^2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 
           1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{-2}, x])/
         (540*(-1 + x^2)^8) + lm^2*((-11*(1 - 6*x - 23*x^2 - 356*x^3 - 
             398*x^4 - 956*x^5 - 398*x^6 - 356*x^7 - 23*x^8 - 6*x^9 + x^10))/
           (480*(-1 + x^2)^8) - (11*x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 
             3*x^5 + 2*x^6)*HPL[{0}, x])/(4*(-1 + x^2)^9)) + 
        (Pi^2*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 
           1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{2}, x])/
         (540*(-1 + x^2)^8) + (x*(29 + 1227*x + 4734*x^2 + 15486*x^3 + 
           114753*x^4 + 97607*x^5 + 229200*x^6 + 140617*x^7 + 176793*x^8 - 
           93480*x^9 - 87858*x^10 + 205013*x^11 + 75517*x^12 - 255366*x^13 - 
           23760*x^14 + 218790*x^15 - 19800*x^16 - 127490*x^17 + 28160*x^18 + 
           48510*x^19 - 15444*x^20 - 10902*x^21 + 4296*x^22 + 1100*x^23 - 
           500*x^24)*HPL[{-2, 0}, x])/(1080*(-1 + x^2)^10) + 
        ((210000 - 462000*x - 1489320*x^2 + 3885840*x^3 + 4165000*x^4 - 
           14352940*x^5 - 4967900*x^6 + 30416540*x^7 - 812420*x^8 + 
           (-40351757 + 1680*Pi^2)*x^9 - 14*(-689677 + 720*Pi^2)*x^10 + 
           (32926448 - 174720*Pi^2)*x^11 - 14*(2376641 + 83280*Pi^2)*x^12 - 
           3*(13847733 + 590800*Pi^2)*x^13 - 56*(1349519 + 37440*Pi^2)*x^14 - 
           42304904*x^15 + 56*(-1349519 + 37440*Pi^2)*x^16 + 
           3*(-13847733 + 590800*Pi^2)*x^17 + 14*(-2376641 + 83280*Pi^2)*
            x^18 + 16*(2057903 + 10920*Pi^2)*x^19 + 14*(689677 + 720*Pi^2)*
            x^20 - (40351757 + 1680*Pi^2)*x^21 - 812420*x^22 + 
           30416540*x^23 - 4967900*x^24 - 14352940*x^25 + 4165000*x^26 + 
           3885840*x^27 - 1489320*x^28 - 462000*x^29 + 210000*x^30)*
          HPL[{-1, 0}, x])/(907200*x^9*(-1 + x^2)^9) + 
        (x*(38837708280 + 2284087674708*x + 22995042112476*x^2 - 
           57991406106951*x^3 - 967670437408542*x^4 - 197065243403307*x^5 + 
           12257742375553248*x^6 + 21080359707338628*x^7 + 
           8497494629846712*x^8 - 261959354008296228*x^9 - 
           1493676232917171408*x^10 + 1129459021235738064*x^11 + 
           12376909031034473352*x^12 + 640217370687886848*x^13 - 
           27073695318424678896*x^14 - 12557180532030800316*x^15 - 
           78594043247676304320*x^16 - 20693805227905902244*x^17 + 
           234728663965565217224*x^18 + 143409535463545355274*x^19 + 
           448864882775746425324*x^20 + 114924912174267800434*x^21 - 
           148595730066986462064*x^22 - 182676550195879922756*x^23 - 
           33549156789665782496*x^24 + 137725146622439668124*x^25 + 
           15853827165424906896*x^26 - 88560059469416773032*x^27 + 
           7462965888643214712*x^28 + 46554978037072633832*x^29 - 
           9616389697344860528*x^30 - 18389402616248191572*x^31 + 
           5149028205191257800*x^32 + 5265421143815099040*x^33 - 
           1744479184787090052*x^34 - 1070310716887260267*x^35 + 
           394989492472222914*x^36 + 151305200386183665*x^37 - 
           60056561917522800*x^38 - 14451569132479920*x^39 + 
           6035474991326760*x^40 + 886409847401400*x^41 - 
           384018595803360*x^42 - 31465388666880*x^43 + 14008062000240*x^44 + 
           491051484000*x^45 - 223205220000*x^46)*HPL[{0, 0}, x])/
         (907200*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        ((-210000 + 462000*x + 1489320*x^2 - 3885840*x^3 - 4165000*x^4 + 
           14352940*x^5 + 4967900*x^6 - 30416540*x^7 + 812420*x^8 + 
           (40351757 - 1680*Pi^2)*x^9 + 14*(-689677 + 720*Pi^2)*x^10 + 
           16*(-2057903 + 10920*Pi^2)*x^11 + 14*(2376641 + 83280*Pi^2)*x^12 + 
           3*(13847733 + 590800*Pi^2)*x^13 + 56*(1349519 + 37440*Pi^2)*x^14 + 
           42304904*x^15 - 56*(-1349519 + 37440*Pi^2)*x^16 + 
           (41543199 - 1772400*Pi^2)*x^17 - 14*(-2376641 + 83280*Pi^2)*x^18 - 
           16*(2057903 + 10920*Pi^2)*x^19 - 14*(689677 + 720*Pi^2)*x^20 + 
           (40351757 + 1680*Pi^2)*x^21 + 812420*x^22 - 30416540*x^23 + 
           4967900*x^24 + 14352940*x^25 - 4165000*x^26 - 3885840*x^27 + 
           1489320*x^28 + 462000*x^29 - 210000*x^30)*HPL[{1, 0}, x])/
         (907200*x^9*(-1 + x^2)^9) + 
        lm*((-3290 + 13503*x + 49479*x^2 + 1145148*x^3 + 1125863*x^4 + 
            3071034*x^5 + 1125863*x^6 + 1145148*x^7 + 49479*x^8 + 13503*x^9 - 
            3290*x^10 - 66*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 16*x^4 - 
              16*x^6 - 48*x^7 - 3*x^8 - 6*x^9 + x^10))/(38880*(-1 + x^2)^8) + 
          (x^2*(22 - 34092*x - 45770*x^2 - 229698*x^3 - 155178*x^4 - 
             289098*x^5 - 82895*x^6 - 68742*x^7 - 2354*x^8 - 594*x^9 + 
             99*x^10)*HPL[{0}, x])/(1080*(-1 + x^2)^9) + 
          (11*(1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + 
             x^8)*HPL[{-1, 0}, x])/(540*(-1 + x^2)^7) - 
          (11*x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 13200*x^4 - 
             7055*x^5 - 9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 6*x^10 + 
             x^11)*HPL[{0, 0}, x])/(270*(-1 + x^2)^10) - 
          (11*(1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 54*x^5 - 2*x^6 - 6*x^7 + 
             x^8)*HPL[{1, 0}, x])/(540*(-1 + x^2)^7)) + 
        (x*(-29 - 1227*x - 4734*x^2 - 15486*x^3 - 114753*x^4 - 97607*x^5 - 
           229200*x^6 - 140617*x^7 - 176793*x^8 + 93480*x^9 + 87858*x^10 - 
           205013*x^11 - 75517*x^12 + 255366*x^13 + 23760*x^14 - 
           218790*x^15 + 19800*x^16 + 127490*x^17 - 28160*x^18 - 48510*x^19 + 
           15444*x^20 + 10902*x^21 - 4296*x^22 - 1100*x^23 + 500*x^24)*
          HPL[{2, 0}, x])/(1080*(-1 + x^2)^10) + 
        ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x^2)^8) + (4*x^2*(-50 - 326*x - 571*x^2 - 974*x^3 - 
           587*x^4 - 374*x^5 - 53*x^6 - 6*x^7 + x^8)*HPL[{-2, 0, 0}, x])/
         (45*(-1 + x^2)^8) - ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 
           1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{-2, 1, 0}, x])/(45*(-1 + x^2)^8) - 
        ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-1, -2, 0}, x])/
         (45*(-1 + x^2)^8) + ((250 - 550*x - 1398*x^2 + 3801*x^3 + 2778*x^4 - 
           11202*x^5 - 1302*x^6 + 18186*x^7 - 3738*x^8 - 17430*x^9 + 
           7350*x^10 + 9611*x^11 - 5650*x^12 - 2474*x^13 + 4350*x^14 + 
           996*x^15 + 4350*x^16 - 2474*x^17 - 5650*x^18 + 9611*x^19 + 
           7350*x^20 - 17430*x^21 - 3738*x^22 + 18186*x^23 - 1302*x^24 - 
           11202*x^25 + 2778*x^26 + 3801*x^27 - 1398*x^28 - 550*x^29 + 
           250*x^30)*HPL[{-1, -1, 0}, x])/(1080*x^11*(-1 + x^2)^7) + 
        ((5731 - 22438*x - 21720*x^2 - 669318*x^3 + 298267*x^4 - 
           1148254*x^5 + 1486814*x^6 - 1230714*x^7 + 1181212*x^8 - 
           1336348*x^9 - 1470580*x^10 + 1949672*x^11 + 1080476*x^12 - 
           2795940*x^13 + 47460*x^14 + 2285220*x^15 - 789075*x^16 - 
           1053570*x^17 + 665140*x^18 + 216090*x^19 - 248395*x^20 + 
           10430*x^21 + 36750*x^22 - 8750*x^23)*HPL[{-1, 0, 0}, x])/
         (18900*(-1 + x)^10*(1 + x)^8) + 
        ((-250 + 550*x + 1398*x^2 - 3801*x^3 - 2778*x^4 + 11202*x^5 + 
           1302*x^6 - 18186*x^7 + 3738*x^8 + 17430*x^9 - 7350*x^10 - 
           9611*x^11 + 5650*x^12 + 2474*x^13 - 4350*x^14 - 996*x^15 - 
           4350*x^16 + 2474*x^17 + 5650*x^18 - 9611*x^19 - 7350*x^20 + 
           17430*x^21 + 3738*x^22 - 18186*x^23 + 1302*x^24 + 11202*x^25 - 
           2778*x^26 - 3801*x^27 + 1398*x^28 + 550*x^29 - 250*x^30)*
          HPL[{-1, 1, 0}, x])/(1080*x^11*(-1 + x^2)^7) + 
        ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x^2)^8) + (x*(-539412615 - 22376323305*x - 
           744174011070*x^2 - 812145134178*x^3 + 27085708472382*x^4 + 
           74286875645712*x^5 - 214270183141812*x^6 - 1793620625287590*x^7 - 
           3730578902246322*x^8 + 21560753147307336*x^9 + 83496870266489736*
            x^10 - 148179865580754306*x^11 - 597325957982667298*x^12 + 
           639990712284597904*x^13 + 1453720495375196804*x^14 - 
           2139925984722381066*x^15 + 1401034991670733048*x^16 + 
           6648485057937832258*x^17 - 2615792915889228124*x^18 - 
           13233994609820065458*x^19 - 30775793310362726878*x^20 + 
           7216427388312290468*x^21 + 14454125154855576484*x^22 - 
           10247260919733392878*x^23 - 3435072871872619558*x^24 + 
           14443297249962006252*x^25 + 1047045267963666552*x^26 - 
           13488255641023872354*x^27 + 504464298748656498*x^28 + 
           9147599962136546156*x^29 - 1264409268452469524*x^30 - 
           4641244545672532566*x^31 + 1026924191693311527*x^32 + 
           1750815948233734095*x^33 - 499928047783646790*x^34 - 
           482897055109762580*x^35 + 161428336388367272*x^36 + 
           95422126022504748*x^37 - 35376900229414800*x^38 - 
           13205266031708100*x^39 + 5253572970220680*x^40 + 
           1241014366744740*x^41 - 518860520912160*x^42 - 
           75175135064820*x^43 + 32583668864040*x^44 + 2642576200740*x^45 - 
           1176638717520*x^46 - 40920957000*x^47 + 18600435000*x^48)*
          HPL[{0, 0, 0}, x])/(37800*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{1, -2, 0}, x])/
         (45*(-1 + x^2)^8) + ((-250 + 550*x + 1398*x^2 - 3801*x^3 - 
           2778*x^4 + 11202*x^5 + 1302*x^6 - 18186*x^7 + 3738*x^8 + 
           17430*x^9 - 7350*x^10 - 9611*x^11 + 5650*x^12 + 2474*x^13 - 
           4350*x^14 - 996*x^15 - 4350*x^16 + 2474*x^17 + 5650*x^18 - 
           9611*x^19 - 7350*x^20 + 17430*x^21 + 3738*x^22 - 18186*x^23 + 
           1302*x^24 + 11202*x^25 - 2778*x^26 - 3801*x^27 + 1398*x^28 + 
           550*x^29 - 250*x^30)*HPL[{1, -1, 0}, x])/
         (1080*x^11*(-1 + x^2)^7) + ((-5731 - 2166*x + 72344*x^2 + 
           789090*x^3 + 1576725*x^4 + 3664582*x^5 + 3567802*x^6 + 
           4134282*x^7 + 1798100*x^8 - 254260*x^9 - 335756*x^10 + 
           1817624*x^11 + 471844*x^12 - 2190300*x^13 - 388500*x^14 + 
           1829100*x^15 + 217875*x^16 - 1046850*x^17 - 80500*x^18 + 
           393050*x^19 + 17675*x^20 - 87430*x^21 - 1750*x^22 + 8750*x^23)*
          HPL[{1, 0, 0}, x])/(18900*(-1 + x)^8*(1 + x)^10) + 
        ((250 - 550*x - 1398*x^2 + 3801*x^3 + 2778*x^4 - 11202*x^5 - 
           1302*x^6 + 18186*x^7 - 3738*x^8 - 17430*x^9 + 7350*x^10 + 
           9611*x^11 - 5650*x^12 - 2474*x^13 + 4350*x^14 + 996*x^15 + 
           4350*x^16 - 2474*x^17 - 5650*x^18 + 9611*x^19 + 7350*x^20 - 
           17430*x^21 - 3738*x^22 + 18186*x^23 - 1302*x^24 - 11202*x^25 + 
           2778*x^26 + 3801*x^27 - 1398*x^28 - 550*x^29 + 250*x^30)*
          HPL[{1, 1, 0}, x])/(1080*x^11*(-1 + x^2)^7) - 
        ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x^2)^8) - ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 
           1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{2, -1, 0}, x])/(45*(-1 + x^2)^8) - 
        (4*x^2*(-50 - 326*x - 571*x^2 - 974*x^3 - 587*x^4 - 374*x^5 - 
           53*x^6 - 6*x^7 + x^8)*HPL[{2, 0, 0}, x])/(45*(-1 + x^2)^8) + 
        ((-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{2, 1, 0}, x])/
         (45*(-1 + x^2)^8) + (2*(-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 
           54*x^5 + 2*x^6 + 6*x^7 - x^8)*HPL[{-1, 0, 0, 0}, x])/
         (45*(-1 + x^2)^7) + (2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 
           1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*
          HPL[{-1, 1, 0, 0}, x])/(45*(-1 + x^2)^8) + 
        (2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{1, -1, 0, 0}, x])/
         (45*(-1 + x^2)^8) + (2*(1 - 6*x - 2*x^2 - 54*x^3 - 18*x^4 - 54*x^5 - 
           2*x^6 - 6*x^7 + x^8)*HPL[{1, 0, 0, 0}, x])/(45*(-1 + x^2)^7) + 
        ((-1 + 11*x + 79*x^2 + 983*x^3 + 1519*x^4 + 4040*x^5 + 2444*x^6 + 
           2792*x^7 + 464*x^8 + 289*x^9 - 25*x^10 + 5*x^11)*master3l10a[x])/
         (360*(-1 + x^2)^9) + (x*(-5 + 25*x - 289*x^2 - 464*x^3 - 2792*x^4 - 
           2444*x^5 - 4040*x^6 - 1519*x^7 - 983*x^8 - 79*x^9 - 11*x^10 + 
           x^11)*master3l10b[x])/(360*(-1 + x^2)^9) - 
        ((36780231168 + 219984864687*x + 1577323152297*x^2 + 
           5156784534762*x^3 + 6203142941544*x^4 + 5606272174671*x^5 + 
           240649731351*x^6 - 1706932920168*x^7 - 973764252864*x^8 - 
           540328340034*x^9 + 98219048346*x^10 + 273934359132*x^11 + 
           45280970640*x^12 - 41091162378*x^13 - 13008879026*x^14 + 
           2236800216*x^15 + 1442524416*x^16 + 48383027*x^17 - 
           77601939*x^18 - 9956534*x^19 + 1794248*x^20 + 292635*x^21 - 
           6677*x^22)*master3l8a[x])/(907200*(-9 + x^2)^6*(-1 + x^2)^10) - 
        ((4060 + 176777*x + 150325*x^2 - 10004580*x^3 - 12840366*x^4 + 
           259152035*x^5 + 274778189*x^6 - 3964932000*x^7 - 2672435808*x^8 + 
           38371794922*x^9 + 12743040170*x^10 - 231109171192*x^11 - 
           40785838212*x^12 + 781009535382*x^13 + 292551429954*x^14 - 
           1040815666800*x^15 - 1816581627756*x^16 - 577131299235*x^17 + 
           3655791054657*x^18 + 717237731772*x^19 + 1711026799650*x^20 + 
           40656095991*x^21 + 48140635473*x^22 - 34101768528*x^23)*
          master3l8b[x])/(907200*x*(1 - 9*x^2)^6*(-1 + x^2)^10) + 
        ((3937888872 + 9546901623*x + 85807935225*x^2 + 192491752131*x^3 + 
           314306726679*x^4 + 129748034682*x^5 + 80355249108*x^6 + 
           20508043164*x^7 + 12653439564*x^8 - 43992426870*x^9 - 
           36526867106*x^10 + 12596407978*x^11 + 11296467090*x^12 - 
           1591188144*x^13 - 1599318876*x^14 + 95936652*x^15 + 
           122712148*x^16 - 1917881*x^17 - 5073871*x^18 - 52885*x^19 + 
           91727*x^20 + 2030*x^21)*master3l9a[x])/(302400*(-9 + x^2)^5*
          (-1 + x^2)^10) + ((2030 + 91727*x - 52885*x^2 - 5073871*x^3 - 
           1917881*x^4 + 122712148*x^5 + 95936652*x^6 - 1599318876*x^7 - 
           1591188144*x^8 + 11296467090*x^9 + 12596407978*x^10 - 
           36526867106*x^11 - 43992426870*x^12 + 12653439564*x^13 + 
           20508043164*x^14 + 80355249108*x^15 + 129748034682*x^16 + 
           314306726679*x^17 + 192491752131*x^18 + 85807935225*x^19 + 
           9546901623*x^20 + 3937888872*x^21)*master3l9b[x])/
         (907200*x*(-1 + x^2)^10*(-1 + 9*x^2)^5) + 
        (HPL[{1}, x]*(Pi^2*(-250 + 550*x + 1648*x^2 - 4351*x^3 - 4176*x^4 + 
             15003*x^5 + 4080*x^6 - 29388*x^7 + 2436*x^8 + 35616*x^9 - 
             11088*x^10 - 27041*x^11 + 13000*x^12 + 12085*x^13 - 10000*x^14 - 
             3470*x^15 + 3470*x^17 + 10000*x^18 - 12085*x^19 - 13000*x^20 + 
             27041*x^21 + 11088*x^22 - 35616*x^23 - 2436*x^24 + 29388*x^25 - 
             4080*x^26 - 15003*x^27 + 4176*x^28 + 4351*x^29 - 1648*x^30 - 
             550*x^31 + 250*x^32) - 288*x^11*(1 - 6*x - 103*x^2 - 700*x^3 - 
             1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + 
             x^10)*Zeta[3]))/(12960*x^11*(-1 + x^2)^8) + 
        (HPL[{-1}, x]*(Pi^2*(250 - 550*x - 1648*x^2 + 4351*x^3 + 4176*x^4 - 
             15003*x^5 - 4080*x^6 + 29388*x^7 - 2436*x^8 - 35616*x^9 + 
             11088*x^10 + 27041*x^11 - 13000*x^12 - 12085*x^13 + 10000*x^14 + 
             3470*x^15 - 3470*x^17 - 10000*x^18 + 12085*x^19 + 13000*x^20 - 
             27041*x^21 - 11088*x^22 + 35616*x^23 + 2436*x^24 - 29388*x^25 + 
             4080*x^26 + 15003*x^27 - 4176*x^28 - 4351*x^29 + 1648*x^30 + 
             550*x^31 - 250*x^32) + 288*x^11*(1 - 6*x - 103*x^2 - 700*x^3 - 
             1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + 
             x^10)*Zeta[3]))/(12960*x^11*(-1 + x^2)^8) + 
        (HPL[{0}, x]*(-669615660000 + 1473154452000*x + 41689378170720*x^2 - 
           93659588774640*x^3 - 1131266899629720*x^4 + 2612522510687880*x^5 + 
           17544237738360480*x^6 - 42056189726391540*x^7 - 
           612360*(280049084941 + 21141*Pi^2)*x^8 - 
           17496*(-24752600277626 + 31306905*Pi^2)*x^9 - 
           1680*(620379792518444825 + 12434167663613526*Pi^2)*x^26 - 
           3*(144744418081838907 + 1931522995525397960*Pi^2)*x^43 + 
           210*(816499516011615 + 9224500983427964*Pi^2)*x^44 + 
           405*(103893725206071 + 2827313422686368*Pi^2)*x^45 - 
           90720*(193388863959 + 4679484157330*Pi^2)*x^46 - 
           204120*(12798954099 + 776323693810*Pi^2)*x^47 + 
           204120*(5542165881 + 308852026468*Pi^2)*x^48 + 
           1224720*(76474287 + 12159654779*Pi^2)*x^49 - 
           2449440*(17019963 + 2541938668*Pi^2)*x^50 - 
           33067440*(44550 + 27280661*Pi^2)*x^51 + 66134880*
            (10125 + 5912221*Pi^2)*x^52 + 31710914408880*Pi^2*x^53 - 
           14119664610240*Pi^2*x^54 - 491051484000*Pi^2*x^55 + 
           223205220000*Pi^2*x^56 + 144*x^41*(145871095024886455*Pi^2 + 
             27*(777351155693173 - 8928208800*Zeta[3])) - 
           8*x^31*(-2134408344070302028 + 19425358561203709905*Pi^2 - 
             944274647073643200*Zeta[3]) - 168*x^24*(-5556647351870891849 + 
             31797301627372560*Pi^2 - 410807471955062400*Zeta[3]) + 
           8*x^33*(14611941684268865474 + 22691597012462908845*Pi^2 - 
             350010488321726400*Zeta[3]) + 24*x^23*(775357814610594553 + 
             235241647549475595*Pi^2 - 120530949548385600*Zeta[3]) + 
           504*x^22*(-196018615306448773 + 20185226352660540*Pi^2 - 
             57449513274796800*Zeta[3]) - 12*x^35*(8997085371295203163 + 
             13507180784798466150*Pi^2 - 38255347012579200*Zeta[3]) - 
           560*x^20*(116012790364159348 + 5702282920638507*Pi^2 - 
             4668414937272000*Zeta[3]) + 168*x^34*(-556919285760906203 + 
             135245303216964000*Pi^2 - 4357523820844800*Zeta[3]) + 
           12*x^37*(4080714715632289503 + 9127746123675213230*Pi^2 - 
             3350971039651200*Zeta[3]) - 36*x^39*(405032337331745009 + 
             1545737785293561090*Pi^2 - 51105067171200*Zeta[3]) + 
           126*x^12*(-37365166658167723 + 381768187500*Pi^2 - 
             9122078476800*Zeta[3]) - 6804*x^10*(-161792844953239 + 
             206584020*Pi^2 - 3401222400*Zeta[3]) - 
           252*x^42*(4368478491287073 + 23806361535983740*Pi^2 + 
             91833004800*Zeta[3]) + 243*x^11*(-12330374870254243 + 
             94774957200*Pi^2 + 142851340800*Zeta[3]) + 
           504*x^40*(9418794272891332 + 24441469934316975*Pi^2 + 
             2280519619200*Zeta[3]) + 504*x^14*(26741428762555979 + 
             502613982900*Pi^2 + 44899536902400*Zeta[3]) - 
           1680*x^16*(15923706918476849 + 16332032158083*Pi^2 + 
             126028422417600*Zeta[3]) - 168*x^38*(86324604711803817 + 
             89422592862300700*Pi^2 + 134698610707200*Zeta[3]) - 
           9*x^13*(-1588477073587759091 + 38998575864360*Pi^2 + 
             204420268684800*Zeta[3]) + 840*x^36*(45062123919731773 + 
             5007784841903574*Pi^2 + 252056844835200*Zeta[3]) + 
           72*x^15*(-662400224900929763 + 29234999458035*Pi^2 + 
             558495173275200*Zeta[3]) + 168*x^18*(263411923845474083 + 
             2629180702116720*Pi^2 + 4357523820844800*Zeta[3]) - 
           280*x^32*(-146819638906071461 + 190876667784415410*Pi^2 + 
             9336829874544000*Zeta[3]) - 24*x^17*(-4613264696301836264 + 
             164029897104885*Pi^2 + 19127673506289600*Zeta[3]) + 
           504*x^30*(1895648439501076253 + 137177145409717620*Pi^2 + 
             57449513274796800*Zeta[3]) + 12*x^19*(-13869051427606184731 + 
             6040957751273970*Pi^2 + 233340325547817600*Zeta[3]) + 
           6*x^29*(31208915380324645703 + 17889133048558671900*Pi^2 + 
             482123798193542400*Zeta[3]) - 84*x^28*(28356611282019229033 + 
             532261198377337560*Pi^2 + 821614943910124800*Zeta[3]) - 
           42*x^27*(28084438840721332099 + 1455150096058891340*Pi^2 + 
             1226387823950534400*Zeta[3]) - 4*x^21*(-28013769960182051219 + 
             301627635852516750*Pi^2 + 1888549294147286400*Zeta[3]) + 
           8*x^25*(46393824342611695256 + 151528677277569585*Pi^2 + 
             6438536075740305600*Zeta[3])))/(10886400*x^7*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6) + (4032*Pi^4*x^9*(-1 + x^2)^2*
           (9 - 82*x^2 + 9*x^4)^6*(-3 + 18*x - 491*x^2 - 3116*x^3 - 
            5662*x^4 - 9740*x^5 - 5918*x^6 - 3884*x^7 - 539*x^8 - 78*x^9 + 
            13*x^10) - 12*Pi^2*(9 - 82*x^2 + 9*x^4)^6*(-210000 + 462000*x + 
            1699320*x^2 - 4347840*x^3 - 5654320*x^4 + 18238780*x^5 + 
            9132900*x^6 - 44769480*x^7 - 4155480*x^8 + 70768297*x^9 - 
            10467898*x^10 - 73278205*x^11 + 42928452*x^12 + 74469647*x^13 + 
            42300090*x^14 + 761705*x^15 - 761705*x^17 - 42300090*x^18 - 
            74469647*x^19 - 42928452*x^20 + 73278205*x^21 + 10467898*x^22 - 
            70768297*x^23 + 4155480*x^24 + 44769480*x^25 - 9132900*x^26 - 
            18238780*x^27 + 5654320*x^28 + 4347840*x^29 - 1699320*x^30 - 
            462000*x^31 + 210000*x^32) + x^2*(2008846980000 - 
            4419463356000*x - 125737750172160*x^2 + 282451920775920*x^3 + 
            3435238971187380*x^4 - 7930674687918780*x^5 - 53748777383971740*
             x^6 + x^33*(945508478323245855324 - 6430224102065715457728*Zeta[
                3]) + x^26*(9158322674740257027128 - 6374993760933864756480*
               Zeta[3]) + x^25*(6121511437130707020858 - 
              3052437854539743854784*Zeta[3]) + x^27*(588910402336373971398 - 
              767213266512819248064*Zeta[3]) - 1141592918719680*x^53*
             Zeta[3] + 508307925968640*x^54*Zeta[3] + 17677853424000*x^55*
             Zeta[3] - 8035387920000*x^56*Zeta[3] - 595213920*x^52*
             (-3375 + 23648884*Zeta[3]) + 595213920*x^51*
             (-7425 + 54561322*Zeta[3]) + 91854*x^8*(5790498413329 + 
              385588512*Zeta[3]) + 352719360*x^50*(-356481 + 635484667*Zeta[
                3]) - 19683*x^7*(-6544360713613 + 1125855936*Zeta[3]) - 
            20412*x^10*(170099421452689 + 8892656928*Zeta[3]) - 
            11022480*x^49*(-25625079 + 48638619116*Zeta[3]) + 
            6561*x^9*(-204425763126989 + 198781807104*Zeta[3]) - 
            918540*x^48*(-3739890447 + 2470816211744*Zeta[3]) + 
            918540*x^47*(-8634000357 + 6210589550480*Zeta[3]) - 
            91008*x^15*(-1518635200415149 + 29810088351801*Zeta[3]) - 
            729*x^11*(-12833715948327709 + 44141781829824*Zeta[3]) + 
            204120*x^46*(-263318078097 + 74871746517280*Zeta[3]) - 
            378*x^12*(-39574502567230789 + 129194849407392*Zeta[3]) + 
            504*x^14*(-74048142702213103 + 2963602945899072*Zeta[3]) - 
            4788*x^16*(1478384459284177 + 4062168209810880*Zeta[3]) + 
            27*x^13*(-1633692548611227629 + 15449478924817152*Zeta[3]) - 
            729*x^45*(-176545152041841 + 56546297881859392*Zeta[3]) + 
            36*x^17*(-8331399419965729145 + 61800107526684576*Zeta[3]) + 
            2268*x^42*(-1526560652678481 + 95225434838334688*Zeta[3]) + 
            1008*x^18*(478356098063734115 + 125261983902574368*Zeta[3]) - 
            378*x^44*(-1406253412585557 + 184489938427527904*Zeta[3]) - 
            1008*x^34*(-24281882968484975 + 672361240961639232*Zeta[3]) - 
            252*x^36*(-212536498654759337 + 681988067593434720*Zeta[3]) - 
            2688*x^30*(494554197459835673 + 949856378263085466*Zeta[3]) + 
            5364*x^35*(-82742258112201475 + 1088113865288701104*Zeta[3]) - 
            378*x^40*(-39545514246054979 + 1173325363979696352*Zeta[3]) - 
            224*x^20*(6517058009304522311 + 1493749405548144432*Zeta[3]) + 
            252*x^38*(-161756199531789641 + 2152224702772880064*Zeta[3]) - 
            168*x^22*(2495633779842948353 + 2300031895315971456*Zeta[3]) + 
            27*x^43*(-49571695025751177 + 7726137993118293632*Zeta[3]) + 
            12*x^19*(59717073839774160947 + 8459641989969073056*Zeta[3]) - 
            81*x^41*(-115849827471058011 + 9336123891753956416*Zeta[3]) + 
            112*x^32*(640959997941431003 + 13292115119962406136*Zeta[3]) - 
            36*x^21*(62016115395424092997 + 21777495451895480288*Zeta[3]) + 
            84*x^24*(56030174884897219993 + 46266535762544542176*Zeta[3]) - 
            72*x^37*(-2258323049256598561 + 54801418984787561304*Zeta[3]) - 
            18*x^29*(15556276426650829065 + 63044034625963431776*Zeta[3]) + 
            84*x^28*(2314706467099847863 + 63770130755027885376*Zeta[3]) + 
            27*x^39*(-1698587586369673859 + 74209842097124666112*Zeta[3]) + 
            36*x^31*(-33040399838966576767 + 132517662643664405872*Zeta[3]) + 
            18*x^23*(127452848049239642025 + 141468569787246819424*Zeta[3])))/
         (130636800*x^9*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6)) + 
      CF^2*((Pi^2*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 
           1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-2}, x])/
         (270*(-1 + x^2)^8) + lm^2*((9*(1 - 6*x - 23*x^2 - 356*x^3 - 
             398*x^4 - 956*x^5 - 398*x^6 - 356*x^7 - 23*x^8 - 6*x^9 + x^10))/
           (80*(-1 + x^2)^8) + (27*x^3*(2 + 3*x + 12*x^2 + 8*x^3 + 12*x^4 + 
             3*x^5 + 2*x^6)*HPL[{0}, x])/(2*(-1 + x^2)^9)) + 
        (Pi^2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{2}, x])/
         (270*(-1 + x^2)^8) - (x*(1015 + 42945*x + 407610*x^2 + 819210*x^3 + 
           6097875*x^4 + 4870285*x^5 + 8353800*x^6 + 7674555*x^7 + 
           15461075*x^8 - 12868912*x^9 - 20129130*x^10 + 37002133*x^11 + 
           26571699*x^12 - 64173336*x^13 - 19815616*x^14 + 76271400*x^15 + 
           4336204*x^16 - 62992620*x^17 + 7167284*x^18 + 35714786*x^19 - 
           8463716*x^20 - 13303386*x^21 + 4391560*x^22 + 2939400*x^23 - 
           1184500*x^24 - 292500*x^25 + 135000*x^26)*HPL[{-2, 0}, x])/
         (18900*(-1 + x^2)^10) + ((56700000 - 122850000*x - 412440000*x^2 + 
           1050273000*x^3 + 1202170200*x^4 - 3960825120*x^5 - 
           1582017920*x^6 + 8626477440*x^7 + 152646900*x^8 - 
           11908724940*x^9 + 2665127780*x^10 + (10725927941 - 58800*Pi^2)*
            x^11 + 70*(-61825937 + 5040*Pi^2)*x^12 + 
           8*(-770741747 + 764400*Pi^2)*x^13 + 210*(20009839 + 194320*Pi^2)*
            x^14 + 25*(126607651 + 2481360*Pi^2)*x^15 + 
           280*(10510343 + 262080*Pi^2)*x^16 + 2096591960*x^17 - 
           280*(-10510343 + 262080*Pi^2)*x^18 + (3165191275 - 62034000*Pi^2)*
            x^19 - 210*(-20009839 + 194320*Pi^2)*x^20 - 
           8*(770741747 + 764400*Pi^2)*x^21 - 70*(61825937 + 5040*Pi^2)*
            x^22 + (10725927941 + 58800*Pi^2)*x^23 + 2665127780*x^24 - 
           11908724940*x^25 + 152646900*x^26 + 8626477440*x^27 - 
           1582017920*x^28 - 3960825120*x^29 + 1202170200*x^30 + 
           1050273000*x^31 - 412440000*x^32 - 122850000*x^33 + 56700000*x^34)*
          HPL[{-1, 0}, x])/(15876000*x^11*(-1 + x^2)^9) - 
        (x*(1359319789800 + 81681390868140*x + 1249549482473460*x^2 - 
           1756670570945325*x^3 - 52865231533318890*x^4 - 20781097242417225*
            x^5 + 714420971912889360*x^6 + 955363853684845080*x^7 - 
           957392402072586480*x^8 - 9876230295863685768*x^9 - 
           62100122026979544480*x^10 + 22885777817504974260*x^11 + 
           533519037296663664960*x^12 + 231681514068510290556*x^13 - 
           881428887447366066480*x^14 - 1408595713322251161360*x^15 - 
           6015347228148396590760*x^16 + 1193121273407717687152*x^17 + 
           18076774522125013344440*x^18 + 1691746970857645171794*x^19 + 
           11234379271094508371500*x^20 + 18941885850756276351970*x^21 + 
           3762018594557874725200*x^22 - 33404962118352608800128*x^23 - 
           11223742896708612864440*x^24 + 39036168699626595884200*x^25 + 
           5772426591606935940400*x^26 - 35737148266567336859676*x^27 + 
           689574745375509891520*x^28 + 25020270772894701247452*x^29 - 
           3459622520501745366160*x^30 - 13139781448374437135760*x^31 + 
           2965750585203704696160*x^32 + 5103388011807266293476*x^33 - 
           1488145417940579594700*x^34 - 1441472023426204552365*x^35 + 
           491818636815264000270*x^36 + 290281070088020679327*x^37 - 
           109733151988939298400*x^38 - 40768738979924473560*x^39 + 
           16520351873379487560*x^40 + 3875496101895327840*x^41 - 
           1648755439523645040*x^42 - 236863170922749840*x^43 + 
           104378339433236400*x^44 + 8384994256086000*x^45 - 
           3793149508680000*x^46 - 130575053700000*x^47 + 
           60265409400000*x^48)*HPL[{0, 0}, x])/(15876000*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6) - ((56700000 - 122850000*x - 
           412440000*x^2 + 1050273000*x^3 + 1202170200*x^4 - 3960825120*x^5 - 
           1582017920*x^6 + 8626477440*x^7 + 152646900*x^8 - 
           11908724940*x^9 + 2665127780*x^10 + (10725927941 - 58800*Pi^2)*
            x^11 + 70*(-61825937 + 5040*Pi^2)*x^12 + 
           8*(-770741747 + 764400*Pi^2)*x^13 + 210*(20009839 + 194320*Pi^2)*
            x^14 + 25*(126607651 + 2481360*Pi^2)*x^15 + 
           280*(10510343 + 262080*Pi^2)*x^16 + 2096591960*x^17 - 
           280*(-10510343 + 262080*Pi^2)*x^18 + (3165191275 - 62034000*Pi^2)*
            x^19 - 210*(-20009839 + 194320*Pi^2)*x^20 - 
           8*(770741747 + 764400*Pi^2)*x^21 - 70*(61825937 + 5040*Pi^2)*
            x^22 + (10725927941 + 58800*Pi^2)*x^23 + 2665127780*x^24 - 
           11908724940*x^25 + 152646900*x^26 + 8626477440*x^27 - 
           1582017920*x^28 - 3960825120*x^29 + 1202170200*x^30 + 
           1050273000*x^31 - 412440000*x^32 - 122850000*x^33 + 56700000*x^34)*
          HPL[{1, 0}, x])/(15876000*x^11*(-1 + x^2)^9) + 
        lm*(-(-221 + 192*x + 321*x^2 + 73932*x^3 + 54584*x^4 + 197784*x^5 + 
             54584*x^6 + 73932*x^7 + 321*x^8 + 192*x^9 - 221*x^10 - 
             12*Pi^2*(-1 + 6*x + 3*x^2 + 48*x^3 + 16*x^4 - 16*x^6 - 48*x^7 - 
               3*x^8 - 6*x^9 + x^10))/(1440*(-1 + x^2)^8) + 
          (x^2*(-2 + 1842*x + 2275*x^2 + 13338*x^3 + 9078*x^4 + 18738*x^5 + 
             5650*x^6 + 4992*x^7 + 214*x^8 + 54*x^9 - 9*x^10)*HPL[{0}, x])/
           (20*(-1 + x^2)^9) + ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 
             54*x^5 + 2*x^6 + 6*x^7 - x^8)*HPL[{-1, 0}, x])/
           (10*(-1 + x^2)^7) + (x^3*(-360 - 540*x - 4500*x^2 - 4400*x^3 - 
             13200*x^4 - 7055*x^5 - 9810*x^6 - 2169*x^7 - 1476*x^8 - 5*x^9 - 
             6*x^10 + x^11)*HPL[{0, 0}, x])/(5*(-1 + x^2)^10) - 
          ((-1 + 6*x + 2*x^2 + 54*x^3 + 18*x^4 + 54*x^5 + 2*x^6 + 6*x^7 - 
             x^8)*HPL[{1, 0}, x])/(10*(-1 + x^2)^7)) + 
        (x*(1015 + 42945*x + 407610*x^2 + 819210*x^3 + 6097875*x^4 + 
           4870285*x^5 + 8353800*x^6 + 7674555*x^7 + 15461075*x^8 - 
           12868912*x^9 - 20129130*x^10 + 37002133*x^11 + 26571699*x^12 - 
           64173336*x^13 - 19815616*x^14 + 76271400*x^15 + 4336204*x^16 - 
           62992620*x^17 + 7167284*x^18 + 35714786*x^19 - 8463716*x^20 - 
           13303386*x^21 + 4391560*x^22 + 2939400*x^23 - 1184500*x^24 - 
           292500*x^25 + 135000*x^26)*HPL[{2, 0}, x])/(18900*(-1 + x^2)^10) + 
        (2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x^2)^8) + (4*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 
           1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x^2)^8) + 
        (2*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{-2, 1, 0}, x])/
         (45*(-1 + x^2)^8) + (2*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 
           1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{-1, -2, 0}, x])/(45*(-1 + x^2)^8) + 
        ((67500 - 146250*x - 254750*x^2 + 738450*x^3 + 247030*x^4 - 
           1496943*x^5 + 225792*x^6 + 1525678*x^7 - 642698*x^8 - 782740*x^9 + 
           508242*x^10 + 157290*x^11 - 171598*x^12 + 9017*x^13 + 24682*x^14 - 
           10404*x^15 + 24682*x^16 + 9017*x^17 - 171598*x^18 + 157290*x^19 + 
           508242*x^20 - 782740*x^21 - 642698*x^22 + 1525678*x^23 + 
           225792*x^24 - 1496943*x^25 + 247030*x^26 + 738450*x^27 - 
           254750*x^28 - 146250*x^29 + 67500*x^30)*HPL[{-1, -1, 0}, x])/
         (18900*x^13*(-1 + x^2)^5) + ((-6838 + 36002*x + 51262*x^2 + 
           865984*x^3 - 339497*x^4 + 893652*x^5 - 1439760*x^6 + 1725552*x^7 - 
           3320382*x^8 + 1484354*x^9 + 8622458*x^10 - 7524430*x^11 - 
           11946214*x^12 + 18142502*x^13 + 7742930*x^14 - 23720554*x^15 + 
           1562478*x^16 + 18427496*x^17 - 6921160*x^18 - 8168818*x^19 + 
           5401403*x^20 + 1597870*x^21 - 1945450*x^22 + 97250*x^23 + 
           281250*x^24 - 67500*x^25)*HPL[{-1, 0, 0}, x])/
         (9450*(-1 + x)^10*(1 + x)^8) - ((67500 - 146250*x - 254750*x^2 + 
           738450*x^3 + 247030*x^4 - 1496943*x^5 + 225792*x^6 + 1525678*x^7 - 
           642698*x^8 - 782740*x^9 + 508242*x^10 + 157290*x^11 - 
           171598*x^12 + 9017*x^13 + 24682*x^14 - 10404*x^15 + 24682*x^16 + 
           9017*x^17 - 171598*x^18 + 157290*x^19 + 508242*x^20 - 
           782740*x^21 - 642698*x^22 + 1525678*x^23 + 225792*x^24 - 
           1496943*x^25 + 247030*x^26 + 738450*x^27 - 254750*x^28 - 
           146250*x^29 + 67500*x^30)*HPL[{-1, 1, 0}, x])/
         (18900*x^13*(-1 + x^2)^5) + (2*(1 - 6*x - 103*x^2 - 700*x^3 - 
           1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*
          HPL[{-1, 2, 0}, x])/(45*(-1 + x^2)^8) + 
        (x*(-539412615 - 23269144185*x + 815230658025*x^2 + 
           1594211742207*x^3 - 31056118656948*x^4 - 24526562452110*x^5 + 
           391856187431646*x^6 - 445542859704582*x^7 - 1105429170372030*x^8 + 
           19451396874940686*x^9 - 4765615656251142*x^10 - 
           268891916517843306*x^11 - 180655069430656618*x^12 + 
           1818637932471212290*x^13 + 3135607857091037334*x^14 - 
           5765943655416996022*x^15 - 16462210807305905620*x^16 + 
           5541739308455536244*x^17 + 27035029717601729068*x^18 - 
           5537555902617695832*x^19 - 1826432163426790074*x^20 + 
           73788801358987914358*x^21 + 91390327817018674242*x^22 - 
           119748058343114240102*x^23 - 95321900745595850242*x^24 + 
           187457352037323409666*x^25 + 74515713570124355710*x^26 - 
           242547619881425719418*x^27 - 42785702718907981774*x^28 + 
           242118103313941243038*x^29 + 5840933819402051578*x^30 - 
           186904729733820827086*x^31 + 17186839240699541363*x^32 + 
           111458928285775864189*x^33 - 20290944882501327213*x^34 - 
           50920616632389431967*x^35 + 12854789425703681734*x^36 + 
           17583659274820005504*x^37 - 5406980618916577352*x^38 - 
           4508886916054457244*x^39 + 1579129631004308400*x^40 + 
           840569988875067360*x^41 - 321896118155241672*x^42 - 
           111143639859018876*x^43 + 45325759238700336*x^44 + 
           10081617060140280*x^45 - 4302145039468392*x^46 - 
           594035877569652*x^47 + 262126605436920*x^48 + 20430611515800*
            x^49 - 9246541959000*x^50 - 310892985000*x^51 + 
           143489070000*x^52)*HPL[{0, 0, 0}, x])/(18900*(-1 + x^2)^11*
          (9 - 82*x^2 + 9*x^4)^6) + (2*(1 - 6*x - 103*x^2 - 700*x^3 - 
           1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*
          HPL[{1, -2, 0}, x])/(45*(-1 + x^2)^8) - 
        ((67500 - 146250*x - 254750*x^2 + 738450*x^3 + 247030*x^4 - 
           1496943*x^5 + 225792*x^6 + 1525678*x^7 - 642698*x^8 - 782740*x^9 + 
           508242*x^10 + 157290*x^11 - 171598*x^12 + 9017*x^13 + 24682*x^14 - 
           10404*x^15 + 24682*x^16 + 9017*x^17 - 171598*x^18 + 157290*x^19 + 
           508242*x^20 - 782740*x^21 - 642698*x^22 + 1525678*x^23 + 
           225792*x^24 - 1496943*x^25 + 247030*x^26 + 738450*x^27 - 
           254750*x^28 - 146250*x^29 + 67500*x^30)*HPL[{1, -1, 0}, x])/
         (18900*x^13*(-1 + x^2)^5) - ((-6838 + 6970*x + 147286*x^2 + 
           1199152*x^3 + 2703551*x^4 + 5367776*x^5 + 5343984*x^6 + 
           6317796*x^7 + 3286506*x^8 - 3096458*x^9 - 2199838*x^10 + 
           9808662*x^11 + 3454626*x^12 - 16175446*x^13 - 3723798*x^14 + 
           18635658*x^15 + 2859414*x^16 - 15084932*x^17 - 1532968*x^18 + 
           8435354*x^19 + 546283*x^20 - 3110930*x^21 - 116450*x^22 + 
           682250*x^23 + 11250*x^24 - 67500*x^25)*HPL[{1, 0, 0}, x])/
         (9450*(-1 + x)^8*(1 + x)^10) + ((67500 - 146250*x - 254750*x^2 + 
           738450*x^3 + 247030*x^4 - 1496943*x^5 + 225792*x^6 + 1525678*x^7 - 
           642698*x^8 - 782740*x^9 + 508242*x^10 + 157290*x^11 - 
           171598*x^12 + 9017*x^13 + 24682*x^14 - 10404*x^15 + 24682*x^16 + 
           9017*x^17 - 171598*x^18 + 157290*x^19 + 508242*x^20 - 
           782740*x^21 - 642698*x^22 + 1525678*x^23 + 225792*x^24 - 
           1496943*x^25 + 247030*x^26 + 738450*x^27 - 254750*x^28 - 
           146250*x^29 + 67500*x^30)*HPL[{1, 1, 0}, x])/
         (18900*x^13*(-1 + x^2)^5) + (2*(-1 + 6*x + 103*x^2 + 700*x^3 + 
           1158*x^4 + 1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{1, 2, 0}, x])/(45*(-1 + x^2)^8) + 
        (2*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{2, -1, 0}, x])/
         (45*(-1 + x^2)^8) + (4*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 
           1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*
          HPL[{2, 0, 0}, x])/(45*(-1 + x^2)^8) + 
        (2*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
           700*x^7 - 103*x^8 - 6*x^9 + x^10)*HPL[{2, 1, 0}, x])/
         (45*(-1 + x^2)^8) + (4*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 
           1948*x^5 + 1158*x^6 + 700*x^7 + 103*x^8 + 6*x^9 - x^10)*
          HPL[{-1, 1, 0, 0}, x])/(45*(-1 + x^2)^8) + 
        (4*(-1 + 6*x + 103*x^2 + 700*x^3 + 1158*x^4 + 1948*x^5 + 1158*x^6 + 
           700*x^7 + 103*x^8 + 6*x^9 - x^10)*HPL[{1, -1, 0, 0}, x])/
         (45*(-1 + x^2)^8) - ((-1 + 11*x + 79*x^2 + 983*x^3 + 1519*x^4 + 
           4040*x^5 + 2444*x^6 + 2792*x^7 + 464*x^8 + 289*x^9 - 25*x^10 + 
           5*x^11)*master3l10a[x])/(180*(-1 + x^2)^9) + 
        (x*(5 - 25*x + 289*x^2 + 464*x^3 + 2792*x^4 + 2444*x^5 + 4040*x^6 + 
           1519*x^7 + 983*x^8 + 79*x^9 + 11*x^10 - x^11)*master3l10b[x])/
         (180*(-1 + x^2)^9) + ((36780231168 + 219984864687*x + 
           1577323152297*x^2 + 5156784534762*x^3 + 6203142941544*x^4 + 
           5606272174671*x^5 + 240649731351*x^6 - 1706932920168*x^7 - 
           973764252864*x^8 - 540328340034*x^9 + 98219048346*x^10 + 
           273934359132*x^11 + 45280970640*x^12 - 41091162378*x^13 - 
           13008879026*x^14 + 2236800216*x^15 + 1442524416*x^16 + 
           48383027*x^17 - 77601939*x^18 - 9956534*x^19 + 1794248*x^20 + 
           292635*x^21 - 6677*x^22)*master3l8a[x])/(453600*(-9 + x^2)^6*
          (-1 + x^2)^10) + ((4060 + 176777*x + 150325*x^2 - 10004580*x^3 - 
           12840366*x^4 + 259152035*x^5 + 274778189*x^6 - 3964932000*x^7 - 
           2672435808*x^8 + 38371794922*x^9 + 12743040170*x^10 - 
           231109171192*x^11 - 40785838212*x^12 + 781009535382*x^13 + 
           292551429954*x^14 - 1040815666800*x^15 - 1816581627756*x^16 - 
           577131299235*x^17 + 3655791054657*x^18 + 717237731772*x^19 + 
           1711026799650*x^20 + 40656095991*x^21 + 48140635473*x^22 - 
           34101768528*x^23)*master3l8b[x])/(453600*x*(1 - 9*x^2)^6*
          (-1 + x^2)^10) - ((3937888872 + 9546901623*x + 85807935225*x^2 + 
           192491752131*x^3 + 314306726679*x^4 + 129748034682*x^5 + 
           80355249108*x^6 + 20508043164*x^7 + 12653439564*x^8 - 
           43992426870*x^9 - 36526867106*x^10 + 12596407978*x^11 + 
           11296467090*x^12 - 1591188144*x^13 - 1599318876*x^14 + 
           95936652*x^15 + 122712148*x^16 - 1917881*x^17 - 5073871*x^18 - 
           52885*x^19 + 91727*x^20 + 2030*x^21)*master3l9a[x])/
         (151200*(-9 + x^2)^5*(-1 + x^2)^10) - 
        ((2030 + 91727*x - 52885*x^2 - 5073871*x^3 - 1917881*x^4 + 
           122712148*x^5 + 95936652*x^6 - 1599318876*x^7 - 1591188144*x^8 + 
           11296467090*x^9 + 12596407978*x^10 - 36526867106*x^11 - 
           43992426870*x^12 + 12653439564*x^13 + 20508043164*x^14 + 
           80355249108*x^15 + 129748034682*x^16 + 314306726679*x^17 + 
           192491752131*x^18 + 85807935225*x^19 + 9546901623*x^20 + 
           3937888872*x^21)*master3l9b[x])/(453600*x*(-1 + x^2)^10*
          (-1 + 9*x^2)^5) - (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*
            (67500 - 146250*x - 254750*x^2 + 738450*x^3 + 247030*x^4 - 
             1496943*x^5 + 225792*x^6 + 1525678*x^7 - 642698*x^8 - 
             782740*x^9 + 508242*x^10 + 157290*x^11 - 171598*x^12 + 
             9017*x^13 + 24682*x^14 - 10404*x^15 + 24682*x^16 + 9017*x^17 - 
             171598*x^18 + 157290*x^19 + 508242*x^20 - 782740*x^21 - 
             642698*x^22 + 1525678*x^23 + 225792*x^24 - 1496943*x^25 + 
             247030*x^26 + 738450*x^27 - 254750*x^28 - 146250*x^29 + 
             67500*x^30) + 10080*x^13*(1 - 6*x - 103*x^2 - 700*x^3 - 
             1158*x^4 - 1948*x^5 - 1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + 
             x^10)*Zeta[3]))/(226800*x^13*(-1 + x^2)^8) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(67500 - 146250*x - 254750*x^2 + 
             738450*x^3 + 247030*x^4 - 1496943*x^5 + 225792*x^6 + 
             1525678*x^7 - 642698*x^8 - 782740*x^9 + 508242*x^10 + 
             157290*x^11 - 171598*x^12 + 9017*x^13 + 24682*x^14 - 
             10404*x^15 + 24682*x^16 + 9017*x^17 - 171598*x^18 + 
             157290*x^19 + 508242*x^20 - 782740*x^21 - 642698*x^22 + 
             1525678*x^23 + 225792*x^24 - 1496943*x^25 + 247030*x^26 + 
             738450*x^27 - 254750*x^28 - 146250*x^29 + 67500*x^30) + 
           10080*x^13*(1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 
             1158*x^6 - 700*x^7 - 103*x^8 - 6*x^9 + x^10)*Zeta[3]))/
         (226800*x^13*(-1 + x^2)^8) + (HPL[{0}, x]*(-180796228200000 + 
           391725161100000*x + 11289050411940000*x^2 - 24959120187708000*
            x^3 - 307505559446089200*x^4 + 698142596437820520*x^5 + 
           4793446759872710520*x^6 - 11279480612267669760*x^7 - 
           47189492097400361520*x^8 + 116723625557193334260*x^9 + 
           3061800*(99938490896131 + 147987*Pi^2)*x^10 + 
           17496*(-46490162340436882 + 1095741675*Pi^2)*x^11 - 
           35280*(-1103636209822708135 + 64717083552992562*Pi^2)*x^28 + 
           27*(30127107064501975761 + 214879623248705657480*Pi^2)*x^45 - 
           210*(1457099411915174805 + 8216941807160399236*Pi^2)*x^46 - 
           945*(123517829924853993 + 1675534473654211952*Pi^2)*x^47 + 
           45360*(1040332718196657 + 12023242135193024*Pi^2)*x^48 + 
           816480*(13814766573912 + 380110107982073*Pi^2)*x^49 - 
           204120*(23483474230221 + 577406338278728*Pi^2)*x^50 - 
           1837080*(380028412719 + 23236382935052*Pi^2)*x^51 + 
           1224720*(251082336735 + 14155225566454*Pi^2)*x^52 + 
           11022480*(2264383350 + 362280936637*Pi^2)*x^53 - 
           198404640*(56899125 + 8571528491*Pi^2)*x^54 - 
           297606960*(1316250 + 809943379*Pi^2)*x^55 + 
           5952139200*(30375 + 17854067*Pi^2)*x^56 + 8450281782936000*Pi^2*
            x^57 - 3823282213380000*Pi^2*x^58 - 130575053700000*Pi^2*x^59 + 
           60265409400000*Pi^2*x^60 + 24*x^33*(2967628209806162231269 + 
             1333510687083964100075*Pi^2 - 11016537549192504000*Zeta[3]) + 
           280*x^26*(-147046066749525853615 + 4960675747302334668*Pi^2 - 
             8626956911056310400*Zeta[3]) - 24*x^25*
            (-2041969763667158443868 + 6560566123387168515*Pi^2 - 
             4218583234193496000*Zeta[3]) - 280*x^24*(-75775987410053966033 + 
             2577475763217288324*Pi^2 - 3619319336312198400*Zeta[3]) - 
           72*x^35*(1068050889964115220433 + 664843373320902548605*Pi^2 - 
             1361151899028936000*Zeta[3]) + 108*x^21*(726388718302498485547 + 
             24639025261251870*Pi^2 - 907434599352624000*Zeta[3]) + 
           36*x^37*(1646619572706069347399 + 1512964466681535671370*Pi^2 - 
             446312381813424000*Zeta[3]) - 72*x^19*(824660045163430892062 + 
             14266876927577715*Pi^2 - 223156190906712000*Zeta[3]) + 
           560*x^22*(-19779106338141174103 + 303817754767697331*Pi^2 - 
             163394522804520000*Zeta[3]) - 840*x^36*(-2224193636641717501 + 
             16017527671322259448*Pi^2 - 30502666745913600*Zeta[3]) - 
           108*x^39*(305906511247585905413 + 437672000537937361350*Pi^2 - 
             13031554043088000*Zeta[3]) + 840*x^38*(-9085165317043054019 + 
             5833646439871289242*Pi^2 - 8821989569232000*Zeta[3]) + 
           216*x^17*(152763225871506665419 + 217132272420525*Pi^2 - 
             6515777021544000*Zeta[3]) + 22680*x^16*(-312724970691484349 + 
             3333667696380*Pi^2 - 34921862035200*Zeta[3]) - 
           3150*x^14*(-1214378431977274649 + 2113697035044*Pi^2 - 
             12770909867520*Zeta[3]) - 648*x^43*(6061470080147249003 + 
             24050548676247654820*Pi^2 - 1874923848000*Zeta[3]) + 
           34020*x^12*(-38983113312035747 + 4620562380*Pi^2 - 
             23808556800*Zeta[3]) + 10125*x^15*(-1324334412638496893 + 
             609276522456*Pi^2 + 6359741692416*Zeta[3]) - 
           81*x^13*(-48480832682694616699 + 8423654778000*Pi^2 + 
             14999390784000*Zeta[3]) - 840*x^42*(4555632518655800430 + 
             5771956754969149607*Pi^2 + 47890912003200*Zeta[3]) + 
           840*x^40*(8486502989474196423 + 2812191163615058372*Pi^2 + 
             942890274950400*Zeta[3]) + 1680*x^18*(4314867079741065157 + 
             271337634582525*Pi^2 + 4410994784616000*Zeta[3]) - 
           840*x^20*(250313134034771701 + 21566077024886100*Pi^2 + 
             30502666745913600*Zeta[3]) + 280*x^34*(43419718085997431231 + 
             63258831800434244394*Pi^2 + 326789045609040000*Zeta[3]) - 
           280*x^32*(182384956436148340313 + 55776131633386338300*Pi^2 + 
             3619319336312198400*Zeta[3]) - 168*x^27*(227554564408455003859 + 
             4795323835129114105*Pi^2 + 10730893459567176000*Zeta[3]) - 
           6*x^31*(9922113138663042083897 + 2730135066788283865340*Pi^2 + 
             16874332936773984000*Zeta[3]) + 140*x^30*
            (636391600454578829705 + 66888954267046923216*Pi^2 + 
             17253913822112620800*Zeta[3]) + 12*x^23*
            (-6206342449038172550213 + 2935591810567462410*Pi^2 + 
             22033075098385008000*Zeta[3]) + 42*x^29*
            (1637089432362168800461 + 155177023014329748540*Pi^2 + 
             42923573838268704000*Zeta[3]) + 420*x^44*
            (8746317158636390060*Pi^2 + 81*(38983276174468487 + 23808556800*
                Zeta[3])) + 60*x^41*(520440257439998484694*Pi^2 - 
             675*(-331318132364530655 + 1589935423104*Zeta[3]))))/
         (190512000*x^9*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) - 
        (235200*Pi^4*x^11*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^6*
           (1 - 6*x - 103*x^2 - 700*x^3 - 1158*x^4 - 1948*x^5 - 1158*x^6 - 
            700*x^7 - 103*x^8 - 6*x^9 + x^10) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^6*
           (-56700000 + 122850000*x + 469140000*x^2 - 1173123000*x^3 - 
            1614610200*x^4 + 5011098120*x^5 + 2784188120*x^6 - 
            12587302560*x^7 - 1734664820*x^8 + 20535202380*x^9 - 
            2512480880*x^10 - 22634652881*x^11 + 6992943370*x^12 + 
            16891861917*x^13 - 8529881780*x^14 - 9331125251*x^15 + 
            1259170150*x^16 + 1068599315*x^17 - 1068599315*x^19 - 
            1259170150*x^20 + 9331125251*x^21 + 8529881780*x^22 - 
            16891861917*x^23 - 6992943370*x^24 + 22634652881*x^25 + 
            2512480880*x^26 - 20535202380*x^27 + 1734664820*x^28 + 
            12587302560*x^29 - 2784188120*x^30 - 5011098120*x^31 + 
            1614610200*x^32 + 1173123000*x^33 - 469140000*x^34 - 
            122850000*x^35 + 56700000*x^36) + x^2*(-180796228200000 + 
            391725161100000*x + 11349315821340000*x^2 - 25089695241408000*
             x^3 - 311245976721544200*x^4 + 706413337521919020*x^5 + 
            4894550037013539420*x^6 - 11509102124193000600*x^7 - 
            48749648604584660460*x^8 + x^35*(98161974351701489617644 - 
              573761233602105462970560*Zeta[3]) + 101403381395232000*x^57*
             Zeta[3] - 45879386560560000*x^58*Zeta[3] - 1566900644400000*x^59*
             Zeta[3] + 723184912800000*x^60*Zeta[3] + 17856417600*x^56*
             (-10125 + 71416268*Zeta[3]) - 688905*x^9*(-174768194526857 + 
              351133056*Zeta[3]) + 238140*x^12*(-5974236887006129 + 
              422703360*Zeta[3]) - 1785641760*x^55*(-219375 + 
              1619886758*Zeta[3]) + 153090*x^10*(2097765844308733 + 
              1696248864*Zeta[3]) - 595213920*x^54*(-19067625 + 
              34286113964*Zeta[3]) + 132269760*x^53*(-189685800 + 
              362280936637*Zeta[3]) + 2187*x^11*(-389093062329837797 + 
              6304507473600*Zeta[3]) + 1837080*x^52*(-169424291115 + 
              113241804531632*Zeta[3]) - 2755620*x^51*(-256353683571 + 
              185891063480416*Zeta[3]) - 630*x^14*(-6715010991721366021 + 
              700120671741792*Zeta[3]) - 81*x^13*(-51648761128483043659 + 
              4128233253399360*Zeta[3]) - 306180*x^50*(-15985858112919 + 
              4619250706229824*Zeta[3]) + 612360*x^49*(-18794666738835 + 
              6081761727713168*Zeta[3]) - 2916*x^17*(-12615115779698186063 + 
              10818431693202000*Zeta[3]) + 5184*x^19*(-13087710131850941623 + 
              14842390056764445*Zeta[3]) + 840*x^16*(-9692466508736178931 + 
              15419921253870816*Zeta[3]) - 2940*x^18*(-2751281877145393471 + 
              57085936834470048*Zeta[3]) + 68040*x^48*(-716485085336349 + 
              96185937081544192*Zeta[3]) + 27*x^15*(-540834794318266728799 + 
              162839736080138880*Zeta[3]) + 840*x^20*(6673282757953573819 + 
              1296865020099401424*Zeta[3]) - 1120*x^22*
             (29938607012283120287 + 2454440521985124432*Zeta[3]) + 
            8820*x^44*(-161291393527978323 + 4997895987148689920*Zeta[3]) - 
            2835*x^47*(-42468213508349121 + 6702137972799613376*Zeta[3]) + 
            2940*x^38*(2991907680526552171 + 19942242326987558496*Zeta[3]) - 
            280*x^24*(-101673976576067096845 + 20908106945562264192*Zeta[
                3]) - 7840*x^32*(-2276905104266647855 + 23707247919232799448*
               Zeta[3]) - 630*x^46*(-509751236254048389 + 
              32867767017933034912*Zeta[3]) + 12*x^21*
             (7957619370180444764287 + 55966028755786914240*Zeta[3]) + 
            420*x^40*(-19480552416363901907 + 67523313563151816000*Zeta[3]) - 
            630*x^42*(-6714808073473135351 + 92352056521242420704*Zeta[3]) + 
            210*x^25*(440811481561373176079 + 134326054630249033120*Zeta[
                3]) - 840*x^36*(-316243746620085859 + 190720875305559906912*
               Zeta[3]) - 28*x^23*(4078175546458676256791 + 
              254619869281735990080*Zeta[3]) + 140*x^26*
             (93466729386111932077 + 366080661051349815648*Zeta[3]) + 
            560*x^34*(-27968703319281797449 + 371726374850432220408*Zeta[
                3]) - 280*x^28*(-535695243998140148605 + 
              405042765031164041952*Zeta[3]) + 644*x^33*
             (-158414774483122326667 + 584783929024393482480*Zeta[3]) - 
            66*x^27*(-705126417889052953351 + 726994293471724121760*Zeta[
                3]) - 210*x^31*(-297802357085482704989 + 
              795507850397225268896*Zeta[3]) + 81*x^45*
             (-10505109150739648269 + 859518645460301160320*Zeta[3]) + 
            140*x^30*(-282541549538469672833 + 1060543888899314398848*Zeta[
                3]) - 324*x^39*(-114414329828958841817 + 
              1750776380783604594000*Zeta[3]) - 81*x^43*
             (-51652802274404311009 + 2308856321204929265280*Zeta[3]) + 
            216*x^37*(-321877370739774275177 + 3026270308125146902680*Zeta[
                3]) + 6*x^29*(-3001444748653842887089 + 
              6846739935965560891680*Zeta[3]) + 9*x^41*
             (-1624775709276345804447 + 41635653373459904951360*Zeta[3])))/
         (762048000*x^11*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6)))
 
CbarLData["v", 2, 4] = 
    NC*(CF*(NL*((Pi^2*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 252*x^5 + 
             68*x^6 + 112*x^7 + 3*x^8 + 7*x^9 - x^10)*HPL[{-1}, x])/
           (2835*(-1 + x^2)^9) + (x^2*(-20484 - 18900*(2831 + 168*Pi^2)*x - 
             54*(1678651 + 117600*Pi^2)*x^2 - 882*(589811 + 45000*Pi^2)*x^3 - 
             160*(2729912 + 277095*Pi^2)*x^4 - 14*(53183351 + 8589000*Pi^2)*
              x^5 - 105*(1039207 + 752640*Pi^2)*x^6 - 
             56*(-9187159 + 2137800*Pi^2)*x^7 + (470324908 - 44123520*Pi^2)*
              x^8 - 8316*(-83527 + 4760*Pi^2)*x^9 + (164479010 - 6444480*
                Pi^2)*x^10 - 70*(-1554661 + 47544*Pi^2)*x^11 - 
             24*(-77017 + 420*Pi^2)*x^12 - 70*(-5263 + 168*Pi^2)*x^13 + 
             7*(-11719 + 240*Pi^2)*x^14)*HPL[{0}, x])/
           (4762800*(-1 + x^2)^12) + 
          lm^2*(-(-1 + 7*x + 34*x^2 + 714*x^3 + 1133*x^4 + 3689*x^5 + 2708*
                x^6 + 3689*x^7 + 1133*x^8 + 714*x^9 + 34*x^10 + 7*x^11 - x^
                12)/(315*(-1 + x^2)^10) + (4*x^3*(1 + 2*x + 10*x^2 + 10*x^3 + 
               20*x^4 + 10*x^5 + 10*x^6 + 2*x^7 + x^8)*HPL[{0}, x])/
             (3*(-1 + x^2)^11)) + (Pi^2*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 
             252*x^5 - 68*x^6 - 112*x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{1}, x])/
           (2835*(-1 + x^2)^9) + (4*x^3*(1890 + 3780*x + 23625*x^2 + 
             26390*x^3 + 71575*x^4 + 47040*x^5 + 71260*x^6 + 26264*x^7 + 
             23562*x^8 + 3836*x^9 + 1981*x^10 + 6*x^11 + 7*x^12 - x^13)*
            HPL[{-2, 0}, x])/(945*(-1 + x^2)^12) - 
          ((-569 + 3528*x + 55415*x^2 + 1652392*x^3 + 2935159*x^4 + 
             13175260*x^5 + 12034095*x^6 + 24629640*x^7 + 12034095*x^8 + 
             13175260*x^9 + 2935159*x^10 + 1652392*x^11 + 55415*x^12 + 
             3528*x^13 - 569*x^14)*HPL[{-1, 0}, x])/(132300*(-1 + x^2)^11) + 
          (x^3*(-294000 - 588000*x - 4806900*x^2 - 5713400*x^3 - 
             20604500*x^4 - 15023400*x^5 - 28993300*x^6 - 11884264*x^7 - 
             12870732*x^8 - 2276736*x^9 - 1379056*x^10 - 3936*x^11 - 
             8232*x^12 + 1111*x^13)*HPL[{0, 0}, x])/(66150*(-1 + x^2)^12) + 
          ((-569 + 3528*x + 55415*x^2 + 1652392*x^3 + 2935159*x^4 + 
             13175260*x^5 + 12034095*x^6 + 24629640*x^7 + 12034095*x^8 + 
             13175260*x^9 + 2935159*x^10 + 1652392*x^11 + 55415*x^12 + 
             3528*x^13 - 569*x^14)*HPL[{1, 0}, x])/(132300*(-1 + x^2)^11) + 
          lm*(-(-11719 + 52630*x + 237694*x^2 + 8008170*x^3 + 11034515*x^4 + 
               40877600*x^5 + 26622620*x^6 + 40877600*x^7 + 11034515*x^8 + 
               8008170*x^9 + 237694*x^10 + 52630*x^11 - 11719*x^12 - 240*Pi^2*
                (-1 + 7*x + 4*x^2 + 105*x^3 + 65*x^4 + 140*x^5 - 140*x^7 - 
                 65*x^8 - 105*x^9 - 4*x^10 - 7*x^11 + x^12))/
             (1360800*(-1 + x^2)^10) + (x^2*(-4 + 11128*x + 19860*x^2 + 
               123817*x^3 + 123218*x^4 + 301254*x^5 + 161018*x^6 + 195217*
                x^7 + 46236*x^8 + 28096*x^9 + 836*x^10 + 168*x^11 - 24*x^12)*
              HPL[{0}, x])/(1890*(-1 + x^2)^11) + 
            (2*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 252*x^5 + 68*x^6 + 112*
                x^7 + 3*x^8 + 7*x^9 - x^10)*HPL[{-1, 0}, x])/
             (945*(-1 + x^2)^9) + (4*x^3*(-630 - 1260*x - 12285*x^2 - 16310*
                x^3 - 58975*x^4 - 47040*x^5 - 83860*x^6 - 36344*x^7 - 34902*
                x^8 - 6356*x^9 - 3241*x^10 - 6*x^11 - 7*x^12 + x^13)*
              HPL[{0, 0}, x])/(945*(-1 + x^2)^12) + 
            (2*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 112*
                x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{1, 0}, x])/
             (945*(-1 + x^2)^9)) + (4*x^3*(-1890 - 3780*x - 23625*x^2 - 
             26390*x^3 - 71575*x^4 - 47040*x^5 - 71260*x^6 - 26264*x^7 - 
             23562*x^8 - 3836*x^9 - 1981*x^10 - 6*x^11 - 7*x^12 + x^13)*
            HPL[{2, 0}, x])/(945*(-1 + x^2)^12) + 
          (4*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 
             112*x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{-1, -1, 0}, x])/
           (945*(-1 + x^2)^9) + (4*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 
             252*x^5 + 68*x^6 + 112*x^7 + 3*x^8 + 7*x^9 - x^10)*
            HPL[{-1, 1, 0}, x])/(945*(-1 + x^2)^9) + 
          (8*x^3*(630 + 1260*x + 12285*x^2 + 16310*x^3 + 58975*x^4 + 
             47040*x^5 + 83860*x^6 + 36344*x^7 + 34902*x^8 + 6356*x^9 + 
             3241*x^10 + 6*x^11 + 7*x^12 - x^13)*HPL[{0, 0, 0}, x])/
           (945*(-1 + x^2)^12) + (4*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 
             252*x^5 + 68*x^6 + 112*x^7 + 3*x^8 + 7*x^9 - x^10)*
            HPL[{1, -1, 0}, x])/(945*(-1 + x^2)^9) + 
          (4*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 
             112*x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{1, 1, 0}, x])/
           (945*(-1 + x^2)^9) - (-19387248*x^14 - 7316344*x^15 - 
            1868447*x^16 + 144*Pi^2*(-569 + 3528*x + 55984*x^2 + 
              1648864*x^3 + 2879744*x^4 + 11522868*x^5 + 9098936*x^6 + 
              11454380*x^7 - 11454380*x^9 - 9098936*x^10 - 11522868*x^11 - 
              2879744*x^12 - 1648864*x^13 - 55984*x^14 - 3528*x^15 + 
              569*x^16) + 48*x^2*(-403901 + 60480*Zeta[3]) + 
            56*x*(-130649 + 60480*Zeta[3]) - 7*(266921 + 69120*Zeta[3]) + 
            13608*x^5*(297631 + 837760*Zeta[3]) + 13608*x^11*
             (297631 + 840000*Zeta[3]) + 56*x^13*(21896227 + 16329600*Zeta[
                3]) + 56*x^3*(21896227 + 17115840*Zeta[3]) + 
            40*x^12*(33017371 + 45722880*Zeta[3]) + 
            40*x^4*(33017371 + 46400256*Zeta[3]) + 56*x^7*(-94089911 + 
              615686400*Zeta[3]) + 56*x^9*(-94089911 + 618408000*Zeta[3]) + 
            16*x^6*(47068339 + 794223360*Zeta[3]) + 
            16*x^10*(47068339 + 798033600*Zeta[3]) + 
            6*x^8*(-684177523 + 3793305600*Zeta[3]))/(228614400*
            (-1 + x^2)^12)) + 
        NM*(-((95760 - 670320*x - 6244344*x^2 + 177772140*x^3 + 
              526444425*x^4 - 11598070806*x^5 - 27941332319*x^6 + 
              277290199340*x^7 + 743147059142*x^8 - 1856598838290*x^9 - 
              9817759013060*x^10 - 33569753563052*x^11 + 46108293669769*x^
                12 + 735624389450986*x^13 + 360441288359641*x^14 - 
              5027583420072444*x^15 - 5767189268466226*x^16 + 
              4287734244943646*x^17 + 23779641284657404*x^18 + 
              105062720329446516*x^19 + 16885781137363419*x^20 - 
              351453838772902194*x^21 - 321776667067180797*x^22 - 
              543133464320915244*x^23 + 219458577554072874*x^24 + 
              2324883669472444122*x^25 + 1377523672862899068*x^26 + 
              2854226580451669836*x^27 + 452629248645163347*x^28 + 
              290894115035432286*x^29 - 233730607226332221*x^30 - 
              188749252585321092*x^31 - 82916093218660110*x^32 - 
              20264096930112630*x^33 - 6532729188030972*x^34 + 
              1680*Pi^2*(1 - 9*x^2)^8*(-1 + x^2)^4*(1 - 7*x - 3*x^2 - 
                112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 112*x^7 - 3*x^8 - 
                7*x^9 + x^10))*HPL[{0}, x])/(4762800*(1 - 9*x^2)^8*
            (-1 + x^2)^13) + lm^2*(-(-1 + 7*x + 34*x^2 + 714*x^3 + 1133*x^4 + 
               3689*x^5 + 2708*x^6 + 3689*x^7 + 1133*x^8 + 714*x^9 + 34*
                x^10 + 7*x^11 - x^12)/(315*(-1 + x^2)^10) + 
            (4*x^3*(1 + 2*x + 10*x^2 + 10*x^3 + 20*x^4 + 10*x^5 + 10*x^6 + 2*
                x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11)) + 
          (4*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 
             112*x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{-2, 0}, x])/
           (945*(-1 + x^2)^9) - ((-1680 + 11760*x + 102092*x^2 - 
             4259864*x^3 - 11068593*x^4 + 243118960*x^5 + 547753727*x^6 - 
             3555561464*x^7 - 11440285055*x^8 - 48797114156*x^9 + 
             63904139485*x^10 + 2087358714336*x^11 + 1422277392855*x^12 - 
             23883365921856*x^13 - 28226147553985*x^14 + 77100065682416*
              x^15 + 183866363039083*x^16 + 614382945553188*x^17 - 
             115643798068029*x^18 - 5489074216082520*x^19 - 4224245890540131*
              x^20 + 6466113434026512*x^21 + 15896251995435405*x^22 + 
             54148035012113448*x^23 + 7704736792409943*x^24 - 
             100531226264839524*x^25 - 82457957282837949*x^26 - 
             193454337168692208*x^27 - 41020551878226579*x^28 - 
             35646909491398464*x^29 + 13217060350655109*x^30 + 
             11033185486702176*x^31 + 6219735940227357*x^32 + 
             1587190668513660*x^33 + 502644627609345*x^34)*HPL[{0, 0}, x])/
           (132300*(1 - 9*x^2)^8*(-1 + x^2)^13) + 
          lm*(-(-11719 + 52630*x + 237694*x^2 + 8008170*x^3 + 11034515*x^4 + 
               40877600*x^5 + 26622620*x^6 + 40877600*x^7 + 11034515*x^8 + 
               8008170*x^9 + 237694*x^10 + 52630*x^11 - 11719*x^12 - 240*Pi^2*
                (-1 + 7*x + 4*x^2 + 105*x^3 + 65*x^4 + 140*x^5 - 140*x^7 - 
                 65*x^8 - 105*x^9 - 4*x^10 - 7*x^11 + x^12))/
             (1360800*(-1 + x^2)^10) + (x^2*(-4 + 11128*x + 19860*x^2 + 
               123817*x^3 + 123218*x^4 + 301254*x^5 + 161018*x^6 + 195217*
                x^7 + 46236*x^8 + 28096*x^9 + 836*x^10 + 168*x^11 - 24*x^12)*
              HPL[{0}, x])/(1890*(-1 + x^2)^11) + 
            (2*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 252*x^5 + 68*x^6 + 112*
                x^7 + 3*x^8 + 7*x^9 - x^10)*HPL[{-1, 0}, x])/
             (945*(-1 + x^2)^9) + (4*x^3*(-630 - 1260*x - 12285*x^2 - 16310*
                x^3 - 58975*x^4 - 47040*x^5 - 83860*x^6 - 36344*x^7 - 34902*
                x^8 - 6356*x^9 - 3241*x^10 - 6*x^11 - 7*x^12 + x^13)*
              HPL[{0, 0}, x])/(945*(-1 + x^2)^12) + 
            (2*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 112*
                x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{1, 0}, x])/
             (945*(-1 + x^2)^9)) + (4*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 
             252*x^5 + 68*x^6 + 112*x^7 + 3*x^8 + 7*x^9 - x^10)*
            HPL[{2, 0}, x])/(945*(-1 + x^2)^9) + 
          (2*(-6 + 54*x - 66*x^2 + 6364*x^3 - 111*x^4 + 64250*x^5 + 
             18555*x^6 + 275520*x^7 + 145560*x^8 + 446610*x^9 + 176196*x^10 + 
             227436*x^11 + 49451*x^12 + 29346*x^13 + 2281*x^14)*
            HPL[{-1, 0, 0}, x])/(945*(-1 + x)^12*(1 + x)^10) + 
          (2*(-70 + 490*x + 3290*x^2 - 234220*x^3 - 571696*x^4 + 
             7358722*x^5 + 22587578*x^6 + 50913492*x^7 - 137382497*x^8 - 
             4150469638*x^9 - 8241345169*x^10 + 16021734876*x^11 + 
             183541325586*x^12 + 1343988520742*x^13 - 1054927965592*x^14 - 
             26125368622388*x^15 - 10026275381323*x^16 + 201810471763194*
              x^17 + 184430813189025*x^18 - 527224564648404*x^19 - 
             1033097905274292*x^20 - 1828155789316962*x^21 + 
             1666037333181186*x^22 + 12718952621011980*x^23 + 
             4917145373995185*x^24 - 9314556198246810*x^25 - 
             13874592821457591*x^26 - 39079439908208028*x^27 - 
             10177522878373038*x^28 - 11899056925292166*x^29 + 
             1488278936988252*x^30 + 878815382379732*x^31 + 1076028651940545*
              x^32 + 215483524696188*x^33 + 94627736633421*x^34)*
            HPL[{0, 0, 0}, x])/(33075*(1 - 9*x^2)^8*(-1 + x^2)^13) - 
          (2*(-6 + 30*x + 102*x^2 + 7580*x^3 + 23339*x^4 + 126710*x^5 + 
             186905*x^6 + 530600*x^7 + 414500*x^8 + 720850*x^9 + 
             308776*x^10 + 320020*x^11 + 67273*x^12 + 35950*x^13 + 1651*x^14)*
            HPL[{1, 0, 0}, x])/(945*(-1 + x)^10*(1 + x)^12) + 
          ((-280 + 1960*x + 18453*x^2 - 622496*x^3 - 1684507*x^4 + 
             40947480*x^5 + 91872755*x^6 - 998073860*x^7 - 2514296729*x^8 + 
             7301538048*x^9 + 35140899773*x^10 + 115231368056*x^11 - 
             198651896923*x^12 - 2881367282080*x^13 - 922030355421*x^14 + 
             24053276637572*x^15 + 21223614009487*x^16 - 71666399744856*
              x^17 - 122733261055305*x^18 - 167333670587664*x^19 + 
             211940004906423*x^20 + 1438962443370648*x^21 + 
             523993535268273*x^22 - 1280293160876604*x^23 - 1610647108344099*
              x^24 - 4289421046872528*x^25 - 1058945509304073*x^26 - 
             1021097995605576*x^27 + 239357747293119*x^28 + 
             212567122536048*x^29 + 136297344962745*x^30 + 35079661512252*
              x^31 + 11173094768709*x^32)*master3l8b[x])/
           (396900*x^2*(1 - 9*x^2)^8*(-1 + x^2)^13) - 
          ((-140 + 980*x + 6693*x^2 - 294196*x^3 - 573656*x^4 + 
             18736368*x^5 + 33415093*x^6 - 413722204*x^7 - 899736836*x^8 + 
             2386178536*x^9 + 11702317433*x^10 + 42774241048*x^11 - 
             60707043888*x^12 - 784018787412*x^13 - 174212985143*x^14 + 
             4550760884488*x^15 + 3551373763052*x^16 - 5701781373372*x^17 - 
             13925152377873*x^18 - 29958906829572*x^19 + 11972632894632*
              x^20 + 30428536857768*x^21 - 5806011188961*x^22 + 
             78180205266324*x^23 + 87358738534308*x^24 + 601273562944320*
              x^25 + 255851677982259*x^26 + 519931742998752*x^27 + 
             74819405701728*x^28 + 82512523336572*x^29 - 1241454974301*x^30)*
            master3l9b[x])/(396900*x^2*(-1 + x^2)^13*(-1 + 9*x^2)^7) + 
          (-151200 + 1058400*x + x^20*(1069429094960088890 - 
              119277176491468800*Zeta[3]) + x^16*(40204677759430052 - 
              11129476488560640*Zeta[3]) + x^6*(79677221092 - 
              674795520*Zeta[3]) + x^2*(13773373 - 322560*Zeta[3]) + 
            56*x^3*(-6813689 + 40320*Zeta[3]) + 2688*x^5*(9588197 + 
              63000*Zeta[3]) + x^4*(-1491983293 + 25482240*Zeta[3]) - 
            2410616376*x^35*(42309251 + 64874880*Zeta[3]) - 
            560*x^7*(1259382871 + 76075776*Zeta[3]) - 43046721*x^36*
             (1290256757 + 632540160*Zeta[3]) + 714256704*x^33*
             (-3224726411 + 1096426800*Zeta[3]) - 12*x^8*(183519803071 + 
              2530805760*Zeta[3]) + 224*x^9*(29778286669 + 9758397600*Zeta[
                3]) - 3024*x^11*(-31099807533 + 17547429760*Zeta[3]) + 
            21952*x^13*(-153941315393 + 31949492400*Zeta[3]) - 
            4782969*x^34*(123777695411 + 101402864640*Zeta[3]) + 
            8817984*x^29*(4057956533401 + 138242386800*Zeta[3]) + 
            16800*x^17*(-13031749598081 + 306566949024*Zeta[3]) + 
            19840464*x^31*(-132992571703 + 410923618560*Zeta[3]) + 
            4*x^10*(8082405613259 + 627699502080*Zeta[3]) + 
            708588*x^32*(-4927728442571 + 1135371202560*Zeta[3]) - 
            806400*x^21*(-4831768061915 + 1410975529362*Zeta[3]) - 
            3674160*x^27*(-16321135652069 + 3725091748224*Zeta[3]) + 
            84*x^14*(-20375681073689 + 13964722007040*Zeta[3]) - 
            4*x^12*(45791345372183 + 18313201105920*Zeta[3]) + 
            236196*x^30*(1559782205789 + 20974613345280*Zeta[3]) + 
            54432*x^25*(-41619346949303 + 37822995252000*Zeta[3]) - 
            112*x^15*(-360081673542473 + 42181076770560*Zeta[3]) - 
            61236*x^28*(-401119615257017 + 60366230830080*Zeta[3]) + 
            1120*x^19*(150074042867143 + 142235617305600*Zeta[3]) + 
            3024*x^23*(-4920433758782219 + 861956334731520*Zeta[3]) - 
            252*x^22*(-667783984459601 + 1698642268369920*Zeta[3]) - 
            972*x^26*(-13936225249809389 + 3987518166051840*Zeta[3]) + 
            10*x^18*(-31668363469127057 + 5942894664268800*Zeta[3]) + 
            324*x^24*(-31969440731221643 + 8716027214039040*Zeta[3]))/
           (228614400*x^2*(1 - 9*x^2)^8*(-1 + x^2)^13)) + 
        NH*((x*(-273363897038400 + 3096790138985472*x - 497892426549723828*
              x^2 - 493679379477745683*x^3 - 3090963747260660166*x^4 - 
             1538222850526507083*x^5 - 2687190920301588876*x^6 + 
             164782578238013736*x^7 + 1816001129260774638*x^8 + 
             714638798131266882*x^9 + 287427446360683524*x^10 - 
             334811330265235131*x^11 - 391456009905294726*x^12 + 
             35055459958681269*x^13 + 102448350315122364*x^14 + 
             13987746026712216*x^15 - 8799623274439746*x^16 - 
             5679401029352694*x^17 - 1048887952381836*x^18 + 
             967708941379911*x^19 + 362594662089534*x^20 - 91572709501441*
              x^21 - 44544524257268*x^22 + 4382268447904*x^23 + 
             3075897519450*x^24 - 1287365506*x^25 - 122611730500*x^26 - 
             12090147385*x^27 + 2372842766*x^28 + 629893079*x^29 - 
             2401980*x^30 - 12087968*x^31 - 407750*x^32 + 37622*x^33)*
            HPL[{0}, x])/(4762800*(-9 + x^2)^8*(-1 + x^2)^13) + 
          lm^2*(-(-1 + 7*x + 34*x^2 + 714*x^3 + 1133*x^4 + 3689*x^5 + 2708*
                x^6 + 3689*x^7 + 1133*x^8 + 714*x^9 + 34*x^10 + 7*x^11 - x^
                12)/(315*(-1 + x^2)^10) + (4*x^3*(1 + 2*x + 10*x^2 + 10*x^3 + 
               20*x^4 + 10*x^5 + 10*x^6 + 2*x^7 + x^8)*HPL[{0}, x])/
             (3*(-1 + x^2)^11)) + (x*(7593441584400 - 53153642554596*x + 
             10145557332302112*x^2 + 10169134736063859*x^3 + 
             62701729480143180*x^4 + 31302485837734851*x^5 + 
             50048344713985128*x^6 - 6309556920798543*x^7 - 47499012448150032*
              x^8 - 17694782976852459*x^9 - 7130287081484280*x^10 + 
             8042744566645371*x^11 + 11020610251054908*x^12 - 
             325170802612125*x^13 - 2572845942185568*x^14 - 
             522258891327417*x^15 + 45788784945792*x^16 + 149069650504463*
              x^17 + 73695179221552*x^18 - 17887710801927*x^19 - 
             13506354893948*x^20 + 756483949609*x^21 + 993078071720*x^22 + 
             55756884079*x^23 - 14705045488*x^24 - 9016523293*x^25 - 
             2453435096*x^26 + 485215721*x^27 + 152838644*x^28 - 
             11535263*x^29 - 2641968*x^30 + 70857*x^31 - 7056*x^32 + 
             813*x^33)*HPL[{0, 0}, x])/(132300*(-9 + x^2)^8*(-1 + x^2)^13) + 
          lm*(-(-11719 + 52630*x + 237694*x^2 + 8008170*x^3 + 11034515*x^4 + 
               40877600*x^5 + 26622620*x^6 + 40877600*x^7 + 11034515*x^8 + 
               8008170*x^9 + 237694*x^10 + 52630*x^11 - 11719*x^12 - 240*Pi^2*
                (-1 + 7*x + 4*x^2 + 105*x^3 + 65*x^4 + 140*x^5 - 140*x^7 - 
                 65*x^8 - 105*x^9 - 4*x^10 - 7*x^11 + x^12))/
             (1360800*(-1 + x^2)^10) + (x^2*(-4 + 11128*x + 19860*x^2 + 
               123817*x^3 + 123218*x^4 + 301254*x^5 + 161018*x^6 + 195217*
                x^7 + 46236*x^8 + 28096*x^9 + 836*x^10 + 168*x^11 - 24*x^12)*
              HPL[{0}, x])/(1890*(-1 + x^2)^11) + 
            (2*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 252*x^5 + 68*x^6 + 112*
                x^7 + 3*x^8 + 7*x^9 - x^10)*HPL[{-1, 0}, x])/
             (945*(-1 + x^2)^9) + (4*x^3*(-630 - 1260*x - 12285*x^2 - 16310*
                x^3 - 58975*x^4 - 47040*x^5 - 83860*x^6 - 36344*x^7 - 34902*
                x^8 - 6356*x^9 - 3241*x^10 - 6*x^11 - 7*x^12 + x^13)*
              HPL[{0, 0}, x])/(945*(-1 + x^2)^12) + 
            (2*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 112*
                x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{1, 0}, x])/
             (945*(-1 + x^2)^9)) + ((4554 + 58764*x + 98814*x^2 + 
             455704*x^3 + 351264*x^4 + 894140*x^5 + 289400*x^6 + 551040*x^7 + 
             38830*x^8 + 127580*x^9 + 906*x^10 + 11896*x^11 - 44*x^12 + 
             36*x^13 - 4*x^14)*HPL[{-1, 0, 0}, x])/(945*(-1 + x)^12*
            (1 + x)^10) + (2*x^3*(-388846185770700 - 405456725626299*x - 
             2404720143094122*x^2 - 1233601721715861*x^3 - 1935216163947276*
              x^4 + 264284270238780*x^5 + 2093536381209966*x^6 + 
             875129973789528*x^7 + 542308267211508*x^8 - 318776621254461*
              x^9 - 569451872523366*x^10 - 37320500305467*x^11 + 
             94345398059220*x^12 + 38422872404982*x^13 + 12503885205546*
              x^14 - 8052161690074*x^15 - 6223173333188*x^16 + 
             647090382635*x^17 + 856190162618*x^18 + 16311998069*x^19 - 
             46966366916*x^20 - 7670475408*x^21 - 595929838*x^22 + 
             656912028*x^23 + 207862172*x^24 - 26647379*x^25 - 9781674*x^26 + 
             525307*x^27 + 159740*x^28 - 5250*x^29 - 490*x^30 + 70*x^31)*
            HPL[{0, 0, 0}, x])/(33075*(-9 + x^2)^8*(-1 + x^2)^13) + 
          (2*(-1647 - 35970*x - 67341*x^2 - 320500*x^3 - 309892*x^4 - 
             722350*x^5 - 415880*x^6 - 530600*x^7 - 185525*x^8 - 125210*x^9 - 
             22223*x^10 - 7100*x^11 - 34*x^12 - 10*x^13 + 2*x^14)*
            HPL[{1, 0, 0}, x])/(945*(-1 + x)^10*(1 + x)^12) + 
          ((11173094768709 - 1520305081570548*x - 1485529557542451*x^2 - 
             9406313449840440*x^3 - 4695049139570325*x^4 - 8761962651394680*
              x^5 - 1808428348953*x^6 + 4084724477967336*x^7 + 
             1889872786814013*x^8 + 888939907969428*x^9 - 751112949749571*
              x^10 - 838845046722816*x^11 + 62658003684555*x^12 + 
             210047921649216*x^13 + 30958228564623*x^14 - 21650858922672*
              x^15 - 10985032750809*x^16 - 839416695180*x^17 + 
             1666331175119*x^18 + 543393368392*x^19 - 133403904647*x^20 - 
             72634099608*x^21 + 4458998141*x^22 + 4917818696*x^23 + 
             113351383*x^24 - 166625172*x^25 - 14716761*x^26 + 1820784*x^27 + 
             416721*x^28 + 16464*x^29 - 2547*x^30)*master3l8a[x])/
           (396900*(-9 + x^2)^8*(-1 + x^2)^13) + 
          ((-1241454974301 + 82512523336572*x + 74819405701728*x^2 + 
             519931742998752*x^3 + 255851677982259*x^4 + 601273562944320*
              x^5 + 87358738534308*x^6 + 78180205266324*x^7 - 
             5806011188961*x^8 + 30428536857768*x^9 + 11972632894632*x^10 - 
             29958906829572*x^11 - 13925152377873*x^12 - 5701781373372*x^13 + 
             3551373763052*x^14 + 4550760884488*x^15 - 174212985143*x^16 - 
             784018787412*x^17 - 60707043888*x^18 + 42774241048*x^19 + 
             11702317433*x^20 + 2386178536*x^21 - 899736836*x^22 - 
             413722204*x^23 + 33415093*x^24 + 18736368*x^25 - 573656*x^26 - 
             294196*x^27 + 6693*x^28 + 980*x^29 - 140*x^30)*master3l9a[x])/
           (132300*(-9 + x^2)^7*(-1 + x^2)^13) + 
          (x^18*(173438783317044410 - 59428946642688000*Zeta[3]) + 
            x^32*(671916613 - 25482240*Zeta[3]) - 56*x^33*
             (-667409 + 40320*Zeta[3]) - 2688*x^31*(-946483 + 
              63000*Zeta[3]) + x^34*(-2764933 + 322560*Zeta[3]) + 
            560*x^29*(-515975939 + 76075776*Zeta[3]) + 
            4*x^30*(-6792743353 + 168698880*Zeta[3]) + 803538792*x*
             (13102384013 + 194624640*Zeta[3]) + 14348907*(-7061787209 + 
              1897620480*Zeta[3]) + 12*x^28*(20666601631 + 2530805760*Zeta[
                3]) - 119042784*x^3*(-669303309511 + 6578560800*Zeta[3]) - 
            224*x^27*(-43262869871 + 9758397600*Zeta[3]) + 
            3024*x^25*(-55701834683 + 17547429760*Zeta[3]) - 
            28*x^26*(-330601969003 + 89671357440*Zeta[3]) - 
            8817984*x^7*(-5127588698599 + 138242386800*Zeta[3]) - 
            896000*x^17*(-556118957203 + 177794521632*Zeta[3]) + 
            1594323*x^2*(6191069146433 + 304208593920*Zeta[3]) - 
            6613488*x^5*(-22673008042679 + 1232770855680*Zeta[3]) - 
            3360*x^19*(4646755791929 + 1532834745120*Zeta[3]) - 
            448*x^23*(-3712039192817 + 1565525127600*Zeta[3]) + 
            4490640*x^9*(-13524450485017 + 3047802339456*Zeta[3]) - 
            236196*x^4*(-196616860888793 + 3406113607680*Zeta[3]) + 
            161280*x^15*(-20375981797273 + 7054877646810*Zeta[3]) + 
            4*x^24*(-80358308251777 + 18313201105920*Zeta[3]) - 
            54432*x^11*(-24312098151563 + 37822995252000*Zeta[3]) + 
            112*x^21*(-70469654268803 + 42181076770560*Zeta[3]) - 
            12*x^22*(-392037541252943 + 97753054049280*Zeta[3]) - 
            15876*x^12*(-664116552286427 + 177878106408960*Zeta[3]) - 
            26244*x^6*(-1708835031204379 + 188771520107520*Zeta[3]) + 
            8748*x^8*(-2259291764202679 + 422563615810560*Zeta[3]) - 
            3024*x^13*(-3036770033233529 + 861956334731520*Zeta[3]) + 
            50*x^16*(-4001694600747757 + 2385543529829376*Zeta[3]) + 
            4*x^20*(-9693892808728313 + 2782369122140160*Zeta[3]) + 
            972*x^10*(-15367232141428709 + 3987518166051840*Zeta[3]) + 
            36*x^14*(-56088669834588407 + 11890495878589440*Zeta[3]))/
           (228614400*(-9 + x^2)^8*(-1 + x^2)^13))) + 
      CA*CF*((Pi^2*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 
           8564*x^6 - 8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + 
           x^12)*HPL[{-2}, x])/(945*(-1 + x^2)^10) + 
        lm^2*((-11*(1 - 7*x - 34*x^2 - 714*x^3 - 1133*x^4 - 3689*x^5 - 
             2708*x^6 - 3689*x^7 - 1133*x^8 - 714*x^9 - 34*x^10 - 7*x^11 + 
             x^12))/(630*(-1 + x^2)^10) - (22*x^3*(1 + 2*x + 10*x^2 + 
             10*x^3 + 20*x^4 + 10*x^5 + 10*x^6 + 2*x^7 + x^8)*HPL[{0}, x])/
           (3*(-1 + x^2)^11)) + (Pi^2*(-1 + 7*x + 184*x^2 + 1596*x^3 + 
           3725*x^4 + 8687*x^5 + 8564*x^6 + 8687*x^7 + 3725*x^8 + 1596*x^9 + 
           184*x^10 + 7*x^11 - x^12)*HPL[{2}, x])/(945*(-1 + x^2)^10) + 
        (x*(777 + 34314*x + 199773*x^2 + 685230*x^3 + 5015829*x^4 + 
           6063610*x^5 + 18221189*x^6 + 14049588*x^7 + 22526609*x^8 + 
           1299298*x^9 - 1068207*x^10 + 12732622*x^11 + 7692545*x^12 - 
           20124894*x^13 - 5942179*x^14 + 24183688*x^15 + 1871100*x^16 - 
           21150360*x^17 + 1630860*x^18 + 13420176*x^19 - 2585352*x^20 - 
           6034896*x^21 + 1704024*x^22 + 1827504*x^23 - 647052*x^24 - 
           334824*x^25 + 138180*x^26 + 28080*x^27 - 12960*x^28)*
          HPL[{-2, 0}, x])/(26460*(-1 + x^2)^12) + 
        ((2721600 - 5896800*x - 24935400*x^2 + 61467840*x^3 + 97343820*x^4 - 
           289117080*x^5 - 201552960*x^6 + 808286640*x^7 + 201031950*x^8 - 
           1487812620*x^9 + 39351900*x^10 + (1884950269 + 11760*Pi^2)*x^11 - 
           (421184293 + 82320*Pi^2)*x^12 - (1684616201 + 2175600*Pi^2)*x^13 - 
           4*(-69082619 + 4671660*Pi^2)*x^14 + (456972129 - 41642160*Pi^2)*
            x^15 - (3031755557 + 83390160*Pi^2)*x^16 - 
           (2545543457 + 56906640*Pi^2)*x^17 - 4111181632*x^18 + 
           (-2545543457 + 56906640*Pi^2)*x^19 + (-3031755557 + 83390160*Pi^2)*
            x^20 + (456972129 + 41642160*Pi^2)*x^21 + 
           4*(69082619 + 4671660*Pi^2)*x^22 + (-1684616201 + 2175600*Pi^2)*
            x^23 + (-421184293 + 82320*Pi^2)*x^24 + (1884950269 - 11760*Pi^2)*
            x^25 + 39351900*x^26 - 1487812620*x^27 + 201031950*x^28 + 
           808286640*x^29 - 201552960*x^30 - 289117080*x^31 + 97343820*x^32 + 
           61467840*x^33 - 24935400*x^34 - 5896800*x^35 + 2721600*x^36)*
          HPL[{-1, 0}, x])/(11113200*x^11*(-1 + x^2)^11) + 
        (x*(42143600793420 + 1852499758777920*x + 17134178891328450*x^2 - 
           49873137992266869*x^3 - 861530744204155557*x^4 - 
           702707753001668652*x^5 + 10303492716646609977*x^6 + 
           44204753995645430061*x^7 + 169381767709704593106*x^8 - 
           638739729846490893768*x^9 - 6260316272381890116972*x^10 + 
           2303993296585756701009*x^11 + 74769871845472342741503*x^12 + 
           34455839031011001383676*x^13 - 393899549375293095757527*x^14 - 
           434805198118323399059733*x^15 + 223370076322430654774148*x^16 + 
           1707476432439966412794264*x^17 + 7019264891497444776073728*x^18 + 
           175215624603396347355246*x^19 - 24112531864302795746169666*x^20 - 
           15787084857685966531565768*x^21 - 13262599305919561615090486*
            x^22 + 8913790837527002141953602*x^23 + 
           123061840027138501115274396*x^24 + 88291690744989032516695088*
            x^25 + 31425650124613618065445232*x^26 - 
           77727621660894856495838734*x^27 - 63330586805105843788686522*
            x^28 + 55663104881390659616691576*x^29 + 
           23663203836904263820822394*x^30 - 51267201301619195962966538*
            x^31 - 1654900577795034742782276*x^32 + 
           41709444198112970791222320*x^33 - 4434589301375998499599830*x^34 - 
           26054502374577942942362553*x^35 + 4708341889748176265451663*x^36 + 
           12543511605600042298860804*x^37 - 3017505769629802000732539*x^38 - 
           4686075707760358128947583*x^39 + 1360985119194985923767058*x^40 + 
           1353589664044882796425944*x^41 - 447728280314196543148692*x^42 - 
           299651710193414325783027*x^43 + 108704610789430322418939*x^44 + 
           50270924360402230278348*x^45 - 19503145689807581718723*x^46 - 
           6300757485565728741009*x^47 + 2569475884830062799780*x^48 + 
           578067100665379993080*x^49 - 244829265272433904860*x^50 - 
           37582792593467763600*x^51 + 16390354843445488920*x^52 + 
           1636988857515088560*x^53 - 730578550446075240*x^54 - 
           42803579344841280*x^55 + 19459821226078800*x^56 + 
           507675808785600*x^57 - 234311911747200*x^58)*HPL[{0, 0}, x])/
         (11113200*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        ((-2721600 + 5896800*x + 24935400*x^2 - 61467840*x^3 - 97343820*x^4 + 
           289117080*x^5 + 201552960*x^6 - 808286640*x^7 - 201031950*x^8 + 
           1487812620*x^9 - 39351900*x^10 - (1884950269 + 11760*Pi^2)*x^11 + 
           (421184293 + 82320*Pi^2)*x^12 + (1684616201 + 2175600*Pi^2)*x^13 + 
           4*(-69082619 + 4671660*Pi^2)*x^14 + (-456972129 + 41642160*Pi^2)*
            x^15 + (3031755557 + 83390160*Pi^2)*x^16 + 
           (2545543457 + 56906640*Pi^2)*x^17 + 4111181632*x^18 + 
           (2545543457 - 56906640*Pi^2)*x^19 + (3031755557 - 83390160*Pi^2)*
            x^20 - 3*(152324043 + 13880720*Pi^2)*x^21 - 
           4*(69082619 + 4671660*Pi^2)*x^22 + (1684616201 - 2175600*Pi^2)*
            x^23 + (421184293 - 82320*Pi^2)*x^24 + (-1884950269 + 11760*Pi^2)*
            x^25 - 39351900*x^26 + 1487812620*x^27 - 201031950*x^28 - 
           808286640*x^29 + 201552960*x^30 + 289117080*x^31 - 97343820*x^32 - 
           61467840*x^33 + 24935400*x^34 + 5896800*x^35 - 2721600*x^36)*
          HPL[{1, 0}, x])/(11113200*x^11*(-1 + x^2)^11) + 
        lm*((-189389 + 1002290*x + 4670954*x^2 + 131272590*x^3 + 
            189903505*x^4 + 672764320*x^5 + 456628660*x^6 + 672764320*x^7 + 
            189903505*x^8 + 131272590*x^9 + 4670954*x^10 + 1002290*x^11 - 
            189389*x^12 - 2640*Pi^2*(-1 + 7*x + 4*x^2 + 105*x^3 + 65*x^4 + 
              140*x^5 - 140*x^7 - 65*x^8 - 105*x^9 - 4*x^10 - 7*x^11 + x^12))/
           (2721600*(-1 + x^2)^10) + (x^2*(44 - 157688*x - 289020*x^2 - 
             1714787*x^3 - 1708198*x^4 - 4019394*x^5 - 2123998*x^6 - 
             2500187*x^7 - 579156*x^8 - 344336*x^9 - 9196*x^10 - 1848*x^11 + 
             264*x^12)*HPL[{0}, x])/(3780*(-1 + x^2)^11) + 
          (11*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 
             112*x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{-1, 0}, x])/
           (945*(-1 + x^2)^9) - (22*x^3*(-630 - 1260*x - 12285*x^2 - 
             16310*x^3 - 58975*x^4 - 47040*x^5 - 83860*x^6 - 36344*x^7 - 
             34902*x^8 - 6356*x^9 - 3241*x^10 - 6*x^11 - 7*x^12 + x^13)*
            HPL[{0, 0}, x])/(945*(-1 + x^2)^12) - 
          (11*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 
             112*x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{1, 0}, x])/
           (945*(-1 + x^2)^9)) + (x*(-777 - 34314*x - 199773*x^2 - 
           685230*x^3 - 5015829*x^4 - 6063610*x^5 - 18221189*x^6 - 
           14049588*x^7 - 22526609*x^8 - 1299298*x^9 + 1068207*x^10 - 
           12732622*x^11 - 7692545*x^12 + 20124894*x^13 + 5942179*x^14 - 
           24183688*x^15 - 1871100*x^16 + 21150360*x^17 - 1630860*x^18 - 
           13420176*x^19 + 2585352*x^20 + 6034896*x^21 - 1704024*x^22 - 
           1827504*x^23 + 647052*x^24 + 334824*x^25 - 138180*x^26 - 
           28080*x^27 + 12960*x^28)*HPL[{2, 0}, x])/(26460*(-1 + x^2)^12) + 
        (4*(-1 + 7*x + 184*x^2 + 1596*x^3 + 3725*x^4 + 8687*x^5 + 8564*x^6 + 
           8687*x^7 + 3725*x^8 + 1596*x^9 + 184*x^10 + 7*x^11 - x^12)*
          HPL[{-2, -1, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*x^2*(-180 - 1491*x - 3660*x^2 - 8547*x^3 - 8564*x^4 - 8827*x^5 - 
           3790*x^6 - 1701*x^7 - 188*x^8 - 14*x^9 + 2*x^10)*
          HPL[{-2, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        (4*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{-2, 1, 0}, x])/(315*(-1 + x^2)^10) + 
        (4*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{-1, -2, 0}, x])/(315*(-1 + x^2)^10) + 
        ((3240 - 7020*x - 24825*x^2 + 62646*x^3 + 77568*x^4 - 247878*x^5 - 
           115587*x^6 + 570132*x^7 + 42048*x^8 - 838368*x^9 + 142758*x^10 + 
           814212*x^11 - 281232*x^12 - 518204*x^13 + 256895*x^14 + 
           205110*x^15 - 102040*x^16 - 19070*x^17 + 153270*x^18 - 
           19070*x^19 - 102040*x^20 + 205110*x^21 + 256895*x^22 - 
           518204*x^23 - 281232*x^24 + 814212*x^25 + 142758*x^26 - 
           838368*x^27 + 42048*x^28 + 570132*x^29 - 115587*x^30 - 
           247878*x^31 + 77568*x^32 + 62646*x^33 - 24825*x^34 - 7020*x^35 + 
           3240*x^36)*HPL[{-1, -1, 0}, x])/(13230*x^13*(-1 + x^2)^9) - 
        ((3393 + 10998*x + 112623*x^2 + 4068168*x^3 + 1115333*x^4 + 
           13954336*x^5 - 9012349*x^6 + 16441856*x^7 - 15698149*x^8 + 
           17047486*x^9 + 13719653*x^10 - 8926512*x^11 - 16707057*x^12 + 
           27772968*x^13 + 11687913*x^14 - 36284400*x^15 + 426600*x^16 + 
           30753450*x^17 - 9057600*x^18 - 16715400*x^19 + 8937960*x^20 + 
           5302860*x^21 - 4456440*x^22 - 650040*x^23 + 1187760*x^24 - 
           107850*x^25 - 135000*x^26 + 32400*x^27)*HPL[{-1, 0, 0}, x])/
         (66150*(-1 + x)^12*(1 + x)^10) + 
        ((-3240 + 7020*x + 24825*x^2 - 62646*x^3 - 77568*x^4 + 247878*x^5 + 
           115587*x^6 - 570132*x^7 - 42048*x^8 + 838368*x^9 - 142758*x^10 - 
           814212*x^11 + 281232*x^12 + 518204*x^13 - 256895*x^14 - 
           205110*x^15 + 102040*x^16 + 19070*x^17 - 153270*x^18 + 
           19070*x^19 + 102040*x^20 - 205110*x^21 - 256895*x^22 + 
           518204*x^23 + 281232*x^24 - 814212*x^25 - 142758*x^26 + 
           838368*x^27 - 42048*x^28 - 570132*x^29 + 115587*x^30 + 
           247878*x^31 - 77568*x^32 - 62646*x^33 + 24825*x^34 + 7020*x^35 - 
           3240*x^36)*HPL[{-1, 1, 0}, x])/(13230*x^13*(-1 + x^2)^9) + 
        (4*(-1 + 7*x + 184*x^2 + 1596*x^3 + 3725*x^4 + 8687*x^5 + 8564*x^6 + 
           8687*x^7 + 3725*x^8 + 1596*x^9 + 184*x^10 + 7*x^11 - x^12)*
          HPL[{-1, 2, 0}, x])/(315*(-1 + x^2)^10) + 
        (x*(-167236511085 - 7313207430690*x - 185326729952805*x^2 - 
           174111509096055*x^3 + 8082249315561918*x^4 + 28037957320006650*
            x^5 - 54547178362251606*x^6 - 913287111021017757*x^7 - 
           3125760228437912451*x^8 + 14798537541490171554*x^9 + 
           86145699913876336617*x^10 - 139210576423012885941*x^11 - 
           993116993622074602434*x^12 + 827285409688895053038*x^13 + 
           5691323975467949401518*x^14 - 3919895403647747045127*x^15 - 
           11799139255618616434986*x^16 + 22279675665745444953692*x^17 - 
           23768977077869560147178*x^18 - 122866956393546767772278*x^19 + 
           39519891010235612242396*x^20 + 390782818006332660187332*x^21 + 
           756225499808710986305348*x^22 - 421400712669008085818706*x^23 - 
           2232883068049867055697054*x^24 - 195107678956567009250796*x^25 + 
           200924107582929427052938*x^26 - 831773628501059222485562*x^27 + 
           142489788625858715752892*x^28 + 1826650865315183510480572*x^29 + 
           238447921906195634221676*x^30 - 2097173707073095307721758*x^31 - 
           194990885824346765264097*x^32 + 1857812032944017847469494*x^33 - 
           23397879183406243632105*x^34 - 1334712659652609317457891*x^35 + 
           145328952227286357643350*x^36 + 770202969808350131252802*x^37 - 
           142887287045011887888606*x^38 - 352931030663207384919681*x^39 + 
           86937096084837641519577*x^40 + 127200675724538763073434*x^41 - 
           37516745844002854433019*x^42 - 35704432894065443395137*x^43 + 
           11917354053470689702854*x^44 + 7721145593049489277878*x^45 - 
           2815512451653395935098*x^46 - 1270826026047196107147*x^47 + 
           494479702155672160200*x^48 + 156826819851176971440*x^49 - 
           64060823481092446680*x^50 - 14207710745463328800*x^51 + 
           6022961090260465680*x^52 + 914231933581871520*x^53 - 
           398905529283238320*x^54 - 39484484306431200*x^55 + 
           17625927025392120*x^56 + 1025176601172240*x^57 - 
           466118504332200*x^58 - 12087519256800*x^59 + 5578855041600*x^60)*
          HPL[{0, 0, 0}, x])/(132300*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        (4*(-1 + 7*x + 184*x^2 + 1596*x^3 + 3725*x^4 + 8687*x^5 + 8564*x^6 + 
           8687*x^7 + 3725*x^8 + 1596*x^9 + 184*x^10 + 7*x^11 - x^12)*
          HPL[{1, -2, 0}, x])/(315*(-1 + x^2)^10) + 
        ((-3240 + 7020*x + 24825*x^2 - 62646*x^3 - 77568*x^4 + 247878*x^5 + 
           115587*x^6 - 570132*x^7 - 42048*x^8 + 838368*x^9 - 142758*x^10 - 
           814212*x^11 + 281232*x^12 + 518204*x^13 - 256895*x^14 - 
           205110*x^15 + 102040*x^16 + 19070*x^17 - 153270*x^18 + 
           19070*x^19 + 102040*x^20 - 205110*x^21 - 256895*x^22 + 
           518204*x^23 + 281232*x^24 - 814212*x^25 - 142758*x^26 + 
           838368*x^27 - 42048*x^28 - 570132*x^29 + 115587*x^30 + 
           247878*x^31 - 77568*x^32 - 62646*x^33 + 24825*x^34 + 7020*x^35 - 
           3240*x^36)*HPL[{1, -1, 0}, x])/(13230*x^13*(-1 + x^2)^9) + 
        ((3393 + 21210*x + 200559*x^2 + 4132160*x^3 + 10991413*x^4 + 
           33264764*x^5 + 43441835*x^6 + 64078752*x^7 + 45243635*x^8 + 
           26589914*x^9 + 7944733*x^10 + 20020760*x^11 + 4819719*x^12 - 
           25501140*x^13 - 5271687*x^14 + 29818800*x^15 + 4455000*x^16 - 
           25586550*x^17 - 2752200*x^18 + 16005000*x^19 + 1211760*x^20 - 
           7118100*x^21 - 360720*x^22 + 2136600*x^23 + 65160*x^24 - 
           388650*x^25 - 5400*x^26 + 32400*x^27)*HPL[{1, 0, 0}, x])/
         (66150*(-1 + x)^10*(1 + x)^12) + 
        ((3240 - 7020*x - 24825*x^2 + 62646*x^3 + 77568*x^4 - 247878*x^5 - 
           115587*x^6 + 570132*x^7 + 42048*x^8 - 838368*x^9 + 142758*x^10 + 
           814212*x^11 - 281232*x^12 - 518204*x^13 + 256895*x^14 + 
           205110*x^15 - 102040*x^16 - 19070*x^17 + 153270*x^18 - 
           19070*x^19 - 102040*x^20 + 205110*x^21 + 256895*x^22 - 
           518204*x^23 - 281232*x^24 + 814212*x^25 + 142758*x^26 - 
           838368*x^27 + 42048*x^28 + 570132*x^29 - 115587*x^30 - 
           247878*x^31 + 77568*x^32 + 62646*x^33 - 24825*x^34 - 7020*x^35 + 
           3240*x^36)*HPL[{1, 1, 0}, x])/(13230*x^13*(-1 + x^2)^9) + 
        (4*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{1, 2, 0}, x])/(315*(-1 + x^2)^10) + 
        (4*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{2, -1, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*x^2*(180 + 1491*x + 3660*x^2 + 8547*x^3 + 8564*x^4 + 8827*x^5 + 
           3790*x^6 + 1701*x^7 + 188*x^8 + 14*x^9 - 2*x^10)*
          HPL[{2, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        (4*(-1 + 7*x + 184*x^2 + 1596*x^3 + 3725*x^4 + 8687*x^5 + 8564*x^6 + 
           8687*x^7 + 3725*x^8 + 1596*x^9 + 184*x^10 + 7*x^11 - x^12)*
          HPL[{2, 1, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 252*x^5 + 68*x^6 + 
           112*x^7 + 3*x^8 + 7*x^9 - x^10)*HPL[{-1, 0, 0, 0}, x])/
         (315*(-1 + x^2)^9) + (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 
           8687*x^5 - 8564*x^6 - 8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 
           7*x^11 + x^12)*HPL[{-1, 1, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{1, -1, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 112*x^7 - 
           3*x^8 - 7*x^9 + x^10)*HPL[{1, 0, 0, 0}, x])/(315*(-1 + x^2)^9) + 
        ((-2 + 29*x + 280*x^2 + 4357*x^3 + 9212*x^4 + 31801*x^5 + 30574*x^6 + 
           48320*x^7 + 20896*x^8 + 17619*x^9 + 2130*x^10 + 1179*x^11 - 
           90*x^12 + 15*x^13)*master3l10a[x])/(1260*(-1 + x^2)^11) + 
        (x*(-15 + 90*x - 1179*x^2 - 2130*x^3 - 17619*x^4 - 20896*x^5 - 
           48320*x^6 - 30574*x^7 - 31801*x^8 - 9212*x^9 - 4357*x^10 - 
           280*x^11 - 29*x^12 + 2*x^13)*master3l10b[x])/
         (1260*(-1 + x^2)^11) - ((-271922947911 - 12660402557421*x + 
           550340744696964*x^2 + 2056218772475907*x^3 + 4037520648360375*
            x^4 + 6128431669779390*x^5 + 3181823259032268*x^6 - 
           78116095252890*x^7 - 2113097863917195*x^8 - 1630528976949507*x^9 + 
           97406439629832*x^10 + 425633075726085*x^11 + 128086061710707*
            x^12 + 24477886201572*x^13 - 24047738874792*x^14 - 
           27312089410188*x^15 - 1268148303669*x^16 + 5145029604573*x^17 + 
           936786669332*x^18 - 453236790947*x^19 - 137417758347*x^20 + 
           16345592446*x^21 + 10109872028*x^22 + 304592070*x^23 - 
           391761337*x^24 - 43421453*x^25 + 6664608*x^26 + 999163*x^27 - 
           11743*x^28)*master3l8a[x])/(3175200*(-9 + x^2)^8*(-1 + x^2)^12) - 
        ((15540 + 694663*x + 209177*x^2 - 51041036*x^3 - 47887739*x^4 + 
           1757842377*x^5 + 1526603010*x^6 - 36973994084*x^7 - 
           23882889202*x^8 + 519435521763*x^9 + 234823270383*x^10 - 
           4981361236664*x^11 - 1943862879709*x^12 + 31822920577141*x^13 + 
           17318502436860*x^14 - 124014432106632*x^15 - 134953043202648*
            x^16 + 216418074905061*x^17 + 672538348847079*x^18 + 
           217489761737604*x^19 - 1654483180080357*x^20 - 1332370740861477*
            x^21 + 625977282434274*x^22 + 769587939964332*x^23 + 
           3129046939177974*x^24 + 813403672786161*x^25 + 
           689524119166257*x^26 - 53273459825280*x^27 + 2865463087581*x^28 + 
           705833895591*x^29)*master3l8b[x])/(3175200*x*(1 - 9*x^2)^8*
          (-1 + x^2)^12) - ((54319824639 + 862548091389*x - 
           33528086937387*x^2 - 75831642062604*x^3 - 182842952747166*x^4 - 
           175058223040368*x^5 - 154328956920126*x^6 + 19665385089246*x^7 + 
           26226067178637*x^8 + 854253724869*x^9 + 9585303136947*x^10 + 
           13811876698374*x^11 + 5972367748236*x^12 - 7322620889304*x^13 - 
           4890108763076*x^14 + 1665852781580*x^15 + 1295047297481*x^16 - 
           208732606729*x^17 - 184891850613*x^18 + 15033047104*x^19 + 
           15948309938*x^20 - 564577080*x^21 - 843735902*x^22 + 
           5158710*x^23 + 25673995*x^24 + 325063*x^25 - 353203*x^26 - 
           7770*x^27)*master3l9a[x])/(1058400*(-9 + x^2)^7*(-1 + x^2)^12) - 
        ((-7770 - 353203*x + 325063*x^2 + 25673995*x^3 + 5158710*x^4 - 
           843735902*x^5 - 564577080*x^6 + 15948309938*x^7 + 
           15033047104*x^8 - 184891850613*x^9 - 208732606729*x^10 + 
           1295047297481*x^11 + 1665852781580*x^12 - 4890108763076*x^13 - 
           7322620889304*x^14 + 5972367748236*x^15 + 13811876698374*x^16 + 
           9585303136947*x^17 + 854253724869*x^18 + 26226067178637*x^19 + 
           19665385089246*x^20 - 154328956920126*x^21 - 175058223040368*
            x^22 - 182842952747166*x^23 - 75831642062604*x^24 - 
           33528086937387*x^25 + 862548091389*x^26 + 54319824639*x^27)*
          master3l9b[x])/(3175200*x*(-1 + x^2)^12*(-1 + 9*x^2)^7) + 
        (HPL[{1}, x]*(Pi^2*(-3240 + 7020*x + 28065*x^2 - 69666*x^3 - 
             102393*x^4 + 310524*x^5 + 193155*x^6 - 818010*x^7 - 157635*x^8 + 
             1408500*x^9 - 100710*x^10 - 1652580*x^11 + 423990*x^12 + 
             1332416*x^13 - 538127*x^14 - 723314*x^15 + 358935*x^16 + 
             224180*x^17 - 255310*x^18 + 255310*x^20 - 224180*x^21 - 
             358935*x^22 + 723314*x^23 + 538127*x^24 - 1332416*x^25 - 
             423990*x^26 + 1652580*x^27 + 100710*x^28 - 1408500*x^29 + 
             157635*x^30 + 818010*x^31 - 193155*x^32 - 310524*x^33 + 
             102393*x^34 + 69666*x^35 - 28065*x^36 - 7020*x^37 + 3240*x^38) - 
           2016*x^13*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 
             8564*x^6 - 8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + 
             x^12)*Zeta[3]))/(158760*x^13*(-1 + x^2)^10) + 
        (HPL[{-1}, x]*(Pi^2*(3240 - 7020*x - 28065*x^2 + 69666*x^3 + 
             102393*x^4 - 310524*x^5 - 193155*x^6 + 818010*x^7 + 157635*x^8 - 
             1408500*x^9 + 100710*x^10 + 1652580*x^11 - 423990*x^12 - 
             1332416*x^13 + 538127*x^14 + 723314*x^15 - 358935*x^16 - 
             224180*x^17 + 255310*x^18 - 255310*x^20 + 224180*x^21 + 
             358935*x^22 - 723314*x^23 - 538127*x^24 + 1332416*x^25 + 
             423990*x^26 - 1652580*x^27 - 100710*x^28 + 1408500*x^29 - 
             157635*x^30 - 818010*x^31 + 193155*x^32 + 310524*x^33 - 
             102393*x^34 - 69666*x^35 + 28065*x^36 + 7020*x^37 - 3240*x^38) + 
           2016*x^13*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 
             8564*x^6 - 8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + 
             x^12)*Zeta[3]))/(158760*x^13*(-1 + x^2)^10) + 
        (HPL[{0}, x]*(-702935735241600 + 1523027426356800*x + 
           58027995810615600*x^2 - 127649224321345440*x^3 - 
           2162780231410854720*x^4 + 4847268879336789360*x^5 + 
           48094480791959622300*x^6 - 110335317316618910040*x^7 - 
           710618387823807045660*x^8 + 1679432303884430062800*x^9 - 
           173604060*(-42378253915954 + 80919*Pi^2)*x^10 - 
           10628820*(1700244117804175 + 58368114*Pi^2)*x^11 - 
           1470*(107015159997613586558329 + 13527640084644634123824*Pi^2)*
            x^33 + 8748*(2065812751089481257 + 37069967731613387690*Pi^2)*
            x^55 - 25515*(288341802840822579 + 4634588354060926780*Pi^2)*
            x^56 - 137781*(12189148211602593 + 387387904529570720*Pi^2)*
            x^57 + 918540*(773639022605229 + 22609954373830460*Pi^2)*x^58 + 
           49601160*(2224450341819 + 132793798244828*Pi^2)*x^59 - 
           8266860*(5817744680805 + 325462701219796*Pi^2)*x^60 - 
           6249746160*(775594521 + 95479694060*Pi^2)*x^61 + 
           4166497440*(519088338 + 60713913649*Pi^2)*x^62 + 
           48212327520*(2647647 + 796429942*Pi^2)*x^63 - 
           2678462640*(21664665 + 6255092746*Pi^2)*x^64 - 
           1446369825600*(1053 + 1146559*Pi^2)*x^65 + 24106163760*
            (29160 + 30709529*Pi^2)*x^66 + 43057417249234080*Pi^2*x^67 - 
           19576977181952400*Pi^2*x^68 - 507675808785600*Pi^2*x^69 + 
           234311911747200*Pi^2*x^70 + 6*x^29*(13743700333028991845691851 + 
             29049331598627379768120*Pi^2 - 871013124083493370022400*
              Zeta[3]) + 56*x^35*(-3410193436218278053584581 + 
             535970857354505598074910*Pi^2 - 171382977752863189824000*
              Zeta[3]) + 24*x^28*(-3059605714085267674124741 + 
             3754756906263507411855*Pi^2 - 171147215044233928584000*
              Zeta[3]) + 14*x^40*(-4813153660735739714726057 + 
             1353725309889577483484340*Pi^2 - 110371409925337695052800*
              Zeta[3]) - 84*x^26*(-160038323959742740714577 + 
             4956437760128042230950*Pi^2 - 18395234987556282508800*Zeta[3]) - 
           48*x^27*(2897128722712639968929084 + 8824333122919647948405*Pi^2 - 
             16565906159404235020800*Zeta[3]) + 27*x^24*
            (-273701656804277890089871 + 4740001944944789035380*Pi^2 - 
             8683793051697027532800*Zeta[3]) - 36*x^42*
            (-350939868833646510726962 + 241522726761534327102525*Pi^2 - 
             6512844788772770649600*Zeta[3]) + 144*x^39*
            (946448549929494166099772 + 510170273181797019831095*Pi^2 - 
             5521968719801411673600*Zeta[3]) + 120*x^36*
            (-256941164611754166791393 + 223521095197611615293715*Pi^2 - 
             3069702677284231343040*Zeta[3]) + 
           9*x^46*(760455545625939604135461 + 685570345846168515796700*Pi^2 - 
             343433759799601094400*Zeta[3]) - 27*x^48*
            (127534013969645880676043 + 222555690523104021375180*Pi^2 - 
             19231357231574208000*Zeta[3]) + 18*x^50*
            (66318949344466106400051 + 202880755189401377310110*Pi^2 - 
             2151268123987180800*Zeta[3]) - 243*x^16*
            (4925638650156014451391 + 6343239484155420*Pi^2 - 
             159353194369420800*Zeta[3]) + 2187*x^14*(136820067339792292499 + 
             63929037114180*Pi^2 - 670806087840000*Zeta[3]) + 
           81*x^54*(677607260966371623681 + 6179371339929883674460*Pi^2 - 
             283488485817600*Zeta[3]) - 39366*x^12*(1394293778351289551 + 
             65739142350*Pi^2 - 583309641600*Zeta[3]) + 
           59049*x^13*(2403347231669384933 + 555985934280*Pi^2 + 
             777746188800*Zeta[3]) - 26244*x^15*(31608746451130360961 + 
             24903961421850*Pi^2 + 120550659264000*Zeta[3]) - 
           6615*x^49*(554702354398855710153 + 2240565504675073818352*Pi^2 + 
             14168338823761920*Zeta[3]) + 5103*x^17*(717135638664583989091 + 
             1064991506075280*Pi^2 + 18366365141913600*Zeta[3]) - 
           756*x^19*(16310966700565285220587 + 18629284276675170*Pi^2 + 
             2037446913621772800*Zeta[3]) + 756*x^47*
            (16493139381265726296631 + 42757321247950804027750*Pi^2 + 
             2037446913621772800*Zeta[3]) - 54*x^18*
            (-64641531302933407255849 + 741750251071065390*Pi^2 + 
             9615678615787104000*Zeta[3]) + 108*x^20*
            (-66828775416064944305588 + 13038930314753498505*Pi^2 + 
             28619479983300091200*Zeta[3]) + 189*x^21*
            (170226638286832484192291 + 1442915519596959240*Pi^2 + 
             79015101644638656000*Zeta[3]) - 63*x^45*
            (529973077111222707221649 + 886423282080564941672680*Pi^2 + 
             237045304933915968000*Zeta[3]) - 18*x^44*
            (478243925888430685021817 + 68536796479494286044290*Pi^2 + 
             365536987371715017600*Zeta[3]) + 108*x^43*
            (673023205712075530589727 + 711379018854938731059770*Pi^2 + 
             745491366007515187200*Zeta[3]) - 36*x^23*
            (1839999995349849602572421 + 236600571970039520250*Pi^2 + 
             2236474098022545561600*Zeta[3]) + 
           x^22*(9720156007367440570480581 - 18624419528847721584660*Pi^2 + 
             6579665772690870316800*Zeta[3]) + 30*x^30*
            (3979085800518144540544463 + 86462876546107523387940*Pi^2 + 
             12278810709136925372160*Zeta[3]) - 10*x^41*
            (12648986127029743078795589 + 8431870276931741450438208*Pi^2 + 
             14850534420377200742400*Zeta[3]) + 
           9*x^25*(12186788806617633585279727 + 10344849725145333998880*
              Pi^2 + 16500593800419111936000*Zeta[3]) + 
           56*x^31*(2061742124336580935882641 + 100289875573986570444210*
              Pi^2 + 171382977752863189824000*Zeta[3]) + 
           x^38*(205591290366292252388676014 - 24757756221159178027555080*
              Pi^2 + 4107533161061614286016000*Zeta[3]) - 
           4*x^34*(181488465784182737189461223 + 5446163651732043680269830*
              Pi^2 + 4231790234033449562899200*Zeta[3]) + 
           x^37*(26541939837698641151432974 - 50487520618532021177816880*
              Pi^2 + 5226078744500960220134400*Zeta[3]) + 
           x^32*(240031338794022528298568422 - 82656788782560212768520*Pi^2 + 
             16927160936133798251596800*Zeta[3]) - 243*x^53*
            (6171126633615089303080*Pi^2 + 243*(2403534298457862173 + 
               777746188800*Zeta[3])) - 36*x^52*(43769999599966937708705*
              Pi^2 - 11178*(-743306362778306681 + 3645685260000*Zeta[3])) + 
           36*x^51*(148398469245227284429150*Pi^2 + 
             729*(31625244176604051037 + 120550659264000*Zeta[3]))))/
         (133358400*x^9*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        (56448*Pi^4*x^11*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^8*
           (-3 + 21*x - 888*x^2 - 7140*x^3 - 18105*x^4 - 42315*x^5 - 
            42820*x^6 - 44555*x^7 - 19145*x^8 - 8820*x^9 - 952*x^10 - 
            91*x^11 + 13*x^12) - 24*Pi^2*(9 - 82*x^2 + 9*x^4)^8*
           (-2721600 + 5896800*x + 27657000*x^2 - 67364640*x^3 - 
            122279220*x^4 + 350584920*x^5 + 298896780*x^6 - 1097403720*x^7 - 
            402584910*x^8 + 2296099260*x^9 + 161680050*x^10 - 
            3372762889*x^11 + 460536193*x^12 + 3569566470*x^13 - 
            697514769*x^14 - 2141588330*x^15 + 3308086033*x^16 + 
            3002515586*x^17 + 1079426075*x^18 - 1079426075*x^20 - 
            3002515586*x^21 - 3308086033*x^22 + 2141588330*x^23 + 
            697514769*x^24 - 3569566470*x^25 - 460536193*x^26 + 
            3372762889*x^27 - 161680050*x^28 - 2296099260*x^29 + 
            402584910*x^30 + 1097403720*x^31 - 298896780*x^32 - 
            350584920*x^33 + 122279220*x^34 + 67364640*x^35 - 27657000*x^36 - 
            5896800*x^37 + 2721600*x^38) + x^2*(4217614411449600 - 
            9138164558140800*x - 349573846334176800*x^2 + 768941400780786240*
             x^3 + 13092210178284928320*x^4 - 29337769454093659440*x^5 - 
            292849217107611165540*x^6 + 671611339334907011880*x^7 + 
            4358300557199751673560*x^8 + x^39*(956723958920709189770317608 - 
              5659531521320850078243195648*Zeta[3]) + 
            x^27*(535848870932137538045065128 - 343280075606497705447231488*
               Zeta[3]) - 3100134041944853760*x^67*Zeta[3] + 
            1409542357100572800*x^68*Zeta[3] + 36552658232563200*x^69*
             Zeta[3] - 16870457645798400*x^70*Zeta[3] + 26034656860800*x^65*
             (-351 + 4586236*Zeta[3]) - 1735643790720*x^66*
             (-2430 + 30709529*Zeta[3]) + 100442349*x^9*(-102483921209507 + 
              35396352*Zeta[3]) - 280600848*x^11*(-398136804500999 + 
              1259352360*Zeta[3]) + 7440174*x^10*(-6119286177152903 + 
              2792991456*Zeta[3]) - 867821895360*x^63*(-886059 + 
              3185719768*Zeta[3]) + 48212327520*x^64*(-7250715 + 
              25020370984*Zeta[3]) - 10713850560*x^62*(-1221989247 + 
              1699989582172*Zeta[3]) + 8035387920*x^61*(-3651070707 + 
              5346862867360*Zeta[3]) + 708588*x^13*(-1251715995033242563 + 
              29878237495008*Zeta[3]) + 118098*x^12*(2909258552906078251 + 
              32873478154272*Zeta[3]) - 3124873080*x^59*(-214924357611 + 
              151764340851232*Zeta[3]) + 520812180*x^60*(-562293334053 + 
              371957372822624*Zeta[3]) - 1417176*x^15*(-3712656036285162347 + 
              577977243212880*Zeta[3]) - 13122*x^14*(144988292748690795695 + 
              24410703217676832*Zeta[3]) + 71442*x^16*
             (109334303059685728849 + 138669261077588832*Zeta[3]) - 
            8266860*x^58*(-527201523837801 + 180879634990643680*Zeta[3]) + 
            1240029*x^57*(-8301164757658407 + 3099103239750322432*Zeta[3]) + 
            4374*x^17*(-5417634169326968644931 + 4669642112415944832*Zeta[
                3]) - 314928*x^55*(-354704652380890449 + 74139936928010572360*
               Zeta[3]) + 91854*x^56*(-495660569935897143 + 
              92691767235330756896*Zeta[3]) - 648*x^19*
             (-126515171507554317002365 + 517497743222952777936*Zeta[3]) - 
            162*x^18*(149330012401630803871109 + 1011395036481454326240*Zeta[
                3]) - 1134*x^22*(106858067030757047003669 + 
              6736132826434690537824*Zeta[3]) + 540*x^21*
             (-401969965876124444545501 + 6823622670126908036832*Zeta[3]) + 
            8748*x^53*(-101316009136274753733 + 12342256206320386236128*Zeta[
                3]) - 1152*x^23*(-362753800422585698797456 + 
              23440458404483299590327*Zeta[3]) - 1458*x^54*
             (-235629417418919042661 + 24717482594201839260448*Zeta[3]) - 
            1764*x^36*(159883235044572857031313 + 27886062970524849208384*
               Zeta[3]) + 54*x^20*(1096580662137263983053053 + 
              28750361658276016541664*Zeta[3]) + 1134*x^44*
             (-72152123868498688991939 + 70572142710803288425696*Zeta[3]) - 
            1134*x^50*(-6849521836386466430457 + 231855022851847616648224*
               Zeta[3]) + 18*x^24*(8955841192260813872011931 + 
              288793461682369479735648*Zeta[3]) + 824*x^29*
             (-2093794383270417317769605 + 386418095342452065971232*Zeta[
                3]) - 648*x^51*(-8092974627778576488129 + 
              593595278790382009518160*Zeta[3]) + 162*x^52*
             (-11734053194722124962845 + 700318030802342802973088*Zeta[3]) + 
            486*x^49*(-48219867429163781192739 + 2195798039127296803837568*
               Zeta[3]) + 162*x^48*(-145063091234011815461459 + 
              2669641811336418420065760*Zeta[3]) - 648*x^47*
             (-122937622824320084027125 + 3592139013525415812369456*Zeta[
                3]) + 252*x^30*(2511046284125110852668179 + 
              6765811790200960893314912*Zeta[3]) + 540*x^45*
             (-381911693691449285319115 + 7452826200656626073525472*Zeta[
                3]) - 54*x^46*(-971948860632403313143583 + 
              8196528103560338909017056*Zeta[3]) - 576*x^43*
             (-706118024808155576585357 + 9651408512939469355370634*Zeta[
                3]) + 8*x^26*(26587259715900234604372589 + 
              19191568429997397406530432*Zeta[3]) - 
            52*x^40*(-4654571854010579956867501 + 23803370983189921466058912*
               Zeta[3]) + 5*x^25*(-103360774254249321222730361 + 
              25434577665258369533243136*Zeta[3]) + 
            18*x^42*(2420131059082389093706751 + 35520608740064616804914208*
               Zeta[3]) + 16*x^31*(201098604761019124058735021 + 
              42662676428515112828609520*Zeta[3]) + 
            16*x^38*(-40832434343463245270485139 + 59842808159555355167149560*
               Zeta[3]) - 16*x^35*(-25833871551827530493446421 + 
              66589847935466295745176480*Zeta[3]) + 
            4*x^34*(338669078705167942671824251 + 100624120896884067899365824*
               Zeta[3]) - 8*x^28*(175397594818135662246034903 + 
              103579391112469590410326080*Zeta[3]) - 
            12*x^33*(-98819866758304446495327271 + 
              117586087937857501020269568*Zeta[3]) - 
            4*x^32*(-971365246290055926480918421 + 
              297262567972336039519946976*Zeta[3]) + 
            8*x^37*(-165601885130621468638333265 + 
              494712701014273459383417696*Zeta[3]) + 
            x^41*(-639725563757281328487513265 + 6203962668832339090907162880*
               Zeta[3])))/(3200601600*x^11*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^
           8)) + CF^2*((2*Pi^2*(-1 + 7*x + 184*x^2 + 1596*x^3 + 3725*x^4 + 
           8687*x^5 + 8564*x^6 + 8687*x^7 + 3725*x^8 + 1596*x^9 + 184*x^10 + 
           7*x^11 - x^12)*HPL[{-2}, x])/(945*(-1 + x^2)^10) + 
        lm^2*((4*(1 - 7*x - 34*x^2 - 714*x^3 - 1133*x^4 - 3689*x^5 - 
             2708*x^6 - 3689*x^7 - 1133*x^8 - 714*x^9 - 34*x^10 - 7*x^11 + 
             x^12))/(35*(-1 + x^2)^10) + (48*x^3*(1 + 2*x + 10*x^2 + 10*x^3 + 
             20*x^4 + 10*x^5 + 10*x^6 + 2*x^7 + x^8)*HPL[{0}, x])/
           (-1 + x^2)^11) + (2*Pi^2*(1 - 7*x - 184*x^2 - 1596*x^3 - 
           3725*x^4 - 8687*x^5 - 8564*x^6 - 8687*x^7 - 3725*x^8 - 1596*x^9 - 
           184*x^10 - 7*x^11 + x^12)*HPL[{2}, x])/(945*(-1 + x^2)^10) - 
        (x*(3885 + 171570*x + 2116485*x^2 + 5197710*x^3 + 39300765*x^4 + 
           44009210*x^5 + 111134065*x^6 + 100323020*x^7 + 198372405*x^8 - 
           54202778*x^9 - 157824429*x^10 + 338306598*x^11 + 351163155*x^12 - 
           750717122*x^13 - 417672179*x^14 + 1200229270*x^15 + 
           306409983*x^16 - 1396559571*x^17 - 72396907*x^18 + 
           1193428753*x^19 - 113201055*x^20 - 743691635*x^21 + 
           152925967*x^22 + 329628445*x^23 - 96331685*x^24 - 98644855*x^25 + 
           35691675*x^26 + 17895825*x^27 - 7497225*x^28 - 1488375*x^29 + 
           694575*x^30)*HPL[{-2, 0}, x])/(66150*(-1 + x^2)^12) + 
        ((583443000 - 1250235000*x - 5422504500*x^2 + 13157140500*x^3 + 
           21604149000*x^4 - 62605036200*x^5 - 46277325150*x^6 + 
           177550290750*x^7 + 50257119780*x^8 - 332819218900*x^9 - 
           1242773630*x^10 + 431689118070*x^11 - 81981062800*x^12 - 
           (393444140807 + 235200*Pi^2)*x^13 + 14*(9536037521 + 117600*Pi^2)*
            x^14 + 15*(16677396721 + 2900800*Pi^2)*x^15 + 
           28*(-3918775303 + 13347600*Pi^2)*x^16 + 
           (-92504602863 + 832843200*Pi^2)*x^17 + 
           70*(1936953139 + 23825760*Pi^2)*x^18 + 
           15*(5819858729 + 75875520*Pi^2)*x^19 + 85853998720*x^20 - 
           15*(-5819858729 + 75875520*Pi^2)*x^21 - 
           70*(-1936953139 + 23825760*Pi^2)*x^22 - 
           3*(30834867621 + 277614400*Pi^2)*x^23 - 
           28*(3918775303 + 13347600*Pi^2)*x^24 + 
           (250160950815 - 43512000*Pi^2)*x^25 - 
           14*(-9536037521 + 117600*Pi^2)*x^26 + 
           (-393444140807 + 235200*Pi^2)*x^27 - 81981062800*x^28 + 
           431689118070*x^29 - 1242773630*x^30 - 332819218900*x^31 + 
           50257119780*x^32 + 177550290750*x^33 - 46277325150*x^34 - 
           62605036200*x^35 + 21604149000*x^36 + 13157140500*x^37 - 
           5422504500*x^38 - 1250235000*x^39 + 583443000*x^40)*
          HPL[{-1, 0}, x])/(111132000*x^13*(-1 + x^2)^11) - 
        (x*(421436007934200 + 18831664150052040*x + 373622141388027420*x^2 - 
           231582937803114870*x^3 - 19556936250812120790*x^4 - 
           23127402822736435020*x^5 + 318444928270990159590*x^6 + 
           804678428542871174040*x^7 + 405741298397305335570*x^8 - 
           9575066263004198464662*x^9 - 78782448658134441484026*x^10 + 
           10802711191826818212480*x^11 + 1054593699891237870519456*x^12 + 
           883921501618904153928654*x^13 - 5331419871381818314202844*x^14 - 
           9484165141220762423166915*x^15 - 4452646561023829008815226*x^16 + 
           39738881214757115815541778*x^17 + 166153445826592866537434910*
            x^18 - 38156435338244935656264126*x^19 - 
           612004219243375624990146018*x^20 - 138419192324899330156725770*
            x^21 + 333712386664961447318596078*x^22 - 
           267407007092549638192890368*x^23 + 1169475398010512986459461808*
            x^24 + 2815870577669851237799651920*x^25 + 
           1637944769410554968051426192*x^26 - 4309295473463828703348888096*
            x^27 - 2569323240191560287840400520*x^28 + 
           5740567326847862884269628604*x^29 + 1839449137068838085043278312*
            x^30 - 6786429079157260749989731970*x^31 - 
           816946468270590982513641452*x^32 + 6474986257253460079639688572*
            x^33 - 69040853594183648179445912*x^34 - 
           4896254313673273326300321370*x^35 + 533866847162119645591863222*
            x^36 + 2930956833308080291198887984*x^37 - 
           547837615345770839334772590*x^38 - 1383662956509097248623074212*
            x^39 + 344762447874238788904641474*x^40 + 
           511493062647807451011211290*x^41 - 152888210626755838990611114*
            x^42 - 146699679743487353762482536*x^43 + 
           49654000300346868947418576*x^44 + 32301223182612489166299990*
            x^45 - 11943771727603114762245036*x^46 - 
           5396154250416454255112307*x^47 + 2128325323696477078212270*x^48 + 
           674075648616550458464970*x^49 - 278975543259240058676130*x^50 - 
           61679121194779596846450*x^51 + 26478686821752730940130*x^52 + 
           4001478400807826919750*x^53 - 1767284598755527806150*x^54 - 
           173989679328117632700*x^55 + 78585416022407773500*x^56 + 
           4542962195991775500*x^57 - 2089163243540299500*x^58 - 
           53818517229435000*x^59 + 25115308040403000*x^60)*HPL[{0, 0}, x])/
         (55566000*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        ((-583443000 + 1250235000*x + 5422504500*x^2 - 13157140500*x^3 - 
           21604149000*x^4 + 62605036200*x^5 + 46277325150*x^6 - 
           177550290750*x^7 - 50257119780*x^8 + 332819218900*x^9 + 
           1242773630*x^10 - 431689118070*x^11 + 81981062800*x^12 + 
           (393444140807 + 235200*Pi^2)*x^13 - 14*(9536037521 + 117600*Pi^2)*
            x^14 - 15*(16677396721 + 2900800*Pi^2)*x^15 - 
           28*(-3918775303 + 13347600*Pi^2)*x^16 + 
           (92504602863 - 832843200*Pi^2)*x^17 - 
           70*(1936953139 + 23825760*Pi^2)*x^18 - 
           15*(5819858729 + 75875520*Pi^2)*x^19 - 85853998720*x^20 + 
           15*(-5819858729 + 75875520*Pi^2)*x^21 + 
           70*(-1936953139 + 23825760*Pi^2)*x^22 + 
           (92504602863 + 832843200*Pi^2)*x^23 + 
           28*(3918775303 + 13347600*Pi^2)*x^24 + 
           15*(-16677396721 + 2900800*Pi^2)*x^25 + 
           14*(-9536037521 + 117600*Pi^2)*x^26 + (393444140807 - 235200*Pi^2)*
            x^27 + 81981062800*x^28 - 431689118070*x^29 + 1242773630*x^30 + 
           332819218900*x^31 - 50257119780*x^32 - 177550290750*x^33 + 
           46277325150*x^34 + 62605036200*x^35 - 21604149000*x^36 - 
           13157140500*x^37 + 5422504500*x^38 + 1250235000*x^39 - 
           583443000*x^40)*HPL[{1, 0}, x])/(111132000*x^13*(-1 + x^2)^11) + 
        lm*(-(-6499 + 16090*x + 60214*x^2 + 4281090*x^3 + 5120255*x^4 + 
             21621020*x^5 + 12486860*x^6 + 21621020*x^7 + 5120255*x^8 + 
             4281090*x^9 + 60214*x^10 + 16090*x^11 - 6499*x^12 - 
             240*Pi^2*(-1 + 7*x + 4*x^2 + 105*x^3 + 65*x^4 + 140*x^5 - 140*
                x^7 - 65*x^8 - 105*x^9 - 4*x^10 - 7*x^11 + x^12))/
           (37800*(-1 + x^2)^10) + (2*x^2*(-4 + 8083*x + 13770*x^2 + 
             93367*x^3 + 92768*x^4 + 240354*x^5 + 130568*x^6 + 164767*x^7 + 
             40146*x^8 + 25051*x^9 + 836*x^10 + 168*x^11 - 24*x^12)*
            HPL[{0}, x])/(105*(-1 + x^2)^11) + 
          (8*(-1 + 7*x + 3*x^2 + 112*x^3 + 68*x^4 + 252*x^5 + 68*x^6 + 
             112*x^7 + 3*x^8 + 7*x^9 - x^10)*HPL[{-1, 0}, x])/
           (105*(-1 + x^2)^9) + (16*x^3*(-630 - 1260*x - 12285*x^2 - 
             16310*x^3 - 58975*x^4 - 47040*x^5 - 83860*x^6 - 36344*x^7 - 
             34902*x^8 - 6356*x^9 - 3241*x^10 - 6*x^11 - 7*x^12 + x^13)*
            HPL[{0, 0}, x])/(105*(-1 + x^2)^12) + 
          (8*(1 - 7*x - 3*x^2 - 112*x^3 - 68*x^4 - 252*x^5 - 68*x^6 - 
             112*x^7 - 3*x^8 - 7*x^9 + x^10)*HPL[{1, 0}, x])/
           (105*(-1 + x^2)^9)) + (x*(3885 + 171570*x + 2116485*x^2 + 
           5197710*x^3 + 39300765*x^4 + 44009210*x^5 + 111134065*x^6 + 
           100323020*x^7 + 198372405*x^8 - 54202778*x^9 - 157824429*x^10 + 
           338306598*x^11 + 351163155*x^12 - 750717122*x^13 - 
           417672179*x^14 + 1200229270*x^15 + 306409983*x^16 - 
           1396559571*x^17 - 72396907*x^18 + 1193428753*x^19 - 
           113201055*x^20 - 743691635*x^21 + 152925967*x^22 + 
           329628445*x^23 - 96331685*x^24 - 98644855*x^25 + 35691675*x^26 + 
           17895825*x^27 - 7497225*x^28 - 1488375*x^29 + 694575*x^30)*
          HPL[{2, 0}, x])/(66150*(-1 + x^2)^12) + 
        (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{-2, -1, 0}, x])/(315*(-1 + x^2)^10) - 
        (16*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{-2, 0, 0}, x])/(315*(-1 + x^2)^10) - 
        (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{-2, 1, 0}, x])/(315*(-1 + x^2)^10) - 
        (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{-1, -2, 0}, x])/(315*(-1 + x^2)^10) + 
        ((694575 - 1488375*x - 4024350*x^2 + 10453950*x^3 + 8624175*x^4 - 
           31491355*x^5 - 6021560*x^6 + 52748420*x^7 - 7139958*x^8 - 
           53054610*x^9 + 18372830*x^10 + 31999828*x^11 - 16494002*x^12 - 
           10619406*x^13 + 7544068*x^14 + 1364485*x^15 - 1679734*x^16 + 
           87063*x^17 + 345912*x^18 + 87063*x^19 - 1679734*x^20 + 
           1364485*x^21 + 7544068*x^22 - 10619406*x^23 - 16494002*x^24 + 
           31999828*x^25 + 18372830*x^26 - 53054610*x^27 - 7139958*x^28 + 
           52748420*x^29 - 6021560*x^30 - 31491355*x^31 + 8624175*x^32 + 
           10453950*x^33 - 4024350*x^34 - 1488375*x^35 + 694575*x^36)*
          HPL[{-1, -1, 0}, x])/(132300*x^15*(-1 + x^2)^7) + 
        ((1665 + 95065*x + 451110*x^2 + 10028344*x^3 + 3137127*x^4 + 
           27839499*x^5 - 19043508*x^6 + 37109656*x^7 - 59849323*x^8 + 
           25387989*x^9 + 148328030*x^10 - 80141718*x^11 - 298073037*x^12 + 
           337349471*x^13 + 374845212*x^14 - 669335996*x^15 - 
           236390745*x^16 + 835707503*x^17 - 38464690*x^18 - 686381216*x^19 + 
           217798369*x^20 + 363985533*x^21 - 202077800*x^22 - 
           112755900*x^23 + 97961155*x^24 + 13165275*x^25 - 25646850*x^26 + 
           2436750*x^27 + 2877525*x^28 - 694575*x^29)*HPL[{-1, 0, 0}, x])/
         (66150*(-1 + x)^12*(1 + x)^10) + 
        ((-694575 + 1488375*x + 4024350*x^2 - 10453950*x^3 - 8624175*x^4 + 
           31491355*x^5 + 6021560*x^6 - 52748420*x^7 + 7139958*x^8 + 
           53054610*x^9 - 18372830*x^10 - 31999828*x^11 + 16494002*x^12 + 
           10619406*x^13 - 7544068*x^14 - 1364485*x^15 + 1679734*x^16 - 
           87063*x^17 - 345912*x^18 - 87063*x^19 + 1679734*x^20 - 
           1364485*x^21 - 7544068*x^22 + 10619406*x^23 + 16494002*x^24 - 
           31999828*x^25 - 18372830*x^26 + 53054610*x^27 + 7139958*x^28 - 
           52748420*x^29 + 6021560*x^30 + 31491355*x^31 - 8624175*x^32 - 
           10453950*x^33 + 4024350*x^34 + 1488375*x^35 - 694575*x^36)*
          HPL[{-1, 1, 0}, x])/(132300*x^15*(-1 + x^2)^7) + 
        (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{-1, 2, 0}, x])/(315*(-1 + x^2)^10) + 
        (x*(-167236511085 - 7457844413250*x + 256272577331400*x^2 + 
           725523491462715*x^3 - 12398790818303757*x^4 - 19501688762266815*
            x^5 + 211719191865048396*x^6 - 31493088242884287*x^7 - 
           1056968837454611205*x^8 + 11651672368383965271*x^9 - 
           3569894920949575572*x^10 - 266033829584410850295*x^11 - 
           167335778524356470043*x^12 + 2987024720156682102819*x^13 + 
           5479508646695300052672*x^14 - 18244737715152732536013*x^15 - 
           59085657102447346909020*x^16 + 52066620103645608687095*x^17 + 
           304277779557250721174260*x^18 - 8563818965133253828714*x^19 - 
           689626880984291704527450*x^20 - 74820739377444863655422*x^21 + 
           375661426781858116140908*x^22 - 1711153649513576853601222*x^23 - 
           1555354863989435534707042*x^24 + 7445061754015431414914846*x^25 + 
           10391086711083323996741528*x^26 - 11631998777439842815187278*
            x^27 - 10663656744194199241860270*x^28 + 
           22643323511316924565314022*x^29 + 11259019894655463269696432*
            x^30 - 35817753934493185395121016*x^31 - 
           10695619430170801582995303*x^32 + 44298372785621475900673100*
            x^33 + 6608181471877798475938352*x^34 - 
           44175458492577789327666089*x^35 - 1185280258048641433736321*x^36 + 
           35766603540092743657146021*x^37 - 2567688596436244703152700*x^38 - 
           23464098035209598219039955*x^39 + 3551930011281576909748791*x^40 + 
           12415252662275599814041939*x^41 - 2682349110506705781643492*x^42 - 
           5263785226823373017909963*x^43 + 1415011044470060129487393*x^44 + 
           1773303845304465299226807*x^45 - 553001845855703427641376*x^46 - 
           469935151608099062330829*x^47 + 162964816206990663267090*x^48 + 
           96842403627396990225903*x^49 - 36312911148017491111404*x^50 - 
           15316198222758596247672*x^51 + 6089878506349904390712*x^52 + 
           1829177220240486476136*x^53 - 760539760495877190780*x^54 - 
           161318204828207697960*x^55 + 69433978520157873264*x^56 + 
           10153222805420909640*x^57 - 4490552764292332320*x^58 - 
           430539397629248160*x^59 + 194594346665242200*x^60 + 
           11008785647228400*x^61 - 5063895727621200*x^62 - 
           128139326736750*x^63 + 59798352477150*x^64)*HPL[{0, 0, 0}, x])/
         (66150*(-1 + x^2)^13*(9 - 82*x^2 + 9*x^4)^8) + 
        (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{1, -2, 0}, x])/(315*(-1 + x^2)^10) + 
        ((-694575 + 1488375*x + 4024350*x^2 - 10453950*x^3 - 8624175*x^4 + 
           31491355*x^5 + 6021560*x^6 - 52748420*x^7 + 7139958*x^8 + 
           53054610*x^9 - 18372830*x^10 - 31999828*x^11 + 16494002*x^12 + 
           10619406*x^13 - 7544068*x^14 - 1364485*x^15 + 1679734*x^16 - 
           87063*x^17 - 345912*x^18 - 87063*x^19 + 1679734*x^20 - 
           1364485*x^21 - 7544068*x^22 + 10619406*x^23 + 16494002*x^24 - 
           31999828*x^25 - 18372830*x^26 + 53054610*x^27 + 7139958*x^28 - 
           52748420*x^29 + 6021560*x^30 + 31491355*x^31 - 8624175*x^32 - 
           10453950*x^33 + 4024350*x^34 + 1488375*x^35 - 694575*x^36)*
          HPL[{1, -1, 0}, x])/(132300*x^15*(-1 + x^2)^7) - 
        ((1665 + 95005*x + 878290*x^2 + 11582884*x^3 + 33059123*x^4 + 
           88999315*x^5 + 120496252*x^6 + 175032032*x^7 + 129603797*x^8 + 
           23151265*x^9 - 8262454*x^10 + 192548014*x^11 + 70456759*x^12 - 
           391677137*x^13 - 102292876*x^14 + 604788564*x^15 + 
           111652479*x^16 - 687893589*x^17 - 90880086*x^18 + 578530324*x^19 + 
           54511981*x^20 - 356305307*x^21 - 23430960*x^22 + 156517420*x^23 + 
           6837355*x^24 - 46511025*x^25 - 1214550*x^26 + 8390250*x^27 + 
           99225*x^28 - 694575*x^29)*HPL[{1, 0, 0}, x])/(66150*(-1 + x)^10*
          (1 + x)^12) + ((694575 - 1488375*x - 4024350*x^2 + 10453950*x^3 + 
           8624175*x^4 - 31491355*x^5 - 6021560*x^6 + 52748420*x^7 - 
           7139958*x^8 - 53054610*x^9 + 18372830*x^10 + 31999828*x^11 - 
           16494002*x^12 - 10619406*x^13 + 7544068*x^14 + 1364485*x^15 - 
           1679734*x^16 + 87063*x^17 + 345912*x^18 + 87063*x^19 - 
           1679734*x^20 + 1364485*x^21 + 7544068*x^22 - 10619406*x^23 - 
           16494002*x^24 + 31999828*x^25 + 18372830*x^26 - 53054610*x^27 - 
           7139958*x^28 + 52748420*x^29 - 6021560*x^30 - 31491355*x^31 + 
           8624175*x^32 + 10453950*x^33 - 4024350*x^34 - 1488375*x^35 + 
           694575*x^36)*HPL[{1, 1, 0}, x])/(132300*x^15*(-1 + x^2)^7) - 
        (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{1, 2, 0}, x])/(315*(-1 + x^2)^10) - 
        (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{2, -1, 0}, x])/(315*(-1 + x^2)^10) + 
        (16*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{2, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{2, 1, 0}, x])/(315*(-1 + x^2)^10) - 
        (16*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{-1, 1, 0, 0}, x])/(315*(-1 + x^2)^10) - 
        (16*(1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
           8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*
          HPL[{1, -1, 0, 0}, x])/(315*(-1 + x^2)^10) - 
        ((-2 + 29*x + 280*x^2 + 4357*x^3 + 9212*x^4 + 31801*x^5 + 30574*x^6 + 
           48320*x^7 + 20896*x^8 + 17619*x^9 + 2130*x^10 + 1179*x^11 - 
           90*x^12 + 15*x^13)*master3l10a[x])/(630*(-1 + x^2)^11) + 
        (x*(15 - 90*x + 1179*x^2 + 2130*x^3 + 17619*x^4 + 20896*x^5 + 
           48320*x^6 + 30574*x^7 + 31801*x^8 + 9212*x^9 + 4357*x^10 + 
           280*x^11 + 29*x^12 - 2*x^13)*master3l10b[x])/(630*(-1 + x^2)^11) + 
        ((-271922947911 - 12660402557421*x + 550340744696964*x^2 + 
           2056218772475907*x^3 + 4037520648360375*x^4 + 6128431669779390*
            x^5 + 3181823259032268*x^6 - 78116095252890*x^7 - 
           2113097863917195*x^8 - 1630528976949507*x^9 + 97406439629832*
            x^10 + 425633075726085*x^11 + 128086061710707*x^12 + 
           24477886201572*x^13 - 24047738874792*x^14 - 27312089410188*x^15 - 
           1268148303669*x^16 + 5145029604573*x^17 + 936786669332*x^18 - 
           453236790947*x^19 - 137417758347*x^20 + 16345592446*x^21 + 
           10109872028*x^22 + 304592070*x^23 - 391761337*x^24 - 
           43421453*x^25 + 6664608*x^26 + 999163*x^27 - 11743*x^28)*
          master3l8a[x])/(1587600*(-9 + x^2)^8*(-1 + x^2)^12) + 
        ((15540 + 694663*x + 209177*x^2 - 51041036*x^3 - 47887739*x^4 + 
           1757842377*x^5 + 1526603010*x^6 - 36973994084*x^7 - 
           23882889202*x^8 + 519435521763*x^9 + 234823270383*x^10 - 
           4981361236664*x^11 - 1943862879709*x^12 + 31822920577141*x^13 + 
           17318502436860*x^14 - 124014432106632*x^15 - 134953043202648*
            x^16 + 216418074905061*x^17 + 672538348847079*x^18 + 
           217489761737604*x^19 - 1654483180080357*x^20 - 1332370740861477*
            x^21 + 625977282434274*x^22 + 769587939964332*x^23 + 
           3129046939177974*x^24 + 813403672786161*x^25 + 
           689524119166257*x^26 - 53273459825280*x^27 + 2865463087581*x^28 + 
           705833895591*x^29)*master3l8b[x])/(1587600*x*(1 - 9*x^2)^8*
          (-1 + x^2)^12) + ((54319824639 + 862548091389*x - 
           33528086937387*x^2 - 75831642062604*x^3 - 182842952747166*x^4 - 
           175058223040368*x^5 - 154328956920126*x^6 + 19665385089246*x^7 + 
           26226067178637*x^8 + 854253724869*x^9 + 9585303136947*x^10 + 
           13811876698374*x^11 + 5972367748236*x^12 - 7322620889304*x^13 - 
           4890108763076*x^14 + 1665852781580*x^15 + 1295047297481*x^16 - 
           208732606729*x^17 - 184891850613*x^18 + 15033047104*x^19 + 
           15948309938*x^20 - 564577080*x^21 - 843735902*x^22 + 
           5158710*x^23 + 25673995*x^24 + 325063*x^25 - 353203*x^26 - 
           7770*x^27)*master3l9a[x])/(529200*(-9 + x^2)^7*(-1 + x^2)^12) + 
        ((-7770 - 353203*x + 325063*x^2 + 25673995*x^3 + 5158710*x^4 - 
           843735902*x^5 - 564577080*x^6 + 15948309938*x^7 + 
           15033047104*x^8 - 184891850613*x^9 - 208732606729*x^10 + 
           1295047297481*x^11 + 1665852781580*x^12 - 4890108763076*x^13 - 
           7322620889304*x^14 + 5972367748236*x^15 + 13811876698374*x^16 + 
           9585303136947*x^17 + 854253724869*x^18 + 26226067178637*x^19 + 
           19665385089246*x^20 - 154328956920126*x^21 - 175058223040368*
            x^22 - 182842952747166*x^23 - 75831642062604*x^24 - 
           33528086937387*x^25 + 862548091389*x^26 + 54319824639*x^27)*
          master3l9b[x])/(1587600*x*(-1 + x^2)^12*(-1 + 9*x^2)^7) - 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(694575 - 1488375*x - 4024350*x^2 + 
             10453950*x^3 + 8624175*x^4 - 31491355*x^5 - 6021560*x^6 + 
             52748420*x^7 - 7139958*x^8 - 53054610*x^9 + 18372830*x^10 + 
             31999828*x^11 - 16494002*x^12 - 10619406*x^13 + 7544068*x^14 + 
             1364485*x^15 - 1679734*x^16 + 87063*x^17 + 345912*x^18 + 
             87063*x^19 - 1679734*x^20 + 1364485*x^21 + 7544068*x^22 - 
             10619406*x^23 - 16494002*x^24 + 31999828*x^25 + 18372830*x^26 - 
             53054610*x^27 - 7139958*x^28 + 52748420*x^29 - 6021560*x^30 - 
             31491355*x^31 + 8624175*x^32 + 10453950*x^33 - 4024350*x^34 - 
             1488375*x^35 + 694575*x^36) + 40320*x^15*(1 - 7*x - 184*x^2 - 
             1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 8687*x^7 - 
             3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*Zeta[3]))/
         (1587600*x^15*(-1 + x^2)^10) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(694575 - 1488375*x - 4024350*x^2 + 
             10453950*x^3 + 8624175*x^4 - 31491355*x^5 - 6021560*x^6 + 
             52748420*x^7 - 7139958*x^8 - 53054610*x^9 + 18372830*x^10 + 
             31999828*x^11 - 16494002*x^12 - 10619406*x^13 + 7544068*x^14 + 
             1364485*x^15 - 1679734*x^16 + 87063*x^17 + 345912*x^18 + 
             87063*x^19 - 1679734*x^20 + 1364485*x^21 + 7544068*x^22 - 
             10619406*x^23 - 16494002*x^24 + 31999828*x^25 + 18372830*x^26 - 
             53054610*x^27 - 7139958*x^28 + 52748420*x^29 - 6021560*x^30 - 
             31491355*x^31 + 8624175*x^32 + 10453950*x^33 - 4024350*x^34 - 
             1488375*x^35 + 694575*x^36) + 40320*x^15*(1 - 7*x - 184*x^2 - 
             1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 8687*x^7 - 
             3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12)*Zeta[3]))/
         (1587600*x^15*(-1 + x^2)^10) + (HPL[{0}, x]*(-150691848242418000 + 
           322911103376610000*x + 12459633537120588000*x^2 - 
           27096317624262348000*x^3 - 465295237019906548500*x^4 + 
           1030416826415189339700*x^5 + 10372091997990963510900*x^6 - 
           23495906563478748018900*x^7 - 153724334359798955803680*x^8 + 
           358411521463837023243600*x^9 + 1597836372044243811144840*x^10 - 
           3867163898133705398336520*x^11 + 2066715*(-5798295351799999711 + 
             135943920*Pi^2)*x^12 + 531441*(57338932437124125329 + 
             23347245600*Pi^2)*x^13 + 840*(3749810731635657918704265 + 
             1587896714176514769141706*Pi^2)*x^35 - 
           2187*(13933361841847557909507 + 148538791187261450151680*Pi^2)*
            x^57 + 8505*(1408985776082446075953 + 13041617460863487154864*
              Pi^2)*x^58 + 918540*(4210120309284310167 + 76089435738117301528*
              Pi^2)*x^59 - 612360*(2609308857607034769 + 42412125358241849482*
              Pi^2)*x^60 - 99202320*(3612934873537605 + 115485492076853167*
              Pi^2)*x^61 + 11022480*(13946438039334066 + 411101338352323033*
              Pi^2)*x^62 + 223205220*(105265936717245 + 6313372808896532*
              Pi^2)*x^63 - 24800580*(418219735102605 + 23553548561050028*
              Pi^2)*x^64 - 3348078300*(307763658459 + 38031099287684*Pi^2)*
            x^65 + 223205220*(2084607326925 + 245118521172268*Pi^2)*x^66 + 
           3254332107600*(8326230 + 2512403017*Pi^2)*x^67 - 
           40176939600*(310119030 + 89922441793*Pi^2)*x^68 - 
           3254332107600*(99225 + 108321259*Pi^2)*x^69 + 1807962282000*
            (83349 + 88085803*Pi^2)*x^70 + 9139742909212986000*Pi^2*x^71 - 
           4203441795121002000*Pi^2*x^72 - 107637034458870000*Pi^2*x^73 + 
           50230616080806000*Pi^2*x^74 - 21*x^52*(67532409701404467045322000*
              Pi^2 + 81*(464011863752780566294291 - 455294841055488000*
                Zeta[3])) - 567*x^56*(623637744494067427519120*Pi^2 + 
             81*(1432662428590517009161 - 9999593856000*Zeta[3])) + 
           2*x^39*(9486844713387063626341398943 + 
             3592410332654067000983572680*Pi^2 - 52260787445009602201344000*
              Zeta[3]) - 14*x^37*(470734297463360825919201953 + 
             235144472535695069809726920*Pi^2 - 13710638220229055185920000*
              Zeta[3]) + 2*x^29*(14269878852198414413926687573 + 
             4135405242332409508217160*Pi^2 - 7951634956514032809984000*
              Zeta[3]) - 2*x^41*(14248357587168923049430786933 + 
             6299411126333451448784433720*Pi^2 - 7951634956514032809984000*
              Zeta[3]) - 70*x^30*(88715011865977382158731731 + 
             755655348242109787085016*Pi^2 - 1173580903160461224576000*
              Zeta[3]) + 70*x^40*(48173712959995869498947951 + 
             70414889078722565468103192*Pi^2 - 1173580903160461224576000*
              Zeta[3]) + 42*x^28*(100649385251071794238322959 + 
             494458988463719634969960*Pi^2 - 735809399502251300352000*
              Zeta[3]) - 42*x^42*(74859330179131935353627659 + 
             126384833944159700755059320*Pi^2 - 735809399502251300352000*
              Zeta[3]) + 14*x^32*(451634347434565146690298523 + 
             8391898121076186657428520*Pi^2 - 526234744677296801664000*
              Zeta[3]) - 14*x^38*(540096534465451696664912423 + 
             252025854292357357883126760*Pi^2 - 526234744677296801664000*
              Zeta[3]) - 105*x^26*(4919767209777507379888091 + 
             43009712004663249055344*Pi^2 - 44659507123013284454400*
              Zeta[3]) + 105*x^44*(4072901179581567270370031 + 
             38170685884964354183562864*Pi^2 - 44659507123013284454400*
              Zeta[3]) - 21*x^46*(-96091197820634616311745603 + 
             75506132315564766369710480*Pi^2 - 6266348354943686016000*
              Zeta[3]) + 189*x^23*(-75552032651517557963160227 + 
             111677859914391439200*Pi^2 - 1580302032892773120000*Zeta[3]) - 
           63*x^48*(39433456743903743874666103 + 9408705988829855796104880*
              Pi^2 - 981239313713145984000*Zeta[3]) + 
           189*x^24*(-10822612444316393494486567 + 2829420956062390601520*
              Pi^2 - 696260928327076224000*Zeta[3]) - 
           63*x^21*(-111412324441080473780898401 + 48629316694577280480*
              Pi^2 - 488987259269225472000*Zeta[3]) + 
           105*x^50*(16116407006617451501326791 + 14910957836197159211576368*
              Pi^2 - 98904122905238784000*Zeta[3]) - 
           945*x^20*(1791807851133722326681859 + 385227472863406320*Pi^2 - 
             10989346989470976000*Zeta[3]) + 1701*x^18*
            (464052781844500049744191 + 85727352461864400*Pi^2 - 
             455294841055488000*Zeta[3]) + 47628*x^19*
            (-56398758391819915424371 + 2522150498782800*Pi^2 - 
             39356496732672000*Zeta[3]) - 5103*x^16*
            (52118438173116421211027 + 1500878836674000*Pi^2 - 
             5749766467200000*Zeta[3]) + 45927*x^14*(1432663217134346051461 + 
             2886805882800*Pi^2 - 9999593856000*Zeta[3]) - 
           19683*x^15*(9088004493278697506111 + 26850161167200*Pi^2 + 
             46664771328000*Zeta[3]) + 32805*x^17*(24177643466539732041601 + 
             143985447033120*Pi^2 + 1928810548224000*Zeta[3]) - 
           63*x^22*(-39566196327719655734165803 + 463774980739985414640*
              Pi^2 + 981239313713145984000*Zeta[3]) - 
           21*x^49*(334372164871298231939810883 + 597012059216572590778258240*
              Pi^2 + 1466961777807676416000*Zeta[3]) + 
           21*x^47*(681157375011832160224512603 + 833365212915684454640894720*
              Pi^2 + 14222718296034958080000*Zeta[3]) + 
           48*x^43*(605577547546330069976830613 + 365816179968938350882912640*
              Pi^2 + 61877226751571669760000*Zeta[3]) - 
           12*x^27*(2393535161729730712101725957 + 161102727710392071111480*
              Pi^2 + 247508907006286679040000*Zeta[3]) + 
           3*x^25*(7597476742060630072982666233 + 26351040597135534473760*
              Pi^2 + 536753783525410934784000*Zeta[3]) - 
           3*x^45*(7641526064557318577566108633 + 
             6525035270321412596027949120*Pi^2 + 536753783525410934784000*
              Zeta[3]) - 14*x^33*(-578515552500217971271817153 + 
             23706333909631730820730440*Pi^2 + 13710638220229055185920000*
              Zeta[3]) - 14*x^34*(908847878847722380333771849 + 
             39692026475534634631312200*Pi^2 + 24181658480191140359424000*
              Zeta[3]) + 14*x^36*(1577776320267051025362813949 + 
             142276763147184824388622200*Pi^2 + 24181658480191140359424000*
              Zeta[3]) + 2*x^31*(-10575050447719322799590159743 + 
             11235982605394613167057320*Pi^2 + 52260787445009602201344000*
              Zeta[3]) + 63*x^54*(13254082464493104119591920*Pi^2 - 
             13041*(-323713982461770094807 + 35712835200000*Zeta[3])) + 
           81*x^55*(14379269612780664482490880*Pi^2 + 
             243*(9088016023276484500511 + 46664771328000*Zeta[3])) - 
           15*x^53*(217123774104687127635755392*Pi^2 + 
             6561*(8059305626132608105739 + 642936849408000*Zeta[3])) + 
           84*x^51*(85379847075495682299896360*Pi^2 + 
             81*(394821143040317510387707 + 275495477128704000*Zeta[3]))))/
         (1333584000*x^11*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) - 
        (11289600*Pi^4*x^13*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^8*
           (1 - 7*x - 184*x^2 - 1596*x^3 - 3725*x^4 - 8687*x^5 - 8564*x^6 - 
            8687*x^7 - 3725*x^8 - 1596*x^9 - 184*x^10 - 7*x^11 + x^12) + 
          48*Pi^2*(9 - 82*x^2 + 9*x^4)^8*(-583443000 + 1250235000*x + 
            6005947500*x^2 - 14407375500*x^3 - 27026653500*x^4 + 
            75762176700*x^5 + 67881474150*x^6 - 240155326950*x^7 - 
            96534444930*x^8 + 510369509650*x^9 + 51499893410*x^10 - 
            764508336970*x^11 + 80738289170*x^12 + 825133258877*x^13 - 
            215485588094*x^14 - 643605091622*x^15 + 243230233778*x^16 + 
            342665553678*x^17 - 245312428214*x^18 - 179802483798*x^19 + 
            49732721010*x^20 - 49732721010*x^22 + 179802483798*x^23 + 
            245312428214*x^24 - 342665553678*x^25 - 243230233778*x^26 + 
            643605091622*x^27 + 215485588094*x^28 - 825133258877*x^29 - 
            80738289170*x^30 + 764508336970*x^31 - 51499893410*x^32 - 
            510369509650*x^33 + 96534444930*x^34 + 240155326950*x^35 - 
            67881474150*x^36 - 75762176700*x^37 + 27026653500*x^38 + 
            14407375500*x^39 - 6005947500*x^40 - 1250235000*x^41 + 
            583443000*x^42) + x^2*(-1808302178909016000 + 3874933240519320000*
             x + 150118369838416728000*x^2 - 326447455904654616000*x^3 - 
            5633155340614997307000*x^4 + 12472902820824256553400*x^5 + 
            126307721050205709457800*x^6 - 286032170683555487238600*x^7 - 
            1885492738020040998365160*x^8 + 4393398662140891802301000*x^9 + 
            19773756625969034662390200*x^10 + 1316122978926669984000*x^71*
             Zeta[3] - 605295618497424288000*x^72*Zeta[3] - 
            15499732962077280000*x^73*Zeta[3] + 7233208715636064000*x^74*
             Zeta[3] + 4519905705*x^11*(-10576595578737857 + 46114560*Zeta[
                3]) + 1240029000*x^12*(-120940920927758411 + 53957664*Zeta[
                3]) + 65086642152000*x^70*(-27783 + 352343212*Zeta[3]) - 
            117155955873600*x^69*(-33075 + 433285036*Zeta[3]) + 
            117155955873600*x^67*(-2786435 + 10049612068*Zeta[3]) - 
            1446369825600*x^68*(-103789755 + 359689767172*Zeta[3]) - 
            12754584*x^13*(-29841630514077360289 + 1743581700000*Zeta[3]) + 
            1102248*x^14*(757757310072082899281 + 143051848109280*Zeta[3]) - 
            60265409400*x^65*(-206966200761 + 304248794301472*Zeta[3]) + 
            4017693960*x^66*(-1402086718575 + 1960948169378144*Zeta[3]) + 
            472392*x^15*(-4790400231856377800443 + 2419962689239200*Zeta[
                3]) + 4017693960*x^63*(-71193120613785 + 50506982471172256*
               Zeta[3]) - 472392*x^17*(-21573546198279040520861 + 
              77154506104324320*Zeta[3]) - 122472*x^16*
             (28072483767486729153073 + 89956990495954080*Zeta[3]) - 
            446410440*x^64*(-282940786622745 + 188428388488400224*Zeta[3]) + 
            367416*x^18*(28439845658462535626317 + 888591748476296160*Zeta[
                3]) - 446410440*x^61*(-9841612714391025 + 3695535746459301344*
               Zeta[3]) + 49601160*x^62*(-38013077476817901 + 
              13155242827274337056*Zeta[3]) + 1458*x^19*
             (-24121569061855147296846149 + 537498933378698148480*Zeta[3]) - 
            5511240*x^60*(-3587896127052205155 + 678594005731869591712*Zeta[
                3]) - 4536*x^20*(5107629193903763491715213 + 
              1172412767095722024480*Zeta[3]) + 68040*x^26*
             (62552481724869149790919 + 1466481166916654506912*Zeta[3]) + 
            2066715*x^59*(-23131013742052213419 + 4869723887391151428352*Zeta[
                3]) + 612360*x^58*(-244905355216229854275 + 
              26083234920570218571488*Zeta[3]) + 1512*x^22*
             (23863823867151195663783961 + 33159189152411028980640*Zeta[3]) - 
            216*x^21*(-435053661149999200999087813 + 54386951780064930959520*
               Zeta[3]) - 157464*x^57*(-2417169252405906210609 + 
              297077582579690235940960*Zeta[3]) + 360*x^23*
             (-544681892587698308914547669 + 344091478167896719782816*Zeta[
                3]) - 504*x^24*(68696089480361970190818563 + 
              485168292842582272978080*Zeta[3]) - 40824*x^56*
             (-20459418049994133572487 + 1247275484515441291424480*Zeta[3]) - 
            216*x^25*(-1484823116148651059471369491 + 
              4208900721376114056293280*Zeta[3]) + 22680*x^44*
             (-19825416196136194382963 + 25474027408371932183353888*Zeta[
                3]) + 4536*x^54*(-757942778125110502149471 + 
              26508162520420888445854880*Zeta[3]) + 5832*x^55*
             (-388018039592681528203683 + 28758539483471723482830560*Zeta[
                3]) + 168*x^28*(365906260934208253833296717 + 
              35466345671753829615369120*Zeta[3]) - 1512*x^48*
             (-23685778436429966135341861 + 56417752426030208592588000*Zeta[
                3]) - 1512*x^34*(-81235077120538941936152623 + 
              92753557020794119204867680*Zeta[3]) - 1512*x^52*
             (-6909726317315184122584131 + 135064611563413369848319520*Zeta[
                3]) + 1512*x^50*(-15304600776707209096247139 + 
              149106133974270284855427040*Zeta[3]) + 1512*x^36*
             (14283101714730689681222023 + 152382570490918075945423520*Zeta[
                3]) + 504*x^32*(212954304004521538824800589 + 
              180465554649949169701280800*Zeta[3]) - 168*x^30*
             (866245519101756373499531803 + 206122485210892018857150240*Zeta[
                3]) - 504*x^46*(65572554595758717969762863 + 
              453626736780746780912209440*Zeta[3]) - 504*x^38*
             (-140349725415779121787053189 + 863728347742194326252940320*Zeta[
                3]) - 8*x^33*(-44192781654734094278886691813 + 
              1488909979595670477450988320*Zeta[3]) - 
            8*x^29*(-51818258780765485560211051843 + 
              1706269729821974120089389600*Zeta[3]) - 
            216*x^53*(-47178153040807012791351807 + 
              2171237938520211924346584160*Zeta[3]) + 
            8*x^31*(-48406810646087373200664640187 + 
              2628951643025204246083121760*Zeta[3]) + 
            168*x^40*(-687706993137548427394646803 + 
              4061829706325293624115454240*Zeta[3]) + 
            x^27*(-409500561078767423186884215943 + 
              4480509791967755920193514240*Zeta[3]) - 
            168*x^42*(-372891893953576892148089417 + 
              4529676140648590545508001760*Zeta[3]) + 
            360*x^47*(-543478396256617799360964509 + 
              7000605527814935532625131744*Zeta[3]) - 
            216*x^49*(-434624355308011093042059013 + 
              8358223123873223078849863520*Zeta[3]) - 
            216*x^45*(-1482754894704702705230350291 + 
              13054278431974255984701241440*Zeta[3]) + 
            4*x^35*(-34161631876011459483150352219 + 
              18623018038340733216757467840*Zeta[3]) + 
            54*x^51*(-651088382235968559834655623 + 
              19125101130114890625681769600*Zeta[3]) - 
            8*x^37*(-30171602997998766793663603813 + 
              54630179170748810738973269280*Zeta[3]) + 
            8*x^39*(-46404453192238112596987198187 + 
              131414465910057140350386090720*Zeta[3]) - 
            8*x^41*(-53922634220708343818837314243 + 
              228573549271702984129347278880*Zeta[3]) + 
            x^43*(-414417428778208812081838674343 + 
              2533167712580785092939184047360*Zeta[3])))/
         (64012032000*x^13*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8)))

CbarLSeries["v", 2, -1, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 391*Pi^4 + 
            20*Pi^2*(-73 + 96*Log[2]^2) + 15*(869 + 936*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 144*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              128*Log[2]^4 - 156*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
              2712*Zeta[3]) - 10*lm*(-1233 + 44*Pi^2 + 648*Zeta[3])) + 
          2*(CF*(5670*lm^2 - 3240*lm^3 + 981*Pi^4 + 10*Pi^2*(259 + 
                576*Log[2]^2) + 15*(1025 + 2808*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 432*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                384*Log[2]^4 - 468*PolyGamma[2, 1] - 9216*PolyLog[4, 1/2] - 
                10464*Zeta[3]) + 135*lm*(95 + 8*Pi^2 - 144*Zeta[3])) - 
            15*(NL*(-219 - 162*lm - 84*lm^2 - 24*lm^3 + 28*Pi^2 + 
                8*lm*Pi^2 - 288*Zeta[3]) + NM*(-219 - 84*lm^2 - 24*lm^3 + 
                28*Pi^2 + 2*lm*(-81 + 4*Pi^2) + 8*PolyGamma[2, 1] - 
                272*Zeta[3]) - NH*(-837 + 162*lm + 84*lm^2 + 24*lm^3 - 
                8*lm*Pi^2 - 1296*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                216*PolyGamma[2, 1] + 2928*Zeta[3])))))/25920, 
      (CF*NC*(-3*CA*(18240*lm^2 + 2640*lm^3 + 647*Pi^4 + 
           30*Pi^2*(5 + 128*Log[2]^2) + 30*(2255 + 216*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 216*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             128*Log[2]^4 - 36*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
             1540*Zeta[3]) - 180*lm*(-275 + 72*Zeta[3])) + 
         2*(CF*(1620*lm^2 - 6480*lm^3 + 1941*Pi^4 + 10*Pi^2*(59 + 1152*
                Log[2]^2) + 15*(1207 + 1296*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] - 1296*Im[PolyLog[2, (-1)^(1/3)]]^2 - 768*
                Log[2]^4 - 216*PolyGamma[2, 1] - 18432*PolyLog[4, 1/2] - 
               11784*Zeta[3]) - 270*lm*(-41 + 144*Zeta[3])) - 
           180*(NM*(-82 - 57*lm - 20*lm^2 - 4*lm^3 + 2*Pi^2 - 32*Zeta[3]) + 
             NL*(-82 - 57*lm - 20*lm^2 - 4*lm^3 + 2*Pi^2 - 32*Zeta[3]) - 
             NH*(178 + 57*lm + 20*lm^2 + 4*lm^3 - 216*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 36*PolyGamma[2, 1] + 200*
                Zeta[3])))))/25920, 
      -(CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 236*Pi^4 + 
            30*Pi^2*(51 + 64*Log[2]^2) + 15*(1523 + 1224*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 128*Log[2]^4 - 300*PolyGamma[2, 
                1] - 3072*PolyLog[4, 1/2] - 3968*Zeta[3]) + 
            10*lm*(1497 + 44*Pi^2 - 648*Zeta[3])) + 
          10*(CF*(1134*lm^2 - 648*lm^3 + 180*Pi^4 + 8*Pi^2*(-17 + 
                144*Log[2]^2) + 3*(1643 + 3672*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 384*Log[2]^4 - 900*PolyGamma[2, 1] - 
                9216*PolyLog[4, 1/2] - 13560*Zeta[3]) - 27*lm*(-47 + 8*Pi^2 + 
                144*Zeta[3])) + 3*(NM*(-1773 + 84*lm^2 + 24*lm^3 + 
                140*Pi^2 + lm*(210 + 8*Pi^2) - 40*PolyGamma[2, 1] + 
                16*Zeta[3]) + NL*(387 + 210*lm + 84*lm^2 + 24*lm^3 - 
                4*Pi^2 + 8*lm*Pi^2 + 96*Zeta[3]) + NH*(339 + 210*lm + 
                84*lm^2 + 24*lm^3 + 8*lm*Pi^2 - 3888*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 792*PolyGamma[2, 1] + 
                6768*Zeta[3])))))/25920, 
      -(CF*NC*(-34875*CF + 82080*NM - 4320*NL - 351200*NH - 4380*CF*Pi^2 - 
          7200*NM*Pi^2 + 1440*NL*Pi^2 + 6300*Sqrt[3]*CF*Pi^3 + 
          8400*Sqrt[3]*NH*Pi^3 + 648*CF*Pi^4 - 64800*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 120960*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 51840*CF*Im[PolyLog[2, (-1)^(1/3)]]^
            2 + 233280*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          311040*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          4860*Sqrt[3]*CF*Pi*Log[3]^2 + 6480*Sqrt[3]*NH*Pi*Log[3]^2 - 
          2880*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
            4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          11520*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          25920*CF*PolyGamma[2, 1] + 1440*NM*PolyGamma[2, 1] - 
          24480*NH*PolyGamma[2, 1] - 34560*CF*Zeta[3] - 83520*NM*Zeta[3] + 
          17280*NL*Zeta[3] - 198720*NH*Zeta[3] - 
          6*CA*(-430*Pi^2 + 525*Sqrt[3]*Pi^3 + 54*Pi^4 + 405*Sqrt[3]*Pi*
             Log[3]^2 - 120*(22 + 45*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              36*Im[PolyLog[2, (-1)^(1/3)]]^2 - 162*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 18*PolyGamma[2, 1] + 
              21*Zeta[3])) - 120*Log[x]*(-3*CA*(608*lm + 132*lm^2 + 
              3*(241 - 9*Pi^2 + 36*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                96*Zeta[3])) + 2*(135*NL + 120*lm*NL + 36*lm^2*NL - 
              889*NH + 120*lm*NH + 36*lm^2*NH - 12*NL*Pi^2 + 
              3*NM*(189 + 40*lm + 12*lm^2 - 4*Pi^2) + 432*Sqrt[3]*NH*Im[
                PolyLog[2, (-1)^(1/3)]] - 3*CF*(60 - 18*lm + 108*lm^2 + 
                29*Pi^2 - 108*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                288*Zeta[3])))))/25920, 
      (CF*NC*(-25083*CF - 3888*CF*lm - 21336*NM + 432*lm*NM - 504*NL + 
         432*lm*NL - 72184*NH + 432*lm*NH + 1728*CF*Pi^2 - 1632*NM*Pi^2 + 
         96*NL*Pi^2 + 980*Sqrt[3]*CF*Pi^3 + 1680*Sqrt[3]*NH*Pi^3 - 
         54864*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 65664*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 36288*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 62208*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 756*Sqrt[3]*CF*Pi*
          Log[3]^2 + 1296*Sqrt[3]*NH*Pi*Log[3]^2 - 
         576*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
           4*(2*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         2304*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
         15552*CF*PolyGamma[2, 1] - 3456*NM*PolyGamma[2, 1] - 
         16128*NH*PolyGamma[2, 1] + 109152*CF*Zeta[3] - 3456*NM*Zeta[3] + 
         3456*NL*Zeta[3] - 122112*NH*Zeta[3] - 
         2*CA*(1188*lm + 57*Pi^2 + 245*Sqrt[3]*Pi^3 + 189*Sqrt[3]*Pi*
            Log[3]^2 - 36*(381*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             4*(-4 + 63*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 27*
                PolyGamma[2, 1] + 179*Zeta[3]))) - 
         24*Log[x]*(3*CA*(-687 - 608*lm - 132*lm^2 + 61*Pi^2 - 
             84*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3]) + 
           2*(135*NL + 120*lm*NL + 36*lm^2*NL - 889*NH + 120*lm*NH + 
             36*lm^2*NH - 12*NL*Pi^2 + 3*NM*(-47 + 40*lm + 12*lm^2 + 20*
                Pi^2) + 432*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
             3*CF*(165 - 18*lm + 108*lm^2 + 71*Pi^2 - 84*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3])))))/10368, 
      -(CF*NC*(-259200*(15*CA*(53 + 22*lm) + 2*(30*CF*(-2 + 9*lm) - 130*NM - 
              30*lm*NM - 45*NL - 30*lm*NL - 8*NH - 30*lm*NH))*Log[x]^2 + 
          5184000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 - 
          1080*Log[x]*(8*(25*NL*(3 + 40*lm + 12*lm^2 - 8*Pi^2) + 
              25*NM*(217 + 40*lm + 12*lm^2 + 16*Pi^2) + NH*(-14923 + 
                1000*lm + 300*lm^2 + 8000*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) - 50*CF*(1317 - 72*lm + 432*lm^2 + 
              98*Pi^2 - 792*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1152*Zeta[3]) + 25*CA*(-1851 - 2432*lm - 528*lm^2 + 106*Pi^2 - 
              792*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1152*Zeta[3])) - 
          225*CA*(-560*Pi^2 + 7700*Sqrt[3]*Pi^3 + 432*Pi^4 + 
            5940*Sqrt[3]*Pi*Log[3]^2 + 15*(-10411 - 4560*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              19008*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              2304*PolyGamma[2, 1] + 1216*Zeta[3])) + 
          2*(16*(2*NH*(87500*Sqrt[3]*Pi^3 + 67500*Sqrt[3]*Pi*Log[3]^2 + 
                9*(-324269 + 72000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                  360000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                  18750*PolyGamma[2, 1] - 175500*Zeta[3])) + 4500*NM*(-82 + 
                12*Pi^2 - 21*PolyGamma[2, 1] - 402*Zeta[3]) + 
              3375*NL*(-75 + 4*Pi^2 + 96*Zeta[3])) + 
            225*CF*(72*Pi^2 + 7700*Sqrt[3]*Pi^3 + 432*Pi^4 + 
              5940*Sqrt[3]*Pi*Log[3]^2 + 15*(-10821 - 4560*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^
                  2 + 19008*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                2304*PolyGamma[2, 1] + 1408*Zeta[3])))))/7776000, 
      (CF*NC*(-86400*(120*CA*(26 + 11*lm) + 5*CF*(-133 + 432*lm) - 
           2*(502*NM + 120*lm*NM + 195*NL + 120*lm*NL + 36*NH + 
             120*lm*NH))*Log[x]^2 + 3456000*(40*CA + 49*CF - 11*NM - 4*NL)*
          Log[x]^3 - 125*CA*(7920*lm + 78948*Pi^2 + 17920*Sqrt[3]*Pi^3 + 
           13824*Sqrt[3]*Pi*Log[3]^2 - 9*(207425 + 68224*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 73728*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] - 25920*PolyGamma[2, 1] - 
             220416*Zeta[3])) + 360*Log[x]*
          (-2*(2*(75*NL*(35 + 112*lm + 36*lm^2 - 20*Pi^2) + NM*
                (12521 + 8400*lm + 2700*lm^2 + 12300*Pi^2) + NH*
                (-134107 + 8400*lm + 2700*lm^2 + 73200*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]])) + 75*CF*(-8011 + 252*lm - 648*
                lm^2 + 112*Pi^2 + 1024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               1728*Zeta[3])) + 75*CA*(-3227 + 3472*lm + 792*lm^2 + 
             172*Pi^2 + 1024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             1728*Zeta[3])) + 8*(125*CF*(-511485 - 1620*lm + 21600*Pi^2 + 
             4480*Sqrt[3]*Pi^3 - 153504*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             165888*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             3456*Sqrt[3]*Pi*Log[3]^2 + 58320*PolyGamma[2, 1] + 
             525096*Zeta[3]) + 2*(NH*(11250*lm + 533750*Sqrt[3]*Pi^3 + 
               411750*Sqrt[3]*Pi*Log[3]^2 + 9*(-2131739 + 1238000*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] + 2196000*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 354000*PolyGamma[2, 
                   1] - 2592000*Zeta[3])) + 3*NM*(-1964849 + 3750*lm + 46500*
                Pi^2 - 468000*PolyGamma[2, 1] - 1746000*Zeta[3]) + 
             1125*NL*(-553 + 10*lm + 20*Pi^2 + 720*Zeta[3])))))/23328000, 
      -(CF*NC*(-90542867625*CF - 64412699904*NM - 11113200000*NL - 
          213683340384*NH + 178737300*CF*Pi^2 + 5000940000*NM*Pi^2 + 
          333396000*NL*Pi^2 + 3727552500*Sqrt[3]*CF*Pi^3 + 
          7034930000*Sqrt[3]*NH*Pi^3 + 150028200*CF*Pi^4 - 
          33784128000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
          32154192000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          12002256000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 138025944000*Sqrt[3]*
           CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 260493408000*Sqrt[3]*
           NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2875540500*Sqrt[3]*CF*
           Pi*Log[3]^2 + 5426946000*Sqrt[3]*NH*Pi*Log[3]^2 - 
          9525600*(35*CA*(637 + 264*lm) + 2*(35*CF*(-43 + 216*lm) - 
              2*(2583*NM + 420*lm*NM + 595*NL + 420*lm*NL + 153*NH + 
                420*lm*NH)))*Log[x]^2 + 3556224000*(22*CA + 86*CF - 
            3*(7*NM + NL))*Log[x]^3 + 18003384000*CF*PolyGamma[2, 1] - 
          5000940000*NM*PolyGamma[2, 1] - 11002068000*NH*PolyGamma[2, 1] + 
          21337344000*CF*Zeta[3] - 46008648000*NM*Zeta[3] + 
          12002256000*NL*Zeta[3] - 110020680000*NH*Zeta[3] - 
          7560*Log[x]*(-600642*NM + 882000*lm*NM + 264600*lm^2*NM - 
            815850*NL + 882000*lm*NL + 264600*lm^2*NL - 20925882*NH + 
            882000*lm*NH + 264600*lm^2*NH + 2381400*NM*Pi^2 - 
            264600*NL*Pi^2 + 11485600*Sqrt[3]*NH*Im[PolyLog[2, (-1)^
                (1/3)]] + 3675*CA*(-500 - 1824*lm - 396*lm^2 + 43*Pi^2 - 
              828*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 864*Zeta[3]) - 
            2450*CF*(5651 - 162*lm + 972*lm^2 + 123*Pi^2 - 2484*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 2592*Zeta[3])) - 
          77175*CA*(1692*Pi^2 + 24150*Sqrt[3]*Pi^3 + 972*Pi^4 + 
            18630*Sqrt[3]*Pi*Log[3]^2 + 5*(-116717 - 43776*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 15552*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 178848*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              23328*PolyGamma[2, 1] + 27216*Zeta[3]))))/6001128000, 
      (-2188945*CF^2*NC)/62208 - (7*CF^2*lm*NC)/288 - (136898029*CF*NM*NC)/
        16669800 + (7*CF*lm*NM*NC)/2592 - (3757*CF*NC*NL)/5184 + 
       (7*CF*lm*NC*NL)/2592 - (4452593609*CF*NC*NH)/222264000 + 
       (7*CF*lm*NC*NH)/2592 + (5273*CF^2*NC*Pi^2)/17280 + 
       (131*CF*NM*NC*Pi^2)/324 + (11*CF*NC*NL*Pi^2)/648 + 
       (123445*CF^2*NC*Pi^3)/(139968*Sqrt[3]) + (10535*CF*NC*NH*Pi^3)/
        (5832*Sqrt[3]) - (61829*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2592*Sqrt[3]) + (694*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27*Sqrt[3]) + (3527*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (108*Sqrt[3]) + (602*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9*Sqrt[3]) + (3527*CF^2*NC*Pi*Log[3]^2)/(5184*Sqrt[3]) + 
       (301*CF*NC*NH*Pi*Log[3]^2)/(216*Sqrt[3]) - 
       (CF*NC*(70*CA*(809 + 660*lm) + 35*CF*(2279 + 2160*lm) - 
          4*(5*(2861 + 420*lm)*NM + 12*(35*(8 + 5*lm)*NL + 
              (66 + 175*lm)*NH)))*Log[x]^2)/7560 + 
       (CF*NC*(345*CA + 4*(7*CF - 46*NM - 5*NL))*Log[x]^3)/27 + 
       (7*CF^2*NC*PolyGamma[2, 1])/2 - (43*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (76*CF*NC*NH*PolyGamma[2, 1])/27 - 
       (CA*CF*NC*(124740*lm + 1131003*Pi^2 + 1234450*Sqrt[3]*Pi^3 + 
          952290*Sqrt[3]*Pi*Log[3]^2 - 135*(1038271 + 247316*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 338592*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 108864*PolyGamma[2, 1] - 
            1107216*Zeta[3])))/8398080 - 
       (CF*NC*Log[x]*(2*(24*(3675*NL*(-26 + 55*lm + 18*lm^2 - 14*Pi^2) + 
              5*NM*(-154442 + 40425*lm + 13230*lm^2 + 177870*Pi^2) + 
              NH*(-5299507 + 202125*lm + 66150*lm^2 + 2949800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 1225*CF*(-362181 + 5184*lm - 
              11664*lm^2 + 23742*Pi^2 + 28216*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 31104*Zeta[3])) - 
          1225*CA*(-276525 + 61704*lm + 14256*lm^2 + 25758*Pi^2 + 
            28216*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 31104*Zeta[3])))/
        19051200 + (2675*CF^2*NC*Zeta[3])/72 - (131*CF*NM*NC*Zeta[3])/27 + 
       (7*CF*NC*NL*Zeta[3])/9 - (182*CF*NC*NH*Zeta[3])/9, 
      (74711*CF^2*NC)/3888 + (3415153639*CF*NM*NC)/222264000 + 
       (6883*CF*NC*NL)/2592 + (57474588853*CF*NC*NH)/1200225600 + 
       (27091*CF^2*NC*Pi^2)/120960 + (35*CF*NM*NC*Pi^2)/54 - 
       (CF*NC*NL*Pi^2)/18 - (329245*CF^2*NC*Pi^3)/(139968*Sqrt[3]) - 
       (32795*CF*NC*NH*Pi^3)/(6561*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (171331*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(7776*Sqrt[3]) - 
       (10678*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(729*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (9407*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(108*Sqrt[3]) - 
       (14992*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) - 
       (9407*CF^2*NC*Pi*Log[3]^2)/(5184*Sqrt[3]) - 
       (937*CF*NC*NH*Pi*Log[3]^2)/(243*Sqrt[3]) + 
       (CF*NC*(315*CA*(4057 + 1760*lm) + 2*(315*CF*(-101 + 1440*lm) - 
            8*(3*(-611 + 2100*lm)*NM + 210*(41 + 30*lm)*NL + 
              5*(527 + 1260*lm)*NH)))*Log[x]^2)/30240 - 
       (CF*NC*(1025*CA + 4010*CF - 24*(92*NM + 5*NL))*Log[x]^3)/54 - 
       4*CF^2*NC*PolyGamma[2, 1] + (23*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (41*CF*NC*NH*PolyGamma[2, 1])/18 + 
       (CF*NC*Log[x]*(2*(8*(27*NM*(-7993673 + 294000*lm + 88200*lm^2 + 
                2704800*Pi^2) - 5*(26460*NL*(115 - 60*lm - 18*lm^2 + 
                  24*Pi^2) - NH*(-52968051 + 1587600*lm + 476280*lm^2 + 
                  29384320*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
            3675*CF*(-445737 + 7776*lm - 46656*lm^2 + 11484*Pi^2 + 
              150512*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 124416*Zeta[3])) - 
          3675*CA*(-106869 + 262656*lm + 57024*lm^2 + 11484*Pi^2 + 
            150512*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 124416*Zeta[3])))/
        114307200 - (1603*CF^2*NC*Zeta[3])/216 - (13*CF*NM*NC*Zeta[3])/9 - 
       (8*CF*NC*NL*Zeta[3])/3 + (71*CF*NC*NH*Zeta[3])/3 + 
       (CA*CF*NC*(-883791*Pi^2 + 3292450*Sqrt[3]*Pi^3 + 104976*Pi^4 + 
          2539890*Sqrt[3]*Pi*Log[3]^2 - 
          45*(685324*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            186624*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
            3*(-599701 + 903072*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                   Sqrt[3])]] + 124416*PolyGamma[2, 1] + 230832*Zeta[3]))))/
        8398080, (-10864813831*CF^2*NC)/349920000 - (9*CF^2*lm*NC)/800 - 
       (21007793549*CF*NM*NC)/2000376000 + (CF*lm*NM*NC)/800 - 
       (43361*CF*NC*NL)/43200 + (CF*lm*NC*NL)/800 - (81967377167*CF*NC*NH)/
        3000564000 + (CF*lm*NC*NH)/800 - (280619*CF^2*NC*Pi^2)/60480 - 
       (47*CF*NM*NC*Pi^2)/180 + (19*CF*NC*NL*Pi^2)/1080 + 
       (31409*CF^2*NC*Pi^3)/(26244*Sqrt[3]) + (135905*CF*NC*NH*Pi^3)/
        (52488*Sqrt[3]) - (3073733*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (109350*Sqrt[3]) + (20102*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (729*Sqrt[3]) + (17948*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (405*Sqrt[3]) + (7766*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) + 
       (4487*CF^2*NC*Pi*Log[3]^2)/(4860*Sqrt[3]) + 
       (3883*CF*NC*NH*Pi*Log[3]^2)/(1944*Sqrt[3]) - 
       (CF*NC*(21*CA*(-161837 + 52800*lm) + 2*(21*CF*(270319 + 43200*lm) - 
            40*(18*(-31 + 140*lm)*NM + 5*(798*NL + 504*lm*NL + 205*NH + 
                504*lm*NH))))*Log[x]^2)/151200 - 
       (CF*NC*(-2889*CA + 2650*CF + 1920*NM + 80*NL)*Log[x]^3)/90 + 
       (9*CF^2*NC*PolyGamma[2, 1])/2 - (20*CF*NM*NC*PolyGamma[2, 1])/9 - 
       (31*CF*NC*NH*PolyGamma[2, 1])/9 - 
       (CF*NC*Log[x]*(80*(13230*NL*(-337 + 273*lm + 90*lm^2 - 90*Pi^2) + 
            9*NM*(-13448069 + 401310*lm + 132300*lm^2 + 4806900*Pi^2) + 
            NH*(-135717597 + 3611790*lm + 1190700*lm^2 + 76106800*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) + 98*CF*(-566753889 + 4082400*lm - 
            8748000*lm^2 + 70696800*Pi^2 + 28716800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3]) - 
          49*CA*(-501267117 + 46040400*lm + 10692000*lm^2 + 72640800*Pi^2 + 
            28716800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3])))/
        571536000 + (11579*CF^2*NC*Zeta[3])/180 - (13*CF*NM*NC*Zeta[3])/9 + 
       CF*NC*NL*Zeta[3] - (220*CF*NC*NH*Zeta[3])/9 - 
       (CA*CF*NC*(433026*lm - 147363705*Pi^2 + 12563600*Sqrt[3]*Pi^3 + 
          9691920*Sqrt[3]*Pi*Log[3]^2 + 12*(-75789849 - 24589864*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 38767680*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 11809800*
             PolyGamma[2, 1] + 163573020*Zeta[3])))/62985600, 
      (1343619557*CF^2*NC)/77760000 - (19847245633*CF*NM*NC)/1000188000 + 
       (224057*CF*NC*NL)/64800 + (727155677979443*CF*NC*NH)/
        11981252052000 + (3827*CF^2*NC*Pi^2)/1890 + (347*CF*NM*NC*Pi^2)/27 - 
       (CF*NC*NL*Pi^2)/18 - (147931*CF^2*NC*Pi^3)/(52488*Sqrt[3]) - 
       (518035*CF*NC*NH*Pi^3)/(78732*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (3967543*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(145800*Sqrt[3]) - 
       (78716*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (42266*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(405*Sqrt[3]) - 
       (59204*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (243*Sqrt[3]) - (21133*CF^2*NC*Pi*Log[3]^2)/(9720*Sqrt[3]) - 
       (14801*CF*NC*NH*Pi*Log[3]^2)/(2916*Sqrt[3]) + 
       (CF*NC*(77*CA*(71629 + 39600*lm) + 16*(231*CF*(719 + 1350*lm) - 
            5*(11*(-23153 + 630*lm)*NM + 10*(231*(4 + 3*lm)*NL + 
                (314 + 693*lm)*NH))))*Log[x]^2)/138600 - 
       (CF*NC*(4049*CA + 8*(1579*CF - 45*(50*NM + NL)))*Log[x]^3)/135 - 
       5*CF^2*NC*PolyGamma[2, 1] + (31*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (49*CF*NC*NH*PolyGamma[2, 1])/18 + 
       (CF*NC*Log[x]*(20*(2401245*NL*(-3487 + 1200*lm + 360*lm^2 - 
              600*Pi^2) + 16335*NM*(-18167027 + 176400*lm + 52920*lm^2 + 
              5309640*Pi^2) + NH*(-125789175753 + 2881494000*lm + 
              864448200*lm^2 + 70204103200*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]])) + 17787*CF*(-146505813 + 1458000*lm - 
            8748000*lm^2 + 12873600*Pi^2 + 33812800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3]) - 
          71148*CA*(-10412301 + 6156000*lm + 1336500*lm^2 + 1609200*Pi^2 + 
            4226600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 2916000*Zeta[3])))/
        51866892000 - (2212*CF^2*NC*Zeta[3])/135 - (383*CF*NM*NC*Zeta[3])/
        9 - (10*CF*NC*NL*Zeta[3])/3 + 29*CF*NC*NH*Zeta[3] + 
       (CA*CF*NC*(-5561996625*Pi^2 + 2588792500*Sqrt[3]*Pi^3 + 
          68890500*Pi^4 + 1997068500*Sqrt[3]*Pi*Log[3]^2 - 
          126*(198377150*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            43740000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
            9*(-42122011 + 84532000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                   Sqrt[3])]] + 12150000*PolyGamma[2, 1] + 39816000*Zeta[
                3]))))/5511240000, (16299117387979*CF^2*NC)/288054144000 - 
       (11*CF^2*lm*NC)/1800 + (58127084691343*CF*NM*NC)/11981252052000 + 
       (11*CF*lm*NM*NC)/16200 - (496307*CF*NC*NL)/388800 + 
       (11*CF*lm*NC*NL)/16200 - (627562212403691*CF*NC*NH)/17971878078000 + 
       (11*CF*lm*NC*NH)/16200 - (9219307*CF^2*NC*Pi^2)/302400 - 
       (1537*CF*NM*NC*Pi^2)/270 + (29*CF*NC*NL*Pi^2)/1620 + 
       (956165*CF^2*NC*Pi^3)/(629856*Sqrt[3]) + (1621585*CF*NC*NH*Pi^3)/
        (472392*Sqrt[3]) - (1703699*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (52488*Sqrt[3]) + (564802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (19683*Sqrt[3]) + (27319*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(486*Sqrt[3]) + 
       (92662*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (729*Sqrt[3]) + (27319*CF^2*NC*Pi*Log[3]^2)/(23328*Sqrt[3]) + 
       (46331*CF*NC*NH*Pi*Log[3]^2)/(17496*Sqrt[3]) - 
       (CF*NC*(165*CA*(-2686829 + 129360*lm) + 
          4*(33*CF*(7376777 + 264600*lm) - 10*((-4076683 + 97020*lm)*NM + 
              13860*(11 + 7*lm)*NL + (40757 + 97020*lm)*NH)))*Log[x]^2)/
        2494800 - (CF*NC*(-28461*CA + 8*(5637*CF + 2230*NM + 35*NL))*
         Log[x]^3)/270 + (11*CF^2*NC*PolyGamma[2, 1])/2 - 
       (77*CF*NM*NC*PolyGamma[2, 1])/27 - (110*CF*NC*NH*PolyGamma[2, 1])/
        27 - (CF*NC*Log[x]*(5*(4*(7203735*NL*(-2159 + 1088*lm + 360*lm^2 - 
                440*Pi^2) + 45*NM*(-21561451811 + 174170304*lm + 
                57629880*lm^2 + 6025524120*Pi^2) + NH*(-390384828501 + 
                7837663680*lm + 2593344600*lm^2 + 219757199200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 363*CF*(-36001150329 + 
              122880240*lm - 257191200*lm^2 + 8261394120*Pi^2 + 
              1070904800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              685843200*Zeta[3])) - 363*CA*(-84964986417 + 3375237600*lm + 
            785862000*lm^2 + 20828121300*Pi^2 + 2677262000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1714608000*Zeta[3])))/
        311201352000 + CA*CF*NC*(-21329012024471/720135360000 - 
         (121*lm)/32400 + (865423*Pi^2)/56700 - (956165*Pi^3)/
          (1259712*Sqrt[3]) + (1703699*Im[PolyLog[2, (-1)^(1/3)]])/
          (104976*Sqrt[3]) - (27319*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (972*Sqrt[3]) - (27319*Pi*Log[3]^2)/(46656*Sqrt[3]) - 
         (11*PolyGamma[2, 1])/4 - (77227*Zeta[3])/1080) + 
       (78547*CF^2*NC*Zeta[3])/540 + (461*CF*NM*NC*Zeta[3])/27 + 
       (11*CF*NC*NL*Zeta[3])/9 - (86*CF*NC*NH*Zeta[3])/3, 
      -(CF*NC*(-63111634185600*(1001*CA*(-64709 + 277200*lm) + 
            2*(1001*CF*(686599 + 226800*lm) - 40*(26*(-4919443 + 24255*lm)*
                 NM + 7*(2145*(55 + 42*lm)*NL + 2*(21514 + 45045*lm)*
                   NH))))*Log[x]^2 + 30323877993497088000*
           (1371*CA + 1783*CF - 11380*NM - 70*NL)*Log[x]^3 + 
          2162160*Log[x]*(-2*(80*(13689*NM*(-49882031113 + 160083000*lm + 
                  48024900*lm^2 + 18249462000*Pi^2) - 7*(626107482*NL*
                   (1947 - 500*lm - 150*lm^2 + 300*Pi^2) - 
                  NH*(-17056099700859 + 313053741000*lm + 93916122300*lm^2 + 
                    9555768622400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
              9018009*CF*(-1786358067 + 8748000*lm - 52488000*lm^2 + 
                315981000*Pi^2 + 235314400*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 139968000*Zeta[3])) + 9018009*CA*
             (-1407506217 + 295488000*lm + 64152000*lm^2 + 315981000*Pi^2 + 
              235314400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 139968000*Zeta[
                3])) - 1289575287*CA*(-2921846288400*Pi^2 + 
            288260140000*Sqrt[3]*Pi^3 + 6613488000*Pi^4 + 
            222372108000*Sqrt[3]*Pi*Log[3]^2 - 21*(136031507200*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 25194240000*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 3*(58450855853 + 169426368000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 25194240000*
                 PolyGamma[2, 1] + 190084320000*Zeta[3]))) + 
          2*(-320*(533871*NM*(-538266941649491 + 158773777192800*Pi^2 + 
                4326563241000*PolyGamma[2, 1] - 446634451494000*Zeta[3]) - 
              7*(5*NH*(-2251539187836033519 + 83696588421446000*Sqrt[3]*
                   Pi^3 + 84439876691089920*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]] + 3099165102691257600*Sqrt[3]*
                   Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 64565939639401200*
                   Sqrt[3]*Pi*Log[3]^2 - 96454299421279800*PolyGamma[2, 1] - 
                  1045767667409665200*Zeta[3]) + 22562409221352*NL*
                 (-28751 + 375*Pi^2 + 27000*Zeta[3]))) + 1289575287*CF*
             (-2922889244400*Pi^2 + 288260140000*Sqrt[3]*Pi^3 + 
              6613488000*Pi^4 + 222372108000*Sqrt[3]*Pi*Log[3]^2 - 
              21*(136031507200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                25194240000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3*(58607564483 + 
                  169426368000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[
                        3])]] + 25194240000*PolyGamma[2, 1] + 190084320000*
                   Zeta[3]))))))/682287254853684480000, 
      (797195647130731*CF^2*NC)/1361055830400 - (13*CF^2*lm*NC)/3528 + 
       (1459954832124653173*CF*NM*NC)/13161405379122000 + 
       (13*CF*lm*NM*NC)/31752 - (21047903*CF*NC*NL)/13608000 + 
       (13*CF*lm*NC*NL)/31752 - (921366545631722017*CF*NC*NH)/
        21536845165836000 + (13*CF*lm*NC*NH)/31752 - 
       (320382179*CF^2*NC*Pi^2)/1905120 - (4253*CF*NM*NC*Pi^2)/126 + 
       (41*CF*NC*NL*Pi^2)/2268 + (980020*CF^2*NC*Pi^3)/(531441*Sqrt[3]) + 
       (6132245*CF*NC*NH*Pi^3)/(1417176*Sqrt[3]) - 
       (1600466429*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(43401015*Sqrt[3]) + 
       (8613718*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) + 
       (3136064*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (45927*Sqrt[3]) + (350414*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) + 
       (196004*CF^2*NC*Pi*Log[3]^2)/(137781*Sqrt[3]) + 
       (175207*CF*NC*NH*Pi*Log[3]^2)/(52488*Sqrt[3]) - 
       (CF*NC*(143*CA*(-159372823 + 1552320*lm) + 
          143*CF*(325055279 + 2540160*lm) - 
          28*((-325941659 + 1441440*lm)*NM + 385*(234*(25 + 16*lm)*NL + 
              (1597 + 3744*lm)*NH)))*Log[x]^2)/22702680 - 
       (CF*NC*(-169321*CA + 318332*CF + 88256*NM + 448*NL)*Log[x]^3)/378 + 
       (13*CF^2*NC*PolyGamma[2, 1])/2 - (94*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (127*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-32059870513395661/108884466432000 - (143*lm)/63504 + 
         (213637439*Pi^2)/2540160 - (490010*Pi^3)/(531441*Sqrt[3]) + 
         (1600466429*Im[PolyLog[2, (-1)^(1/3)]])/(86802030*Sqrt[3]) - 
         (1568032*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(45927*Sqrt[3]) - 
         (98002*Pi*Log[3]^2)/(137781*Sqrt[3]) - (13*PolyGamma[2, 1])/4 - 
         (62105*Zeta[3])/252) + (6941*CF^2*NC*Zeta[3])/14 + 
       (2617*CF*NM*NC*Zeta[3])/27 + (13*CF*NC*NL*Zeta[3])/9 - 
       (296*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((56782313976329*NM*NC)/
          292183491600 - (95*lm*NM*NC)/189 - (lm^2*NM*NC)/6 + 
         (14809*NC*NL)/10800 - (95*lm*NC*NL)/189 - (lm^2*NC*NL)/6 + 
         (7543006819409*NC*NH)/239059220400 - (95*lm*NC*NH)/189 - 
         (lm^2*NC*NH)/6 - (3211*NM*NC*Pi^2)/54 + (13*NC*NL*Pi^2)/54 - 
         (350414*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
         CA*NC*(-749520229441/3086294400 + (743*lm)/189 + (11*lm^2)/12 + 
           (82907*Pi^2)/756 + (1568032*Im[PolyLog[2, (-1)^(1/3)]])/
            (137781*Sqrt[3]) - 2*Zeta[3]) + CF*NC*(336265978891/675126900 - 
           (61*lm)/84 + (3*lm^2)/2 - (27575*Pi^2)/126 - 
           (3136064*Im[PolyLog[2, (-1)^(1/3)]])/(137781*Sqrt[3]) + 
           4*Zeta[3])), (-25976928869179973*CF^2*NC)/136105583040000 - 
       (987721958435857643*CF*NM*NC)/584951350183200 + 
       (26782633*CF*NC*NL)/5292000 + (20730024426972390631*CF*NC*NH)/
        236905296824196000 + (88876727*CF^2*NC*Pi^2)/1587600 + 
       (19993*CF*NM*NC*Pi^2)/45 - (CF*NC*NL*Pi^2)/18 - 
       (7883069*CF^2*NC*Pi^3)/(2125764*Sqrt[3]) - (21209965*CF*NC*NH*Pi^3)/
        (2125764*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (65228707633*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1736040600*Sqrt[3]) - (221164*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (59049*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (31532276*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (229635*Sqrt[3]) - (2423996*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (7883069*CF^2*NC*Pi*Log[3]^2)/(2755620*Sqrt[3]) - 
       (605999*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) + 
       (CF*NC*(143*CA*(-70707943 + 7761600*lm) + 
          4*(143*CF*(44058419 + 3175200*lm) - 140*(630*(-570937 + 572*lm)*
               NM + 15015*(31 + 24*lm)*NL + (178679 + 360360*lm)*NH)))*
         Log[x]^2)/37837800 + 
       (CF*NC*(-57649*CA + 8*(4376*CF + 90545*NM + 140*NL))*Log[x]^3)/315 - 
       7*CF^2*NC*PolyGamma[2, 1] + (47*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (65*CF*NC*NH*PolyGamma[2, 1])/18 - (1157*CF^2*NC*Zeta[3])/7 - 
       (10039*CF*NM*NC*Zeta[3])/9 - (14*CF*NC*NL*Zeta[3])/3 + 
       (119*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*
        (12986649161482279/136105583040000 - (19749431*Pi^2)/705600 + 
         (7883069*Pi^3)/(4251528*Sqrt[3]) + Pi^4/80 - 
         (65228707633*Im[PolyLog[2, (-1)^(1/3)]])/(3472081200*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (15766138*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(229635*Sqrt[3]) + 
         (7883069*Pi*Log[3]^2)/(5511240*Sqrt[3]) + (7*PolyGamma[2, 1])/2 + 
         (1157*Zeta[3])/14) + CF*Log[x]*((-15894510038087*NM*NC)/
          16232416200 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (205031*NC*NL)/37800 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (288255311502329*NC*NH)/3944477136600 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (5177*NM*NC*Pi^2)/9 - (7*NC*NL*Pi^2)/9 + 
         (2423996*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CF*NC*(-6745576831067/27005076000 + lm/2 - 3*lm^2 + (1391*Pi^2)/18 + 
           (31532276*Im[PolyLog[2, (-1)^(1/3)]])/(688905*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(3080502264331/27005076000 - (76*lm)/9 - 
           (11*lm^2)/6 - (1391*Pi^2)/36 - 
           (15766138*Im[PolyLog[2, (-1)^(1/3)]])/(688905*Sqrt[3]) + 
           4*Zeta[3])), (9431281586988054657931*CF^2*NC)/
        2608654046777856000 - (15*CF^2*lm*NC)/6272 + 
       (95639596186170803321*CF*NM*NC)/140388324043968000 + 
       (5*CF*lm*NM*NC)/18816 - (7687021*CF*NC*NL)/4233600 + 
       (5*CF*lm*NC*NL)/18816 - (18074599182648023711*CF*NC*NH)/
        355357945236294000 + (5*CF*lm*NC*NH)/18816 - 
       (1380301583*CF^2*NC*Pi^2)/1451520 - (1338251*CF*NM*NC*Pi^2)/7560 + 
       (55*CF*NC*NL*Pi^2)/3024 + (1330809445*CF^2*NC*Pi^3)/
        (612220032*Sqrt[3]) + (22385825*CF*NC*NH*Pi^3)/(4251528*Sqrt[3]) - 
       (42186871637*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1020366720*Sqrt[3]) + (25772162*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) + 
       (38023127*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (472392*Sqrt[3]) + (1279190*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) + 
       (38023127*CF^2*NC*Pi*Log[3]^2)/(22674816*Sqrt[3]) + 
       (639595*CF*NC*NH*Pi*Log[3]^2)/(157464*Sqrt[3]) + 
       CF*((-26650826509*CF*NC)/2328480 + CA*(26546935249/4656960 - 11*lm)*
          NC - 18*CF*lm*NC - (229302977*NM*NC)/108108 + 2*lm*NM*NC + 
         (28*NC*NL)/9 + 2*lm*NC*NL + (38713*NC*NH)/45045 + 2*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-572213*CA + 16*(70510*CF + 15386*NM + 21*NL))*
         Log[x]^3)/252 + (15*CF^2*NC*PolyGamma[2, 1])/2 - 
       (37*CF*NM*NC*PolyGamma[2, 1])/9 - (16*CF*NC*NH*PolyGamma[2, 1])/3 + 
       CA*CF*NC*(-9440878302360171545341/5217308093555712000 - 
         (55*lm)/37632 + (51124349*Pi^2)/107520 - (1330809445*Pi^3)/
          (1224440064*Sqrt[3]) + (42186871637*Im[PolyLog[2, (-1)^(1/3)]])/
          (2040733440*Sqrt[3]) - 
         (38023127*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(944784*Sqrt[3]) - 
         (38023127*Pi*Log[3]^2)/(45349632*Sqrt[3]) - (15*PolyGamma[2, 1])/4 - 
         (2341573*Zeta[3])/2016) + (2344933*CF^2*NC*Zeta[3])/1008 + 
       (4183*CF*NM*NC*Zeta[3])/9 + (5*CF*NC*NL*Zeta[3])/3 - 
       (334*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((29108658290821*NM*NC)/
          48697248600 - (253*lm*NM*NC)/504 - (lm^2*NM*NC)/6 + 
         (26321*NC*NL)/15120 - (253*lm*NC*NL)/504 - (lm^2*NC*NL)/6 + 
         (60486399210323*NC*NH)/1577790854640 - (253*lm*NC*NH)/504 - 
         (lm^2*NC*NH)/6 - (491*NM*NC*Pi^2)/2 + (5*NC*NL*Pi^2)/18 - 
         (1279190*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CA*NC*(-173017545026353/294085277640 + (3959*lm)/1008 + 
           (11*lm^2)/12 + (759481*Pi^2)/1344 + 
           (38023127*Im[PolyLog[2, (-1)^(1/3)]])/(2834352*Sqrt[3]) - 
           2*Zeta[3]) + CF*NC*(11195734117734871/9410728884480 - (41*lm)/56 + 
           (3*lm^2)/2 - (2277323*Pi^2)/2016 - 
           (38023127*Im[PolyLog[2, (-1)^(1/3)]])/(1417176*Sqrt[3]) + 
           4*Zeta[3])), (-1237087645615681639*CF^2*NC)/1088844664320000 - 
       (1381201167664216321127*CF*NM*NC)/140388324043968000 + 
       (868673371*CF*NC*NL)/148176000 + (152943961647297193529488559*CF*NC*
         NH)/1508434777393268332608000 + (163558708009*CF^2*NC*Pi^2)/
        558835200 + (268246*CF*NM*NC*Pi^2)/105 - (CF*NC*NL*Pi^2)/18 - 
       (93852211*CF^2*NC*Pi^3)/(22674816*Sqrt[3]) - 
       (168930020*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (1187181918493*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (27776649600*Sqrt[3]) + (269356144*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (93852211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (612360*Sqrt[3]) - (77225152*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (93852211*CF^2*NC*Pi*Log[3]^2)/(29393280*Sqrt[3]) - 
       (4826572*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) + 
       CF*((7421698933*CF*NC)/2116800 + 54*CF*lm*NC + 
         CA*(-7108378093/4233600 + 33*lm)*NC + (3313318565*NM*NC)/108108 - 
         6*lm*NM*NC - (23*NC*NL)/3 - 6*lm*NC*NL - (208261*NC*NH)/68068 - 
         6*lm*NC*NH)*Log[x]^2 + (CF*NC*(-482913*CA + 767446*CF + 
          840*(9028*NM + 3*NL))*Log[x]^3)/630 - 8*CF^2*NC*PolyGamma[2, 1] + 
       (55*CF*NM*NC*PolyGamma[2, 1])/18 + (73*CF*NC*NH*PolyGamma[2, 1])/
        18 - (752711*CF^2*NC*Zeta[3])/1008 - (53813*CF*NM*NC*Zeta[3])/9 - 
       (16*CF*NC*NL*Zeta[3])/3 + 45*CF*NC*NH*Zeta[3] + 
       CA*CF*NC*(1237065858603656539/2177689328640000 - 
         (4956290953*Pi^2)/33868800 + (93852211*Pi^3)/(45349632*Sqrt[3]) + 
         Pi^4/80 - (1187181918493*Im[PolyLog[2, (-1)^(1/3)]])/
          (55553299200*Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (93852211*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1224720*Sqrt[3]) + 
         (93852211*Pi*Log[3]^2)/(58786560*Sqrt[3]) + 4*PolyGamma[2, 1] + 
         (752711*Zeta[3])/2016) + CF*Log[x]*((-467658725140813*NM*NC)/
          194788994400 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (1725523*NC*NL)/264600 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (2119146828289999919*NC*NH)/24623004077511840 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (27088*NM*NC*Pi^2)/9 - (8*NC*NL*Pi^2)/9 + 
         (77225152*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-102376997267579/144027072000 + lm/2 - 3*lm^2 + 
           (246769*Pi^2)/672 + (93852211*Im[PolyLog[2, (-1)^(1/3)]])/
            (1837080*Sqrt[3]) - 8*Zeta[3]) + 
         CA*NC*(99259606070099/288054144000 - (76*lm)/9 - (11*lm^2)/6 - 
           (246769*Pi^2)/1344 - (93852211*Im[PolyLog[2, (-1)^(1/3)]])/
            (3674160*Sqrt[3]) + 4*Zeta[3])), 
      (13271154288958771534191059*CF^2*NC)/614058529368316032000 - 
       (17*CF^2*lm*NC)/10368 + (298488495896649420669199*CF*NM*NC)/
        79583981080155552000 + (17*CF*lm*NM*NC)/93312 - 
       (8337740303*CF*NC*NL)/4000752000 + (17*CF*lm*NC*NL)/93312 - 
       (267609898454451710118586171*CF*NC*NH)/4525304332179804997824000 + 
       (17*CF*lm*NC*NH)/93312 - (407432416177*CF^2*NC*Pi^2)/71850240 - 
       (64494629*CF*NM*NC*Pi^2)/68040 + (71*CF*NC*NL*Pi^2)/3888 + 
       (323663900*CF^2*NC*Pi^3)/(129140163*Sqrt[3]) + 
       (6448947085*CF*NC*NH*Pi^3)/(1033121304*Sqrt[3]) - 
       (1096578581*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
       (14325583078*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (502211745*Sqrt[3]) + (147960640*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (368511262*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) + (9247540*CF^2*NC*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       (184255631*CF*NC*NH*Pi*Log[3]^2)/(38263752*Sqrt[3]) - 
       (CF*NC*(51*CA*(-1765274666509 + 634233600*lm) + 
          34*CF*(5299678078327 + 1556755200*lm) - 
          96*(104*(-3014261947 + 589050*lm)*NM + 
            45*(68068*(31 + 20*lm)*NL + (586983 + 1361360*lm)*NH)))*
         Log[x]^2)/2646483840 - (CF*NC*(-4155323*CA + 8285940*CF + 
          1523904*NM + 480*NL)*Log[x]^3)/324 + (17*CF^2*NC*PolyGamma[2, 1])/
        2 - (128*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (161*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-26547470654962169600071063/2456234117473264128000 - 
         (187*lm)/186624 + (7407912007*Pi^2)/2612736 - (161831950*Pi^3)/
          (129140163*Sqrt[3]) + (1096578581*Im[PolyLog[2, (-1)^(1/3)]])/
          (47829690*Sqrt[3]) - (73980320*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
         (4623770*Pi*Log[3]^2)/(4782969*Sqrt[3]) - (17*PolyGamma[2, 1])/4 - 
         (8349293*Zeta[3])/1296) + (8351741*CF^2*NC*Zeta[3])/648 + 
       (62753*CF*NM*NC*Zeta[3])/27 + (17*CF*NC*NL*Zeta[3])/9 - 
       (124*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((24237898398323971*NM*NC)/
          12990927549600 - (325*lm*NM*NC)/648 - (lm^2*NM*NC)/6 + 
         (3348547*NC*NL)/1587600 - (325*lm*NC*NL)/648 - (lm^2*NC*NL)/6 + 
         (50304016191669287587*NC*NH)/1108035183488032800 - 
         (325*lm*NC*NH)/648 - (lm^2*NC*NH)/6 - (63575*NM*NC*Pi^2)/54 + 
         (17*NC*NL*Pi^2)/54 - (368511262*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CA*NC*(-102492934161788597929/
            122689016856806400 + (5087*lm)/1296 + (11*lm^2)/12 + 
           (461293*Pi^2)/144 + (73980320*Im[PolyLog[2, (-1)^(1/3)]])/
            (4782969*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(103334087302961851123/61344508428403200 - (53*lm)/72 + 
           (3*lm^2)/2 - (1383743*Pi^2)/216 - 
           (147960640*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
           4*Zeta[3])), (-11691438699770394343*CF^2*NC)/1837425371040000 - 
       (20266695258426189258461219*CF*NM*NC)/344863918014007392000 + 
       (17773683199*CF*NC*NL)/2667168000 + (5379812629449540599603099357017*
         CF*NC*NH)/46558593621631923720112224000 + 
       (676938452893*CF^2*NC*Pi^2)/419126400 + (2162163*CF*NM*NC*Pi^2)/140 - 
       (CF*NC*NL*Pi^2)/18 - (6285375307*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (260630405*CF*NC*NH*Pi^3)/(19131876*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (8980049695609*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (187492384800*Sqrt[3]) + (11544469999*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1506635235*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (6285375307*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (37200870*Sqrt[3]) - (29786332*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (6285375307*CF^2*NC*Pi*Log[3]^2)/(1785641760*Sqrt[3]) - 
       (7446583*CF*NC*NH*Pi*Log[3]^2)/(708588*Sqrt[3]) + 
       CF*((30759873601*CF*NC)/1587600 + 60*CF*lm*NC + 
         CA*(-30498792151/3175200 + (110*lm)/3)*NC + (425733296543*NM*NC)/
          2297295 - (20*lm*NM*NC)/3 - (76*NC*NL)/9 - (20*lm*NC*NL)/3 - 
         (30331346*NC*NH)/8729721 - (20*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-10958861*CA + 8*(2604659*CF + 1575*(15586*NM + NL)))*
         Log[x]^3)/2835 - 9*CF^2*NC*PolyGamma[2, 1] + 
       (7*CF*NM*NC*PolyGamma[2, 1])/2 + (9*CF*NC*NH*PolyGamma[2, 1])/2 - 
       (322871*CF^2*NC*Zeta[3])/84 - 34591*CF*NM*NC*Zeta[3] - 
       6*CF*NC*NL*Zeta[3] + (151*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(46765640330382369187/14699402968320000 - 
         (676937815753*Pi^2)/838252800 + (6285375307*Pi^3)/
          (2754990144*Sqrt[3]) + Pi^4/80 - 
         (8980049695609*Im[PolyLog[2, (-1)^(1/3)]])/(374984769600*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (6285375307*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74401740*Sqrt[3]) + (6285375307*Pi*Log[3]^2)/
          (3571283520*Sqrt[3]) + (9*PolyGamma[2, 1])/2 + 
         (322871*Zeta[3])/168) + CF*Log[x]*((-6847913712539657*NM*NC)/
          3752934625440 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (8063141*NC*NL)/1058400 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (1473224840628345757741*NC*NH)/14814840786636290400 + 
         (10*lm*NC*NH)/9 + (lm^2*NC*NH)/3 + (51955*NM*NC*Pi^2)/3 - 
         NC*NL*Pi^2 + (29786332*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (177147*Sqrt[3]) + CF*NC*(-18602536652193953/8749644624000 + lm/2 - 
           3*lm^2 + (8686045*Pi^2)/4536 + 
           (6285375307*Im[PolyLog[2, (-1)^(1/3)]])/(111602610*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(18413160290415713/17499289248000 - (76*lm)/9 - 
           (11*lm^2)/6 - (8686045*Pi^2)/9072 - 
           (6285375307*Im[PolyLog[2, (-1)^(1/3)]])/(223205220*Sqrt[3]) + 
           4*Zeta[3])), (1105113378050190113979711101*CF^2*NC)/
        8289790146472266432000 - (19*CF^2*lm*NC)/16200 + 
       (18612536241450591605263911781*CF*NM*NC)/887033105121778763148000 + 
       (19*CF*lm*NM*NC)/145800 - (12546276727*CF*NC*NL)/5334336000 + 
       (19*CF*lm*NC*NL)/145800 - (314635151822295437157920006509*CF*NC*NH)/
        4655859362163192372011222400 + (19*CF*lm*NC*NH)/145800 - 
       (39852315673*CF^2*NC*Pi^2)/1122660 - (362878219*CF*NM*NC*Pi^2)/
        68040 + (89*CF*NC*NL*Pi^2)/4860 + (11741221807*CF^2*NC*Pi^3)/
        (4132485216*Sqrt[3]) + (7493666215*CF*NC*NH*Pi^3)/
        (1033121304*Sqrt[3]) - (1138890086981*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22599528525*Sqrt[3]) + 
       (82894255321*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3013270470*Sqrt[3]) + (1677317401*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(15943230*Sqrt[3]) + 
       (428209498*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) + (1677317401*CF^2*NC*Pi*Log[3]^2)/
        (765275040*Sqrt[3]) + (214104749*CF*NC*NH*Pi*Log[3]^2)/
        (38263752*Sqrt[3]) - 
       (CF*NC*(323*CA*(-41445408955207 + 2616213600*lm) + 
          4*(323*CF*(20725352206759 + 1070269200*lm) - 
            30*((-33520210102381 + 1280359080*lm)*NM + 
              9*(12932920*(17 + 11*lm)*NL + (61415051 + 142262120*lm)*
                 NH))))*Log[x]^2)/62853991200 - 
       (CF*NC*(-62918603*CA + 40*(3144131*CF + 506424*NM + 33*NL))*
         Log[x]^3)/810 + (19*CF^2*NC*PolyGamma[2, 1])/2 - 
       (145*CF*NM*NC*PolyGamma[2, 1])/27 - (178*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-22103051936572918287449725537/
          331591605858890657280000 - (209*lm)/291600 + (637637733067*Pi^2)/
          35925120 - (11741221807*Pi^3)/(8264970432*Sqrt[3]) + 
         (1138890086981*Im[PolyLog[2, (-1)^(1/3)]])/(45199057050*Sqrt[3]) - 
         (1677317401*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (31886460*Sqrt[3]) - (1677317401*Pi*Log[3]^2)/
          (1530550080*Sqrt[3]) - (19*PolyGamma[2, 1])/4 - 
         (13993967*Zeta[3])/360) + (4664909*CF^2*NC*Zeta[3])/60 + 
       (336769*CF*NM*NC*Zeta[3])/27 + (19*CF*NC*NL*Zeta[3])/9 - 
       (410*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((135334072439665202657*NM*NC)/
          24386569196109120 - (203*lm*NM*NC)/405 - (lm^2*NM*NC)/6 + 
         (1048577*NC*NL)/423360 - (203*lm*NC*NL)/405 - (lm^2*NC*NL)/6 + 
         (8433896558829508446637*NC*NH)/160000280495671936320 - 
         (203*lm*NC*NH)/405 - (lm^2*NC*NH)/6 - (337705*NM*NC*Pi^2)/54 + 
         (19*NC*NL*Pi^2)/54 - (428209498*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CA*NC*(64879476896879392469/10954376505072000 + 
           (1589*lm)/405 + (11*lm^2)/12 + (125817073*Pi^2)/6480 + 
           (1677317401*Im[PolyLog[2, (-1)^(1/3)]])/(95659380*Sqrt[3]) - 
           2*Zeta[3]) + CF*NC*(-453603886594730245709/38340317767752000 - 
           (133*lm)/180 + (3*lm^2)/2 - (125814793*Pi^2)/3240 - 
           (1677317401*Im[PolyLog[2, (-1)^(1/3)]])/(47829690*Sqrt[3]) + 
           4*Zeta[3])), (-8712529907884594412407*CF^2*NC)/
        238130328086784000 - (432300689267173203540730968661*CF*NM*NC)/
        1182710806829038350864000 + (716802637*CF*NC*NL)/96018048 + 
       (1485007036190725135275677291183*CF*NC*NH)/
        11428018434400563094936636800 + (1136068605167*CF^2*NC*Pi^2)/
        121080960 + (277064201*CF*NM*NC*Pi^2)/2835 - (CF*NC*NL*Pi^2)/18 - 
       (7719229835*CF^2*NC*Pi^3)/(1549681956*Sqrt[3]) - 
       (18039985355*CF*NC*NH*Pi^3)/(1162261467*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (805494956957113*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15186883168800*Sqrt[3]) + 
       (583615586572*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (40679151345*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (6175383868*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (33480783*Sqrt[3]) - (8246850448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (1543845967*CF^2*NC*Pi*Log[3]^2)/(401769396*Sqrt[3]) - 
       (515428153*CF*NC*NH*Pi*Log[3]^2)/(43046721*Sqrt[3]) + 
       (CF*NC*(46189*CA*(-89227180169 + 64033200*lm) + 
          8*(46189*CF*(22342692101 + 13097700*lm) - 
            210*((-51188868194333 + 320089770*lm)*NM + 
              77*(62985*(83 + 66*lm)*NL + (2204663 + 4157010*lm)*NH))))*
         Log[x]^2)/73329656400 + 
       (CF*NC*(-60885269*CA + 4*(30121177*CF + 315*(956438*NM + 11*NL)))*
         Log[x]^3)/2835 - 10*CF^2*NC*PolyGamma[2, 1] + 
       (71*CF*NM*NC*PolyGamma[2, 1])/18 + (89*CF*NC*NH*PolyGamma[2, 1])/
        18 - (60817447*CF^2*NC*Zeta[3])/2835 - (1912429*CF*NM*NC*Zeta[3])/
        9 - (20*CF*NC*NL*Zeta[3])/3 + (167*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(8712526937497682750881/476260656173568000 - 
         (262169644397*Pi^2)/55883520 + (7719229835*Pi^3)/
          (3099363912*Sqrt[3]) + Pi^4/80 - (805494956957113*
           Im[PolyLog[2, (-1)^(1/3)]])/(30373766337600*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (3087691934*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33480783*Sqrt[3]) + (1543845967*Pi*Log[3]^2)/(803538792*Sqrt[3]) + 
         5*PolyGamma[2, 1] + (60817447*Zeta[3])/5670) + 
       CF*Log[x]*((114087406467310200917*NM*NC)/2540267624594700 + 
         (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - (8301673*NC*NL)/952560 + 
         (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - (462986820091944640069*NC*NH)/
          4090916262673430190 + (10*lm*NC*NH)/9 + (lm^2*NC*NH)/3 + 
         (956444*NM*NC*Pi^2)/9 - (10*NC*NL*Pi^2)/9 + 
         (8246850448*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(-431618677417980389/78746801616000 + lm/2 - 3*lm^2 + 
           (30386831*Pi^2)/2835 + (6175383868*Im[PolyLog[2, (-1)^(1/3)]])/
            (100442349*Sqrt[3]) - 8*Zeta[3]) + 
         CA*NC*(429914282754869669/157493603232000 - (76*lm)/9 - 
           (11*lm^2)/6 - (30386831*Pi^2)/5670 - 
           (3087691934*Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) + 
           4*Zeta[3])), (18772678005881945710169942797515463*CF^2*NC)/
        21992979054393852289424640000 - (21*CF^2*lm*NC)/24200 + 
       (288893496044904970861055127877*CF*NM*NC)/2365421613658076701728000 + 
       (7*CF*lm*NM*NC)/72600 - (2174001437191*CF*NC*NL)/829870272000 + 
       (7*CF*lm*NC*NL)/72600 - (95753622254599831985650248980183*CF*NC*NH)/
        1257082027784061940443030048000 + (7*CF*lm*NC*NH)/72600 - 
       (65984593299283*CF^2*NC*Pi^2)/285405120 - (7856440621*CF*NM*NC*Pi^2)/
        249480 + (109*CF*NC*NL*Pi^2)/5940 + (121892695295*CF^2*NC*Pi^3)/
        (38354628411*Sqrt[3]) + (77133964985*CF*NC*NH*Pi^3)/
        (9298091736*Sqrt[3]) - (811597559346683*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(14766531938235*Sqrt[3]) + 
       (303262542683*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (11622614670*Sqrt[3]) + (55722374992*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(473513931*Sqrt[3]) + 
       (4407655142*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) + (3482648437*CF^2*NC*Pi*Log[3]^2)/
        (1420541793*Sqrt[3]) + (2203827571*CF*NC*NH*Pi*Log[3]^2)/
        (344373768*Sqrt[3]) - 
       (CF*NC*(10944*CA*(-4868636775242 + 51476425*lm) + 
          19*CF*(5608789542587981 + 48518870400*lm) - 
          220*((-65977786931443 + 465585120*lm)*NM + 
            385*(50388*(37 + 24*lm)*NL + (522073 + 1209312*lm)*NH)))*
         Log[x]^2)/38410772400 - (CF*NC*(-489368405*CA + 
          176*(5560429*CF + 801745*NM + 10*NL))*Log[x]^3)/990 + 
       (21*CF^2*NC*PolyGamma[2, 1])/2 - 6*CF*NM*NC*PolyGamma[2, 1] - 
       (65*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-103250365373019977674613455970369773/
          241922769598332375183671040000 - (7*lm)/13200 + 
         (126893469413*Pi^2)/1097712 - (121892695295*Pi^3)/
          (76709256822*Sqrt[3]) + (811597559346683*
           Im[PolyLog[2, (-1)^(1/3)]])/(29533063876470*Sqrt[3]) - 
         (27861187496*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (473513931*Sqrt[3]) - (3482648437*Pi*Log[3]^2)/
          (2841083586*Sqrt[3]) - (21*PolyGamma[2, 1])/4 - 
         (97888393*Zeta[3])/396) + (97889317*CF^2*NC*Zeta[3])/198 + 
       71231*CF*NM*NC*Zeta[3] + (7*CF*NC*NL*Zeta[3])/3 - 
       (448*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((486819467538865729013*NM*NC)/
          40644281993515200 - (248*lm*NM*NC)/495 - (lm^2*NM*NC)/6 + 
         (3405575*NC*NL)/1197504 - (248*lm*NC*NL)/495 - (lm^2*NC*NL)/6 + 
         (61970516842134034517029*NC*NH)/1028573231757891019200 - 
         (248*lm*NC*NH)/495 - (lm^2*NC*NH)/6 - (641429*NM*NC*Pi^2)/18 + 
         (7*NC*NL*Pi^2)/18 - (4407655142*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CA*NC*(604303801072088090300814941/
            6581728989918914832000 + (353*lm)/90 + (11*lm^2)/12 + 
           (24467753*Pi^2)/198 + (27861187496*Im[PolyLog[2, (-1)^(1/3)]])/
            (1420541793*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-604254058361228332395829763/3290864494959457416000 - 
           (163*lm)/220 + (3*lm^2)/2 - (8155892*Pi^2)/33 - 
           (55722374992*Im[PolyLog[2, (-1)^(1/3)]])/(1420541793*Sqrt[3]) + 
           4*Zeta[3])), (-571641291421723119318810223*CF^2*NC)/
        2614849600138953408000 - (5583620407674685374750118660001*CF*NM*NC)/
        2365421613658076701728000 + (24010979218757*CF*NC*NL)/
        2904545952000 + (19898499025168750678933605234429374317*CF*NC*NH)/
        137654253288438134664333119346144000 + (379067607962611*CF^2*NC*Pi^2)/
        6659452800 + (7280849551*CF*NM*NC*Pi^2)/11340 - 
       (CF*NC*NL*Pi^2)/18 - (2207095956887*CF^2*NC*Pi^3)/
        (409116036384*Sqrt[3]) - (730732792195*CF*NC*NH*Pi^3)/
        (41841412812*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (320685066962980003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5512838590274400*Sqrt[3]) + (7910294803553*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (2207095956887*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (11048658390*Sqrt[3]) - (83512319108*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) - 
       (2207095956887*CF^2*NC*Pi*Log[3]^2)/(530335602720*Sqrt[3]) - 
       (20878079777*CF*NC*NH*Pi*Log[3]^2)/(1549681956*Sqrt[3]) + 
       CF*((131214382678789*CF*NC)/192099600 + 72*CF*lm*NC + 
         CA*(-131176476495859/384199200 + 44*lm)*NC + 
         (336294736512809*NM*NC)/43648605 - 8*lm*NM*NC - 10*NC*NL - 
         8*lm*NC*NL - (1440235306*NC*NH)/334639305 - 8*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-3949524763*CA + 8*(985306522*CF + 
            10395*(1024665*NM + 2*NL)))*Log[x]^3)/31185 - 
       11*CF^2*NC*PolyGamma[2, 1] + (79*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (97*CF*NC*NH*PolyGamma[2, 1])/18 - (15794857151*CF^2*NC*Zeta[3])/
        124740 - (12295487*CF*NM*NC*Zeta[3])/9 - (22*CF*NC*NL*Zeta[3])/3 + 
       61*CF*NC*NH*Zeta[3] + CA*CF*NC*(1143282529402482809767511123/
          10459398400555813632000 - (1137202804254373*Pi^2)/39956716800 + 
         (2207095956887*Pi^3)/(818232072768*Sqrt[3]) + Pi^4/80 - 
         (320685066962980003*Im[PolyLog[2, (-1)^(1/3)]])/(11025677180548800*
           Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (2207095956887*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (22097316780*Sqrt[3]) + (2207095956887*Pi*Log[3]^2)/
          (1060671205440*Sqrt[3]) + (11*PolyGamma[2, 1])/2 + 
         (15794857151*Zeta[3])/249480) + CF*Log[x]*
        ((11633615997360355138781*NM*NC)/20322140996757600 + 
         (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - (205622009*NC*NL)/20956320 + 
         (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - (436122968371073459021224807*NC*
           NH)/3427926009479523399687840 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (6147997*NM*NC*Pi^2)/9 - (11*NC*NL*Pi^2)/9 + 
         (83512319108*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(-817384986196954618369/
            314435978852688000 + lm/2 - 3*lm^2 + (15792735311*Pi^2)/249480 + 
           (2207095956887*Im[PolyLog[2, (-1)^(1/3)]])/(33145975170*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(810579220173261169249/628871957705376000 - 
           (76*lm)/9 - (11*lm^2)/6 - (15792735311*Pi^2)/498960 - 
           (2207095956887*Im[PolyLog[2, (-1)^(1/3)]])/(66291950340*Sqrt[3]) + 
           4*Zeta[3])), (8435319185976749796369746822905411923997*CF^2*NC)/
        1493413449007465585246319697024000 - (23*CF^2*lm*NC)/34848 + 
       (4256479554517097769148782289674731*CF*NM*NC)/
        5756016954675563845984915200 + (23*CF*lm*NM*NC)/313632 - 
       (50316679953851*CF*NC*NL)/17427275712000 + (23*CF*lm*NC*NL)/313632 - 
       (922657079935349238011889552479478917*CF*NC*NH)/
        10867441049087221157710509422064000 + (23*CF*lm*NC*NH)/313632 - 
       (2662268459038477*CF^2*NC*Pi^2)/1712430720 - 
       (144978652039*CF*NM*NC*Pi^2)/748440 + (131*CF*NC*NL*Pi^2)/7128 + 
       (7062533480555*CF^2*NC*Pi^3)/(2008387814976*Sqrt[3]) + 
       (2351369083385*CF*NC*NH*Pi^3)/(251048476872*Sqrt[3]) - 
       (299007745816817*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5020969537440*Sqrt[3]) + (53395521054971*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2196674172630*Sqrt[3]) + 
       (201786670873*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1549681956*Sqrt[3]) + (134363947622*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) + 
       (201786670873*CF^2*NC*Pi*Log[3]^2)/(74384733888*Sqrt[3]) + 
       (67181973811*CF*NC*NH*Pi*Log[3]^2)/(9298091736*Sqrt[3]) + 
       CF*((-20474171336258273*CF*NC)/1097450640 + 
         CA*(61422302388488201/6584703840 - (143*lm)/9)*NC - 26*CF*lm*NC - 
         (1866877594297031*NM*NC)/803134332 + (26*lm*NM*NC)/9 + 
         (40*NC*NL)/9 + (26*lm*NC*NL)/9 + (158047699*NC*NH)/126810684 + 
         (26*lm*NC*NH)/9)*Log[x]^2 - 
       (4*CF*NC*(-242497472*CA + 484986279*CF + 63477535*NM + 143*NL)*
         Log[x]^3)/297 + (23*CF^2*NC*PolyGamma[2, 1])/2 - 
       (179*CF*NM*NC*PolyGamma[2, 1])/27 - (212*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-1687065567070391514597142712549425215233/
          597365379602986234098527878809600 - (23*lm)/57024 + 
         (42258230533331*Pi^2)/54362880 - (7062533480555*Pi^3)/
          (4016775629952*Sqrt[3]) + (299007745816817*
           Im[PolyLog[2, (-1)^(1/3)]])/(10041939074880*Sqrt[3]) - 
         (201786670873*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3099363912*Sqrt[3]) - (201786670873*Pi*Log[3]^2)/
          (148769467776*Sqrt[3]) - (23*PolyGamma[2, 1])/4 - 
         (7760113057*Zeta[3])/4752) + (7760125201*CF^2*NC*Zeta[3])/2376 + 
       (11540315*CF*NM*NC*Zeta[3])/27 + (23*CF*NC*NL*Zeta[3])/9 - 
       54*CF*NC*NH*Zeta[3] + CF*Log[x]*((-1481129253096210031697161*NM*NC)/
          64502475523708622400 - (595*lm*NM*NC)/1188 - (lm^2*NM*NC)/6 + 
         (403698833*NC*NL)/125737920 - (595*lm*NC*NL)/1188 - 
         (lm^2*NC*NL)/6 + (73600383153641163093542273*NC*NH)/
          1082502950361954757796160 - (595*lm*NC*NH)/1188 - 
         (lm^2*NC*NH)/6 - (11541479*NM*NC*Pi^2)/54 + (23*NC*NL*Pi^2)/54 - 
         (134363947622*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CA*NC*(478434629021524093398149297101/
            534600937206163857229200 + (847*lm)/216 + (11*lm^2)/12 + 
           (7759884575*Pi^2)/9504 + (201786670873*Im[PolyLog[2, (-1)^(1/3)]])/
            (9298091736*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-1913721593089873659204941652991/1069201874412327714458400 - 
           (49*lm)/66 + (3*lm^2)/2 - (7759880527*Pi^2)/4752 - 
           (201786670873*Im[PolyLog[2, (-1)^(1/3)]])/(4649045868*Sqrt[3]) + 
           4*Zeta[3])), (-14158418842049395348636897249*CF^2*NC)/
        10459398400555813632000 - (45290666473631572392138206008860841*CF*NM*
         NC)/2878008477337781922992457600 + (3017970807529*CF*NC*NL)/
        332812557000 + (949174648718464354081315421873069691349*CF*NC*NH)/
        5956193651903573134514413817862000000 + 
       (595893116393269*CF^2*NC*Pi^2)/1664863200 + 
       (4304761859*CF*NM*NC*Pi^2)/990 - (CF*NC*NL*Pi^2)/18 - 
       (527712448861*CF^2*NC*Pi^3)/(90914674752*Sqrt[3]) - 
       (1830872948485*CF*NC*NH*Pi^3)/(94143178827*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (174457410482445239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2756419295137200*Sqrt[3]) + 
       (1065379495087414*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (36245123848395*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (527712448861*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2455257420*Sqrt[3]) - (836970490736*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) - 
       (527712448861*CF^2*NC*Pi*Log[3]^2)/(117852356160*Sqrt[3]) - 
       (52310655671*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) + 
       CF*((206270348453821*CF*NC)/48024900 + 78*CF*lm*NC + 
         CA*(-8594170099709/4002075 + (143*lm)/3)*NC + 
         (104766708178475723*NM*NC)/2007835830 - (26*lm*NM*NC)/3 - 
         (97*NC*NL)/9 - (26*lm*NC*NL)/3 - (3643755277*NC*NH)/772244550 - 
         (26*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-97276299457*CA + 194475620474*CF + 
          55440*(40949092*NM + 13*NL))*Log[x]^3)/124740 - 
       12*CF^2*NC*PolyGamma[2, 1] + (29*CF*NM*NC*PolyGamma[2, 1])/6 + 
       (35*CF*NC*NH*PolyGamma[2, 1])/6 - (194545599667*CF^2*NC*Zeta[3])/
        249480 - (27299215*CF*NM*NC*Zeta[3])/3 - 8*CF*NC*NL*Zeta[3] + 
       (199*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*(14158418752869337216927976257/
          20918796801111627264000 - (5363038035302581*Pi^2)/29967537600 + 
         (527712448861*Pi^3)/(181829349504*Sqrt[3]) + Pi^4/80 - 
         (174457410482445239*Im[PolyLog[2, (-1)^(1/3)]])/(5512838590274400*
           Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (527712448861*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4910514840*Sqrt[3]) + (527712448861*Pi*Log[3]^2)/
          (235704712320*Sqrt[3]) + 6*PolyGamma[2, 1] + (194545599667*Zeta[3])/
          498960) + CF*Log[x]*((4789620735231557345821963*NM*NC)/
          895867715607064200 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (209555729*NC*NL)/19209960 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (10499217928058273286712770533*NC*NH)/74161860782008919704785000 + 
         (10*lm*NC*NH)/9 + (lm^2*NC*NH)/3 + 4549900*NM*NC*Pi^2 - 
         (4*NC*NL*Pi^2)/3 + (836970490736*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*(9387488663552795654233/
            69874661967264000 + lm/2 - 3*lm^2 + (194540965807*Pi^2)/498960 + 
           (527712448861*Im[PolyLog[2, (-1)^(1/3)]])/(7365772260*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(-9389001089689243348393/139749323934528000 - 
           (76*lm)/9 - (11*lm^2)/6 - (194540965807*Pi^2)/997920 - 
           (527712448861*Im[PolyLog[2, (-1)^(1/3)]])/(14731544520*Sqrt[3]) + 
           4*Zeta[3])), (1220760884761173518330677488530628843511427*CF^2*NC)/
        31768977006158813358876255373056000 - (25*CF^2*lm*NC)/48672 + 
       (1389347069639619810983966314847314393*CF*NM*NC)/
        299792549722685616978381000000 + (25*CF*lm*NM*NC)/438048 - 
       (817625476519723*CF*NC*NL)/259178444388864 + (25*CF*lm*NC*NL)/
        438048 - (2074154813083318630385863387703007392291*CF*NC*NH)/
        22123004992784700213910679894916000000 + (25*CF*lm*NC*NH)/438048 - 
       (10859238672343433*CF^2*NC*Pi^2)/1011890880 - 
       (11992630968821*CF*NM*NC*Pi^2)/9729720 + (155*CF*NC*NL*Pi^2)/8424 + 
       (56636164104625*CF^2*NC*Pi^3)/(14686335897012*Sqrt[3]) + 
       (7879910502485*CF*NC*NH*Pi^3)/(753145430616*Sqrt[3]) - 
       (2358065489381246003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (36752555582272530*Sqrt[3]) + (1608093181426357*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(72490247696790*Sqrt[3]) + 
       (6472704469100*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (45328197213*Sqrt[3]) + (450280600142*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) + 
       (1618176117275*CF^2*NC*Pi*Log[3]^2)/(543938366556*Sqrt[3]) + 
       (225140300071*CF*NC*NH*Pi*Log[3]^2)/(27894275208*Sqrt[3]) - 
       (CF*NC*(230*CA*(-438441725754534083 + 116512676280*lm) + 
          115*CF*(1753767845559363617 + 381314213280*lm) - 
          338*(9*(-7614806288726687 + 1601692400*lm)*NM + 
            514829700*(43 + 28*lm)*NL + (6212452331 + 14415231600*lm)*NH))*
         Log[x]^2)/1566111947400 - (CF*NC*(-31212796587*CA + 62425407902*CF + 
          7490845648*NM + 2912*NL)*Log[x]^3)/1404 + 
       (25*CF^2*NC*PolyGamma[2, 1])/2 - (196*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (229*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-110978280513888543787655306994660167562937/
          5776177637483420610704773704192000 - (275*lm)/876096 + 
         (10859238710394953*Pi^2)/2023781760 - (56636164104625*Pi^3)/
          (29372671794024*Sqrt[3]) + (2358065489381246003*
           Im[PolyLog[2, (-1)^(1/3)]])/(73505111164545060*Sqrt[3]) - 
         (3236352234550*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (45328197213*Sqrt[3]) - (1618176117275*Pi*Log[3]^2)/
          (1087876733112*Sqrt[3]) - (25*PolyGamma[2, 1])/4 - 
         (100041415*Zeta[3])/9) + (200082880*CF^2*NC*Zeta[3])/9 + 
       (72026203*CF*NM*NC*Zeta[3])/27 + (25*CF*NC*NL*Zeta[3])/9 - 
       (524*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((-11191934907169751210237537*NM*NC)/17720460308711160000 - 
         (703*lm*NM*NC)/1404 - (lm^2*NM*NC)/6 + (64318606241*NC*NL)/
          17980522560 - (703*lm*NC*NL)/1404 - (lm^2*NC*NL)/6 + 
         (585564026791961955267276552391*NC*NH)/
          7712833521328927649297640000 - (703*lm*NC*NH)/1404 - 
         (lm^2*NC*NH)/6 - (72027481*NM*NC*Pi^2)/54 + (25*NC*NL*Pi^2)/54 - 
         (450280600142*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CA*NC*(127637794895084006147588729717539/
            16541701726445268441868800 + (11009*lm)/2808 + (11*lm^2)/12 + 
           (10404258235*Pi^2)/1872 + (3236352234550*Im[PolyLog[2, (-1)^
                (1/3)]])/(135984591639*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-1404014238663981623071664146859849/
            90979359495448976430278400 - (29*lm)/39 + (3*lm^2)/2 - 
           (31212772105*Pi^2)/2808 - (6472704469100*Im[PolyLog[2, (-1)^
                (1/3)]])/(135984591639*Sqrt[3]) + 4*Zeta[3])), 
      (-1254930976475510748175080322068467629*CF^2*NC)/
        145183206571081452267766272000 - 
       (387580682114654268834585224108344419557*CF*NM*NC)/
        3597510596672227403740572000000 + (53290677158054729*CF*NC*NL)/
        5399550924768000 + (242991055738358681272651231692006543579367*CF*NC*
         NH)/1393749314545436113476372833379708000000 + 
       (1806718791167570677*CF^2*NC*Pi^2)/779155977600 + 
       (753269498897*CF*NM*NC*Pi^2)/24948 - (CF*NC*NL*Pi^2)/18 - 
       (8026811781667363*CF^2*NC*Pi^3)/(1292397558937056*Sqrt[3]) - 
       (72760055686325*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (15485856622421048596781*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(226395742386798784800*Sqrt[3]) + 
       (12288050751590843*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (326206114635555*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (8026811781667363*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (34902711854010*Sqrt[3]) - (8315434935580*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) - 
       (8026811781667363*CF^2*NC*Pi*Log[3]^2)/(1675330168992480*Sqrt[3]) - 
       (2078858733895*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) + 
       CF*((301119717551975657*CF*NC)/10821610800 + 84*CF*lm*NC + 
         CA*(-301117226352845237/21643221600 + (154*lm)/3)*NC + 
         (1818712657025974019*NM*NC)/5019589575 - (28*lm*NM*NC)/3 - 
         (104*NC*NL)/9 - (28*lm*NC*NL)/3 - (11042158514*NC*NH)/
          2151252675 - (28*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-2014326031639*CA + 8*(503545618306*CF + 
            45045*(140295457*NM + 7*NL)))*Log[x]^3)/405405 - 
       13*CF^2*NC*PolyGamma[2, 1] + (95*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (113*CF*NC*NH*PolyGamma[2, 1])/18 - (8057255281373*CF^2*NC*Zeta[3])/
        1621620 - (561181243*CF*NM*NC*Zeta[3])/9 - (26*CF*NC*NL*Zeta[3])/
        3 + (215*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*
        (313732743856712893339903271691071683/72591603285540726133883136000 - 
         (1806718790630003647*Pi^2)/1558311955200 + (8026811781667363*Pi^3)/
          (2584795117874112*Sqrt[3]) + Pi^4/80 - 
         (15485856622421048596781*Im[PolyLog[2, (-1)^(1/3)]])/
          (452791484773597569600*Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (8026811781667363*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (69805423708020*Sqrt[3]) + (8026811781667363*Pi*Log[3]^2)/
          (3350660337984960*Sqrt[3]) + (13*PolyGamma[2, 1])/2 + 
         (8057255281373*Zeta[3])/3243240) + CF*Log[x]*
        ((12191955673125727028156455639*NM*NC)/268760314682119260000 + 
         (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - (35977343141*NC*NL)/
          2996753760 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (37908374415382889884351317071*NC*NH)/242711544377483737215660000 + 
         (10*lm*NC*NH)/9 + (lm^2*NC*NH)/3 + (280590923*NM*NC*Pi^2)/9 - 
         (13*NC*NL*Pi^2)/9 + (8315434935580*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CF*NC*(2179336691119395143888980397/1311470706766120275375 + lm/2 - 
           3*lm^2 + (8057222627213*Pi^2)/3243240 + 
           (8026811781667363*Im[PolyLog[2, (-1)^(1/3)]])/(104708135562030*
             Sqrt[3]) - 8*Zeta[3]) + CA*NC*(-278958730030655431062773001571/
            335736500932126790496000 - (76*lm)/9 - (11*lm^2)/6 - 
           (8057222627213*Pi^2)/6486480 - (8026811781667363*
             Im[PolyLog[2, (-1)^(1/3)]])/(209416271124060*Sqrt[3]) + 
           4*Zeta[3])), (965322761237629689476217031464099105371003587417*
         CF^2*NC)/3607642670183386633282842391823741952000 - 
       (27*CF^2*lm*NC)/66248 + (193674677209700578027020970465375954811*CF*
         NM*NC)/6475519074010009326733029600000 + (3*CF*lm*NM*NC)/66248 - 
       (4106121836154133*CF*NC*NL)/1199900205504000 + 
       (3*CF*lm*NC*NL)/66248 - (143172799918095402427880481500001233028509*
         CF*NC*NH)/1393749314545436113476372833379708000000 + 
       (3*CF*lm*NC*NH)/66248 - (357525010881681491*CF^2*NC*Pi^2)/
        4722157440 - (26165851753259*CF*NM*NC*Pi^2)/3243240 + 
       (181*CF*NC*NL*Pi^2)/9828 + (37935493821445*CF^2*NC*Pi^3)/
        (9037745167392*Sqrt[3]) + (78514052459885*CF*NC*NH*Pi^3)/
        (6778308875544*Sqrt[3]) - (34904048196398681*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(507431733877530*Sqrt[3]) + 
       (12882253197050653*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (652412229271110*Sqrt[3]) + (7587098764289*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(48814981614*Sqrt[3]) + 
       (4486517283422*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) + (7587098764289*CF^2*NC*Pi*Log[3]^2)/
        (2343119117472*Sqrt[3]) + (2243258641711*CF*NC*NH*Pi*Log[3]^2)/
        (251048476872*Sqrt[3]) + CF*((-13551293325220121831*CF*NC)/
          14915351880 + CA*(83001664842879085993/182713060530 - (55*lm)/3)*
          NC - 30*CF*lm*NC - (35342928216366209*NM*NC)/365061060 + 
         (10*lm*NM*NC)/3 + (46*NC*NL)/9 + (10*lm*NC*NL)/3 + 
         (86420704759*NC*NH)/60235074900 + (10*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-253991771913*CA + 56*(9071130379*CF + 1005660747*NM + 
            65*NL))*Log[x]^3)/1638 + (27*CF^2*NC*PolyGamma[2, 1])/2 - 
       (71*CF*NM*NC*PolyGamma[2, 1])/9 - (82*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-120665348246421629937668014192924740624779225369/
          901910667545846658320710597955935488000 - (33*lm)/132496 + 
         (44690626382361031*Pi^2)/1180539360 - (37935493821445*Pi^3)/
          (18075490334784*Sqrt[3]) + (34904048196398681*
           Im[PolyLog[2, (-1)^(1/3)]])/(1014863467755060*Sqrt[3]) - 
         (7587098764289*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (97629963228*Sqrt[3]) - (7587098764289*Pi*Log[3]^2)/
          (4686238234944*Sqrt[3]) - (27*PolyGamma[2, 1])/4 - 
         (507983859235*Zeta[3])/6552) + (507983878891*CF^2*NC*Zeta[3])/3276 + 
       (154716617*CF*NM*NC*Zeta[3])/9 + 3*CF*NC*NL*Zeta[3] - 
       (562*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((-197091684878248082480481023*NM*NC)/29319307056231192000 - 
         (410*lm*NM*NC)/819 - (lm^2*NM*NC)/6 + (1125475189*NC*NL)/
          285405120 - (410*lm*NC*NL)/819 - (lm^2*NC*NL)/6 + 
         (5832581951332213508873437273987*NC*NH)/
          69415501691960348843678760000 - (410*lm*NC*NH)/819 - 
         (lm^2*NC*NH)/6 - (154717081*NM*NC*Pi^2)/18 + (NC*NL*Pi^2)/2 - 
         (4486517283422*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CA*NC*
          (3050093838227336307514918844804485691/
            48128081173092508531617273600 + (6421*lm)/1638 + (11*lm^2)/12 + 
           (507983489317*Pi^2)/13104 + (7587098764289*
             Im[PolyLog[2, (-1)^(1/3)]])/(292889889684*Sqrt[3]) - 
           2*Zeta[3]) + CF*NC*(-42701307919075849317640868790938680033/
            336896568211647559721320915200 - (271*lm)/364 + (3*lm^2)/2 - 
           (507983482765*Pi^2)/6552 - (7587098764289*Im[PolyLog[2, (-1)^
                (1/3)]])/(146444944842*Sqrt[3]) + 4*Zeta[3])), 
      (-49363391623612831068304440491477057113*CF^2*NC)/
        871099239426488713606597632000 - 
       (12210274978883505862517340298376923965283*CF*NM*NC)/
        16188797685025023316832574000000 + (53502220916122679*CF*NC*NL)/
        5013868715856000 + (1932382509869290246063073287418898528229419269*CF*
         NC*NH)/10197645609734592411472577109989309523600000 + 
       (25507959100648121953*CF^2*NC*Pi^2)/1655706452400 + 
       (86792316146951*CF*NM*NC*Pi^2)/405405 - (CF*NC*NL*Pi^2)/18 - 
       (12822202237069477*CF^2*NC*Pi^3)/(1938596338405584*Sqrt[3]) - 
       (59794539973805*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (49921924769551111019623*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(679187227160396354400*Sqrt[3]) + 
       (590296417557925244*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12722038470786645*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (1831743176724211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7479152540145*Sqrt[3]) - (27334646845168*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (1831743176724211*CF^2*NC*Pi*Log[3]^2)/(358999321926960*Sqrt[3]) - 
       (1708415427823*CF*NC*NH*Pi*Log[3]^2)/(94143178827*Sqrt[3]) + 
       CF*((31755939033980999*CF*NC)/171771600 + 90*CF*lm*NC + 
         CA*(-95267690001011897/1030629600 + 55*lm)*NC + 
         (12895602278186476183*NM*NC)/5019589575 - 10*lm*NM*NC - 
         (37*NC*NL)/3 - 10*lm*NC*NL - (161503790213*NC*NH)/29113619535 - 
         10*lm*NC*NH)*Log[x]^2 + (CF*NC*(-26401703696243*CA + 
          52802754239986*CF + 1081080*(655987222*NM + 5*NL))*Log[x]^3)/
        810810 - 14*CF^2*NC*PolyGamma[2, 1] + (103*CF*NM*NC*PolyGamma[2, 1])/
        18 + (121*CF*NC*NH*PolyGamma[2, 1])/18 - 
       (26401677598819*CF^2*NC*Zeta[3])/810810 - 
       (3935922701*CF*NM*NC*Zeta[3])/9 - (28*CF*NC*NL*Zeta[3])/3 + 
       77*CF*NC*NH*Zeta[3] + CA*CF*NC*
        (49363391618214058590109637233635179527/
          1742198478852977427213195264000 - (6001872729334065491*Pi^2)/
          779155977600 + (12822202237069477*Pi^3)/(3877192676811168*
           Sqrt[3]) + Pi^4/80 - (49921924769551111019623*
           Im[PolyLog[2, (-1)^(1/3)]])/(1358374454320792708800*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + (1831743176724211*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14958305080290*Sqrt[3]) + 
         (1831743176724211*Pi*Log[3]^2)/(717998643853920*Sqrt[3]) + 
         7*PolyGamma[2, 1] + (26401677598819*Zeta[3])/1621620) + 
       CF*Log[x]*((5326591271797365964638558649*NM*NC)/
          14397874000827817500 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (36459356321*NC*NL)/2782699920 + (10*lm*NC*NL)/9 + 
         (lm^2*NC*NL)/3 - (187233555601190184965935206834653*NC*NH)/
          1094595692305099750828759446750 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (1967961676*NM*NC*Pi^2)/9 - (14*NC*NL*Pi^2)/9 + 
         (27334646845168*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CF*NC*(15518235268760835733170668055091/
            1007209502796380371488000 + lm/2 - 3*lm^2 + (26401660005529*Pi^2)/
            1621620 + (1831743176724211*Im[PolyLog[2, (-1)^(1/3)]])/
            (22437457620435*Sqrt[3]) - 8*Zeta[3]) + 
         CA*NC*(-15518257070666107676535389238121/2014419005592760742976000 - 
           (76*lm)/9 - (11*lm^2)/6 - (26401660005529*Pi^2)/3243240 - 
           (1831743176724211*Im[PolyLog[2, (-1)^(1/3)]])/(44874915240870*
             Sqrt[3]) + 4*Zeta[3])), 
      (202272062190318611587321577108138887966834663158317*CF^2*NC)/
        106431765838015121392741198185359520000000 - (29*CF^2*lm*NC)/88200 + 
       (175826788861413233056953054675764445058745971*CF*NM*NC)/
        888364320165169410767016706393500000 + (29*CF*lm*NM*NC)/793800 - 
       (1553833941721187149*CF*NC*NL)/421164972131904000 + 
       (29*CF*lm*NC*NL)/793800 - 
       (1005973490063742315894303338157670985459736829*CF*NC*NH)/
        8997922596824640363064038626461155462000000 + 
       (29*CF*lm*NC*NH)/793800 - (279994266547818689*CF^2*NC*Pi^2)/
        514594080 - (47839981884509*CF*NM*NC*Pi^2)/884520 + 
       (209*CF*NC*NL*Pi^2)/11340 + (11538960484093*CF^2*NC*Pi^3)/
        (2541865828329*Sqrt[3]) + (776341008915395*CF*NC*NH*Pi^3)/
        (61004779879896*Sqrt[3]) - (4670580095401235789*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(63610192353933225*Sqrt[3]) + 
       (259754910922719635*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15266446164943974*Sqrt[3]) + (26374766820784*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(156905298045*Sqrt[3]) + 
       (44362343366594*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) + (1648422926299*CF^2*NC*Pi*Log[3]^2)/
        (470715894135*Sqrt[3]) + (22181171683297*CF*NC*NH*Pi*Log[3]^2)/
        (2259436291848*Sqrt[3]) + CF*((-9176812182289817897647*CF*NC)/
          1405485081000 + CA*(2294203017781615387123/702742540500 - 
           (176*lm)/9)*NC - 32*CF*lm*NC - (261631449787988498147*NM*NC)/
          403111655100 + (32*lm*NM*NC)/9 + (49*NC*NL)/9 + 
         (32*lm*NC*NL)/9 + (471107126561*NC*NH)/308261853900 + 
         (32*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-1043083623234*CA + 5*(417233418081*CF + 43003883132*NM + 
            448*NL))*Log[x]^3)/945 + (29*CF^2*NC*PolyGamma[2, 1])/2 - 
       (230*CF*NM*NC*PolyGamma[2, 1])/27 - (263*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-8899970770975544351873867845339631317547482193650573/
          9365995393745330682561225440311637760000000 - (319*lm)/1587600 + 
         (197643011694421597*Pi^2)/726485760 - (11538960484093*Pi^3)/
          (5083731656658*Sqrt[3]) + (4670580095401235789*
           Im[PolyLog[2, (-1)^(1/3)]])/(127220384707866450*Sqrt[3]) - 
         (13187383410392*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (156905298045*Sqrt[3]) - (1648422926299*Pi*Log[3]^2)/
          (941431788270*Sqrt[3]) - (29*PolyGamma[2, 1])/4 - 
         (1043083721137*Zeta[3])/1890) + (1043083727227*CF^2*NC*Zeta[3])/
        945 + (3071704571*CF*NM*NC*Zeta[3])/27 + (29*CF*NC*NL*Zeta[3])/9 - 
       (200*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-726531015511186262450757328681331*NM*NC)/
          12205480930973764073640000 - (473*lm*NM*NC)/945 - 
         (lm^2*NM*NC)/6 + (719538439547*NC*NL)/166961995200 - 
         (473*lm*NC*NL)/945 - (lm^2*NC*NL)/6 + 
         (407472540272413203786584693065823*NC*NH)/
          4415175901734856137796676760000 - (473*lm*NC*NH)/945 - 
         (lm^2*NC*NH)/6 - (3071706077*NM*NC*Pi^2)/54 + 
         (29*NC*NL*Pi^2)/54 - (44362343366594*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CA*NC*(29698798127367637331192848128939527765983/
            58309021421246693028690158400000 + (3704*lm)/945 + (11*lm^2)/12 + 
           (2086167213029*Pi^2)/7560 + (13187383410392*
             Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) - 
           2*Zeta[3]) + CF*NC*(-2121342685929056528063721300232099122197/
            2082465050758810465310362800000 - (313*lm)/420 + (3*lm^2)/2 - 
           (2086167208969*Pi^2)/3780 - (26374766820784*
             Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) + 
           4*Zeta[3])), (-2482854373020446051451701702439653655799*CF^2*NC)/
        6533244295698665352049482240000 - 
       (12749288292170970463415877766656343074774910691*CF*NM*NC)/
        2368971520440451762045377883716000000 + (2147421885961769*CF*NC*NL)/
        187184432058624 + 
       (5599501284799585910329505318598424319236102271938079*CF*NC*NH)/
        27341825432364291827716159021532236801581084000000 + 
       (277073062013661987413*CF^2*NC*Pi^2)/2649130323840 + 
       (167044862773043*CF*NM*NC*Pi^2)/108108 - (CF*NC*NL*Pi^2)/18 - 
       (81595161787869383*CF^2*NC*Pi^3)/(11631578030433504*Sqrt[3]) - 
       (2343639723637835*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (32028096941882667260849*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(407512336296237812640*Sqrt[3]) + 
       (6360811121607106481*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (114498346237079805*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (81595161787869383*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(314124406686090*Sqrt[3]) - 
       (267844539844324*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) - (81595161787869383*CF^2*NC*Pi*Log[3]^2)/
        (15077971520932320*Sqrt[3]) - (66961134961081*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) + CF*((40746038270091120619*CF*NC)/
          32464832400 + 96*CF*lm*NC + CA*(-40746029728955097199/64929664800 + 
           (176*lm)/3)*NC + (8097370258195025898173*NM*NC)/436704293025 - 
         (32*lm*NM*NC)/3 - (118*NC*NL)/9 - (32*lm*NC*NL)/3 - 
         (11529979440794*NC*NH)/1933976154825 - (32*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-88592316314797*CA + 4*(44296066017851*CF + 
            180180*(3518653717*NM + 4*NL)))*Log[x]^3)/405405 - 
       15*CF^2*NC*PolyGamma[2, 1] + (37*CF*NM*NC*PolyGamma[2, 1])/6 + 
       (43*CF*NC*NH*PolyGamma[2, 1])/6 - (354369209715137*CF^2*NC*Zeta[3])/
        1621620 - (9383076353*CF*NM*NC*Zeta[3])/3 - 10*CF*NC*NL*Zeta[3] + 
       (247*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*
        (1241427186492660825249888890337844876367/
          6533244295698665352049482240000 - (30785895779145084727*Pi^2)/
          588695627520 + (81595161787869383*Pi^3)/(23263156060867008*
           Sqrt[3]) + Pi^4/80 - (32028096941882667260849*
           Im[PolyLog[2, (-1)^(1/3)]])/(815024672592475625280*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + (81595161787869383*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(628248813372180*Sqrt[3]) + 
         (81595161787869383*Pi*Log[3]^2)/(30155943041864640*Sqrt[3]) + 
         (15*PolyGamma[2, 1])/2 + (354369209715137*Zeta[3])/3243240) + 
       CF*Log[x]*((6028964005475087711215614027073411*NM*NC)/
          2034246821828960678940000 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (184385278873*NC*NL)/12985932960 + (10*lm*NC*NL)/9 + 
         (lm^2*NC*NL)/3 - (140986422502032928765714381282051581439*NC*NH)/
          757372651419744619593435236395260000 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (4691538293*NM*NC*Pi^2)/3 - (5*NC*NL*Pi^2)/3 + 
         (267844539844324*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CF*NC*(97949050939674658761071776239847/
            755407127097285278616000 + lm/2 - 3*lm^2 + (354369171997457*Pi^2)/
            3243240 + (81595161787869383*Im[PolyLog[2, (-1)^(1/3)]])/
            (942373220058270*Sqrt[3]) - 8*Zeta[3]) + 
         CA*NC*(-195898134582917398631368881523709/
            3021628508389141114464000 - (76*lm)/9 - (11*lm^2)/6 - 
           (354369171997457*Pi^2)/6486480 - (81595161787869383*
             Im[PolyLog[2, (-1)^(1/3)]])/(1884746440116540*Sqrt[3]) + 
           4*Zeta[3])), 
      (180363732955748973799375944518012619700506178059432419*CF^2*NC)/
        13136720812006437840475485033164375040000000 - 
       (31*CF^2*lm*NC)/115200 + 
       (49821436788017855144607885870649195357159040974771*CF*NM*NC)/
        37225862276276834343609944193643968000000 + (31*CF*lm*NM*NC)/
        1036800 - (6665611044172040369*CF*NC*NL)/1684659888527616000 + 
       (31*CF*lm*NC*NL)/1036800 - 
       (26461497442643781855486404756374167200669423848358317*CF*NC*NH)/
        218734603458914334621729272172257894412648672000000 + 
       (31*CF*lm*NC*NH)/1036800 - (168216693614401429211*CF^2*NC*Pi^2)/
        42343741440 - (7201915572916327*CF*NM*NC*Pi^2)/19459440 + 
       (239*CF*NC*NL*Pi^2)/12960 + (85784143008121985*CF^2*NC*Pi^3)/
        (17569376605410048*Sqrt[3]) + (2541981074845975*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) - (13731330070163355212323*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(175869459820154580480*Sqrt[3]) + 
       (41664813905506237*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2973983019144930*Sqrt[3]) + (2450975514517771*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13556617751088*Sqrt[3]) + 
       (145256061419770*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) + (2450975514517771*CF^2*NC*Pi*Log[3]^2)/
        (650717652052224*Sqrt[3]) + (72628030709885*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((-1378325535421622638400299*CF*NC)/
          28912835952000 + CA*(1378325532991854972594709/57825671904000 - 
           (187*lm)/9)*NC - 34*CF*lm*NC - (1442976739166667536970179*NM*NC)/
          324907994010600 + (34*lm*NM*NC)/9 + (52*NC*NL)/9 + 
         (34*lm*NC*NL)/9 + (18815557559749*NC*NH)/11603856928950 + 
         (34*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-8633752445387*CA + 32*(539609521658*CF + 51978637790*NM + 
            85*NL))*Log[x]^3)/1080 + (31*CF^2*NC*PolyGamma[2, 1])/2 - 
       (247*CF*NM*NC*PolyGamma[2, 1])/27 - (280*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*
        (-1984001063657981641841250723203081425733354069173669609/
          289007857864141632490460670729616250880000000 - (341*lm)/2073600 + 
         (168216693615985590427*Pi^2)/84687482880 - (85784143008121985*Pi^3)/
          (35138753210820096*Sqrt[3]) + (13731330070163355212323*
           Im[PolyLog[2, (-1)^(1/3)]])/(351738919640309160960*Sqrt[3]) - 
         (2450975514517771*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27113235502176*Sqrt[3]) - (2450975514517771*Pi*Log[3]^2)/
          (1301435304104448*Sqrt[3]) - (31*PolyGamma[2, 1])/4 - 
         (11511670086911*Zeta[3])/2880) + (11511670096831*CF^2*NC*Zeta[3])/
        1440 + (20791453645*CF*NM*NC*Zeta[3])/27 + (31*CF*NC*NL*Zeta[3])/
        9 - (638*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((-443222372027841777676249270736826919*NM*NC)/
          902266705743522098059080000 - (1081*lm*NM*NC)/2160 - 
         (lm^2*NM*NC)/6 + (2732296003763*NC*NL)/584366983200 - 
         (1081*lm*NC*NL)/2160 - (lm^2*NC*NL)/6 + 
         (10895863787820184436094854144320758487*NC*NH)/
          108196093059963517084776462342180000 - (1081*lm*NC*NH)/2160 - 
         (lm^2*NC*NH)/6 - (20791455265*NM*NC*Pi^2)/54 + 
         (31*NC*NL*Pi^2)/54 - (145256061419770*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(47364761253477940389608200246759920229141/
            11683440284776702870312684800000 + (16931*lm)/4320 + 
           (11*lm^2)/12 + (34535009700563*Pi^2)/17280 + 
           (2450975514517771*Im[PolyLog[2, (-1)^(1/3)]])/(81339706506528*
             Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-7294173216204447044634541230200242213209889/
            899624901927806121014076729600000 - (179*lm)/240 + (3*lm^2)/2 - 
           (11511669896881*Pi^2)/2880 - (2450975514517771*
             Im[PolyLog[2, (-1)^(1/3)]])/(40669853253264*Sqrt[3]) + 
           4*Zeta[3])), (-7336332198765315243294141903029893248427577*CF^2*
         NC)/2822361535741823432085376327680000 - 
       (2938529970976154162370844894641576596526018094510069*CF*NM*NC)/
        75278965936470931672633442702702246400000 + 
       (1723070395140088261*CF*NC*NL)/140388324043968000 + 
       (1889204285218561831365520608780241713705859044586243*CF*NC*NH)/
        8577827586624091553793304791068937035790144000000 + 
       (971027397075194181058097*CF^2*NC*Pi^2)/1342226030745600 + 
       (9181301259003317*CF*NM*NC*Pi^2)/810810 - (CF*NC*NL*Pi^2)/18 - 
       (18625805765066051675*CF^2*NC*Pi^3)/(2512420854573636864*Sqrt[3]) - 
       (634360742598380*CF*NC*NH*Pi^3)/(22876792454961*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (73655172889849360475987099*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(880226646399873675302400*Sqrt[3]) + 
       (2484848721959335334*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (38166115412359935*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (3725161153013210335*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13570174368839088*Sqrt[3]) - 
       (289993482330688*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) - (3725161153013210335*CF^2*NC*Pi*Log[3]^2)/
        (651368369704276224*Sqrt[3]) - (18124592645668*CF*NC*NH*Pi*Log[3]^2)/
        (847288609443*Sqrt[3]) + CF*((4509415152368004764323*CF*NC)/
          519437318400 + 102*CF*lm*NC + CA*(-4509415007169188521843/
            1038874636800 + (187*lm)/3)*NC + (327034082429104577596921*NM*
           NC)/2406725881560 - (34*lm*NM*NC)/3 - (125*NC*NL)/9 - 
         (34*lm*NC*NL)/3 - (5803036854457*NC*NH)/910106425800 - 
         (34*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-1213579268549237*CA + 2427157710973174*CF + 
          360360*(102347157092*NM + 17*NL))*Log[x]^3)/810810 - 
       16*CF^2*NC*PolyGamma[2, 1] + (119*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (137*CF*NC*NH*PolyGamma[2, 1])/18 - (19417267825645621*CF^2*NC*
         Zeta[3])/12972960 - (204694313461*CF*NM*NC*Zeta[3])/9 - 
       (32*CF*NC*NL*Zeta[3])/3 + (263*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(7336332198752027642204351173838739614417537/
          5644723071483646864170752655360000 - (51106705109189099969323*Pi^2)/
          141286950604800 + (18625805765066051675*Pi^3)/(5024841709147273728*
           Sqrt[3]) + Pi^4/80 - (73655172889849360475987099*
           Im[PolyLog[2, (-1)^(1/3)]])/(1760453292799747350604800*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + (3725161153013210335*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27140348737678176*
           Sqrt[3]) + (3725161153013210335*Pi*Log[3]^2)/(1302736739408552448*
           Sqrt[3]) + 8*PolyGamma[2, 1] + (19417267825645621*Zeta[3])/
          25945920) + CF*Log[x]*((12281110678034333530729325072566948721*NM*
           NC)/521309652207368323323024000 + (10*lm*NM*NC)/9 + 
         (lm^2*NM*NC)/3 - (1489700423573*NC*NL)/97394497200 + 
         (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (5129003127239481491393258988296000963*NC*NH)/
          25457904249403180490535638198160000 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (102347157104*NM*NC*Pi^2)/9 - 
         (16*NC*NL*Pi^2)/9 + (289993482330688*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(1364864836467485222856402378413028047/
            1305343515624108961448448000 + lm/2 - 3*lm^2 + 
           (19417267503663961*Pi^2)/25945920 + (3725161153013210335*
             Im[PolyLog[2, (-1)^(1/3)]])/(40710523106517264*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(-1364864864723937517630805329852335167/
            2610687031248217922896896000 - (76*lm)/9 - (11*lm^2)/6 - 
           (19417267503663961*Pi^2)/51891840 - (3725161153013210335*
             Im[PolyLog[2, (-1)^(1/3)]])/(81421046213034528*Sqrt[3]) + 
           4*Zeta[3])), 
      (1085577100111210297942500734065837144621000432356988189882123*CF^2*NC)/
        10784377347536281920459063306589654436349849600000 - 
       (33*CF^2*lm*NC)/147968 + 
       (1301624352503339365451321873892475402121476421960261*CF*NM*NC)/
        141148061130882996886187705067566712000000 + (11*CF*lm*NM*NC)/
        443904 - (62317482191187116063*CF*NC*NL)/14753536599529728000 + 
       (11*CF*lm*NC*NL)/443904 - 
       (34186304585340486670855152268773705447087248791966007*CF*NC*NH)/
        262481524150697201546075126606709473295178406400000 + 
       (11*CF*lm*NC*NH)/443904 - (13406375285032982206111*CF^2*NC*Pi^2)/
        455900949504 - (18951637912864141*CF*NM*NC*Pi^2)/7351344 + 
       (271*CF*NC*NL*Pi^2)/14688 + (54879966525810335*CF^2*NC*Pi^3)/
        (10500447736827099*Sqrt[3]) + (8275555744911035*CF*NC*NH*Pi^3)/
        (549043018919064*Sqrt[3]) - (147844329201929736598601*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1786861191375867436830*Sqrt[3]) + 
       (7383083447552713669*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (686990077422478830*Sqrt[3]) + (25087984697513296*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129635157244779*Sqrt[3]) + 
       (472888899709202*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (847288609443*Sqrt[3]) + (1567999043594581*CF^2*NC*Pi*Log[3]^2)/
        (388905471734337*Sqrt[3]) + (236444449854601*CF*NC*NH*Pi*Log[3]^2)/
        (20334926626632*Sqrt[3]) + CF*((-134130784756446630098513321*CF*NC)/
          380107416648960 + CA*(26826156944524550116277353/152042966659584 - 
           22*lm)*NC - 36*CF*lm*NC - (418803599497334153287774*NM*NC)/
          13537833083775 + 4*lm*NM*NC + (55*NC*NL)/9 + 4*lm*NC*NL + 
         (3852670911*NC*NH)/2247176360 + 4*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-71929189664327*CA + 136*(1057782199129*CF + 95654837120*NM + 
            24*NL))*Log[x]^3)/1224 + (33*CF^2*NC*PolyGamma[2, 1])/2 - 
       (88*CF*NM*NC*PolyGamma[2, 1])/9 - 11*CF*NC*NH*PolyGamma[2, 1] + 
       CA*CF*NC*
        (-155082442886056381911008262137665569267361249656017169809989/
          3081250670724651977274018087597044124671385600000 - 
         (121*lm)/887808 + (3527993496065794411321*Pi^2)/239947868160 - 
         (54879966525810335*Pi^3)/(21000895473654198*Sqrt[3]) + 
         (147844329201929736598601*Im[PolyLog[2, (-1)^(1/3)]])/
          (3573722382751734873660*Sqrt[3]) - 
         (12543992348756648*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (129635157244779*Sqrt[3]) - (1567999043594581*Pi*Log[3]^2)/
          (777810943468674*Sqrt[3]) - (33*PolyGamma[2, 1])/4 - 
         (143858379618113*Zeta[3])/4896) + (143858379636065*CF^2*NC*Zeta[3])/
        2448 + (47827418035*CF*NM*NC*Zeta[3])/9 + (11*CF*NC*NL*Zeta[3])/3 - 
       (676*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((-30687992944697810980531934497640108477*NM*NC)/
          7819644783110524849845360000 - (1225*lm*NM*NC)/2448 - 
         (lm^2*NM*NC)/6 + (137974369751*NC*NL)/27367048800 - 
         (1225*lm*NC*NL)/2448 - (lm^2*NC*NL)/6 + 
         (198604896185110630219810415777306069173*NC*NH)/
          1817694363407387087024244567348624000 - (1225*lm*NC*NH)/2448 - 
         (lm^2*NC*NH)/6 - (15942472871*NM*NC*Pi^2)/6 + 
         (11*NC*NL*Pi^2)/18 - (472888899709202*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CA*NC*(85064258258991492088460055061518212367661101149/
            2645884228703007931639869600635904000 + (19187*lm)/4896 + 
           (11*lm^2)/12 + (23976396546697*Pi^2)/1632 + 
           (12543992348756648*Im[PolyLog[2, (-1)^(1/3)]])/(388905471734337*
             Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-595449807632971120231690621271687567994471730253/
            9260594800460527760739543602225664000 - (203*lm)/272 + 
           (3*lm^2)/2 - (71929189637099*Pi^2)/2448 - 
           (25087984697513296*Im[PolyLog[2, (-1)^(1/3)]])/(388905471734337*
             Sqrt[3]) + 4*Zeta[3])), 
      (-1066004772882894108784584801913392329332035055223*CF^2*NC)/
        58931614456673208717800679066040320000 - 
       (162147110527926322206438103538001321813469362033633887*CF*NM*NC)/
        564592244523531987544750820270266848000000 + 
       (2121923770858544264477*CF*NC*NL)/162288902594827008000 + 
       (4178208282550277395287526735483292529813522948506138891*CF*NC*NH)/
        17717502880172061104360071045952889447424542432000000 + 
       (29015796168754861965454691*CF^2*NC*Pi^2)/5704460630668800 + 
       (272731976519776483*CF*NM*NC*Pi^2)/3243240 - (CF*NC*NL*Pi^2)/18 - 
       (83393261348425731475*CF^2*NC*Pi^3)/(10677788631937956672*Sqrt[3]) - 
       (221441698813151845*CF*NC*NH*Pi^3)/(7412080755407364*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (5644369598415380314977127109*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(63596375202390873040598400*Sqrt[3]) + 
       (126525377540213926429*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1686248371855175310*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (16678652269685146295*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(57673241067566124*Sqrt[3]) - 
       (25307622721503068*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (22876792454961*Sqrt[3]) - (16678652269685146295*CF^2*NC*Pi*Log[3]^2)/
        (2768315571243173952*Sqrt[3]) - (6326905680375767*CF*NC*NH*Pi*
         Log[3]^2)/(274521509459532*Sqrt[3]) + 
       CF*((2290720749841587080987083*CF*NC)/37529346254400 + 108*CF*lm*NC + 
         CA*(-2290720738733899707784663/75058692508800 + 66*lm)*NC + 
         (27322307134999755624127799*NM*NC)/27075666167550 - 12*lm*NM*NC - 
         (44*NC*NL)/3 - 12*lm*NC*NL - (10214475243391*NC*NH)/
          1504203675975 - 12*lm*NC*NH)*Log[x]^2 + 
       (2*CF*NC*(-35956479371803996*CA + 71912954832846137*CF + 
          9189180*(125832373414*NM + 3*NL))*Log[x]^3)/6891885 - 
       17*CF^2*NC*PolyGamma[2, 1] + (127*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (145*CF*NC*NH*PolyGamma[2, 1])/18 - (575303667832669733*CF^2*NC*
         Zeta[3])/55135080 - (1509988480199*CF*NM*NC*Zeta[3])/9 - 
       (34*CF*NC*NL*Zeta[3])/3 + 93*CF*NC*NH*Zeta[3] + 
       CA*CF*NC*(1066004772882649135173651308377572378311798163773/
          117863228913346417435601358132080640000 - 
         (29015796168752606564266651*Pi^2)/11408921261337600 + 
         (83393261348425731475*Pi^3)/(21355577263875913344*Sqrt[3]) + 
         Pi^4/80 - (5644369598415380314977127109*Im[PolyLog[2, (-1)^(1/3)]])/
          (127192750404781746081196800*Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^
          2 + (16678652269685146295*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (115346482135132248*Sqrt[3]) + (16678652269685146295*Pi*Log[3]^2)/
          (5536631142486347904*Sqrt[3]) + (17*PolyGamma[2, 1])/2 + 
         (575303667832669733*Zeta[3])/110270160) + 
       CF*Log[x]*((1460418057650392152568241353484832270521*NM*NC)/
          7819644783110524849845360000 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (217125395491261*NC*NL)/13245651619200 + (10*lm*NC*NL)/9 + 
         (lm^2*NC*NL)/3 - (53247787217487685977028400858389755301403*NC*NH)/
          245388739059997256748273016592064240000 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (754994240497*NM*NC*Pi^2)/9 - 
         (17*NC*NL*Pi^2)/9 + (25307622721503068*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(13241661293007674861282576131375933659799/
            1603288173065311831899056256000 + lm/2 - 3*lm^2 + 
           (575303666378256773*Pi^2)/110270160 + (16678652269685146295*
             Im[PolyLog[2, (-1)^(1/3)]])/(173019723202698372*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(-13241661327714305432786954602982508612799/
            3206576346130623663798112512000 - (76*lm)/9 - (11*lm^2)/6 - 
           (575303666378256773*Pi^2)/220540320 - (16678652269685146295*
             Im[PolyLog[2, (-1)^(1/3)]])/(346039446405396744*Sqrt[3]) + 
           4*Zeta[3])), 
      (810647391694885791522040871621001552205945578621961352659359655183*
         CF^2*NC)/1084311176266530139586836348012316834182381996838400000 - 
       (35*CF^2*lm*NC)/187272 + 
       (4973319297638452068214136262080577962536752774501193*CF*NM*NC)/
        76989851525936180119738748218672752000000 + (35*CF*lm*NM*NC)/
        1685448 - (124947504048043781197*CF*NC*NL)/27820954730541772800 + 
       (35*CF*lm*NC*NL)/1685448 - 
       (77023540614868705180640678627137609046046673444315783*CF*NC*NH)/
        551756145057261418474881105237287214625677792000000 + 
       (35*CF*lm*NC*NH)/1685448 - (141240779455107417169853*CF^2*NC*Pi^2)/
        641110710240 - (223475669130450697*CF*NM*NC*Pi^2)/12252240 + 
       (305*CF*NC*NL*Pi^2)/16524 + (2973081702881764705*CF^2*NC*Pi^3)/
        (533669814389330208*Sqrt[3]) + (2171273899360646605*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) - (116740005016122999651521*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1335508710509298845520*Sqrt[3]) + 
       (2417607846178170142489*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (333877177627324711380*Sqrt[3]) + (84945191510907563*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(411782264189298*Sqrt[3]) + 
       (124072794249179806*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (205891132094649*Sqrt[3]) + (84945191510907563*CF^2*NC*Pi*Log[3]^2)/
        (19765548681086304*Sqrt[3]) + (62036397124589903*CF*NC*NH*Pi*
         Log[3]^2)/(4941387170271576*Sqrt[3]) + 
       CF*((-1347893352408410226843954979*CF*NC)/509855621370480 + 
         CA*(2695786704721034637163504643/2039422485481920 - (209*lm)/9)*NC - 
         38*CF*lm*NC - (71114210657960773974159703*NM*NC)/324907994010600 + 
         (38*lm*NM*NC)/9 + (58*NC*NL)/9 + (38*lm*NC*NL)/9 + 
         (4106084174191*NC*NH)/2272083874200 + (38*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-1205190939312391*CA + 24*(100432578250605*CF + 
            8559381724540*NM + 323*NL))*Log[x]^3)/2754 + 
       (35*CF^2*NC*PolyGamma[2, 1])/2 - (281*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (314*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*
        (-3242589566818529549466165569825049388376070512403985209371092542607/
          8674489410132241116694690784098534673459055974707200000 - 
         (385*lm)/3370896 + (564963117820525406917007*Pi^2)/5128885681920 - 
         (2973081702881764705*Pi^3)/(1067339628778660416*Sqrt[3]) + 
         (116740005016122999651521*Im[PolyLog[2, (-1)^(1/3)]])/
          (2671017421018597691040*Sqrt[3]) - 
         (84945191510907563*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (823564528378596*Sqrt[3]) - (84945191510907563*Pi*Log[3]^2)/
          (39531097362172608*Sqrt[3]) - (35*PolyGamma[2, 1])/4 - 
         (2410381879316383*Zeta[3])/11016) + 
       (2410381879359223*CF^2*NC*Zeta[3])/5508 + 
       (1006986083561*CF*NM*NC*Zeta[3])/27 + (35*CF*NC*NL*Zeta[3])/9 - 
       (238*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-1447922526181478749894049130474926020211*NM*NC)/
          46917868698663149099072160000 - (689*lm*NM*NC)/1377 - 
         (lm^2*NM*NC)/6 + (1364309895989*NC*NL)/252298126080 - 
         (689*lm*NC*NL)/1377 - (lm^2*NC*NL)/6 + 
         (520995793108570012029176323592063365444217*NC*NH)/
          4416997303079950621468914298657156320000 - (689*lm*NC*NH)/1377 - 
         (lm^2*NC*NH)/6 - (1006986085409*NM*NC*Pi^2)/54 + 
         (35*NC*NL*Pi^2)/54 - (124072794249179806*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(15308923736022046926888610593316510629939234527561483/
            60071163321887328451977234461737325952000 + (5396*lm)/1377 + 
           (11*lm^2)/12 + (803460626169971*Pi^2)/7344 + 
           (84945191510907563*Im[PolyLog[2, (-1)^(1/3)]])/(2470693585135788*
             Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-15308923735416538461026229088022848520174705038422233/
            30035581660943664225988617230868662976000 - (457*lm)/612 + 
           (3*lm^2)/2 - (267820208721737*Pi^2)/1224 - 
           (84945191510907563*Im[PolyLog[2, (-1)^(1/3)]])/(1235346792567894*
             Sqrt[3]) + 4*Zeta[3])), 
      (-152529203173020134716714428468030653929903242668197*CF^2*NC)/
        1193365192747632476535463751087316480000 - 
       (603984392014789018308837408449378770310627232235645847*CF*NM*NC)/
        282296122261765993772375410135133424000000 + 
       (2126868122200011021697*CF*NC*NL)/153272852450669952000 + 
       (4112589570600883291072108538968375997734537846738790463149*CF*NC*NH)/
        16350206600210928542656591312177865147011251275856000000 + 
       (1862750963579932404485888999*CF^2*NC*Pi^2)/51340145676019200 + 
       (2902907432631322559*CF*NM*NC*Pi^2)/4594590 - (CF*NC*NL*Pi^2)/18 - 
       (7096193645302230083165*CF^2*NC*Pi^3)/(864900879186974490432*
         Sqrt[3]) - (534486167793774665*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (483301720230438059355260926669*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5151306391393660716288470400*Sqrt[3]) + 
       (121061101205397890224462*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1418978004916130023365*Sqrt[3]) - 2*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (1419238729060446016633*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) - (244336533848582704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (1419238729060446016633*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) - (15271033365536419*CF*NC*NH*Pi*Log[3]^2)/
        (617673396283947*Sqrt[3]) + CF*((49019762198470414929615379*CF*NC)/
          112588038763200 + 114*CF*lm*NC + 
         CA*(-49019762163296105673509359/225176077526400 + (209*lm)/3)*NC + 
         (205280086086709926669460273*NM*NC)/27075666167550 - 
         (38*lm*NM*NC)/3 - (139*NC*NL)/9 - (38*lm*NC*NL)/3 - 
         (379893465977227*NC*NH)/52726297273650 - (38*lm*NC*NH)/3)*
        Log[x]^2 + (2*CF*NC*(-84860664494744807*CA + 169721327545512079*CF + 
          510510*(5639540532910*NM + 19*NL))*Log[x]^3)/2297295 - 
       18*CF^2*NC*PolyGamma[2, 1] + (15*CF*NM*NC*PolyGamma[2, 1])/2 + 
       (17*CF*NC*NH*PolyGamma[2, 1])/2 - (4073311893517732823*CF^2*NC*
         Zeta[3])/55135080 - 1253231229445*CF*NM*NC*Zeta[3] - 
       12*CF*NC*NL*Zeta[3] + (295*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(305058406346031445343452890591967797625562930531639/
          4773460770990529906141855004349265920000 - 
         (1862750963579914353781417199*Pi^2)/102680291352038400 + 
         (7096193645302230083165*Pi^3)/(1729801758373948980864*Sqrt[3]) + 
         Pi^4/80 - (483301720230438059355260926669*
           Im[PolyLog[2, (-1)^(1/3)]])/(10302612782787321432576940800*
           Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (1419238729060446016633*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) + (1419238729060446016633*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) + 9*PolyGamma[2, 1] + 
         (4073311893517732823*Zeta[3])/110270160) + 
       CF*Log[x]*((723696361736592192880151284727217884647*NM*NC)/
          488727798944407803115335000 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (24309100393829*NC*NL)/1389975787200 + (10*lm*NC*NL)/9 + 
         (lm^2*NC*NL)/3 - (578608122123089282212167432246349698260419*NC*
           NH)/2486377182531436020062065655781927221250 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (1879846844308*NM*NC*Pi^2)/3 - 2*NC*NL*Pi^2 + 
         (244336533848582704*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CF*NC*(8387698997628001673683313576506347218798009/
            129866342018290258383823556736000 + lm/2 - 3*lm^2 + 
           (4073311891977353983*Pi^2)/110270160 + (1419238729060446016633*
             Im[PolyLog[2, (-1)^(1/3)]])/(14014597579418568132*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(-8387699000439286404445138374742501273093649/
            259732684036580516767647113472000 - (76*lm)/9 - (11*lm^2)/6 - 
           (4073311891977353983*Pi^2)/220540320 - (1419238729060446016633*
             Im[PolyLog[2, (-1)^(1/3)]])/(28029195158837136264*Sqrt[3]) + 
           4*Zeta[3])), (7424868936628157280351635424427822834564943809196943\
675724677906763*CF^2*NC)/
        1322047851276838886768976937683466514404187675289600000 - 
       (37*CF^2*lm*NC)/233928 + 
       (271671483787898720742680163120857679126838282477967609579*CF*NM*NC)/
        591688778521044119278019240672065379001600000 + 
       (37*CF*lm*NM*NC)/2105352 - (28434896312523988059615449*CF*NC*NL)/
        5975801971346720088576000 + (37*CF*lm*NC*NL)/2105352 - 
       (37616988673159748625722823855811743112385355109551735905461*CF*NC*
         NH)/252406314390756209377261128381745793206986191571027000000 + 
       (37*CF*lm*NC*NH)/2105352 - (281240294095621743627229*CF^2*NC*Pi^2)/
        168596588160 - (274124184277650184837*CF*NM*NC*Pi^2)/2095133040 + 
       (341*CF*NC*NL*Pi^2)/18468 + (5623972674062722070*CF^2*NC*Pi^3)/
        (950599356880994433*Sqrt[3]) + (2333910961446246875*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) - (141525642188735787559329619*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1536753179324168815304295*Sqrt[3]) + 
       (361688661632908811401*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (103198400357536728972*Sqrt[3]) + (2570958936714387232*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11735794529394993*Sqrt[3]) + 
       (133366340654071250*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (205891132094649*Sqrt[3]) + (160684933544649202*CF^2*NC*Pi*Log[3]^2)/
        (35207383588184979*Sqrt[3]) + (66683170327035625*CF*NC*NH*Pi*
         Log[3]^2)/(4941387170271576*Sqrt[3]) + 
       CF*((-296575483613074274983617813217*CF*NC)/14815804526883360 + 
         CA*(74143870902902303619129724873/7407902263441680 - (220*lm)/9)*
          NC - 40*CF*lm*NC - (11833641990669891029852989*NM*NC)/
          7537050644760 + (40*lm*NM*NC)/9 + (61*NC*NL)/9 + 
         (40*lm*NC*NL)/9 + (1201997514602383*NC*NH)/632715567283800 + 
         (40*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-10145314200697205*CA + 152*(133490976320059*CF + 
            10758766704078*NM + 60*NL))*Log[x]^3)/3078 + 
       (37*CF^2*NC*PolyGamma[2, 1])/2 - (298*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (331*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*
        (-2041838957576205242031786210888534924209915423090047380126291838906\
7/7271263182022613877229373157259065829223032214092800000 - 
         (407*lm)/4210704 + (478108499962567655577863*Pi^2)/573228399744 - 
         (2811986337031361035*Pi^3)/(950599356880994433*Sqrt[3]) + 
         (141525642188735787559329619*Im[PolyLog[2, (-1)^(1/3)]])/
          (3073506358648337630608590*Sqrt[3]) - 
         (1285479468357193616*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (11735794529394993*Sqrt[3]) - (80342466772324601*Pi*Log[3]^2)/
          (35207383588184979*Sqrt[3]) - (37*PolyGamma[2, 1])/4 - 
         (3381771400368739*Zeta[3])/2052) + (3381771400377175*CF^2*NC*
         Zeta[3])/1026 + (7172511134269*CF*NM*NC*Zeta[3])/27 + 
       (37*CF*NC*NL*Zeta[3])/9 - (752*CF*NC*NH*Zeta[3])/9 + 
       CF*Log[x]*((-106701616798934650141640257406848999767937*NM*NC)/
          442969394817033455976757152000 - (770*lm*NM*NC)/1539 - 
         (lm^2*NM*NC)/6 + (1829669133913763*NC*NL)/316914479481600 - 
         (770*lm*NC*NL)/1539 - (lm^2*NC*NL)/6 + 
         (766555278599716023346691540723841892404525811*NC*NH)/
          6046869307916452400790943674861647002080000 - 
         (770*lm*NC*NH)/1539 - (lm^2*NC*NH)/6 - (7172511136231*NM*NC*Pi^2)/
          54 + (37*NC*NL*Pi^2)/54 - (133366340654071250*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(3637817140110984102474700029865836530562025964171371/
            1798348901968265610169486535881842216000 + (12061*lm)/3078 + 
           (11*lm^2)/12 + (1268164275078721*Pi^2)/1539 + 
           (1285479468357193616*Im[PolyLog[2, (-1)^(1/3)]])/
            (35207383588184979*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-15670596911166415697046631248886428541033042235398127/
            3873366865777802852672740231130121696000 - (511*lm)/684 + 
           (3*lm^2)/2 - (2536328550155333*Pi^2)/1539 - 
           (2570958936714387232*Im[PolyLog[2, (-1)^(1/3)]])/
            (35207383588184979*Sqrt[3]) + 4*Zeta[3]))}, 0, 39, 1]
 
CbarLSeries["v", 2, -1, "x1"] = SeriesData[x, 1, 
     {-(CF*NC*(10*(2*NL*(27 - 65*lm + 12*lm^3 + 96*Zeta[3]) + 
            NM*(36 - 130*lm + 24*lm^3 + 147*Zeta[3]) + 
            NH*(36 - 130*lm + 24*lm^3 + 147*Zeta[3])) + 
          3*CF*(3780*lm^2 - 720*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
            90*lm*(-31 + 48*Zeta[3]) - 5*(331 + 192*Log[2]^4 + 
              4608*PolyLog[4, 1/2] + 1272*Zeta[3])) - 
          2*CA*(1260*lm^2 + 660*lm^3 - 5*lm*(961 + 648*Zeta[3]) + 
            6*(22*Pi^4 + 120*Pi^2*Log[2]^2 - 5*(21 + 24*Log[2]^4 + 
                576*PolyLog[4, 1/2] + 55*Zeta[3])))))/8640, 
      -(CF*NC*(782*NM - 144*lm^2*NM + 260*NL - 144*lm^2*NL - 262*NH - 
          144*lm^2*NH + 2*CA*(-961 + 504*lm + 396*lm^2 - 648*Zeta[3]) - 
          567*NM*Zeta[3] + 567*NH*Zeta[3] + 54*CF*(-31 - 84*lm + 24*lm^2 + 
            48*Zeta[3])))/1728, (CF*NC*(100246*NM - 75264*lm*NM - 
         10368*lm^2*NM + 31968*NL - 75264*lm*NL - 10368*lm^2*NL - 
         87674*NH - 75264*lm*NH - 10368*lm^2*NH + 
         12*CA*(28966 + 40544*lm + 4752*lm^2 - 27729*Zeta[3]) + 
         72*CF*(136 + 4872*lm + 1296*lm^2 - 11877*Zeta[3]) - 
         61425*NM*Zeta[3] + 142695*NH*Zeta[3]))/622080, 
      -(CF*NC*(13006*NM - 44160*lm*NM - 1728*lm^2*NM - 24336*NL - 
          44160*lm*NL - 1728*lm^2*NL - 113042*NH - 44160*lm*NH - 
          1728*lm^2*NH + 12*CA*(48160 + 21248*lm + 792*lm^2 - 
            21249*Zeta[3]) + 72*CF*(13423 + 4764*lm + 216*lm^2 - 
            14037*Zeta[3]) - 27405*NM*Zeta[3] + 108675*NH*Zeta[3]))/622080, 
      -(CF*NC*(80*CF*(-109586362 - 7544016*lm + 116640*lm^2 + 
            89307765*Zeta[3]) + 8*CA*(-240504682 - 42700320*lm + 
            712800*lm^2 + 123182775*Zeta[3]) - 
          3*(128*(-230723 - 165180*lm + 2700*lm^2)*NL + 
            5*NM*(232690 - 4228608*lm + 69120*lm^2 - 4531275*Zeta[3]) + 
            5*NH*(-17521550 - 4228608*lm + 69120*lm^2 + 14519925*Zeta[3]))))/
       1741824000, (CF*NC*(-54613270*NM + 60334080*lm*NM - 
         4147200*lm^2*NM + 145427968*NL + 60334080*lm*NL - 
         4147200*lm^2*NL + 386381350*NH + 60334080*lm*NH - 
         4147200*lm^2*NH + 158594625*NM*Zeta[3] - 302801625*NH*Zeta[3] + 
         96*CA*(-43913414 - 3154240*lm + 237600*lm^2 + 27093825*Zeta[3]) + 
         320*CF*(-88115530 - 2105136*lm + 116640*lm^2 + 71076825*Zeta[3])))/
       3483648000, -(CF*NC*(-48174873222*NM + 10112040960*lm*NM - 
          1445068800*lm^2*NM + 40594341888*NL + 10112040960*lm*NL - 
          1445068800*lm^2*NL + 104770414378*NH + 10112040960*lm*NH - 
          1445068800*lm^2*NH + 73181579625*NM*Zeta[3] - 
          80263929375*NH*Zeta[3] + 3*CA*(-631580589114 - 15166914560*lm + 
            2649292800*lm^2 + 446854440375*Zeta[3]) + 
          14*CF*(-1269988956574 - 9752002560*lm + 928972800*lm^2 + 
            1036283338125*Zeta[3])))/1365590016000, 
      (CF*NC*(CA*(-2254668687626 - 11133480960*lm + 5960908800*lm^2 + 
           1728192200175*Zeta[3]) + 2*(7*CF*(-1942828185562 - 4626616320*lm + 
             696729600*lm^2 + 1599448839975*Zeta[3]) - 
           3*(21*NM*(586911658 - 27013120*lm + 8601600*lm^2 - 668721375*
                Zeta[3]) + 2*(1024*(-2190743 - 276990*lm + 88200*lm^2)*NL + 
               21*NH*(-278945898 - 13506560*lm + 4300800*lm^2 + 211845375*
                  Zeta[3]))))))/1365590016000, 
      -(CF*NC*(144*CF*(-1659869686130066 - 1095226675200*lm + 
            283481856000*lm^2 + 1373484289030875*Zeta[3]) + 
          8*CA*(-2023800553317086 + 2835304012800*lm + 3118300416000*lm^2 + 
            1618015693762125*Zeta[3]) - 
          35*(16384*(-176604602 - 2875005*lm + 7909650*lm^2)*NL + 
            63*NM*(264108043066 - 747683840*lm + 2057011200*lm^2 - 
              259383576375*Zeta[3]) + 63*NH*(-124845649886 - 747683840*lm + 
              2057011200*lm^2 + 94581766125*Zeta[3]))))/8111604695040000, 
      (CF*NC*(72*CF*(-2383771850674514 - 299987251200*lm + 
           195084288000*lm^2 + 1977747392950875*Zeta[3]) + 
         4*CA*(-2447732969882654 + 6942065356800*lm + 2145927168000*lm^2 + 
           1998597515410125*Zeta[3]) - 
         35*(8192*(-107842871 + 10681020*lm + 5443200*lm^2)*NL + 
           9*NM*(1151371090734 + 9722101760*lm + 4954521600*lm^2 - 
             1043248177125*Zeta[3]) + 63*NH*(-40848900154 + 1388871680*lm + 
             707788800*lm^2 + 30959688375*Zeta[3]))))/4055802347520000, 
      -(CF*NC*(1089*CA*(-30188216956358946 + 80272860774400*lm + 
            15100968960000*lm^2 + 24902423975401875*Zeta[3]) + 
          22*CF*(-30507892869502623706 + 664204404326400*lm + 
            1223178485760000*lm^2 + 25345567110203022375*Zeta[3]) - 
          15*(1310720*(-2591632231 + 614857089*lm + 152078850*lm^2)*NL + 
            11*NM*(7469878183769606 + 73264134881280*lm + 18121162752000*lm^
                2 - 6479700381779625*Zeta[3]) + 11*NH*(-998228051202778 + 
              73264134881280*lm + 18121162752000*lm^2 + 757722164574375*Zeta[
                3]))))/11341825942487040000, 
      (CF*NC*(-893314935137229682*NM - 7357011774013440*lm*NM - 
         1236912419635200*lm^2*NM + 17254473142763520*NL - 
         7357011774013440*lm*NL - 1236912419635200*lm^2*NL + 
         64971201231639582*NH - 7357011774013440*lm*NH - 
         1236912419635200*lm^2*NH + 757364354516644875*NM*Zeta[3] - 
         49402682093890125*NH*Zeta[3] + 1815*CA*(-12915766765378954 + 
           27064436195328*lm + 3748219453440*lm^2 + 10706306820742575*
            Zeta[3]) + 330*CF*(-1666472444917054226 + 82576862871552*lm + 
           33733975080960*lm^2 + 1385413121095940475*Zeta[3])))/
       6805095565492224000, CA*CF*NC*(978118943416755807069157/
          241512841619319029760000 - (221717003*lm)/35416180800 - 
         (61*lm^2)/87360 - (508571642209*Zeta[3])/151145938944) - 
       (CF*NC*(832*CF*(-2007465143879390028248462 + 89003501398219161600*lm + 
            21227258326450176000*lm^2 + 1669454472612462373963125*Zeta[3]) - 
          1155*(143*NM*(14889968399299287554 + 91399973366661120*lm + 
              11881101341491200*lm^2 - 12480132927006619875*Zeta[3]) + 
            3*(6291456*(-951230950983 + 692483912120*lm + 90016126200*lm^2)*
               NL + 143*NH*(-197849129963473066 + 30466657788887040*lm + 
                3960367113830400*lm^2 + 150648414679137375*Zeta[3])))))/
        15456821863636417904640000, 
      (CF*NC*(128*CA*(-379402331172894700320158 + 421192835921726668800*lm + 
           39932678839173120000*lm^2 + 315534216868134877738125*Zeta[3]) + 
         3328*CF*(-439082034928320400791914 + 14513604580255334400*lm + 
           2513245521346560000*lm^2 + 365212110941965821909375*Zeta[3]) - 
         3465*(8388608*(-223093924849 + 296544087840*lm + 31972941000*lm^2)*
            NL + 39*NM*(14822207355357704002 + 63784413015572480*lm + 
             6877140221952000*lm^2 - 12357002465164231875*Zeta[3]) + 
           143*NH*(-88935252822345826 + 17395749004247040*lm + 
             1875583696896000*lm^2 + 67769486355445875*Zeta[3]))))/
       10304547909090945269760000, CA*CF*NC*((-149198321*lm)/34735100400 - 
         (5*lm^2)/13923 + (45685655523905049064997911622 - 
           38011216327708573473570671625*Zeta[3])/
          8408511093818211340124160000) - 
       (CF*NC*(CF*(-769507231955946195963451016122 + 
            17758864260947330570649600*lm + 2470620877304522342400000*lm^2 + 
            640101836281215019475140752375*Zeta[3]) - 
          5005*(268435456*(-671537517757 + 2183819617980*lm + 
              204324120000*lm^2)*NL + 13*NM*(15496597228989439437026 + 
              45093431921092853760*lm + 4219064486461440000*lm^2 - 
              12890181087125985517875*Zeta[3]) + 143*NH*
             (-17253815738453661194 + 4099402901917532160*lm + 
              383551316951040000*lm^2 + 13147668268186827375*Zeta[3]))))/
        4204255546909105670062080000, 
      (CF*NC*(CA*(-7462192979254692143368344646 + 4205766355506453440102400*
            lm + 318500940082141200384000*lm^2 + 6209616334357209807648239625*
            Zeta[3]) + 18*CF*(-15532759016348006655096334442 + 
           244149839307922105958400*lm + 28954630916558290944000*lm^2 + 
           12921227276224330873664229375*Zeta[3]) - 
         2860*(117440512*(68957783593 + 2057229886140*lm + 172410638400*lm^2)*
            NL + 2*NM*(62789075647917684542618 + 120801065564991651840*lm + 
             10123996823971430400*lm^2 - 52188358959411125826375*Zeta[3]) + 
           715*NH*(-1210389074684878370 + 337905078503473152*lm + 
             28318872234885120*lm^2 + 921653679454182675*Zeta[3]))))/
       1201215870545458762874880000, 
      -(CF*NC*(CA*(-558129958203430224191705775338438 + 
            225704299765207970806235136000*lm + 15797033711479575942266880000*
             lm^2 + 464458455144066901566686740727625*Zeta[3]) + 
          34*CF*(-679947609853991953129535681454746 + 
            7234140616471312336945152000*lm + 760285044937519697756160000*
             lm^2 + 565640209748094809578452365538375*Zeta[3]) - 
          6435*(134217728*(13282698547414861 + 43281254557440900*lm + 
              3325480620462000*lm^2)*NL + 51*NM*
             (90824661456808589950563346 + 113904150033124766515200*lm + 
              8751734380126273536000*lm^2 - 75481888608548473531354875*Zeta[
                3]) + 21879*NH*(-831291790876518606582 + 
              265510839238053068800*lm + 20400313240387584000*lm^2 + 
              632111934224646500625*Zeta[3]))))/
       79150516141981368803351592960000, 
      CA*CF*NC*((1742271521*lm)/747962495280 + (1619*lm^2)/10581480 + 
         (-78696349129951586543760861227114 + 
           65487344290314455885891393253375*Zeta[3])/
          9893814517747671100418949120000) + 
       (CF*NC*(544*CF*(-105387513401456676283653529785398 + 
            761454920337970333483008000*lm + 72855962577913251889152000*
             lm^2 + 87671610329112768672865134608625*Zeta[3]) - 
          2145*(51*NM*(693073303247924346556449502 + 
              561623504438251487232000*lm + 40255388111771113881600*lm^2 - 
              576068487922920337674454125*Zeta[3]) + 
            11*(1073741824*(1292245247023357 + 2425062277638000*lm + 
                173820757874400*lm^2)*NL + 663*NH*(
                -10989563966699135228674 + 3927437093973786624000*lm + 
                281506210571825971200*lm^2 + 8340805961837822347875*
                 Zeta[3])))))/158301032283962737606703185920000, 
      -(CF*NC*(12*CA*(-793315420042793814736321192207078582 + 
            170032517240807526078118625280000*lm + 
            10604839744453727779653943296000*lm^2 + 
            660134361345473114600832998649608625*Zeta[3]) + 
          152*CF*(-3117638891939545905998303905954946666 + 
            15427271545348706445211729920000*lm + 
            1370003220575361961964863488000*lm^2 + 
            2593571583259124386704269743297413375*Zeta[3]) - 
          7735*(17179869184*(1860567339509044021 + 2570106309439769100*lm + 
              174117529309323600*lm^2)*NL + 969*NM*
             (87479698176902035131517596658 + 45566656537820699138457600*lm + 
              3087013804102647388569600*lm^2 - 72725262317327955671153692875*
               Zeta[3]) + 37791*NH*(-2977137472657098561710546 + 
              1168375808662069208678400*lm + 79154200105196086886400*lm^2 + 
              2254673369718233812222875*Zeta[3]))))/
       1066737889550863567819037202186240000, 
      CA*CF*NC*(-1329117376523832253433406572983947913/
          133342236193857945977379650273280000 + (800922151*lm)/
          506641262400 + (1999*lm^2)/21162960 + (4738658020310358967*Zeta[3])/
          571335103972638720) + 
       (CF*NC*(8360*CF*(-13770138351235518689647960534969790 + 
            47190004716988272882185404416*lm + 3944551606592143306480680960*
             lm^2 + 11455448219696577685786123959277245*Zeta[3]) - 
          13923*(665*NM*(18327660240779583233493264434 + 
              6119419060986614762176512*lm + 395737259439512113643520*lm^2 - 
              15239237795111945282750757675*Zeta[3]) + 
            13*(17179869184*(16185988092656777 + 18220850103338190*lm + 
                1178325787577400*lm^2)*NL + 323*NH*(
                -2284440361596217801608578 + 969138765314622247403520*lm + 
                62673321630691963699200*lm^2 + 1726111027351012823395875*
                 Zeta[3])))))/213347577910172713563807440437248000, 
      -(CF*NC*(6*CA*(-1995846106036997791486826419121362189478 + 
            236746810319878410126804254510284800*lm + 
            13644085443363426994430404460544000*lm^2 + 
            1660655974681225257989487921632089769625*Zeta[3]) + 
          324*CF*(-2164268027682785430463031770643593307054 + 
            5200827624633836347623279794585600*lm + 
            413457134647376575588800135168000*lm^2 + 
            1800468496516926701092315141057904425125*Zeta[3]) - 
          1616615*(42949672960*(3556644928182385001 + 3446849460151921824*
               lm + 214371242886921120*lm^2)*NL + 
            57*NM*(12149500160396288940289375009034 + 
              2597211527296098144847134720*lm + 161529382000385760795033600*
               lm^2 - 10103641031404143814063052955375*Zeta[3]) + 
            37791*NH*(-8653986887925397219805754 + 3917362786268624652861440*
               lm + 243634060332406879027200*lm^2 + 6524066401104072502056375*
               Zeta[3]))))/1079538744225473930632865648612474880000, 
      (CF*NC*(168*CA*(-158211205800938225242384581729562376362 + 
           14177795298426377500701952573440000*lm + 
           792171807774257151979145920512000*lm^2 + 
           131636347408337434975035006153232737375*Zeta[3]) + 
         16*CF*(-104658148985024182669019458833340138904078 + 
           178638939361887373830134578544640000*lm + 
           13610951969939509247641688997888000*lm^2 + 
           87065858737106889656680841670741398275125*Zeta[3]) - 
         1616615*(240518168576*(1198825103986121231 + 1034579607054364800*
              lm + 62231673833128800*lm^2)*NL + 
           15*NM*(121225552440529421255865667999946 + 
             16589012822319570117533368320*lm + 997856547850874720794705920*
              lm^2 - 100823362686594670881058820895375*Zeta[3]) + 
           37791*NH*(-13777672245410772108885722 + 6584509336476768324812800*
              lm + 396069122747826752716800*lm^2 + 10364389818023649039006375*
              Zeta[3]))))/2159077488450947861265731297224949760000, 
      -(CF*NC*(CA*(-124599936281975310383303778459148307635827334 + 
            8511696825464287427249745602352355737600*lm + 
            462901538489444240507774030742080716800*lm^2 + 
            103667982434523743942943762948052802957810025*Zeta[3]) + 
          46*CF*(-182567495159623781199284320599672072560115862 + 
            224195834992706450469925111429123276800*lm + 
            16466853147845842547707376587662950400*lm^2 + 
            151879258765731563968208793549838143622077825*Zeta[3]) - 
          373065*(1099511627776*(4467638232891988060463 + 
              3511704256028227579320*lm + 205183106867161463040*lm^2)*NL + 
            207*NM*(18652945230983109016146422005760*lm + 
              1089860926684297893853758750720*lm^2 + 
              23*(9253412869797207829418077033389146 - 
                7696674188427697946639993185734375*Zeta[3])) + 
            156009*NH*(-49470267321762145058297425814 + 
              24749595618288070344289812480*lm + 1446078186666472216524226560*
               lm^2 + 37141175204074853073852314625*Zeta[3]))))/
       9137215931124411348876574849855987384320000, 
      (CF*NC*(459*CA*(-27311882519447199671009399367244839026834 + 
           1433336403703512486156464175238348800*lm + 
           76103589279769940668601611793203200*lm^2 + 
           22723162359683376838881100465024692140475*Zeta[3]) + 
         2*(299*CF*(-1502520192519513098172795376641921459588526 + 
             1344069303647641050777557216211763200*lm + 
             95586478356561150775917682674892800*lm^2 + 
             1249957960856384369891062675796694862575525*Zeta[3]) - 
           11305*(7559142440960*(897092301467676908623 + 
               652587105206893507560*lm + 37160542414576316736*lm^2)*NL + 
             161*NM*(545372628369071416247873944158445606 + 
               30639744617345697605937109401600*lm + 
               1744731883820608889291758632960*lm^2 - 
               453647366459905295816299316996465625*Zeta[3]) + 
             14858*NH*(-638242379515282027016411841322 + 
               332009616596625206256284467200*lm + 
               18905763446972542144028344320*lm^2 + 
               478331468040732024026390457375*Zeta[3])))))/
       830655993738582849897870440895998853120000}, 2, 26, 1]
 
CbarLSeries["v", 2, 0, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(2*CA*(-5540*Pi^2 + 324*Pi^4 - 660*lm*(3 + 4*Pi^2) + 
            15*(-175 + 3024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1728*Im[PolyLog[2, (-1)^(1/3)]]^2 - 504*PolyGamma[2, 1] - 
              5616*Zeta[3])) + 15*(CF*(-484*Pi^2 + 16*Pi^4 - 
              9*(103 + 1344*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                768*Im[PolyLog[2, (-1)^(1/3)]]^2 - 224*PolyGamma[2, 1] - 
                3168*Zeta[3])) + 4*(NL*(4*lm*(3 + 4*Pi^2) + 
                3*(15 + 4*Pi^2 - 64*Zeta[3])) + NM*(45 + 12*Pi^2 + 
                4*lm*(3 + 4*Pi^2) + 16*PolyGamma[2, 1] - 160*Zeta[3]) + 
              NH*(-891 + 4*lm*(3 + 4*Pi^2) - 3024*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 504*PolyGamma[2, 1] + 6000*Zeta[3])))))/
       155520, (CF*NC*(CF*(-51460*Pi^2 + 72*Pi^4 - 
           15*(10937 + 5184*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             24192*Im[PolyLog[2, (-1)^(1/3)]]^2 - 864*PolyGamma[2, 1] - 
             31968*Zeta[3])) + 12*CA*(-3860*Pi^2 + 189*Pi^4 - 
           1320*lm*(9 + Pi^2) + 30*(-1235 + 108*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 504*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             18*PolyGamma[2, 1] - 184*Zeta[3])) + 
         480*(3*NH*(541 + 2*lm*(9 + Pi^2) - 180*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 30*PolyGamma[2, 1] - 148*Zeta[3]) + 
           NL*(135 + 7*Pi^2 + 6*lm*(9 + Pi^2) - 72*Zeta[3]) + 
           NM*(135 + 7*Pi^2 + 6*lm*(9 + Pi^2) + 6*PolyGamma[2, 1] - 
             60*Zeta[3]))))/155520, 
      -(CF*NC*(CF*(-940*Pi^2 - 592*Pi^4 + 15*(3397 + 3840*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              128*PolyGamma[2, 1] - 10848*Zeta[3])) + 
          8*CA*(-1670*Pi^2 + 101*Pi^4 - 220*lm*(-21 + 2*Pi^2) - 
            15*(-681 + 240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              144*Im[PolyLog[2, (-1)^(1/3)]]^2 - 8*PolyGamma[2, 1] - 
              712*Zeta[3])) + 80*(NL*(-111 - 84*lm + 16*Pi^2 + 8*lm*Pi^2 - 
              96*Zeta[3]) + NM*(-471 + 40*Pi^2 + lm*(-84 + 8*Pi^2) + 
              32*PolyGamma[2, 1] - 32*Zeta[3]) + NH*(-927 - 84*lm + 
              8*lm*Pi^2 - 4608*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              852*PolyGamma[2, 1] + 9192*Zeta[3]))))/51840, 
      -(CF*NC*(1545885*CF - 1766880*NM - 181440*lm*NM - 522720*NL - 
          181440*lm*NL - 20521440*NH - 181440*lm*NH + 20268*CF*Pi^2 + 
          7200*NM*Pi^2 - 8640*lm*NM*Pi^2 + 59040*NL*Pi^2 - 
          8640*lm*NL*Pi^2 - 8640*lm*NH*Pi^2 + 173600*Sqrt[3]*CF*Pi^3 + 
          548800*Sqrt[3]*NH*Pi^3 + 22680*CF*Pi^4 - 648000*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 2229120*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 5132160*CF*Im[PolyLog[2, (-1)^(1/3)]]^
            2 + 6428160*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          20321280*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          133920*Sqrt[3]*CF*Pi*Log[3]^2 + 423360*Sqrt[3]*NH*Pi*Log[3]^2 + 
          51840*(135*CF - 2*CA*(76 + 33*lm) + 4*(5*NM + 3*lm*NM + 5*NL + 
              3*lm*NL + 3*lm*NH))*Log[x]^2 + 207360*(11*CA + 36*CF - 
            2*(NM + NL))*Log[x]^3 + 361440*CF*PolyGamma[2, 1] - 
          8640*NM*PolyGamma[2, 1] - 175680*NH*PolyGamma[2, 1] - 
          6495840*CF*Zeta[3] - 1157760*NM*Zeta[3] + 725760*NL*Zeta[3] - 
          3392640*NH*Zeta[3] + 4320*Log[x]*(8*(NM*(-43 + 3*lm + 3*Pi^2) + 
              NL*(11 + 3*lm + 3*Pi^2) + NH*(355 + 3*lm - 196*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) - 4*CA*(145 + 33*lm + 12*Pi^2 - 
              62*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 108*Zeta[3]) + 
            CF*(1209 + 80*Pi^2 - 496*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              864*Zeta[3])) - 4*CA*(-64080*Pi^2 + 21700*Sqrt[3]*Pi^3 + 
            4563*Pi^4 - 11880*lm*(21 + Pi^2) + 16740*Sqrt[3]*Pi*Log[3]^2 - 
            180*(4854 + 450*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              3564*Im[PolyLog[2, (-1)^(1/3)]]^2 - 4464*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 251*PolyGamma[2, 1] + 
              2432*Zeta[3]))))/466560, 
      -(CF*NC*(-881415*CF - 184680*NM - 125280*lm*NM - 197640*NL - 
          125280*lm*NL + 1936440*NH - 125280*lm*NH - 214452*CF*Pi^2 + 
          171360*NM*Pi^2 + 5760*lm*NM*Pi^2 + 24480*NL*Pi^2 + 
          5760*lm*NL*Pi^2 + 5760*lm*NH*Pi^2 + 64400*Sqrt[3]*CF*Pi^3 - 
          100800*Sqrt[3]*NH*Pi^3 + 1008*CF*Pi^4 + 4011840*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] - 9705600*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 1555200*CF*Im[PolyLog[2, (-1)^(1/3)]]^
            2 + 2384640*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
          3732480*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          49680*Sqrt[3]*CF*Pi*Log[3]^2 - 77760*Sqrt[3]*NH*Pi*Log[3]^2 - 
          4320*(-(CA*(65 + 66*lm + 53*Pi^2 + 92*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]])) + CF*(237 + 114*Pi^2 + 184*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]]) + 4*((5 + 3*lm)*NL + 
              NM*(41 + 3*lm - 6*Pi^2) + NH*(125 + 3*lm - 72*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])))*Log[x] - 311040*(3*CF - NM)*
           Log[x]^2 - 468480*CF*PolyGamma[2, 1] + 191520*NM*
           PolyGamma[2, 1] + 1964640*NH*PolyGamma[2, 1] + 
          8*CA*(-11655*Pi^2 - 4025*Sqrt[3]*Pi^3 + 513*Pi^4 - 
            990*lm*(-87 + 4*Pi^2) - 3105*Sqrt[3]*Pi*Log[3]^2 - 
            30*(-11871 + 8358*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              3240*Im[PolyLog[2, (-1)^(1/3)]]^2 + 4968*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 976*PolyGamma[2, 1] - 
              22004*Zeta[3])) - 11136480*CF*Zeta[3] - 308160*NM*Zeta[3] - 
          69120*NL*Zeta[3] + 19688640*NH*Zeta[3]))/466560, 
      -(CF*NC*(-554036625*CF - 300024000*NM - 24300000*lm*NM - 
          146934000*NL - 24300000*lm*NL - 5470465248*NH - 
          24300000*lm*NH - 47596500*CF*Pi^2 + 8964000*NM*Pi^2 - 
          648000*lm*NM*Pi^2 + 16740000*NL*Pi^2 - 648000*lm*NL*Pi^2 - 
          648000*lm*NH*Pi^2 + 62195000*Sqrt[3]*CF*Pi^3 + 
          182140000*Sqrt[3]*NH*Pi^3 + 6334200*CF*Pi^4 - 283788000*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 226224000*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 921456000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 2302992000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6744384000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 47979000*Sqrt[3]*CF*Pi*
           Log[3]^2 + 140508000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          2332800*(1010*CF - 5*CA*(226 + 99*lm) + 330*NM + 90*lm*NM + 
            135*NL + 90*lm*NL + 8*NH + 90*lm*NH)*Log[x]^2 + 
          69984000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 + 
          152412000*CF*PolyGamma[2, 1] - 648000*NM*PolyGamma[2, 1] + 
          10632000*NH*PolyGamma[2, 1] - 1089996000*CF*Zeta[3] - 
          810000000*NM*Zeta[3] + 217728000*NL*Zeta[3] - 
          1388784000*NH*Zeta[3] - 25*CA*(-1661256*Pi^2 + 1243900*Sqrt[3]*
             Pi^3 + 147420*Pi^4 - 71280*lm*(75 + 2*Pi^2) + 959580*Sqrt[3]*Pi*
             Log[3]^2 - 15*(2292435 + 378384*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 1228608*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              3070656*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              203216*PolyGamma[2, 1] + 878336*Zeta[3])) - 
          1080*Log[x]*(25*CA*(39441 + 7128*lm + 1230*Pi^2 - 14216*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 15552*Zeta[3]) - 
            2*(-4*(450*NM*(99 - 9*lm + Pi^2) - 675*NL*(35 + 6*lm + 
                  6*Pi^2) - 2*NH*(234633 + 2025*lm - 130100*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 25*CF*(34725 + 510*Pi^2 - 
                14216*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 15552*Zeta[3])))))/
       34992000, -(CF*NC*(412381935*CF + 86687280*NM - 4717440*lm*NM - 
          9272880*NL - 4717440*lm*NL + 335856240*NH - 4717440*lm*NH - 
          20975436*CF*Pi^2 + 11301120*NM*Pi^2 + 155520*lm*NM*Pi^2 + 
          984960*NL*Pi^2 + 155520*lm*NL*Pi^2 + 155520*lm*NH*Pi^2 + 
          4566800*Sqrt[3]*CF*Pi^3 - 12488000*Sqrt[3]*NH*Pi^3 + 
          408240*CF*Pi^4 + 283763520*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          557867520*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          92378880*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 169102080*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 462412800*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3522960*Sqrt[3]*CF*Pi*
           Log[3]^2 - 9633600*Sqrt[3]*NH*Pi*Log[3]^2 - 
          2160*(CA*(-124689 - 13464*lm + 4410*Pi^2 - 13048*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]]) - 4*(-810*NL - 612*lm*NL - 
              30768*NH - 612*lm*NH + 36*NL*Pi^2 - 12*NM*(796 + 51*lm - 
                213*Pi^2) + 17840*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
              7*CF*(-8925 + 261*Pi^2 - 932*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])))*Log[x] + 311040*(311*CF - 
            3*CA*(125 + 11*lm) + 122*NM + 6*lm*NM - 3*NL + 6*lm*NL + 
            6*lm*NH)*Log[x]^2 - 622080*(133*CA - 446*CF - 32*NM + 2*NL)*
           Log[x]^3 - 18771840*CF*PolyGamma[2, 1] + 38957760*NM*
           PolyGamma[2, 1] + 122728320*NH*PolyGamma[2, 1] - 
          2*CA*(-1911600*Pi^2 + 1141700*Sqrt[3]*Pi^3 + 39852*Pi^4 + 
            142560*lm*(-91 + 3*Pi^2) + 880740*Sqrt[3]*Pi*Log[3]^2 + 
            45*(1025661 + 1576464*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              513216*Im[PolyLog[2, (-1)^(1/3)]]^2 + 939456*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 104288*PolyGamma[2, 1] - 
              5723488*Zeta[3])) - 1093330080*CF*Zeta[3] + 
          36858240*NM*Zeta[3] + 1172355840*NH*Zeta[3]))/12597120, 
      (4633163*CF^2*NC)/93312 + (43373*CF*NM*NC)/972 + 
       (329*CF*lm*NM*NC)/324 + (23759*CF*NC*NL)/1944 + 
       (329*CF*lm*NC*NL)/324 + (2412645826*CF*NC*NH)/6251175 + 
       (329*CF*lm*NC*NH)/324 + (103205*CF^2*NC*Pi^2)/18144 + 
       (CF*NM*NC*Pi^2)/324 + (CF*lm*NM*NC*Pi^2)/54 - 
       (331*CF*NC*NL*Pi^2)/324 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (1486625*CF^2*NC*Pi^3)/(104976*Sqrt[3]) - 
       (1101625*CF*NC*NH*Pi^3)/(26244*Sqrt[3]) - (857*CF^2*NC*Pi^4)/2160 + 
       (204757*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(2916*Sqrt[3]) - 
       (2575*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(729*Sqrt[3]) - 
       (145*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (42475*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) - 
       (125900*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (81*Sqrt[3]) - (42475*CF^2*NC*Pi*Log[3]^2)/(3888*Sqrt[3]) - 
       (31475*CF*NC*NH*Pi*Log[3]^2)/(972*Sqrt[3]) - 
       (CF*NC*(64442*CF - 21*CA*(3587 + 1606*lm) + 19320*NM + 6132*lm*NM + 
          8666*NL + 6132*lm*NL + 972*NH + 6132*lm*NH)*Log[x]^2)/378 - 
       (4*CF*NC*(512*CA + 2179*CF - 472*NM - 73*NL)*Log[x]^3)/27 - 
       (231131*CF^2*NC*PolyGamma[2, 1])/26244 + 
       (401*CF*NM*NC*PolyGamma[2, 1])/54 - (30899*CF*NC*NH*PolyGamma[2, 1])/
        13122 + (1796585*CF^2*NC*Zeta[3])/26244 + (1793*CF*NM*NC*Zeta[3])/
        27 - (148*CF*NC*NL*Zeta[3])/9 + (718513*CF*NC*NH*Zeta[3])/6561 + 
       (CA*CF*NC*(-39354336*Pi^2 + 29732500*Sqrt[3]*Pi^3 + 2685636*Pi^4 - 
          213840*lm*(329 + 6*Pi^2) + 22936500*Sqrt[3]*Pi*Log[3]^2 - 
          15*(43851411 + 9828336*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            20295360*Im[PolyLog[2, (-1)^(1/3)]]^2 - 73396800*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
            3698096*PolyGamma[2, 1] + 18811520*Zeta[3])))/12597120 - 
       (CF*NC*Log[x]*(-245*CA*(899601 + 144936*lm + 15786*Pi^2 - 
            339800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 279936*Zeta[3]) + 
          2*(4*(13230*NM*(297 + 61*lm - 365*Pi^2) + 2205*NL*(3019 + 
                366*lm + 438*Pi^2) + 2*NH*(55456053 + 403515*lm - 
                30845500*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            245*CF*(747213 + 738*Pi^2 - 339800*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 279936*Zeta[3]))))/2857680, 
      -(CF*NC*(16130043423*CF + 3185745984*NM - 74560500*lm*NM - 
          191797875*NL - 74560500*lm*NL + 12238254936*NH - 
          74560500*lm*NH + 707036850*CF*Pi^2 + 523584000*NM*Pi^2 + 
          1944000*lm*NM*Pi^2 + 16848000*NL*Pi^2 + 1944000*lm*NL*Pi^2 + 
          1944000*lm*NH*Pi^2 + 93957500*Sqrt[3]*CF*Pi^3 - 
          430570000*Sqrt[3]*NH*Pi^3 + 12490200*CF*Pi^4 + 
          6988101000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          12412752000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          1994544000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 3479112000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 15943392000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 72481500*Sqrt[3]*CF*Pi*
           Log[3]^2 - 332154000*Sqrt[3]*NH*Pi*Log[3]^2 - 
          540*(4579248*NM + 261000*lm*NM + 288450*NL + 261000*lm*NL + 
            17004492*NH + 261000*lm*NH - 2610000*NM*Pi^2 - 
            25200*NL*Pi^2 - 9841600*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            2*CA*(-12573864 - 717750*lm + 1444725*Pi^2 - 536900*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]]) + CF*(49402731 - 5409900*Pi^2 + 
              2147600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))*Log[x] + 
          194400*(109669*CF - 2*CA*(34106 + 1155*lm) + 21752*NM + 
            420*lm*NM - 285*NL + 420*lm*NL + 108*NH + 420*lm*NH)*
           Log[x]^2 - 3888000*(1757*CA - 5013*CF + 14*(-58*NM + NL))*
           Log[x]^3 + 3345472000*CF*PolyGamma[2, 1] + 3300426000*NM*
           PolyGamma[2, 1] + 2956262000*NH*PolyGamma[2, 1] - 
          CA*(5965037649 + 456643575*Pi^2 + 46978750*Sqrt[3]*Pi^3 + 
            4689900*Pi^4 + 222750*lm*(-1841 + 48*Pi^2) + 3494050500*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 997272000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 1739556000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 36240750*Sqrt[3]*Pi*
             Log[3]^2 + 1672736000*PolyGamma[2, 1] - 13884686000*Zeta[3]) - 
          29408164000*CF*Zeta[3] + 5142852000*NM*Zeta[3] + 
          58320000*NL*Zeta[3] + 27312076000*NH*Zeta[3]))/157464000, 
      (194948747089*CF^2*NC)/2519424000 + (119369713*CF*NM*NC)/1944000 + 
       (1739*CF*lm*NM*NC)/1296 + (216275*CF*NC*NL)/7776 + 
       (1739*CF*lm*NC*NL)/1296 + (42092328923111*CF*NC*NH)/54010152000 + 
       (1739*CF*lm*NC*NH)/1296 + (25151*CF^2*NC*Pi^2)/1296 + 
       (8875*CF*NM*NC*Pi^2)/324 + (CF*lm*NM*NC*Pi^2)/54 - 
       (142*CF*NC*NL*Pi^2)/81 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (54648055*CF^2*NC*Pi^3)/(1889568*Sqrt[3]) - 
       (10489745*CF*NC*NH*Pi^3)/(118098*Sqrt[3]) - (167*CF^2*NC*Pi^4)/240 + 
       (48435137*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(314928*Sqrt[3]) + 
       (1094635*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) - 
       77*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (1561373*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1458*Sqrt[3]) - (2397656*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (1561373*CF^2*NC*Pi*Log[3]^2)/(69984*Sqrt[3]) - 
       (299707*CF*NC*NH*Pi*Log[3]^2)/(4374*Sqrt[3]) - 
       (CF*NC*(-147*CA*(39229 + 19360*lm) + 8*(526722*CF - 432831*NM + 
            64680*lm*NM + 88060*NL + 64680*lm*NL + 13801*NH + 
            64680*lm*NH))*Log[x]^2)/15120 - 
       (2*CF*NC*(7277*CA + 33270*CF - 15684*NM - 924*NL)*Log[x]^3)/81 + 
       (4658515*CF^2*NC*PolyGamma[2, 1])/236196 + 
       (5057*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (752123*CF*NC*NH*PolyGamma[2, 1])/118098 + 
       (CF*NC*Log[x]*(8*(-11907*NM*(886179 + 21500*lm - 488800*Pi^2) - 
            198450*NL*(13877 + 1290*lm + 1848*Pi^2) + 
            NH*(-42129362427 - 256000500*lm + 23497028800*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) + 49*CF*(-2294748393 + 
            90055800*Pi^2 + 1249098400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            839808000*Zeta[3]) - 49*CA*(-1452492759 - 229878000*lm + 
            18152100*Pi^2 + 624549200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            419904000*Zeta[3])))/514382400 + (44368079*CF^2*NC*Zeta[3])/
        236196 + (5099*CF*NM*NC*Zeta[3])/27 - (310*CF*NC*NL*Zeta[3])/9 + 
       (13603345*CF*NC*NH*Zeta[3])/59049 + 
       (CA*CF*NC*(-385820807850*Pi^2 + 191268192500*Sqrt[3]*Pi^3 + 
          14393521800*Pi^4 - 168399000*lm*(1739 + 24*Pi^2) + 
          147549748500*Sqrt[3]*Pi*Log[3]^2 - 21*(151491638049 + 
            48435137000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            72748368000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 337256568000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 18634060000*
             PolyGamma[2, 1] + 138263780000*Zeta[3])))/39680928000, 
      (-59661745994021*CF^2*NC)/1440270720000 + (8307774667*CF*NM*NC)/
        1000188000 + (27697*CF*lm*NM*NC)/48600 + (47977*CF*NC*NL)/24300 + 
       (27697*CF*lm*NC*NL)/48600 - (4583418465211*CF*NC*NH)/27005076000 + 
       (27697*CF*lm*NC*NH)/48600 - (201176609*CF^2*NC*Pi^2)/2721600 - 
       (29546*CF*NM*NC*Pi^2)/1215 - (CF*lm*NM*NC*Pi^2)/81 - 
       (341*CF*NC*NL*Pi^2)/2430 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 - (706279*CF^2*NC*Pi^3)/(314928*Sqrt[3]) + 
       (1045660*CF*NC*NH*Pi^3)/(59049*Sqrt[3]) - (463*CF^2*NC*Pi^4)/3240 - 
       (298183147*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(1312200*Sqrt[3]) + 
       (7388984*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) - 
       (58*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (100897*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1215*Sqrt[3]) + (478016*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (100897*CF^2*NC*Pi*Log[3]^2)/(58320*Sqrt[3]) + 
       (29876*CF*NC*NH*Pi*Log[3]^2)/(2187*Sqrt[3]) - 
       (CF*NC*(3*CF*(-348412439793 + 99972230400*Pi^2 - 7910324800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]]) - 6*CA*(-88290882921 - 
            3603322800*lm + 25567901100*Pi^2 - 1977581200*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]]) + 
          400*(-27*NM*(3858755 + 363972*lm - 10360560*Pi^2) - 
            15876*NL*(548 + 619*lm - 80*Pi^2) + NH*(-811338963 - 
              9827244*lm + 468455680*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])))*
         Log[x])/2571912000 - (CF*NC*(120387151*CF - 
          3*CA*(21471713 + 246400*lm) + 40*(771733*NM + 3360*lm*NM - 
            2730*NL + 3360*lm*NL + 1521*NH + 3360*lm*NH))*Log[x]^2)/
        113400 + (2*CF*NC*(48644*CA - 5*(23665*CF + 5672*NM - 32*NL))*
         Log[x]^3)/405 - (49945715*CF^2*NC*PolyGamma[2, 1])/177147 - 
       (13193*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (11397653*CF*NC*NH*PolyGamma[2, 1])/354294 + 
       (CA*CF*NC*(841617679671 + 36786977866170*Pi^2 + 363380545500*Sqrt[3]*
           Pi^3 + 59861251800*Pi^4 + 110020680*lm*(-27697 + 600*Pi^2) + 
          36819654991560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          9397766448000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 13455462484800*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 280322135100*Sqrt[3]*Pi*
           Log[3]^2 + 137051041960000*PolyGamma[2, 1] - 11909876221600*
           Zeta[3]))/972182736000 + (39432772*CF^2*NC*Zeta[3])/885735 - 
       (21694*CF*NM*NC*Zeta[3])/81 - (28*CF*NC*NL*Zeta[3])/27 - 
       (51376013*CF*NC*NH*Zeta[3])/177147, 
      (-890680382481839*CF^2*NC)/12962436480000 - (391913370923*CF*NM*NC)/
        666792000 + (54131*CF*lm*NM*NC)/32400 + (10424717*CF*NC*NL)/
        194400 + (54131*CF*lm*NC*NL)/32400 + (298695911697876569*CF*NC*NH)/
        215662536936000 + (54131*CF*lm*NC*NH)/32400 + 
       (14134493*CF^2*NC*Pi^2)/151200 + (450719*CF*NM*NC*Pi^2)/1620 + 
       (CF*lm*NM*NC*Pi^2)/54 - (1082*CF*NC*NL*Pi^2)/405 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (288081563*CF^2*NC*Pi^3)/(5668704*Sqrt[3]) - (28829150*CF*NC*NH*Pi^3)/
        (177147*Sqrt[3]) - (2329*CF^2*NC*Pi^4)/2160 + 
       (6781958461*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(23619600*Sqrt[3]) + 
       (10920665*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(59049*Sqrt[3]) - 
       (337*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (41154509*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (21870*Sqrt[3]) - (13179040*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (41154509*CF^2*NC*Pi*Log[3]^2)/(1049760*Sqrt[3]) - 
       (823690*CF*NC*NH*Pi*Log[3]^2)/(6561*Sqrt[3]) + 
       (CF*NC*(11*CA*(26370689 + 25872000*lm) + 
          4*(39197917*CF - 10*(165*(-399787 + 7840*lm)*NM + 
              7700*(223 + 168*lm)*NL + 3*(110823 + 431200*lm)*NH)))*
         Log[x]^2)/831600 - (2*CF*NC*(91401*CA + 318202*CF - 
          240*(1634*NM + 35*NL))*Log[x]^3)/405 + 
       (856866805*CF^2*NC*PolyGamma[2, 1])/2125764 + 
       (48929*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (13751651*CF*NC*NH*PolyGamma[2, 1])/1062882 + 
       (CF*NC*Log[x]*(40*(-88209*NM*(143674959 + 1629740*lm - 
              125851600*Pi^2) - 5*(5762988*NL*(66458 + 4989*lm + 
                8400*Pi^2) + NH*(5591102651097 + 28751547132*lm - 
                3125541126400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
          121*CF*(-1552880102523 + 593104339800*Pi^2 + 1613256752800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 925888320000*Zeta[3]) - 
          605*CA*(-235909530519 - 52275540240*lm + 52263871380*Pi^2 + 
            161325675280*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            92588832000*Zeta[3])))/933604056000 + 
       (CA*CF*NC*(-739925065496817 - 1354204465799850*Pi^2 + 
          247029940272500*Sqrt[3]*Pi^3 + 16155786717000*Pi^4 - 
          4950930600*lm*(54131 + 600*Pi^2) - 1395727051273800*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 1638127910160000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 9147165788376000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 190565953924500*Sqrt[3]*Pi*
           Log[3]^2 - 5878106282300000*PolyGamma[2, 1] - 12709608769396000*
           Zeta[3]))/29165482080000 + (9980221273*CF^2*NC*Zeta[3])/10628820 + 
       (32699*CF*NM*NC*Zeta[3])/27 - (562*CF*NC*NL*Zeta[3])/9 + 
       (221027173*CF*NC*NH*Zeta[3])/531441, 
      (34186341710056159*CF^2*NC)/23332385664000 + (13424669369843*CF*NM*NC)/
        27005076000 + (133*CF*lm*NM*NC)/200 + (1808981*CF*NC*NL)/583200 + 
       (133*CF*lm*NC*NL)/200 - (230166815828423*CF*NC*NH)/729137052000 + 
       (133*CF*lm*NC*NH)/200 - (1620810601*CF^2*NC*Pi^2)/2721600 - 
       (938903*CF*NM*NC*Pi^2)/4860 - (CF*lm*NM*NC*Pi^2)/81 - 
       (869*CF*NC*NL*Pi^2)/4860 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 - (54485501*CF^2*NC*Pi^3)/(25509168*Sqrt[3]) + 
       (52574270*CF*NC*NH*Pi^3)/(1594323*Sqrt[3]) - (241*CF^2*NC*Pi^4)/
        1080 - (37716555443*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (106288200*Sqrt[3]) + (292452133*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) - 
       (82*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (7783643*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (98415*Sqrt[3]) + (24033952*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (7783643*CF^2*NC*Pi*Log[3]^2)/(4723920*Sqrt[3]) + 
       (1502122*CF*NC*NH*Pi*Log[3]^2)/(59049*Sqrt[3]) - 
       (CF*NC*(CA*(8956803168786 + 884566267200*lm - 24649440366600*Pi^2 + 
            305118805600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
          5*(CF*(-3512869373541 + 9792349187040*Pi^2 - 122047522240*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
            16*(-535815*NL*(2459 + 3752*lm - 600*Pi^2) + 3240*NM*(
                63900071 - 620487*lm + 64853460*Pi^2) - 2*NH*(102191393163 + 
                1005188940*lm - 58883182400*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]]))))*Log[x])/69441624000 - 
       (CF*NC*(2538883653*CF - 15*CA*(86185063 + 277200*lm) + 
          40*((19484743 + 18900*lm)*NM + 1575*(-11 + 12*lm)*NL + 
            (11509 + 18900*lm)*NH))*Log[x]^2)/340200 + 
       (2*CF*NC*(286766*CA - 620261*CF + 60*(-3058*NM + 5*NL))*Log[x]^3)/
        405 - (4341896036*CF^2*NC*PolyGamma[2, 1])/1594323 - 
       (454153*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (323929897*CF*NC*NH*PolyGamma[2, 1])/6377292 - 
       (27010365191*CF^2*NC*Zeta[3])/7971615 - (386497*CF*NM*NC*Zeta[3])/
        162 - (56*CF*NC*NL*Zeta[3])/27 - (1433106313*CF*NC*NH*Zeta[3])/
        3188646 + (CA*CF*NC*(-199831616942324391 + 78455221348499100*Pi^2 + 
          93442634215000*Sqrt[3]*Pi^3 + 26694517626000*Pi^4 + 
          89116750800*lm*(-10773 + 200*Pi^2) + 15524134220338800*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 3587354295840000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 3460047255504000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 72084317823000*Sqrt[3]*Pi*
           Log[3]^2 + 357424881683520000*PolyGamma[2, 1] + 
          449182845374424000*Zeta[3]))/262489338720000, 
      (-65434555321806637*CF^2*NC)/38887309440000 - 
       (118193755266491*CF*NM*NC)/18003384000 + (64831*CF*lm*NM*NC)/32400 + 
       (44867069*CF*NC*NL)/486000 + (64831*CF*lm*NC*NL)/32400 + 
       (3202569822974569294837*CF*NC*NH)/1421431780945176000 + 
       (64831*CF*lm*NC*NH)/32400 + (635453491*CF^2*NC*Pi^2)/1020600 + 
       (681151*CF*NM*NC*Pi^2)/324 + (CF*lm*NM*NC*Pi^2)/54 - 
       (3059*CF*NC*NL*Pi^2)/810 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (1377457781*CF^2*NC*Pi^3)/
        (17006112*Sqrt[3]) - (575283695*CF*NC*NH*Pi^3)/(2125764*Sqrt[3]) - 
       (667*CF^2*NC*Pi^4)/432 + (34171837157*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(70858800*Sqrt[3]) + 
       (367680923*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) - 
       (463*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (196779683*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (65610*Sqrt[3]) - (65746708*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (196779683*CF^2*NC*Pi*Log[3]^2)/(3149280*Sqrt[3]) - 
       (16436677*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) + 
       (CF*NC*(2145*CA*(-33779803 + 8519280*lm) + 
          8*(24068726968*CF - 5*(143*(-141620947 + 580860*lm)*NM + 
              30030*(3605 + 2766*lm)*NL + (24279847 + 83062980*lm)*NH)))*
         Log[x]^2)/32432400 - (4*CF*NC*(169866*CA + 127340*CF - 1069590*NM - 
          6915*NL)*Log[x]^3)/405 + (77582342419*CF^2*NC*PolyGamma[2, 1])/
        19131876 + (49657*CF*NM*NC*PolyGamma[2, 1])/6 - 
       (216722747*CF*NC*NH*PolyGamma[2, 1])/9565938 + 
       (CF*NC*Log[x]*(40*(-2191376187*NL*(755603 + 47460*lm + 92200*Pi^2) + 
            3312738*NM*(805750531 - 31394790*lm + 9397136700*Pi^2) - 
            2*NH*(11762046993426441 + 52001356917510*lm - 6587826716270800*
               Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          20449*CF*(22486241396091 + 13716728260200*Pi^2 + 
            7713763573600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            3888730944000*Zeta[3]) - 204490*CA*(929760231291 - 
            111891031560*lm + 668658184110*Pi^2 + 385688178680*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 194436547200*Zeta[3])))/
        473337256392000 + (CA*CF*NC*(795768324383579823 - 
          326097202300619400*Pi^2 + 14174040566490000*Sqrt[3]*Pi^3 + 
          826112279916000*Pi^4 - 178233501600*lm*(64831 + 600*Pi^2) - 
          84390769042927200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          81021709218240000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          524844473547744000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          10934259865578000*Sqrt[3]*Pi*Log[3]^2 - 2128859475977360000*
           PolyGamma[2, 1] - 3821639580442768000*Zeta[3]))/1049957354880000 + 
       (706267186081*CF^2*NC*Zeta[3])/95659380 + 11887*CF*NM*NC*Zeta[3] - 
       (308*CF*NC*NL*Zeta[3])/3 + (3251106925*CF*NC*NH*Zeta[3])/4782969, 
      (45443277569120527767091*CF^2*NC)/3260817558472320000 + 
       (6731237749671353*CF*NM*NC)/1437750246240 + (1808381*CF*lm*NM*NC)/
        2381400 + (67064453*CF*NC*NL)/14288400 + (1808381*CF*lm*NC*NL)/
        2381400 - (308053712992797743*CF*NC*NH)/582288849727200 + 
       (1808381*CF*lm*NC*NH)/2381400 - (16757821229*CF^2*NC*Pi^2)/3810240 - 
       (2561488*CF*NM*NC*Pi^2)/1701 - (CF*lm*NM*NC*Pi^2)/81 - 
       (421*CF*NC*NL*Pi^2)/1890 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 - (87193985*CF^2*NC*Pi^3)/(76527504*Sqrt[3]) + 
       (531730675*CF*NC*NH*Pi^3)/(9565938*Sqrt[3]) - 
       (1037*CF^2*NC*Pi^4)/3240 - (1628332297099*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3124873080*Sqrt[3]) + 
       (6064294688*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) - 
       (110*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (17438797*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (413343*Sqrt[3]) + (121538440*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (17438797*CF^2*NC*Pi*Log[3]^2)/(19840464*Sqrt[3]) + 
       (15192305*CF*NC*NH*Pi*Log[3]^2)/(354294*Sqrt[3]) - 
       (CF*NC*(CF*(1071092781333908013 + 819817233898370400*Pi^2 - 
            827157019304000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) - 
          56*CA*(9562386080611083 - 56428029434700*lm + 7332298273047825*
             Pi^2 - 7385330529500*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
          560*(-27785835*NL*(15387 + 36924*lm - 7000*Pi^2) + 
            486*NM*(2118811926977 - 2111037390*lm + 1033479839700*Pi^2) - 
            2*NH*(62633721750069 + 512982085770*lm - 36030070538000*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]])))*Log[x])/176451166584000 - 
       (CF*NC*(1396057218023*CF - CA*(700983631021 + 533610000*lm) + 
          280*((1687209781 + 346500*lm)*NM + 346500*(-1 + lm)*NL + 
            (255601 + 346500*lm)*NH))*Log[x]^2)/26195400 + 
       (2*CF*NC*(13175510*CA - 26981003*CF - 8892800*NM + 3500*NL)*
         Log[x]^3)/2835 - (356429648249*CF^2*NC*PolyGamma[2, 1])/14348907 - 
       (674261*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (1083501634*CF*NC*NH*PolyGamma[2, 1])/14348907 - 
       (19766474796611*CF^2*NC*Zeta[3])/502211745 - 
       (591581*CF*NM*NC*Zeta[3])/27 - (32*CF*NC*NL*Zeta[3])/9 - 
       (9447036380*CF*NC*NH*Zeta[3])/14348907 + 
       CA*CF*NC*(-11426653914668875043137/1630408779236160000 + 
         (25152641573*Pi^2)/11430720 + (87193985*Pi^3)/(153055008*Sqrt[3]) + 
         (973*Pi^4)/6480 + (11*lm*(-1808381 + 29400*Pi^2))/4762800 + 
         (1628332297099*Im[PolyLog[2, (-1)^(1/3)]])/(6249746160*Sqrt[3]) + 
         (55*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (17438797*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(826686*Sqrt[3]) + 
         (17438797*Pi*Log[3]^2)/(39680928*Sqrt[3]) + 
         (356429648249*PolyGamma[2, 1])/28697814 + (39586946656027*Zeta[3])/
          2008846980), (-434746525807015516694029*CF^2*NC)/
        29347358026250880000 - (1216506940417579663*CF*NM*NC)/
        23962504104000 + (3702319*CF*lm*NM*NC)/1587600 + 
       (249300073*CF*NC*NL)/1701000 + (3702319*CF*lm*NC*NL)/1587600 + 
       (35952297729488035212157*CF*NC*NH)/10466906750596296000 + 
       (3702319*CF*lm*NC*NH)/1587600 + (164536695551*CF^2*NC*Pi^2)/
        34927200 + (171802037*CF*NM*NC*Pi^2)/11340 + 
       (CF*lm*NM*NC*Pi^2)/54 - (28733*CF*NC*NL*Pi^2)/5670 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (166052118323*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (72252612005*CF*NC*NH*Pi^3)/(172186884*Sqrt[3]) - 
       (1507*CF^2*NC*Pi^4)/720 + (30177429872077*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(40176939600*Sqrt[3]) + 
       (55959867667*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (71744535*Sqrt[3]) - 203*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (23721731189*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5314410*Sqrt[3]) - (8257441372*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (23721731189*CF^2*NC*Pi*Log[3]^2)/(255091680*Sqrt[3]) - 
       (2064360343*CF*NC*NH*Pi*Log[3]^2)/(6377292*Sqrt[3]) + 
       (CF*NC*(1911*CA*(-3083969437 + 102656400*lm) + 
          4*(3075302301903*CF - 350*(13*(-2263352587 + 1959804*lm)*NM + 
              11*(3822*(779 + 606*lm)*NL + (744307 + 2316132*lm)*NH))))*
         Log[x]^2)/227026800 + (4*CF*NC*(-2338106*CA + 2809104*CF + 
          35*(444512*NM + 707*NL))*Log[x]^3)/945 + 
       (6408403369909*CF^2*NC*PolyGamma[2, 1])/172186884 + 
       (1344443*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (3109178963*CF*NC*NH*PolyGamma[2, 1])/86093442 + 
       CA*CF*NC*(214036351585253688440153/29347358026250880000 - 
         (269100098453*Pi^2)/114307200 + (166052118323*Pi^3)/
          (2754990144*Sqrt[3]) + (917*Pi^4)/864 - 
         (11*lm*(3702319 + 29400*Pi^2))/3175200 - 
         (30177429872077*Im[PolyLog[2, (-1)^(1/3)]])/(80353879200*Sqrt[3]) + 
         (203*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (23721731189*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (10628820*Sqrt[3]) + (23721731189*Pi*Log[3]^2)/
          (510183360*Sqrt[3]) - (6408403369909*PolyGamma[2, 1])/344373768 - 
         (79350706954619*Zeta[3])/2410616376) + 
       (79533534350321*CF^2*NC*Zeta[3])/1205308188 + 
       (1056719*CF*NM*NC*Zeta[3])/9 - (472*CF*NC*NL*Zeta[3])/3 + 
       (44573833321*CF*NC*NH*Zeta[3])/43046721 + 
       CF*Log[x]*((1215776661409*NM*NC)/61746300 - (7477*lm*NM*NC)/630 - 
         (44023*NC*NL)/200 - (7477*lm*NC*NL)/630 - 
         (6384845835277051*NC*NH)/2074692519900 - (7477*lm*NC*NH)/630 + 
         (444211*NM*NC*Pi^2)/27 - (707*NC*NL*Pi^2)/27 + 
         (8257441372*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(6415739016278895199/529353499752000 + (6908815*Pi^2)/1512 + 
           (23721731189*Im[PolyLog[2, (-1)^(1/3)]])/(15943230*Sqrt[3]) - 
           224*Zeta[3]) + CA*NC*(-157056500426608501/26467674987600 + 
           (82247*lm)/1260 - (20624119*Pi^2)/9072 - 
           (23721731189*Im[PolyLog[2, (-1)^(1/3)]])/(31886460*Sqrt[3]) + 
           112*Zeta[3])), (3485644802306015851416166019*CF^2*NC)/
        32238072791836591680000 + (47706783363485131531697*CF*NM*NC)/
        1263494916395712000 + (16256473*CF*lm*NM*NC)/19051200 + 
       (7820121367*CF*NC*NL)/1143072000 + (16256473*CF*lm*NC*NL)/19051200 - 
       (30348509958293215093661*CF*NC*NH)/36843511762098961920 + 
       (16256473*CF*lm*NC*NH)/19051200 - (4593901852963*CF^2*NC*Pi^2)/
        139708800 - (100448198*CF*NM*NC*Pi^2)/8505 - 
       (CF*lm*NM*NC*Pi^2)/81 - (2059*CF*NC*NL*Pi^2)/7560 - 
       (CF*lm*NC*NL*Pi^2)/81 - (CF*lm*NC*NH*Pi^2)/81 + 
       (1505254151*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) + 
       (15014218975*CF*NC*NH*Pi^3)/(172186884*Sqrt[3]) - 
       (281*CF^2*NC*Pi^4)/648 - (411265595475281*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(562477154400*Sqrt[3]) + 
       (14424261059*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (14348907*Sqrt[3]) - (142*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (1505254151*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (37200870*Sqrt[3]) + (1715910740*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) + 
       (1505254151*CF^2*NC*Pi*Log[3]^2)/(1785641760*Sqrt[3]) + 
       (428977685*CF*NC*NH*Pi*Log[3]^2)/(6377292*Sqrt[3]) - 
       (CF*NC*(-(CA*(38301352160277036416217 - 25668558743156128800*lm + 
             17780733387201577993200*Pi^2 + 2413225863289841600*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]])) + 
          2*(CF*(38296411941695539412841 + 17774252453487058729200*Pi^2 + 
              2413225863289841600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
            140*(-16904902014*NL*(168921 + 985980*lm - 215600*Pi^2) + 
              15309*NM*(7907805380450693 - 1088764471080*lm + 
                2935565994160800*Pi^2) - 5*NH*(478857857699514747 + 
                3333579057552744*lm - 275095084382518400*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]]))))*Log[x])/1073528897497056000 - 
       (CF*NC*(538555853487348*CF - 3*CA*(89837383672891 + 14243829600*lm) + 
          280*((689254179067 + 27747720*lm)*NM + 
            5*(126126*(-47 + 44*lm)*NL + (4694801 + 5549544*lm)*NH)))*
         Log[x]^2)/1362160800 + (CF*NC*(375488249*CA - 755379110*CF - 
          264951680*NM + 21560*NL)*Log[x]^3)/5670 - 
       (28939694197904*CF^2*NC*PolyGamma[2, 1])/129140163 - 
       (12112153*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (55367400031*CF*NC*NH*PolyGamma[2, 1])/516560652 - 
       (982567515259157*CF^2*NC*Zeta[3])/2582803260 - 
       (10857685*CF*NM*NC*Zeta[3])/54 - (50*CF*NC*NL*Zeta[3])/9 - 
       (238523226271*CF*NC*NH*Zeta[3])/258280326 + 
       CA*CF*NC*(-13956880837481020306586467103/257904582334692733440000 + 
         (3759034655017*Pi^2)/228614400 - (1505254151*Pi^3)/
          (2754990144*Sqrt[3]) + (149*Pi^4)/720 + 
         lm*(-178821203/38102400 + (11*Pi^2)/162) + 
         (411265595475281*Im[PolyLog[2, (-1)^(1/3)]])/(1124954308800*
           Sqrt[3]) + (71*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (1505254151*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74401740*Sqrt[3]) - (1505254151*Pi*Log[3]^2)/
          (3571283520*Sqrt[3]) + (14469847098952*PolyGamma[2, 1])/129140163 + 
         (982773374244917*Zeta[3])/5165606520), 
      (-15313450295738148957375953531*CF^2*NC)/128952291167346366720000 - 
       (31443948633506973490999*CF*NM*NC)/84232994426380800 + 
       (16915051*CF*lm*NM*NC)/6350400 + (73019873527*CF*NC*NL)/333396000 + 
       (16915051*CF*lm*NC*NL)/6350400 + (683304692098894622478842647*CF*NC*
         NH)/137130434308478939328000 + (16915051*CF*lm*NC*NH)/6350400 + 
       (18673248719179*CF^2*NC*Pi^2)/502951680 + (315472427*CF*NM*NC*Pi^2)/
        2835 + (CF*lm*NM*NC*Pi^2)/54 - (148427*CF*NC*NL*Pi^2)/22680 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (156593499635*CF^2*NC*Pi^3)/(918330048*Sqrt[3]) - 
       (26563512325*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (5887*CF^2*NC*Pi^4)/2160 + (248747855489531*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(224990861760*Sqrt[3]) + 
       (6295405865*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) - 
       (775*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (31318699927*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4960116*Sqrt[3]) - (12143319920*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (31318699927*CF^2*NC*Pi*Log[3]^2)/(238085568*Sqrt[3]) - 
       (758957495*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) + 
       (CF*NC*(17*CA*(-199247647836301 + 1140986246400*lm) + 
          14*(487536474041037*CF - 40*(17*(-2164621447543 + 370450080*lm)*
               NM + 11*(371280*(1961 + 1542*lm)*NL + (197892407 + 
                  572513760*lm)*NH))))*Log[x]^2)/15437822400 + 
       (CF*NC*(-412958787*CA + 753928222*CF + 1680*(1534567*NM + 514*NL))*
         Log[x]^3)/5670 + (520824388013539*CF^2*NC*PolyGamma[2, 1])/
        1549681956 + (4035257*CF*NM*NC*PolyGamma[2, 1])/6 - 
       (41768323067*CF*NC*NH*PolyGamma[2, 1])/774840978 + 
       CA*CF*NC*(1091024574675697636791603571/18421755881049480960000 - 
         (18671407721447*Pi^2)/1005903360 + (156593499635*Pi^3)/
          (1836660096*Sqrt[3]) + (5951*Pi^4)/4320 - 
         (11*lm*(16915051 + 117600*Pi^2))/12700800 - 
         (248747855489531*Im[PolyLog[2, (-1)^(1/3)]])/(449981723520*
           Sqrt[3]) + (775*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (31318699927*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9920232*Sqrt[3]) + (31318699927*Pi*Log[3]^2)/(476171136*Sqrt[3]) - 
         (520824388013539*PolyGamma[2, 1])/3099363912 - 
         (65218773719529341*Zeta[3])/216955473840) + 
       (65241957822525521*CF^2*NC*Zeta[3])/108477736920 + 
       (3357439*CF*NM*NC*Zeta[3])/3 - (686*CF*NC*NL*Zeta[3])/3 + 
       (579883723801*CF*NC*NH*Zeta[3])/387420489 + 
       CF*Log[x]*((130251168370820477*NM*NC)/584366983200 - 
         (19399*lm*NM*NC)/1260 - (43164403*NC*NL)/132300 - 
         (19399*lm*NC*NL)/1260 - (151756932498216165949*NC*NH)/
          33576823742061600 - (19399*lm*NC*NH)/1260 + (3068842*NM*NC*Pi^2)/
          27 - (1028*NC*NL*Pi^2)/27 + (12143319920*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(12815045049884834506433/119280988610784000 + 
           (1626767771*Pi^2)/45360 + (31318699927*Im[PolyLog[2, (-1)^(1/3)]])/
            (14880348*Sqrt[3]) - 288*Zeta[3]) + 
         CA*NC*(-2554429492899781061473/47712395444313600 + 
           (213389*lm)/2520 - (1625289511*Pi^2)/90720 - 
           (31318699927*Im[PolyLog[2, (-1)^(1/3)]])/(29760696*Sqrt[3]) + 
           144*Zeta[3])), (574728075548263212818071158359*CF^2*NC)/
        696342372303670380288000 + (63129644300570186727989*CF*NM*NC)/
        210582486065952000 + (81180941*CF*lm*NM*NC)/85730400 + 
       (8260573819*CF*NC*NL)/857304000 + (81180941*CF*lm*NC*NL)/85730400 - 
       (274449091641196767139837*CF*NC*NH)/226085185812879993600 + 
       (81180941*CF*lm*NC*NH)/85730400 - (86568488805509*CF^2*NC*Pi^2)/
        342921600 - (4805034929*CF*NM*NC*Pi^2)/51030 - 
       (CF*lm*NM*NC*Pi^2)/81 - (33449*CF*NC*NL*Pi^2)/102060 - 
       (CF*lm*NC*NL*Pi^2)/81 - (CF*lm*NC*NH*Pi^2)/81 + 
       (6774526489*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) + 
       (50185702840*CF*NC*NH*Pi^3)/(387420489*Sqrt[3]) - 
       (203*CF^2*NC*Pi^4)/360 - (15041144455156213*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15186883168800*Sqrt[3]) + 
       (17376968833408*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (13559717115*Sqrt[3]) - (178*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        3 + (6774526489*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (37200870*Sqrt[3]) + (22942035584*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) + 
       (6774526489*CF^2*NC*Pi*Log[3]^2)/(1785641760*Sqrt[3]) + 
       (1433877224*CF*NC*NH*Pi*Log[3]^2)/(14348907*Sqrt[3]) - 
       (CF*NC*(-9*CA*(350028953963052771634761 - 33000473955125476800*lm + 
            133355572631332683231600*Pi^2 + 10860931706407182400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]]) + 
          20*(9*CF*(35001506507327702328783 + 13334622067048951829160*Pi^2 + 
              1086093170640718240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
            28*(98415*NM*(48884436625661269 - 979829867016*lm + 
                15983597067197760*Pi^2) + 11*(9220855644*NL*(75283 - 
                  950710*lm + 235200*Pi^2) + NH*(-1456678693944580569 - 
                  8766359669307240*lm + 835925185352857600*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])))))*Log[x])/
        9661760077473504000 - 
       (CF*NC*(-3*CA*(2064323746299263 + 62154892800*lm) + 
          28*(442282681108783*CF + 60*((2748343578847 + 20180160*lm)*NM + 
              11*(229320*(-9 + 8*lm)*NL + (1721929 + 1834560*lm)*NH))))*
         Log[x]^2)/4086482400 + (CF*NC*(4225610095*CA - 8461964013*CF + 
          1680*(-1845103*NM + 28*NL))*Log[x]^3)/8505 - 
       (2345052174197831*CF^2*NC*PolyGamma[2, 1])/1162261467 - 
       (81727406*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (340959400739*CF*NC*NH*PolyGamma[2, 1])/2324522934 - 
       (575412637221490013*CF^2*NC*Zeta[3])/162716605380 - 
       (148711480*CF*NM*NC*Zeta[3])/81 - (220*CF*NC*NL*Zeta[3])/27 - 
       (1454549375195*CF*NC*NH*Zeta[3])/1162261467 + 
       CA*CF*NC*(-718539757410574082818591982191/1740855930759175950720000 + 
         (952268726484049*Pi^2)/7544275200 - (6774526489*Pi^3)/
          (2754990144*Sqrt[3]) + (1763*Pi^4)/6480 + 
         lm*(-892990351/171460800 + (11*Pi^2)/162) + 
         (15041144455156213*Im[PolyLog[2, (-1)^(1/3)]])/(30373766337600*
           Sqrt[3]) + (89*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (6774526489*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74401740*Sqrt[3]) - (6774526489*Pi*Log[3]^2)/
          (3571283520*Sqrt[3]) + (2345052174197831*PolyGamma[2, 1])/
          2324522934 + (575431009131545603*Zeta[3])/325433210760), 
      (-3300299662475351381243495125417*CF^2*NC)/3481711861518351901440000 - 
       (167561261106818649003811*CF*NM*NC)/60166424590272000 + 
       (171208259*CF*lm*NM*NC)/57153600 + (3749034287431*CF*NC*NL)/
        12002256000 + (171208259*CF*lm*NC*NL)/57153600 + 
       (232998526138834726965010438159693*CF*NC*NH)/
        33522187407574985078480801280 + (171208259*CF*lm*NC*NH)/57153600 + 
       (3247139673321223*CF^2*NC*Pi^2)/10897286400 + 
       (2864724223*CF*NM*NC*Pi^2)/3402 + (CF*lm*NM*NC*Pi^2)/54 - 
       (558401*CF*NC*NL*Pi^2)/68040 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (1917007865677*CF^2*NC*Pi^3)/
        (8264970432*Sqrt[3]) - (224855555155*CF*NC*NH*Pi^3)/
        (258280326*Sqrt[3]) - (7433*CF^2*NC*Pi^4)/2160 + 
       (47306675181135323*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (30373766337600*Sqrt[3]) + (27972440620277*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(13559717115*Sqrt[3]) - 
       (961*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (1917007865677*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (223205220*Sqrt[3]) - (51395555464*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (1917007865677*CF^2*NC*Pi*Log[3]^2)/(10713850560*Sqrt[3]) - 
       (6424444433*CF*NC*NH*Pi*Log[3]^2)/(9565938*Sqrt[3]) + 
       (CF*NC*(47481*CA*(-11015789020537 + 10827273600*lm) + 
          10*(104744085457756903*CF - 56*(323*(-16385199547909 + 
                516756240*lm)*NM + 232792560*(904 + 717*lm)*NL + 
              (61134332681 + 166912265520*lm)*NH)))*Log[x]^2)/293318625600 + 
       (CF*NC*(-9757154405*CA + 19184440954*CF + 56869706880*NM + 
          3613680*NL)*Log[x]^3)/17010 + (42209867046212773*CF^2*NC*
         PolyGamma[2, 1])/13947137604 + (326881345*CF*NM*NC*PolyGamma[2, 1])/
        54 - (534337602563*CF*NC*NH*PolyGamma[2, 1])/6973568802 + 
       CA*CF*NC*(1649459390207584148408773206629/3481711861518351901440000 - 
         (749327346842533*Pi^2)/5029516800 + (1917007865677*Pi^3)/
          (16529940864*Sqrt[3]) + (833*Pi^4)/480 + 
         lm*(-1883290849/114307200 - (11*Pi^2)/108) - 
         (47306675181135323*Im[PolyLog[2, (-1)^(1/3)]])/(60747532675200*
           Sqrt[3]) + (961*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (1917007865677*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (446410440*Sqrt[3]) + (1917007865677*Pi*Log[3]^2)/
          (21427701120*Sqrt[3]) - (42209867046212773*PolyGamma[2, 1])/
          27894275208 - (5351922167516494163*Zeta[3])/1952599264560) + 
       (5352206758859303783*CF^2*NC*Zeta[3])/976299632280 + 
       (281799847*CF*NM*NC*Zeta[3])/27 - (2870*CF*NC*NL*Zeta[3])/9 + 
       (7242999573949*CF*NC*NH*Zeta[3])/3486784401 + 
       CF*Log[x]*((1198380131621787281*NM*NC)/584366983200 - 
         (219671*lm*NM*NC)/11340 - (2200494809*NC*NL)/4762800 - 
         (219671*lm*NC*NL)/11340 - (509538178617524327719769*NC*NH)/
          80000140247835968160 - (219671*lm*NC*NH)/11340 + 
         (2507456*NM*NC*Pi^2)/3 - (478*NC*NL*Pi^2)/9 + 
         (51395555464*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(978254986953503683078027/1073528897497056000 + 
           (38923504591*Pi^2)/136080 + (1917007865677*
             Im[PolyLog[2, (-1)^(1/3)]])/(669615660*Sqrt[3]) - 360*Zeta[3]) + 
         CA*NC*(-39109007158653672043327/85882311799764480 + 
           (2416381*lm)/22680 - (38917347811*Pi^2)/272160 - 
           (1917007865677*Im[PolyLog[2, (-1)^(1/3)]])/(1339231320*Sqrt[3]) + 
           180*Zeta[3])), (328562302842188653546921558357868341*CF^2*NC)/
        51316951126918988675324160000 + (71779457527762336534481993*CF*NM*
         NC)/29843992905058332000 + (89189893*CF*lm*NM*NC)/85730400 + 
       (158026039769*CF*NC*NL)/12002256000 + (89189893*CF*lm*NC*NL)/
        85730400 - (31416609813833050250585848027*CF*NC*NH)/
        18327482545328210241187200 + (89189893*CF*lm*NC*NH)/85730400 - 
       (19446871143694811*CF^2*NC*Pi^2)/9807557760 - 
       (77803568603*CF*NM*NC*Pi^2)/102060 - (CF*lm*NM*NC*Pi^2)/81 - 
       (1985*CF*NC*NL*Pi^2)/5103 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (398077129379*CF^2*NC*Pi^3)/
        (37192366944*Sqrt[3]) + (428635560535*CF*NC*NH*Pi^3)/
        (2324522934*Sqrt[3]) - (2303*CF^2*NC*Pi^4)/3240 - 
       (59418910888229531*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (45560649506400*Sqrt[3]) + (64533770116859*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40679151345*Sqrt[3]) - 
       (218*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (398077129379*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1004423490*Sqrt[3]) + (97973842408*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) + 
       (398077129379*CF^2*NC*Pi*Log[3]^2)/(48212327520*Sqrt[3]) + 
       (12246730301*CF*NC*NH*Pi*Log[3]^2)/(86093442*Sqrt[3]) - 
       (CF*NC*(-(CA*(23577907002921937540763353149 - 321624448110255778488000*
              lm + 8064194585251424901590509200*Pi^2 + 
             184439190424963924049600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          4*(CF*(11788846862247834661131995559 + 4032046754217630908712552600*
               Pi^2 + 92219595212481962024800*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]]) + 140*(6281378591202*NL*(5546027 - 
                16624300*lm + 4586400*Pi^2) + 11514555*NM*(
                3110915118644992957 - 9068828288520*lm + 948099544115724000*
                 Pi^2) + NH*(-19793465804537863088991 - 
                104423522113719408600*lm + 11348439060505711964800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]]))))*Log[x])/
        8376745987169527968000 - 
       (CF*NC*(-(CA*(826570182178614281 + 4415217206400*lm)) + 
          224*(7379878051752322*CF + 15*(156*(1212430055077 + 1531530*lm)*
               NM + 4594590*(-61 + 52*lm)*NL + (243421901 + 238918680*lm)*
               NH)))*Log[x]^2)/69470200800 - 
       (CF*NC*(-32750007841*CA + 65516565067*CF + 65520*(378902*NM - NL))*
         Log[x]^3)/8505 - (189961340651860220*CF^2*NC*PolyGamma[2, 1])/
        10460353203 - (2942007949*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (8153179442773*CF*NC*NH*PolyGamma[2, 1])/41841412812 - 
       (47545619311855186973*CF^2*NC*Zeta[3])/1464449448420 - 
       (2705625901*CF*NM*NC*Zeta[3])/162 - (308*CF*NC*NL*Zeta[3])/27 - 
       (34497772694773*CF*NC*NH*Zeta[3])/20920706406 + 
       CA*CF*NC*(-6571447262384204677877097779966039/
          2052678045076759547012966400 + (1495916799839597*Pi^2)/1508855040 - 
         (398077129379*Pi^3)/(74384733888*Sqrt[3]) + (2239*Pi^4)/6480 + 
         lm*(-981088823/171460800 + (11*Pi^2)/162) + 
         (59418910888229531*Im[PolyLog[2, (-1)^(1/3)]])/(91121299012800*
           Sqrt[3]) + (109*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (398077129379*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2008846980*Sqrt[3]) - (398077129379*Pi*Log[3]^2)/
          (96424655040*Sqrt[3]) + (94980670325930110*PolyGamma[2, 1])/
          10460353203 + (47545845243861757103*Zeta[3])/2928898896840), 
      (-10582080613189049990053594662041237909*CF^2*NC)/
        1385557680426812694233752320000 - (44062483546593097116313035047*CF*
         NM*NC)/2069183508084044352000 + (38039191*CF*lm*NM*NC)/11430720 + 
       (10304121552199*CF*NC*NL)/24004512000 + (38039191*CF*lm*NC*NL)/
        11430720 + (127513308610420572502317823650296879*CF*NC*NH)/
        13576485900067868956784724518400 + (38039191*CF*lm*NC*NH)/11430720 + 
       (2397893980144723*CF^2*NC*Pi^2)/990662400 + 
       (222399568411*CF*NM*NC*Pi^2)/34020 + (CF*lm*NM*NC*Pi^2)/54 - 
       (684149*CF*NC*NL*Pi^2)/68040 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (614206387514381*CF^2*NC*Pi^3)/
        (2008387814976*Sqrt[3]) - (149104253771725*CF*NC*NH*Pi^3)/
        (125524238436*Sqrt[3]) - (3053*CF^2*NC*Pi^4)/720 + 
       (5212145270429226149*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2460275073345600*Sqrt[3]) + (672490971254302*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(219667417263*Sqrt[3]) - 
       389*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (614206387514381*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (54238868460*Sqrt[3]) - (17040486145340*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (614206387514381*CF^2*NC*Pi*Log[3]^2)/(2603465686080*Sqrt[3]) - 
       (4260121536335*CF*NC*NH*Pi*Log[3]^2)/(4649045868*Sqrt[3]) + 
       ((74718027632732137*CF^2*NC)/2572970400 + 
         CA*CF*(-224105644927902841/15437822400 + 2365*lm)*NC + 
         CF*NC*((2162591238702809/27567540 - 430*lm)*NM - 
           (5*(323 + 258*lm)*NL)/3 - (17295941269*NH)/104756652 - 
           430*lm*NH))*Log[x]^2 + (CF*NC*(-26217285275*CA + 52273330442*CF + 
          144843395760*NM + 1625400*NL)*Log[x]^3)/5670 + 
       (3419291705124444163*CF^2*NC*PolyGamma[2, 1])/125524238436 + 
       (2941968001*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (6581196594875*CF*NC*NH*PolyGamma[2, 1])/62762119218 + 
       CA*CF*NC*(21162748909019011643181934698166909/
          5542230721707250776935009280 - (79130288770331399*Pi^2)/
          65383718400 + (614206387514381*Pi^3)/(4016775629952*Sqrt[3]) + 
         (9223*Pi^4)/4320 - (11*lm*(38039191 + 211680*Pi^2))/22861440 - 
         (5212145270429226149*Im[PolyLog[2, (-1)^(1/3)]])/
          (4920550146691200*Sqrt[3]) + (389*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (614206387514381*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (108477736920*Sqrt[3]) + (614206387514381*Pi*Log[3]^2)/
          (5206931372160*Sqrt[3]) - (3419291705124444163*PolyGamma[2, 1])/
          251048476872 - (438103435846674075209*Zeta[3])/17573393381040) + 
       (438106835159277068789*CF^2*NC*Zeta[3])/8786696690520 + 
       (2597174857*CF*NM*NC*Zeta[3])/27 - (3872*CF*NC*NL*Zeta[3])/9 + 
       (87571280323861*CF*NC*NH*Zeta[3])/31381059609 + 
       CF*Log[x]*((93854463522622835443*NM*NC)/5277564317025 - 
         (269819*lm*NM*NC)/11340 - (2003657911*NC*NL)/3175200 - 
         (269819*lm*NC*NL)/11340 - (84388929408929764662668633*NC*NH)/
          9720017040112070131440 - (269819*lm*NC*NH)/11340 + 
         (57477493*NM*NC*Pi^2)/9 - (215*NC*NL*Pi^2)/3 + 
         (17040486145340*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(579477267240488434028006102663/
            75390713884525751712000 + (104821790279*Pi^2)/45360 + 
           (614206387514381*Im[PolyLog[2, (-1)^(1/3)]])/(162716605380*
             Sqrt[3]) - 440*Zeta[3]) + CA*NC*(-579427750264426791414273399311/
            150781427769051503424000 + (2968009*lm)/22680 - 
           (104819031019*Pi^2)/90720 - (614206387514381*
             Im[PolyLog[2, (-1)^(1/3)]])/(325433210760*Sqrt[3]) + 
           220*Zeta[3])), (480724347773663829876578476597561158539431*CF^2*
         NC)/9503540130047508269749307162880000 + 
       (416024997671061879527560110832003*CF*NM*NC)/
        21288794522922690315552000 + (2351898449*CF*lm*NM*NC)/2074675680 + 
       (3635585361311*CF*NC*NL)/207467568000 + (2351898449*CF*lm*NC*NL)/
        2074675680 - (1556830425508575851969920049726977*CF*NC*NH)/
        665514014709209262587486496000 + (2351898449*CF*lm*NC*NH)/
        2074675680 - (1221374159974050781*CF^2*NC*Pi^2)/77059382400 - 
       (1753262600422*CF*NM*NC*Pi^2)/280665 - (CF*lm*NM*NC*Pi^2)/81 - 
       (512111*CF*NC*NL*Pi^2)/1122660 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (207917329693477*CF^2*NC*Pi^3)/
        (11046132982368*Sqrt[3]) + (5305869416645*CF*NC*NH*Pi^3)/
        (20920706406*Sqrt[3]) - (2833*CF^2*NC*Pi^4)/3240 - 
       (249751224229524948863*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (148846641937408800*Sqrt[3]) + (701513879763346*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) - 
       (262*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (207917329693477*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (298313776530*Sqrt[3]) + (1212770152376*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) + 
       (207917329693477*CF^2*NC*Pi*Log[3]^2)/(14319061273440*Sqrt[3]) + 
       (151596269047*CF*NC*NH*Pi*Log[3]^2)/(774840978*Sqrt[3]) - 
       (CF*NC*(-(CA*(21477129006385270311924449946435861 - 
             42097751401352283566044315200*lm + 
             6849440876781106296286074243562800*Pi^2 + 
             34776339832923252876204692800*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]])) + 4*(CF*(10738545227728427454824696842478769 + 
              3424713173658817384159702429943400*Pi^2 + 
              17388169916461626438102346400*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]]) + 4620*(3188646*NM*(
                310879759087671314718649 - 129893654532221580*lm + 
                90548086731393542050800*Pi^2) + 17*(381971639838789*NL*
                 (37701437 - 63784360*lm + 19404000*Pi^2) - 4*NH*
                 (1301707275753769317541707 + 6090954146316914885010*lm - 
                  745766340875220015551200*Sqrt[3]*Im[PolyLog[2, (-1)^
                      (1/3)]])))))*Log[x])/898129574506355280145056000 - 
       (CF*NC*(-9*CA*(153420594910199369323 + 138022708824000*lm) + 
          4*(690389342666145891641*CF + 4620*(21*(2804549313816641 + 
                581981400*lm)*NM + 17*(51351300*(-17 + 14*lm)*NL + 
                (782981813 + 718918200*lm)*NH))))*Log[x]^2)/14519271967200 + 
       (CF*NC*(2853918308697*CA - 5708105138461*CF - 2223144665280*NM + 
          970200*NL)*Log[x]^3)/93555 - (15387019179173692109*CF^2*NC*
         PolyGamma[2, 1])/94143178827 - (13238907593*CF*NM*NC*
         PolyGamma[2, 1])/162 - (23779461007273*CF*NC*NH*PolyGamma[2, 1])/
        94143178827 - (42968767684303221204769*CF^2*NC*Zeta[3])/
        144980495393580 - (12276545153*CF*NM*NC*Zeta[3])/81 - 
       (416*CF*NC*NL*Zeta[3])/27 - (199833770375018*CF*NC*NH*Zeta[3])/
        94143178827 + CA*CF*NC*(-165249821845421311989050987891713138102291/
          6533683839407661935452648674480000 + (1221374594543076331*Pi^2)/
          154118764800 - (207917329693477*Pi^3)/(22092265964736*Sqrt[3]) + 
         (923*Pi^4)/2160 + lm*(-2351898449/377213760 + (11*Pi^2)/162) + 
         (249751224229524948863*Im[PolyLog[2, (-1)^(1/3)]])/
          (297693283874817600*Sqrt[3]) + (131*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 - (207917329693477*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (596627553060*Sqrt[3]) - (207917329693477*Pi*Log[3]^2)/
          (28638122546880*Sqrt[3]) + (15387019179173692109*PolyGamma[2, 1])/
          188286357654 + (42968797365032417057119*Zeta[3])/289960990787160), 
      (-19494194075621590778160502175598528289779859*CF^2*NC)/
        313616824291567772901727136375040000 - 
       (2361757611459676602846812279165111*CF*NM*NC)/
        14192529681948460210368000 + (5062511071*CF*lm*NM*NC)/1383117120 + 
       (237500285627579*CF*NC*NL)/414935136000 + (5062511071*CF*lm*NC*NL)/
        1383117120 + (6126469790933857596997594875103369603909*CF*NC*NH)/
        495555311838377284791599229646118400 + (5062511071*CF*lm*NC*NH)/
        1383117120 + (475866866626911689*CF^2*NC*Pi^2)/23974030080 + 
       (3874132220275*CF*NM*NC*Pi^2)/74844 + (CF*lm*NM*NC*Pi^2)/54 - 
       (9047719*CF*NC*NL*Pi^2)/748440 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (26055674551528867*CF^2*NC*Pi^3)/
        (66276797894208*Sqrt[3]) - (593767011462625*CF*NC*NH*Pi^3)/
        (376572715308*Sqrt[3]) - (2213*CF^2*NC*Pi^4)/432 + 
       (357278127694720546319*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (127582835946350400*Sqrt[3]) + (14349938453715296*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3295011258945*Sqrt[3]) - 
       (1393*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (3722239221646981*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (255697522740*Sqrt[3]) - (67859087024300*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) - 
       (3722239221646981*CF^2*NC*Pi*Log[3]^2)/(12273481091520*Sqrt[3]) - 
       (16964771756075*CF*NC*NH*Pi*Log[3]^2)/(13947137604*Sqrt[3]) + 
       (CF*NC*(23*CA*(-1152707284799642284813 + 30061345981867200*lm) + 
          2*(26513187467369817805109*CF - 9240*(161*(-46478442672580007 + 
                42251849640*lm)*NM + 14724129420*(575 + 462*lm)*NL + 
              (2716485695089 + 6802547792040*lm)*NH)))*Log[x]^2)/
        222628836830400 + (CF*NC*(-7060400820007*CA + 
          10*(1411325659889*CF + 8316*(450413132*NM + 847*NL)))*Log[x]^3)/
        187110 + (276966204243101076229*CF^2*NC*PolyGamma[2, 1])/
        1129718145924 + (26477760721*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (78632109457139*CF*NC*NH*PolyGamma[2, 1])/564859072962 + 
       CA*CF*NC*(2436748989338144281116759505444071684189017/
          78404206072891943225431784093760000 - (95173334191912393*Pi^2)/
          9589612032 + (26055674551528867*Pi^3)/(132553595788416*Sqrt[3]) + 
         (11129*Pi^4)/4320 + lm*(-5062511071/251475840 - (11*Pi^2)/108) - 
         (357278127694720546319*Im[PolyLog[2, (-1)^(1/3)]])/
          (255165671892700800*Sqrt[3]) + (1393*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          6 + (3722239221646981*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (511395045480*Sqrt[3]) + (3722239221646981*Pi*Log[3]^2)/
          (24546962183040*Sqrt[3]) - (276966204243101076229*PolyGamma[2, 1])/
          2259436291848 - (393707861781039991355749*Zeta[3])/
          1739765944722960) + (393708298188440069964169*CF^2*NC*Zeta[3])/
        869882972361480 + (23775376897*CF*NM*NC*Zeta[3])/27 - 
       (5084*CF*NC*NL*Zeta[3])/9 + (1030960316904289*CF*NC*NH*Zeta[3])/
        282429536481 + CF*Log[x]*((57634137517015392075947*NM*NC)/
          381040143689205 - (3575329*lm*NM*NC)/124740 - 
         (1789764077*NC*NL)/2138400 - (3575329*lm*NC*NL)/124740 - 
         (888132703924270702502377454641*NC*NH)/77128335213289276492976400 - 
         (3575329*lm*NC*NH)/124740 + (450413143*NM*NC*Pi^2)/9 - 
         (847*NC*NL*Pi^2)/9 + (67859087024300*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3486784401*Sqrt[3]) + 
         CF*NC*(58287153720042092288422711003225021/
            898129574506355280145056000 + (28239548937953*Pi^2)/1496880 + 
           (3722239221646981*Im[PolyLog[2, (-1)^(1/3)]])/(767092568220*
             Sqrt[3]) - 528*Zeta[3]) + 
         CA*NC*(-11657277613876606424373731154128393/
            359251829802542112058022400 + (3575329*lm)/22680 - 
           (28239429700373*Pi^2)/2993760 - (3722239221646981*
             Im[PolyLog[2, (-1)^(1/3)]])/(1534185136440*Sqrt[3]) + 
           264*Zeta[3])), (286331760497068378954337230746036291427884161*CF^2*
         NC)/705637854656027489028886056843840000 + 
       (683263717241282354387229526523147*CF*NM*NC)/
        4257758904584538063110400 + (2545166699*CF*lm*NM*NC)/2074675680 + 
       (595932704330141*CF*NC*NL)/26140913568000 + (2545166699*CF*lm*NC*NL)/
        2074675680 - (2844802745530456515896933452623473179*CF*NC*NH)/
        916412798254581154582968904992000 + (2545166699*CF*lm*NC*NH)/
        2074675680 - (299858419784559523*CF^2*NC*Pi^2)/2335132800 - 
       (429673737985*CF*NM*NC*Pi^2)/8316 - (CF*lm*NM*NC*Pi^2)/81 - 
       (594221*CF*NC*NL*Pi^2)/1122660 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (8845028043282325*CF^2*NC*Pi^3)/
        (298245590523936*Sqrt[3]) + (1149240318557345*CF*NC*NH*Pi^3)/
        (3389154437772*Sqrt[3]) - (1139*CF^2*NC*Pi^4)/1080 - 
       (1701668144467632169237*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (803771866462007520*Sqrt[3]) + (9600519796820567*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) - 
       (310*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (1769005608656465*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1610894393262*Sqrt[3]) + (131341750692268*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) + 
       (1769005608656465*CF^2*NC*Pi*Log[3]^2)/(77322930876576*Sqrt[3]) + 
       (32835437673067*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) + 
       CF*((-576886986407703597497153*NM*NC)/3325441254014880 + 
         (955487*lm*NM*NC)/93555 - (8195732197*NC*NL)/943034400 + 
         (955487*lm*NC*NL)/93555 + (6394837318276427680268815429*NC*NH)/
          2624404600830258935488800 + (955487*lm*NC*NH)/93555 - 
         (3961817863*NM*NC*Pi^2)/81 - (275*NC*NL*Pi^2)/81 - 
         (131341750692268*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (-327094598677705258970204582114122871/
            808316617055719752130550400 - (18376045301419*Pi^2)/149688 - 
           (1769005608656465*Im[PolyLog[2, (-1)^(1/3)]])/(4832683179786*
             Sqrt[3])) + CA*NC*(233639075357491762862077636131516361/
            1154738024365313931615072000 - (955487*lm)/17010 + 
           (18376051624351*Pi^2)/299376 + (1769005608656465*
             Im[PolyLog[2, (-1)^(1/3)]])/(9665366359572*Sqrt[3])))*Log[x] - 
       (CF*NC*(-7*CA*(319619904037582383871 + 46477034604000*lm) + 
          6*(745779196774125154643*CF + 616*(12*(40594494671846611 + 
                1333707375*lm)*NM + 4001122125*(-5 + 4*lm)*NL + 
              4*(4606078088 + 4001122125*lm)*NH)))*Log[x]^2)/2903854393440 + 
       (CF*NC*(22970050042421*CA - 4*(11485120610441*CF + 
            28875*(158472260*NM - 11*NL)))*Log[x]^3)/93555 - 
       (1246350367079420719256*CF^2*NC*PolyGamma[2, 1])/847288609443 - 
       (79433327621*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (1087006889365963*CF*NC*NH*PolyGamma[2, 1])/3389154437772 - 
       (703677165053883037808117*CF^2*NC*Zeta[3])/260964891708444 - 
       (74150953721*CF*NM*NC*Zeta[3])/54 - (182*CF*NC*NL*Zeta[3])/9 - 
       (4540095005914699*CF*NC*NH*Zeta[3])/1694577218886 + 
       CA*CF*NC*(-40904569638979030478385276814846194264339887/
          201610815616007854008253159098240000 + (299858435041541003*Pi^2)/
          4670265600 - (8845028043282325*Pi^3)/(596491181047872*Sqrt[3]) + 
         (3353*Pi^4)/6480 + lm*(-2545166699/377213760 + (11*Pi^2)/162) + 
         (1701668144467632169237*Im[PolyLog[2, (-1)^(1/3)]])/
          (1607543732924015040*Sqrt[3]) + (155*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 - (1769005608656465*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3221788786524*Sqrt[3]) - (1769005608656465*Pi*Log[3]^2)/
          (154645861753152*Sqrt[3]) + (623175183539710359628*PolyGamma[2, 1])/
          847288609443 + (703677234248240805984065*Zeta[3])/521929783416888), 
      (-1152444507876145507309435950548223937807366421*CF^2*NC)/
        2258041134899287964892435381900288000 - 
       (18778964369103658684907659138063997*CF*NM*NC)/
        14192529681948460210368000 + (5522482891*CF*lm*NM*NC)/1383117120 + 
       (2548227725293757*CF*NC*NL)/3423214872000 + (5522482891*CF*lm*NC*NL)/
        1383117120 + (333622764162973231053263325037738405302979*CF*NC*NH)/
        20958636308953926518441696742552000000 + (5522482891*CF*lm*NC*NH)/
        1383117120 + (8428140899153396693*CF^2*NC*Pi^2)/51372921600 + 
       (4325523777929*CF*NM*NC*Pi^2)/10395 + (CF*lm*NM*NC*Pi^2)/54 - 
       (10708609*CF*NC*NL*Pi^2)/748440 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (26834082699908549*CF^2*NC*Pi^3)/
        (54226471004352*Sqrt[3]) - (3466011023822375*CF*NC*NH*Pi^3)/
        (1694577218886*Sqrt[3]) - (13151*CF^2*NC*Pi^4)/2160 + 
       (2641199959513617259441*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (730701696783643200*Sqrt[3]) + (279093711385676353*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(46600873519365*Sqrt[3]) - 
       (1639*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (26834082699908549*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1464449448420*Sqrt[3]) - (792231091159400*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) - 
       (26834082699908549*CF^2*NC*Pi*Log[3]^2)/(70293573524160*Sqrt[3]) - 
       (99028886394925*CF*NC*NH*Pi*Log[3]^2)/(62762119218*Sqrt[3]) + 
       (CF*NC*(69*CA*(-3175970125945905250553 + 12863716462396800*lm) + 
          2*(219143122542400884545677*CF - 1848*(115*(-2615453262249631103 + 
                379684665360*lm)*NM + 19*(234834600*(12119 + 9786*lm)*NL + 
                (948651287989 + 2298091395600*lm)*NH))))*Log[x]^2)/
        222628836830400 + (CF*NC*(-29067411388457*CA + 58129621806637*CF + 
          27720*(5390670770*NM + 1631*NL))*Log[x]^3)/93555 + 
       (22434305036391740476339*CF^2*NC*PolyGamma[2, 1])/10167463313316 + 
       (238299910721*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (916380876779003*CF*NC*NH*PolyGamma[2, 1])/5083731656658 + 
       CA*CF*NC*(180069170799124268983624148969102941047877031/
          705637854656027489028886056843840000 - (8428140386522455343*Pi^2)/
          102745843200 + (26834082699908549*Pi^3)/(108452942008704*Sqrt[3]) + 
         (881*Pi^4)/288 + lm*(-5522482891/251475840 - (11*Pi^2)/108) - 
         (2641199959513617259441*Im[PolyLog[2, (-1)^(1/3)]])/
          (1461403393567286400*Sqrt[3]) + (1639*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          6 + (26834082699908549*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2928898896840*Sqrt[3]) + (26834082699908549*Pi*Log[3]^2)/
          (140587147048320*Sqrt[3]) - (22434305036391740476339*
           PolyGamma[2, 1])/20334926626632 - (32116433230818869580850813*
           Zeta[3])/15657893502506640) + (32116438224092111431139593*CF^2*NC*
         Zeta[3])/7828946751253320 + (216737349863*CF*NM*NC*Zeta[3])/27 - 
       (6526*CF*NC*NL*Zeta[3])/9 + (11870898816934753*CF*NC*NH*Zeta[3])/
        2541865828329 + CF*Log[x]*((25988209820290226730644723*NM*NC)/
          20322140996757600 - (4238299*lm*NM*NC)/124740 - 
         (267599090981*NC*NL)/246985200 - (4238299*lm*NC*NL)/124740 - 
         (27266313837037848128836229564501*NC*NH)/
          1826723728735798653781020000 - (4238299*lm*NC*NH)/124740 + 
         (10781341814*NM*NC*Pi^2)/27 - (3262*NC*NL*Pi^2)/27 + 
         (792231091159400*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*(554930800213359106745223966921061439/
            1010395771319649690163188000 + (232536651457889*Pi^2)/1496880 + 
           (26834082699908549*Im[PolyLog[2, (-1)^(1/3)]])/(4393348345260*
             Sqrt[3]) - 624*Zeta[3]) + 
         CA*NC*(-4439437642752107132026707197016450673/
            16166332341114395042611008000 + (4238299*lm)/22680 - 
           (232536498725309*Pi^2)/2993760 - (26834082699908549*
             Im[PolyLog[2, (-1)^(1/3)]])/(8786696690520*Sqrt[3]) + 
           312*Zeta[3])), 
      (217936568727382499173485909328771785231409371062197*CF^2*NC)/
        66140115620028754943518777183435269120000 + 
       (344256734285170714030460735892458455991*CF*NM*NC)/
        259020762960400373069321184000 + (462765024461*CF*lm*NM*NC)/
        350620189920 + (3211279383675169*CF*NC*NL)/110445359824800 + 
       (462765024461*CF*lm*NC*NL)/350620189920 - 
       (8974413459902602865435849373594080873897*CF*NC*NH)/
        2229998903272697781562196533407532800 + (462765024461*CF*lm*NC*NH)/
        350620189920 - (737329518428452229333*CF^2*NC*Pi^2)/701240379840 - 
       (3141686545262527*CF*NM*NC*Pi^2)/7297290 - (CF*lm*NM*NC*Pi^2)/81 - 
       (8879873*CF*NC*NL*Pi^2)/14594580 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (56337730993069829*CF^2*NC*Pi^3)/
        (1292397558937056*Sqrt[3]) + (375146869432300*CF*NC*NH*Pi^3)/
        (847288609443*Sqrt[3]) - (811*CF^2*NC*Pi^4)/648 - 
       (66089455789873047592397*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (25155082487422087200*Sqrt[3]) + (171684439015340824*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(65241222927111*Sqrt[3]) - 
       (362*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (56337730993069829*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (34902711854010*Sqrt[3]) + (171495711740480*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) + 
       (56337730993069829*CF^2*NC*Pi*Log[3]^2)/(1675330168992480*Sqrt[3]) + 
       (10718481983780*CF*NC*NH*Pi*Log[3]^2)/(31381059609*Sqrt[3]) + 
       CF*((-71444790240087059952821531051*NM*NC)/48376856642781466800 + 
         (29318287*lm*NM*NC)/2432430 - (10276481291*NC*NL)/766215450 + 
         (29318287*lm*NC*NL)/2432430 + (441946407893120023072482469259*NC*
           NH)/138831003383920697687357520 + (29318287*lm*NC*NH)/2432430 - 
         (32895387752*NM*NC*Pi^2)/81 - (352*NC*NL*Pi^2)/81 - 
         (171495711740480*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (-63441516963102758642719133634618698998321/
            18529311251640615784672650336000 - (1390086649995961*Pi^2)/
            1389960 - (56337730993069829*Im[PolyLog[2, (-1)^(1/3)]])/
            (104708135562030*Sqrt[3])) + 
         CA*NC*(31720760254296358559644109276264682090191/
            18529311251640615784672650336000 - (29318287*lm)/442260 + 
           (1390086724972291*Pi^2)/2779920 + (56337730993069829*
             Im[PolyLog[2, (-1)^(1/3)]])/(209416271124060*Sqrt[3])))*Log[x] - 
       (CF*NC*(-(CA*(27388115829408268431345383 + 622569173927500800*lm)) + 
          2*(27388112518134405333255133*CF + 360360*
             (3*(10373150614853881193 + 52352460160*lm)*NM + 
              5*(981608628*(-41 + 32*lm)*NL + (37897550011 + 31411476096*lm)*
                 NH))))*Log[x]^2)/4341262318192800 + 
       (2*CF*NC*(1216325757716146*CA - 65*(37425460803641*CF + 
            40656*(373811059*NM - 4*NL)))*Log[x]^3)/1216215 - 
       (100954401015557762864891*CF^2*NC*PolyGamma[2, 1])/7625597484987 - 
       (536174843123*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (6102788908832369*CF*NC*NH*PolyGamma[2, 1])/15251194969974 - 
       (533836638028796054319527071*CF^2*NC*Zeta[3])/21809208807062820 - 
       (1006559009482*CF*NM*NC*Zeta[3])/81 - (700*CF*NC*NL*Zeta[3])/27 - 
       (25356951842530409*CF*NC*NH*Zeta[3])/7625597484987 + 
       CA*CF*NC*(-121616403650650201411253672772819173796221002093/
          73817093325924949713748635249369720000 + 
         (1474659047377488385519*Pi^2)/2804961519360 - 
         (56337730993069829*Pi^3)/(2584795117874112*Sqrt[3]) + 
         (3991*Pi^4)/6480 + lm*(-462765024461/63749125440 + (11*Pi^2)/162) + 
         (66089455789873047592397*Im[PolyLog[2, (-1)^(1/3)]])/
          (50310164974844174400*Sqrt[3]) + (181*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 - (56337730993069829*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (69805423708020*Sqrt[3]) - (56337730993069829*Pi*Log[3]^2)/
          (3350660337984960*Sqrt[3]) + (100954401015557762864891*
           PolyGamma[2, 1])/15251194969974 + (533836645366787069421830341*
           Zeta[3])/43618417614125640), 
      (-67857005484540786198010461558057535286699950689031459*CF^2*NC)/
        16072048095666987451275062855574770396160000 - 
       (141677119017708596111013099921620373817*CF*NM*NC)/
        13283116049251301183042112000 + (1011061526659*CF*lm*NM*NC)/
        233746793280 + (7677988501437812821*CF*NC*NL)/8099326387152000 + 
       (1011061526659*CF*lm*NC*NL)/233746793280 + 
       (100924461476278736905217454896554892856724153*CF*NC*NH)/
        5017497532363570008514942200166948800000 + 
       (1011061526659*CF*lm*NC*NH)/233746793280 + 
       (36160948700108201776759*CF^2*NC*Pi^2)/26491303238400 + 
       (304968286006607*CF*NM*NC*Pi^2)/90090 + (CF*lm*NM*NC*Pi^2)/54 - 
       (162607597*CF*NC*NL*Pi^2)/9729720 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (42706161216251003525*CF^2*NC*Pi^3)/
        (69789468182601024*Sqrt[3]) - (19840081642179575*CF*NC*NH*Pi^3)/
        (7625597484987*Sqrt[3]) - (571*CF^2*NC*Pi^4)/80 + 
       (11180846105957366313972617*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2445074017777426875840*Sqrt[3]) + (4703357416623226861*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(587171006343999*Sqrt[3]) - 
       635*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (8541232243250200705*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (376949288023308*Sqrt[3]) - (9069751607853520*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) - 
       (8541232243250200705*CF^2*NC*Pi*Log[3]^2)/(18093565825118784*
         Sqrt[3]) - (566859475490845*CF*NC*NH*Pi*Log[3]^2)/
        (282429536481*Sqrt[3]) + 
       (CF*NC*(5*CA*(-948138525696281465541727 + 581253219657766656*lm) + 
          6*(1580232171023546880712185*CF - 8008*((-489371611847546167483 + 
                10997586119520*lm)*NM + 3*(3866943080*(1169 + 948*lm)*NL + 
                (1556886970399 + 3665862039840*lm)*NH))))*Log[x]^2)/
        578834975759040 + (CF*NC*(-1044716156734438*CA + 
          7*(298485996715367*CF + 17160*(43602140393*NM + 2054*NL)))*
         Log[x]^3)/405405 + (1817179201037928351555349*CF^2*NC*
         PolyGamma[2, 1])/91507169819844 + (2144699279201*CF*NM*NC*
         PolyGamma[2, 1])/54 - (10459486628114339*CF*NC*NH*PolyGamma[2, 1])/
        45753584909922 + CA*CF*NC*
        (302932989230246373056384045735756804626130946845633/
          143500429425598102243527346924774735680000 - 
         (2127114610792019680417*Pi^2)/3116623910400 + 
         (42706161216251003525*Pi^3)/(139578936365202048*Sqrt[3]) + 
         (15481*Pi^4)/4320 + lm*(-1011061526659/42499416960 - 
           (11*Pi^2)/108) - (11180846105957366313972617*
           Im[PolyLog[2, (-1)^(1/3)]])/(4890148035554853751680*Sqrt[3]) + 
         (635*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (8541232243250200705*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (753898576046616*Sqrt[3]) + (8541232243250200705*Pi*Log[3]^2)/
          (36187131650237568*Sqrt[3]) - (1817179201037928351555349*
           PolyGamma[2, 1])/183014339639688 - (6803892973690106679694223003*
           Zeta[3])/366394707958655376) + (6803893119708575431995019655*CF^2*
         NC*Zeta[3])/183197353979327688 + (1970290871855*CF*NM*NC*Zeta[3])/
        27 - (8218*CF*NC*NL*Zeta[3])/9 + (134142176613865813*CF*NC*NH*
         Zeta[3])/22876792454961 + CF*Log[x]*
        ((116133939380672506805409101563*NM*NC)/10750412587284770400 - 
         (64439527*lm*NM*NC)/1621620 - (15442810620553*NC*NL)/11237826600 - 
         (64439527*lm*NC*NL)/1621620 - (1185444015178490969669908072625951*
           NC*NH)/62473951522764313959310884000 - (64439527*lm*NC*NH)/
          1621620 + (87204281384*NM*NC*Pi^2)/27 - (4108*NC*NL*Pi^2)/27 + 
         (9069751607853520*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (282429536481*Sqrt[3]) + CF*NC*
          (233133110272997536953496540458022494004577/
            50029140379429662618616155907200 + (1671542967715805*Pi^2)/
            1297296 + (8541232243250200705*Im[PolyLog[2, (-1)^(1/3)]])/
            (1130847864069924*Sqrt[3]) - 728*Zeta[3]) + 
         CA*NC*(-2331330425758051195957242613437158418949463/
            1000582807588593252372323118144000 + (64439527*lm)/294840 - 
           (1671542801313569*Pi^2)/2594592 - (8541232243250200705*
             Im[PolyLog[2, (-1)^(1/3)]])/(2261695728139848*Sqrt[3]) + 
           364*Zeta[3])), 
      (172343288849316689323324667317787886044575571500760977*CF^2*NC)/
        6377796863359915655267882085545543808000000 + 
       (179436830689667652303805862957672735889473*CF*NM*NC)/
        16188797685025023316832574000000 + (495372951461*CF*lm*NM*NC)/
        350620189920 + (451860337268089*CF*NC*NL)/12396928143600 + 
       (495372951461*CF*lm*NC*NL)/350620189920 - 
       (16040643305431412399877784273800798089574781*CF*NC*NH)/
        3135935957727231255321838875104343000000 + 
       (495372951461*CF*lm*NC*NH)/350620189920 - 
       (10563392853324980362321*CF^2*NC*Pi^2)/1216437393600 - 
       (10534734058674877*CF*NM*NC*Pi^2)/2918916 - (CF*lm*NM*NC*Pi^2)/81 - 
       (5061409*CF*NC*NL*Pi^2)/7297290 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (21506863650735053*CF^2*NC*Pi^3)/
        (352472061528288*Sqrt[3]) + (4320679188501305*CF*NC*NH*Pi^3)/
        (7625597484987*Sqrt[3]) - (4747*CF^2*NC*Pi^4)/3240 - 
       (198446442160880654921641*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (61744293378217850400*Sqrt[3]) + (8826931972406733277*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2935855031719995*Sqrt[3]) - 
       (418*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (21506863650735053*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9518921414730*Sqrt[3]) + (1975167629029168*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) + 
       (21506863650735053*CF^2*NC*Pi*Log[3]^2)/(456908227907040*Sqrt[3]) + 
       (123447976814323*CF*NC*NH*Pi*Log[3]^2)/(282429536481*Sqrt[3]) + 
       CF*((-5633532489690886116093946499*NM*NC)/447271233753526875 + 
         (34156417*lm*NM*NC)/2432430 - (1302920303093*NC*NL)/67426959600 + 
         (34156417*lm*NC*NL)/2432430 + (5683473855646432195665161102759*NC*
           NH)/1394507846490274865163189375 + (34156417*lm*NC*NH)/2432430 - 
         (274976297456*NM*NC*Pi^2)/81 - (442*NC*NL*Pi^2)/81 - 
         (1975167629029168*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (282429536481*Sqrt[3]) + CF*NC*
          (-8064353724788044256257445574678290929361779/
            277939668774609236770089755040000 - (80035436841419603*Pi^2)/
            9729720 - (21506863650735053*Im[PolyLog[2, (-1)^(1/3)]])/
            (28556764244190*Sqrt[3])) + 
         CA*NC*(366561536291779472441086787793499427275477/
            25267242615873566979099068640000 - (34156417*lm)/442260 + 
           (80035437499226753*Pi^2)/19459440 + (21506863650735053*
             Im[PolyLog[2, (-1)^(1/3)]])/(57113528488380*Sqrt[3])))*Log[x] - 
       (CF*NC*(-3*CA*(75397981590069621657385553 + 260582930753745600*lm) + 
          2*(226193940628302130033902929*CF + 144144*
             ((652187825966190230799 + 493035242700*lm)*NM + 
              7250518275*(-89 + 68*lm)*NL + 4*(154821073109 + 123258810675*
                 lm)*NH)))*Log[x]^2)/4341262318192800 - 
       (2*CF*NC*(-10004429521960779*CA + 20008863680391101*CF + 
          60060*(137488139576*NM - 221*NL))*Log[x]^3)/1216215 - 
       (8177306726649775256119124*CF^2*NC*PolyGamma[2, 1])/68630377364883 - 
       (19302293735441*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (134986076068871041*CF*NC*NH*PolyGamma[2, 1])/274521509459532 - 
       (304814978694563443239637178677*CF^2*NC*Zeta[3])/1373980154844957660 - 
       (18202388799977*CF*NM*NC*Zeta[3])/162 - (880*CF*NC*NL*Zeta[3])/27 - 
       (558305021964344929*CF*NC*NH*Zeta[3])/137260754729766 + 
       CA*CF*NC*(-75400190257080541560507234406989895496690201861262979/
          5580572255439926198359396824852350832000000 + 
         (8699264711296343722357*Pi^2)/2003543942400 - 
         (21506863650735053*Pi^3)/(704944123056576*Sqrt[3]) + 
         (1561*Pi^4)/2160 + lm*(-495372951461/63749125440 + (11*Pi^2)/162) + 
         (198446442160880654921641*Im[PolyLog[2, (-1)^(1/3)]])/
          (123488586756435700800*Sqrt[3]) + 
         (209*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (21506863650735053*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (19037842829460*Sqrt[3]) - (21506863650735053*Pi*Log[3]^2)/
          (913816455814080*Sqrt[3]) + (4088653363324887628059562*
           PolyGamma[2, 1])/68630377364883 + (304814979271049894504863210207*
           Zeta[3])/2747960309689915320), 
      (-2492421528679323376084307349978410560687985106262634257*CF^2*NC)/
        70906094539707297579154689068712222336000000 - 
       (1876378387548722910352893536783754881048663*CF*NM*NC)/
        21585063580033364422443432000000 + (1088844614899*CF*lm*NM*NC)/
        233746793280 + (49941649730237216059*CF*NC*NL)/42116497213190400 + 
       (1088844614899*CF*lm*NC*NL)/233746793280 + 
       (45905555894425684893481403413609276687484730724337*CF*NC*NH)/
        1835576209752226634065063879798075714248000000 + 
       (1088844614899*CF*lm*NC*NH)/233746793280 + 
       (23275952206766806561897*CF^2*NC*Pi^2)/2037792556800 + 
       (9017427100010215*CF*NM*NC*Pi^2)/324324 + (CF*lm*NM*NC*Pi^2)/54 - 
       (187807057*CF*NC*NL*Pi^2)/9729720 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (156043449734891732461*CF^2*NC*Pi^3)/
        (209368404547803072*Sqrt[3]) - (297791855598500725*CF*NC*NH*Pi^3)/
        (91507169819844*Sqrt[3]) - (17863*CF^2*NC*Pi^4)/2160 + 
       (29793838296011025587450111*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5239444323808771876800*Sqrt[3]) + (1198457304240800394394*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(114498346237079805*Sqrt[3]) - 
       (2191*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (22291921390698818923*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (807748474335660*Sqrt[3]) - (34033354925542940*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (22291921390698818923*CF^2*NC*Pi*Log[3]^2)/(38771926768111680*
         Sqrt[3]) - (8508338731385735*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) + 
       (CF*NC*(5423*CA*(-1060673683289372998510859 + 96264418027377600*lm) + 
          2*(5752034083557633864427926637*CF - 
            24024*(29*(-20097139671493890779867 + 68119176925800*lm)*NM + 
              452878526100*(5359 + 4362*lm)*NL + (859897721616173 + 
                1975456130848200*lm)*NH)))*Log[x]^2)/83931071485060800 + 
       (CF*NC*(-26155605679208372*CA + 52311091354424323*CF + 
          180180*(712972337614*NM + 5089*NL))*Log[x]^3)/1216215 + 
       (147191520892931727407213875*CF^2*NC*PolyGamma[2, 1])/
        823564528378596 + (19302293617217*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (117292412815563323*CF*NC*NH*PolyGamma[2, 1])/411782264189298 + 
       CA*CF*NC*(178030103098092382885121038851128329729641894074959763/
          10129442077101042511307812724101746048000000 - 
         (23275952178067385244407*Pi^2)/4075585113600 + 
         (156043449734891732461*Pi^3)/(418736809095606144*Sqrt[3]) + 
         (17927*Pi^4)/4320 + lm*(-1088844614899/42499416960 - 
           (11*Pi^2)/108) - (29793838296011025587450111*
           Im[PolyLog[2, (-1)^(1/3)]])/(10478888647617543753600*Sqrt[3]) + 
         (2191*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (22291921390698818923*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1615496948671320*Sqrt[3]) + (22291921390698818923*Pi*Log[3]^2)/
          (77543853536223360*Sqrt[3]) - (147191520892931727407213875*
           PolyGamma[2, 1])/1647129056757192 - 
         (251771231877265823971023829751*Zeta[3])/1498887441649044720) + 
       (251771232612706050086065762691*CF^2*NC*Zeta[3])/749443720824522360 + 
       (17876349133349*CF*NM*NC*Zeta[3])/27 - (10180*CF*NC*NL*Zeta[3])/9 + 
       (1491586646956933885*CF*NC*NH*Zeta[3])/205891132094649 + 
       CF*Log[x]*((12278080962637378116910823524723*NM*NC)/
          134380157341059630000 - (74503867*lm*NM*NC)/1621620 - 
         (1000889675967121*NC*NL)/584366983200 - (74503867*lm*NC*NL)/
          1621620 - (9347307512202574642088302601574479563*NC*NH)/
          394054449229835910298353400830000 - (74503867*lm*NC*NH)/1621620 + 
         (712972338629*NM*NC*Pi^2)/27 - (5089*NC*NL*Pi^2)/27 + 
         (34033354925542940*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CF*NC*
          (336513678756208123525215240728810625934951/
            8489107530446209720353420120000 + (19022253802777963*Pi^2)/
            1769040 + (22291921390698818923*Im[PolyLog[2, (-1)^(1/3)]])/
            (2423245423006980*Sqrt[3]) - 840*Zeta[3]) + 
         CA*NC*(-1590791869154632578332731844005135041594767/
            80260653015127800992432335680000 + (74503867*lm)/294840 - 
           (19022253522084823*Pi^2)/3538080 - (22291921390698818923*
             Im[PolyLog[2, (-1)^(1/3)]])/(4846490846013960*Sqrt[3]) + 
           420*Zeta[3])), 
      (64804703340021114533236869917200521089044001092320676597*CF^2*NC)/
        290070386753348035551087364372004545920000000 + 
       (81274485131942489620201859002699532683392211*CF*NM*NC)/
        874195074991351259108958996000000 + (2639808769393*CF*lm*NM*NC)/
        1753100949600 + (364527842164427723*CF*NC*NL)/8099326387152000 + 
       (2639808769393*CF*lm*NC*NL)/1753100949600 - 
       (166527509269072722810441761569129399554404633*CF*NC*NH)/
        26052391033426228890366046039328388000000 + 
       (2639808769393*CF*lm*NC*NH)/1753100949600 - 
       (287019730838208923994463*CF^2*NC*Pi^2)/3973695485760 - 
       (110951394473014024*CF*NM*NC*Pi^2)/3648645 - (CF*lm*NM*NC*Pi^2)/81 - 
       (2290801*CF*NC*NL*Pi^2)/2918916 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (77565672549903418835*CF^2*NC*Pi^3)/
        (942157820465113824*Sqrt[3]) + (293449694073906965*CF*NC*NH*Pi^3)/
        (411782264189298*Sqrt[3]) - (1831*CF^2*NC*Pi^4)/1080 - 
       (640838770755600032829544519*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (165042496199976314119200*Sqrt[3]) + (697692878106209459938*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(206097023226743649*Sqrt[3]) - 
       (478*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (15513134509980683767*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5088815388314658*Sqrt[3]) + (67074215788321592*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) + 
       (15513134509980683767*CF^2*NC*Pi*Log[3]^2)/(244263138639103584*
         Sqrt[3]) + (8384276973540199*CF*NC*NH*Pi*Log[3]^2)/
        (15251194969974*Sqrt[3]) + 
       CF*((-53258482180387174491253839218321*NM*NC)/494763306573901365000 + 
         (7871351*lm*NM*NC)/486486 - (22098988757*NC*NL)/832431600 + 
         (7871351*lm*NC*NL)/486486 + (10812564615443441711187271827691409*NC*
           NH)/2108495863893295596126742335000 + (7871351*lm*NC*NH)/
          486486 - (85604576474*NM*NC*Pi^2)/3 - (182*NC*NL*Pi^2)/27 - 
         (67074215788321592*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7625597484987*Sqrt[3]) + 
         CF*NC*(-699281870876919268144127033271489997059580601/
            2837787374463447249375286154400000 - (663475303288031537*Pi^2)/
            9729720 - (15513134509980683767*Im[PolyLog[2, (-1)^(1/3)]])/
            (15266446164943974*Sqrt[3])) + 
         CA*NC*(188268196276070759553312769138011081692850607/
            1528039355480317749663615621600000 - (7871351*lm)/88452 + 
           (663475304099412107*Pi^2)/19459440 + (15513134509980683767*
             Im[PolyLog[2, (-1)^(1/3)]])/(30532892329887948*Sqrt[3])))*
        Log[x] - (CF*NC*(-17*CA*(553357162470674213420763817 + 
            284026377811176000*lm) + 2*(9407071736507087866408235499*CF + 
            40040*((98910949110745125841031 + 10962783631800*lm)*NM + 
              11*(332205564600*(-4 + 3*lm)*NL + (1296387748549 + 
                  996616693800*lm)*NH))))*Log[x]^2)/21706311590964000 + 
       (2*CF*NC*(82934412801289972*CA - 11*(15078984702402749*CF + 
            16380*(385220590360*NM - 91*NL)))*Log[x]^3)/1216215 - 
       (662361847613906959823038145*CF^2*NC*PolyGamma[2, 1])/
        617673396283947 - (86860321415891*CF*NM*NC*PolyGamma[2, 1])/162 - 
       (368307958452642544*CF*NC*NH*PolyGamma[2, 1])/617673396283947 - 
       (24834503051881956380225075758327*CF^2*NC*Zeta[3])/
        12365821393604618940 - (82237674446891*CF*NM*NC*Zeta[3])/81 - 
       (1088*CF*NC*NL*Zeta[3])/27 - (3034360951081567928*CF*NC*NH*Zeta[3])/
        617673396283947 + CA*CF*NC*
        (-178212934667822676282945201568274398073838149816851327673/
          1595387127143414195530980504046025002560000000 + 
         (574039461753179042543971*Pi^2)/15894781943040 - 
         (77565672549903418835*Pi^3)/(1884315640930227648*Sqrt[3]) + 
         (5429*Pi^4)/6480 + lm*(-2639808769393/318745627200 + 
           (11*Pi^2)/162) + (640838770755600032829544519*
           Im[PolyLog[2, (-1)^(1/3)]])/(330084992399952628238400*Sqrt[3]) + 
         (239*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (15513134509980683767*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (10177630776629316*Sqrt[3]) - (15513134509980683767*Pi*Log[3]^2)/
          (488526277278207168*Sqrt[3]) + (662361847613906959823038145*
           PolyGamma[2, 1])/1235346792567894 + 
         (24834503058255163328473411864237*Zeta[3])/24731642787209237880), 
      (-5320741450532694010583337696952956213965566508535108423059*CF^2*NC)/
        18081054107625360882684445712521616695680000000 - 
       (416643580607820941182292077543523895758110951*CF*NM*NC)/
        582796716660900839405972664000000 + (5833223910719*CF*lm*NM*NC)/
        1168733966400 + (27960078034662400751*CF*NC*NL)/19143862369632000 + 
       (5833223910719*CF*lm*NC*NL)/1168733966400 + 
       (5029554329506519376526657612124741399484109155298277771*CF*NC*NH)/
        164050952594185750966296954129193420809486504000000 + 
       (5833223910719*CF*lm*NC*NH)/1168733966400 + 
       (4143896451017012066002253*CF^2*NC*Pi^2)/43142979559680 + 
       (1119760579286320351*CF*NM*NC*Pi^2)/4864860 + 
       (CF*lm*NM*NC*Pi^2)/54 - (214810033*CF*NC*NL*Pi^2)/9729720 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (51157213885686414475*CF^2*NC*Pi^3)/(57100473967582656*Sqrt[3]) - 
       (1101194234924647325*CF*NC*NH*Pi^3)/(274521509459532*Sqrt[3]) - 
       (20489*CF^2*NC*Pi^4)/2160 + (69687892174884915763101551*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10002575527271291764800*Sqrt[3]) + 
       (921213366572939508424*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (68699007742247883*Sqrt[3]) - 
       (2497*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (10231442777137282895*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (308413053837252*Sqrt[3]) - (125850769705673980*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (10231442777137282895*CF^2*NC*Pi*Log[3]^2)/(14803826584188096*
         Sqrt[3]) - (31462692426418495*CF*NC*NH*Pi*Log[3]^2)/
        (10167463313316*Sqrt[3]) + 
       (CF*NC*(24273*CA*(-308873752407217382970981489 + 4071198880428680000*
             lm) + 2*(7497292724730967281270987979177*CF - 
            40040*(899*(-499122080235440329681331 + 249573993669000*lm)*NM + 
              30084073519500*(9133 + 7458*lm)*NL + (99794193508741799 + 
                224367020308431000*lm)*NH)))*Log[x]^2)/
        13009316080184424000 + (CF*NC*(-219437171836068875*CA + 
          438874188247712281*CF + 180180*(5880256349912*NM + 6215*NL))*
         Log[x]^3)/1216215 + (11922513255050315977241607445*CF^2*NC*
         PolyGamma[2, 1])/7412080755407364 + 
       (57906880894843*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (1295477726635994771*CF*NC*NH*PolyGamma[2, 1])/3706040377703682 + 
       CA*CF*NC*(2660370712177071387211655834513089442512103091157450475467/
          18081054107625360882684445712521616695680000000 - 
         (12829400774955812443069*Pi^2)/267139192320 + 
         (51157213885686414475*Pi^3)/(114200947935165312*Sqrt[3]) + 
         (6851*Pi^4)/1440 + lm*(-5833223910719/212497084800 - 
           (11*Pi^2)/108) - (69687892174884915763101551*
           Im[PolyLog[2, (-1)^(1/3)]])/(20005151054542583529600*Sqrt[3]) + 
         (2497*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (10231442777137282895*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (616826107674504*Sqrt[3]) + (10231442777137282895*Pi*Log[3]^2)/
          (29607653168376192*Sqrt[3]) - (11922513255050315977241607445*
           PolyGamma[2, 1])/14824161510814728 - 
         (225301999841353009607187091358827*Zeta[3])/148389856723255427280) + 
       (225301999929824965757808760043887*CF^2*NC*Zeta[3])/
        74194928361627713640 + (17995570024301*CF*NM*NC*Zeta[3])/3 - 
       (4144*CF*NC*NL*Zeta[3])/3 + (16355431767083534233*CF*NC*NH*Zeta[3])/
        1853020188851841 + CF*Log[x]*((2809714779148555775817564297570571*NM*
           NC)/3628264248208610010000 - (85290643*lm*NM*NC)/1621620 - 
         (111715047275317*NC*NL)/53124271200 - (85290643*lm*NC*NL)/
          1621620 - (33200793791706008006157445512915057364409*NC*NH)/
          1136058977129616929390152854592890000 - (85290643*lm*NC*NH)/
          1621620 + (5880256351447*NM*NC*Pi^2)/27 - (6215*NC*NL*Pi^2)/27 + 
         (125850769705673980*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (2541865828329*Sqrt[3]) + 
         CF*NC*(19026790207172172932586125482205054213815431757/
            56282782926858370445943175395600000 + (1755497309196153599*Pi^2)/
            19459440 + (10231442777137282895*Im[PolyLog[2, (-1)^(1/3)]])/
            (925239161511756*Sqrt[3]) - 960*Zeta[3]) + 
         CA*NC*(-38053580186997080301838632808527580245211857989/
            225131131707433481783772701582400000 + (85290643*lm)/294840 - 
           (1755497305429851059*Pi^2)/38918880 - (10231442777137282895*
             Im[PolyLog[2, (-1)^(1/3)]])/(1850478323023512*Sqrt[3]) + 
           480*Zeta[3])), 
      (29522250625983403552816830673030147439175993684089308596729369821*CF^2*
         NC)/15875237830711497356440474073376829545273822720000000 + 
       (38188941119101121870193795665790662389019041597819*CF*NM*NC)/
        48733128420489293390647773607872000000 + 
       (22421401113473*CF*lm*NM*NC)/14024807596800 + 
       (69288009228531793241*CF*NC*NL)/1263494916395712000 + 
       (22421401113473*CF*lm*NC*NL)/14024807596800 - 
       (3120714852253780932449035074535160037495397619003791*CF*NC*NH)/
        396484461306480952958053798036384354277568000000 + 
       (22421401113473*CF*lm*NC*NH)/14024807596800 - 
       (8596239263734212472061413*CF^2*NC*Pi^2)/14222960294400 - 
       (834560286315701021*CF*NM*NC*Pi^2)/3243240 - (CF*lm*NM*NC*Pi^2)/81 - 
       (51494693*CF*NC*NL*Pi^2)/58378320 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (610069020843007395445*CF^2*NC*Pi^3)/
        (5652946922790682944*Sqrt[3]) + (2181398075505603535*CF*NC*NH*Pi^3)/
        (2470693585135788*Sqrt[3]) - (6293*CF^2*NC*Pi^4)/3240 - 
       (9188583573312401733045401407*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1980509954399715769430400*Sqrt[3]) + 
       (1056986023535357502889*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (281041395309195885*Sqrt[3]) - 
       (542*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (122013804168601479089*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (30532892329887948*Sqrt[3]) + (249302637200640404*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) + 
       (122013804168601479089*CF^2*NC*Pi*Log[3]^2)/(1465578831834621504*
         Sqrt[3]) + (62325659300160101*CF*NC*NH*Pi*Log[3]^2)/
        (91507169819844*Sqrt[3]) + 
       CF*((-6137720420004243794499848934575262847*NM*NC)/
          6657535053258416767440000 + (179676247*lm*NM*NC)/9729720 - 
         (61720640717261*NC*NL)/1753100949600 + (179676247*lm*NC*NL)/
          9729720 + (540965286537628997553604283796847036409*NC*NH)/
          85115761033644556624444334579280000 + (179676247*lm*NC*NH)/
          9729720 - (19519021892125*NM*NC*Pi^2)/81 - (665*NC*NL*Pi^2)/81 - 
         (249302637200640404*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (22876792454961*Sqrt[3]) + 
         CF*NC*(-21151842013769360080222106837002733566508142173633/
            10082943999370201323203405788622400000 - 
           (11072120934389233091*Pi^2)/19459440 - (122013804168601479089*
             Im[PolyLog[2, (-1)^(1/3)]])/(91598676989663844*Sqrt[3])) + 
         CA*NC*(1021331800317976780052045436445799534177489508268747/
            973724306224893727783643187586963200000 - (179676247*lm)/
            1769040 + (11072120936363285171*Pi^2)/38918880 + 
           (122013804168601479089*Im[PolyLog[2, (-1)^(1/3)]])/
            (183197353979327688*Sqrt[3])))*Log[x] - 
       (CF*NC*(-(CA*(9130903867148256579301215766267 + 682173097681355280000*
              lm)) + 2*(9130903863557518028161186700187*CF + 
            40040*((97091191423528985791102727 + 1548844559262000*lm)*NM + 
              20379533674500*(-103 + 76*lm)*NL + (2077544621073893 + 
                1548844559262000*lm)*NH)))*Log[x]^2)/2517932144551824000 - 
       (CF*NC*(-5536060466067590471*CA + 4*(2768030248916568767*CF + 
            300300*(3903804372904*NM - 133*NL)))*Log[x]^3)/4864860 - 
       (53651309687302892517995199776*CF^2*NC*PolyGamma[2, 1])/
        5559060566555523 - (521161928166641*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (15892725762889493047*CF*NC*NH*PolyGamma[2, 1])/22236242266222092 - 
       (4043102264371710546730162498187309*CF^2*NC*Zeta[3])/
        222584785084883140920 - (495136565776733*CF*NM*NC*Zeta[3])/54 - 
       (442*CF*NC*NL*Zeta[3])/9 - (65231927615032260343*CF*NC*NH*Zeta[3])/
        11118121133111046 + CA*CF*NC*
        (-29522250637563676430845362422672052747720248086037198943759957071/
          31750475661422994712880948146753659090547645440000000 + 
         (3167035518274715142361489*Pi^2)/10480076006400 - 
         (610069020843007395445*Pi^3)/(11305893845581365888*Sqrt[3]) + 
         (6229*Pi^4)/6480 + lm*(-22421401113473/2549965017600 + 
           (11*Pi^2)/162) + (9188583573312401733045401407*
           Im[PolyLog[2, (-1)^(1/3)]])/(3961019908799431538860800*Sqrt[3]) + 
         (271*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (122013804168601479089*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (61065784659775896*Sqrt[3]) - (122013804168601479089*Pi*Log[3]^2)/
          (2931157663669243008*Sqrt[3]) + (26825654843651446258997599888*
           PolyGamma[2, 1])/5559060566555523 + 
         (4043102264510784818003569112532509*Zeta[3])/445169570169766281840), 
      (-176838362777585920112913807375797532687867753623578031060961374581*
         CF^2*NC)/71438570238201738103982133330195732953732202240000000 - 
       (134716271685387349168229685075869726665044738234893*CF*NM*NC)/
        22742126596228336915635627683673600000 + 
       (24889178546051*CF*lm*NM*NC)/4674935865600 + 
       (1494991936697252358151*CF*NC*NL)/842329944263808000 + 
       (24889178546051*CF*lm*NC*NL)/4674935865600 + 
       (112748657941171442062069428276418879936134282996237675299*CF*NC*NH)/
        3037286208029496189318869322163352476701350131200000 + 
       (24889178546051*CF*lm*NC*NH)/4674935865600 + 
       (1633192656564934758408394441*CF^2*NC*Pi^2)/2013339046118400 + 
       (3732570767775662083*CF*NM*NC*Pi^2)/1945944 + 
       (CF*lm*NM*NC*Pi^2)/54 - (487232621*CF*NC*NL*Pi^2)/19459440 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (108334628246011013737595*CF^2*NC*Pi^3)/(101753044610232292992*
         Sqrt[3]) - (27135609746709301390*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (1553*CF^2*NC*Pi^4)/144 + 
       (300374604279614883073723368161*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (35649179179194883849747200*Sqrt[3]) + 
       (469894223082737945803111*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) - 941*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (21666925649202202747519*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(549592061937983064*
         Sqrt[3]) - (12404850169924252064*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (21666925649202202747519*CF^2*NC*Pi*Log[3]^2)/(26380418973023187072*
         Sqrt[3]) - (775303135620265754*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + 
       (CF*NC*(341*CA*(-742731474867139431768694839419 + 
            1398105137448923904000*lm) + 26*(19482417966931786311068001151923*
             CF - 30800*(31*(-48248926721737981732245589 + 3491771072549760*
                 lm)*NM + 19253807052480*(6865 + 5622*lm)*NL + 
              (49071111646742657 + 108244903249042560*lm)*NH)))*Log[x]^2)/
        52037264320737696000 + (CF*NC*(-2466004812387618111*CA + 
          280*(17614319144884217*CF + 1716*(24424818258223*NM + 3748*NL)))*
         Log[x]^3)/1621620 + (965723574350248727394627334339*CF^2*NC*
         PolyGamma[2, 1])/66708726798666276 + 
       (173720642702137*CF*NM*NC*PolyGamma[2, 1])/6 - 
       (14120573605566410747*CF*NC*NH*PolyGamma[2, 1])/33354363399333138 + 
       CA*CF*NC*
        (88419181327155485291001463095352732015160466093607841753675220353/
          71438570238201738103982133330195732953732202240000000 - 
         (4899577969581166805915539043*Pi^2)/12080034276710400 + 
         (108334628246011013737595*Pi^3)/(203506089220464585984*Sqrt[3]) + 
         (23359*Pi^4)/4320 + lm*(-24889178546051/849988339200 - 
           (11*Pi^2)/108) - (300374604279614883073723368161*
           Im[PolyLog[2, (-1)^(1/3)]])/(71298358358389767699494400*Sqrt[3]) + 
         (941*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (21666925649202202747519*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1099184123875966128*Sqrt[3]) + (21666925649202202747519*Pi*
           Log[3]^2)/(52760837946046374144*Sqrt[3]) - 
         (965723574350248727394627334339*PolyGamma[2, 1])/
          133417453597332552 - (36636657844935701983331181871382879*Zeta[3])/
          2671017421018597691040) + (36636657846848471968136731538259959*CF^2*
         NC*Zeta[3])/1335508710509298845520 + 
       (488595503856293*CF*NM*NC*Zeta[3])/9 - 1666*CF*NC*NL*Zeta[3] + 
       (177158053062061160425*CF*NC*NH*Zeta[3])/16677181699666569 + 
       CF*Log[x]*((32121111814381597813609939886206341397*NM*NC)/
          4882192372389505629456000 - (193599281*lm*NM*NC)/3243240 - 
         (1489089285418733*NC*NL)/584366983200 - (193599281*lm*NC*NL)/
          3243240 - (5233769970574054338113224235538419226254557*NC*NH)/
          147233243435998354048963809955238544000 - (193599281*lm*NC*NH)/
          3243240 + (48849636518614*NM*NC*Pi^2)/27 - (7496*NC*NL*Pi^2)/27 + 
         (12404850169924252064*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CF*NC*(177276226737612010653332580888145165027598350570688501/
            61344631292168304850369520817978681600000 + 
           (9864019196871135209*Pi^2)/12972960 + (21666925649202202747519*
             Im[PolyLog[2, (-1)^(1/3)]])/(1648776185813949192*Sqrt[3]) - 
           1088*Zeta[3]) + CA*NC*
          (-177276226588990454727142002184646400059562617088765551/
            122689262584336609700739041635957363200000 + (193599281*lm)/
            589680 - (3288006397948584283*Pi^2)/8648640 - 
           (21666925649202202747519*Im[PolyLog[2, (-1)^(1/3)]])/
            (3297552371627898384*Sqrt[3]) + 544*Zeta[3])), 
      (1942349916957461414891419298148234136619341867831351953173231347730064\
7*CF^2*NC)/1247581020049191574398187568230263391973062504408320000000 + 
       (3806223555459416878526491307480622311536816589036833*CF*NM*NC)/
        573837402677785193439046570573958400000 + 
       (3428092108845661*CF*lm*NM*NC)/2026584697737600 + 
       (24111649922356910330999*CF*NC*NL)/365150030838360768000 + 
       (3428092108845661*CF*lm*NC*NL)/2026584697737600 - 
       (101711474803269333350546045377453597879575298951686612719*CF*NC*NH)/
        10630501728103236662616042627571733668454725459200000 + 
       (3428092108845661*CF*lm*NC*NH)/2026584697737600 - 
       (8603541786052846913641297327*CF^2*NC*Pi^2)/1692532275033600 - 
       (446323347568195675*CF*NM*NC*Pi^2)/204204 - (CF*lm*NM*NC*Pi^2)/81 - 
       (488988623*CF*NC*NL*Pi^2)/496215720 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (119526011708821439772755*CF^2*NC*Pi^3)/
        (864900879186974490432*Sqrt[3]) + (6001106569794365120*CF*NC*NH*
         Pi^3)/(5559060566555523*Sqrt[3]) - (7147*CF^2*NC*Pi^4)/3240 - 
       (5655671215882513821801004326293*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1030261278278732143257694080*Sqrt[3]) + 
       (114816830163654266854432*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) - 
       (610*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (23905202341764287954551*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) + (2743363003334566912*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (23905202341764287954551*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) + (171460187708410432*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + 
       CF*((-220089430576058569992996120345982070609*NM*NC)/
          27816918200788428319608000 + (1728666817*lm*NM*NC)/82702620 - 
         (676861243895801*NC*NL)/14901358071600 + (1728666817*lm*NC*NL)/
          82702620 + (572248326899373438472109231602881024482791*NC*NH)/
          73616621717999177024481904977619272000 + (1728666817*lm*NC*NH)/
          82702620 - (165501992364508*NM*NC*Pi^2)/81 - 
         (800*NC*NL*Pi^2)/81 - (2743363003334566912*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-23793910865259124717324887971195117438147469420888373927/
            1329160797639461003104093980906256924800000 - 
           (315855024003612355555*Pi^2)/66162096 - 
           (23905202341764287954551*Im[PolyLog[2, (-1)^(1/3)]])/
            (14014597579418568132*Sqrt[3])) + 
         CA*NC*(309320841258509868029267105419917082922872156446703189351/
            34558180738625986080706443503562680044800000 - 
           (1728666817*lm)/15036840 + (315855024011678617759*Pi^2)/
            132324192 + (23905202341764287954551*Im[PolyLog[2, (-1)^(1/3)]])/
            (28029195158837136264*Sqrt[3])))*Log[x] - 
       (CF*NC*(-87*CA*(465186334839586486102461301410259 + 
            4971120525148377600000*lm) + 
          22*(3679201011706722171877832039902793*CF + 
            618800*(253*(10104800352239782282599431 + 22830601248000*lm)*
               NM + 722017764468000*(-11 + 8*lm)*NL + (7961358297424079 + 
                5776142115744000*lm)*NH)))*Log[x]^2)/
        1326950240178811248000 + (CF*NC*(394818779992475018643*CA - 
          34*(23224634137473261763*CF + 1201200*(8275099616563*NM - 
              40*NL)))*Log[x]^3)/41351310 - (4345756085006230043253361193999*
         CF^2*NC*PolyGamma[2, 1])/50031545098999707 - 
       (1172614338273608*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (84843028993607126783*CF*NC*NH*PolyGamma[2, 1])/100063090197999414 - 
       (1118195952206536975019094078840713813*CF^2*NC*Zeta[3])/
        6811094423597424112152 - (2234894015052196*CF*NM*NC*Zeta[3])/27 - 
       (532*CF*NC*NL*Zeta[3])/9 - (347117035830111566135*CF*NC*NH*Zeta[3])/
        50031545098999707 + CA*CF*NC*(-24279373963325638922750212674603684294\
26056629049568620502821243712159/
          311895255012297893599546892057565847993265626102080000000 + 
         (1229077398010478398476160741*Pi^2)/483580650009600 - 
         (119526011708821439772755*Pi^3)/(1729801758373948980864*Sqrt[3]) + 
         (787*Pi^4)/720 + lm*(-3428092108845661/368469945043200 + 
           (11*Pi^2)/162) + (5655671215882513821801004326293*
           Im[PolyLog[2, (-1)^(1/3)]])/(2060522556557464286515388160*
           Sqrt[3]) + (305*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (23905202341764287954551*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) - (23905202341764287954551*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) + 
         (4345756085006230043253361193999*PolyGamma[2, 1])/
          100063090197999414 + (1118195952211636845034451757528244217*
           Zeta[3])/13622188847194848224304), 
      (-809139991427909793493160054371873132041974466837307059644725547017639*
         CF^2*NC)/38695026290295781451922395164361110553175200671488000000 - 
       (8806870863427340811420099548132221646525639600837605579*CF*NM*NC)/
        178292287744273259224658153769557952000000 + 
       (7642805317543139*CF*lm*NM*NC)/1351056465158400 + 
       (37060706978281294580933*CF*NC*NL)/17388096706588608000 + 
       (7642805317543139*CF*lm*NC*NL)/1351056465158400 + 
       (50816395431143474337332833971561683733723079560266892463*CF*NC*NH)/
        1143064701946584587378069099738896093382228544000000 + 
       (7642805317543139*CF*lm*NC*NH)/1351056465158400 + 
       (706118528156840570724685052797*CF^2*NC*Pi^2)/102680291352038400 + 
       (2658846437951415598321*CF*NM*NC*Pi^2)/165405240 + 
       (CF*lm*NM*NC*Pi^2)/54 - (9323674237*CF*NC*NL*Pi^2)/330810480 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (2166610046180524340876605*CF^2*NC*Pi^3)/(1729801758373948980864*
         Sqrt[3]) - (7255085410369211905*CF*NC*NH*Pi^3)/
        (1235346792567894*Sqrt[3]) - (26281*CF^2*NC*Pi^4)/2160 + 
       (103792482596665673849277334564247*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (10302612782787321432576940800*Sqrt[3]) + 
       (27766484433157693877734*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1324909435029066315*Sqrt[3]) - 
       (3169*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (433322009236104868175321*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9343065052945712088*
         Sqrt[3]) - (1658305236655819864*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (433322009236104868175321*CF^2*NC*Pi*Log[3]^2)/(448467122541394180224*
         Sqrt[3]) - (207288154581977483*CF*NC*NH*Pi*Log[3]^2)/
        (45753584909922*Sqrt[3]) + 
       (CF*NC*(5*CA*(-1460041279641223513968368325012593 + 
            386730309702128094743040*lm) + 
          26*(561554338523612134357350754011001*CF - 
            20944*(133*(-471231152543331122329249793 + 4854348007423200*lm)*
               NM + 31*(26396348378400*(961 + 789*lm)*NL + 
                (9602853454608949 + 20826718870557600*lm)*NH))))*Log[x]^2)/
        176926698690508166400 + (CF*NC*(-1064297866651137262897*CA + 
          352*(6047146921479402461*CF + 69615*(204148706425096*NM + 
              4471*NL)))*Log[x]^3)/82702620 + 
       (78223609529889346138939230880069*CF^2*NC*PolyGamma[2, 1])/
        600378541187996484 + (4690457353021483*CF*NM*NC*PolyGamma[2, 1])/
        18 - (152138458658421800003*CF*NC*NH*PolyGamma[2, 1])/
        300189270593998242 + CA*CF*NC*(18913647297783487338860551688520528653\
828689620970233197893611910205321/
          1808992479071327782877371973933881918360940631392064000000 - 
         (235372842718213949403712617719*Pi^2)/68453527568025600 + 
         (2166610046180524340876605*Pi^3)/(3459603516747897961728*Sqrt[3]) + 
         (5269*Pi^4)/864 + lm*(-7642805317543139/245646630028800 - 
           (11*Pi^2)/108) - (103792482596665673849277334564247*
           Im[PolyLog[2, (-1)^(1/3)]])/(20605225565574642865153881600*
           Sqrt[3]) + (3169*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (433322009236104868175321*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (18686130105891424176*Sqrt[3]) + (433322009236104868175321*Pi*
           Log[3]^2)/(896934245082788360448*Sqrt[3]) - 
         (78223609529889346138939230880069*PolyGamma[2, 1])/
          1200757082375992968 - (50615692626325795441279091939160230641*
           Zeta[3])/408665665415845446729120) + 
       (50615692626673694792612409033768767881*CF^2*NC*Zeta[3])/
        204332832707922723364560 + (1472753025966823*CF*NM*NC*Zeta[3])/3 - 
       (5962*CF*NC*NL*Zeta[3])/3 + (1898309913194449747501*CF*NC*NH*
         Zeta[3])/150094635296999121 + CF*Log[x]*
        ((760280993867279035158711747584618569901*NM*NC)/
          13567920387120633053520000 - (3707043217*lm*NM*NC)/55135080 - 
         (60645686186305601*NC*NL)/19868477428800 - (3707043217*lm*NC*NL)/
          55135080 - (112804414661905492120120355349013207793059*NC*NH)/
          2638588592042981255357774371957680000 - (3707043217*lm*NC*NH)/
          55135080 + (408297412853116*NM*NC*Pi^2)/27 - (8942*NC*NL*Pi^2)/
          27 + (1658305236655819864*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (22876792454961*Sqrt[3]) + 
         CF*NC*(4962604379408532941338793793044145367125592920999768139703/
            200437448284030719268097372320663544259840000 + 
           (4257191463398751820637*Pi^2)/661620960 + 
           (433322009236104868175321*Im[PolyLog[2, (-1)^(1/3)]])/
            (28029195158837136264*Sqrt[3]) - 1224*Zeta[3]) + 
         CA*NC*(-64449407517298790580501383943285542214413178994819380349/
            5206167487896901799171360320017234915840000 + 
           (3707043217*lm)/10024560 - (4257191463214847740277*Pi^2)/
            1323241920 - (433322009236104868175321*Im[PolyLog[2, (-1)^
                (1/3)]])/(56058390317674272528*Sqrt[3]) + 612*Zeta[3])), 
      (3367357841614137712951520771345319346349533592576545662000932837528116\
183*CF^2*NC)/25706735228908342177731075419060427260918630025045120000000 + 
       (502333503351443732465364094826158863122527627815979673*CF*NM*NC)/
        8914614387213662961232907688477897600000 + 
       (133934452644743*CF*lm*NM*NC)/75058692508800 + 
       (3591147744571935647399*CF*NC*NL)/45643753854795096000 + 
       (133934452644743*CF*lm*NC*NL)/75058692508800 - 
       (103139388497466993028639851257950405845406077314963994041*CF*NC*NH)/
        8969485833087105934082285967013650282758674606200000 + 
       (133934452644743*CF*lm*NC*NH)/75058692508800 - 
       (6613966539646362557116554256469*CF^2*NC*Pi^2)/154020437028057600 - 
       (171158796730052109689*CF*NM*NC*Pi^2)/9189180 - 
       (CF*lm*NM*NC*Pi^2)/81 - (543292873*CF*NC*NL*Pi^2)/496215720 - 
       (CF*lm*NC*NL*Pi^2)/81 - (CF*lm*NC*NH*Pi^2)/81 + 
       (368452496904671307573415*CF^2*NC*Pi^3)/(2122938521640755567424*
         Sqrt[3]) + (391620776588355859475*CF*NC*NH*Pi^3)/
        (300189270593998242*Sqrt[3]) - (179*CF^2*NC*Pi^4)/72 - 
       (81411430906086294309855981961949*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (12644115687966258121798972800*Sqrt[3]) + 
       (672339549389990922977848*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (150244729932296120121*Sqrt[3]) - 
       (682*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (73690499380934261514683*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11466488928615192108*
         Sqrt[3]) + (89513320363052767880*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) + 
       (73690499380934261514683*CF^2*NC*Pi*Log[3]^2)/(550391468573529221184*
         Sqrt[3]) + (11189165045381595985*CF*NC*NH*Pi*Log[3]^2)/
        (11118121133111046*Sqrt[3]) + 
       CF*((-44921031223150539698937442966076419607*NM*NC)/
          660257088357207276936000 + (1942380317*lm*NM*NC)/82702620 - 
         (427061015786089*NC*NL)/7450679035800 + (1942380317*lm*NC*NL)/
          82702620 + (2668154831240868658799579545120903717187789*NC*NH)/
          283949826626568254237287347770817192000 + (1942380317*lm*NC*NH)/
          82702620 - (1408228353125234*NM*NC*Pi^2)/81 - 
         (952*NC*NL*Pi^2)/81 - (89513320363052767880*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CF*NC*(-109030894614283637196695993333607735329215551014304136019153/
            712080408377477555294556454297094170396800000 - 
           (211329356742067485329*Pi^2)/5250960 - (73690499380934261514683*
             Im[PolyLog[2, (-1)^(1/3)]])/(34399466785845576324*Sqrt[3])) + 
         CA*NC*(8386991893446583231179932091326663158237464406660436426981/
            109550832058073470045316377584168333907200000 - 
           (1942380317*lm)/15036840 + (633988070228485991527*Pi^2)/31505760 + 
           (73690499380934261514683*Im[PolyLog[2, (-1)^(1/3)]])/
            (68798933571691152648*Sqrt[3])))*Log[x] - 
       (CF*NC*(-19*CA*(53983020846243534541401659516861729 + 
            81262122310833399936000*lm) + 
          14*(146525342295791960109792968272160303*CF + 
            17503200*(38*(95554361879589213024233077 + 30147408411120*lm)*
               NM + 40914339986520*(-39 + 28*lm)*NL + (1617765155561837 + 
                1145601519622560*lm)*NH)))*Log[x]^2)/
        3980850720536433744000 - (CF*NC*(-3328437368672696083587*CA + 
          10*(665687473821247473377*CF + 11435424*(25146934876529*NM - 
              17*NL)))*Log[x]^3)/41351310 - 
       (352006242889124478330866259265004*CF^2*NC*PolyGamma[2, 1])/
        450283905890997363 - (126642348532070549*CF*NM*NC*PolyGamma[2, 1])/
        324 - (1795133749079179240621*CF*NC*NH*PolyGamma[2, 1])/
        1801135623563989452 - (64933796035449710647409569715586872119*CF^2*NC*
         Zeta[3])/43785607008840583578120 - (121009435120159013*CF*NM*NC*
         Zeta[3])/162 - (1900*CF*NC*NL*Zeta[3])/27 - 
       (7323063576461991311821*CF*NC*NH*Zeta[3])/900567811781994726 + 
       CA*CF*NC*(-67347156832811867619652256667359913729450554087559594140774\
13782497673741/102826940915633368710924301676241709043674520100180480000000 + 
         (6613966539648434476354849582889*Pi^2)/308040874056115200 - 
         (368452496904671307573415*Pi^3)/(4245877043281511134848*Sqrt[3]) + 
         (7991*Pi^4)/6480 + lm*(-133934452644743/13647035001600 + 
           (11*Pi^2)/162) + (81411430906086294309855981961949*
           Im[PolyLog[2, (-1)^(1/3)]])/(25288231375932516243597945600*
           Sqrt[3]) + (341*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (73690499380934261514683*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (22932977857230384216*Sqrt[3]) - (73690499380934261514683*Pi*
           Log[3]^2)/(1100782937147058442368*Sqrt[3]) + 
         (176003121444562239165433129632502*PolyGamma[2, 1])/
          450283905890997363 + (64933796035488597942345439818324336139*
           Zeta[3])/87571214017681167156240), 
      (-173197434654884898544229659570886252696442029614886796952919422779645\
983471*CF^2*NC)/
        976855938698517002753780865924296235914907940951714560000000 - 
       (1500471871139571614438919751329908651523701651459154349*CF*NM*NC)/
        3623051836514643770340646974996364800000 + 
       (8092694147333539*CF*lm*NM*NC)/1351056465158400 + 
       (1397586447961286872922947*CF*NC*NL)/551782268822411827200 + 
       (8092694147333539*CF*lm*NC*NL)/1351056465158400 + 
       (1532997067283367567763273419403231866757450873646026907386705931*CF*
         NC*NH)/
        29077207417815115320260481989577115377444809268982310400000 + 
       (8092694147333539*CF*lm*NC*NH)/1351056465158400 + 
       (18019058438125309591800046316489*CF^2*NC*Pi^2)/308040874056115200 + 
       (1243919797963373974603*CF*NM*NC*Pi^2)/9189180 + 
       (CF*lm*NM*NC*Pi^2)/54 - (1158410573*CF*NC*NL*Pi^2)/36756720 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (68204464150406782764118105*CF^2*NC*Pi^3)/(46704647476096622483328*
         Sqrt[3]) - (4199501018383246167025*CF*NC*NH*Pi^3)/
        (600378541187996484*Sqrt[3]) - (29447*CF^2*NC*Pi^4)/2160 + 
       (13538319366790335262543350290167*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1135389980143908892569703680*Sqrt[3]) + 
       (131125965618942482899695617*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5108320817698068084114*Sqrt[3]) - 
       (3535*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (1948698975725908078974803*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(36037536632790603768*
         Sqrt[3]) - (479942973529513847660*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (1948698975725908078974803*CF^2*NC*Pi*Log[3]^2)/
        (1729801758373948980864*Sqrt[3]) - (119985743382378461915*CF*NC*NH*
         Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) + 
       ((103494464251981984965464978565672949*CF^2*NC)/
          147438915575423472000 + CA*CF*
          (-310483392740566395773953049463796007/884633493452540832000 + 
           (38731*lm)/3)*NC + CF*NC*((6209238454979077384321663693/
              3822446988360 - (7042*lm)/3)*NM - ((25673 + 21126*lm)*NL)/9 - 
           (2642046835557395179*NH)/2404319155678440 - (7042*lm*NH)/3))*
        Log[x]^2 + (CF*NC*(-3012951136393771755791*CA + 
          48*(125539630536979309181*CF + 255255*(1143505570121738*NM + 
              3521*NL)))*Log[x]^3)/27567540 + 
       (6336112372001918158139983375121059*CF^2*NC*PolyGamma[2, 1])/
        5403406870691968356 + (126642348531808513*CF*NM*NC*PolyGamma[2, 1])/
        54 - (1622443269785558967227*CF*NC*NH*PolyGamma[2, 1])/
        2701703435345984178 + CA*CF*NC*(8659871732627557621965267446301021942\
0076413810519869397830007931423529923/
          976855938698517002753780865924296235914907940951714560000000 - 
         (18019058438117864805154649295569*Pi^2)/616081748112230400 + 
         (68204464150406782764118105*Pi^3)/(93409294952193244966656*
           Sqrt[3]) + (1093*Pi^4)/160 + 
         lm*(-8092694147333539/245646630028800 - (11*Pi^2)/108) - 
         (13538319366790335262543350290167*Im[PolyLog[2, (-1)^(1/3)]])/
          (2270779960287817785139407360*Sqrt[3]) + 
         (3535*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (1948698975725908078974803*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (72075073265581207536*Sqrt[3]) + (1948698975725908078974803*Pi*
           Log[3]^2)/(3459603516747897961728*Sqrt[3]) - 
         (6336112372001918158139983375121059*PolyGamma[2, 1])/
          10806813741383936712 - (822374967038846619583370944464673373411*
           Zeta[3])/735598197748521804112416) + 
       (822374967039584199809596733119202425643*CF^2*NC*Zeta[3])/
        367799098874260902056208 + (119781315111476881*CF*NM*NC*Zeta[3])/
        27 - (21128*CF*NC*NL*Zeta[3])/9 + (20146482128969609547301*CF*NC*NH*
         Zeta[3])/1350851717672992089 + CF*Log[x]*
        ((6166408081121064985773035085066350894183*NM*NC)/
          12889524367764601400844000 - (1382481059*lm*NM*NC)/18378360 - 
         (488947161988427767*NC*NL)/135105646515840 - (1382481059*lm*NC*NL)/
          18378360 - (69252185862807525521614613110441631804477437993*NC*NH)/
          1360545594281201790177962326843870575468000 - 
         (1382481059*lm*NC*NH)/18378360 + (1143505570123009*NM*NC*Pi^2)/9 - 
         (3521*NC*NL*Pi^2)/9 + (479942973529513847660*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CF*NC*(5751883505062097406238355171526863761894093208217504493835911/
            27059055518344147101193145263289578475078400000 + 
           (2410360908862499333605*Pi^2)/44108064 + 
           (1948698975725908078974803*Im[PolyLog[2, (-1)^(1/3)]])/
            (108112609898371811304*Sqrt[3]) - 1368*Zeta[3]) + 
         CA*NC*(-575188350497054180622816402221959256543679084987018257010486\
1/54118111036688294202386290526579156950156800000 + (1382481059*lm)/3341520 - 
           (2410360908848026851581*Pi^2)/88216128 - 
           (1948698975725908078974803*Im[PolyLog[2, (-1)^(1/3)]])/
            (216225219796743622608*Sqrt[3]) + 684*Zeta[3])), 
      (1932033284033312556246651630139813480483290700984812238773560014190502\
95641*CF^2*NC)/174547926350518712090800969773306850931503926753127680000000 + 
       (2440366149955144891964692323847867444744216924914537520969*CF*NM*NC)/
        5081330200711787887902757382432401632000000 + 
       (1373358268819874021*CF*lm*NM*NC)/731597075883273600 + 
       (14546985309481797771233*CF*NC*NL)/156647844483242112000 + 
       (1373358268819874021*CF*lm*NC*NL)/731597075883273600 - 
       (58898544888458743803096206737802606397845087020436689621357*CF*NC*
         NH)/4305353199881810848359497264166552135724163810976000000 + 
       (1373358268819874021*CF*lm*NC*NH)/731597075883273600 - 
       (355236791871902386640346634086599*CF^2*NC*Pi^2)/975462767844364800 - 
       (5685228505223245783508*CF*NM*NC*Pi^2)/35712495 - 
       (CF*lm*NM*NC*Pi^2)/81 - (3803940919*CF*NC*NL*Pi^2)/3142699560 - 
       (CF*lm*NC*NL*Pi^2)/81 - (CF*lm*NC*NH*Pi^2)/81 + 
       (285398365630096337203314475*CF^2*NC*Pi^3)/(1331082453068753740774848*
         Sqrt[3]) + (1405104545947444928845*CF*NC*NH*Pi^3)/
        (900567811781994726*Sqrt[3]) - (9017*CF^2*NC*Pi^4)/3240 - 
       (1128603485255516999191365043456562123*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(150629350190742033004991162966400*
         Sqrt[3]) + (183822976050859150813082777*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(38312406132735510630855*Sqrt[3]) - 
       (758*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (57079673126019267440662895*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7189488558241725451716*
         Sqrt[3]) + (321166753359415983736*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) + 
       (57079673126019267440662895*CF^2*NC*Pi*Log[3]^2)/
        (345095450795602821682368*Sqrt[3]) + (40145844169926997967*CF*NC*NH*
         Pi*Log[3]^2)/(33354363399333138*Sqrt[3]) + 
       CF*((-1473174564012653058588024260596321931752909*NM*NC)/
          2513457251714097273164580000 + (13733098601*lm*NM*NC)/523783260 - 
         (430081864816649*NC*NL)/6056166916800 + (13733098601*lm*NC*NL)/
          523783260 + (167571157287712985159698147802634572041848889*NC*NH)/
          14907365897894833347457585757967902580000 + (13733098601*lm*NC*NH)/
          523783260 - (445168065819626*NM*NC*Pi^2)/3 - 
         (374*NC*NL*Pi^2)/27 - (321166753359415983736*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CF*NC*
          (-34903243525150424792227934090076836200458249912804706335879083/
            26592520078372696289103608275991482294473600000 - 
           (101970005514489492368827*Pi^2)/299304720 - 
           (57079673126019267440662895*Im[PolyLog[2, (-1)^(1/3)]])/
            (21568465674725176355148*Sqrt[3])) + 
         CA*NC*(4986177646453483253937398773532099025846392544147710400952469/
            7597862879535056082601030935997566369849600000 - 
           (13733098601*lm)/95233320 + (33990001838180197086509*Pi^2)/
            199536480 + (57079673126019267440662895*Im[PolyLog[2, (-1)^
                (1/3)]])/(43136931349450352710296*Sqrt[3])))*Log[x] - 
       (CF*NC*(-29*CA*(5698886233625513322028075457656615483 + 
            1192211407745022528864000*lm) + 
          14*(23609671539279899964298718946513412391*CF + 
            11085360*(7*(133003354405103824436776150193 + 5786456655236400*
                 lm)*NM + 1841145299393400*(-31 + 22*lm)*NL + 
              (58458987237038639 + 40505196586654800*lm)*NH)))*Log[x]^2)/
        75636163690192241136000 + (CF*NC*(178447509650242085994479*CA - 
          418*(853815835663414321097*CF + 185640*(2003256296180528*NM - 
              187*NL)))*Log[x]^3)/261891630 - 
       (28512505674057818530375416521366741*CF^2*NC*PolyGamma[2, 1])/
        4052555153018976267 - (569890568393428637*CF*NM*NC*PolyGamma[2, 1])/
        162 - (4708676262004734057367*CF*NC*NH*PolyGamma[2, 1])/
        4052555153018976267 - (100255413036527024310434820982777766403751*
         CF^2*NC*Zeta[3])/7487338798511739791858520 - 
       (545851492839520853*CF*NM*NC*Zeta[3])/81 - (2240*CF*NC*NL*Zeta[3])/
        27 - (38315973225552490875590*CF*NC*NH*Zeta[3])/
        4052555153018976267 + CA*CF*NC*(-408699348545953998107494740736071947\
74351964518723656019176434747031440513/
          73847199609834839730723487211783667701790122857092480000000 + 
         (118412263957305629312405920470953*Pi^2)/650308511896243200 - 
         (285398365630096337203314475*Pi^3)/(2662164906137507481549696*
           Sqrt[3]) + (8953*Pi^4)/6480 + 
         lm*(-1373358268819874021/133017650160595200 + (11*Pi^2)/162) + 
         (1128603485255516999191365043456562123*Im[PolyLog[2, (-1)^(1/3)]])/
          (301258700381484066009982325932800*Sqrt[3]) + 
         (379*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (57079673126019267440662895*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14378977116483450903432*
           Sqrt[3]) - (57079673126019267440662895*Pi*Log[3]^2)/
          (690190901591205643364736*Sqrt[3]) + 
         (28512505674057818530375416521366741*PolyGamma[2, 1])/
          8105110306037952534 + (100255413036534839844250667487163834722211*
           Zeta[3])/14974677597023479583717040)}, 0, 39, 1]
 
CbarLSeries["v", 2, 0, "x1"] = SeriesData[x, 1, 
     {-(CF*NC*(121118*NM + 23424*lm*NM - 137088*NL + 23424*lm*NL + 
          121118*NH + 23424*lm*NH - 193725*NM*Zeta[3] - 
          193725*NH*Zeta[3] + 3024*CF*(-1416 + 1175*Zeta[3]) - 
          24*CA*(5368*lm - 5*(764 + 4779*Zeta[3]))))/3732480, 
      (CF*NC*(12182*NM + 23424*lm*NM - 113664*NL + 23424*lm*NL + 
         276902*NH + 23424*lm*NH - 24*CA*(1548 + 5368*lm - 23895*Zeta[3]) - 
         91665*NM*Zeta[3] - 295785*NH*Zeta[3] + 
         3024*CF*(-1416 + 1175*Zeta[3])))/3732480, 
      -(CF*NC*(74572450*NM + 40719360*lm*NM - 101282304*NL + 
          40719360*lm*NL + 630484450*NH + 40719360*lm*NH - 
          16*CA*(400636498 + 13997280*lm - 359567775*Zeta[3]) - 
          155617875*NM*Zeta[3] - 584269875*NH*Zeta[3] + 
          160*CF*(-327368654 + 272580525*Zeta[3])))/5225472000, 
      (CF*NC*(468689390*NM + 97290240*lm*NM - 81949696*NL + 
         97290240*lm*NL + 1551943650*NH + 97290240*lm*NH - 
         192*CA*(133144646 + 2786960*lm - 111492675*Zeta[3]) - 
         507205125*NM*Zeta[3] - 1367485875*NH*Zeta[3] + 
         640*CF*(-308634974 + 257035275*Zeta[3])))/10450944000, 
      -(CF*NC*(602359428930*NM + 78596259840*lm*NM + 13349691392*NL + 
          78596259840*lm*NL + 1272754418530*NH + 78596259840*lm*NH - 
          4*CA*(10577138028934 + 108069857280*lm - 8723154558825*Zeta[3]) - 
          528575047875*NM*Zeta[3] - 1094514757875*NH*Zeta[3] + 
          280*CF*(-1571465833022 + 1307802839805*Zeta[3])))/8193540096000, 
      (CF*NC*(381474353260*NM + 35405045760*lm*NM + 31759986688*NL + 
         35405045760*lm*NL + 597232439370*NH + 35405045760*lm*NH - 
         2*CA*(19198320064402 + 97363875840*lm - 15837595724475*Zeta[3]) - 
         303892769250*NM*Zeta[3] - 506177319375*NH*Zeta[3] + 
         140*CF*(-3348498192826 + 2785819031415*Zeta[3])))/4096770048000, 
      -(CF*NC*(5*(32768*(3151751692 + 2077680465*lm)*NL + 
            63*NH*(19566054084794 + 1080657674240*lm - 16420548288375*Zeta[
                3]) + 63*NM*(16155315679874 + 1080657674240*lm - 
              12284229139875*Zeta[3])) - 4*CA*(191611010425847938 + 
            468059855155200*lm - 158501882546035875*Zeta[3]) + 
          72*CF*(-155857850505993998 + 129653229666547125*Zeta[3])))/
       48669628170240000, (CF*NC*(5*(40960*(655358855 + 308016828*lm)*NL + 
           63*NH*(4015188731162 + 200259829760*lm - 3345812922375*Zeta[3]) + 
           63*NM*(4288091366874 + 200259829760*lm - 3210120750375*
              Zeta[3])) - 4*CA*(75954087426185278 + 86737538764800*lm - 
           62973839587168125*Zeta[3]) + 72*CF*(-72939247248450098 + 
           60674839173592875*Zeta[3])))/12167407042560000, 
      -(CF*NC*(5*(65536*(18676991479081 + 6645407256180*lm)*NL + 
            99*NM*(142440916923630578 + 4399125352939520*lm - 
              107081724583708875*Zeta[3]) + 495*NH*(20230643329135690 + 
              879825070587904*lm - 16768829348045775*Zeta[3])) - 
          847*CA*(27337142662475399846 + 14140045777305600*lm - 
            22699015244064329625*Zeta[3]) + 286*CF*(-1632156832186379881946 + 
            1357734219748409262375*Zeta[3])))/612458600894300160000, 
      (CF*NC*(14476048546519455126*NM + 276376038223380480*lm*NM + 
         1016217320783544320*NL + 276376038223380480*lm*NL + 
         7626647792494513926*NH + 276376038223380480*lm*NH - 
         121*CA*(55790838222920245514 + 12562547191971840*lm - 
           46365455069857716975*Zeta[3]) - 11042538634392890625*NM*Zeta[3] - 
         6296337698085059625*NH*Zeta[3] + 286*CF*(-549054339544720904282 + 
           456746705137779539175*Zeta[3])))/122491720178860032000, 
      -(CF*NC*(35*(16777216*(511177335126817 + 103169930793930*lm)*NL + 
            429*NM*(4034741756724510720*lm + 1859*(199387686283044158 - 
                154795131316720125*Zeta[3])) + 1287*NH*
             (47649441086958627774 + 1344913918908170240*lm - 
              39219098911331464125*Zeta[3])) - 
          88*CA*(41010581907054502780106002 + 3786352967326158028800*lm - 
            34098674307958209269194875*Zeta[3]) + 
          208*CF*(-461327643083839033769898146 + 383773735160719108476145875*
             Zeta[3])))/46370465590909253713920000, 
      (CF*NC*(35*(8388608*(1520981622700433 + 208309026105180*lm)*NL + 
           429*NM*(735245273889337619402 + 4073246533468815360*lm - 
             579980200915627887375*Zeta[3]) + 9009*NH*(9946666802277135502 + 
             193964120641372160*lm - 8168293307492443125*Zeta[3])) - 
         352*CA*(28187680180992414378599102 + 955621823438035353600*lm - 
           23443038088002090865432125*Zeta[3]) + 
         832*CF*(-359457431206806864216104366 + 299031553858325334426505125*
            Zeta[3])))/92740931181818507427840000, 
      -(CF*NC*(35*(603979776*(4109570639514199 + 294183454144580*lm)*NL + 
            143*NM*(564279318378276239041654 + 1242523473686361538560*lm - 
              450487063789769313932625*Zeta[3]) + 143*NH*
             (123082257148006276881046 + 1242523473686361538560*lm - 
              100906870888384282346625*Zeta[3])) - 
          6*CA*(604184537578674536841551021434 + 5700594153650219542118400*
             lm - 502555080511589062055711988375*Zeta[3]) + 
          12*CF*(-10247188107548080183667382024838 + 
            8524650477724985199967709963625*Zeta[3])))/
       25225533281454634020372480000, 
      (CF*NC*(5*(167772160*(5110306479389885 + 1443530772684*lm)*NL + 
           143*NM*(235124252989197415582982 + 1693596333983662080*lm - 
             188949584445498006755625*Zeta[3]) + 286*NH*
            (22074695651063170660402 + 846798166991831040*lm - 
             18075670698768728920875*Zeta[3])) - 
         9*CA*(37878971524210577618506700158 + 740007509265639014400*lm - 
           31509610977759548538055276125*Zeta[3]) + 
         14*CF*(-923495755756527924956035621982 + 
           768259850169087969868880830125*Zeta[3])))/
       1801823805818188144312320000, 
      -(CF*NC*(170*CF*(-20176775886375464658951761105193994 + 
            16785171328033727705448334460062575*Zeta[3]) + 
          CA*(-81372139761516820114037694985994414 + 
            243555210398898753756022702080*lm + 
            67691836008123144076982704994137125*Zeta[3]) - 
          21*(805306368*(-31246939482631957813 + 2618510425508998020*lm)*
             NL + 17017*NM*(-50553397155365990852491406 + 
              123917442577233692590080*lm + 40400043620395010341915125*Zeta[
                3]) + 2431*NH*(-81683847557828611556531642 + 
              867422098040635848130560*lm + 66829523591745296991984375*Zeta[
                3]))))/332432167796321748974076690432000, 
      (CF*NC*(4*CA*(-64789775717640690048745906449949054 + 
           224166254420062567187192217600*lm + 
           53898278512785123530819245467052125*Zeta[3]) + 
         136*CF*(-88805956834356690409030091248916578 + 
           73878239858891626894730622462709875*Zeta[3]) - 
         105*(536870912*(-15103412564548052357 + 2892067092064430280*lm)*
            NL + 2431*NM*(60428102398707891658665502 + 
             638694651288284100034560*lm - 54008437274005884458914125*
              Zeta[3]) + 2431*NH*(638694651288284100034560*lm + 
             2431*(-12057606971622718674386 + 9859304243266265662875*
                Zeta[3])))))/831080419490804372435191726080000, 
      -(CF*NC*(8*CA*(-313517182390062936200753057499539015102 + 
            953656514670425964239577415680000*lm + 
            260815630880684039354942839995698920125*Zeta[3]) + 
          304*CF*(-423033447931748485669958545088825194742 + 
            351924408098335028206433546221446212625*Zeta[3]) - 
          35*(42949672960*(-2688679726738057850767 + 922765548614737627800*
               lm)*NL + 4199*NM*(6383313420550340138590820588674 + 
              9438551686534403941466112000*lm - 
              5340828748545881581690676851875*Zeta[3]) + 
            29393*NH*(1348364526647771991638016000*lm + 205751*(
                -196595389517067185589502 + 160693854772095219700125*
                 Zeta[3])))))/6400427337305181406914223213117440000, 
      (CF*NC*(2736*CF*(-63916872419644856779904980530586544662 + 
           53172897866447871677922752406572786625*Zeta[3]) + 
         8*CA*(-389218123211548293915370279687147889486 + 
           940047635550623987288652329779200*lm + 
           323792770198694030867648983792370671125*Zeta[3]) - 
         35*(8589934592*(-7769312946131540247113 + 4547987450401039805160*lm)*
            NL + 4199*NM*(15780133870568845262293470161618 + 
             9303861568035669467757281280*lm - 
             13144732190478494587779313390875*Zeta[3]) + 
           4199*NH*(9303861568035669467757281280*lm + 
             4199*(-49169282993213670627952802 + 40180958049089356145521875*
                Zeta[3])))))/6400427337305181406914223213117440000, 
      -(CF*NC*(2*CA*(-5804306721097858312631393203974701296607038 + 
            10613292697709685184121339171674521600*lm + 
            4828644877249537902423662353991255608912125*Zeta[3]) + 
          CF*(-711214604187137601900796248758006673884480264 + 
            591664553743190914625009139550243053291199500*Zeta[3]) - 
          1155*(46189*NM*(260790296400750564355054665820342 + 
              72343064812165447558071582720*lm - 
              217022016074758613094309180872625*Zeta[3]) + 
            7*(206158430208*(-2195268850133159887739 + 2315454892238395444680*
                 lm)*NL + 4199*NH*(113681958990545703305541058560*lm + 
                71383*(-28065435774035042871994606 + 
                  22931606861161918623829125*Zeta[3]))))))/
       19431697396058530751391581675024547840000, 
      (CF*NC*(52*CA*(-54292857228619308356158432710008081820262 + 
           73430710817906822789068655217868800*lm + 
           45166656228717782010369636576494694682425*Zeta[3]) + 
         200*CF*(-939846124698630909100377713703092718678434 + 
           781864834150271721091444063655355881898579*Zeta[3]) - 
         231*(137438953472*(-9051173392505062927673 + 21867370683591830997600*
              lm)*NL + 146965*NM*(147000317692004714136344234404682 + 
             20449961160392981283424174080*lm - 
             122297086745689233194952726365775*Zeta[3]) + 
           4199*NH*(715748640613754344919846092800*lm + 
             4199*(-2502021318808646731025134762 + 
               2044121949023626423978401375*Zeta[3])))))/
       3886339479211706150278316335004909568000, 
      -(CF*NC*(228*CA*(-210536790428487566684457512110937898795992206 + 
            208463832352420851452954591082892492800*lm + 
            175147257554093209018823916695860549688155125*Zeta[3]) + 
          184*CF*(-18808876689325576182883283248712098611729969646 + 
            15647242244676452207074223834564148690338245125*Zeta[3]) - 
          385*(21440476741632*(-12266710169302155804751 + 
              1046906045134597044852840*lm)*NL + 37145*NM*
             (8370358819384979586437675170929075962 + 
              604284956558951912103909412306944*lm - 
              6963263130114967444240406361848796375*Zeta[3]) + 
            7429*NH*(3021424782794759560519547061534720*lm + 
              170867*(-223904475172306112046936769162 + 
                182908814844261645933117699375*Zeta[3])))))/
       54823295586746468093259449099135924305920000, 
      (CF*NC*(2*CA*(-782671632392857405006417575174291752885682946 + 
           565826708037533404818279400426186997760*lm + 
           651110856232555794274686950564797528979621475*Zeta[3]) + 
         92*CF*(-1323921696879190599936151288446037139753442226 + 
           1101380184062064449171569408195767876951789675*Zeta[3]) - 
         21*(274877906944*(10896001812666478476306757 + 
             35644425494840116446852360*lm)*NL + 59432*NM*
            (4302118400598334483187631986333421406 + 
             164858410860193207040584313733120*lm - 
             3578874220874816537436044574621454125*Zeta[3]) + 
           22287*NH*(439622428960515218774891503288320*lm + 
             141151*(-34958085574221237367600887922 + 
               28554195279554669260730068875*Zeta[3])))))/
       1495180788729449129816166793612797935616000}, 2, 24, 1]
 
CbarLSeries["v", 2, 1, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(15*CA*(4665 + 15840*lm^2 - 10732*Pi^2 + 432*Pi^4 - 
            80*lm*(-483 + 44*Pi^2) - 244512*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 34560*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            40752*PolyGamma[2, 1] + 434496*Zeta[3]) + 
          2*(CF*(-194400*lm^2 - 72892*Pi^2 + 1200*Pi^4 + 43200*lm*(-6 + 
                Pi^2) + 15*(-16097 + 244512*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 34560*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                40752*PolyGamma[2, 1] - 396480*Zeta[3])) + 
            60*(NL*(15 - 420*lm - 360*lm^2 + 52*Pi^2 + 80*lm*Pi^2 - 
                960*Zeta[3]) + NM*(15 - 360*lm^2 + 52*Pi^2 + 
                20*lm*(-21 + 4*Pi^2) + 80*PolyGamma[2, 1] - 800*Zeta[3]) + 
              NH*(-10593 - 420*lm - 360*lm^2 + 80*lm*Pi^2 - 68976*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 11496*PolyGamma[2, 1] + 
                132432*Zeta[3])))))/6220800, 
      (CF*NC*(5*CA*(-619125 + 63360*lm^2 - 59860*Pi^2 + 2376*Pi^4 - 
           1280*lm*(3 + 11*Pi^2) - 396960*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 190080*Im[PolyLog[2, (-1)^(1/3)]]^
             2 + 66400*PolyGamma[2, 1] + 688160*Zeta[3]) - 
         2*(-1600*(NH*(4101 - 18*lm^2 + 4*lm*(6 + Pi^2) - 504*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 84*PolyGamma[2, 1] - 2520*
                Zeta[3]) + NL*(147 - 18*lm^2 + 4*Pi^2 + 4*lm*(6 + Pi^2) - 48*
                Zeta[3]) + NM*(147 - 18*lm^2 + 4*Pi^2 + 4*lm*(6 + Pi^2) + 4*
                PolyGamma[2, 1] - 40*Zeta[3])) + 
           CF*(259200*lm^2 + 160436*Pi^2 + 1640*Pi^4 - 14400*lm*
              (21 + 4*Pi^2) + 5*(191133 - 396960*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 190080*Im[PolyLog[2, (-1)^(1/3)]]^2 + 66400*
                PolyGamma[2, 1] + 485216*Zeta[3])))))/2073600, 
      -(CF*NC*(CF*(171495 + 19440*lm^2 + 12236*Pi^2 - 1572*Pi^4 + 
            2160*lm*(-45 + 2*Pi^2) + 479616*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 181440*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
            87880*PolyGamma[2, 1] - 1124816*Zeta[3]) + 
          CA*(227865 - 11880*lm^2 - 17228*Pi^2 + 1170*Pi^4 - 
            60*lm*(-771 + 44*Pi^2) - 239808*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 90720*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            43940*PolyGamma[2, 1] + 532888*Zeta[3]) + 
          2*(3*NL*(-5185 + 360*lm^2 + 404*Pi^2 + 20*lm*(-93 + 4*Pi^2) - 
              960*Zeta[3]) + 3*NM*(-10585 + 360*lm^2 + 884*Pi^2 + 
              20*lm*(-93 + 4*Pi^2) + 240*PolyGamma[2, 1] - 480*Zeta[3]) + 
            NH*(-252363 + 1080*lm^2 + 60*lm*(-93 + 4*Pi^2) - 
              632016*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 113000*PolyGamma[2, 
                1] + 1360720*Zeta[3]))))/103680, 
      -(CF*NC*(6220800*(27*CF*(5 + 2*lm) - CA*(76 + 33*lm) + 
            2*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          12441600*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          5*CA*(11975040*lm^2 - 4793796*Pi^2 + 1118600*Sqrt[3]*Pi^3 + 
            289440*Pi^4 - 34560*lm*(-639 + 22*Pi^2) + 862920*Sqrt[3]*Pi*
             Log[3]^2 + 15*(-2473281 - 2605440*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 3608064*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              2761344*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              586592*PolyGamma[2, 1] + 2492512*Zeta[3])) - 
          10800*Log[x]*(CA*(57531 + 29016*lm + 4752*lm^2 + 978*Pi^2 - 
              6392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 10368*Zeta[3]) - 
            2*(24*(3*NM*(-14 + 29*lm + 6*lm^2 + 6*Pi^2) + 3*NL*
                 (58 + 29*lm + 6*lm^2 + 6*Pi^2) + NH*(3296 + 87*lm + 
                  18*lm^2 - 1864*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
              CF*(37803 + 19440*lm + 3888*lm^2 + 426*Pi^2 - 6392*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 10368*Zeta[3]))) + 
          4*(-2400*(9*NL*(366 - 126*lm^2 - 95*Pi^2 + 8*lm*(-9 + Pi^2) - 
                744*Zeta[3]) + 9*NM*(1851 - 126*lm^2 - 59*Pi^2 + 
                8*lm*(-9 + Pi^2) - 34*PolyGamma[2, 1] + 484*Zeta[3]) - 
              NH*(-276921 + 1134*lm^2 + 8155*Sqrt[3]*Pi^3 - 
                72*lm*(-9 + Pi^2) - 12420*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 301968*Sqrt[3]*Im[PolyLog[3, 
                   -((-1)^(5/6)/Sqrt[3])]] + 6291*Sqrt[3]*Pi*Log[3]^2 + 
                6012*PolyGamma[2, 1] + 8136*Zeta[3])) + 
            CF*(24494400*lm^2 - 668124*Pi^2 + 2796500*Sqrt[3]*Pi^3 + 
              447120*Pi^4 - 194400*lm*(-93 + 8*Pi^2) + 2157300*Sqrt[3]*Pi*
               Log[3]^2 + 15*(5916141 - 6513600*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 9020160*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
                6903360*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                1466480*PolyGamma[2, 1] + 1047712*Zeta[3])))))/27993600, 
      -(CF*NC*(9331200*(9*CF*(19 + 12*lm) - 2*CA*(76 + 33*lm) + 
            4*(8*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          37324800*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          15*CA*(-10692000*lm^2 - 1508652*Pi^2 - 2921800*Sqrt[3]*Pi^3 + 
            99576*Pi^4 - 2160*lm*(-6273 + 308*Pi^2) - 2253960*Sqrt[3]*Pi*
             Log[3]^2 - 3*(-63932355 + 32300448*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 31259520*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              36063360*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              4502128*PolyGamma[2, 1] - 99376064*Zeta[3])) + 
          10800*Log[x]*(3*CA*(-49305 - 20304*lm - 4752*lm^2 + 2886*Pi^2 + 
              16696*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 10368*Zeta[3]) + 
            2*(8*(9*NM*(-241 + 54*lm + 18*lm^2 + 48*Pi^2) + 
                2*(9*NL*(55 + 27*lm + 9*lm^2 + 9*Pi^2) + NH*(3894 + 
                    243*lm + 81*lm^2 - 2128*Sqrt[3]*Im[PolyLog[2, (-1)^
                        (1/3)]]))) + CF*(73161 + 36936*lm + 11664*lm^2 - 
                10026*Pi^2 - 50088*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                31104*Zeta[3]))) + 2*(-3*CF*(-43740000*lm^2 + 16860492*Pi^2 - 
              14609000*Sqrt[3]*Pi^3 + 14040*Pi^4 - 388800*lm*(-267 + 
                7*Pi^2) - 11269800*Sqrt[3]*Pi*Log[3]^2 - 15*(-4917897 + 
                32300448*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 31259520*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 + 36063360*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 4502128*PolyGamma[2, 
                  1] - 112617728*Zeta[3])) + 20*(81*NM*(-215955 + 
                9000*lm^2 + 32732*Pi^2 + 20*lm*(-1143 + 28*Pi^2) + 
                16424*PolyGamma[2, 1] - 112112*Zeta[3]) + 81*NL*(-83475 + 
                9000*lm^2 + 12092*Pi^2 + 20*lm*(-1143 + 28*Pi^2) + 
                45120*Zeta[3]) + NH*(-117074403 + 729000*lm^2 + 
                1489600*Sqrt[3]*Pi^3 + 1620*lm*(-1143 + 28*Pi^2) - 
                237080016*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 55157760*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                1149120*Sqrt[3]*Pi*Log[3]^2 + 46277952*PolyGamma[2, 1] + 
                491775744*Zeta[3])))))/167961600, (3785303*CF^2*NC)/622080 - 
       (95*CF^2*lm*NC)/8 - (51*CF^2*lm^2*NC)/4 + (1769*CF*NM*NC)/54 - 
       (13*CF*lm*NM*NC)/12 - (17*CF*lm^2*NM*NC)/12 + (1577*CF*NC*NL)/216 - 
       (13*CF*lm*NC*NL)/12 - (17*CF*lm^2*NC*NL)/12 + 
       (2481923*CF*NC*NH)/4500 - (13*CF*lm*NC*NH)/12 - 
       (17*CF*lm^2*NC*NH)/12 + (31995043*CF^2*NC*Pi^2)/5443200 + 
       (CF^2*lm*NC*Pi^2)/2 - (109*CF*NM*NC*Pi^2)/108 + 
       (CF*lm*NM*NC*Pi^2)/18 - (101*CF*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NL*Pi^2)/18 + (CF*lm*NC*NH*Pi^2)/18 - 
       (831355*CF^2*NC*Pi^3)/(69984*Sqrt[3]) - (533155*CF*NC*NH*Pi^3)/
        (8748*Sqrt[3]) - (13169*CF^2*NC*Pi^4)/25920 + 
       (335693*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(1944*Sqrt[3]) + 
       (33370*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(243*Sqrt[3]) - 
       (1123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (23753*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(54*Sqrt[3]) - 
       (60932*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27*Sqrt[3]) - 
       (23753*CF^2*NC*Pi*Log[3]^2)/(2592*Sqrt[3]) - 
       (15233*CF*NC*NH*Pi*Log[3]^2)/(324*Sqrt[3]) - 
       (CF*NC*(-5*CA*(1733 + 792*lm) + 2*(5*CF*(1535 + 648*lm) + 
            4*(280*NM + 90*lm*NM + 135*NL + 90*lm*NL + 4*NH + 
              90*lm*NH)))*Log[x]^2)/60 - 4*CF*NC*(13*CA + 46*CF - 
         2*(2*NM + NL))*Log[x]^3 - (606287*CF^2*NC*PolyGamma[2, 1])/34992 - 
       (7*CF*NM*NC*PolyGamma[2, 1])/9 - (36980*CF*NC*NH*PolyGamma[2, 1])/
        2187 + (2470237*CF^2*NC*Zeta[3])/174960 + (358*CF*NM*NC*Zeta[3])/9 - 
       (50*CF*NC*NL*Zeta[3])/3 + (152516*CF*NC*NH*Zeta[3])/2187 + 
       (CF*NC*Log[x]*(2*(-4*(225*NM*(211 + 582*lm + 108*lm^2 + 18*Pi^2) + 
              450*NL*(704 + 291*lm + 54*lm^2 + 72*Pi^2) + NH*(5403273 + 
                130950*lm + 24300*lm^2 - 3046600*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) + 25*CF*(-420204 - 194400*lm - 34992*lm^2 + 
              3951*Pi^2 + 95012*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              93312*Zeta[3])) + 25*CA*(653961 + 284904*lm + 42768*lm^2 + 
            3969*Pi^2 - 95012*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            93312*Zeta[3])))/97200 + 
       (CA*CF*NC*(261740160*lm^2 - 136594188*Pi^2 + 66508400*Sqrt[3]*Pi^3 + 
          10026504*Pi^4 - 466560*lm*(-1143 + 22*Pi^2) + 51306480*Sqrt[3]*Pi*
           Log[3]^2 + 15*(-107735355 - 64453056*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 104789376*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 164180736*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 19401184*
             PolyGamma[2, 1] + 36275168*Zeta[3])))/33592320, 
      -(CF*NC*(-5443200*(165*CA*(449 + 142*lm) - 2*(53495*CF + 19170*CF*lm + 
              10610*NM + 2130*lm*NM + 2940*NL + 2130*lm*NL + 108*NH + 
              2130*lm*NH))*Log[x]^2 + 108864000*(277*CA + 5008*CF - 
            122*NM - 142*NL)*Log[x]^3 - 525*CA*(24698520*lm^2 - 
            2770686*Pi^2 + 13515250*Sqrt[3]*Pi^3 + 675540*Pi^4 + 
            5940*lm*(-3779 + 156*Pi^2) + 10426050*Sqrt[3]*Pi*Log[3]^2 + 
            3*(-105761025 + 75336936*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              89346240*Im[PolyLog[2, (-1)^(1/3)]]^2 + 166816800*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 3537052*PolyGamma[2, 
                1] - 343143320*Zeta[3])) - 3780*Log[x]*
           (75*CA*(472503 + 324096*lm + 71280*lm^2 + 24834*Pi^2 - 
              308920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 155520*Zeta[3]) - 
            2*(8*(225*NL*(2467 + 884*lm + 270*lm^2 + 374*Pi^2) + 
                150*NM*(-5797 + 1326*lm + 405*lm^2 + 1896*Pi^2) + 
                NH*(3280119 + 198900*lm + 60750*lm^2 - 1755200*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 75*CF*(66033 + 200664*lm + 
                58320*lm^2 + 13530*Pi^2 - 308920*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 155520*Zeta[3]))) + 
          2*(30*CF*(353637900*lm^2 - 221113773*Pi^2 + 236516875*Sqrt[3]*Pi^
                3 + 14180670*Pi^4 + 170100*lm*(-4189 + 78*Pi^2) + 
              182455875*Sqrt[3]*Pi*Log[3]^2 + 105*(14797671 + 37668468*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 44673120*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 + 83408400*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1768526*PolyGamma[2, 
                  1] - 193056748*Zeta[3])) + 7*(675*NM*(-1783505 + 
                249480*lm^2 + 1630068*Pi^2 + 60*lm*(-9071 + 156*Pi^2) + 
                1491624*PolyGamma[2, 1] - 7911792*Zeta[3]) + 
              2025*NL*(-1017875 + 83160*lm^2 + 149596*Pi^2 + 
                20*lm*(-9071 + 156*Pi^2) + 1039680*Zeta[3]) + 
              NH*(-28637153091 + 168399000*lm^2 + 614320000*Sqrt[3]*Pi^3 + 
                40500*lm*(-9071 + 156*Pi^2) - 57284869200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 22747392000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 473904000*Sqrt[3]*Pi*
                 Log[3]^2 + 12003491200*PolyGamma[2, 1] + 112976086400*
                 Zeta[3])))))/4408992000, (1155838669*CF^2*NC)/8398080 - 
       (1649*CF^2*lm*NC)/54 - 31*CF^2*lm^2*NC + (940577*CF*NM*NC)/5832 - 
       (685*CF*lm*NM*NC)/243 - (31*CF*lm^2*NM*NC)/9 + 
       (70045*CF*NC*NL)/1944 - (685*CF*lm*NC*NL)/243 - 
       (31*CF*lm^2*NC*NL)/9 + (1532462542103*CF*NC*NH)/750141000 - 
       (685*CF*lm*NC*NH)/243 - (31*CF*lm^2*NC*NH)/9 + 
       (2491177*CF^2*NC*Pi^2)/75600 + (8*CF^2*lm*NC*Pi^2)/9 + 
       (1943*CF*NM*NC*Pi^2)/243 + (8*CF*lm*NM*NC*Pi^2)/81 - 
       (1547*CF*NC*NL*Pi^2)/243 + (8*CF*lm*NC*NL*Pi^2)/81 + 
       (8*CF*lm*NC*NH*Pi^2)/81 - (8343055*CF^2*NC*Pi^3)/(157464*Sqrt[3]) - 
       (3200645*CF*NC*NH*Pi^3)/(13122*Sqrt[3]) - (3127*CF^2*NC*Pi^4)/1620 + 
       (3488324*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
       (1351940*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2187*Sqrt[3]) - 
       284*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (476746*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(243*Sqrt[3]) - 
       (731576*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (81*Sqrt[3]) - (238373*CF^2*NC*Pi*Log[3]^2)/(5832*Sqrt[3]) - 
       (91447*CF*NC*NH*Pi*Log[3]^2)/(486*Sqrt[3]) - 
       (CF*NC*(-105*CA*(68659 + 32384*lm) + 8*(35*CF*(45589 + 19872*lm) + 
            81830*NM + 77280*lm*NM + 109200*NL + 77280*lm*NL + 7047*NH + 
            77280*lm*NH))*Log[x]^2)/11340 - 
       (2*CF*NC*(10217*CA + 44492*CF - 9160*NM - 1472*NL)*Log[x]^3)/81 - 
       (14381419*CF^2*NC*PolyGamma[2, 1])/236196 + 
       (2867*CF*NM*NC*PolyGamma[2, 1])/162 - 
       (2690723*CF*NC*NH*PolyGamma[2, 1])/39366 + 
       (CA*CF*NC*(2505777120*lm^2 - 2212471260*Pi^2 + 1168027700*Sqrt[3]*
           Pi^3 + 138107592*Pi^4 - 272160*lm*(-19253 + 264*Pi^2) + 
          901049940*Sqrt[3]*Pi*Log[3]^2 - 35*(718443873 + 334879104*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 536637312*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 1235725632*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 115051352*
             PolyGamma[2, 1] - 84512656*Zeta[3])))/132269760 + 
       (59958799*CF^2*NC*Zeta[3])/590490 + (16847*CF*NM*NC*Zeta[3])/81 - 
       (1864*CF*NC*NL*Zeta[3])/27 + (7540549*CF*NC*NH*Zeta[3])/19683 + 
       (CF*NC*Log[x]*(48*(-7350*NM*(9529 + 4614*lm + 810*lm^2 - 4893*Pi^2) - 
            11025*NL*(8959 + 3076*lm + 540*lm^2 + 916*Pi^2) - 
            2*NH*(796018473 + 16956450*lm + 2976750*lm^2 - 448090300*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          1225*CF*(-27102543 - 12309408*lm - 2099520*lm^2 + 452088*Pi^2 + 
            7627936*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 5598720*Zeta[3]) + 
          1225*CA*(21710685 + 8941536*lm + 1283040*lm^2 + 45576*Pi^2 - 
            3813968*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 2799360*Zeta[3])))/
        42865200, (-99114591437*CF^2*NC)/839808000 + (11599*CF^2*lm*NC)/576 - 
       (171*CF^2*lm^2*NC)/16 + (11231011*CF*NM*NC)/1944000 + 
       (12625*CF*lm*NM*NC)/5184 - (19*CF*lm^2*NM*NC)/16 + 
       (455965*CF*NC*NL)/20736 + (12625*CF*lm*NC*NL)/5184 - 
       (19*CF*lm^2*NC*NL)/16 + (3934889615567*CF*NC*NH)/18003384000 + 
       (12625*CF*lm*NC*NH)/5184 - (19*CF*lm^2*NC*NH)/16 - 
       (14568857*CF^2*NC*Pi^2)/604800 - (7*CF^2*lm*NC*Pi^2)/24 - 
       (263183*CF*NM*NC*Pi^2)/12960 - (7*CF*lm*NM*NC*Pi^2)/216 - 
       (35023*CF*NC*NL*Pi^2)/12960 - (7*CF*lm*NC*NL*Pi^2)/216 - 
       (7*CF*lm*NC*NH*Pi^2)/216 - (21003955*CF^2*NC*Pi^3)/(629856*Sqrt[3]) - 
       (5909365*CF*NC*NH*Pi^3)/(314928*Sqrt[3]) - (293*CF^2*NC*Pi^4)/360 - 
       (430088161*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(1049760*Sqrt[3]) + 
       (368081923*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(262440*Sqrt[3]) - 
       170*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (600113*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(486*Sqrt[3]) - 
       (168839*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (243*Sqrt[3]) - (600113*CF^2*NC*Pi*Log[3]^2)/(23328*Sqrt[3]) - 
       (168839*CF*NC*NH*Pi*Log[3]^2)/(11664*Sqrt[3]) - 
       (CF*NC*(14*CF*(1094339 + 210060*lm) - 7*CA*(1331149 + 256740*lm) + 
          3302264*NM + 326760*lm*NM + 407190*NL + 326760*lm*NL + 
          35568*NH + 326760*lm*NH)*Log[x]^2)/15120 + 
       (CF*NC*(9063*CA - 131149*CF - 804*NM + 2334*NL)*Log[x]^3)/162 - 
       (414309997*CF^2*NC*PolyGamma[2, 1])/9447840 - 
       (673*CF*NM*NC*PolyGamma[2, 1])/36 - 
       (489629663*CF*NC*NH*PolyGamma[2, 1])/4723920 + 
       (CA*CF*NC*(12341241000*lm^2 + 28453362075*Pi^2 + 10501977500*Sqrt[3]*
           Pi^3 + 719960400*Pi^4 + 182250*lm*(-52691 + 1848*Pi^2) + 
          8101525500*Sqrt[3]*Pi*Log[3]^2 + 4*(-25463331981 + 
            32256612075*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            40153320000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 97218306000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10357749925*
             PolyGamma[2, 1] - 196033914850*Zeta[3])))/1889568000 + 
       (4336619453*CF^2*NC*Zeta[3])/4723920 + (361*CF*NM*NC*Zeta[3])/6 - 
       (236*CF*NC*NL*Zeta[3])/9 - (2084127623*CF*NC*NH*Zeta[3])/2361960 - 
       (CF*NC*Log[x]*(-49*CA*(234517053 + 226516500*lm + 48114000*lm^2 + 
            115352100*Pi^2 - 240045200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            104976000*Zeta[3]) + 2*(2665878075*NL + 736249500*lm*NL + 
            214326000*lm^2*NL + 12547352976*NH + 736249500*lm*NH + 
            214326000*lm^2*NH + 380230200*NL*Pi^2 + 
            2646*NM*(1008703 + 278250*lm + 81000*lm^2 + 668100*Pi^2) - 
            6618488800*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            98*CF*(-31906461 + 70895250*lm + 19683000*lm^2 + 50758650*Pi^2 - 
              120022600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 52488000*Zeta[
                3]))))/171460800, (13091107417147*CF^2*NC)/30233088000 - 
       (26551*CF^2*lm*NC)/432 - (245*CF^2*lm^2*NC)/4 + 
       (1401542231*CF*NM*NC)/5832000 - (22141*CF*lm*NM*NC)/3888 - 
       (245*CF*lm^2*NM*NC)/36 + (246383*CF*NC*NL)/1944 - 
       (22141*CF*lm*NC*NL)/3888 - (245*CF*lm^2*NC*NL)/36 + 
       (78335397027431*CF*NC*NH)/13502538000 - (22141*CF*lm*NC*NH)/3888 - 
       (245*CF*lm^2*NC*NH)/36 + (16062143*CF^2*NC*Pi^2)/108864 + 
       (25*CF^2*lm*NC*Pi^2)/18 + (49943*CF*NM*NC*Pi^2)/243 + 
       (25*CF*lm*NM*NC*Pi^2)/162 - (15635*CF*NC*NL*Pi^2)/972 + 
       (25*CF*lm*NC*NL*Pi^2)/162 + (25*CF*lm*NC*NH*Pi^2)/162 - 
       (3687683125*CF^2*NC*Pi^3)/(22674816*Sqrt[3]) - 
       (84957215*CF*NC*NH*Pi^3)/(118098*Sqrt[3]) - (26965*CF^2*NC*Pi^4)/
        5184 + (5133771779*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (3779136*Sqrt[3]) + (38689171*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (19683*Sqrt[3]) - (8075*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (105362375*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (17496*Sqrt[3]) - (19418792*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (105362375*CF^2*NC*Pi*Log[3]^2)/(839808*Sqrt[3]) - 
       (2427349*CF*NC*NH*Pi*Log[3]^2)/(4374*Sqrt[3]) - 
       (CF*NC*(-7*CA*(23096021 + 12392160*lm) + 
          2*(21*CF*(6698077 + 3379680*lm) + 8*(7*(-1578721 + 140820*lm)*NM + 
              6*(35*(6395 + 4694*lm)*NL + (22037 + 164290*lm)*NH))))*
         Log[x]^2)/90720 - (CF*NC*(145155*CA + 691790*CF - 
          8*(37985*NM + 2347*NL))*Log[x]^3)/162 - 
       (1085119739*CF^2*NC*PolyGamma[2, 1])/8503056 + 
       (26995*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (11790664*CF*NC*NH*PolyGamma[2, 1])/59049 + 
       (CF*NC*Log[x]*(2*(96*(-1323*NM*(10355119 + 4771500*lm + 810000*lm^2 - 
                20756400*Pi^2) - 4*(99225*NL*(54664 + 15905*lm + 2700*lm^2 + 
                  5594*Pi^2) + NH*(84570564867 + 1578173625*lm + 267907500*
                   lm^2 - 47576040400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
            49*CF*(-219732297639 - 114458832000*lm - 18895680000*lm^2 + 
              9835619400*Pi^2 + 84289900000*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 50388480000*Zeta[3])) - 
          49*CA*(-381963188139 - 165438288000*lm - 23094720000*lm^2 + 
            4125702600*Pi^2 + 84289900000*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 50388480000*Zeta[3])))/12345177600 + 
       (3203960915*CF^2*NC*Zeta[3])/8503056 + (59852*CF*NM*NC*Zeta[3])/81 - 
       (5644*CF*NC*NL*Zeta[3])/27 + (74104672*CF*NC*NH*Zeta[3])/59049 + 
       (CA*CF*NC*(142586801280000*lm^2 - 269796543120000*Pi^2 + 
          103255127500000*Sqrt[3]*Pi^3 + 10377664920000*Pi^4 - 
          489888000*lm*(-613991 + 6600*Pi^2) + 79653955500000*Sqrt[3]*Pi*
           Log[3]^2 - 7*(267876081257823 + 123210522696000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 183099139200000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 546198552000000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 34723831648000*
             PolyGamma[2, 1] + 764694496000*Zeta[3])))/3809369088000, 
      (21358890452612021*CF^2*NC)/51849745920000 + (1566019*CF^2*lm*NC)/
        43200 - (319*CF^2*lm^2*NC)/16 + (461267142181*CF*NM*NC)/2000376000 + 
       (1709569*CF*lm*NM*NC)/388800 - (319*CF*lm^2*NM*NC)/144 + 
       (477933497*CF*NC*NL)/7776000 + (1709569*CF*lm*NC*NL)/388800 - 
       (319*CF*lm^2*NC*NL)/144 + (13121743702957*CF*NC*NH)/30380710500 + 
       (1709569*CF*lm*NC*NH)/388800 - (319*CF*lm^2*NC*NH)/144 - 
       (2475727717*CF^2*NC*Pi^2)/5443200 - (31*CF^2*lm*NC*Pi^2)/72 - 
       (6414839*CF*NM*NC*Pi^2)/38880 - (31*CF*lm*NM*NC*Pi^2)/648 - 
       (237583*CF*NC*NL*Pi^2)/38880 - (31*CF*lm*NC*NL*Pi^2)/648 - 
       (31*CF*lm*NC*NH*Pi^2)/648 - (1955936857*CF^2*NC*Pi^3)/
        (22674816*Sqrt[3]) - (390297845*CF*NC*NH*Pi^3)/(8503056*Sqrt[3]) - 
       (11461*CF^2*NC*Pi^4)/5184 - (83932534171*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(94478400*Sqrt[3]) + 
       (4379940079*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1417176*Sqrt[3]) - 
       (1481*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (279419551*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (87480*Sqrt[3]) - (11151367*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (279419551*CF^2*NC*Pi*Log[3]^2)/(4199040*Sqrt[3]) - 
       (11151367*CF*NC*NH*Pi*Log[3]^2)/(314928*Sqrt[3]) - 
       (CF*NC*(-(CA*(942320693 + 79949100*lm)) + 
          5*(CF*(346318729 + 26165160*lm) + 8*(11092432 + 363405*lm)*NM + 
            6*(566069*NL + 484540*lm*NL + 78224*NH + 484540*lm*NH)))*
         Log[x]^2)/226800 + (CF*NC*(734891*CA - 3477689*CF - 273620*NM + 
          34610*NL)*Log[x]^3)/810 - (51934316639*CF^2*NC*PolyGamma[2, 1])/
        85030560 - (179603*CF*NM*NC*PolyGamma[2, 1])/1620 - 
       (30512261197*CF*NC*NH*PolyGamma[2, 1])/127545840 + 
       (CA*CF*NC*(-81917060747340699 + 2274259480416000*lm^2 + 
          43712162890522560*Pi^2 + 2683545367804000*Sqrt[3]*Pi^3 + 
          199193041252800*Pi^4 + 2640496320*lm*(-613369 + 18600*Pi^2) + 
          27637304851826880*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          34555263168384000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          99367851333542400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          2070163569448800*Sqrt[3]*Pi*Log[3]^2 + 57003105942966400*
           PolyGamma[2, 1] - 191757313651993600*Zeta[3]))/186659085312000 + 
       (24146318863*CF^2*NC*Zeta[3])/10628820 + (163537*CF*NM*NC*Zeta[3])/
        810 - (2030*CF*NC*NL*Zeta[3])/27 - (119708531317*CF*NC*NH*Zeta[3])/
        63772920 - (CF*NC*Log[x]*(-3*CA*(42590590301361 + 9535287535200*lm + 
            1980372240000*lm^2 + 18030934416600*Pi^2 - 10953246399200*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 4320812160000*Zeta[3]) + 
          10*(8*(35721*NL*(6010531 + 1338940*lm + 378000*lm^2 + 
                818200*Pi^2) + 486*NM*(4213070419 + 98412090*lm + 
                27783000*lm^2 + 675538500*Pi^2) + 4*NH*(209357905647 + 
                11957068935*lm + 3375634500*lm^2 - 109283396600*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 3*CF*(5808770692359 + 
              1201888769760*lm + 324060912000*lm^2 + 3461704487640*Pi^2 - 
              2190649279840*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              864162432000*Zeta[3]))))/185177664000, 
      (-3817324704909769*CF^2*NC)/38887309440000 - (16127*CF^2*lm*NC)/150 - 
       (213*CF^2*lm^2*NC)/2 - (4512192031*CF*NM*NC)/1111320 - 
       (26929*CF*lm*NM*NC)/2700 - (71*CF*lm^2*NM*NC)/6 + 
       (11355227*CF*NC*NL)/32400 - (26929*CF*lm*NC*NL)/2700 - 
       (71*CF*lm^2*NC*NL)/6 + (4470336251801355211*CF*NC*NH)/
        323493805404000 - (26929*CF*lm*NC*NH)/2700 - (71*CF*lm^2*NC*NH)/6 + 
       (162170387*CF^2*NC*Pi^2)/181440 + 2*CF^2*lm*NC*Pi^2 + 
       (424597*CF*NM*NC*Pi^2)/180 + (2*CF*lm*NM*NC*Pi^2)/9 - 
       (6119*CF*NC*NL*Pi^2)/180 + (2*CF*lm*NC*NL*Pi^2)/9 + 
       (2*CF*lm*NC*NH*Pi^2)/9 - (6805201753*CF^2*NC*Pi^3)/
        (17006112*Sqrt[3]) - (3724946015*CF*NC*NH*Pi^3)/(2125764*Sqrt[3]) - 
       (37157*CF^2*NC*Pi^4)/3240 + (107584883773*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(35429400*Sqrt[3]) + 
       (900187049*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(177147*Sqrt[3]) - 
       (4094*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (972171679*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (65610*Sqrt[3]) - (425708116*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (972171679*CF^2*NC*Pi*Log[3]^2)/(3149280*Sqrt[3]) - 
       (106427029*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) - 
       (CF*NC*(-121*CA*(60664693 + 101001600*lm) + 
          4*(11*CF*(196553353 + 454507200*lm) + 
            360*(264*(-354391 + 5845*lm)*NM + 770*(2665 + 2004*lm)*NL + 
              (264967 + 1543080*lm)*NH)))*Log[x]^2)/4989600 - 
       (CF*NC*(2604373*CA + 4*(2339453*CF - 360*(7397*NM + 167*NL)))*
         Log[x]^3)/810 + (882845143*CF^2*NC*PolyGamma[2, 1])/4251528 + 
       (33578*CF*NM*NC*PolyGamma[2, 1])/9 - 
       (1528201747*CF*NC*NH*PolyGamma[2, 1])/3188646 + 
       CA*CF*NC*(-79804717892107123/155549237760000 + (781*lm^2)/12 - 
         (4753242551*Pi^2)/10886400 + (6805201753*Pi^3)/(34012224*Sqrt[3]) + 
         (38309*Pi^4)/6480 + lm*(743519/5400 - (11*Pi^2)/9) - 
         (107584883773*Im[PolyLog[2, (-1)^(1/3)]])/(70858800*Sqrt[3]) + 
         (2047*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (972171679*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(131220*Sqrt[3]) + 
         (972171679*Pi*Log[3]^2)/(6298560*Sqrt[3]) - 
         (882845143*PolyGamma[2, 1])/8503056 - (3043212911*Zeta[3])/
          21257640) + (5939623111*CF^2*NC*Zeta[3])/5314410 + 
       (32554*CF*NM*NC*Zeta[3])/9 - 518*CF*NC*NL*Zeta[3] + 
       (5096387465*CF*NC*NH*Zeta[3])/1594323 + 
       CF*Log[x]*((988684013*NM*NC)/264600 - (18977*lm*NM*NC)/90 - 
         35*lm^2*NM*NC - (301943*NC*NL)/360 - (18977*lm*NC*NL)/90 - 
         35*lm^2*NC*NL - (299129899281721*NC*NH)/23340101400 - 
         (18977*lm*NC*NH)/90 - 35*lm^2*NC*NH + (28819*NM*NC*Pi^2)/9 - 
         (773*NC*NL*Pi^2)/9 + (425708116*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (19683*Sqrt[3]) + CF*NC*(-3980342835949/7715736000 - (9751*lm)/5 - 
           315*lm^2 + (2089177*Pi^2)/3240 + 
           (972171679*Im[PolyLog[2, (-1)^(1/3)]])/(196830*Sqrt[3]) - 
           840*Zeta[3]) + CA*NC*(10597843970773/6172588800 + 
           (252847*lm)/180 + (385*lm^2)/2 - (866017*Pi^2)/3240 - 
           (972171679*Im[PolyLog[2, (-1)^(1/3)]])/(393660*Sqrt[3]) + 
           420*Zeta[3])), (825595842668823881*CF^2*NC)/77774618880000 + 
       (2559707*CF^2*lm*NC)/43200 - (533*CF^2*lm^2*NC)/16 + 
       (367580370939347*CF*NM*NC)/108020304000 + (2799557*CF*lm*NM*NC)/
        388800 - (533*CF*lm^2*NM*NC)/144 + (3440524271*CF*NC*NL)/23328000 + 
       (2799557*CF*lm*NC*NL)/388800 - (533*CF*lm^2*NC*NL)/144 + 
       (1233904340402677021*CF*NC*NH)/1663682427792000 + 
       (2799557*CF*lm*NC*NH)/388800 - (533*CF*lm^2*NC*NH)/144 - 
       (53035099351*CF^2*NC*Pi^2)/10886400 - (43*CF^2*lm*NC*Pi^2)/72 - 
       (13003195*CF*NM*NC*Pi^2)/7776 - (43*CF*lm*NM*NC*Pi^2)/648 - 
       (155597*CF*NC*NL*Pi^2)/12960 - (43*CF*lm*NC*NL*Pi^2)/648 - 
       (43*CF*lm*NC*NH*Pi^2)/648 - (12708230717*CF^2*NC*Pi^3)/
        (68024448*Sqrt[3]) - (7261083305*CF*NC*NH*Pi^3)/(76527504*Sqrt[3]) - 
       (125257*CF^2*NC*Pi^4)/25920 - (486262422401*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(283435200*Sqrt[3]) + 
       (77708868487*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12754584*Sqrt[3]) - (8491*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (1815461531*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (262440*Sqrt[3]) - (207459523*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (1815461531*CF^2*NC*Pi*Log[3]^2)/(12597120*Sqrt[3]) - 
       (207459523*CF*NC*NH*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (CF*NC*(66*CF*(28922527957 + 635115600*lm) - 
          33*CA*(29679111911 + 776252400*lm) + 
          40*(110*(136583165 + 1058526*lm)*NM + 
            7*(99*(187727 + 168020*lm)*NL + 2*(1722641 + 8316990*lm)*NH)))*
         Log[x]^2)/29937600 + (CF*NC*(2947351*CA - 8162912*CF - 1617400*NM + 
          33604*NL)*Log[x]^3)/324 - (177645976307*CF^2*NC*PolyGamma[2, 1])/
        28343520 - (1972909*CF*NM*NC*PolyGamma[2, 1])/2160 - 
       (281503339567*CF*NC*NH*PolyGamma[2, 1])/573956280 + 
       (CA*CF*NC*(3562442113230000*lm^2 + 428540739566434425*Pi^2 + 
          5448653919913750*Sqrt[3]*Pi^3 + 413532104422500*Pi^4 + 
          225042300*lm*(-10647727 + 283800*Pi^2) + 4203247309647750*Sqrt[3]*
           Pi*Log[3]^2 + 12*(-83771453821840536 + 4169700272088575*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 5159252257110000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 16812989238591000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 45699427404975750*
             PolyGamma[2, 1] - 15111598766523000*Zeta[3])))/174992892480000 + 
       (18005710307*CF^2*NC*Zeta[3])/7085880 + (1321571*CF*NM*NC*Zeta[3])/
        1080 - (1603*CF*NC*NL*Zeta[3])/9 - (1033113259987*CF*NC*NH*Zeta[3])/
        286978140 - (CF*NC*Log[x]*(-1089*CA*(871959239468823 + 
            29061191048400*lm + 5941116720000*lm^2 + 226523739172500*Pi^2 - 
            35583046007600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            12962436480000*Zeta[3]) + 
          4*(10*(117612*NM*(218911370203 + 904872465*lm + 250047000*lm^2 + 
                29713455450*Pi^2) + 7*(5557167*NL*(14715861 + 2735820*lm + 
                  756000*lm^2 + 1932200*Pi^2) + 2*NH*(135758555351169 + 
                  7601704310970*lm + 2100609126000*lm^2 - 70287286392400*
                   Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
            1089*CF*(413697101676279 + 9200436499800*lm + 2430456840000*lm^
                2 + 111953330770050*Pi^2 - 17791523003800*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 6481218240000*Zeta[3]))))/
        100829238048000, (-11951504298706523813*CF^2*NC)/839965883904000 - 
       (1852751*CF^2*lm*NC)/10800 - (679*CF^2*lm^2*NC)/4 - 
       (30373421629507*CF*NM*NC)/540101520 - (1547201*CF*lm*NM*NC)/97200 - 
       (679*CF*lm^2*NM*NC)/36 + (597342839*CF*NC*NL)/729000 - 
       (1547201*CF*lm*NC*NL)/97200 - (679*CF*lm^2*NC*NL)/36 + 
       (74315900119368299035783*CF*NC*NH)/2558577205701316800 - 
       (1547201*CF*lm*NC*NH)/97200 - (679*CF*lm^2*NC*NH)/36 + 
       (92103852107*CF^2*NC*Pi^2)/11975040 + (49*CF^2*lm*NC*Pi^2)/18 + 
       (107929273*CF*NM*NC*Pi^2)/4860 + (49*CF*lm*NM*NC*Pi^2)/162 - 
       (103229*CF*NC*NL*Pi^2)/1620 + (49*CF*lm*NC*NL*Pi^2)/162 + 
       (49*CF*lm*NC*NH*Pi^2)/162 - (1560918426613*CF^2*NC*Pi^3)/
        (1836660096*Sqrt[3]) - (71529645635*CF*NC*NH*Pi^3)/
        (19131876*Sqrt[3]) - (191387*CF^2*NC*Pi^4)/8640 + 
       (46924878267431*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (7652750400*Sqrt[3]) + (90905995192*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) - 
       (29827*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (222988346659*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7085880*Sqrt[3]) - (8174816644*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (222988346659*CF^2*NC*Pi*Log[3]^2)/(340122240*Sqrt[3]) - 
       (2043704161*CF*NC*NH*Pi*Log[3]^2)/(708588*Sqrt[3]) - 
       (CF*NC*(-429*CA*(-14100262123 + 2451372000*lm) + 
          8*(3861*CF*(-408877549 + 55713000*lm) + 
            10*(572*(-1121485313 + 4178475*lm)*NM + 3153150*(991 + 758*lm)*
               NL + (488071709 + 2390087700*lm)*NH)))*Log[x]^2)/194594400 - 
       (CF*NC*(6874243*CA + 4527179*CF - 38820260*NM - 265300*NL)*Log[x]^3)/
        405 + (3964262414903*CF^2*NC*PolyGamma[2, 1])/688747536 + 
       (1961671*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (28879654217*CF*NC*NH*PolyGamma[2, 1])/28697814 + 
       (CA*CF*NC*(457687996109486284851 + 7842131483598720000*lm^2 - 
          288909890357675428800*Pi^2 + 10707900406565180000*Sqrt[3]*Pi^3 + 
          855576708187320000*Pi^4 - 388873094400*lm*(-42685411 + 
            323400*Pi^2) - 77257119579498398400*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 93951234072017280000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 396498255054527808000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 8260380313635996000*
           Sqrt[3]*Pi*Log[3]^2 - 217558721329876640000*PolyGamma[2, 1] - 
          56966767479664672000*Zeta[3]))/75596929551360000 + 
       (2187230063587*CF^2*NC*Zeta[3])/688747536 + (835471*CF*NM*NC*Zeta[3])/
        27 - (10052*CF*NC*NL*Zeta[3])/9 + (99840316099*CF*NC*NH*Zeta[3])/
        14348907 + CF*Log[x]*((287345234039*NM*NC)/4286520 - 
         (107989*lm*NM*NC)/270 - (196*lm^2*NM*NC)/3 - (271687*NC*NL)/150 - 
         (107989*lm*NC*NL)/270 - (196*lm^2*NC*NL)/3 - 
         (485267928790002089*NC*NH)/17750147114700 - (107989*lm*NC*NH)/
          270 - (196*lm^2*NC*NH)/3 + (1928987*NM*NC*Pi^2)/81 - 
         (15029*NC*NL*Pi^2)/81 + (8174816644*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(177147*Sqrt[3]) + 
         CF*NC*(26833767045524837/833299488000 - (110929*lm)/30 - 588*lm^2 + 
           (82144627*Pi^2)/12960 + (222988346659*Im[PolyLog[2, (-1)^(1/3)]])/
            (21257640*Sqrt[3]) - 1568*Zeta[3]) + 
         CA*NC*(-21992887776643307/1666598976000 + (1434839*lm)/540 + 
           (1078*lm^2)/3 - (79107343*Pi^2)/25920 - 
           (222988346659*Im[PolyLog[2, (-1)^(1/3)]])/(42515280*Sqrt[3]) + 
           784*Zeta[3])), (4667533080458079058547953*CF^2*NC)/
        39129810701667840000 + (63755639*CF^2*lm*NC)/705600 - 
       (825*CF^2*lm^2*NC)/16 + (1923231734716947679*CF*NM*NC)/
        47925008208000 + (69819389*CF*lm*NM*NC)/6350400 - 
       (275*CF*lm^2*NM*NC)/48 + (23923325371*CF*NC*NL)/76204800 + 
       (69819389*CF*lm*NC*NL)/6350400 - (275*CF*lm^2*NC*NL)/48 + 
       (3501690318417174810727*CF*NC*NH)/3070292646841580160 + 
       (69819389*CF*lm*NC*NH)/6350400 - (275*CF*lm^2*NC*NH)/48 - 
       (118500321961729*CF^2*NC*Pi^2)/2514758400 - (19*CF^2*lm*NC*Pi^2)/24 - 
       (1607860481*CF*NM*NC*Pi^2)/90720 - (19*CF*lm*NM*NC*Pi^2)/216 - 
       (215417*CF*NC*NL*Pi^2)/10080 - (19*CF*lm*NC*NL*Pi^2)/216 - 
       (19*CF*lm*NC*NH*Pi^2)/216 - (329125485407*CF^2*NC*Pi^3)/
        (918330048*Sqrt[3]) - (40076015945*CF*NC*NH*Pi^3)/
        (229582512*Sqrt[3]) - (19931*CF^2*NC*Pi^4)/2160 - 
       (569594236622849*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (187492384800*Sqrt[3]) + (2112215594579*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(191318760*Sqrt[3]) - 
       1233*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (329125485407*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (24800580*Sqrt[3]) - (1145029027*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (329125485407*CF^2*NC*Pi*Log[3]^2)/(1190427840*Sqrt[3]) - 
       (1145029027*CF*NC*NH*Pi*Log[3]^2)/(8503056*Sqrt[3]) - 
       (CF*NC*(26*CF*(20141958666923 + 103541684400*lm) - 
          13*CA*(20266783348223 + 126550947600*lm) + 
          280*(26*(26541330803 + 41087970*lm)*NM + 
            7*(9009*(18317 + 16940*lm)*NL + 2*(18817319 + 76306230*lm)*
               NH)))*Log[x]^2)/908107200 + 
       (CF*NC*(322169793*CA - 28*(25292159*CF + 7870730*NM - 29645*NL))*
         Log[x]^3)/3780 - (415351735121299*CF^2*NC*PolyGamma[2, 1])/
        6887475360 - (1343395*CF*NM*NC*PolyGamma[2, 1])/144 - 
       (527799656831*CF*NC*NH*PolyGamma[2, 1])/573956280 - 
       (111393166239695*CF^2*NC*Zeta[3])/4821232752 + 
       (831245*CF*NM*NC*Zeta[3])/72 - (1111*CF*NC*NL*Zeta[3])/3 - 
       (1832668001771*CF*NC*NH*Zeta[3])/286978140 + 
       CA*CF*NC*(-4727481645107790788862649/78259621403335680000 + 
         (3025*lm^2)/96 + (3594412021441*Pi^2)/152409600 + 
         (329125485407*Pi^3)/(1836660096*Sqrt[3]) + (19627*Pi^4)/4320 + 
         (11*lm*(-23514389 + 558600*Pi^2))/12700800 + 
         (569594236622849*Im[PolyLog[2, (-1)^(1/3)]])/(374984769600*
           Sqrt[3]) + (1233*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (329125485407*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (49601160*Sqrt[3]) + (329125485407*Pi*Log[3]^2)/
          (2380855680*Sqrt[3]) + (415351735121299*PolyGamma[2, 1])/
          13774950720 + (579042300610927*Zeta[3])/48212327520) + 
       CF*Log[x]*((-45259537515407*NM*NC)/432224100 - (194567*lm*NM*NC)/
          2520 - 21*lm^2*NM*NC - (24447589*NC*NL)/50400 - 
         (194567*lm*NC*NL)/2520 - 21*lm^2*NC*NL - 
         (297501636723980609*NC*NH)/213001765376400 - (194567*lm*NC*NH)/
          2520 - 21*lm^2*NC*NH - (1605527*NM*NC*Pi^2)/108 - 
         (6685*NC*NL*Pi^2)/108 + (1145029027*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-29243236029109640873/141160933267200 - (203387*lm)/280 - 
           189*lm^2 - (981276179*Pi^2)/22680 + 
           (329125485407*Im[PolyLog[2, (-1)^(1/3)]])/(74401740*Sqrt[3]) - 
           504*Zeta[3]) + CA*NC*(21077796564051277327/201658476096000 + 
           (2881117*lm)/5040 + (231*lm^2)/2 + (7288709*Pi^2)/336 - 
           (329125485407*Im[PolyLog[2, (-1)^(1/3)]])/(148803480*Sqrt[3]) + 
           252*Zeta[3])), (-259965875605143664198867*CF^2*NC)/
        1467367901312544000 - (8481194*CF^2*lm*NC)/33075 - 254*CF^2*lm^2*NC - 
       (562587070795405631*CF*NM*NC)/1026964461600 - (7081019*CF*lm*NM*NC)/
        297675 - (254*CF*lm^2*NM*NC)/9 + (7574499631*CF*NC*NL)/4465125 - 
       (7081019*CF*lm*NC*NL)/297675 - (254*CF*lm^2*NC*NL)/9 + 
       (640130532397057162253183*CF*NC*NH)/11513597425655925600 - 
       (7081019*CF*lm*NC*NH)/297675 - (254*CF*lm^2*NC*NH)/9 + 
       (1182475526329*CF^2*NC*Pi^2)/15717240 + (32*CF^2*lm*NC*Pi^2)/9 + 
       (1706264359*CF*NM*NC*Pi^2)/8505 + (32*CF*lm*NM*NC*Pi^2)/81 - 
       (310592*CF*NC*NL*Pi^2)/2835 + (32*CF*lm*NC*NL*Pi^2)/81 + 
       (32*CF*lm*NC*NH*Pi^2)/81 - (186486417457*CF^2*NC*Pi^3)/
        (114791256*Sqrt[3]) - (311466184820*CF*NC*NH*Pi^3)/
        (43046721*Sqrt[3]) - (31547*CF^2*NC*Pi^4)/810 + 
       (803607104797703*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (70309644300*Sqrt[3]) + (1654624859212*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) - 
       4184*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (372972834914*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6200145*Sqrt[3]) - (142384541632*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (186486417457*CF^2*NC*Pi*Log[3]^2)/(148803480*Sqrt[3]) - 
       (8899033852*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) - 
       (CF*NC*(CA*(71791043467559 - 1821915295200*lm) + 
          4*(52*CF*(-694821680029 + 14333249700*lm) + 
            35*(637*(-4586495231 + 3714480*lm)*NM + 17657640*(173 + 134*lm)*
               NL + (549722869 + 2366123760*lm)*NH)))*Log[x]^2)/170270100 + 
       (CF*NC*(-389399227*CA + 8*(61854031*CF + 70*(3907177*NM + 6566*NL)))*
         Log[x]^3)/2835 + (50138350136885*CF^2*NC*PolyGamma[2, 1])/
        774840978 + (9177287*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (9167538475*CF*NC*NH*PolyGamma[2, 1])/4782969 + 
       CA*CF*NC*(45438082724441324439623/524059964754480000 + (1397*lm^2)/9 - 
         (3936715743127*Pi^2)/104781600 + (186486417457*Pi^3)/
          (229582512*Sqrt[3]) + (32059*Pi^4)/1620 + 
         lm*(195505909/595350 - (176*Pi^2)/81) - 
         (803607104797703*Im[PolyLog[2, (-1)^(1/3)]])/(140619288600*
           Sqrt[3]) + 2092*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (186486417457*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6200145*Sqrt[3]) + (186486417457*Pi*Log[3]^2)/
          (297606960*Sqrt[3]) - (50138350136885*PolyGamma[2, 1])/1549681956 - 
         (5860046783786*Zeta[3])/1937102445) + 
       (3541891297907*CF^2*NC*Zeta[3])/387420489 + 
       (8274238*CF*NM*NC*Zeta[3])/27 - (19568*CF*NC*NL*Zeta[3])/9 + 
       (64922123482*CF*NC*NH*Zeta[3])/4782969 + 
       CF*Log[x]*((248218049707379*NM*NC)/324168075 - (218588*lm*NM*NC)/
          315 - 112*lm^2*NM*NC - (33352093*NC*NL)/9450 - 
         (218588*lm*NC*NL)/315 - 112*lm^2*NC*NL - 
         (4224475670348455183*NC*NH)/79875662016150 - (218588*lm*NC*NH)/
          315 - 112*lm^2*NC*NH + (15610256*NM*NC*Pi^2)/81 - 
         (29288*NC*NL*Pi^2)/81 + (142384541632*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(17074773967671310211/44112791646000 - (224468*lm)/35 - 
           1008*lm^2 + (17385001*Pi^2)/270 + 
           (372972834914*Im[PolyLog[2, (-1)^(1/3)]])/(18600435*Sqrt[3]) - 
           2688*Zeta[3]) + CA*NC*(-16609536680502075389/88225583292000 + 
           (1449194*lm)/315 + 616*lm^2 - (51789307*Pi^2)/1620 - 
           (186486417457*Im[PolyLog[2, (-1)^(1/3)]])/(18600435*Sqrt[3]) + 
           1344*Zeta[3])), (860744959793190391047383609*CF^2*NC)/
        732683472541740720000 + (1107296837*CF^2*lm*NC)/8467200 - 
       (1207*CF^2*lm^2*NC)/16 + (2221420943106321801899557*CF*NM*NC)/
        5053979665582848000 + (1213754237*CF*lm*NM*NC)/76204800 - 
       (1207*CF*lm^2*NM*NC)/144 + (22254690193*CF*NC*NL)/36578304 + 
       (1213754237*CF*lm*NC*NL)/76204800 - (1207*CF*lm^2*NC*NL)/144 + 
       (320536170222871480976323*CF*NC*NH)/200964609611448883200 + 
       (1213754237*CF*lm*NC*NH)/76204800 - (1207*CF*lm^2*NC*NH)/144 - 
       (2261879019950929*CF^2*NC*Pi^2)/5029516800 - (73*CF^2*lm*NC*Pi^2)/72 - 
       (50491183469*CF*NM*NC*Pi^2)/272160 - (73*CF*lm*NM*NC*Pi^2)/648 - 
       (801761*CF*NC*NL*Pi^2)/22680 - (73*CF*lm*NC*NL*Pi^2)/648 - 
       (73*CF*lm*NC*NH*Pi^2)/648 - (3467902410007*CF^2*NC*Pi^3)/
        (5509980288*Sqrt[3]) - (101468624075*CF*NC*NH*Pi^3)/
        (344373768*Sqrt[3]) - (207931*CF^2*NC*Pi^4)/12960 - 
       (1617683043524539*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (321415516800*Sqrt[3]) + (32251081176671*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1721868840*Sqrt[3]) - 
       (4011*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (495414630001*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (21257640*Sqrt[3]) - (5798207090*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (495414630001*CF^2*NC*Pi*Log[3]^2)/(1020366720*Sqrt[3]) - 
       (2899103545*CF*NC*NH*Pi*Log[3]^2)/(12754584*Sqrt[3]) - 
       (CF*NC*(-11*CA*(335897819509729 + 429963534000*lm) + 
          11*CF*(670940130708593 + 703576692000*lm) + 
          70*((43326687540119 + 12284672400*lm)*NM + 
            11*(22932*(51353 + 48700*lm)*NL + (313666819 + 1116788400*lm)*
               NH)))*Log[x]^2)/1362160800 + 
       (CF*NC*(9095801765*CA - 18603364197*CF - 7129729880*NM + 4772600*NL)*
         Log[x]^3)/11340 - (35392445467767413*CF^2*NC*PolyGamma[2, 1])/
        61987278240 - (107487869*CF*NM*NC*PolyGamma[2, 1])/1080 - 
       (149515284320203*CF*NC*NH*PolyGamma[2, 1])/92980917360 - 
       (34364683716539203*CF^2*NC*Zeta[3])/108477736920 + 
       (63246421*CF*NM*NC*Zeta[3])/540 - (12599*CF*NC*NL*Zeta[3])/18 - 
       (495532289149843*CF*NC*NH*Zeta[3])/46490458680 + 
       CA*CF*NC*(-6900907473620126312089990933/11722935560667851520000 + 
         (13277*lm^2)/288 + (754085422078427*Pi^2)/3353011200 + 
         (3467902410007*Pi^3)/(11019960576*Sqrt[3]) + (41119*Pi^4)/5184 + 
         lm*(-4408875007/152409600 + (803*Pi^2)/1296) + 
         (1617683043524539*Im[PolyLog[2, (-1)^(1/3)]])/(642831033600*
           Sqrt[3]) + (4011*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (495414630001*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (42515280*Sqrt[3]) + (495414630001*Pi*Log[3]^2)/
          (2040733440*Sqrt[3]) + (35392445467767413*PolyGamma[2, 1])/
          123974556480 + (34544562102554041*Zeta[3])/216955473840) + 
       CF*Log[x]*((-7348509095479639639*NM*NC)/7012403798400 - 
         (1969633*lm*NM*NC)/15120 - 35*lm^2*NM*NC - (283441049*NC*NL)/
          302400 - (1969633*lm*NC*NL)/15120 - 35*lm^2*NC*NL - 
         (157474654065184579*NC*NH)/66390160636800 - (1969633*lm*NC*NH)/
          15120 - 35*lm^2*NC*NH - (12776387*NM*NC*Pi^2)/81 - 
         (18935*NC*NL*Pi^2)/162 + (5798207090*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(-137180180918753109806173/65062357424064000 - 
           (2057833*lm)/1680 - 315*lm^2 - (7300315991*Pi^2)/18144 + 
           (495414630001*Im[PolyLog[2, (-1)^(1/3)]])/(63772920*Sqrt[3]) - 
           840*Zeta[3]) + CA*NC*(17175043850308565430719/16265589356016000 + 
           (29074763*lm)/30240 + (385*lm^2)/2 + (7304433223*Pi^2)/36288 - 
           (495414630001*Im[PolyLog[2, (-1)^(1/3)]])/(127545840*Sqrt[3]) + 
           420*Zeta[3])), (-30057979097820180148892783789*CF^2*NC)/
        16119036395918295840000 - (85842101*CF^2*lm*NC)/235200 - 
       (1449*CF^2*lm^2*NC)/4 - (4923153813341505294313*CF*NM*NC)/
        981736531776000 - (71641901*CF*lm*NM*NC)/2116800 - 
       (161*CF*lm^2*NM*NC)/4 + (1424443451639*CF*NC*NL)/444528000 - 
       (71641901*CF*lm*NC*NL)/2116800 - (161*CF*lm^2*NC*NL)/4 + 
       (134355102719833275355268455007*CF*NC*NH)/1357591299653941499347200 - 
       (71641901*CF*lm*NC*NH)/2116800 - (161*CF*lm^2*NC*NH)/4 + 
       (98029010646306811*CF^2*NC*Pi^2)/130767436800 + 
       (9*CF^2*lm*NC*Pi^2)/2 + (2297395417*CF*NM*NC*Pi^2)/1260 + 
       (CF*lm*NM*NC*Pi^2)/2 - (148217*CF*NC*NL*Pi^2)/840 + 
       (CF*lm*NC*NL*Pi^2)/2 + (CF*lm*NC*NH*Pi^2)/2 - 
       (31616555624197*CF^2*NC*Pi^3)/(11019960576*Sqrt[3]) - 
       (559184981425*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (551459*CF^2*NC*Pi^4)/8640 + (89875357899632507*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4499817235200*Sqrt[3]) + 
       (64862643527587*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1506635235*Sqrt[3]) - (26521*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        4 - (31616555624197*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (297606960*Sqrt[3]) - (255627420080*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (31616555624197*CF^2*NC*Pi*Log[3]^2)/(14285134080*Sqrt[3]) - 
       (15976713755*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) + 
       CF*((48479790825852481*CF*NC)/5448643200 - 31932*CF*lm*NC + 
         CA*(-48423833388828421/10897286400 + 19514*lm)*NC + 
         (82672002809*NM*NC)/3780 - 3548*lm*NM*NC - (13610*NC*NL)/3 - 
         3548*lm*NC*NL - (837269231*NC*NH)/918918 - 3548*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-29816792965*CA + 6*(9173692417*CF + 
            10080*(2514400*NM + 887*NL)))*Log[x]^3)/22680 + 
       (12065250433815779*CF^2*NC*PolyGamma[2, 1])/18596183472 + 
       (18879781*CF*NM*NC*PolyGamma[2, 1])/6 - 
       (7876676252731*CF*NC*NH*PolyGamma[2, 1])/2324522934 + 
       CA*CF*NC*(479296460830059466691957415791/515809164669385466880000 + 
         (1771*lm^2)/8 - (2513022649888613*Pi^2)/6706022400 + 
         (31616555624197*Pi^3)/(22039921152*Sqrt[3]) + (558371*Pi^4)/17280 + 
         lm*(1980877711/4233600 - (11*Pi^2)/4) - 
         (89875357899632507*Im[PolyLog[2, (-1)^(1/3)]])/(8999634470400*
           Sqrt[3]) + (26521*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (31616555624197*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (595213920*Sqrt[3]) + (31616555624197*Pi*Log[3]^2)/
          (28570268160*Sqrt[3]) - (12065250433815779*PolyGamma[2, 1])/
          37192366944 - (11278941563206483*Zeta[3])/2603465686080) + 
       (18274159766505571*CF^2*NC*Zeta[3])/1301732843040 + 
       2963909*CF*NM*NC*Zeta[3] - 3914*CF*NC*NL*Zeta[3] + 
       (28367285334197*CF*NC*NH*Zeta[3])/1162261467 + 
       CF*Log[x]*((10511885125572463*NM*NC)/1362160800 - 
         (157597*lm*NM*NC)/140 - 180*lm^2*NM*NC - (841153127*NC*NL)/
          132300 - (157597*lm*NC*NL)/140 - 180*lm^2*NC*NL - 
         (17527273000254630966553*NC*NH)/184672530581338800 - 
         (157597*lm*NC*NH)/140 - 180*lm^2*NC*NH + (5027858*NM*NC*Pi^2)/3 - 
         (1954*NC*NL*Pi^2)/3 + (255627420080*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(797723043873997065885763/204481694761344000 - 
           (1456173*lm)/140 - 1620*lm^2 + (39279920201*Pi^2)/60480 + 
           (31616555624197*Im[PolyLog[2, (-1)^(1/3)]])/(892820880*Sqrt[3]) - 
           4320*Zeta[3]) + CA*NC*(-1111699200396884710754069/
            572548745331763200 + (2086367*lm)/280 + 990*lm^2 - 
           (117693455731*Pi^2)/362880 - (31616555624197*
             Im[PolyLog[2, (-1)^(1/3)]])/(1785641760*Sqrt[3]) + 
           2160*Zeta[3])), (3747617594852288955444204372029*CF^2*NC)/
        331591605858890657280000 + (1978257073*CF^2*lm*NC)/10886400 - 
       (1691*CF^2*lm^2*NC)/16 + (4689625331517233182128643*CF*NM*NC)/
        1010795933116569600 + (2170016473*CF*lm*NM*NC)/97977600 - 
       (1691*CF*lm^2*NM*NC)/144 + (105101238545003*CF*NC*NL)/96018048000 + 
       (2170016473*CF*lm*NC*NL)/97977600 - (1691*CF*lm^2*NC*NL)/144 + 
       (54306655654362501490108859231*CF*NC*NH)/26658156429568305805363200 + 
       (2170016473*CF*lm*NC*NH)/97977600 - (1691*CF*lm^2*NC*NH)/144 - 
       (1687164298236170177*CF^2*NC*Pi^2)/392302310400 - 
       (91*CF^2*lm*NC*Pi^2)/72 - (1555597954277*CF*NM*NC*Pi^2)/816480 - 
       (91*CF*lm*NM*NC*Pi^2)/648 - (1611271*CF*NC*NL*Pi^2)/29160 - 
       (91*CF*lm*NC*NL*Pi^2)/648 - (91*CF*lm*NC*NH*Pi^2)/648 - 
       (102473955018695*CF^2*NC*Pi^3)/(99179645184*Sqrt[3]) - 
       (4326022284115*CF*NC*NH*Pi^3)/(9298091736*Sqrt[3]) - 
       (674731*CF^2*NC*Pi^4)/25920 - (64084591473062911*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8099671023360*Sqrt[3]) + 
       (1401180500579783*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (46490458680*Sqrt[3]) - (37105*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        12 - (20494791003739*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (535692528*Sqrt[3]) - (247201273378*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (20494791003739*CF^2*NC*Pi*Log[3]^2)/(25713241344*Sqrt[3]) - 
       (123600636689*CF*NC*NH*Pi*Log[3]^2)/(344373768*Sqrt[3]) - 
       (CF*NC*(-51*CA*(281468534113606531 + 67213857110400*lm) + 
          2*(17*CF*(844203700324279369 + 164979467452800*lm) + 
            840*(51*(148304124699527 + 7274226960*lm)*NM + 
              11*(167076*(208667 + 201860*lm)*NL + (10482214517 + 
                  33725961360*lm)*NH))))*Log[x]^2)/555761606400 + 
       (CF*NC*(519039019151*CA - 48*(21727946033*CF + 9270216165*NM - 
            1059765*NL))*Log[x]^3)/68040 - (1000231792005807373*CF^2*NC*
         PolyGamma[2, 1])/185961834720 - (3399911831*CF*NM*NC*
         PolyGamma[2, 1])/3240 - (2225142873245987*CF*NC*NH*PolyGamma[2, 1])/
        836828256240 - (4020588728670379781*CF^2*NC*Zeta[3])/1301732843040 + 
       (1902056299*CF*NM*NC*Zeta[3])/1620 - (66407*CF*NC*NL*Zeta[3])/54 - 
       (7087843392519707*CF*NC*NH*Zeta[3])/418414128120 + 
       CA*CF*NC*(-23431045969790461419730981361/4144895073236133216000 + 
         (18601*lm^2)/288 + (5191415111244389*Pi^2)/2414168064 + 
         (102473955018695*Pi^3)/(198359290368*Sqrt[3]) + (74323*Pi^4)/5760 + 
         lm*(-7762391603/195955200 + (1001*Pi^2)/1296) + 
         (64084591473062911*Im[PolyLog[2, (-1)^(1/3)]])/(16199342046720*
           Sqrt[3]) + (37105*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (20494791003739*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1071385056*Sqrt[3]) + (20494791003739*Pi*Log[3]^2)/
          (51426482688*Sqrt[3]) + (1000231792005807373*PolyGamma[2, 1])/
          371923669440 + (804853125472998865*Zeta[3])/520693137216) + 
       CF*Log[x]*((-24274746779382162967*NM*NC)/2337467932800 - 
         (4018477*lm*NM*NC)/19440 - 55*lm^2*NM*NC - (31955144213*NC*NL)/
          19051200 - (4018477*lm*NC*NL)/19440 - 55*lm^2*NC*NL - 
         (13659662096063756478281*NC*NH)/3626296964142652800 - 
         (4018477*lm*NC*NH)/19440 - 55*lm^2*NC*NH - (4907795*NM*NC*Pi^2)/
          3 - (11083*NC*NL*Pi^2)/54 + (247201273378*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(-265475303836574410924114801/12882346769964672000 - 
           (4196677*lm)/2160 - 495*lm^2 - (2077459352861*Pi^2)/544320 + 
           (20494791003739*Im[PolyLog[2, (-1)^(1/3)]])/(1607077584*Sqrt[3]) - 
           1320*Zeta[3]) + CA*NC*(265548817527109927959320203/
            25764693539929344000 + (59172047*lm)/38880 + (605*lm^2)/2 + 
           (2077677717077*Pi^2)/1088640 - (20494791003739*
             Im[PolyLog[2, (-1)^(1/3)]])/(3214155168*Sqrt[3]) + 
           660*Zeta[3])), (-2410328302011265993955322896201*CF^2*NC)/
        127899619402714967808000 - (95265361*CF^2*lm*NC)/190512 - 
       (995*CF^2*lm^2*NC)/2 - (527313386177901257472133*CF*NM*NC)/
        11486317421779200 - (79468741*CF*lm*NM*NC)/1714608 - 
       (995*CF*lm^2*NM*NC)/18 + (45098120743129*CF*NC*NL)/8001504000 - 
       (79468741*CF*lm*NC*NL)/1714608 - (995*CF*lm^2*NC*NL)/18 + 
       (949840709166461798259415937497459*CF*NC*NH)/
        5714009217200281547468318400 - (79468741*CF*lm*NC*NH)/1714608 - 
       (995*CF*lm^2*NC*NH)/18 + (14570344747768213*CF^2*NC*Pi^2)/
        1961511552 + (50*CF^2*lm*NC*Pi^2)/9 + (428442543064*CF*NM*NC*Pi^2)/
        25515 + (50*CF*lm*NM*NC*Pi^2)/81 - (5511455*CF*NC*NL*Pi^2)/20412 + 
       (50*CF*lm*NC*NL*Pi^2)/81 + (50*CF*lm*NC*NH*Pi^2)/81 - 
       (265734523678325*CF^2*NC*Pi^3)/(55788550416*Sqrt[3]) - 
       (102150127306745*CF*NC*NH*Pi^3)/(4649045868*Sqrt[3]) - 
       (64175*CF^2*NC*Pi^4)/648 + (180970521300949147*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5467277940768*Sqrt[3]) + 
       (3067332783798802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (40679151345*Sqrt[3]) - (30050*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        3 - (53146904735665*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (301327047*Sqrt[3]) - (11674300263628*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (53146904735665*CF^2*NC*Pi*Log[3]^2)/(14463698256*Sqrt[3]) - 
       (2918575065907*CF*NC*NH*Pi*Log[3]^2)/(172186884*Sqrt[3]) + 
       CF*((1817877611097761*CF*NC)/20432412 - 54596*CF*lm*NC + 
         CA*(-24233505759006667/544864320 + (300278*lm)/9)*NC + 
         (1485158908276*NM*NC)/7371 - (54596*lm*NM*NC)/9 - 
         (69280*NC*NL)/9 - (54596*lm*NC*NL)/9 - (120561174257*NC*NH)/
          71424990 - (54596*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-88288405205*CA + 48*(3624820603*CF + 8604319836*NM + 
            573258*NL))*Log[x]^3)/6804 + (1590974456927775289*CF^2*NC*
         PolyGamma[2, 1])/251048476872 + (4705373533*CF*NM*NC*
         PolyGamma[2, 1])/162 - (59079955204948*CF*NC*NH*PolyGamma[2, 1])/
        10460353203 - (218090999921032895*CF^2*NC*Zeta[3])/878669669052 + 
       (2250235651*CF*NM*NC*Zeta[3])/81 - (178838*CF*NC*NL*Zeta[3])/27 + 
       (430931148649804*CF*NC*NH*Zeta[3])/10460353203 + 
       CA*CF*NC*(236084362524388277019559784405569/
          25068325402932133690368000 + (10945*lm^2)/36 - 
         (3642458491778137*Pi^2)/980755776 + (265734523678325*Pi^3)/
          (111577100832*Sqrt[3]) + (21605*Pi^4)/432 + 
         lm*(2201072231/3429216 - (275*Pi^2)/81) - 
         (180970521300949147*Im[PolyLog[2, (-1)^(1/3)]])/
          (10934555881536*Sqrt[3]) + (15025*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (53146904735665*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (602654094*Sqrt[3]) + (53146904735665*Pi*Log[3]^2)/
          (28927396512*Sqrt[3]) - (1590974456927775289*PolyGamma[2, 1])/
          502096953744 + (112938848652849649*Zeta[3])/878669669052) + 
       CF*Log[x]*((3961020459492284263*NM*NC)/53124271200 - 
         (5894495*lm*NM*NC)/3402 - 275*lm^2*NM*NC - (34183153601*NC*NL)/
          3175200 - (5894495*lm*NC*NL)/3402 - 275*lm^2*NC*NL - 
         (52514973411664910478677057*NC*NH)/327273301013874415200 - 
         (5894495*lm*NC*NH)/3402 - 275*lm^2*NC*NH + (45524333*NM*NC*Pi^2)/
          3 - (29773*NC*NL*Pi^2)/27 + (11674300263628*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(110432942982260519449301843/2898528023242051200 - 
           (3025210*lm)/189 - 2475*lm^2 + (44052272791*Pi^2)/6804 + 
           (53146904735665*Im[PolyLog[2, (-1)^(1/3)]])/(903981141*Sqrt[3]) - 
           6600*Zeta[3]) + CA*NC*(-220699829324138257035122491/
            11594112092968204800 + (77937145*lm)/6804 + (3025*lm^2)/2 - 
           (88086088493*Pi^2)/27216 - (53146904735665*
             Im[PolyLog[2, (-1)^(1/3)]])/(1807962282*Sqrt[3]) + 
           3300*Zeta[3])), (1214866386413090517235610397245476687*CF^2*NC)/
        11196425700418688438252544000 + (248323153*CF^2*lm*NC)/1016064 - 
       (2289*CF^2*lm^2*NC)/16 + (79157703229197847045714337339*CF*NM*NC)/
        1655346806467235481600 + (272549929*CF*lm*NM*NC)/9144576 - 
       (763*CF*lm^2*NM*NC)/48 + (19786289662637*CF*NC*NL)/10668672000 + 
       (272549929*CF*lm*NC*NL)/9144576 - (763*CF*lm^2*NC*NL)/48 + 
       (126688494550823078094393885820567*CF*NC*NH)/
        53778910279532061623231232000 + (272549929*CF*lm*NC*NH)/9144576 - 
       (763*CF*lm^2*NC*NH)/48 - (5387619391308780523*CF^2*NC*Pi^2)/
        130767436800 - (37*CF^2*lm*NC*Pi^2)/24 - 
       (1048123276099*CF*NM*NC*Pi^2)/54432 - (37*CF*lm*NM*NC*Pi^2)/216 - 
       (561733*CF*NC*NL*Pi^2)/6804 - (37*CF*lm*NC*NL*Pi^2)/216 - 
       (37*CF*lm*NC*NH*Pi^2)/216 - (1435607162516111*CF^2*NC*Pi^3)/
        (892616806656*Sqrt[3]) - (6475251148415*CF*NC*NH*Pi^3)/
        (9298091736*Sqrt[3]) - (69185*CF^2*NC*Pi^4)/1728 - 
       (13037255422590720301*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1093455588153600*Sqrt[3]) + (3022446656896925*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(65086642152*Sqrt[3]) - 
       (18271*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (1435607162516111*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (24106163760*Sqrt[3]) - (370014351338*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (1435607162516111*CF^2*NC*Pi*Log[3]^2)/(1157095860480*Sqrt[3]) - 
       (185007175669*CF*NC*NH*Pi*Log[3]^2)/(344373768*Sqrt[3]) + 
       CF*((-4163694643051099811*CF*NC)/8420630400 - 16887*CF*lm*NC + 
         CA*(1387956511028929601/5613753600 + (61919*lm)/6)*NC - 
         (404444403798143*NM*NC)/1750320 - (5629*lm*NM*NC)/3 - 
         (38171*NC*NL)/20 - (5629*lm*NC*NL)/3 - (202513085*NC*NH)/320112 - 
         (5629*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(165457188518*CA - 331212011671*CF - 
          504*(299716481*NM - 5629*NL))*Log[x]^3)/2268 - 
       (50754522693684575381*CF^2*NC*PolyGamma[2, 1])/1004193907488 - 
       (7815909841*CF*NM*NC*PolyGamma[2, 1])/720 - 
       (2636147296123951*CF*NC*NH*PolyGamma[2, 1])/627621192180 - 
       (986413265242398099791*CF^2*NC*Zeta[3])/35146786762080 + 
       (4174330019*CF*NM*NC*Zeta[3])/360 - (36707*CF*NC*NL*Zeta[3])/18 - 
       (8114896757571241*CF*NC*NH*Zeta[3])/313810596090 + 
       CA*CF*NC*(-173562373682421499231082032433668759/
          3198978771548196696643584000 + (8393*lm^2)/96 + 
         (1077528392350695991*Pi^2)/52306974720 + (1435607162516111*Pi^3)/
          (1785233613312*Sqrt[3]) + (38173*Pi^4)/1920 + 
         lm*(-963000035/18289152 + (407*Pi^2)/432) + 
         (13037255422590720301*Im[PolyLog[2, (-1)^(1/3)]])/
          (2186911176307200*Sqrt[3]) + (18271*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          8 + (1435607162516111*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (48212327520*Sqrt[3]) + (1435607162516111*Pi*Log[3]^2)/
          (2314191720960*Sqrt[3]) + (50754522693684575381*PolyGamma[2, 1])/
          2008387814976 + (986574148617415246559*Zeta[3])/70293573524160) + 
       CF*Log[x]*((-2554981101043638328067*NM*NC)/25019564169600 - 
         (14177197*lm*NM*NC)/45360 - (165*lm^2*NM*NC)/2 - 
         (298978079*NC*NL)/105840 - (14177197*lm*NC*NL)/45360 - 
         (165*lm^2*NC*NL)/2 - (436604017382781056361239*NC*NH)/
          77005482591499862400 - (14177197*lm*NC*NH)/45360 - 
         (165*lm^2*NC*NH)/2 - 16652531*NM*NC*Pi^2 - (3062*NC*NL*Pi^2)/9 + 
         (370014351338*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(-604815882217870077898071200897/
            3046089449879828352000 - (14800897*lm)/5040 - (1485*lm^2)/2 - 
           (6619032460363*Pi^2)/181440 + (1435607162516111*
             Im[PolyLog[2, (-1)^(1/3)]])/(72318491280*Sqrt[3]) - 
           1980*Zeta[3]) + CA*NC*(604843741739633355606398240399/
            6092178899759656704000 + (208339967*lm)/90720 + (1815*lm^2)/4 + 
           (6619153721699*Pi^2)/362880 - (1435607162516111*
             Im[PolyLog[2, (-1)^(1/3)]])/(144636982560*Sqrt[3]) + 
           990*Zeta[3])), (-1557889398502402581243091520503875092387*CF^2*NC)/
        8313346082560876165402513920000 - (2531853161*CF^2*lm*NC)/3810240 - 
       (2651*CF^2*lm^2*NC)/4 - (1317635688968509462679408009081*CF*NM*NC)/
        3103775262126066528000 - (2110980401*CF*lm*NM*NC)/34292160 - 
       (2651*CF*lm^2*NM*NC)/36 + (22477244804629*CF*NC*NL)/2400451200 - 
       (2110980401*CF*lm*NC*NL)/34292160 - (2651*CF*lm^2*NC*NL)/36 + 
       (951348621735075420839322005831419993*CF*NC*NH)/
        3572759447386281304417032768000 - (2110980401*CF*lm*NC*NH)/
        34292160 - (2651*CF*lm^2*NC*NH)/36 + 
       (9547156659650553467*CF^2*NC*Pi^2)/130767436800 + 
       (121*CF^2*lm*NC*Pi^2)/18 + (15937681936147*CF*NM*NC*Pi^2)/102060 + 
       (121*CF*lm*NM*NC*Pi^2)/162 - (80936339*CF*NC*NL*Pi^2)/204120 + 
       (121*CF*lm*NC*NL*Pi^2)/162 + (121*CF*lm*NC*NH*Pi^2)/162 - 
       (181374534625754119*CF^2*NC*Pi^3)/(24100653779712*Sqrt[3]) - 
       (4444201559974855*CF*NC*NH*Pi^3)/(125524238436*Sqrt[3]) - 
       (1270907*CF^2*NC*Pi^4)/8640 + (1549458210418732070851*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(29523300880147200*Sqrt[3]) + 
       (137709851700285413*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1098337086315*Sqrt[3]) - (174691*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/12 - (181374534625754119*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(650866421520*Sqrt[3]) - 
       (507908749711412*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) - (181374534625754119*CF^2*NC*Pi*Log[3]^2)/
        (31241588232960*Sqrt[3]) - (126977187427853*CF*NC*NH*Pi*Log[3]^2)/
        (4649045868*Sqrt[3]) - 
       (CF*NC*(CA*(243369199918801495687 - 30096837535564800*lm) + 
          6*(19*CF*(-4269778308470379823 + 432012022041600*lm) + 
            1120*(84*(-1844953984422061 + 9694147320*lm)*NM + 
              808647840*(1270 + 1007*lm)*NL + (241995115169 + 814308374880*
                 lm)*NH)))*Log[x]^2)/555761606400 + 
       (CF*NC*(-8698231611295*CA + 17350756032718*CF + 
          20160*(1891993397*NM + 22154*NL))*Log[x]^3)/68040 + 
       (277165267930677835867*CF^2*NC*PolyGamma[2, 1])/4518872583696 + 
       (21693665522*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (281650865599397*CF*NC*NH*PolyGamma[2, 1])/31381059609 - 
       (1608108186640864446871*CF^2*NC*Zeta[3])/316321080858720 + 
       (20688701368*CF*NM*NC*Zeta[3])/81 - (287870*CF*NC*NL*Zeta[3])/27 + 
       (2074320494873402*CF*NC*NH*Zeta[3])/31381059609 + 
       CA*CF*NC*(311551541822759356052482031791552372243/
          3325338433024350466161005568000 + (29161*lm^2)/72 - 
         (867918614426798177*Pi^2)/23775897600 + (181374534625754119*Pi^3)/
          (48201307559424*Sqrt[3]) + (3843697*Pi^4)/51840 + 
         lm*(58574096251/68584320 - (1331*Pi^2)/324) - 
         (1549458210418732070851*Im[PolyLog[2, (-1)^(1/3)]])/
          (59046601760294400*Sqrt[3]) + (174691*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          24 + (181374534625754119*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1301732843040*Sqrt[3]) + (181374534625754119*Pi*Log[3]^2)/
          (62483176465920*Sqrt[3]) - (277165267930677835867*PolyGamma[2, 1])/
          9037745167392 + (1612533223914848917567*Zeta[3])/632642161717440) + 
       CF*Log[x]*((119829762389971117764559*NM*NC)/168882058144800 - 
         (86979299*lm*NM*NC)/34020 - (1210*lm^2*NM*NC)/3 - 
         (10322103599*NC*NL)/595350 - (86979299*lm*NC*NL)/34020 - 
         (1210*lm^2*NC*NL)/3 - (330536839881678576904743773*NC*NH)/
          1278949610541061859400 - (86979299*lm*NC*NH)/34020 - 
         (1210*lm^2*NC*NH)/3 + (420441695*NM*NC*Pi^2)/3 - 
         (47938*NC*NL*Pi^2)/27 + (507908749711412*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CF*NC*(9530958932961289208881347158009/25848244760408829158400 - 
           (89266199*lm)/3780 - 3630*lm^2 + (6956189693765*Pi^2)/108864 + 
           (181374534625754119*Im[PolyLog[2, (-1)^(1/3)]])/
            (1952599264560*Sqrt[3]) - 9680*Zeta[3]) + 
         CA*NC*(-333543783166378455630811207972339/
            1809377133228618041088000 + (1148871889*lm)/68040 + 
           (6655*lm^2)/3 - (34779765693721*Pi^2)/1088640 - 
           (181374534625754119*Im[PolyLog[2, (-1)^(1/3)]])/
            (3905198529120*Sqrt[3]) + 4840*Zeta[3])), 
      (9139005227877987930659263314867665655896447*CF^2*NC)/
        8772498581582315325922437381120000 + (16862002783*CF^2*lm*NC)/
        52690176 - (3013*CF^2*lm^2*NC)/16 + 
       (11787473611463848283398965437441623*CF*NM*NC)/
        24330050883340217503488000 + (18515705911*CF*lm*NM*NC)/474211584 - 
       (3013*CF*lm^2*NM*NC)/144 + (11584826465194049*CF*NC*NL)/
        3872727936000 + (18515705911*CF*lm*NC*NL)/474211584 - 
       (3013*CF*lm^2*NC*NL)/144 + (5833534110555020793739514184153834349*CF*
         NC*NH)/2443767462012216412221250413312000 + 
       (18515705911*CF*lm*NC*NH)/474211584 - (3013*CF*lm^2*NC*NH)/144 - 
       (851470288398681234391*CF^2*NC*Pi^2)/2157662707200 - 
       (133*CF^2*lm*NC*Pi^2)/72 - (1725962164172941*CF*NM*NC*Pi^2)/8981280 - 
       (133*CF*lm*NM*NC*Pi^2)/648 - (9534311*CF*NC*NL*Pi^2)/80190 - 
       (133*CF*lm*NC*NL*Pi^2)/648 - (133*CF*lm*NC*NH*Pi^2)/648 - 
       (317868433995424717*CF^2*NC*Pi^3)/(132553595788416*Sqrt[3]) - 
       (2253593256569795*CF*NC*NH*Pi^3)/(2259436291848*Sqrt[3]) - 
       (764791*CF^2*NC*Pi^4)/12960 - (30996829418187498469477*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1786159703248905600*Sqrt[3]) + 
       (1091350512352914701*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15816054042936*Sqrt[3]) - (13031*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 - (317868433995424717*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3579765318360*Sqrt[3]) - 
       (128776757518274*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (317868433995424717*CF^2*NC*Pi*Log[3]^2)/
        (171828735281280*Sqrt[3]) - (64388378759137*CF*NC*NH*Pi*Log[3]^2)/
        (83682825624*Sqrt[3]) - 
       (CF*NC*(-13*CA*(10578180358972939616927 + 73486626990638400*lm) + 
          2*(13*CF*(10578106121649012512449 + 60125422083249600*lm) + 
            4620*(15*(966309468220960921 + 1253215467504*lm)*NM + 
              384107724*(49119 + 48940*lm)*NL + (6777441342877 + 
                18798232012560*lm)*NH)))*Log[x]^2)/58077087868800 + 
       (CF*NC*(522925392775125*CA - 176*(5943302264894*CF + 
            3465*(820313827*NM - 2447*NL)))*Log[x]^3)/748440 - 
       (21421557223254223028507*CF^2*NC*PolyGamma[2, 1])/45188725836960 - 
       (715746209809*CF*NM*NC*PolyGamma[2, 1])/6480 - 
       (108220216492773823*CF*NC*NH*PolyGamma[2, 1])/16945772188860 - 
       (27107787874819997733187*CF^2*NC*Zeta[3])/108735371545185 + 
       (367088603531*CF*NM*NC*Zeta[3])/3240 - (174239*CF*NC*NL*Zeta[3])/
        54 - (323375351194595713*CF*NC*NH*Zeta[3])/8472886094430 + 
       CA*CF*NC*(-100529962375306385878273746916249783901283409/
          192994968794810937170293622384640000 + (33143*lm^2)/288 + 
         (851470821976950540319*Pi^2)/4315325414400 + 
         (317868433995424717*Pi^3)/(265107191576832*Sqrt[3]) + 
         (152107*Pi^4)/5184 + (lm*(-5887427479 + 97330464*Pi^2))/86220288 + 
         (30996829418187498469477*Im[PolyLog[2, (-1)^(1/3)]])/
          (3572319406497811200*Sqrt[3]) + (13031*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/4 + (317868433995424717*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (7159530636720*Sqrt[3]) + (317868433995424717*Pi*Log[3]^2)/
          (343657470562560*Sqrt[3]) + (21421557223254223028507*
           PolyGamma[2, 1])/90377451673920 + (21686849369309849241695*
           Zeta[3])/173976594472296) + CF*Log[x]*
        ((-48638483037732081988322779*NM*NC)/48773138392218240 - 
         (97182929*lm*NM*NC)/213840 - (715*lm^2*NM*NC)/6 - 
         (158177678599*NC*NL)/34927200 - (97182929*lm*NC*NL)/213840 - 
         (715*lm^2*NC*NL)/6 - (28575977808609369198109827749*NC*NH)/
          3499206134440345247318400 - (97182929*lm*NC*NH)/213840 - 
         (715*lm^2*NC*NH)/6 - (1503931693*NM*NC*Pi^2)/9 - 
         (14531*NC*NL*Pi^2)/27 + (128776757518274*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-18758087711688366429765028780331809/
            9869555763806101979616000 - (101430029*lm)/23760 - 
           (2145*lm^2)/2 - (69724717069505*Pi^2)/199584 + 
           (317868433995424717*Im[PolyLog[2, (-1)^(1/3)]])/
            (10739295955080*Sqrt[3]) - 2860*Zeta[3]) + 
         CA*NC*(37516453013648631980577725936094449/
            39478223055224407918464000 + (129615329*lm)/38880 + 
           (7865*lm^2)/12 + (348624644340229*Pi^2)/1995840 - 
           (317868433995424717*Im[PolyLog[2, (-1)^(1/3)]])/
            (21478591910160*Sqrt[3]) + 1430*Zeta[3])), 
      (-19074568495182811150357669807539551637439687*CF^2*NC)/
        10339016185436300205551444056320000 - (551406871*CF^2*lm*NC)/640332 - 
       861*CF^2*lm^2*NC - (445750485795221915752724252670059*CF*NM*NC)/
        112639124459908414368000 - (459519229*CF*lm*NM*NC)/5762988 - 
       (287*CF*lm^2*NM*NC)/3 + (47917816751237*CF*NC*NL)/3227273280 - 
       (459519229*CF*lm*NC*NL)/5762988 - (287*CF*lm^2*NC*NL)/3 + 
       (60260527442592072290896643270421338717*CF*NC*NH)/
        146967647545882780494958053792000 - (459519229*CF*lm*NC*NH)/
        5762988 - (287*CF*lm^2*NC*NH)/3 + (192146046630852297391*CF^2*NC*
         Pi^2)/269707838400 + 8*CF^2*lm*NC*Pi^2 + 
       (91093874214439*CF*NM*NC*Pi^2)/62370 + (8*CF*lm*NM*NC*Pi^2)/9 - 
       (17553743*CF*NC*NL*Pi^2)/31185 + (8*CF*lm*NC*NL*Pi^2)/9 + 
       (8*CF*lm*NC*NH*Pi^2)/9 - (51589893465041399*CF^2*NC*Pi^3)/
        (4518872583696*Sqrt[3]) - (30953273880532955*CF*NC*NH*Pi^3)/
        (564859072962*Sqrt[3]) - (341501*CF^2*NC*Pi^4)/1620 + 
       (4880982614069426814601*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (60891808065303600*Sqrt[3]) + (1973746884436648094*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9885033776835*Sqrt[3]) - 
       (61468*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (51589893465041399*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (122037454035*Sqrt[3]) - (7075034029836104*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3486784401*Sqrt[3]) - 
       (51589893465041399*CF^2*NC*Pi*Log[3]^2)/(5857797793680*Sqrt[3]) - 
       (884379253729513*CF*NC*NH*Pi*Log[3]^2)/(20920706406*Sqrt[3]) + 
       CF*((2386928096767455955831*CF*NC)/279216768600 - 137808*CF*lm*NC + 
         CA*(-30998898511182928901/7252383600 + 84216*lm)*NC + 
         (1530009756288469751*NM*NC)/87297210 - 15312*lm*NM*NC - 
         (57640*NC*NL)/3 - 15312*lm*NC*NL - (15396247273*NC*NH)/3202290 - 
         15312*lm*NC*NH)*Log[x]^2 + (CF*NC*(-117050412351571*CA + 
          233995081152956*CF + 5488560*(89096551*NM + 174*NL))*Log[x]^3)/
        93555 + (2000928582942569536213*CF^2*NC*PolyGamma[2, 1])/
        3389154437772 + (44422481149*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (23232210070612813*CF*NC*NH*PolyGamma[2, 1])/1694577218886 - 
       (22907182515529802401963*CF^2*NC*Zeta[3])/326206114635555 + 
       (20901910177*CF*NM*NC*Zeta[3])/9 - (49400*CF*NC*NL*Zeta[3])/3 + 
       (86206599306767531*CF*NC*NH*Zeta[3])/847288609443 + 
       CA*CF*NC*(16690031860592815275217145144733492384826523/
          18093278324513525359715027098560000 + (3157*lm^2)/6 - 
         (192145890396191888641*Pi^2)/539415676800 + (51589893465041399*Pi^3)/
          (9037745167392*Sqrt[3]) + (68761*Pi^4)/648 + 
         lm*(1161206677/1047816 - (44*Pi^2)/9) - 
         (4880982614069426814601*Im[PolyLog[2, (-1)^(1/3)]])/
          (121783616130607200*Sqrt[3]) + (30734*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 + (51589893465041399*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (244074908070*Sqrt[3]) + (51589893465041399*Pi*Log[3]^2)/
          (11715595587360*Sqrt[3]) - (2000928582942569536213*PolyGamma[2, 1])/
          6778308875544 + (11457062466565740734543*Zeta[3])/
          326206114635555) + CF*Log[x]*((8523593323295826415809343*NM*NC)/
          1270133812297350 - (37881796*lm*NM*NC)/10395 - 572*lm^2*NM*NC - 
         (233921193281*NC*NL)/8731800 - (37881796*lm*NC*NL)/10395 - 
         572*lm^2*NC*NL - (2213276643836528787290160109*NC*NH)/
          5535526450714541375094 - (37881796*lm*NC*NH)/10395 - 
         572*lm^2*NC*NH + 1306749026*NM*NC*Pi^2 - (8228*NC*NL*Pi^2)/3 + 
         (7075034029836104*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (10460353203*Sqrt[3]) + CF*NC*(9197685602854024868269534639593851/
            2590758387999101769649200 - (38872786*lm)/1155 - 5148*lm^2 + 
           (46817596893325*Pi^2)/74844 + (51589893465041399*
             Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) - 
           13728*Zeta[3]) + CA*NC*(-45987584709948238881526578222752773/
            25907583879991017696492000 + (22724678*lm)/945 + 3146*lm^2 - 
           (234086733306407*Pi^2)/748440 - (51589893465041399*
             Im[PolyLog[2, (-1)^(1/3)]])/(732224724210*Sqrt[3]) + 
           6864*Zeta[3])), (1446470449072548897956465057207548815530614349*
         CF^2*NC)/144746226596108202877720216788480000 + 
       (755738431673*CF^2*lm*NC)/1844156160 - (3875*CF^2*lm^2*NC)/16 + 
       (48535026683624368661040944435614469*CF*NM*NC)/
        10018256246081266030848000 + (830177026673*CF*lm*NM*NC)/
        16597405440 - (3875*CF*lm^2*NM*NC)/144 + 
       (242116819883689489*CF*NC*NL)/52281827136000 + 
       (830177026673*CF*lm*NC*NL)/16597405440 - (3875*CF*lm^2*NC*NL)/144 + 
       (11334376418176289391107976263746994697971*CF*NC*NH)/
        5946663742060527417499190755753420800 + (830177026673*CF*lm*NC*NH)/
        16597405440 - (3875*CF*lm^2*NC*NH)/144 - 
       (4072010602736564647693*CF^2*NC*Pi^2)/1078831353600 - 
       (157*CF^2*lm*NC*Pi^2)/72 - (17053176137629781*CF*NM*NC*Pi^2)/
        8981280 - (157*CF*lm*NM*NC*Pi^2)/648 - (745751563*CF*NC*NL*Pi^2)/
        4490640 - (157*CF*lm*NC*NL*Pi^2)/648 - (157*CF*lm*NC*NH*Pi^2)/648 - 
       (686080412285781143*CF^2*NC*Pi^3)/(198830393682624*Sqrt[3]) - 
       (691034001996835*CF*NC*NH*Pi^3)/(502096953744*Sqrt[3]) - 
       (544333*CF^2*NC*Pi^4)/6480 - (32868847117328048898649*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1339619777436679200*Sqrt[3]) + 
       (7863211836636984617*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (79080270214680*Sqrt[3]) - (27079*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (686080412285781143*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5369647977540*Sqrt[3]) - 
       (19743828628481*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) - (686080412285781143*CF^2*NC*Pi*Log[3]^2)/
        (257743102921920*Sqrt[3]) - (19743828628481*CF*NC*NH*Pi*Log[3]^2)/
        (18596183472*Sqrt[3]) - 
       (CF*NC*(-6279*CA*(2408910949675410358411 + 2679341458978800*lm) + 
          20*(299*CF*(5058707292464579674693 + 4603595779518120*lm) + 
            693*(391*(2808090041363906491 + 564437513640*lm)*NM + 
              490804314*(446249 + 449660*lm)*NL + (84172949611511 + 
                220695067833240*lm)*NH)))*Log[x]^2)/667886510491200 + 
       (CF*NC*(5004576887399011*CA - 168*(59579975700888*CF + 
            605*(48842131690*NM - 22483*NL)))*Log[x]^3)/748440 - 
       (120350651241641725186099*CF^2*NC*PolyGamma[2, 1])/27113235502176 - 
       (898282724119*CF*NM*NC*PolyGamma[2, 1])/810 - 
       (5735303267051302121*CF*NC*NH*PolyGamma[2, 1])/610047798798960 - 
       (11434403688536310597502573*CF^2*NC*Zeta[3])/5219297834168880 + 
       (444879475706*CF*NM*NC*Zeta[3])/405 - (132587*CF*NC*NL*Zeta[3])/27 - 
       (16696209057248411201*CF*NC*NH*Zeta[3])/305023899399480 + 
       CA*CF*NC*(-2892944850354013994077455539317033908982572193/
          578984906384432811510880867153920000 + (42625*lm^2)/288 + 
         (4072010973832701694867*Pi^2)/2157662707200 + 
         (686080412285781143*Pi^3)/(397660787365248*Sqrt[3]) + 
         (180607*Pi^4)/4320 + lm*(-261736846673/3017710080 + 
           (1727*Pi^2)/1296) + (32868847117328048898649*
           Im[PolyLog[2, (-1)^(1/3)]])/(2679239554873358400*Sqrt[3]) + 
         (27079*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (686080412285781143*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (10739295955080*Sqrt[3]) + (686080412285781143*Pi*Log[3]^2)/
          (515486205843840*Sqrt[3]) + (120350651241641725186099*
           PolyGamma[2, 1])/54226471004352 + (11434459449919585408487113*
           Zeta[3])/10438595668337760) + CF*Log[x]*
        ((-41655465747792349879894711*NM*NC)/4303512211078080 - 
         (957759377*lm*NM*NC)/1496880 - (1001*lm^2*NM*NC)/6 - 
         (26295063092581*NC*NL)/3772137600 - (957759377*lm*NC*NL)/1496880 - 
         (1001*lm^2*NC*NL)/6 - (72854419735262603230647306271*NC*NH)/
          6427361267774106374414700 - (957759377*lm*NC*NH)/1496880 - 
         (1001*lm^2*NC*NH)/6 - (537264708871*NM*NC*Pi^2)/324 - 
         (265331*NC*NL*Pi^2)/324 + (19743828628481*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CF*NC*(-7510634466438097593743960272432202957/
            414521342079856283143872000 - (999380957*lm)/166320 - 
           (3003*lm^2)/2 - (2502296207108393*Pi^2)/748440 + 
           (686080412285781143*Im[PolyLog[2, (-1)^(1/3)]])/
            (16108943932620*Sqrt[3]) - 4004*Zeta[3]) + 
         CA*NC*(150212862507011658118952943503212321/
            16580853683194251325754880 + (1275596897*lm)/272160 + 
           (11011*lm^2)/12 + (2502297419206973*Pi^2)/1496880 - 
           (686080412285781143*Im[PolyLog[2, (-1)^(1/3)]])/
            (32217887865240*Sqrt[3]) + 2002*Zeta[3])), 
      (-222007205440171811685027740890666558690364743117*CF^2*NC)/
        12316588008541570717595102083092480000 - (503826932117*CF^2*lm*NC)/
        461039040 - (4381*CF^2*lm^2*NC)/4 - 
       (92833523471890415990246260518049457*CF*NM*NC)/
        2504564061520316507712000 - (419668097357*CF*lm*NM*NC)/4149351360 - 
       (4381*CF*lm^2*NM*NC)/36 + (6512217660598867673*CF*NC*NL)/
        287550049248000 - (419668097357*CF*lm*NC*NL)/4149351360 - 
       (4381*CF*lm^2*NC*NL)/36 + 
       (40527516117912232359950613955168976791501121*CF*NC*NH)/
        66369014978354100641732039684748000000 - (419668097357*CF*lm*NC*NH)/
        4149351360 - (4381*CF*lm^2*NC*NH)/36 + 
       (506888704608304930583473*CF^2*NC*Pi^2)/73360532044800 + 
       (169*CF^2*lm*NC*Pi^2)/18 + (15380383339316203*CF*NM*NC*Pi^2)/
        1122660 + (169*CF*lm*NM*NC*Pi^2)/162 - (1744019251*CF*NC*NL*Pi^2)/
        2245320 + (169*CF*lm*NC*NL*Pi^2)/162 + (169*CF*lm*NC*NH*Pi^2)/162 - 
       (119827376563101037049*CF^2*NC*Pi^3)/(7157894172574464*Sqrt[3]) - 
       (46307266793310775*CF*NC*NH*Pi^3)/(564859072962*Sqrt[3]) - 
       (7600489*CF^2*NC*Pi^4)/25920 + (11436699102649404580053181*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(96452623975440902400*Sqrt[3]) + 
       (33336969544492769737*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (108735371545185*Sqrt[3]) - (112281*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - (119827376563101037049*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(193307327191440*Sqrt[3]) - 
       (10584518124185320*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (119827376563101037049*CF^2*NC*Pi*Log[3]^2)/
        (9278751705189120*Sqrt[3]) - (1323064765523165*CF*NC*NH*Pi*Log[3]^2)/
        (20920706406*Sqrt[3]) - 
       (CF*NC*(46*CF*(-4815406282675458606907097 + 12008057405811667200*lm) - 
          23*CA*(-4815402210973855865739169 + 14676514607103148800*lm) + 
          133056*(1955*(-1688423804841699339 + 235942867160*lm)*NM + 
            14*(690525550*(59617 + 47714*lm)*NL + (10840816056853 + 
                32947736092700*lm)*NH)))*Log[x]^2)/2671546041964800 + 
       (CF*NC*(-9105781484609805*CA + 22*(827736253080991*CF + 
            1680*(991462257605*NM + 310141*NL)))*Log[x]^3)/748440 + 
       (2071134913690349066068301*CF^2*NC*PolyGamma[2, 1])/366028679279376 + 
       (1841005282306*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (154468655484725197*CF*NC*NH*PolyGamma[2, 1])/7625597484987 - 
       (34197802446535958959338529*CF^2*NC*Zeta[3])/40263154720731360 + 
       (1699098494822*CF*NM*NC*Zeta[3])/81 - (663208*CF*NC*NL*Zeta[3])/27 + 
       (1153449690530220502*CF*NC*NH*Zeta[3])/7625597484987 + 
       CA*CF*NC*(2442074537994202060222729091049324626363590613771/
          270964936187914555787092245828034560000 + (48191*lm^2)/72 - 
         (2293613776947385712093*Pi^2)/663896217600 + 
         (119827376563101037049*Pi^3)/(14315788345148928*Sqrt[3]) + 
         (7643753*Pi^4)/51840 + lm*(1062335562797/754427520 - 
           (1859*Pi^2)/324) - (11436699102649404580053181*
           Im[PolyLog[2, (-1)^(1/3)]])/(192905247950881804800*Sqrt[3]) + 
         (112281*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (119827376563101037049*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (386614654382880*Sqrt[3]) + (119827376563101037049*Pi*Log[3]^2)/
          (18557503410378240*Sqrt[3]) - (2071134913690349066068301*
           PolyGamma[2, 1])/732057358558752 + (34199065601686382525251273*
           Zeta[3])/80526309441462720) + CF*Log[x]*
        ((680731951786768752662687179*NM*NC)/10758780527695200 - 
         (1888343431*lm*NM*NC)/374220 - (2366*lm^2*NM*NC)/3 - 
         (414712726464613*NC*NL)/10373378400 - (1888343431*lm*NC*NL)/
          374220 - (2366*lm^2*NC*NL)/3 - (17646486440972114610905447685569*
           NC*NH)/29513393576513753760067500 - (1888343431*lm*NC*NH)/
          374220 - (2366*lm^2*NC*NH)/3 + (991462239652*NM*NC*Pi^2)/81 - 
         (331435*NC*NL*Pi^2)/81 + (10584518124185320*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(330172320814289723197359452826893737823/
            9699799404668637025566604800 - (1937532571*lm)/41580 - 
           7098*lm^2 + (346883971948417*Pi^2)/57024 + 
           (119827376563101037049*Im[PolyLog[2, (-1)^(1/3)]])/
            (579921981574320*Sqrt[3]) - 18928*Zeta[3]) + 
         CA*NC*(-1650857068948913256314529257768954802709/
            96997994046686370255666048000 + (2263969591*lm)/68040 + 
           (13013*lm^2)/3 - (64237720076719*Pi^2)/21120 - 
           (119827376563101037049*Im[PolyLog[2, (-1)^(1/3)]])/
            (1159843963148640*Sqrt[3]) + 9464*Zeta[3])), 
      (410096756917779685292832112139909558264116872378154039*CF^2*NC)/
        4285879492177863320340016761486605438976000 + 
       (53496502729457*CF^2*lm*NC)/103887463680 - (4887*CF^2*lm^2*NC)/16 + 
       (2547432065065533533192591557105374242447*CF*NM*NC)/
        53132464197005204732168448000 + (58785023927417*CF*lm*NM*NC)/
        934987173120 - (543*CF*lm^2*NM*NC)/16 + 
       (17257898137693368833*CF*NC*NL)/2492100426816000 + 
       (58785023927417*CF*lm*NC*NL)/934987173120 - (543*CF*lm^2*NC*NL)/16 + 
       (110177683579191125902907607580881150238391*CF*NC*NH)/
        178876917374815330071833946530016000000 + 
       (58785023927417*CF*lm*NC*NH)/934987173120 - (543*CF*lm^2*NC*NH)/16 - 
       (3817684543183608925001063*CF^2*NC*Pi^2)/105965212953600 - 
       (61*CF^2*lm*NC*Pi^2)/24 - (724173288809350673*CF*NM*NC*Pi^2)/
        38918880 - (61*CF*lm*NM*NC*Pi^2)/216 - (4398556531*CF*NC*NL*Pi^2)/
        19459440 - (61*CF*lm*NC*NL*Pi^2)/216 - (61*CF*lm*NC*NH*Pi^2)/216 - 
       (448406618202958547489*CF^2*NC*Pi^3)/(93052624243468032*Sqrt[3]) - 
       (74795158231164665*CF*NC*NH*Pi^3)/(40669853253264*Sqrt[3]) - 
       (111511*CF^2*NC*Pi^4)/960 - (78817927892411840531252621*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2328641921692787500800*Sqrt[3]) + 
       (1092600607774665767209*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (7828946751253320*Sqrt[3]) - 
       (48797*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (64058088314708363927*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (358999321926960*Sqrt[3]) - (2137004520890419*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (64058088314708363927*CF^2*NC*Pi*Log[3]^2)/(17231967452494080*
         Sqrt[3]) - (2137004520890419*CF*NC*NH*Pi*Log[3]^2)/
        (1506290861232*Sqrt[3]) - 
       (CF*NC*(-(CA*(2502493972861498845698088331 + 431755259443573665600*
              lm)) + 6*(CF*(834164511409132788210054941 + 
              117751434393701908800*lm) + 24024*(15*(1195529660781362468487 + 
                36306728578120*lm)*NM + 17*(170600430*(184571 + 187780*lm)*
                 NL + (12818543752967 + 32035348745400*lm)*NH))))*Log[x]^2)/
        11576699515180800 + (CF*NC*(103592919338419090*CA - 
          39*(5312482350007163*CF + 1540*(1761262268042*NM - 122057*NL)))*
         Log[x]^3)/1621620 - (151904813693132560841066863*CF^2*NC*
         PolyGamma[2, 1])/3660286792793760 - 
       (495682766024*CF*NM*NC*PolyGamma[2, 1])/45 - 
       (24637496224835938691*CF*NC*NH*PolyGamma[2, 1])/1830143396396880 - 
       (14010194362782394376893906973*CF^2*NC*Zeta[3])/732789415917310752 + 
       (476353561067*CF*NM*NC*Zeta[3])/45 - (65093*CF*NC*NL*Zeta[3])/9 - 
       (70085413296015282011*CF*NC*NH*Zeta[3])/915071698198440 + 
       CA*CF*NC*(-2050484200678525456192834453221695036348789636372754281/
          42858794921778633203400167614866054389760000 + (5973*lm^2)/32 + 
         (224569681919293728880091*Pi^2)/12466495641600 + 
         (448406618202958547489*Pi^3)/(186105248486936064*Sqrt[3]) + 
         (199939*Pi^4)/3456 + lm*(-18399952961177/169997667840 + 
           (671*Pi^2)/432) + (78817927892411840531252621*
           Im[PolyLog[2, (-1)^(1/3)]])/(4657283843385575001600*Sqrt[3]) + 
         (48797*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (64058088314708363927*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (717998643853920*Sqrt[3]) + (64058088314708363927*Pi*Log[3]^2)/
          (34463934904988160*Sqrt[3]) + (151904813693132560841066863*
           PolyGamma[2, 1])/7320573585587520 + (70051028844184607680628706337*
           Zeta[3])/7327894159173107520) + CF*Log[x]*
        ((-6028002053257737080747029254799*NM*NC)/64502475523708622400 - 
         (5686836893*lm*NM*NC)/6486480 - (455*lm^2*NM*NC)/2 - 
         (143408620127219*NC*NL)/13831171200 - (5686836893*lm*NC*NL)/
          6486480 - (455*lm^2*NC*NL)/2 - (93354051548848956873769027597973*
           NC*NH)/6124897208114148427383420000 - (5686836893*lm*NC*NH)/
          6486480 - (455*lm^2*NC*NH)/2 - (1761262886335*NM*NC*Pi^2)/108 - 
         (130247*NC*NL*Pi^2)/108 + (2137004520890419*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(-28714619853559514003738951520660821290066057/
            166763801264765542062053853024000 - (5932782593*lm)/720720 - 
           (4095*lm^2)/2 - (828743758194594353*Pi^2)/25945920 + 
           (64058088314708363927*Im[PolyLog[2, (-1)^(1/3)]])/
            (1076997965780880*Sqrt[3]) - 5460*Zeta[3]) + 
         CA*NC*(7178656219656985114526478071921346593810047/
            83381900632382771031026926512000 + (7564967693*lm)/1179360 + 
           (5005*lm^2)/4 + (828743820218532329*Pi^2)/51891840 - 
           (64058088314708363927*Im[PolyLog[2, (-1)^(1/3)]])/
            (2153995931561760*Sqrt[3]) + 2730*Zeta[3])), 
      (-1205428200822613194008990832350646043354031124792612091*CF^2*NC)/
        6888020612428708907689312652389187312640000 - 
       (541579849913*CF^2*lm*NC)/397528560 - (2737*CF^2*lm^2*NC)/2 - 
       (45071659625230972645122414533360438207333*CF*NM*NC)/
        129510381480200186534660592000 - (450910210853*CF*lm*NM*NC)/
        3577757040 - (2737*CF*lm^2*NM*NC)/18 + 
       (232073523164941000349*CF*NC*NL)/6942279760416000 - 
       (450910210853*CF*lm*NC*NL)/3577757040 - (2737*CF*lm^2*NC*NL)/18 + 
       (11085688416032976056660358481185772851337523533*CF*NC*NH)/
        12543743830908925021287355500417372000000 - 
       (450910210853*CF*lm*NC*NH)/3577757040 - (2737*CF*lm^2*NC*NH)/18 + 
       (81094037897591305515713*CF^2*NC*Pi^2)/1216437393600 + 
       (98*CF^2*lm*NC*Pi^2)/9 + (187778322407020777*CF*NM*NC*Pi^2)/1459458 + 
       (98*CF*lm*NM*NC*Pi^2)/81 - (2181476423*CF*NC*NL*Pi^2)/2084940 + 
       (98*CF*lm*NC*NL*Pi^2)/81 + (98*CF*lm*NC*NH*Pi^2)/81 - 
       (312096334704527273327*CF^2*NC*Pi^3)/(13085525284237692*Sqrt[3]) - 
       (3633822642826497695*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) - 
       (1288609*CF^2*NC*Pi^4)/3240 + (446964565732643728204174331*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2619722161904385938400*Sqrt[3]) + 
       (1339593985743853015256*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2935855031719995*Sqrt[3]) - 
       (112742*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (178340762688301299044*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (201937118583915*Sqrt[3]) - (415294016323028308*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) - 
       (44585190672075324761*CF^2*NC*Pi*Log[3]^2)/(2423245423006980*
         Sqrt[3]) - (103823504080757077*CF*NC*NH*Pi*Log[3]^2)/
        (1129718145924*Sqrt[3]) - 
       (CF*NC*(-6*CA*(-20672195652988297046568473 + 9503612768666016000*lm) + 
          CF*(-248066379765184847922158797 + 93308198092357248000*lm) + 
          10296*(5*(-9300033971740754820839 + 201390395606400*lm)*NM + 
            2*(507536279250*(1235 + 992*lm)*NL + (172467634979203 + 
                503475989016000*lm)*NH)))*Log[x]^2)/310090165585200 + 
       (CF*NC*(-40882670063536339*CA + 81764352519417426*CF + 
          34320*(4653059828593*NM + 225680*NL))*Log[x]^3)/347490 + 
       (88992045606409432273502051*CF^2*NC*PolyGamma[2, 1])/
        1647129056757192 + (16946054802325*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (1331053506164259683*CF*NC*NH*PolyGamma[2, 1])/45753584909922 - 
       (5649357199902201257452991899*CF^2*NC*Zeta[3])/588848637790696140 + 
       (15279888449972*CF*NM*NC*Zeta[3])/81 - (960442*CF*NC*NL*Zeta[3])/
        27 + (4994917353469916641*CF*NC*NH*Zeta[3])/22876792454961 + 
       CA*CF*NC*(2410855716584824968718278937567855149920788004136148871/
          27552082449714835630757250609556749250560000 + (30107*lm^2)/36 - 
         (2270633023034596363916159*Pi^2)/68120494041600 + 
         (312096334704527273327*Pi^3)/(26171050568475384*Sqrt[3]) + 
         (431627*Pi^4)/2160 + lm*(1143296545493/650501280 - (539*Pi^2)/81) - 
         (446964565732643728204174331*Im[PolyLog[2, (-1)^(1/3)]])/
          (5239444323808771876800*Sqrt[3]) + 
         (56371*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (89170381344150649522*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (201937118583915*Sqrt[3]) + (44585190672075324761*Pi*Log[3]^2)/
          (4846490846013960*Sqrt[3]) - (88992045606409432273502051*
           PolyGamma[2, 1])/3294258113514384 + (706172962533023687050387739*
           Zeta[3])/147212159447674035) + CF*Log[x]*
        ((2304060373151812587949383788135*NM*NC)/3870148531422517344 - 
         (2369043803*lm*NM*NC)/347490 - (3185*lm^2*NM*NC)/3 - 
         (1115789504825899*NC*NL)/19264845600 - (2369043803*lm*NC*NL)/
          347490 - (3185*lm^2*NC*NL)/3 - 
         (271306031649167613593985062039268247*NC*NH)/
          312369757613821569796554420000 - (2369043803*lm*NC*NH)/347490 - 
         (3185*lm^2*NC*NH)/3 + (9306119668561*NM*NC*Pi^2)/81 - 
         (480025*NC*NL*Pi^2)/81 + (415294016323028308*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(6338016253940698775617953035965012442716711/
            19491872875102465955304995808000 - (1215265114*lm)/19305 - 
           9555*lm^2 + (10220654449746199*Pi^2)/173745 + 
           (178340762688301299044*Im[PolyLog[2, (-1)^(1/3)]])/
            (605811355751745*Sqrt[3]) - 25480*Zeta[3]) + 
         CA*NC*(-218895292710930200745909724338801988402681/
            1346377404245696235531271296000 + (2838576503*lm)/63180 + 
           (35035*lm^2)/6 - (81765225614218529*Pi^2)/2779920 - 
           (89170381344150649522*Im[PolyLog[2, (-1)^(1/3)]])/
            (605811355751745*Sqrt[3]) + 12740*Zeta[3])), 
      (169522806578264189228403212034289482927157087270236173749*CF^2*NC)/
        185446708796157547514712263718170427648000000 + 
       (198424791093887*CF^2*lm*NC)/311662391040 - (6061*CF^2*lm^2*NC)/16 + 
       (6414064739290158218707491918429711751082497*CF*NM*NC)/
        13632671734757914372069536000000 + (218101726011527*CF*lm*NM*NC)/
        2804961519360 - (6061*CF*lm^2*NM*NC)/144 + 
       (5551542687843974077*CF*NC*NL)/552226799124000 + 
       (218101726011527*CF*lm*NC*NL)/2804961519360 - (6061*CF*lm^2*NC*NL)/
        144 - (1680333960449625872744250525437795701782628139*CF*NC*NH)/
        903149555825442601532689596030050784000000 + 
       (218101726011527*CF*lm*NC*NH)/2804961519360 - (6061*CF*lm^2*NC*NH)/
        144 - (327212056313092737432871153*CF^2*NC*Pi^2)/953686916582400 - 
       (211*CF^2*lm*NC*Pi^2)/72 - (21145261182784211939*CF*NM*NC*Pi^2)/
        116756640 - (211*CF*lm*NM*NC*Pi^2)/648 - (3513569627*CF*NC*NL*Pi^2)/
        11675664 - (211*CF*lm*NC*NL*Pi^2)/648 - (211*CF*lm*NC*NH*Pi^2)/
        648 - (5494090716350689037525*CF^2*NC*Pi^3)/(837473618191212288*
         Sqrt[3]) - (2623430469347657935*CF*NC*NH*Pi^3)/
        (1098086037838128*Sqrt[3]) - (4062341*CF^2*NC*Pi^4)/25920 - 
       (268269382680699013397250875*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5868177642665824502016*Sqrt[3]) + (40469780579745197606027*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(211381562283839640*Sqrt[3]) - 
       (64565*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (1098818143270137807505*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4523391456279696*Sqrt[3]) - (74955156267075941*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (1098818143270137807505*CF^2*NC*Pi*Log[3]^2)/(217122789901425408*
         Sqrt[3]) - (74955156267075941*CF*NC*NH*Pi*Log[3]^2)/
        (40669853253264*Sqrt[3]) - 
       (CF*NC*(-7*CA*(10213691695424902965985881851 + 266208456376488225600*
             lm) + 2*(CF*(71495839970914045755417427297 + 
              1524648431974432564800*lm) + 72072*
             (57*(9186441275873996466457 + 41236877481800*lm)*NM + 
              20301451170*(112859 + 115780*lm)*NL + (980303548493683 + 
                2350502016462600*lm)*NH)))*Log[x]^2)/34730098545542400 - 
       (CF*NC*(-2962626816009888939*CA + 7*(846465446285793119*CF + 
            8580*(51580395324842*NM - 526799*NL)))*Log[x]^3)/4864860 - 
       (2552852912916038651717227453*CF^2*NC*PolyGamma[2, 1])/
        6588516227028768 - (702724193417339*CF*NM*NC*PolyGamma[2, 1])/6480 - 
       (464971463978798341661*CF*NC*NH*PolyGamma[2, 1])/24706935851357880 - 
       (5472446887479519778228254366149*CF^2*NC*Zeta[3])/
        32975523716278983840 + (328883763806461*CF*NM*NC*Zeta[3])/3240 - 
       (279674*CF*NC*NL*Zeta[3])/27 - (1295748434970644746001*CF*NC*NH*
         Zeta[3])/12353467925678940 + CA*CF*NC*
        (-550949137679999154726581650791095739129516131355402838603/
          1205403607175024058845629714168107779712000000 + (66671*lm^2)/288 + 
         (327212056903870039579939189*Pi^2)/1907373833164800 + 
         (5494090716350689037525*Pi^3)/(1674947236382424576*Sqrt[3]) + 
         (4048837*Pi^4)/51840 + lm*(-67841495731367/509993003520 + 
           (2321*Pi^2)/1296) + (268269382680699013397250875*
           Im[PolyLog[2, (-1)^(1/3)]])/(11736355285331649004032*Sqrt[3]) + 
         (64565*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (1098818143270137807505*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9046782912559392*Sqrt[3]) + (1098818143270137807505*Pi*Log[3]^2)/
          (434245579802850816*Sqrt[3]) + (2552852912916038651717227453*
           PolyGamma[2, 1])/13177032454057536 + 
         (1094489523231426430251531236977*Zeta[3])/13190209486511593536) + 
       CF*Log[x]*((-114337938281218751318506781781743*NM*NC)/
          127307517481003860000 - (22842708563*lm*NM*NC)/19459440 - 
         (910*lm^2*NM*NC)/3 - (146899680041993*NC*NL)/9807557760 - 
         (22842708563*lm*NC*NL)/19459440 - (910*lm^2*NC*NL)/3 - 
         (112088518080006531604582546499916781*NC*NH)/
          5622655637048788256337979560000 - (22842708563*lm*NC*NH)/
          19459440 - (910*lm^2*NC*NH)/3 - (51580397978857*NM*NC*Pi^2)/324 - 
         (559559*NC*NL*Pi^2)/324 + (74955156267075941*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(-48986852359343757602155430559469720345998389189/
            30017484227657797571169693544320000 - (23826491363*lm)/2162160 - 
           2730*lm^2 - (7900338762558823793*Pi^2)/25945920 + 
           (1098818143270137807505*Im[PolyLog[2, (-1)^(1/3)]])/
            (13570174368839088*Sqrt[3]) - 7280*Zeta[3]) + 
         CA*NC*(48986853631708108771323307880436202563950364449/
            60034968455315595142339387088640000 + (30355231763*lm)/3538080 + 
           (5005*lm^2)/3 + (1580067770309270885*Pi^2)/10378368 - 
           (1098818143270137807505*Im[PolyLog[2, (-1)^(1/3)]])/
            (27140348737678176*Sqrt[3]) + 3640*Zeta[3])), 
      (-24446105205105158705536816835055515901129405496460274865537*CF^2*NC)/
        14464843286100288706147556570017293356544000000 - 
       (2896109606185*CF^2*lm*NC)/1731457728 - (6735*CF^2*lm^2*NC)/4 - 
       (82283114791373112257523810175535401679419*CF*NM*NC)/
        25157416759945646180004000000 - (2410219281265*CF*lm*NM*NC)/
        15583119552 - (2245*CF*lm^2*NM*NC)/12 + 
       (3367719532123393864141*CF*NC*NL)/70194162021984000 - 
       (2410219281265*CF*lm*NC*NL)/15583119552 - (2245*CF*lm^2*NC*NL)/12 + 
       (6870993957901137520474597393781679458709252967556699*CF*NC*NH)/
        5506728629256679902195191639394227142744000000 - 
       (2410219281265*CF*lm*NC*NH)/15583119552 - (2245*CF*lm^2*NC*NH)/12 + 
       (464096722494532262786522275*CF^2*NC*Pi^2)/724802056602624 + 
       (25*CF^2*lm*NC*Pi^2)/2 + (35634631451205019*CF*NM*NC*Pi^2)/29484 + 
       (25*CF*lm*NM*NC*Pi^2)/18 - (895461755*CF*NC*NL*Pi^2)/648648 + 
       (25*CF*lm*NC*NL*Pi^2)/18 + (25*CF*lm*NC*NH*Pi^2)/18 - 
       (83286028461431655480575*CF^2*NC*Pi^3)/(2512420854573636864*Sqrt[3]) - 
       (46345460346446912455*CF*NC*NH*Pi^3)/(274521509459532*Sqrt[3]) - 
       (2736605*CF^2*NC*Pi^4)/5184 + (4218945583012280543670294535*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(17604532927997473506048*Sqrt[3]) + 
       (227042243514222115316353*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (343495038711239415*Sqrt[3]) - 
       (591875*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (16657205692286331096115*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13570174368839088*Sqrt[3]) - 
       (5296624039593932852*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (847288609443*Sqrt[3]) - (16657205692286331096115*CF^2*NC*Pi*
         Log[3]^2)/(651368369704276224*Sqrt[3]) - 
       (1324156009898483213*CF*NC*NH*Pi*Log[3]^2)/(10167463313316*Sqrt[3]) + 
       CF*((133427785371732404835121018867*CF*NC)/17365049272771200 - 
         426594*CF*lm*NC + CA*(-133427782816412826045771321667/
            34730098545542400 + (782089*lm)/3)*NC + 
         (2206080627988886132858*NM*NC)/152108775 - (142198*lm*NM*NC)/3 - 
         (529445*NC*NL)/9 - (142198*lm*NC*NL)/3 - (890157457881649*NC*NH)/
          52933853700 - (142198*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-2203312133308318565*CA + 4406615909565569242*CF + 
          864864*(9712142070971*NM + 71099*NL))*Log[x]^3)/1945944 + 
       (1693852291449668078975618887*CF^2*NC*PolyGamma[2, 1])/
        3294258113514384 + (34646108505847*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (50362796966810804263*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 - 
       (685177798659541823295230655775*CF^2*NC*Zeta[3])/6595104743255796768 + 
       (15221827230199*CF*NM*NC*Zeta[3])/9 - 50216*CF*NC*NL*Zeta[3] + 
       (189795482546124277637*CF*NC*NH*Zeta[3])/617673396283947 + 
       CA*CF*NC*(24446104201011505659305299846889651063043110988571579545787/
          28929686572200577412295113140034586713088000000 + (24695*lm^2)/24 - 
         (24426143232123363057420325*Pi^2)/76294953326592 + 
         (83286028461431655480575*Pi^3)/(5024841709147273728*Sqrt[3]) + 
         (2748125*Pi^4)/10368 + lm*(6120654489745/2833294464 - 
           (275*Pi^2)/36) - (4218945583012280543670294535*
           Im[PolyLog[2, (-1)^(1/3)]])/(35209065855994947012096*Sqrt[3]) + 
         (591875*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (16657205692286331096115*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27140348737678176*Sqrt[3]) + (16657205692286331096115*Pi*Log[3]^2)/
          (1302736739408552448*Sqrt[3]) - (1693852291449668078975618887*
           PolyGamma[2, 1])/6588516227028768 + 
         (685178214432531784122674368543*Zeta[3])/13190209486511593536) + 
       CF*Log[x]*((1503061437812924872579227999744359*NM*NC)/
          268760314682119260000 - (974981195*lm*NM*NC)/108108 - 
         1400*lm^2*NM*NC - (15932101421375837*NC*NL)/194788994400 - 
         (974981195*lm*NC*NL)/108108 - 1400*lm^2*NC*NL - 
         (1454488944255704866632683325038624795551*NC*NH)/
          1182163347689507730895060202490000 - (974981195*lm*NC*NH)/108108 - 
         1400*lm^2*NC*NH + (9712142077999*NM*NC*Pi^2)/9 - 
         (75299*NC*NL*Pi^2)/9 + (5296624039593932852*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(4978459694708885324391426622581774954575240567/
            1608079512195953441312662154160000 - (1000206395*lm)/12012 - 
           12600*lm^2 + (8813246871282565457*Pi^2)/15567552 + 
           (16657205692286331096115*Im[PolyLog[2, (-1)^(1/3)]])/
            (40710523106517264*Sqrt[3]) - 33600*Zeta[3]) + 
         CA*NC*(-10722835644896561174320171623663903943585961327/
            6927111744844107131808390817920000 + (1167609995*lm)/19656 + 
           7700*lm^2 - (8813246713755491753*Pi^2)/31135104 - 
           (16657205692286331096115*Im[PolyLog[2, (-1)^(1/3)]])/
            (81421046213034528*Sqrt[3]) + 16800*Zeta[3])), 
      (27395072755515365932417973705934297909588498533832984948679*CF^2*NC)/
        3144531149152236675249468819568976816640000000 + 
       (1209512524176601*CF^2*lm*NC)/1558311955200 - (7409*CF^2*lm^2*NC)/16 + 
       (32063208367479385679954757197746076899366143503*CF*NM*NC)/
        6993560599930810072871671968000000 + (1329778495802401*CF*lm*NM*NC)/
        14024807596800 - (7409*CF*lm^2*NM*NC)/144 + 
       (1123296695277765214249*CF*NC*NL)/78968432274732000 + 
       (1329778495802401*CF*lm*NC*NL)/14024807596800 - 
       (7409*CF*lm^2*NC*NL)/144 - 
       (1187815667427948290958142698977316240689482716286213*CF*NC*NH)/
        198242230653240476479026899018192177138784000000 + 
       (1329778495802401*CF*lm*NC*NH)/14024807596800 - 
       (7409*CF*lm^2*NC*NH)/144 - (29534076500425049475908897251*CF^2*NC*
         Pi^2)/9060025707532800 - (241*CF^2*lm*NC*Pi^2)/72 - 
       (1948763052039144145*CF*NM*NC*Pi^2)/1111968 - (241*CF*lm*NM*NC*Pi^2)/
        648 - (22945025377*CF*NC*NL*Pi^2)/58378320 - (241*CF*lm*NC*NL*Pi^2)/
        648 - (241*CF*lm*NC*NH*Pi^2)/648 - (5487663996903095962255*CF^2*NC*
         Pi^3)/(628105213643409216*Sqrt[3]) - 
       (29907202745081351725*CF*NC*NH*Pi^3)/(9882774340543152*Sqrt[3]) - 
       (134173*CF^2*NC*Pi^4)/648 - (952922806361442087620547367*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15718332971426315630400*Sqrt[3]) + 
       (578822360482256738414743*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2248331162473567080*Sqrt[3]) - 
       (62902*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (156790399911517027493*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (484649084601396*Sqrt[3]) - (854491507002324335*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (156790399911517027493*CF^2*NC*Pi*Log[3]^2)/(23263156060867008*
         Sqrt[3]) - (854491507002324335*CF*NC*NH*Pi*Log[3]^2)/
        (366028679279376*Sqrt[3]) - 
       (CF*NC*(-2001*CA*(12305865400558465679691569207 + 47377916570666682000*
             lm) + 4*(5336*CF*(2307349753545745880922661556 + 
              7268203110272729625*lm) + 5005*
             (29*(45603686268859865165896183 + 29689185754027800*lm)*NM + 
              407590673490*(2044193 + 2112380*lm)*NL + (372311654599148861 + 
                860986386866806200*lm)*NH)))*Log[x]^2)/1258966072275912000 + 
       (CF*NC*(56354252590693887445*CA - 12*(9392376550876726601*CF + 
            10010*(500399906031346*NM - 739333*NL)))*Log[x]^3)/9729720 - 
       (119018144272138531762202030539*CF^2*NC*PolyGamma[2, 1])/
        32942581135143840 - (2289131416889657*CF*NM*NC*PolyGamma[2, 1])/
        2160 - (5728558733570207499757*CF*NC*NH*PolyGamma[2, 1])/
        222362422662220920 - (2149138364654347210561168304677*CF^2*NC*
         Zeta[3])/1498887441649044720 + (1046867978351263*CF*NM*NC*Zeta[3])/
        1080 - (130322*CF*NC*NL*Zeta[3])/9 - 
       (15672113508915247182217*CF*NC*NH*Zeta[3])/111181211331110460 + 
       CA*CF*NC*(-27395072871786535133217755411564985690120236581859113791679/
          6289062298304473350498937639137953633280000000 + (81499*lm^2)/288 + 
         (1554425079354629517603827593*Pi^2)/953686916582400 + 
         (5487663996903095962255*Pi^3)/(1256210427286818432*Sqrt[3]) + 
         (222979*Pi^4)/2160 + lm*(-411383803387201/2549965017600 + 
           (2651*Pi^2)/1296) + (952922806361442087620547367*
           Im[PolyLog[2, (-1)^(1/3)]])/(31436665942852631260800*Sqrt[3]) + 
         (31451*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (156790399911517027493*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (969298169202792*Sqrt[3]) + (156790399911517027493*Pi*Log[3]^2)/
          (46526312121734016*Sqrt[3]) + (119018144272138531762202030539*
           PolyGamma[2, 1])/65885162270287680 + 
         (429827682125034461461032739397*Zeta[3])/599554976659617888) + 
       CF*Log[x]*((-93569087947099670919221231268519497*NM*NC)/
          10884792744625830030000 - (29980940537*lm*NM*NC)/19459440 - 
         (1190*lm^2*NM*NC)/3 - (5918119812626353*NC*NL)/280496151936 - 
         (29980940537*lm*NC*NL)/19459440 - (1190*lm^2*NC*NL)/3 - 
         (1082718673060862977220195225479544388463*NC*NH)/
          42557880516822278312222167289640000 - (29980940537*lm*NC*NH)/
          19459440 - (1190*lm^2*NC*NH)/3 - (500399909737475*NM*NC*Pi^2)/
          324 - (782173*NC*NL*Pi^2)/324 + (854491507002324335*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-302068971552205686068998066354269017778827101759/
            19576620148472476676849800137600000 - (31267425737*lm)/2162160 - 
           3570*lm^2 - (5123113928497425173*Pi^2)/1769040 + 
           (156790399911517027493*Im[PolyLog[2, (-1)^(1/3)]])/
            (1453947253804188*Sqrt[3]) - 9520*Zeta[3]) + 
         CA*NC*(302068972694224372523717848308237663704292106909/
            39153240296944953353699600275200000 + (39805009337*lm)/3538080 + 
           (6545*lm^2)/3 + (5123113936991573381*Pi^2)/3538080 - 
           (156790399911517027493*Im[PolyLog[2, (-1)^(1/3)]])/
            (2907894507608376*Sqrt[3]) + 4760*Zeta[3])), 
      (-1982738281859835511938826740738504346483040188139381121028199*CF^2*
         NC)/122047115226471185958120008559520912695840000000 - 
       (12335437922989*CF^2*lm*NC)/6087156075 - 2044*CF^2*lm^2*NC - 
       (13437007904108021768561984636701427317137330827*CF*NM*NC)/
        437097537495675629554479498000000 - (10261746753439*CF*lm*NM*NC)/
        54784404675 - (2044*CF*lm^2*NM*NC)/9 + 
       (1061380851136886598037*CF*NC*NL)/15793686454946400 - 
       (10261746753439*CF*lm*NC*NL)/54784404675 - (2044*CF*lm^2*NC*NL)/9 + 
       (127261369551024718168279785732868529148461642968032101041*CF*NC*NH)/
        73822928667383587934833629358137039364268926800000 - 
       (10261746753439*CF*lm*NC*NH)/54784404675 - (2044*CF*lm^2*NC*NH)/9 + 
       (578124235637911925200011479*CF^2*NC*Pi^2)/94375267786800 + 
       (128*CF^2*lm*NC*Pi^2)/9 + (4600962788774287336*CF*NM*NC*Pi^2)/
        405405 + (128*CF*lm*NM*NC*Pi^2)/81 - (6527134616*CF*NC*NL*Pi^2)/
        3648645 + (128*CF*lm*NC*NL*Pi^2)/81 + (128*CF*lm*NC*NH*Pi^2)/81 - 
       (95595796099725999910135*CF^2*NC*Pi^3)/(2119855096046506104*Sqrt[3]) - 
       (144560348276313607960*CF*NC*NH*Pi^3)/(617673396283947*Sqrt[3]) - 
       (92833*CF^2*NC*Pi^4)/135 + (122381636245467856617373578023*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(371345616449946706768200*Sqrt[3]) + 
       (2890946811839186854598464*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3091455348401154735*Sqrt[3]) - 
       (190864*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (38238318439890399964054*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22899669247415961*Sqrt[3]) - 
       (66084730640600506496*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7625597484987*Sqrt[3]) - (19119159219945199982027*CF^2*NC*Pi*
         Log[3]^2)/(549592061937983064*Sqrt[3]) - 
       (4130295665037531656*CF*NC*NH*Pi*Log[3]^2)/(22876792454961*Sqrt[3]) + 
       CF*((16621071372316997873716231928*CF*NC)/226107412405875 - 
         (1773472*CF*lm*NC)/3 + CA*(-199452855910574686027103167081/
            5426577897741000 + (9754096*lm)/27)*NC + 
         (18457498364419037186606347*NM*NC)/135528918525 - 
         (1773472*lm*NM*NC)/27 - (2195120*NC*NL)/27 - (1773472*lm*NC*NL)/
          27 - (585646332850983659*NC*NH)/24368099550795 - 
         (1773472*lm*NC*NH)/27)*Log[x]^2 + 
       (4*CF*NC*(-3299318321991553165*CA + 4*(1649658680660120281*CF + 
            30030*(102615459028877*NM + 110842*NL)))*Log[x]^3)/1216215 + 
       (81367659111666061301927429237*CF^2*NC*PolyGamma[2, 1])/
        16677181699666569 + (477901415301862*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (310868647893087334954*CF*NC*NH*PolyGamma[2, 1])/5559060566555523 - 
       (91243530559854148209124683940892*CF^2*NC*Zeta[3])/
        83469294406831177845 + (408520394384300*CF*NM*NC*Zeta[3])/27 - 
       (623968*CF*NC*NL*Zeta[3])/9 + (2351499756910383961804*CF*NC*NH*
         Zeta[3])/5559060566555523 + CA*CF*NC*
        (9532395530107486270172854953617190819709588457714860541903/
          1173529954100684480366538543841547237460000000 + (11242*lm^2)/9 - 
         (46249938836236266920349137*Pi^2)/15100042845888 + 
         (95595796099725999910135*Pi^3)/(4239710192093012208*Sqrt[3]) + 
         (279523*Pi^4)/810 + lm*(26097206593639/9960800850 - (704*Pi^2)/81) - 
         (122381636245467856617373578023*Im[PolyLog[2, (-1)^(1/3)]])/
          (742691232899893413536400*Sqrt[3]) + 
         (95432*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (19119159219945199982027*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (22899669247415961*Sqrt[3]) + (19119159219945199982027*Pi*Log[3]^2)/
          (1099184123875966128*Sqrt[3]) - (81367659111666061301927429237*
           PolyGamma[2, 1])/33354363399333138 + 
         (91243537778966886472439041020503*Zeta[3])/166938588813662355690) + 
       CF*Log[x]*((285508561025297698210881736905407509*NM*NC)/
          5442396372312915015000 - (14245979752*lm*NM*NC)/1216215 - 
         (5440*lm^2*NM*NC)/3 - (707265684961559*NC*NL)/6261074820 - 
         (14245979752*lm*NC*NL)/1216215 - (5440*lm^2*NC*NL)/3 - 
         (1743363462005310689005708455883680959591893*NC*NH)/
          1022453079416655236451137569133601000 - (14245979752*lm*NC*NH)/
          1216215 - (5440*lm^2*NC*NH)/3 + (820923672376928*NM*NC*Pi^2)/81 - 
         (935696*NC*NL*Pi^2)/81 + (66084730640600506496*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(22330404722816083640968324201342088810443424339879/
            759817569512588001020232867840600000 - (14613546952*lm)/135135 - 
           16320*lm^2 + (13197272927723550397*Pi^2)/2432430 + 
           (38238318439890399964054*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) - 43520*Zeta[3]) + 
         CA*NC*(-858861713077434299606974501901594574357414561829/
            58447505347122153924633297526200000 + (8526428276*lm)/110565 + 
           (29920*lm^2)/3 - (13197272893799494231*Pi^2)/4864860 - 
           (19119159219945199982027*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) + 21760*Zeta[3])), 
      (2254074726553519810980022927704286933257473466854604269417550774209*
         CF^2*NC)/27214693424076852611040812697217422077612267520000000 + 
       (21340620910669*CF^2*lm*NC)/22832409600 - (8943*CF^2*lm^2*NC)/16 + 
       (20199556424920282825402658747784676555870785228327743*CF*NM*NC)/
        454842531924566738312712553673472000000 + 
       (23467602567469*CF*lm*NM*NC)/205491686400 - (2981*CF*lm^2*NM*NC)/
        48 + (4144729954517419069553*CF*NC*NL)/210582486065952000 + 
       (23467602567469*CF*lm*NC*NL)/205491686400 - (2981*CF*lm^2*NC*NL)/
        48 - (350014492171373687621743911886740759334419535255623215191*CF*NC*
         NH)/28348004608275297766976113673524623115879267891200000 + 
       (23467602567469*CF*lm*NC*NH)/205491686400 - (2981*CF*lm^2*NC*NH)/
        48 - (124427534131080713039133740189*CF^2*NC*Pi^2)/4026678092236800 - 
       (91*CF^2*lm*NC*Pi^2)/24 - (6841169991367648663*CF*NM*NC*Pi^2)/
        405405 - (91*CF*lm*NM*NC*Pi^2)/216 - (431801737*CF*NC*NL*Pi^2)/
        855360 - (91*CF*lm*NC*NL*Pi^2)/216 - (91*CF*lm*NC*NH*Pi^2)/216 - 
       (774311873073135600165485*CF^2*NC*Pi^3)/(67835363073488195328*
         Sqrt[3]) - (27765556154771891575*CF*NC*NH*Pi^3)/
        (7412080755407364*Sqrt[3]) - (1160347*CF^2*NC*Pi^4)/4320 - 
       (1880248328241353053098667367173*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (23766119452796589233164800*Sqrt[3]) + 
       (25235716227628905542881559*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (74194928361627713640*Sqrt[3]) - 
       (53601*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (154862374614627120033097*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(366394707958655376*
         Sqrt[3]) - (3173206417688216180*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (154862374614627120033097*CF^2*NC*Pi*Log[3]^2)/(17586945982015458048*
         Sqrt[3]) - (793301604422054045*CF*NC*NH*Pi*Log[3]^2)/
        (274521509459532*Sqrt[3]) + 
       CF*((-622448740541807755554740281228069*CF*NC)/1678621429701216000 - 
         169238*CF*lm*NC + CA*(207482913632130371341940379834833/
            1119080953134144000 + (930809*lm)/9)*NC - 
         (8489482584240720767962435627*NM*NC)/41923612130400 - 
         (169238*lm*NM*NC)/9 - (1627313*NC*NL)/90 - (169238*lm*NC*NL)/9 - 
         (2182050290615893979*NC*NH)/259926395208480 - (169238*lm*NC*NH)/9)*
        Log[x]^2 - (CF*NC*(-356493296358685476765*CA + 712986605764291210628*
           CF + 480480*(804797145159281*NM - 169238*NL))*Log[x]^3)/
        6486480 - (89782113529808131774376116385797*CF^2*NC*PolyGamma[2, 1])/
        2668349071946651040 - (3705135589936897*CF*NM*NC*PolyGamma[2, 1])/
        360 - (15395945785615870203263*CF*NC*NH*PolyGamma[2, 1])/
        444724845324441840 - (6589234563858179581697587587549461*CF^2*NC*
         Zeta[3])/534203484203719538208 + (1660178715672113*CF*NM*NC*
         Zeta[3])/180 - (118915*CF*NC*NL*Zeta[3])/6 - 
       (41425205079383707726823*CF*NC*NH*Zeta[3])/222362422662220920 + 
       CA*CF*NC*
        (-2254074727906293282658013832940288873941618821417344573574484877709/
          54429386848153705222081625394434844155224535040000000 + 
         (32791*lm^2)/96 + (373282602405740580256364295863*Pi^2)/
          24160068553420800 + (774311873073135600165485*Pi^3)/
          (135670726146976390656*Sqrt[3]) + (231487*Pi^4)/1728 + 
         lm*(-7225197188269/37362124800 + (1001*Pi^2)/432) + 
         (1880248328241353053098667367173*Im[PolyLog[2, (-1)^(1/3)]])/
          (47532238905593178466329600*Sqrt[3]) + 
         (53601*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (154862374614627120033097*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (732789415917310752*Sqrt[3]) + (154862374614627120033097*Pi*
           Log[3]^2)/(35173891964030916096*Sqrt[3]) + 
         (89782113529808131774376116385797*PolyGamma[2, 1])/
          5336698143893302080 + (32946172930750471409842485403968529*Zeta[3])/
          5342034842037195382080) + CF*Log[x]*
        ((-8005242746747452002300381192873314575807*NM*NC)/
          97643847447790112589120000 - (283311439*lm*NM*NC)/142560 - 
         510*lm^2*NM*NC - (33980274905919191*NC*NL)/1168733966400 - 
         (283311439*lm*NC*NL)/142560 - 510*lm^2*NC*NL - 
         (6234178226943976660771558228745528477448001*NC*NH)/
          196310991247997805398618413273651392000 - (283311439*lm*NC*NH)/
          142560 - 510*lm^2*NC*NH - (804797146003735*NM*NC*Pi^2)/54 - 
         (89209*NC*NL*Pi^2)/27 + (3173206417688216180*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-2976742417754883400280988797132912015890820852533676231/
            20448210430722768283456506939326227200000 - (295429039*lm)/
            15840 - 4590*lm^2 - (712986593866320698621*Pi^2)/25945920 + 
           (154862374614627120033097*Im[PolyLog[2, (-1)^(1/3)]])/
            (1099184123875966128*Sqrt[3]) - 12240*Zeta[3]) + 
         CA*NC*(5953484838730688693711864422533692801874344752644051937/
            81792841722891073133826027757304908800000 + (375845839*lm)/
            25920 + 2805*lm^2 + (237662198012347590047*Pi^2)/17297280 - 
           (154862374614627120033097*Im[PolyLog[2, (-1)^(1/3)]])/
            (2198368247751932256*Sqrt[3]) + 6120*Zeta[3])), 
      (-12698371484774311728582532993180252786775125848839788373031789202813*
         CF^2*NC)/81644080272230557833122438091652266232836802560000000 - 
       (3781532954683741*CF^2*lm*NC)/1558311955200 - (9809*CF^2*lm^2*NC)/4 - 
       (98520878172243002784511224737176387440135670200345833*CF*NM*NC)/
        341131898943425053734534415255104000000 - 
       (3144637872660541*CF*lm*NM*NC)/14024807596800 - 
       (9809*CF*lm^2*NM*NC)/36 + (33267238961521549812403*CF*NC*NL)/
        360998547541632000 - (3144637872660541*CF*lm*NC*NL)/14024807596800 - 
       (9809*CF*lm^2*NC*NL)/36 + 
       (2258112422231565513863509021076996332909657165672200406391*CF*NC*NH)/
        966409248009385151146912966142884878950429587200000 - 
       (3144637872660541*CF*lm*NC*NH)/14024807596800 - 
       (9809*CF*lm^2*NC*NH)/36 + (4232907387780383416658846837497*CF^2*NC*
         Pi^2)/72480205660262400 + (289*CF^2*lm*NC*Pi^2)/18 + 
       (1036155994198697135063*CF*NM*NC*Pi^2)/9729720 + 
       (289*CF*lm*NM*NC*Pi^2)/162 - (133206691529*CF*NC*NL*Pi^2)/58378320 + 
       (289*CF*lm*NC*NL*Pi^2)/162 + (289*CF*lm*NC*NH*Pi^2)/162 - 
       (24502790047220324220296815*CF^2*NC*Pi^3)/(407012178440929171968*
         Sqrt[3]) - (1769057191103245395310*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (22839721*CF^2*NC*Pi^4)/25920 + 
       (63424594521730837047440779245949*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (142596716716779535398988800*Sqrt[3]) + 
       (36052336845072892514907439*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) - 
       (323289*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (4900558009444064844059363*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2198368247751932256*
         Sqrt[3]) - (808711858790055037856*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (4900558009444064844059363*CF^2*NC*Pi*Log[3]^2)/(105521675892092748288*
         Sqrt[3]) - (50544491174378439866*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + 
       CF*((7058373044835323688250559914365791*CF*NC)/10071728578207296000 - 
         (2408968*CF*lm*NC)/3 + CA*(-2352791014002639772854877575136637/
            6714485718804864000 + (13249324*lm)/27)*NC + 
         (40181487033193338831174647257*NM*NC)/31442709097800 - 
         (2408968*lm*NM*NC)/27 - (2974660*NC*NL)/27 - (2408968*lm*NC*NL)/
          27 - (3270204834825430727*NC*NH)/97472398203180 - 
         (2408968*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-252022323706131942039*CA + 20*(25202231265908155421*CF + 
            12012*(3852798507206585*NM + 602242*NL)))*Log[x]^3)/2432430 + 
       (110884682413519215100598900243185*CF^2*NC*PolyGamma[2, 1])/
        2401514164751985936 + (8785446484137407*CF*NM*NC*PolyGamma[2, 1])/
        54 - (836908698568022681509*CF*NC*NH*PolyGamma[2, 1])/
        11118121133111046 - (541536786830454811078027059337383169*CF^2*NC*
         Zeta[3])/48078313578334758438720 + (3648381824092937*CF*NM*NC*
         Zeta[3])/27 - (844798*CF*NC*NL*Zeta[3])/9 + 
       (3175083705256232056235*CF*NC*NH*Zeta[3])/5559060566555523 + 
       CA*CF*NC*
        (6837584640028220942895408951217665626833112510861900763384105212707/
          87924394139325216127978010252548594404593479680000000 + 
         (107899*lm^2)/72 - (248994552211620048952960144889*Pi^2)/
          8527083018854400 + (24502790047220324220296815*Pi^3)/
          (814024356881858343936*Sqrt[3]) + (4582741*Pi^4)/10368 + 
         lm*(8008200317201341/2549965017600 - (3179*Pi^2)/324) - 
         (63424594521730837047440779245949*Im[PolyLog[2, (-1)^(1/3)]])/
          (285193433433559070797977600*Sqrt[3]) + 
         (323289*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (4900558009444064844059363*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4396736495503864512*Sqrt[3]) + (4900558009444064844059363*Pi*
           Log[3]^2)/(211043351784185496576*Sqrt[3]) - 
         (110884682413519215100598900243185*PolyGamma[2, 1])/
          4803028329503971872 + (541536792430654527062010118460188801*
           Zeta[3])/96156627156669516877440) + 
       CF*Log[x]*((35988892954734523253101312159525253373217*NM*NC)/
          73232885585842584441840000 - (145661093489*lm*NM*NC)/9729720 - 
         2312*lm^2*NM*NC - (268206707013756113*NC*NL)/1753100949600 - 
         (145661093489*lm*NC*NL)/9729720 - 2312*lm^2*NC*NL - 
         (170621152901370268209557856520248984018195029*NC*NH)/
          73616621717999177024481904977619272000 - (145661093489*lm*NC*NH)/
          9729720 - 2312*lm^2*NC*NH + (7705597014682382*NM*NC*Pi^2)/81 - 
         (1266908*NC*NL*Pi^2)/81 + (808711858790055037856*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(68275083318570651651809324434655960491425233858350545943/
            245378525168673219401478083271914726400000 - (149410278929*lm)/
            1081080 - 20808*lm^2 + (2688238109083876943417*Pi^2)/51891840 + 
           (4900558009444064844059363*Im[PolyLog[2, (-1)^(1/3)]])/
            (6595104743255796768*Sqrt[3]) - 55488*Zeta[3]) + 
         CA*NC*(-68275083240650020732246570765064117853669967772436407143/
            490757050337346438802956166543829452800000 + (174291236849*lm)/
            1769040 + 12716*lm^2 - (2688238108105450838761*Pi^2)/103783680 - 
           (4900558009444064844059363*Im[PolyLog[2, (-1)^(1/3)]])/
            (13190209486511593536*Sqrt[3]) + 27744*Zeta[3])), 
      (1136873946563232674512723862518323556402872702180399412818016995539242\
44589*CF^2*NC)/144719398325706222630189757914710553468875250511365120000000 + 
       (2005616651353822327*CF^2*lm*NC)/1801408620211200 - 
       (10675*CF^2*lm^2*NC)/16 + 
       (3479627431527815566749394028697689223131891055063262245973*CF*NM*NC)/
        8130128321138860620644411811891842611200000 + 
       (2205929536986682327*CF*lm*NM*NC)/16212677581900800 - 
       (10675*CF*lm^2*NM*NC)/144 + (1392945769619807672212429*CF*NC*NL)/
        52164290119765824000 + (2205929536986682327*CF*lm*NC*NL)/
        16212677581900800 - (10675*CF*lm^2*NC*NL)/144 - 
       (5512680525398516074953297493779758822082142165797785386153*CF*NC*NH)/
        255132041474477679902785023061721608042913411020800000 + 
       (2205929536986682327*CF*lm*NC*NH)/16212677581900800 - 
       (10675*CF*lm^2*NC*NH)/144 - (360131336871191182679984734528733*CF^2*
         NC*Pi^2)/1232163496224460800 - (307*CF^2*lm*NC*Pi^2)/72 - 
       (49555597549301449171*CF*NM*NC*Pi^2)/306306 - (307*CF*lm*NM*NC*Pi^2)/
        648 - (2536195517579*CF*NC*NL*Pi^2)/3969725760 - 
       (307*CF*lm*NC*NL*Pi^2)/648 - (307*CF*lm*NC*NH*Pi^2)/648 - 
       (101460630308675469926661145*CF^2*NC*Pi^3)/(6919207033495795923456*
         Sqrt[3]) - (302789555350183334965*CF*NC*NH*Pi^3)/
        (66708726798666276*Sqrt[3]) - (8887967*CF^2*NC*Pi^4)/25920 - 
       (4194715496938529035362093138928717*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41210451131149285730307763200*
         Sqrt[3]) + (295392973689516582446587253*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(667754355254649422760*Sqrt[3]) - 
       (135087*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (20292126061735093985332229*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37372260211782848352*
         Sqrt[3]) - (34604520611449523996*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (20292126061735093985332229*CF^2*NC*Pi*Log[3]^2)/
        (1793868490165576720896*Sqrt[3]) - (8651130152862380999*CF*NC*NH*Pi*
         Log[3]^2)/(2470693585135788*Sqrt[3]) - 
       (CF*NC*(6*CF*(6205363045227857696530058264042192711 + 
            403500208544897527679616000*lm) - 
          CA*(18616089137196260521091882231303623073 + 
            1479500764664624268158592000*lm) + 13613600*
           ((1513875281602398127497646166393 + 19759662325169807040*lm)*NM + 
            7*(7013886854832*(384797 + 402460*lm)*NL + 
              5*(259285254421893229 + 564561780719137344*lm)*NH)))*Log[x]^2)/
        10615601921430489984000 + (CF*NC*(172133971404882460575273*CA - 
          68*(5062763878794179724737*CF + 120120*(23191464619024049*NM - 
              684182*NL)))*Log[x]^3)/330810480 - 
       (7516799977975818492365630345234231*CF^2*NC*PolyGamma[2, 1])/
        24015141647519859360 - (107367500376373579*CF*NM*NC*PolyGamma[2, 1])/
        1080 - (329687028271582159863347*CF*NC*NH*PolyGamma[2, 1])/
        7204542494255957808 - (86363241257891757954373823111445806471*CF^2*NC*
         Zeta[3])/817331330831690893458240 + 
       (47242263767297591*CF*NM*NC*Zeta[3])/540 - (479275*CF*NC*NL*Zeta[3])/
        18 - (873803473750068039129131*CF*NC*NH*Zeta[3])/
        3602271247127978904 + CA*CF*NC*(-113687394665847704296873912004034128\
401713624247447700466854330816241104089/
          289438796651412445260379515829421106937750501022730240000000 + 
         (117425*lm^2)/288 + (360131336872801813801697803552301*Pi^2)/
          2464326992448921600 + (101460630308675469926661145*Pi^3)/
          (13838414066991591846912*Sqrt[3]) + (8868319*Pi^4)/51840 + 
         lm*(-676267501244842327/2947759560345600 + (3377*Pi^2)/1296) + 
         (4194715496938529035362093138928717*Im[PolyLog[2, (-1)^(1/3)]])/
          (82420902262298571460615526400*Sqrt[3]) + 
         (135087*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (20292126061735093985332229*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74744520423565696704*Sqrt[3]) + (20292126061735093985332229*Pi*
           Log[3]^2)/(3587736980331153441792*Sqrt[3]) + 
         (7516799977975818492365630345234231*PolyGamma[2, 1])/
          48030283295039718720 + (86363241303485196781557285728494845863*
           Zeta[3])/1634662661663381786916480) + 
       CF*Log[x]*((-3989211866244191465850841688530964498100097*NM*NC)/
          5118312948945070810807872000 - (1670285915021*lm*NM*NC)/
          661620960 - 646*lm^2*NM*NC - (2342390220763774327*NC*NL)/
          59605432286400 - (1670285915021*lm*NC*NL)/661620960 - 
         646*lm^2*NC*NL - (5279234762057432651101512261942292320150331*NC*
           NH)/135907609325536942199043516881758656000 - 
         (1670285915021*lm*NC*NH)/661620960 - 646*lm^2*NC*NH - 
         (23191464622423471*NM*NC*Pi^2)/162 - (359533*NC*NL*Pi^2)/81 + 
         (34604520611449523996*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CF*NC*(-549471270331015371091610501350854429742333749925966956996404\
9/4008748965680614385361947446413270885196800000 - (1741520438381*lm)/
            73513440 - 5814*lm^2 - (45902392385231045470201*Pi^2)/176432256 + 
           (20292126061735093985332229*Im[PolyLog[2, (-1)^(1/3)]])/
            (112116780635348545056*Sqrt[3]) - 15504*Zeta[3]) + 
         CA*NC*(5494712703729217673867613302877416970342239488895093700422399/
            8017497931361228770723894892826541770393600000 + 
           (2214258638861*lm)/120294720 + 3553*lm^2 + 
           (8500443034591163904247*Pi^2)/65345280 - 
           (20292126061735093985332229*Im[PolyLog[2, (-1)^(1/3)]])/
            (224233561270697090112*Sqrt[3]) + 7752*Zeta[3])), 
      (-596459967223932476963452954140886798496877565369572380605359149662885\
3039*CF^2*NC)/4019983286825172850838604386519737596357645847537920000000 - 
       (3997744339513181*CF^2*lm*NC)/1389975787200 - (5823*CF^2*lm^2*NC)/2 - 
       (306137948220321942765241674675305315679891285649117508677*CF*NM*NC)/
        112918448904706397508950164054053369600000 - 
       (3323258588774381*CF*lm*NM*NC)/12509782084800 - 
       (647*CF*lm^2*NM*NC)/2 + (958448362382510836473463*CF*NC*NL)/
        7728042980706048000 - (3323258588774381*CF*lm*NC*NL)/
        12509782084800 - (647*CF*lm^2*NC*NL)/2 + 
       (62064535251586733322921141886601507197553907174629905316197*CF*NC*
         NH)/19932190740193568742405079926697000628352610236000000 - 
       (3323258588774381*CF*lm*NC*NH)/12509782084800 - 
       (647*CF*lm^2*NC*NH)/2 + (28495758894836651126155460004829*CF^2*NC*
         Pi^2)/51340145676019200 + 18*CF^2*lm*NC*Pi^2 + 
       (201632307667090054639*CF*NM*NC*Pi^2)/201960 + 2*CF*lm*NM*NC*Pi^2 - 
       (2197739263*CF*NC*NL*Pi^2)/765765 + 2*CF*lm*NC*NL*Pi^2 + 
       2*CF*lm*NC*NH*Pi^2 - (843991681733752867470175*CF^2*NC*Pi^3)/
        (10677788631937956672*Sqrt[3]) - (28373018677495713247495*CF*NC*NH*
         Pi^3)/(66708726798666276*Sqrt[3]) - (1201901*CF^2*NC*Pi^4)/1080 + 
       (337887126435094483477519128986507*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (572367376821517857365385600*Sqrt[3]) + 
       (42034914094835506730036597*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (23848369830523193670*Sqrt[3]) - 101294*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (168798336346750573494035*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(57673241067566124*Sqrt[3]) - 
       (3242630705999510085428*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (168798336346750573494035*CF^2*NC*Pi*Log[3]^2)/(2768315571243173952*
         Sqrt[3]) - (810657676499877521357*CF*NC*NH*Pi*Log[3]^2)/
        (2470693585135788*Sqrt[3]) + 
       CF*((259944179287231662491086138944179173*CF*NC)/
          39027948240553272000 - 1071612*CF*lm*NC + 
         CA*(-2209525523816484684851317825550878363/663475120089405624000 + 
           654874*lm)*NC + (64876162220927429656176241339*NM*NC)/
          5415133233510 - 119068*lm*NM*NC - (440164*NC*NL)/3 - 
         119068*lm*NC*NL - (2484467696024525359*NC*NH)/54151332335100 - 
         119068*lm*NC*NH)*Log[x]^2 + (CF*NC*(-5436599427285834728487*CA + 
          8*(1359149848007636666837*CF + 1837836*(1338317762631868*NM + 
              29767*NL)))*Log[x]^3)/5513508 + 
       (1570277848753194123868754580400303*CF^2*NC*PolyGamma[2, 1])/
        3602271247127978904 + (2989555825760235*CF*NM*NC*PolyGamma[2, 1])/
        2 - (44868793586482694633483*CF*NC*NH*PolyGamma[2, 1])/
        450283905890997363 - (35009673084714444376097231840367201557*CF^2*NC*
         Zeta[3])/306499249061884085046840 + 
       (3615396429162299*CF*NM*NC*Zeta[3])/3 - 124906*CF*NC*NL*Zeta[3] + 
       (341358820920204794100878*CF*NC*NH*Zeta[3])/450283905890997363 + 
       CA*CF*NC*(170417133473111049258116155293297508025588072131849406703363\
6840359759279/2297133306757241629050631078011278626490083341450240000000 + 
         (7117*lm^2)/4 - (9498586298224167056486794504897*Pi^2)/
          34226763784012800 + (843991681733752867470175*Pi^3)/
          (21355577263875913344*Sqrt[3]) + (1205357*Pi^4)/2160 + 
         lm*(8473877048961581/2274505833600 - 11*Pi^2) - 
         (337887126435094483477519128986507*Im[PolyLog[2, (-1)^(1/3)]])/
          (1144734753643035714730771200*Sqrt[3]) + 
         50647*Im[PolyLog[2, (-1)^(1/3)]]^2 + (168798336346750573494035*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(115346482135132248*
           Sqrt[3]) + (168798336346750573494035*Pi*Log[3]^2)/
          (5536631142486347904*Sqrt[3]) - (1570277848753194123868754580400303*
           PolyGamma[2, 1])/7204542494255957808 + 
         (35009673132010837870773477783645222323*Zeta[3])/
          612998498123768170093680) + CF*Log[x]*
        ((7190505146412737815508405111441976657158911*NM*NC)/
          1563928956622104969969072000 - (4815117746*lm*NM*NC)/255255 - 
         2907*lm^2*NM*NC - (899120747212111013*NC*NL)/4415217206400 - 
         (4815117746*lm*NC*NL)/255255 - 2907*lm^2*NC*NL - 
         (621749692876048253025125967668569932704731453*NC*NH)/
          200772604685452300975859740848052560000 - (4815117746*lm*NC*NH)/
          255255 - 2907*lm^2*NC*NH + (2676635525280209*NM*NC*Pi^2)/3 - 
         (62441*NC*NL*Pi^2)/3 + (3242630705999510085428*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(16257216546580697641961482667650166443560778666384659894193/
            6186340996420701211978313960514306921600000 - (29632732761*lm)/
            170170 - 26163*lm^2 + (54365994243207384454097*Pi^2)/110270160 + 
           (168798336346750573494035*Im[PolyLog[2, (-1)^(1/3)]])/
            (173019723202698372*Sqrt[3]) - 69768*Zeta[3]) + 
         CA*NC*(-2032152068003346860347564172806064117006401504151424496571/
            1546585249105175302994578490128576730400000 + 
           (2879757418*lm)/23205 + (31977*lm^2)/2 - 
           (18121998080148036184237*Pi^2)/73513440 - 
           (168798336346750573494035*Im[PolyLog[2, (-1)^(1/3)]])/
            (346039446405396744*Sqrt[3]) + 34884*Zeta[3])), 
      (3227568989384272420438296876315069849170164640276450576653720603462616\
373617*CF^2*NC)/
        434158194977118667890569273744131660406625751534095360000000 + 
       (338013039978073469*CF^2*lm*NC)/257344088601600 - 
       (12617*CF^2*lm^2*NC)/16 + 
       (33385830735930614575290054696770498561596797115493007435539*CF*NM*
         NC)/8130128321138860620644411811891842611200000 + 
       (371835022956056669*CF*lm*NM*NC)/2316096797414400 - 
       (12617*CF*lm^2*NM*NC)/144 + (3851844732069957179471729*CF*NC*NL)/
        108192601729884672000 + (371835022956056669*CF*lm*NC*NL)/
        2316096797414400 - (12617*CF*lm^2*NC*NL)/144 - 
       (108258493098995028592928525475099836306553927490252265837087*CF*NC*
         NH)/3131165963550407889715998010302947007799391862528000000 + 
       (371835022956056669*CF*lm*NC*NH)/2316096797414400 - 
       (12617*CF*lm^2*NC*NH)/144 - (3399246644766900733480876530198257*CF^2*
         NC*Pi^2)/1232163496224460800 - (343*CF^2*lm*NC*Pi^2)/72 - 
       (255583686503246969240707*CF*NM*NC*Pi^2)/165405240 - 
       (343*CF*lm*NM*NC*Pi^2)/648 - (150853019467*CF*NC*NL*Pi^2)/
        189034560 - (343*CF*lm*NC*NL*Pi^2)/648 - (343*CF*lm*NC*NH*Pi^2)/
        648 - (128406431109447967779017125*CF^2*NC*Pi^3)/
        (6919207033495795923456*Sqrt[3]) - (9707634513125076975545*CF*NC*NH*
         Pi^3)/(1801135623563989452*Sqrt[3]) - (11187307*CF^2*NC*Pi^4)/
        25920 - (15987069396103582179505659384939491*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(123631353393447857190923289600*
         Sqrt[3]) + (10228415872497428976347290543*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(18029367591875534414520*Sqrt[3]) - 
       (504241*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (25681286221889593555803425*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37372260211782848352*
         Sqrt[3]) - (1109443944357151654348*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (25681286221889593555803425*CF^2*NC*Pi*Log[3]^2)/
        (1793868490165576720896*Sqrt[3]) - (277360986089287913587*CF*NC*NH*
         Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) + 
       CF*((-527146671571572148068400511172836293279*CF*NC)/
          15923402882145734976000 - 302192*CF*lm*NC + 
         CA*(527146671577591346755242268735284614899/
            31846805764291469952000 + (1662056*lm)/9)*NC - 
         (14458949831643549864313464998959*NM*NC)/779779185625440 - 
         (302192*lm*NM*NC)/9 - (2874683*NC*NL)/90 - (302192*lm*NC*NL)/9 - 
         (61668626626515539849*NC*NH)/3898895928127200 - 
         (302192*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-542084236906198033308125*CA + 
          8*(135521059281748173986681*CF + 1021020*(73956975126257257*NM - 
              302192*NL)))*Log[x]^3)/110270160 - 
       (209553716468689668627638558116642387*CF^2*NC*PolyGamma[2, 1])/
        72045424942559578080 - (6193602358123599853*CF*NM*NC*
         PolyGamma[2, 1])/6480 - (1207752865154942295741071*CF*NC*NH*
         PolyGamma[2, 1])/20262775765094881335 - 
       (2209985949233510780188719714992292941161*CF^2*NC*Zeta[3])/
        2451993992495072680374720 + (2681234657150050607*CF*NM*NC*Zeta[3])/
        3240 - (1900019*CF*NC*NL*Zeta[3])/54 - 
       (6314807506432036390980697*CF*NC*NH*Zeta[3])/20262775765094881335 + 
       CA*CF*NC*(-24827453764781413685093312701298825627077212054779036491058\
8584708416309009/
          66793568458018256598549119037558716985634731005245440000000 + 
         (138787*lm^2)/288 + (3399246644768909556558752138896961*Pi^2)/
          2464326992448921600 + (128406431109447967779017125*Pi^3)/
          (13838414066991591846912*Sqrt[3]) + (248119*Pi^4)/1152 + 
         lm*(-113558062033275869/421108508620800 + (3773*Pi^2)/1296) + 
         (15987069396103582179505659384939491*Im[PolyLog[2, (-1)^(1/3)]])/
          (247262706786895714381846579200*Sqrt[3]) + 
         (504241*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (25681286221889593555803425*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74744520423565696704*Sqrt[3]) + (25681286221889593555803425*Pi*
           Log[3]^2)/(3587736980331153441792*Sqrt[3]) + 
         (209553716468689668627638558116642387*PolyGamma[2, 1])/
          144090849885119156160 + (2209985949413499717058893626308324496521*
           Zeta[3])/4903987984990145360749440) + 
       CF*Log[x]*((-415976510753055694850616171830774674703902321*NM*NC)/
          56301442438395778918886592000 - (99679161589*lm*NM*NC)/31505760 - 
         (1615*lm^2*NM*NC)/2 - (2489850714749839271*NC*NL)/47684345829120 - 
         (99679161589*lm*NC*NL)/31505760 - (1615*lm^2*NC*NL)/2 - 
         (11121032567349542761024381314249738659216129947*NC*NH)/
          238517854366317333559321372127486441280000 - 
         (99679161589*lm*NC*NH)/31505760 - (1615*lm^2*NC*NH)/2 - 
         (24652325042584283*NM*NC*Pi^2)/18 - (316727*NC*NL*Pi^2)/54 + 
         (1109443944357151654348*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*
          (-51641060810760794954838282021811435147081197760162512455727149/
            4008748965680614385361947446413270885196800000 - 
           (103919311789*lm)/3500640 - (14535*lm^2)/2 - 
           (2168336947695380678143321*Pi^2)/882161280 + 
           (25681286221889593555803425*Im[PolyLog[2, (-1)^(1/3)]])/
            (112116780635348545056*Sqrt[3]) - 19380*Zeta[3]) + 
         CA*NC*(5164106081130865830705841050039744911677221412333842055886129\
9/8017497931361228770723894892826541770393600000 + (132058490389*lm)/
            5728320 + (17765*lm^2)/4 + (2168336947705705164043049*Pi^2)/
            1764322560 - (25681286221889593555803425*Im[PolyLog[2, (-1)^
                (1/3)]])/(224233561270697090112*Sqrt[3]) + 9690*Zeta[3])), 
      (-141766664092604789213289461248790619817854912921819210164803843420640\
941055389*CF^2*NC)/
        10047661083756174885467460335221332712267624535503349760000000 - 
       (1521120446125657061*CF^2*lm*NC)/450352155052800 - 
       (13699*CF^2*lm^2*NC)/4 - 
       (1359995836816768449706239579040657246649345195938354151353*CF*NM*NC)/
        53487686323281977767397446130867385600000 - 
       (1264063188956144261*CF*lm*NM*NC)/4053169395475200 - 
       (13699*CF*lm^2*NM*NC)/36 + (75482837509422667005228763*CF*NC*NL)/
        459818557352009856000 - (1264063188956144261*CF*lm*NC*NL)/
        4053169395475200 - (13699*CF*lm^2*NC*NL)/36 + 
       (93818032054111531792174963630702134206094608624380059315461535371*CF*
         NC*NH)/
        22955690066696143673889854202297722666403796791301824000000 - 
       (1264063188956144261*CF*lm*NC*NH)/4053169395475200 - 
       (13699*CF*lm^2*NC*NH)/36 + (149076579268899747853452244057483831*CF^2*
         NC*Pi^2)/28339760413162598400 + (361*CF^2*lm*NC*Pi^2)/18 + 
       (35149473128851728636251*CF*NM*NC*Pi^2)/3759210 + 
       (361*CF*lm*NM*NC*Pi^2)/162 - (1179373120139*CF*NC*NL*Pi^2)/
        330810480 + (361*CF*lm*NC*NL*Pi^2)/162 + (361*CF*lm*NC*NH*Pi^2)/
        162 - (171923344192952561889713702245*CF^2*NC*Pi^3)/
        (1681367309139478409399808*Sqrt[3]) - 
       (1008266842188769231345445*CF*NC*NH*Pi^3)/(1801135623563989452*
         Sqrt[3]) - (35964017*CF^2*NC*Pi^4)/25920 + 
       (7729463972154320336178152850705488447*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10014139624869276432464786457600*
         Sqrt[3]) + (180704653438038288044361235103*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(76624812265471021261710*Sqrt[3]) - 
       (1505123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (34384668838590512377942740449*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9081459231463232149536*
         Sqrt[3]) - (115230496250145055010908*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (34384668838590512377942740449*CF^2*NC*Pi*Log[3]^2)/
        (435910043110235143177728*Sqrt[3]) - (28807624062536263752727*CF*NC*
         NH*Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) + 
       CF*((3478023652780235831136363363822631027*CF*NC)/
          55098279869016384000 - 1407748*CF*lm*NC + 
         CA*(-1005148835645567038399450537889131657603/
            31846805764291469952000 + (7742614*lm)/9)*NC + 
         (287807119729878368953140143317*NM*NC)/2565063110610 - 
         (1407748*lm*NM*NC)/9 - (1731470*NC*NL)/9 - (1407748*lm*NC*NL)/9 - 
         (116942354747922776047*NC*NH)/1898146701851400 - 
         (1407748*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-128971549350401869576483*CA + 5*(51588619691430974008421*CF + 
            15519504*(5939820471201874*NM + 18523*NL)))*Log[x]^3)/
        13783770 + (798795666747543465325372416215178659*CF^2*NC*
         PolyGamma[2, 1])/194522647344910860816 + 
       (1111954448868075035*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (526639528416254678692690*CF*NC*NH*PolyGamma[2, 1])/
        4052555153018976267 - (15145954139692538703167152888180131337637*CF^2*
         NC*Zeta[3])/13240767559473392474023488 + 
       (869629830387635794*CF*NM*NC*Zeta[3])/81 - 
       (4418906*CF*NC*NL*Zeta[3])/27 + (4015997343196479751384648*CF*NC*NH*
         Zeta[3])/4052555153018976267 + CA*CF*NC*
        (99236664863269186602178529128349883283902967475701580336753117039593\
1129527723/140667255172586448396544444693098657971746743497046896640000000 + 
         (150689*lm^2)/72 - (341136336999511349036083802677979*Pi^2)/
          129701420655206400 + (171923344192952561889713702245*Pi^3)/
          (3362734618278956818799616*Sqrt[3]) + (12018811*Pi^4)/17280 + 
         lm*(3227045880068787461/736939890086400 - (3971*Pi^2)/324) - 
         (7729463972154320336178152850705488447*Im[PolyLog[2, (-1)^(1/3)]])/
          (20028279249738552864929572915200*Sqrt[3]) + 
         (1505123*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (34384668838590512377942740449*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(18162918462926464299072*Sqrt[3]) + 
         (34384668838590512377942740449*Pi*Log[3]^2)/
          (871820086220470286355456*Sqrt[3]) - 
         (798795666747543465325372416215178659*PolyGamma[2, 1])/
          389045294689821721632 + (75729770711798294762761995220171219415113*
           Zeta[3])/132407675594733924740234880) + 
       CF*Log[x]*((31827358723520186922764872682315560212044119*NM*NC)/
          740808453136786564722192000 - (1294062254699*lm*NM*NC)/55135080 - 
         3610*lm^2*NM*NC - (135226312051621998719*NC*NL)/506646174434400 - 
         (1294062254699*lm*NC*NL)/55135080 - 3610*lm^2*NC*NL - 
         (795766864775936853943213413314081056483038386281*NC*NH)/
          195293625973378247393965884235962283560000 - 
         (1294062254699*lm*NC*NH)/55135080 - 3610*lm^2*NC*NH + 
         8359747329848145*NM*NC*Pi^2 - (736364*NC*NL*Pi^2)/27 + 
         (115230496250145055010908*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*
          (24124455050011952745585255182739136203340412959032136176108133909/
            974125998660389295642953229478424825102822400000 - 
           (1327235194499*lm)/6126120 - 32490*lm^2 + 
           (1375696526300354644212059*Pi^2)/294053760 + 
           (34384668838590512377942740449*Im[PolyLog[2, (-1)^(1/3)]])/
            (27244377694389696448608*Sqrt[3]) - 86640*Zeta[3]) + 
         CA*NC*
          (-2193132277226925009181757589356413647883893014745950682699493319/
            177113817938252599207809678086986331836876800000 + 
           (1547382885899*lm)/10024560 + 19855*lm^2 - 
           (4127089578872129020325873*Pi^2)/1764322560 - 
           (34384668838590512377942740449*Im[PolyLog[2, (-1)^(1/3)]])/
            (54488755388779392897216*Sqrt[3]) + 43320*Zeta[3])), 
      (9381307334960637427327358615646009622228841216308173619676228172777752\
2253374259*CF^2*NC)/
        1336338924139571259767172224584437250731594063221945518080000000 + 
       (332999936395921593707*CF^2*lm*NC)/216769503965414400 - 
       (14781*CF^2*lm^2*NC)/16 + 
       (531805155983857676032220981753437297903440361439672226723019*CF*NM*
         NC)/13550213868564767701074019686486404352000000 + 
       (366375665959596492107*CF*lm*NM*NC)/1950925535688729600 - 
       (4927*CF*lm^2*NM*NC)/48 + (31029386780711461416622359689*CF*NC*NL)/
        663977996816302232064000 + (366375665959596492107*CF*lm*NC*NL)/
        1950925535688729600 - (4927*CF*lm^2*NC*NL)/48 - 
       (13005946499194945396783054032231766810069423416903978406186473997*CF*
         NC*NH)/
        249233206438415274173661274196375274663812650876991232000000 + 
       (366375665959596492107*CF*lm*NC*NH)/1950925535688729600 - 
       (4927*CF*lm^2*NC*NH)/48 - (2332317527593068065342714670607932667*CF^2*
         NC*Pi^2)/89742574641681561600 - (127*CF^2*lm*NC*Pi^2)/24 - 
       (15408203155690112617885111*CF*NM*NC*Pi^2)/1047566520 - 
       (127*CF*lm*NM*NC*Pi^2)/216 - (8256208357231*CF*NC*NL*Pi^2)/
        8380532160 - (127*CF*lm*NC*NL*Pi^2)/216 - (127*CF*lm*NC*NH*Pi^2)/
        216 - (370177496017577606176066351115*CF^2*NC*Pi^3)/
        (15972989436825044889298176*Sqrt[3]) - 
       (11303825472154773681305*CF*NC*NH*Pi^3)/(1801135623563989452*
         Sqrt[3]) - (2317571*CF^2*NC*Pi^4)/4320 - 
       (58719207812773394548320061991746079617*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(361510440457780879211978791119360*
         Sqrt[3]) + (220198259500048384691460378317*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(306499249061884085046840*Sqrt[3]) - 
       (103385*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (74035499203515521235213270223*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(86273862698900705420592*
         Sqrt[3]) - (1291865768246259849292*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (74035499203515521235213270223*CF^2*NC*Pi*Log[3]^2)/
        (4141145409547233860188416*Sqrt[3]) - 
       (322966442061564962323*CF*NC*NH*Pi*Log[3]^2)/(66708726798666276*
         Sqrt[3]) + CF*((-15725650929869427157687996863315069570149*CF*NC)/
          50424109126794827424000 - 394440*CF*lm*NC + 
         CA*(15725650929894327682056435195968693833319/
            100848218253589654848000 + (723140*lm)/3)*NC - 
         (229388699988189092522689141688711*NM*NC)/1299631976042400 - 
         (131480*lm*NM*NC)/3 - (415017*NC*NL)/10 - (131480*lm*NC*NL)/3 - 
         (59746975554102199477*NC*NH)/2828610771386400 - 
         (131480*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(97111612206375064756937949*CA - 
          2128*(91270312229448276422291*CF + 218790*(235010926166159221*NM - 
              131480*NL)))*Log[x]^3)/2095133040 - 
       (52525381546384104632805449297029819051*CF^2*NC*PolyGamma[2, 1])/
        1945226473449108608160 - (6589359697082322829*CF*NM*NC*
         PolyGamma[2, 1])/720 - (9314443417834946636878571*CF*NC*NH*
         PolyGamma[2, 1])/121576654590569288010 - 
       (4813463840065226341409951067111566399091683*CF^2*NC*Zeta[3])/
        628936459074986142516115680 + (937025783193458797*CF*NM*NC*Zeta[3])/
        120 - (824663*CF*NC*NL*Zeta[3])/18 - 
       (24046960581689777293761026*CF*NC*NH*Zeta[3])/60788327295284644005 + 
       CA*CF*NC*(-93813073349754458520799855995827541631877222479934914229845\
967308252144710365759/
          2672677848279142519534344449168874501463188126443891036160000000 + 
         (54197*lm^2)/96 + (101405109895358628392316283148306989*Pi^2)/
          7803702142754918400 + (370177496017577606176066351115*Pi^3)/
          (31945978873650089778596352*Sqrt[3]) + (771169*Pi^4)/2880 + 
         lm*(-111506458382442722507/354713733761587200 + (1397*Pi^2)/432) + 
         (58719207812773394548320061991746079617*Im[PolyLog[2, (-1)^(1/3)]])/
          (723020880915561758423957582238720*Sqrt[3]) + 
         (103385*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (74035499203515521235213270223*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(172547725397801410841184*Sqrt[3]) + 
         (74035499203515521235213270223*Pi*Log[3]^2)/
          (8282290819094467720376832*Sqrt[3]) + 
         (52525381546384104632805449297029819051*PolyGamma[2, 1])/
          3890452946898217216320 + 
         (4813463840125124284928166711210685655182379*Zeta[3])/
          1257872918149972285032231360) + CF*Log[x]*
        ((-45840830674701660638939013922340946896583007*NM*NC)/
          656193967813470616770240000 - (5471638811473*lm*NM*NC)/
          1396755360 - (1995*lm^2*NM*NC)/2 - (1753923563514212158283*NC*NL)/
          25670072838009600 - (5471638811473*lm*NC*NL)/1396755360 - 
         (1995*lm^2*NC*NL)/2 - 
         (17950930045682234985705376408616104306015282817257*NC*NH)/
          326530942627488429642710958442528938112320000 - 
         (5471638811473*lm*NC*NH)/1396755360 - (1995*lm^2*NC*NH)/2 - 
         (78336975388935859*NM*NC*Pi^2)/6 - (137465*NC*NL*Pi^2)/18 + 
         (1291865768246259849292*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*
          (-50840742608452746517719886940549266847538289291644253166273558563/
            420645317603349923118547985456592538112582400000 - 
           (5703849390073*lm)/155195040 - (17955*lm^2)/2 - 
           (194223224413629668518772051*Pi^2)/8380532160 + 
           (74035499203515521235213270223*Im[PolyLog[2, (-1)^(1/3)]])/
            (258821588096702116261776*Sqrt[3]) - 23940*Zeta[3]) + 
         CA*NC*
          (65793902199270090198774238824306537939642190025709629631143537183/
            1088729057326317448071535962358239510409036800000 + 
           (7244883229873*lm)/253955520 + (21945*lm^2)/4 + 
           (12948214960917165033582781*Pi^2)/1117404288 - 
           (74035499203515521235213270223*Im[PolyLog[2, (-1)^(1/3)]])/
            (517643176193404232523552*Sqrt[3]) + 11970*Zeta[3]))}, 0, 39, 1]
 
CbarLSeries["v", 2, 1, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-671280150*NM - 9768960*lm*NM + 49766400*lm^2*NM + 
         309141504*NL - 9768960*lm*NL + 49766400*lm^2*NL - 671280150*NH - 
         9768960*lm*NH + 49766400*lm^2*NH + 80*CF*(1241720570 - 165888*lm + 
           5598720*lm^2 - 1022968575*Zeta[3]) + 645458625*NM*Zeta[3] + 
         645458625*NH*Zeta[3] - 8*CA*(36829440*lm + 34214400*lm^2 + 
           79*(-21452674 + 19284075*Zeta[3]))))/83607552000, 
      -(CF*NC*(320*CF*(1241637626 + 5432832*lm + 5598720*lm^2 - 
            1022968575*Zeta[3]) - 32*CA*(-1676346526 + 71043840*lm + 
            34214400*lm^2 + 1523441925*Zeta[3]) + 
          3*(24576*(16507 + 2170*lm + 2700*lm^2)*NL + 
            5*NM*(-46545986 + 10665984*lm + 13271040*lm^2 + 73591875*Zeta[
                3]) + 5*NH*(-314075150 + 10665984*lm + 13271040*lm^2 + 
              270652725*Zeta[3]))))/167215104000, 
      (CF*NC*(28084468286*NM + 25021022208*lm*NM + 19074908160*lm^2*NM + 
         124432908288*NL + 25021022208*lm*NL + 19074908160*lm^2*NL - 
         758451273874*NH + 25021022208*lm*NH + 19074908160*lm^2*NH + 
         126*CF*(3285599947346 + 2014298112*lm + 1362493440*lm^2 - 
           2730598298715*Zeta[3]) + 56945657475*NM*Zeta[3] + 
         636304556475*NH*Zeta[3] - 3*CA*(-12222127720262 + 90379993088*lm + 
           34970664960*lm^2 + 10318158066825*Zeta[3])))/13109664153600, 
      -(CF*NC*(-(CA*(-99597952590454 + 262920978432*lm + 100143267840*lm^2 + 
             83308394847825*Zeta[3])) + 
          2*(7*CF*(83142253428646 + 17784520704*lm + 11705057280*lm^2 - 
              69143254849305*Zeta[3]) + 9*(7*NM*(145748702 + 195477504*lm + 
                144506880*lm^2 + 746205075*Zeta[3]) + 
              96*(512*(142847 + 27839*lm + 20580*lm^2)*NL + 
                7*NH*(-96395278 + 2036224*lm + 1505280*lm^2 + 80493525*
                   Zeta[3]))))))/13109664153600, 
      (CF*NC*(-103424695324650*NM + 12852142571520*lm*NM + 
         14631321600000*lm^2*NM + 101631017172992*NL + 
         12852142571520*lm*NL + 14631321600000*lm^2*NL - 
         1481891359060350*NH + 12852142571520*lm*NH + 14631321600000*lm^2*
          NH + 108*CF*(35113769029650938 + 1274224680960*lm + 
           1219276800000*lm^2 - 29209531818425175*Zeta[3]) + 
         197255733357375*NM*Zeta[3] + 1237687610284125*NH*Zeta[3] - 
         2*CA*(-127448032348238498 + 86553017671680*lm + 40236134400000*
            lm^2 + 106186115435281875*Zeta[3])))/12978567512064000, 
      (CF*NC*(605359095948810*NM + 5543944519680*lm*NM - 
         20913035673600*lm^2*NM - 125568629211136*NL + 
         5543944519680*lm*NL - 20913035673600*lm^2*NL + 
         3353395258788246*NH + 5543944519680*lm*NH - 20913035673600*lm^2*
          NH - 720*CF*(27399069005799766 - 25730482176*lm + 
           261412945920*lm^2 - 22793378906013345*Zeta[3]) - 
         681920666571375*NM*Zeta[3] - 2802663478778625*NH*Zeta[3] + 
         8*CA*(-142235230562477026 + 14487444357120*lm + 14377712025600*
            lm^2 + 118358246232407475*Zeta[3])))/25957135024128000, 
      (CF*NC*(-363*CA*(-299483299124133491074 - 11289287039385600*lm + 
           9476414373888000*lm^2 + 249123428915637283875*Zeta[3]) + 
         2*(11*CF*(100108499318250179452478 - 587810942956339200*lm + 
             255863188094976000*lm^2 - 83281396087864954720125*Zeta[3]) + 
           15*(131072*(499540722881 - 391924985760*lm + 159058468800*lm^2)*
              NL + 1386*NM*(-1237791759638786 - 37063774699520*lm + 
               15041927577600*lm^2 + 1149494651179875*Zeta[3]) + 
             693*NH*(-7844652439348714 - 74127549399040*lm + 30083855155200*
                lm^2 + 6557458337805375*Zeta[3])))))/1224917201788600320000, 
      (CF*NC*(-22*CF*(43424096093983713323006 - 186774788688445440*lm + 
           28089328258252800*lm^2 - 36124958965478379536925*Zeta[3]) + 
         1815*CA*(-22486583399893632602 - 1153379920379904*lm + 
           208069098209280*lm^2 + 18704358460586636775*Zeta[3]) - 
         6*(231*NM*(-11181823800790442 - 337665508638720*lm + 
             49540261478400*lm^2 + 9496199939601375*Zeta[3]) + 
           4*(8192*(-1439084054357 - 2380393447740*lm + 349237072800*lm^2)*
              NL + 3465*NH*(-376238023247262 - 5627758477312*lm + 
               825671024640*lm^2 + 314387095747725*Zeta[3])))))/
       244983440357720064000, 
      (CF*NC*(1248*CF*(4688169004373651466943218194 - 11385774539280639590400*
            lm + 644628143567536128000*lm^2 - 3900129176594119380199162875*
            Zeta[3]) - 880*CA*(-248147284770494339655980494 - 
           9249739844906259578880*lm + 558677724425197977600*lm^2 + 
           206414327349629439738823125*Zeta[3]) + 
         35*(16777216*(-3896260649889539 - 2714098309502580*lm + 
             152227599123600*lm^2)*NL + 1287*NH*(-1906727211670887925462 - 
             35380740935322173440*lm + 1984425261583564800*lm^2 + 
             1592075802502575014625*Zeta[3]) + 1287*NM*
            (-35380740935322173440*lm + 1984425261583564800*lm^2 + 
             1287*(-1129332363499934458 + 921956122028316375*Zeta[3])))))/
       741927449454548059422720000, 
      -(CF*NC*(1664*CF*(13417668707823168651756902786 - 
            16547465083031440588800*lm + 167034163880263680000*lm^2 - 
            11162264067488838115516579875*Zeta[3]) - 
          31680*CA*(-23172781043563444748042234 - 525222956218428948480*lm + 
            5361590445539328000*lm^2 + 19276293022641102077004375*Zeta[3]) + 
          105*(134217728*(-435807339551621 - 217456871551920*lm + 
              2191376187000*lm^2)*NL + 1287*NH*(-1101167795051327958526 - 
              22677985421667860480*lm + 228532659683328000*lm^2 + 
              918557349322363876125*Zeta[3]) + 429*NM*
             (-3941597914118419024406 - 68033956265003581440*lm + 
              685597979049984000*lm^2 + 3178823518378245362625*Zeta[3]))))/
       1483854898909096118845440000, 
      -(CF*NC*(-121*CA*(177373514035198924302042993314 + 
            2241630398251776564264960*lm + 41925687614864621568000*lm^2 - 
            147552231325623854743111173075*Zeta[3]) + 
          2*(77*(268435456*(2906452090726889 + 1164563230210380*lm + 
                22312193904000*lm^2)*NL + 13*NM*(
                2166307196582167681140254 + 24046927826335102402560*lm + 
                460721841921589248000*lm^2 - 1749630901326903888418125*
                 Zeta[3]) + 1001*NH*(14618290863064232184646 + 
                312297763978377953280*lm + 5983400544436224000*lm^2 - 
                12181116477419392127625*Zeta[3])) + 
            9*CF*(-40857714858461986633159044498814 + 
              24147838514788689311170560*lm + 461182563763510837248000*lm^2 + 
              33989836761202602307396915871325*Zeta[3]))))/
       26907235500218276288397312000, 
      (CF*NC*(-11*CA*(6505984404275057579359827076714 + 
           43464968814304473749913600*lm + 1717669752792667914240000*lm^2 - 
           5412247405340911164631488261375*Zeta[3]) + 
         2*(10*(134217728*(91922207170240061 + 30755135174383620*lm + 
               1279763693208000*lm^2)*NL + 5148*NM*
              (121607604070346126797578 + 801842340217298616320*lm + 
               33365768313765888000*lm^2 - 98857153362044297595375*Zeta[3]) + 
             3003*NH*(65186989032149103724462 + 1374586868943940485120*lm + 
               57198459966455808000*lm^2 - 54261047955066604777125*
                Zeta[3])) + CF*(-1372339676060449681164693141018994 + 
             374086097698667796784742400*lm + 15459027775134011228160000*
              lm^2 + 1141659386256954536792740201156875*Zeta[3]))))/
       57658361786182020617994240000, 
      -(CF*NC*(945*(134217728*(99435430430338271431 + 28090380718373353380*
               lm + 1750181062573944000*lm^2)*NL + 2431*NH*
             (77794067265270398324228518 + 1550895548611715074621440*lm + 
              96629093297943478272000*lm^2 - 64689717514717595821145625*Zeta[
                3]) + 48620*NM*(21141090221805878519514134 + 
              77544777430585753731072*lm + 4831454664897173913600*lm^2 - 
              17305776330032255992351425*Zeta[3])) - 
          CA*(6227743192638202161643931451350907466 + 
            21149653971629018343356655206400*lm + 
            1220920430883444846042808320000*lm^2 - 
            5180836681836312789969430657023495375*Zeta[3]) + 
          34*CF*(-7815481503321289981776363647258525782 + 
            952904694219511718692572364800*lm + 58760876352679163713290240000*
             lm^2 + 6501755901863886019310712892043534625*Zeta[3])))/
       3324321677963217489740766904320000, 
      (CF*NC*(-4*CA*(4576691442371195789306424674153157454 + 
           7635207689200329927643732377600*lm + 
           585916141163750308876124160000*lm^2 - 
           3807355860924927681341327376662767125*Zeta[3]) + 
         136*CF*(-6355569964927077217406090935658640274 + 
           336279894882548373366453043200*lm + 28199172569378357111685120000*
            lm^2 + 5287244989387777994573491143487714875*Zeta[3]) + 
         315*(34359738368*(1951775265050969753 + 462939637306611465*lm + 
             39370629805006500*lm^2)*NL + 85085*NM*
            (96904030205704678291490302 + 186948167338919693647872*lm + 
             15898977957141754675200*lm^2 - 79769057364826039555069725*
              Zeta[3]) + 109395*NH*(145404130152493095059456*lm + 
             12365871744443586969600*lm^2 - 80223*(-100467328895039874914 + 
               83467243794630661875*Zeta[3])))))/
       6648643355926434979481533808640000, 
      -(CF*NC*(-(CA*(50610436078639330735541879644702494726278 + 
             40016990579471147533278506699980800*lm + 
             4000211639333842370921590947840000*lm^2 - 
             42103032760359124136893014487014466859625*Zeta[3])) + 
          38*CF*(-69246243685358706002082061508658559725022 + 
            1532691993414783760843261398220800*lm + 
            172257917483275508795666595840000*lm^2 + 
            57606456652142142849717376548184721446125*Zeta[3]) + 
          35*(309237645312*(3010866872945758340113 + 586709907519814758680*
               lm + 67198546229278464000*lm^2)*NL + 4199*NM*
             (44881842312511560034061235640178 + 
              43208571155667729925370019840*lm + 4948873589981340481093632000*
               lm^2 - 37091241446264058804346453732875*Zeta[3]) + 
            4199*NH*(43208571155667729925370019840*lm + 
              4948873589981340481093632000*lm^2 - 4199*(
                -663761445775149412095978142 + 551005662485707553305306125*
                 Zeta[3])))))/12800854674610362813828446426234880000, 
      (CF*NC*(-143*CA*(497806513991412839363257186248165997162 + 
           178320025966713031321192916582400*lm + 
           23670325189324577643184521216000*lm^2 - 
           414128073133674964402962252073915845375*Zeta[3]) + 
         3*(35*(17179869184*(13960702638364992265813 + 2135970638700330552120*
                lm + 341168103053566588800*lm^2)*NL + 4199*NM*
              (19303605288994029950538176292646 + 
               8739151263095167102400593920*lm + 1395861724270946639727820800*
                lm^2 - 15993672943926138124541013761625*Zeta[3]) + 
             4199*NH*(704430683980655271066393917158 + 
               8739151263095167102400593920*lm + 1395861724270946639727820800*
                lm^2 - 584373189787023970681432709625*Zeta[3])) + 
           1482*CF*(-912632760627711804162272585211245448278 + 
             8007326933797739951552043417600*lm + 
             1245806588911819875957080064000*lm^2 + 
             759225887868016510773678352603206734625*Zeta[3]))))/
       12800854674610362813828446426234880000, 
      -(CF*NC*(-52*CA*(7652394679352715691437769612566705973488146 + 
            1159955255163751373037141681713971200*lm + 
            216698840823494588532107671240704000*lm^2 - 
            6366076933494797450333870711016360074362875*Zeta[3]) + 
          5*(104*CF*(-47624795304045473058234960147202359214684054 + 
              150590160646345005762663200807976960*lm + 
              35459810316571841759799437112115200*lm^2 + 
              39619417228028605227857071939209449526247425*Zeta[3]) + 
            231*(687194767360*(96245872233395860692289 + 
                10531932894250939787616*lm + 2581281769554356188320*lm^2)*
               NL + 4199*NM*(8859221567106224058145009869682106 + 
                1723622094573923803003606794240*lm + 
                422444230797693482187934924800*lm^2 - 
                7351718948498981412186062697840375*Zeta[3]) + 
              29393*NH*(246231727796274829000515256320*lm + 
                60349175828241926026847846400*lm^2 - 4199*
                 (-6644397034884952400092163482 + 
                  5508991322763639853802034375*Zeta[3]))))))/
       51817859722822748670377551133398794240000, 
      (CF*NC*(385*(1099511627776*(263114100613674304786837 + 
             16261881209306168075640*lm + 7826015853569358244800*lm^2)*NL + 
           4199*NM*(62828856747410485885938728122183702 + 
             4258187063382751183711355535360*lm + 
             2049248733069499200632468275200*lm^2 - 
             52186356019921574869895522671250625*Zeta[3]) + 
           4199*NH*(880295543153105674060803643968922 + 
             4258187063382751183711355535360*lm + 
             2049248733069499200632468275200*lm^2 - 
             729566317180961897623029182514375*Zeta[3])) - 
         48*CA*(22520762212756904003805552284598980712846946 + 
           1271897783778454663089971574236774400*lm + 
           379596965070027426588906611539968000*lm^2 - 
           18735178295395578094452105517393791506197875*Zeta[3]) + 
         32*CF*(-2286969268946475282478880324267954075993406682 + 
           2091372221129727481845171369069772800*lm + 
           931738005171885501627316228325376000*lm^2 + 
           1902546563905719745933870338541939549010622375*Zeta[3])))/
       103635719445645497340755102266797588480000, 
      -(CF*NC*(3465*(1649267441664*(175743639666359928822168581 + 
              1243864477200032259291720*lm + 5896429297524300008073600*lm^2)*
             NL + 408595*NM*(981020895208528690618824522913777270 + 
              5020778972058948499762172657664*lm + 
              23800557673198543700211605176320*lm^2 - 
              815270913082140184681021853944326225*Zeta[3]) + 
            572033*NH*(6851370666400830197091564166347218 + 
              3586270694327820356972980469760*lm + 
              17000398337998959785865432268800*lm^2 - 
              5676561424900517744036038118398875*Zeta[3])) - 
          CA*(18366120988933139376971793936280096391990167204414 + 
            274970551605231137333650132104770066841600*lm + 
            185330163746723252440954563270329499648000*lm^2 - 
            15278907524319148280288489390159559316343144224125*Zeta[3]) + 
          782*CF*(-1723686077679724869635981580142552142308372241582 + 
            146444414166931294070022582491833958400*lm + 
            387810154317718965814599179128799232000*lm^2 + 
            1433947141936594938810020887714356176735220121125*Zeta[3])))/
       1315759094081915234238226778379262183342080000, 
      CA*CF*NC*(-1102194884207105136723568300378889610442080663263/
          59807231549177965192646671744511917424640000 + 
         (151702849855177*lm)/5212321254441100800 - (24331*lm^2)/216332480 + 
         (495118957300378148920126495*Zeta[3])/32294602485032609120256) + 
       (CF*NC*(28405*CF*(-615497788776154979367337113612523512010506034 - 
            105776131013151210547225298523389952*lm + 
            77500936656099541852081578427023360*lm^2 + 
            512037145366486222088900460503223032517045675*Zeta[3]) + 
          63*(22287*NM*(7942152960420626710954013231651768902 - 
              266799529560324620660298838179840*lm + 
              174207590090482076992264155955200*lm^2 - 
              6601728671673417066534674702360207625*Zeta[3]) + 
            2*(962072674304*(52087293554045194119721903 - 
                3090286874436296691344760*lm + 2017812512529455774932800*
                 lm^2)*NL + 37145*NH*(-80039858868097386198089651453952*
                 lm + 52262277027144623097679246786560*lm^2 - 
                7429*(-2678453849621447738581817217826 + 
                  2218759566466871282170933091475*Zeta[3]))))))/
        11961446309835593038529334348902383484928000}, 2, 22, 1]
 
CbarLSeries["v", 2, 2, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(4*CA*(59400*lm^2 - 24777*Pi^2 + 810*Pi^4 - 
            150*lm*(-1285 + 44*Pi^2) + 10*(16688 + 6294*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 6480*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              1049*PolyGamma[2, 1] - 17506*Zeta[3])) + 
          CF*(-1296625 - 777600*lm^2 - 39668*Pi^2 + 1200*Pi^4 + 
            86400*lm*(-11 + Pi^2) - 503520*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 518400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            83920*PolyGamma[2, 1] + 2015360*Zeta[3]) + 
          20*(NL*(-2365 - 2160*lm^2 - 12*Pi^2 + 60*lm*(-71 + 4*Pi^2) - 
              2880*Zeta[3]) + NM*(-2365 - 2160*lm^2 - 12*Pi^2 + 
              60*lm*(-71 + 4*Pi^2) + 240*PolyGamma[2, 1] - 2400*Zeta[3]) + 
            NH*(-33577 - 2160*lm^2 + 60*lm*(-71 + 4*Pi^2) - 
              598704*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 99784*PolyGamma[2, 
                1] + 1103888*Zeta[3]))))/7776000, 
      -(CF*NC*(-3*CA*(1188000*lm^2 - 705684*Pi^2 + 25920*Pi^4 - 
            600*lm*(-3411 + 220*Pi^2) + 5*(-1150623 - 352032*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 414720*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 60112*PolyGamma[2, 1] + 519680*Zeta[3])) + 
          2*(-50*(NH*(1707363 - 6480*lm^2 + 36*lm*(-81 + 20*Pi^2) + 
                176208*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 29368*
                 PolyGamma[2, 1] - 1734896*Zeta[3]) + 9*NL*(3219 - 
                720*lm^2 + 20*Pi^2 + 4*lm*(-81 + 20*Pi^2) - 960*Zeta[3]) + 
              9*NM*(3219 - 720*lm^2 + 20*Pi^2 + 4*lm*(-81 + 20*Pi^2) + 
                80*PolyGamma[2, 1] - 800*Zeta[3])) + 
            3*CF*(1944000*lm^2 + 200372*Pi^2 + 6720*Pi^4 - 21600*lm*(27 + 
                10*Pi^2) + 5*(601715 - 352032*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 414720*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
                60112*PolyGamma[2, 1] + 79616*Zeta[3])))))/23328000, 
      -(CF*NC*(CF*(55987200*lm^2 + 11486484*Pi^2 - 1175040*Pi^4 + 
            777600*lm*(-121 + 4*Pi^2) + 5*(20635227 + 24276288*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 29859840*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 2882624*PolyGamma[2, 1] - 76519072*Zeta[3])) + 
          10*CA*(15306165 - 1710720*lm^2 - 915408*Pi^2 + 72576*Pi^4 - 
            2160*lm*(271 + 44*Pi^2) - 6069072*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 7464960*Im[PolyLog[2, (-1)^(1/3)]]^
              2 + 720656*PolyGamma[2, 1] + 16373824*Zeta[3]) + 
          240*(3*NL*(-28955 + 4320*lm^2 + 2508*Pi^2 + 60*lm*(-67 + 4*Pi^2) - 
              2880*Zeta[3]) + 3*NM*(-48935 + 4320*lm^2 + 4668*Pi^2 + 
              60*lm*(-67 + 4*Pi^2) + 600*PolyGamma[2, 1] - 1680*Zeta[3]) + 
            NH*(-2644341 + 12960*lm^2 + 180*lm*(-67 + 4*Pi^2) - 
              5906352*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1034284*PolyGamma[
                2, 1] + 12903128*Zeta[3]))))/69984000, 
      -(CF*NC*(97977600*(-10*CA*(76 + 33*lm) + 9*CF*(227 + 120*lm) + 
            20*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          1959552000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          75600*Log[x]*(16*(-2*(27*NM*(122 + 204*lm + 45*lm^2 + 30*Pi^2) + 
                27*NL*(392 + 204*lm + 45*lm^2 + 30*Pi^2) + 
                NH*(214710 + 5508*lm + 1215*lm^2 - 122200*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 3*CF*(-68361 - 55161*lm - 
                14580*lm^2 + 351*Pi^2 + 5080*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 9720*Zeta[3])) + 3*CA*(767505 + 413856*lm + 
              71280*lm^2 + 4356*Pi^2 - 40640*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 77760*Zeta[3])) - 
          21*CA*(1122660000*lm^2 - 256264884*Pi^2 + 35560000*Sqrt[3]*Pi^3 + 
            12457800*Pi^4 - 243000*lm*(-13789 + 132*Pi^2) + 
            27432000*Sqrt[3]*Pi*Log[3]^2 + 15*(33966009 - 139877184*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 193622400*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 87782400*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 27676976*PolyGamma[2, 1] + 
              172955584*Zeta[3])) + 10*(3*CF*(2571912000*lm^2 - 
              132966900*Pi^2 + 49784000*Sqrt[3]*Pi^3 + 10909080*Pi^4 - 
              24494400*lm*(-101 + 3*Pi^2) + 38404800*Sqrt[3]*Pi*Log[3]^2 + 
              21*(204458643 - 139877184*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                193622400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 87782400*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 27676976*
                 PolyGamma[2, 1] + 66434752*Zeta[3])) - 
            70*(729*NL*(465 - 8400*lm^2 - 4452*Pi^2 + 20*lm*(-719 + 
                  12*Pi^2) - 25920*Zeta[3]) + 729*NM*(51201 - 8400*lm^2 - 
                3492*Pi^2 + 20*lm*(-719 + 12*Pi^2) - 1520*PolyGamma[2, 1] + 
                5600*Zeta[3]) - NH*(-1045783521 + 6123600*lm^2 + 
                34216000*Sqrt[3]*Pi^3 - 14580*lm*(-719 + 12*Pi^2) - 
                206235504*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1266969600*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                26395200*Sqrt[3]*Pi*Log[3]^2 + 52498008*PolyGamma[2, 1] + 
                212771376*Zeta[3])))))/4408992000, 
      (CF*NC*(-11128678785*CF + 2608653600*CF*lm - 34610587200*CF*lm^2 + 
         18777594150*NM - 1297182600*lm*NM - 1922810400*lm^2*NM + 
         4665757950*NL - 1297182600*lm*NL - 1922810400*lm^2*NL + 
         249079771710*NH - 1297182600*lm*NH - 1922810400*lm^2*NH + 
         2541011472*CF*Pi^2 - 220449600*CF*lm*Pi^2 - 2436580440*NM*Pi^2 - 
         12247200*lm*NM*Pi^2 - 1371074040*NL*Pi^2 - 12247200*lm*NL*Pi^2 - 
         12247200*lm*NH*Pi^2 - 2029678000*Sqrt[3]*CF*Pi^3 - 
         5198900000*Sqrt[3]*NH*Pi^3 + 35789040*CF*Pi^4 - 
         19317401040*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         304115202720*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
         87885907200*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 - 75156076800*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 192507840000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1565751600*Sqrt[3]*CF*Pi*
          Log[3]^2 - 4010580000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         97977600*(36*CF*(22 + 15*lm) - 5*CA*(76 + 33*lm) + 
           5*(13*NM + 6*lm*NM + 10*NL + 6*lm*NL + 6*lm*NH))*Log[x]^2 - 
         979776000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         97868680*CF*PolyGamma[2, 1] - 968753520*NM*PolyGamma[2, 1] - 
         58509514560*NH*PolyGamma[2, 1] - 14*CA*(-755389800*lm^2 + 
           27013581*Pi^2 - 72488500*Sqrt[3]*Pi^3 + 1978020*Pi^4 - 
           36450*lm*(40357 + 132*Pi^2) - 55919700*Sqrt[3]*Pi*Log[3]^2 - 
           10*(-356372451 + 68990718*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             313878240*Im[PolyLog[2, (-1)^(1/3)]]^2 + 268414560*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             349531*PolyGamma[2, 1] - 414247738*Zeta[3])) + 
         153464982160*CF*Zeta[3] + 5557779360*NM*Zeta[3] - 
         5731689600*NL*Zeta[3] - 607984782720*NH*Zeta[3] - 
         37800*Log[x]*(CA*(-2123301 - 1059804*lm - 213840*lm^2 + 45576*Pi^2 + 
             331376*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 233280*Zeta[3]) + 
           2*(2*(27*NL*(2479 + 1326*lm + 360*lm^2 + 240*Pi^2) + 27*NM*
                (-371 + 1326*lm + 360*lm^2 + 420*Pi^2) + NH*(748479 + 
                 35802*lm + 9720*lm^2 - 424400*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) + CF*(1277391 + 1026432*lm + 349920*lm^2 - 
               61452*Pi^2 - 331376*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               233280*Zeta[3])))))/2204496000, 
      -(CF*NC*(-(CA*(6971 + 3300*lm)) + 3*CF*(6371 + 3600*lm) + 
           4*(400*NM + 150*lm*NM + 225*NL + 150*lm*NL + 4*NH + 
             150*lm*NH))*Log[x]^2)/30 - 
       (20*CF*NC*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3)/3 + 
       (CF*NC*Log[x]*(-2*(2025*NL*(7493 + 3522*lm + 720*lm^2 + 600*Pi^2) + 
            405*NM*(23131 + 17610*lm + 3600*lm^2 + 840*Pi^2) + 
            NH*(277562649 + 7132050*lm + 1458000*lm^2 - 157553600*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) + 135*CF*(-2070665 - 1610280*lm - 
            388800*lm^2 + 34794*Pi^2 + 258904*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 259200*Zeta[3]) - 
          135*CA*(-1495069 - 732330*lm - 118800*lm^2 + 1257*Pi^2 + 
            129452*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 129600*Zeta[3])))/
        437400 - (CF*NC*(3*CF*(246903552000*lm^2 - 40425640704*Pi^2 + 
            14272083000*Sqrt[3]*Pi^3 + 2261377440*Pi^4 - 293932800*lm*
             (-913 + 15*Pi^2) + 11009892600*Sqrt[3]*Pi*Log[3]^2 - 
            35*(-4992840603 + 9631110912*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              14226347520*Im[PolyLog[2, (-1)^(1/3)]]^2 - 15099281280*Sqrt[
                3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 2372375488*
               PolyGamma[2, 1] - 3787509824*Zeta[3])) - 
          12*CA*(18860688000*lm^2 - 5546652876*Pi^2 + 1784010375*Sqrt[3]*
             Pi^3 + 331660980*Pi^4 - 2041200*lm*(-28733 + 165*Pi^2) + 
            1376236575*Sqrt[3]*Pi*Log[3]^2 - 70*(202234743 + 601944432*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] - 889146720*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 943705080*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 148273468*PolyGamma[2, 1] - 
              674201012*Zeta[3])) - 
          112*(-(NH*(-84420142281 + 367416000*lm^2 + 3446485000*Sqrt[3]*
                Pi^3 - 437400*lm*(-1543 + 15*Pi^2) - 16973272200*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 127618416000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2658717000*Sqrt[3]*Pi*
                Log[3]^2 + 4635363275*PolyGamma[2, 1] - 2696537450*
                Zeta[3])) + 54675*NL*(3853 - 6720*lm^2 - 5380*Pi^2 + 
              8*lm*(-1543 + 15*Pi^2) - 37440*Zeta[3]) + 
            54675*NM*(66625 - 6720*lm^2 - 2950*Pi^2 + 8*lm*(-1543 + 
                15*Pi^2) - 1835*PolyGamma[2, 1] + 62570*Zeta[3]))))/
        6613488000, (CF*NC*(-24494400*(-21*CA*(10083 + 3520*lm) + 
           4*(5*CF*(22919 + 12096*lm) + 4*(3493*NM + 840*lm*NM + 1200*NL + 
               840*lm*NL + 27*NH + 840*lm*NH)))*Log[x]^2 - 
         7838208000*(109*CA + 844*CF - 38*NM - 28*NL)*Log[x]^3 - 
         3*CF*(539660620800*lm^2 - 62610256368*Pi^2 + 63522816000*Sqrt[3]*
            Pi^3 + 3757440960*Pi^4 + 195955200*lm*(341 + 6*Pi^2) + 
           49003315200*Sqrt[3]*Pi*Log[3]^2 + 35*(2567427705 + 
             5233640256*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             45853516800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 67204546560*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2745879104*
              PolyGamma[2, 1] - 94714878848*Zeta[3])) + 
         24*CA*(20612037600*lm^2 - 1843751079*Pi^2 + 3970176000*Sqrt[3]*
            Pi^3 + 228308220*Pi^4 + 340200*lm*(130055 + 132*Pi^2) + 
           3062707200*Sqrt[3]*Pi*Log[3]^2 + 140*(-660954546 + 
             81775629*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             716461200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1050071040*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 42904361*
              PolyGamma[2, 1] - 1157591174*Zeta[3])) + 
         15120*Log[x]*(-16*(405*NL*(9279 + 4343*lm + 1080*lm^2 + 920*Pi^2) + 
             135*NM*(7858 + 13029*lm + 3240*lm^2 + 4800*Pi^2) + 
             NH*(38344449 + 1758915*lm + 437400*lm^2 - 21604400*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) + 45*CF*(-10787961 - 
             9157536*lm - 2799360*lm^2 + 109512*Pi^2 + 3457024*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 1866240*Zeta[3]) + 
           180*CA*(2292009 + 1132074*lm + 213840*lm^2 + 9108*Pi^2 - 
             432128*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 233280*Zeta[3])) - 
         224*(1215*NM*(-2948630 + 330480*lm^2 + 666204*Pi^2 + 
             60*lm*(4813 + 12*Pi^2) + 428661*PolyGamma[2, 1] - 
             3557718*Zeta[3]) + 14580*NL*(-85790 + 27540*lm^2 + 25852*Pi^2 + 
             5*lm*(4813 + 12*Pi^2) + 164880*Zeta[3]) + 
           NH*(-61544736774 + 401533200*lm^2 + 1890385000*Sqrt[3]*Pi^3 + 
             72900*lm*(4813 + 12*Pi^2) - 55920236880*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 69998256000*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] + 1458297000*Sqrt[3]*Pi*Log[3]^2 + 
             11635066295*PolyGamma[2, 1] + 97775098990*Zeta[3]))))/
       19840464000, (5174797*CF^2*NC)/39366 - (12799*CF^2*lm*NC)/27 - 
       420*CF^2*lm^2*NC + (12488993*CF*NM*NC)/29160 - 
       (10652*CF*lm*NM*NC)/243 - (70*CF*lm^2*NM*NC)/3 + 
       (514729*CF*NC*NL)/9720 - (10652*CF*lm*NC*NL)/243 - 
       (70*CF*lm^2*NC*NL)/3 + (150543015018869*CF*NC*NH)/20253807000 - 
       (10652*CF*lm*NC*NH)/243 - (70*CF*lm^2*NC*NH)/3 + 
       (17188447*CF^2*NC*Pi^2)/136080 + (50*CF^2*lm*NC*Pi^2)/9 + 
       (160241*CF*NM*NC*Pi^2)/4860 + (25*CF*lm*NM*NC*Pi^2)/81 - 
       (11945*CF*NC*NL*Pi^2)/486 + (25*CF*lm*NC*NL*Pi^2)/81 + 
       (25*CF*lm*NC*NH*Pi^2)/81 - (128033885*CF^2*NC*Pi^3)/
        (944784*Sqrt[3]) - (172560185*CF*NC*NH*Pi^3)/(177147*Sqrt[3]) - 
       (325*CF^2*NC*Pi^4)/54 + (818584387*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (393660*Sqrt[3]) + (1297249591*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (295245*Sqrt[3]) - (3080*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (3658111*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (729*Sqrt[3]) - (78884656*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (3658111*CF^2*NC*Pi*Log[3]^2)/(34992*Sqrt[3]) - 
       (4930291*CF*NC*NH*Pi*Log[3]^2)/(6561*Sqrt[3]) - 
       (CF*NC*(-21*CA*(412451 + 203500*lm) + 35*CF*(693263 + 399600*lm) - 
          455084*NM + 777000*lm*NM + 1098300*NL + 777000*lm*NL + 
          46332*NH + 777000*lm*NH)*Log[x]^2)/5670 - 
       (10*CF*NC*(5129*CA + 22472*CF - 4504*NM - 740*NL)*Log[x]^3)/81 - 
       (1757631341*CF^2*NC*PolyGamma[2, 1])/8857350 + 
       (136361*CF*NM*NC*PolyGamma[2, 1])/3240 - 
       (1737280121*CF*NC*NH*PolyGamma[2, 1])/4251528 + 
       (CF*NC*Log[x]*(2*(-39302089785*NL - 16507269450*lm*NL - 
            3214890000*lm^2*NL - 682391437737*NH - 16507269450*lm*NH - 
            3214890000*lm^2*NH - 3274425000*NL*Pi^2 - 
            19845*NM*(1236659 + 831810*lm + 162000*lm^2 - 452280*Pi^2) + 
            386534814400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            735*CF*(-442791984 - 345210660*lm - 78732000*lm^2 + 
              9591453*Pi^2 + 73162220*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              52488000*Zeta[3])) - 735*CA*(-653669490 - 308283570*lm - 
            48114000*lm^2 + 2301129*Pi^2 + 73162220*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 52488000*Zeta[3])))/192893400 - 
       (1456038157*CF^2*NC*Zeta[3])/8857350 + (805001*CF*NM*NC*Zeta[3])/
        1620 - (5600*CF*NC*NL*Zeta[3])/27 + (1991887303*CF*NC*NH*Zeta[3])/
        2125764 + (CA*CF*NC*(127309644000*lm^2 - 57893623209*Pi^2 + 
          22405929875*Sqrt[3]*Pi^3 + 3230199000*Pi^4 - 
          2041200*lm*(-196552 + 825*Pi^2) + 17284574475*Sqrt[3]*Pi*Log[3]^2 + 
          14*(-23332084785 - 24557531610*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            36374184000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 59261398200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 7030525364*
             PolyGamma[2, 1] + 24299403748*Zeta[3])))/992023200, 
      (CF*NC*(-771573600*(-21*CA*(1220673 + 295130*lm) + 
           7*CF*(7742231 + 2897640*lm) + 7940744*NM + 1126860*lm*NM + 
           1485645*NL + 1126860*lm*NL + 80568*NH + 1126860*lm*NH)*
          Log[x]^2 - 108020304000*(4805*CA + 240545*CF - 10876*NM - 
           5366*NL)*Log[x]^3 - 49*CF*(48480173784000*lm^2 + 
           10010590551270*Pi^2 + 8991238952500*Sqrt[3]*Pi^3 + 
           672343723800*Pi^4 + 413343000*lm*(22927 + 120*Pi^2) + 
           6936098620500*Sqrt[3]*Pi*Log[3]^2 + 7*(-114651937197 + 
             1703672100600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             23919096528000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 47561819112000*
              Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             4630680773000*PolyGamma[2, 1] - 61545443841200*Zeta[3])) + 
         49*CA*(14813386434000*lm^2 + 7128624094875*Pi^2 + 
           4495619476250*Sqrt[3]*Pi^3 + 333967365900*Pi^4 + 
           57408750*lm*(572371 + 264*Pi^2) + 3468049310250*Sqrt[3]*Pi*
            Log[3]^2 + 7*(-10362876613911 + 851836050300*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 11959548264000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 23780909556000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2315340386500*
              PolyGamma[2, 1] - 25112733553000*Zeta[3])) - 
         3780*Log[x]*(6*(297675*NL*(313339 + 128180*lm + 30240*lm^2 + 31544*
                Pi^2) + 15876*NM*(10336246 + 2403375*lm + 567000*lm^2 + 
               793650*Pi^2) + 2*NH*(445996251453 + 19077990750*lm + 
               4500846000*lm^2 - 250204682000*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]])) - 98*CA*(39507304866 + 16706310750*lm + 
             3031182000*lm^2 + 1785528765*Pi^2 - 7339786900*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 3306744000*Zeta[3]) + 
           49*CF*(98810016189 + 69218550000*lm + 19840464000*lm^2 + 
             5289784380*Pi^2 - 29359147600*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 13226976000*Zeta[3])) - 
         3*(500094*NM*(-951597133 + 87966000*lm^2 + 368040900*Pi^2 + 
             750*lm*(110893 + 120*Pi^2) + 194575680*PolyGamma[2, 1] - 
             1840400640*Zeta[3]) + 18753525*NL*(-11918541 + 2345760*lm^2 + 
             2746360*Pi^2 + 20*lm*(110893 + 120*Pi^2) + 22682880*Zeta[3]) + 
           2*NH*(-4234161912808941 + 21995634402000*lm^2 + 
             153250367725000*Sqrt[3]*Pi^3 + 187535250*lm*(110893 + 120*
                Pi^2) - 3236024624120400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             5674642187760000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             118221712245000*Sqrt[3]*Pi*Log[3]^2 + 713118481856760*
              PolyGamma[2, 1] + 4939957418993520*Zeta[3]))))/8749644624000, 
      (34600189225079*CF^2*NC)/22674816000 - (21707*CF^2*lm*NC)/16 - 
       (2365*CF^2*lm^2*NC)/2 + (38971679*CF*NM*NC)/36000 - 
       (35897*CF*lm*NM*NC)/288 - (2365*CF*lm^2*NM*NC)/36 + 
       (16960223*CF*NC*NL)/51840 - (35897*CF*lm*NC*NL)/288 - 
       (2365*CF*lm^2*NC*NL)/36 + (2751539878335173*CF*NC*NH)/97218273600 - 
       (35897*CF*lm*NC*NH)/288 - (2365*CF*lm^2*NC*NH)/36 + 
       (42370487*CF^2*NC*Pi^2)/60480 + (25*CF^2*lm*NC*Pi^2)/2 + 
       (1953553*CF*NM*NC*Pi^2)/2160 + (25*CF*lm*NM*NC*Pi^2)/36 - 
       (36935*CF*NC*NL*Pi^2)/432 + (25*CF*lm*NC*NL*Pi^2)/36 + 
       (25*CF*lm*NC*NH*Pi^2)/36 - (5047230895*CF^2*NC*Pi^3)/
        (8503056*Sqrt[3]) - (1802175445*CF*NC*NH*Pi^3)/(472392*Sqrt[3]) - 
       (7495*CF^2*NC*Pi^4)/324 + (5024701267*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(708588*Sqrt[3]) + 
       (58339429279*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(3542940*Sqrt[3]) - 
       (10180*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (144206597*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6561*Sqrt[3]) - (102981454*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (144206597*CF^2*NC*Pi*Log[3]^2)/(314928*Sqrt[3]) - 
       (51490727*CF*NC*NH*Pi*Log[3]^2)/(17496*Sqrt[3]) - 
       (CF*NC*(-7*CA*(18958169 + 10959300*lm) + 
          2*(14*CF*(14010481 + 8966700*lm) + 126*(-821201 + 55350*lm)*NM + 
            15*(634347*NL + 464940*lm*NL + 43228*NH + 464940*lm*NH)))*
         Log[x]^2)/22680 - (CF*NC*(256388*CA + 1234411*CF - 
          54*(9652*NM + 615*NL))*Log[x]^3)/81 - 
       (71859696607*CF^2*NC*PolyGamma[2, 1])/106288200 + 
       (368047*CF*NM*NC*PolyGamma[2, 1])/360 - 
       (73171646807*CF*NC*NH*PolyGamma[2, 1])/47829690 + 
       (CA*CF*NC*(1032299341920000*lm^2 - 912941305019280*Pi^2 + 
          282644930120000*Sqrt[3]*Pi^3 + 34632632160000*Pi^4 - 
          54561276000*lm*(-59977 + 200*Pi^2) + 218040374664000*Sqrt[3]*Pi*
           Log[3]^2 - 21*(221302340452527 + 160790440544000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 230829626880000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 498377999232000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 45990205828480*
             PolyGamma[2, 1] - 145200892194560*Zeta[3])))/2857026816000 + 
       (CF*NC*Log[x]*(2*(36*(23814*NM*(7644757 - 3343350*lm - 630000*lm^2 + 
                7784700*Pi^2) - 5*(11907*NL*(3555217 + 1337340*lm + 
                  252000*lm^2 + 305400*Pi^2) + 2*NH*(356838317403 + 
                  7961853690*lm + 1500282000*lm^2 - 201843649840*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]]))) + 49*CF*(-1015224495753 - 
              904111048800*lm - 198404640000*lm^2 + 40859166960*Pi^2 + 
              230730555200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              132269760000*Zeta[3])) - 49*CA*(-1594641165573 - 
            797762487600*lm - 121247280000*lm^2 + 19874347920*Pi^2 + 
            230730555200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            132269760000*Zeta[3])))/9258883200 - 
       (15663091357*CF^2*NC*Zeta[3])/53144100 + (426847*CF*NM*NC*Zeta[3])/
        180 - (2570*CF*NC*NL*Zeta[3])/3 + (115867231303*CF*NC*NH*Zeta[3])/
        23914845, (7444505831470526257*CF^2*NC)/3499857849600000 - 
       (244021*CF^2*lm*NC)/1500 - (3532*CF^2*lm^2*NC)/5 + 
       (111315380891*CF*NM*NC)/138915000 - (1038721*CF*lm*NM*NC)/27000 - 
       (1766*CF*lm^2*NM*NC)/45 + (171286871*CF*NC*NL)/540000 - 
       (1038721*CF*lm*NC*NL)/27000 - (1766*CF*lm^2*NC*NL)/45 + 
       (3453048386484353*CF*NC*NH)/364568526000 - (1038721*CF*lm*NC*NH)/
        27000 - (1766*CF*lm^2*NC*NH)/45 - (1784814317*CF^2*NC*Pi^2)/
        1008000 - (2*CF^2*lm*NC*Pi^2)/5 - (1634401*CF*NM*NC*Pi^2)/2700 - 
       (CF*lm*NM*NC*Pi^2)/45 - (148801*CF*NC*NL*Pi^2)/2700 - 
       (CF*lm*NC*NL*Pi^2)/45 - (CF*lm*NC*NH*Pi^2)/45 - 
       (13246683296*CF^2*NC*Pi^3)/(23914845*Sqrt[3]) - 
       (3591053669*CF*NC*NH*Pi^3)/(3188646*Sqrt[3]) - 
       (4681*CF^2*NC*Pi^4)/324 - (289910829199*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(797161500*Sqrt[3]) + 
       (51590556071*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) - 
       (41804*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (30278133248*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1476225*Sqrt[3]) - (4104061336*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(98415*Sqrt[3]) - 
       (1892383328*CF^2*NC*Pi*Log[3]^2)/(4428675*Sqrt[3]) - 
       (513007667*CF*NC*NH*Pi*Log[3]^2)/(590490*Sqrt[3]) - 
       (CF*NC*(-10*CA*(2091576439 + 252640080*lm) + 
          CF*(43033198193 + 8268220800*lm) + 
          240*(18*(1936967 + 106330*lm)*NM + 21*(114493 + 91140*lm)*NL + 
            620*(338 + 3087*lm)*NH))*Log[x]^2)/1134000 + 
       (CF*NC*(4676770*CA - 39740287*CF + 2520*(40*NM + 217*NL))*Log[x]^3)/
        2025 - (2768900851949*CF^2*NC*PolyGamma[2, 1])/1434890700 - 
       (134483*CF*NM*NC*PolyGamma[2, 1])/900 - 
       (35547899993*CF*NC*NH*PolyGamma[2, 1])/23914845 + 
       (CA*CF*NC*(-6958423154774594997 + 679882385863296000*lm^2 + 
          2915414962592766480*Pi^2 + 290791191713792000*Sqrt[3]*Pi^3 + 
          22697939210486400*Pi^4 + 58330964160*lm*(26260331 + 6600*Pi^2) + 
          190923675677293440*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          4389241726340352000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          10767582413173555200*Sqrt[3]*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]] + 224324633607782400*Sqrt[3]*Pi*
           Log[3]^2 + 3039145575099222400*PolyGamma[2, 1] - 
          11831630197325612800*Zeta[3]))/3149872064640000 + 
       (12847241498831*CF^2*NC*Zeta[3])/1434890700 + 
       (700717*CF*NM*NC*Zeta[3])/450 - (8312*CF*NC*NL*Zeta[3])/15 - 
       (207999253114*CF*NC*NH*Zeta[3])/23914845 - 
       (CF*NC*Log[x]*(480*(964467*NL*(4091833 + 1475340*lm + 336000*lm^2 + 
              415800*Pi^2) + 13122*NM*(2132039807 + 108437490*lm + 
              24696000*lm^2 + 81099900*Pi^2) + 10*NH*(3594545907945 + 
              142291674378*lm + 32406091200*lm^2 - 2010990054640*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) - 10*CA*(2146059920310321 + 
            484534486789920*lm + 85552080768000*lm^2 + 205972832756880*Pi^2 - 
            237380564664320*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            93329542656000*Zeta[3]) + CF*(33806176011704193 + 
            10194085956499200*lm + 2799886279680000*lm^2 + 3804641638182000*
             Pi^2 - 4747611293286400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            1866590853120000*Zeta[3])))/2083248720000, 
      (5328575017681590529*CF^2*NC)/1749928924800000 - 
       (1284287*CF^2*lm*NC)/400 - (5551*CF^2*lm^2*NC)/2 - 
       (129036871247*CF*NM*NC)/9261000 - (2116937*CF*lm*NM*NC)/7200 - 
       (5551*CF*lm^2*NM*NC)/36 + (38550403*CF*NC*NL)/28800 - 
       (2116937*CF*lm*NC*NL)/7200 - (5551*CF*lm^2*NC*NL)/36 + 
       (1523166121101176397779*CF*NC*NH)/17468665491816000 - 
       (2116937*CF*lm*NC*NH)/7200 - (5551*CF*lm^2*NC*NH)/36 + 
       (63700281019*CF^2*NC*Pi^2)/12474000 + (49*CF^2*lm*NC*Pi^2)/2 + 
       (27077441*CF*NM*NC*Pi^2)/2160 + (49*CF*lm*NM*NC*Pi^2)/36 - 
       (515459*CF*NC*NL*Pi^2)/2160 + (49*CF*lm*NC*NL*Pi^2)/36 + 
       (49*CF*lm*NC*NH*Pi^2)/36 - (1506197830109*CF^2*NC*Pi^3)/
        (765275040*Sqrt[3]) - (1368039842575*CF*NC*NH*Pi^3)/
        (114791256*Sqrt[3]) - (2231761*CF^2*NC*Pi^4)/32400 + 
       (64046349865093*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (3188646000*Sqrt[3]) + (4815158579941*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(95659380*Sqrt[3]) - 
       (137123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (215171118587*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2952450*Sqrt[3]) - (78173705290*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (215171118587*CF^2*NC*Pi*Log[3]^2)/(141717600*Sqrt[3]) - 
       (39086852645*CF*NC*NH*Pi*Log[3]^2)/(4251528*Sqrt[3]) - 
       (CF*NC*(-11*CA*(766464137 + 2631598200*lm) + 
          22*CF*(2959286699 + 4306251600*lm) + 
          180*(22*(-90804121 + 1329090*lm)*NM + 385*(101287 + 75948*lm)*
             NL + 4*(907048 + 7309995*lm)*NH))*Log[x]^2)/2494800 - 
       (CF*NC*(6191218*CA + 22424969*CF - 90*(269744*NM + 6329*NL))*
         Log[x]^3)/405 - (1763564710643*CF^2*NC*PolyGamma[2, 1])/2869781400 + 
       (541409*CF*NM*NC*PolyGamma[2, 1])/40 - 
       (1987421828713*CF*NC*NH*PolyGamma[2, 1])/430467210 - 
       (513121936889*CF^2*NC*Zeta[3])/358722675 + (203489*CF*NM*NC*Zeta[3])/
        20 - (8338*CF*NC*NL*Zeta[3])/3 + (3665138765177*CF*NC*NH*Zeta[3])/
        215233605 + (CA*CF*NC*(-124812240116398945371 + 26713102519303200000*
           lm^2 - 77023314392705503200*Pi^2 + 10332517114547740000*Sqrt[3]*
           Pi^3 + 1119138364465128000*Pi^4 - 2187411156000*lm*
           (-38829107 + 107800*Pi^2) - 105445910417889115200*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 143973302373210240000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 382598348012967744000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 7970798916936828000*
           Sqrt[3]*Pi*Log[3]^2 + 9678443132008784000*PolyGamma[2, 1] + 
          107158553162715712000*Zeta[3]))/31498720646400000 + 
       CF*Log[x]*((2670634471*NM*NC)/52920 - (106519*lm*NM*NC)/60 - 
         (980*lm^2*NM*NC)/3 - (2262293*NC*NL)/432 - (106519*lm*NC*NL)/60 - 
         (980*lm^2*NC*NL)/3 - (54674798025693757*NC*NH)/630182737800 - 
         (106519*lm*NC*NH)/60 - (980*lm^2*NC*NH)/3 + (87151*NM*NC*Pi^2)/
          6 - (921*NC*NL*Pi^2)/2 + (78173705290*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-2296957929342761/347208120000 - (275457*lm)/10 - 5880*lm^2 + 
           (57759763*Pi^2)/16200 + (215171118587*Im[PolyLog[2, (-1)^(1/3)]])/
            (8857350*Sqrt[3]) - 3920*Zeta[3]) + 
         CA*NC*(8689017314914481/694416240000 + (1446109*lm)/120 + 
           (5390*lm^2)/3 - (46328051*Pi^2)/32400 - 
           (215171118587*Im[PolyLog[2, (-1)^(1/3)]])/(17714700*Sqrt[3]) + 
           1960*Zeta[3])), (50921182200694591379*CF^2*NC)/1259948825856000 - 
       (21162199*CF^2*lm*NC)/54000 - (15673*CF^2*lm^2*NC)/10 + 
       (568985006080079*CF*NM*NC)/67512690000 - (84637849*CF*lm*NM*NC)/
        972000 - (15673*CF*lm^2*NM*NC)/180 + (61290059027*CF*NC*NL)/
        58320000 - (84637849*CF*lm*NC*NL)/972000 - (15673*CF*lm^2*NC*NL)/
        180 + (680853101121399003967*CF*NC*NH)/26202998237724000 - 
       (84637849*CF*lm*NC*NH)/972000 - (15673*CF*lm^2*NC*NH)/180 - 
       (690936091609*CF^2*NC*Pi^2)/27216000 - (49*CF^2*lm*NC*Pi^2)/90 - 
       (800507099*CF*NM*NC*Pi^2)/97200 - (49*CF*lm*NM*NC*Pi^2)/1620 - 
       (1540651*CF*NC*NL*Pi^2)/10800 - (49*CF*lm*NC*NL*Pi^2)/1620 - 
       (49*CF*lm*NC*NH*Pi^2)/1620 - (5582327987467*CF^2*NC*Pi^3)/
        (3443737680*Sqrt[3]) - (1127093280523*CF*NC*NH*Pi^3)/
        (344373768*Sqrt[3]) - (341509*CF^2*NC*Pi^4)/8100 - 
       (735205745747*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1793613375*Sqrt[3]) + (14146876168927*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(286978140*Sqrt[3]) - 
       (34804*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (797475426781*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (13286025*Sqrt[3]) - (322026651578*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (797475426781*CF^2*NC*Pi*Log[3]^2)/(637729200*Sqrt[3]) - 
       (161013325789*CF*NC*NH*Pi*Log[3]^2)/(63772920*Sqrt[3]) - 
       (CF*NC*(-33*CA*(200905338427 + 8070724200*lm) + 
          33*CF*(405711112253 + 26413279200*lm) + 
          20*(22*(8484828217 + 110055330*lm)*NM + 693*(4250969 + 3493820*lm)*
             NL + 10*(34895983 + 242121726*lm)*NH))*Log[x]^2)/37422000 + 
       (CF*NC*(79947627*CA - 272553236*CF - 32716900*NM + 1746910*NL)*
         Log[x]^3)/2025 - (1082820423146239*CF^2*NC*PolyGamma[2, 1])/
        51656065200 - (3285113*CF*NM*NC*PolyGamma[2, 1])/1800 - 
       (10044082229951*CF*NC*NH*PolyGamma[2, 1])/2582803260 + 
       (CA*CF*NC*(-816674280927724158327 + 16970231048754060000*lm^2 + 
          453647925261805724100*Pi^2 + 9573692498505905000*Sqrt[3]*Pi^3 + 
          746163131301252000*Pi^4 + 18228426300*lm*(2115895139 + 
            323400*Pi^2) + 2420885479595721600*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 123331665754946880000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 354500156516104368000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 7385419927418841000*
           Sqrt[3]*Pi*Log[3]^2 + 371407405139159977000*PolyGamma[2, 1] - 
          448163148151852126000*Zeta[3]))/35436060727200000 + 
       (151078549505821*CF^2*NC*Zeta[3])/5165606520 + 
       (9389287*CF*NM*NC*Zeta[3])/900 - (75854*CF*NC*NL*Zeta[3])/45 - 
       (25362522555419*CF*NC*NH*Zeta[3])/1291401630 + 
       CF*Log[x]*((-4457914855621*NM*NC)/53581500 - (2383241*lm*NM*NC)/
          2700 - 196*lm^2*NM*NC - (445404307*NC*NL)/162000 - 
         (2383241*lm*NC*NL)/2700 - 196*lm^2*NC*NL - 
         (45580467425855557*NC*NH)/1890548213400 - (2383241*lm*NC*NH)/
          2700 - 196*lm^2*NC*NH - (3910913*NM*NC*Pi^2)/810 - 
         (227611*NC*NL*Pi^2)/810 + (322026651578*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-1123490185908627121/6249746160000 - (1986341*lm)/150 - 
           3528*lm^2 - (357662623*Pi^2)/16200 + 
           (797475426781*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) - 
           2352*Zeta[3]) + CA*NC*(300155735043860053/3124873080000 + 
           (33624451*lm)/5400 + 1078*lm^2 + (15215209*Pi^2)/1350 - 
           (797475426781*Im[PolyLog[2, (-1)^(1/3)]])/(79716150*Sqrt[3]) + 
           1176*Zeta[3])), (-2640027392738667613*CF^2*NC)/52497867744000 - 
       (18008549*CF^2*lm*NC)/2700 - 5740*CF^2*lm^2*NC - 
       (179670197964421*CF*NM*NC)/675126900 - (29632049*CF*lm*NM*NC)/
        48600 - (2870*CF*lm^2*NM*NC)/9 + (621578591*CF*NC*NL)/145800 - 
       (29632049*CF*lm*NC*NL)/48600 - (2870*CF*lm^2*NC*NL)/9 + 
       (3315403353753454056054881*CF*NC*NH)/14391996782069907000 - 
       (29632049*CF*lm*NC*NH)/48600 - (2870*CF*lm^2*NC*NH)/9 + 
       (67316995927*CF^2*NC*Pi^2)/1247400 + (392*CF^2*lm*NC*Pi^2)/9 + 
       (176376218*CF*NM*NC*Pi^2)/1215 + (196*CF*lm*NM*NC*Pi^2)/81 - 
       (463099*CF*NC*NL*Pi^2)/810 + (196*CF*lm*NC*NL*Pi^2)/81 + 
       (196*CF*lm*NC*NH*Pi^2)/81 - (207015920027*CF^2*NC*Pi^3)/
        (38263752*Sqrt[3]) - (151776176615*CF*NC*NH*Pi^3)/
        (4782969*Sqrt[3]) - (139867*CF^2*NC*Pi^4)/810 + 
       (23815483267321*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (478296900*Sqrt[3]) + (1905987602608*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(14348907*Sqrt[3]) - 
       21336*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (59147405722*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (295245*Sqrt[3]) - (69383395024*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (29573702861*CF^2*NC*Pi*Log[3]^2)/(7085880*Sqrt[3]) - 
       (4336462189*CF*NC*NH*Pi*Log[3]^2)/(177147*Sqrt[3]) - 
       (CF*NC*(-4719*CA*(-5874363331 + 851361000*lm) + 
          50*(429*CF*(-2271398483 + 612979920*lm) + 
            2*(143*(-14662055621 + 51081660*lm)*NM + 45045*(212915 + 
                162164*lm)*NL + (1112290547 + 7304677380*lm)*NH)))*
         Log[x]^2)/121621500 - (CF*NC*(213607773*CA + 137757830*CF - 
          1132896200*NM - 8108200*NL)*Log[x]^3)/2025 + 
       (21076372623652*CF^2*NC*PolyGamma[2, 1])/1076168025 + 
       (80880287*CF*NM*NC*PolyGamma[2, 1])/540 - 
       (6173377316843*CF*NC*NH*PolyGamma[2, 1])/516560652 - 
       (24098316022156*CF^2*NC*Zeta[3])/1076168025 + 
       (15859727*CF*NM*NC*Zeta[3])/270 - (68428*CF*NC*NL*Zeta[3])/9 + 
       (12439438132693*CF*NC*NH*Zeta[3])/258280326 + 
       CF*Log[x]*((8144318842357*NM*NC)/10716300 - (585599*lm*NM*NC)/135 - 
         784*lm^2*NM*NC - (38061707*NC*NL)/2700 - (585599*lm*NC*NL)/135 - 
         784*lm^2*NC*NL - (205129690017920182*NC*NH)/887507355735 - 
         (585599*lm*NC*NH)/135 - 784*lm^2*NC*NH + (11244532*NM*NC*Pi^2)/
          81 - (102250*NC*NL*Pi^2)/81 + (69383395024*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(177147*Sqrt[3]) + 
         CF*NC*(2616324731454701/8680203000 - (1012438*lm)/15 - 14112*lm^2 + 
           (6620327*Pi^2)/162 + (59147405722*Im[PolyLog[2, (-1)^(1/3)]])/
            (885735*Sqrt[3]) - 9408*Zeta[3]) + 
         CA*NC*(-22089642905189891/173604060000 + (7923349*lm)/270 + 
           4312*lm^2 - (17534953*Pi^2)/900 - 
           (29573702861*Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) + 
           4704*Zeta[3])) + CA*CF*NC*((15785*lm^2)/9 - (10569430841*Pi^2)/
          396000 + (207015920027*Pi^3)/(76527504*Sqrt[3]) + 
         (143003*Pi^4)/1620 + lm*(542924539/97200 - (1078*Pi^2)/81) + 
         (29573702861*Pi*Log[3]^2)/(14171760*Sqrt[3]) + 
         (280620776180354364 - 122530661410366545*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 157513289932404000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 492987711952297800*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 144583916198252720*
            PolyGamma[2, 1] + 266293691846510300*Zeta[3])/14765025303000), 
      (764200015574245470609559*CF^2*NC)/1375657407480510000 - 
       (134825431*CF^2*lm*NC)/165375 - (15536*CF^2*lm^2*NC)/5 + 
       (1612276644670089383*CF*NM*NC)/11232423798750 - 
       (520215331*CF*lm*NM*NC)/2976750 - (7768*CF*lm^2*NM*NC)/45 + 
       (131240574347*CF*NC*NL)/44651250 - (520215331*CF*lm*NC*NL)/2976750 - 
       (7768*CF*lm^2*NC*NL)/45 + (50133009967390772047979*CF*NC*NH)/
        799555376781661500 - (520215331*CF*lm*NC*NH)/2976750 - 
       (7768*CF*lm^2*NC*NH)/45 - (41121421314371*CF^2*NC*Pi^2)/130977000 - 
       (32*CF^2*lm*NC*Pi^2)/45 - (5012171228*CF*NM*NC*Pi^2)/42525 - 
       (16*CF*lm*NM*NC*Pi^2)/405 - (4581926*CF*NC*NL*Pi^2)/14175 - 
       (16*CF*lm*NC*NL*Pi^2)/405 - (16*CF*lm*NC*NH*Pi^2)/405 - 
       (872759944408*CF^2*NC*Pi^3)/(215233605*Sqrt[3]) - 
       (353813377316*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (209404*CF^2*NC*Pi^4)/2025 + (91836333888053*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(527322332250*Sqrt[3]) + 
       (896636394352*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (7971615*Sqrt[3]) - (76736*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (13964159110528*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (93002175*Sqrt[3]) - (808716291008*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (872759944408*CF^2*NC*Pi*Log[3]^2)/(279006525*Sqrt[3]) - 
       (50544768188*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-39*CA*(21287635628689 + 209395678800*lm) + 
          39*CF*(42677635390469 + 685294948800*lm) + 
          280*(13*(165793341169 + 407913660*lm)*NM + 
            19*(9009*(36851 + 30980*lm)*NL + 5*(9778247 + 55819764*lm)*
               NH)))*Log[x]^2)/425675250 + 
       (4*CF*NC*(1787641761*CA - 56*(74644408*CF + 20557025*NM - 
            147155*NL))*Log[x]^3)/14175 - (2266551560616953*CF^2*NC*
         PolyGamma[2, 1])/9685512225 - (48821033*CF*NM*NC*PolyGamma[2, 1])/
        1350 - (175677196163659*CF*NC*NH*PolyGamma[2, 1])/19371024450 + 
       CA*CF*NC*(-488576012229959143318597/1719571759350637500 + 
         (42724*lm^2)/45 + (2745816583159*Pi^2)/17463600 + 
         (436379972204*Pi^3)/(215233605*Sqrt[3]) + (104638*Pi^4)/2025 + 
         lm*(12916313441/5953500 + (88*Pi^2)/405) - 
         (91836333888053*Im[PolyLog[2, (-1)^(1/3)]])/(1054644664500*
           Sqrt[3]) + (38368*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (6982079555264*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (93002175*Sqrt[3]) + (436379972204*Pi*Log[3]^2)/
          (279006525*Sqrt[3]) + (2266551560616953*PolyGamma[2, 1])/
          19371024450 - (3698775126228673*Zeta[3])/67798585575) + 
       (8046376890753854*CF^2*NC*Zeta[3])/67798585575 + 
       (71608567*CF*NM*NC*Zeta[3])/675 - (197264*CF*NC*NL*Zeta[3])/45 - 
       (389788907955019*CF*NC*NH*Zeta[3])/9685512225 + 
       CF*Log[x]*((-240578948191102*NM*NC)/231548625 - (3238876*lm*NM*NC)/
          1575 - 448*lm^2*NM*NC - (504902984*NC*NL)/70875 - 
         (3238876*lm*NC*NL)/1575 - 448*lm^2*NC*NL - 
         (2420472254551633577*NC*NH)/39937831008075 - (3238876*lm*NC*NH)/
          1575 - 448*lm^2*NC*NH - (33720784*NM*NC*Pi^2)/405 - 
         (295928*NC*NL*Pi^2)/405 + (808716291008*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-177244996451434349857/82711484336250 - (5419352*lm)/175 - 
           8064*lm^2 - (733931728*Pi^2)/2835 + 
           (13964159110528*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) - 
           5376*Zeta[3]) + CA*NC*(5135045572236882143/4726370533500 + 
           (22753018*lm)/1575 + 2464*lm^2 + (614467262*Pi^2)/4725 - 
           (6982079555264*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) + 
           2688*Zeta[3])), (-36565427443281367995525307*CF^2*NC)/
        36684197532813600000 - (185146061*CF^2*lm*NC)/14700 - 
       10812*CF^2*lm^2*NC - (934306748628926429*CF*NM*NC)/285267906000 - 
       (304348361*CF*lm*NM*NC)/264600 - (1802*CF*lm^2*NM*NC)/3 + 
       (4540491691*CF*NC*NL)/396900 - (304348361*CF*lm*NC*NL)/264600 - 
       (1802*CF*lm^2*NC*NL)/3 + (28062317713126610093165941*CF*NC*NH)/
        51811188415451665200 - (304348361*CF*lm*NC*NH)/264600 - 
       (1802*CF*lm^2*NC*NH)/3 + (6666759337359493*CF^2*NC*Pi^2)/
        10216206000 + 72*CF^2*lm*NC*Pi^2 + (505880374*CF*NM*NC*Pi^2)/315 + 
       4*CF*lm*NM*NC*Pi^2 - (771037*CF*NC*NL*Pi^2)/630 + 
       4*CF*lm*NC*NL*Pi^2 + 4*CF*lm*NC*NH*Pi^2 - 
       (22359348263929*CF^2*NC*Pi^3)/(1721868840*Sqrt[3]) - 
       (9682133200985*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) - 
       (516019*CF^2*NC*Pi^4)/1350 + (9799637872924003*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(87887055375*Sqrt[3]) + 
       (40472319839648*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (129140163*Sqrt[3]) - (223816*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (44718696527858*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (93002175*Sqrt[3]) - (4426118034736*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (22359348263929*CF^2*NC*Pi*Log[3]^2)/(2232052200*Sqrt[3]) - 
       (276632377171*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       CF*((16889556498539*CF*NC)/2338875 - 268344*CF*lm*NC + 
         CA*(-24095505049069/6548850 + 81994*lm)*NC + (28552926791*NM*NC)/
          1485 - 14908*lm*NM*NC - (58063*NC*NL)/3 - 14908*lm*NC*NL - 
         (119243431*NC*NH)/45045 - 14908*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-15351583085*CA + 6*(3278761727*CF + 
            6300*(2106959*NM + 3727*NL)))*Log[x]^3)/14175 + 
       (9555017984798656*CF^2*NC*PolyGamma[2, 1])/29056536675 + 
       (282918019*CF*NM*NC*PolyGamma[2, 1])/180 - 
       (384454765416799*CF*NC*NH*PolyGamma[2, 1])/13947137604 - 
       (64035366174034342*CF^2*NC*Zeta[3])/203395756725 + 
       (39030739*CF*NM*NC*Zeta[3])/90 - 18316*CF*NC*NL*Zeta[3] + 
       (820577923568801*CF*NC*NH*Zeta[3])/6973568802 + 
       CA*CF*NC*(4441879139429774602794299/9171049383203400000 + 
         (9911*lm^2)/3 - (10661829599849*Pi^2)/32744250 + 
         (22359348263929*Pi^3)/(3443737680*Sqrt[3]) + (524659*Pi^4)/2700 + 
         lm*(5572941571/529200 - 22*Pi^2) - (9799637872924003*
           Im[PolyLog[2, (-1)^(1/3)]])/(175774110750*Sqrt[3]) + 
         (111908*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (22359348263929*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (93002175*Sqrt[3]) + (22359348263929*Pi*Log[3]^2)/
          (4464104400*Sqrt[3]) - (4777508992399328*PolyGamma[2, 1])/
          29056536675 + (70403221164152383*Zeta[3])/406791513450) + 
       CF*Log[x]*((1347949377013739*NM*NC)/144074700 - (989717*lm*NM*NC)/
          105 - 1680*lm^2*NM*NC - (8445845*NC*NL)/252 - 
         (989717*lm*NC*NL)/105 - 1680*lm^2*NC*NL - 
         (130890632783108690977*NC*NH)/239626986048450 - 
         (989717*lm*NC*NH)/105 - 1680*lm^2*NC*NH + (4207852*NM*NC*Pi^2)/
          3 - (9134*NC*NL*Pi^2)/3 + (4426118034736*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(1510209399113886551023/330845937345000 - (5144502*lm)/35 - 
           30240*lm^2 + (4834081657*Pi^2)/9450 + 
           (44718696527858*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) - 
           20160*Zeta[3]) + CA*NC*(-2950180402614257169353/1323383749380000 + 
           (13356487*lm)/210 + 9240*lm^2 - (14374088033*Pi^2)/56700 - 
           (22359348263929*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) + 
           10080*Zeta[3])), (121028584147003597885252285958749*CF^2*NC)/
        17408559307591759507200000 - (1802314099*CF^2*lm*NC)/1176000 - 
       (56631*CF^2*lm^2*NC)/10 + (3264012602986231582866857*CF*NM*NC)/
        1403883240439680000 - (6797168299*CF*lm*NM*NC)/21168000 - 
       (18877*CF*lm^2*NM*NC)/60 + (9170469045347*CF*NC*NL)/1270080000 - 
       (6797168299*CF*lm*NC*NL)/21168000 - (18877*CF*lm^2*NC*NL)/60 + 
       (454434997462315622228370311*CF*NC*NH)/3315916058588906572800 - 
       (6797168299*CF*lm*NC*NH)/21168000 - (18877*CF*lm^2*NC*NH)/60 - 
       (55376231470872283*CF^2*NC*Pi^2)/14859936000 - 
       (9*CF^2*lm*NC*Pi^2)/10 - (40246208561*CF*NM*NC*Pi^2)/25200 - 
       (CF*lm*NM*NC*Pi^2)/20 - (2783911*CF*NC*NL*Pi^2)/4200 - 
       (CF*lm*NC*NL*Pi^2)/20 - (CF*lm*NC*NH*Pi^2)/20 - 
       (223950160778345*CF^2*NC*Pi^3)/(24794911296*Sqrt[3]) - 
       (9556273156843*CF*NC*NH*Pi^3)/(516560652*Sqrt[3]) - 
       (2423291*CF^2*NC*Pi^4)/10800 + (78051594008818001*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(30373766337600*Sqrt[3]) + 
       (608915722713671*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2582803260*Sqrt[3]) - 30797*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (44790032155669*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (133923132*Sqrt[3]) - (5460727518196*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) - 
       (44790032155669*CF^2*NC*Pi*Log[3]^2)/(6428310336*Sqrt[3]) - 
       (1365181879549*CF*NC*NH*Pi*Log[3]^2)/(95659380*Sqrt[3]) - 
       (CF*NC*(-7*CA*(43816485793503611 + 88751003140800*lm) + 
          8*(CF*(76717120582519889 + 254150599903200*lm) + 
            315*((103642706566759 + 44823738960*lm)*NM + 36036*(1454947 + 
                1243860*lm)*NL + 5*(1819083025 + 8964747792*lm)*NH)))*
         Log[x]^2)/13621608000 + (CF*NC*(342619746637*CA - 711030714486*CF - 
          273692185200*NM + 313452720*NL)*Log[x]^3)/56700 - 
       (3678842719249523147*CF^2*NC*PolyGamma[2, 1])/1394713760400 - 
       (550933099*CF*NM*NC*PolyGamma[2, 1])/900 - 
       (13470053280989543*CF*NC*NH*PolyGamma[2, 1])/697356880200 + 
       CA*CF*NC*(-48595521627529114807704444678913/
          13926847446073407605760000 + (207647*lm^2)/120 + 
         (15623325218945401*Pi^2)/8382528000 + (223950160778345*Pi^3)/
          (49589822592*Sqrt[3]) + (2422427*Pi^4)/21600 + 
         lm*(168006129689/42336000 + (11*Pi^2)/40) - 
         (78051594008818001*Im[PolyLog[2, (-1)^(1/3)]])/(60747532675200*
           Sqrt[3]) + (30797*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (44790032155669*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (267846264*Sqrt[3]) + (44790032155669*Pi*Log[3]^2)/
          (12856620672*Sqrt[3]) + (3678842719249523147*PolyGamma[2, 1])/
          2789427520800 - (2286099002131308569*Zeta[3])/4881498161400) + 
       (467484335610677293*CF^2*NC*Zeta[3])/488149816140 + 
       (551957651*CF*NM*NC*Zeta[3])/450 - (50699*CF*NC*NL*Zeta[3])/5 - 
       (26648843074385183*CF*NC*NH*Zeta[3])/348678440100 + 
       CF*Log[x]*((-24766413539097335579*NM*NC)/1947889944000 - 
         (18081409*lm*NM*NC)/4200 - 924*lm^2*NM*NC - (12429601759*NC*NL)/
          756000 - (18081409*lm*NC*NL)/4200 - 924*lm^2*NC*NL - 
         (209303099856561213821*NC*NH)/1533612710710080 - 
         (18081409*lm*NC*NH)/4200 - 924*lm^2*NC*NH - (18171928*NM*NC*Pi^2)/
          15 - (25351*NC*NL*Pi^2)/15 + (5460727518196*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
         CF*NC*(-57741174987607561951138739/2300419066065120000 - 
           (45512427*lm)/700 - 16632*lm^2 - (229655955751*Pi^2)/75600 + 
           (44790032155669*Im[PolyLog[2, (-1)^(1/3)]])/(401769396*Sqrt[3]) - 
           11088*Zeta[3]) + CA*NC*(405240884982845142191196371/
            32205866924911680000 + (253226699*lm)/8400 + 5082*lm^2 + 
           (137920818619*Pi^2)/90720 - (44790032155669*
             Im[PolyLog[2, (-1)^(1/3)]])/(803538792*Sqrt[3]) + 
           5544*Zeta[3])), (-19349366688661218386991149938373*CF^2*NC)/
        1392684744607340760576000 - (207999941*CF^2*lm*NC)/9408 - 
       (37905*CF^2*lm^2*NC)/2 - (4087171492381946835073*CF*NM*NC)/
        110498484096000 - (341728781*CF*lm*NM*NC)/169344 - 
       (12635*CF*lm^2*NM*NC)/12 + (1925499885661*CF*NC*NL)/71124480 - 
       (341728781*CF*lm*NC*NL)/169344 - (12635*CF*lm^2*NC*NL)/12 + 
       (170378802516735997977653687088523*CF*NC*NH)/
        146619860362625681929497600 - (341728781*CF*lm*NC*NH)/169344 - 
       (12635*CF*lm^2*NC*NH)/12 + (1995030479867219*CF^2*NC*Pi^2)/
        251475840 + (225*CF^2*lm*NC*Pi^2)/2 + (2543121029*CF*NM*NC*Pi^2)/
        144 + (25*CF*lm*NM*NC*Pi^2)/4 - (605435*CF*NC*NL*Pi^2)/252 + 
       (25*CF*lm*NC*NL*Pi^2)/4 + (25*CF*lm*NC*NH*Pi^2)/4 - 
       (21786720684905*CF^2*NC*Pi^3)/(774840978*Sqrt[3]) - 
       (750337362503575*CF*NC*NH*Pi^3)/(4649045868*Sqrt[3]) - 
       (20789*CF^2*NC*Pi^4)/27 + (34981531224456311*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(151868831688*Sqrt[3]) + 
       (110133385210136129*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (162716605380*Sqrt[3]) - 86480*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (34858753095848*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (33480783*Sqrt[3]) - (85752841428980*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (4357344136981*CF^2*NC*Pi*Log[3]^2)/(200884698*Sqrt[3]) - 
       (21438210357245*CF*NC*NH*Pi*Log[3]^2)/(172186884*Sqrt[3]) + 
       CF*((15978803808975691*CF*NC)/170270100 - 599580*CF*lm*NC + 
         CA*(-64124714306095033/1362160800 + 183205*lm)*NC + 
         (2313194434573*NM*NC)/10920 - 33310*lm*NM*NC - (257285*NC*NL)/6 - 
         33310*lm*NC*NL - (17511868139*NC*NH)/2625480 - 33310*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-145120418371*CA + 84*(3194590877*CF + 
            8057789820*NM + 2997900*NL))*Log[x]^3)/11340 + 
       (999406995431535347*CF^2*NC*PolyGamma[2, 1])/232452293400 + 
       (734563892*CF*NM*NC*PolyGamma[2, 1])/45 - 
       (24311638566561431*CF*NC*NH*PolyGamma[2, 1])/418414128120 - 
       (1606612835436224423*CF^2*NC*Zeta[3])/406791513450 + 
       (136360669*CF*NM*NC*Zeta[3])/45 - 39985*CF*NC*NL*Zeta[3] + 
       (54015904631630689*CF*NC*NH*Zeta[3])/209207064060 + 
       CA*CF*NC*(96333273079802347746104730152941/
          13926847446073407605760000 + (138985*lm^2)/24 - 
         (43210506660899261*Pi^2)/10897286400 + (21786720684905*Pi^3)/
          (1549681956*Sqrt[3]) + (21059*Pi^4)/54 + 
         lm*(6255288271/338688 - (275*Pi^2)/8) - 
         (34981531224456311*Im[PolyLog[2, (-1)^(1/3)]])/
          (303737663376*Sqrt[3]) + 43240*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (17429376547924*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33480783*Sqrt[3]) + (4357344136981*Pi*Log[3]^2)/
          (401769396*Sqrt[3]) - (999406995431535347*PolyGamma[2, 1])/
          464904586800 + (408348507137332922*Zeta[3])/203395756725) + 
       CF*Log[x]*((114915010109673037*NM*NC)/1073217600 - 
         (1048497*lm*NM*NC)/56 - 3300*lm^2*NM*NC - (15320716913*NC*NL)/
          211680 - (1048497*lm*NC*NL)/56 - 3300*lm^2*NC*NL - 
         (23454360794338474200039997*NC*NH)/19944633302784590400 - 
         (1048497*lm*NC*NH)/56 - 3300*lm^2*NC*NH + 14918394*NM*NC*Pi^2 - 
         (19955*NC*NL*Pi^2)/3 + (85752841428980*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(178997418180637623929313907/3220586692491168000 - 
           (8189073*lm)/28 - 59400*lm^2 + (47861375003*Pi^2)/7560 + 
           (34858753095848*Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) - 
           39600*Zeta[3]) + CA*NC*(-22286479792519187117117579/
            805146673122792000 + (14120667*lm)/112 + 18150*lm^2 - 
           (143362413589*Pi^2)/45360 - (17429376547924*
             Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) + 
           19800*Zeta[3])), (3160430250113982894088873997904547*CF^2*NC)/
        37602488104398200535552000 - (2545606691*CF^2*lm*NC)/952560 - 
       9668*CF^2*lm^2*NC + (21246127870244307815481457*CF*NM*NC)/
        631747458197856000 - (9452619251*CF*lm*NM*NC)/17146080 - 
       (4834*CF*lm^2*NM*NC)/9 + (64113704795459*CF*NC*NL)/4000752000 - 
       (9452619251*CF*lm*NC*NL)/17146080 - (4834*CF*lm^2*NC*NL)/9 + 
       (456674366664408920172902730321181*CF*NC*NH)/
        1649473429079538921706848000 - (9452619251*CF*lm*NC*NH)/17146080 - 
       (4834*CF*lm^2*NC*NH)/9 - (2127395996492297677*CF^2*NC*Pi^2)/
        49037788800 - (10*CF^2*lm*NC*Pi^2)/9 - (2087687950483*CF*NM*NC*Pi^2)/
        102060 - (5*CF*lm*NM*NC*Pi^2)/81 - (6416710*CF*NC*NL*Pi^2)/5103 - 
       (5*CF*lm*NC*NL*Pi^2)/81 - (5*CF*lm*NC*NH*Pi^2)/81 - 
       (1539384416889257*CF^2*NC*Pi^3)/(83682825624*Sqrt[3]) - 
       (399845675596325*CF*NC*NH*Pi^3)/(10460353203*Sqrt[3]) - 
       (359741*CF^2*NC*Pi^4)/810 + (232821203909408579*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(25627865347350*Sqrt[3]) + 
       (168846741578590891*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (366112362105*Sqrt[3]) - (172216*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (3078768833778514*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4519905705*Sqrt[3]) - 
       (182786594558320*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) - (1539384416889257*CF^2*NC*Pi*Log[3]^2)/
        (108477736920*Sqrt[3]) - (11424162159895*CF*NC*NH*Pi*Log[3]^2)/
        (387420489*Sqrt[3]) - 
       (CF*NC*(-306*CA*(59171173985765377 + 22341354235200*lm) + 
          5*(17*CF*(426072325711794131 + 263221773534720*lm) + 
            336*(459*(22115906497809 + 1611930320*lm)*NM + 9189180*(92969 + 
                80516*lm)*NL + 5*(33699345499 + 147975203376*lm)*NH)))*
         Log[x]^2)/69470200800 + (CF*NC*(1203862749080*CA - 
          21*(115534371079*CF + 51893738400*NM - 9661920*NL))*Log[x]^3)/
        17010 - (11183966729403298019*CF^2*NC*PolyGamma[2, 1])/376572715308 - 
       (18154552802*CF*NM*NC*PolyGamma[2, 1])/2025 - 
       (359932051116995611*CF*NC*NH*PolyGamma[2, 1])/9414317882700 + 
       CA*CF*NC*(-395295865906402124378101634363789/
          9400622026099550133888000 + (26587*lm^2)/9 + 
         (16621050632707349*Pi^2)/766215450 + (1539384416889257*Pi^3)/
          (167365651248*Sqrt[3]) + (119887*Pi^4)/540 + 
         lm*(232909712881/34292160 + (55*Pi^2)/162) - 
         (232821203909408579*Im[PolyLog[2, (-1)^(1/3)]])/
          (51255730694700*Sqrt[3]) + (86108*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1539384416889257*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4519905705*Sqrt[3]) + (1539384416889257*Pi*Log[3]^2)/
          (216955473840*Sqrt[3]) + (11183966729403298019*PolyGamma[2, 1])/
          753145430616 - (77334466859638683641*Zeta[3])/13180045035780) + 
       (155232310912355726683*CF^2*NC*Zeta[3])/13180045035780 + 
       (28718165096*CF*NM*NC*Zeta[3])/2025 - (578116*CF*NC*NL*Zeta[3])/27 - 
       (642633556781273611*CF*NC*NH*Zeta[3])/4707158941350 + 
       CF*Log[x]*((-14790774642282256307*NM*NC)/97394497200 - 
         (28233145*lm*NM*NC)/3402 - 1760*lm^2*NM*NC - (27522285353*NC*NL)/
          793800 - (28233145*lm*NC*NL)/3402 - 1760*lm^2*NC*NL - 
         (12656643785103592760851823*NC*NH)/44875424931265328400 - 
         (28233145*lm*NC*NH)/3402 - 1760*lm^2*NC*NH - 
         (144237896*NM*NC*Pi^2)/9 - (96356*NC*NL*Pi^2)/27 + 
         (182786594558320*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(-24971983589064565717517709617/
            86955840697261536000 - (23742505*lm)/189 - 31680*lm^2 - 
           (2410206173617*Pi^2)/68040 + (3078768833778514*
             Im[PolyLog[2, (-1)^(1/3)]])/(13559717115*Sqrt[3]) - 
           21120*Zeta[3]) + CA*NC*(6245841639006391090848491717/
            43477920348630768000 + (394389875*lm)/6804 + 9680*lm^2 + 
           (602652483973*Pi^2)/34020 - (1539384416889257*
             Im[PolyLog[2, (-1)^(1/3)]])/(13559717115*Sqrt[3]) + 
           10560*Zeta[3])), (-949183116330507308878509801955169*CF^2*NC)/
        5371784014914028647936000 - (27914158381*CF^2*lm*NC)/762048 - 
       (62755*CF^2*lm^2*NC)/2 - (1040252033121731817737309273*CF*NM*NC)/
        2526989832791424000 - (45847529221*CF*lm*NM*NC)/13716864 - 
       (62755*CF*lm^2*NM*NC)/36 + (20686540414553*CF*NC*NL)/355622400 - 
       (45847529221*CF*lm*NC*NL)/13716864 - (62755*CF*lm^2*NC*NL)/36 + 
       (314396608264604607785769852872424808907*CF*NC*NH)/
        135764859000678689567847245184000 - (45847529221*CF*lm*NC*NH)/
        13716864 - (62755*CF*lm^2*NC*NH)/36 + 
       (264416832486963929*CF^2*NC*Pi^2)/2802159360 + (3025*CF^2*lm*NC*Pi^2)/
        18 + (79247972220479*CF*NM*NC*Pi^2)/408240 + 
       (3025*CF*lm*NM*NC*Pi^2)/324 - (89871925*CF*NC*NL*Pi^2)/20412 + 
       (3025*CF*lm*NC*NL*Pi^2)/324 + (3025*CF*lm*NC*NH*Pi^2)/324 - 
       (37588713070093255*CF^2*NC*Pi^3)/(669462604992*Sqrt[3]) - 
       (40474845169647385*CF*NC*NH*Pi^3)/(125524238436*Sqrt[3]) - 
       (1866557*CF^2*NC*Pi^4)/1296 + (298247773128793267*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(669462604992*Sqrt[3]) + 
       (5977261346884258331*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (4393348345260*Sqrt[3]) - (469315*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (1073963230574093*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(516560652*Sqrt[3]) - 
       (4625696590816844*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) - (1073963230574093*CF^2*NC*Pi*Log[3]^2)/
        (24794911296*Sqrt[3]) - (1156424147704211*CF*NC*NH*Pi*Log[3]^2)/
        (4649045868*Sqrt[3]) + CF*((659421557673741767*CF*NC)/583783200 - 
         1232660*CF*lm*NC + CA*(-513170864036549263/908107200 + 
           (3389815*lm)/9)*NC + (7554355806262049*NM*NC)/3243240 - 
         (616330*lm*NM*NC)/9 - (1576487*NC*NL)/18 - (616330*lm*NC*NL)/9 - 
         (47474668968131*NC*NH)/3142699560 - (616330*lm*NC*NH)/9)*
        Log[x]^2 + (CF*NC*(-5196450977057*CA + 84*(121957068131*CF + 
            300*(877265317*NM + 61633*NL)))*Log[x]^3)/34020 + 
       (990831131383432855637*CF^2*NC*PolyGamma[2, 1])/18828635765400 + 
       (68739246356*CF*NM*NC*PolyGamma[2, 1])/405 - 
       (1287069072061405451*CF*NC*NH*PolyGamma[2, 1])/11297181459240 - 
       (884667280849361961251*CF^2*NC*Zeta[3])/18828635765400 + 
       (6080103577*CF*NM*NC*Zeta[3])/405 - (2178715*CF*NC*NL*Zeta[3])/27 + 
       (2945031254917837069*CF*NC*NH*Zeta[3])/5648590729620 + 
       CA*CF*NC*(33199313088618879363689963025826063/
          376024881043982005355520000 + (690305*lm^2)/72 - 
         (120182748179381231*Pi^2)/2547417600 + (37588713070093255*Pi^3)/
          (1338925209984*Sqrt[3]) + (628639*Pi^4)/864 + 
         lm*(839079077111/27433728 - (33275*Pi^2)/648) - 
         (298247773128793267*Im[PolyLog[2, (-1)^(1/3)]])/
          (1338925209984*Sqrt[3]) + (469315*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (1073963230574093*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1033121304*Sqrt[3]) + (1073963230574093*Pi*Log[3]^2)/
          (49589822592*Sqrt[3]) - (990831131383432855637*PolyGamma[2, 1])/
          37657271530800 + (887099495048940881471*Zeta[3])/37657271530800) + 
       CF*Log[x]*((55542150926891669977*NM*NC)/46749358656 - 
         (471395419*lm*NM*NC)/13608 - 6050*lm^2*NM*NC - 
         (6128190049*NC*NL)/42336 - (471395419*lm*NC*NL)/13608 - 
         6050*lm^2*NC*NL - (456724686273119250204634496203*NC*NH)/
          194400340802241402628800 - (471395419*lm*NC*NH)/13608 - 
         6050*lm^2*NC*NH + 162451382*NM*NC*Pi^2 - (362615*NC*NL*Pi^2)/27 + 
         (4625696590816844*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(997104012315022134259758179/
            1552782869593956000 - (409649119*lm)/756 - 108900*lm^2 + 
           (1481968761097*Pi^2)/19440 + (1073963230574093*
             Im[PolyLog[2, (-1)^(1/3)]])/(1549681956*Sqrt[3]) - 
           72600*Zeta[3]) + CA*NC*(-55801256610812507697121888651/
            173911681394523072000 + (6337947209*lm)/27216 + 33275*lm^2 - 
           (1481588079673*Pi^2)/38880 - (1073963230574093*
             Im[PolyLog[2, (-1)^(1/3)]])/(3099363912*Sqrt[3]) + 
           36300*Zeta[3])), (41339975753191213359428592633970445026873*CF^2*
         NC)/41566730412804380827012569600000 - (83742405679*CF^2*lm*NC)/
        19051200 - (156629*CF^2*lm^2*NC)/10 + 
       (27820741160908139227445083148791*CF*NM*NC)/62075505242521330560000 - 
       (307540186039*CF*lm*NM*NC)/342921600 - (156629*CF*lm^2*NM*NC)/180 + 
       (2623927824162797*CF*NC*NL)/80015040000 - (307540186039*CF*lm*NC*NL)/
        342921600 - (156629*CF*lm^2*NC*NL)/180 + 
       (27389823158067019932040874749617000289*CF*NC*NH)/
        52217253461799495987633555840000 - (307540186039*CF*lm*NC*NH)/
        342921600 - (156629*CF*lm^2*NC*NH)/180 - 
       (30471917311320024521*CF^2*NC*Pi^2)/61297236000 - 
       (121*CF^2*lm*NC*Pi^2)/90 - (512214480301289*CF*NM*NC*Pi^2)/2041200 - 
       (121*CF*lm*NM*NC*Pi^2)/1620 - (2287211069*CF*NC*NL*Pi^2)/1020600 - 
       (121*CF*lm*NC*NL*Pi^2)/1620 - (121*CF*lm*NC*NH*Pi^2)/1620 - 
       (525514087377859013*CF^2*NC*Pi^3)/(15062908612320*Sqrt[3]) - 
       (4627329199681349*CF*NC*NH*Pi^3)/(62762119218*Sqrt[3]) - 
       (2650967*CF^2*NC*Pi^4)/3240 + (62675031197437069781*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2636009007156000*Sqrt[3]) + 
       (3743015586903457427*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (4393348345260*Sqrt[3]) - (1512434*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/15 - (75073441053979859*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(58113073350*Sqrt[3]) - 
       (5288376228207256*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1937102445*Sqrt[3]) - (75073441053979859*CF^2*NC*Pi*Log[3]^2)/
        (2789427520800*Sqrt[3]) - (661047028525907*CF*NC*NH*Pi*Log[3]^2)/
        (11622614670*Sqrt[3]) - 
       (CF*NC*(-57*CA*(345426368813860908631 + 22759114473295200*lm) + 
          10*(19*CF*(207259221928525035961 + 22345312391962560*lm) + 
            42*(399*(118591542146805293 + 1407490072560*lm)*NM + 
              13*(29546748*(1670947 + 1462060*lm)*NL + (10800854149369 + 
                  43199118380880*lm)*NH))))*Log[x]^2)/6599669076000 + 
       (CF*NC*(138784574846615*CA - 72*(3860757714979*CF + 
            70*(27043982639*NM - 804133*NL)))*Log[x]^3)/170100 - 
       (112665042844539144397219*CF^2*NC*PolyGamma[2, 1])/338915443777200 - 
       (1941359358883*CF*NM*NC*PolyGamma[2, 1])/16200 - 
       (502987418242750318*CF*NC*NH*PolyGamma[2, 1])/7060738412025 + 
       CA*CF*NC*(-5906275875389198140202584838642999248261/
          11876208689372680236289305600000 + (1722919*lm^2)/360 + 
         (2770194409793976673*Pi^2)/11144952000 + (525514087377859013*Pi^3)/
          (30125817224640*Sqrt[3]) + (4417633*Pi^4)/10800 + 
         (11*lm*(687318237559 + 25613280*Pi^2))/685843200 - 
         (62675031197437069781*Im[PolyLog[2, (-1)^(1/3)]])/
          (5272018014312000*Sqrt[3]) + (756217*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          15 + (75073441053979859*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (116226146700*Sqrt[3]) + (75073441053979859*Pi*Log[3]^2)/
          (5578855041600*Sqrt[3]) + (112665042844539144397219*
           PolyGamma[2, 1])/677830887554400 - (180011370073489168817459*
           Zeta[3])/2372408106440400) + (36021612831265800008797*CF^2*NC*
         Zeta[3])/237240810644040 + (1305172543937*CF*NM*NC*Zeta[3])/8100 - 
       (5674097*CF*NC*NL*Zeta[3])/135 - (1637269390899798146*CF*NC*NH*
         Zeta[3])/7060738412025 + CF*Log[x]*
        ((-2989930786648218170463581*NM*NC)/1688820581448000 - 
         (5096549821*lm*NM*NC)/340200 - 3146*lm^2*NM*NC - 
         (1079676206471*NC*NL)/15876000 - (5096549821*lm*NC*NL)/340200 - 
         3146*lm^2*NC*NL - (5810313759159138918927731993*NC*NH)/
          10681337406716560584000 - (5096549821*lm*NC*NH)/340200 - 
         3146*lm^2*NC*NH - (9015521681*NM*NC*Pi^2)/45 - 
         (945703*NC*NL*Pi^2)/135 + (5288376228207256*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5811307335*Sqrt[3]) + 
         CF*NC*(-3646300269599824601350332159269729/
            1130860708267886275680000 - (4293847921*lm)/18900 - 56628*lm^2 - 
           (13880986888463*Pi^2)/34020 + (75073441053979859*
             Im[PolyLog[2, (-1)^(1/3)]])/(174339220050*Sqrt[3]) - 
           37752*Zeta[3]) + CA*NC*(1823288725941098290400491222416667/
            1130860708267886275680000 + (71045816831*lm)/680400 + 
           17303*lm^2 + (17351729579953*Pi^2)/85050 - 
           (75073441053979859*Im[PolyLog[2, (-1)^(1/3)]])/(348678440100*
             Sqrt[3]) + 18876*Zeta[3])), 
      (-33523203391215807524202674842770058951229*CF^2*NC)/
        15587523904801642810129713600000 - (6129156101*CF^2*lm*NC)/105840 - 
       49588*CF^2*lm^2*NC - (32143712053253652742544045153*CF*NM*NC)/
        7038039143143008000 - (10065451541*CF*lm*NM*NC)/1905120 - 
       (24794*CF*lm^2*NM*NC)/9 + (1389417103470251*CF*NC*NL)/12002256000 - 
       (10065451541*CF*lm*NC*NL)/1905120 - (24794*CF*lm^2*NC*NL)/9 + 
       (3979735990592927599300793612599566768949*CF*NC*NH)/
        916412798254581154582968904992000 - (10065451541*CF*lm*NC*NH)/
        1905120 - (24794*CF*lm^2*NC*NH)/9 + (134489220819229137479*CF^2*NC*
         Pi^2)/122594472000 + 242*CF^2*lm*NC*Pi^2 + 
       (689114127281*CF*NM*NC*Pi^2)/324 + (121*CF*lm*NM*NC*Pi^2)/9 - 
       (86521919*CF*NC*NL*Pi^2)/11340 + (121*CF*lm*NC*NL*Pi^2)/9 + 
       (121*CF*lm*NC*NH*Pi^2)/9 - (1186434484633477807*CF^2*NC*Pi^3)/
        (11297181459240*Sqrt[3]) - (513391419209849285*CF*NC*NH*Pi^3)/
        (847288609443*Sqrt[3]) - (20555579*CF^2*NC*Pi^4)/8100 + 
       (3224929713307402379123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (3954013510734000*Sqrt[3]) + (76416661815801463501*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(29655101330505*Sqrt[3]) - 
       (4022788*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (338981281323850802*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (87169610025*Sqrt[3]) - (234693220210216816*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) - 
       (169490640661925401*CF^2*NC*Pi*Log[3]^2)/(2092070640600*Sqrt[3]) - 
       (14668326263138551*CF*NC*NH*Pi*Log[3]^2)/(31381059609*Sqrt[3]) - 
       (CF*NC*(-95*CA*(-228560493583878352801 + 25139227876963200*lm) + 
          38*CF*(-1142696757056440794443 + 205684591720608000*lm) + 
          37800*(19*(-117264928924085051 + 604599035040*lm)*NM + 
            106696590*(136981 + 107664*lm)*NL + (2744612680969 + 
              11487381665760*lm)*NH))*Log[x]^2)/3299834538000 + 
       (CF*NC*(-76136309894771*CA + 4*(37970877046531*CF + 
            9450*(8002841965*NM + 98692*NL)))*Log[x]^3)/42525 + 
       (26407759689676869359797*CF^2*NC*PolyGamma[2, 1])/42364430472150 + 
       (382133796415*CF*NM*NC*PolyGamma[2, 1])/216 - 
       (2377964794947250861*CF*NC*NH*PolyGamma[2, 1])/11297181459240 - 
       (80469488996074881380333*CF^2*NC*Zeta[3])/148275506652525 - 
       (1903494881*CF*NM*NC*Zeta[3])/108 - 152724*CF*NC*NL*Zeta[3] + 
       (5564425742034988499*CF*NC*NH*Zeta[3])/5648590729620 + 
       CA*CF*NC*(67039553381416673790261947901293856734911/
          62350095619206571240518854400000 + (136367*lm^2)/9 - 
         (940476019855008997*Pi^2)/1714608000 + (1186434484633477807*Pi^3)/
          (22594362918480*Sqrt[3]) + (20729819*Pi^4)/16200 + 
         lm*(184197481831/3810240 - (1331*Pi^2)/18) - 
         (3224929713307402379123*Im[PolyLog[2, (-1)^(1/3)]])/
          (7908027021468000*Sqrt[3]) + (2011394*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          15 + (169490640661925401*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (87169610025*Sqrt[3]) + (169490640661925401*Pi*Log[3]^2)/
          (4184141281200*Sqrt[3]) - (26407759689676869359797*PolyGamma[2, 1])/
          84728860944300 + (80504965276933498527917*Zeta[3])/
          296551013305050) + CF*Log[x]*((10137245810955619865077*NM*NC)/
          781861380300 - (57175822*lm*NM*NC)/945 - (31460*lm^2*NM*NC)/3 - 
         (258995817229*NC*NL)/952560 - (57175822*lm*NC*NL)/945 - 
         (31460*lm^2*NC*NL)/3 - (5792720164721281712373288342887*NC*NH)/
          1312202300415129467744400 - (57175822*lm*NC*NH)/945 - 
         (31460*lm^2*NC*NH)/3 + (16005623474*NM*NC*Pi^2)/9 - 
         (228844*NC*NL*Pi^2)/9 + (234693220210216816*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CF*NC*(1536185630486654084051374894904909/212036382800228676690000 - 
           (99486794*lm)/105 - 188760*lm^2 + (38056594042939*Pi^2)/42525 + 
           (338981281323850802*Im[PolyLog[2, (-1)^(1/3)]])/
            (261508830075*Sqrt[3]) - 125840*Zeta[3]) + 
         CA*NC*(-877728151493537284171968944189531/242327294628832773360000 + 
           (383836321*lm)/945 + (173030*lm^2)/3 - (19027513606484*Pi^2)/
            42525 - (169490640661925401*Im[PolyLog[2, (-1)^(1/3)]])/
            (261508830075*Sqrt[3]) + 62920*Zeta[3])), 
      (352833986915730316499897102144404453715293013*CF^2*NC)/
        30547093275152705152765630166400000 - (22089345263*CF^2*lm*NC)/
        3201660 - (121544*CF^2*lm^2*NC)/5 + 
       (16698772454517546500148221545359079*CF*NM*NC)/
        2956777017072595877160000 - (80460729719*CF*lm*NM*NC)/57629880 - 
       (60772*CF*lm^2*NM*NC)/45 + (14249601117847853*CF*NC*NL)/
        226917652500 - (80460729719*CF*lm*NC*NL)/57629880 - 
       (60772*CF*lm^2*NC*NL)/45 + (1079237384822837130591997583423480925641*
         CF*NC*NH)/1145515997818226443228711131240000 - 
       (80460729719*CF*lm*NC*NH)/57629880 - (60772*CF*lm^2*NC*NH)/45 - 
       (3784149949211188960807*CF^2*NC*Pi^2)/674269596000 - 
       (8*CF^2*lm*NC*Pi^2)/5 - (464590367378579*CF*NM*NC*Pi^2)/155925 - 
       (4*CF*lm*NM*NC*Pi^2)/45 - (591665933*CF*NC*NL*Pi^2)/155925 - 
       (4*CF*lm*NC*NL*Pi^2)/45 - (4*CF*lm*NC*NH*Pi^2)/45 - 
       (7757968040088363583*CF^2*NC*Pi^3)/(124268996051640*Sqrt[3]) - 
       (113852807024165426*CF*NC*NH*Pi^3)/(847288609443*Sqrt[3]) - 
       (5762077*CF^2*NC*Pi^4)/4050 + (89187047229317762745157*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1674524721795849000*Sqrt[3]) + 
       (44475341375517090964*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29655101330505*Sqrt[3]) - (2529592*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (15515936080176727166*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6712059971925*Sqrt[3]) - 
       (260234987483806688*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (52301766015*Sqrt[3]) - (7757968040088363583*CF^2*NC*Pi*Log[3]^2)/
        (161089439326200*Sqrt[3]) - (16264686717737918*CF*NC*NH*Pi*Log[3]^2)/
        (156905298045*Sqrt[3]) - 
       (CF*NC*(-(CA*(611163060736236735362749 + 6691187127054830400*lm)) + 
          2*(CF*(611164733406659432310553 + 10949215298816995200*lm) + 
            83160*((3901638839135202807 + 7314691424040*lm)*NM + 
              21339318*(388501 + 342780*lm)*NL + (1975875438227 + 
                7314691424040*lm)*NH)))*Log[x]^2)/18149089959000 - 
       (4*CF*NC*(-1083656858836037*CA + 11*(197080255114151*CF + 
            219240*(467548091*NM - 2167*NL)))*Log[x]^3)/467775 - 
       (1407338662779175413803057*CF^2*NC*PolyGamma[2, 1])/381279874249350 - 
       (1358155106803*CF*NM*NC*PolyGamma[2, 1])/900 - 
       (32073006028232493319*CF*NC*NH*PolyGamma[2, 1])/254186582832900 + 
       CA*CF*NC*(-679215304982289941629381373258582247197895487/
          117606309109337914838147676140640000 + (334246*lm^2)/45 + 
         (151366163780632317373*Pi^2)/53941567680 + 
         (7757968040088363583*Pi^3)/(248537992103280*Sqrt[3]) + 
         (5761501*Pi^4)/8100 + lm*(179515200311/10478160 + (22*Pi^2)/45) - 
         (89187047229317762745157*Im[PolyLog[2, (-1)^(1/3)]])/
          (3349049443591698000*Sqrt[3]) + (1264796*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/15 + (7757968040088363583*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(6712059971925*Sqrt[3]) + 
         (7757968040088363583*Pi*Log[3]^2)/(322178878652400*Sqrt[3]) + 
         (1407338662779175413803057*PolyGamma[2, 1])/762559748498700 - 
         (13839751764756713064589918*Zeta[3])/14679275158599975) + 
       (27681666782107879030120826*CF^2*NC*Zeta[3])/14679275158599975 + 
       (811396162157*CF*NM*NC*Zeta[3])/450 - (388544*CF*NC*NL*Zeta[3])/5 - 
       (47987209983686370439*CF*NC*NH*Zeta[3])/127093291416450 + 
       CF*Log[x]*((-256545436724162675651876563*NM*NC)/12701338122973500 - 
         (1332235852*lm*NM*NC)/51975 - (16016*lm^2*NM*NC)/3 - 
         (4115540740237*NC*NL)/32744250 - (1332235852*lm*NC*NL)/51975 - 
         (16016*lm^2*NC*NL)/3 - (406460837934122287605525275566*NC*NH)/
          410063218879727958670125 - (1332235852*lm*NC*NH)/51975 - 
         (16016*lm^2*NC*NH)/3 - (108472731344*NM*NC*Pi^2)/45 - 
         (582824*NC*NL*Pi^2)/45 + (260234987483806688*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(156905298045*Sqrt[3]) + 
         CF*NC*(-12006757490172845250168283141624978333/
            336798590439883230054396000 - (2248255904*lm)/5775 - 96096*lm^2 - 
           (4334760016706159*Pi^2)/935550 + (15515936080176727166*
             Im[PolyLog[2, (-1)^(1/3)]])/(20136179915775*Sqrt[3]) - 
           64064*Zeta[3]) + CA*NC*(60034519048491675287808144733226056721/
            3367985904398832300543960000 + (842694326*lm)/4725 + 
           (88088*lm^2)/3 + (4334780208446189*Pi^2)/1871100 - 
           (7757968040088363583*Im[PolyLog[2, (-1)^(1/3)]])/
            (20136179915775*Sqrt[3]) + 32032*Zeta[3])), 
      (-2757783903404189759822216542097792591100812239*CF^2*NC)/
        108559669947081152158290162591360000 - (1127773239101*CF^2*lm*NC)/
        12806640 - 75400*CF^2*lm^2*NC - (119303488273825733347519166035756913*
         CF*NM*NC)/2365421613658076701728000 - (1851988731101*CF*lm*NM*NC)/
        230519520 - (37700*CF*lm^2*NM*NC)/9 + (314307629691399349*CF*NC*NL)/
        1452272976000 - (1851988731101*CF*lm*NC*NL)/230519520 - 
       (37700*CF*lm^2*NC*NL)/9 + 
       (36984409294692350643095592416404216758766121*CF*NC*NH)/
        4778569078441495246204706857301856000 - (1851988731101*CF*lm*NC*NH)/
        230519520 - (37700*CF*lm^2*NC*NH)/9 + 
       (26587578119594195081*CF^2*NC*Pi^2)/2126638800 + 338*CF^2*lm*NC*Pi^2 + 
       (963207160891711*CF*NM*NC*Pi^2)/41580 + (169*CF*lm*NM*NC*Pi^2)/9 - 
       (1574451853*CF*NC*NL*Pi^2)/124740 + (169*CF*lm*NC*NL*Pi^2)/9 + 
       (169*CF*lm*NC*NH*Pi^2)/9 - (27753421400139480875*CF^2*NC*Pi^3)/
        (149122795261968*Sqrt[3]) - (2749714832312521955*CF*NC*NH*Pi^3)/
        (2541865828329*Sqrt[3]) - (1723891*CF^2*NC*Pi^4)/405 + 
       (1431996255329141194018709*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1004714833077509400*Sqrt[3]) + (412962202998372131827*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(88965303991515*Sqrt[3]) - 
       (1318928*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (5550684280027896175*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (805447196631*Sqrt[3]) - (1257012494771438608*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (5550684280027896175*CF^2*NC*Pi*Log[3]^2)/(38661465438288*Sqrt[3]) - 
       (78563280923214913*CF*NC*NH*Pi*Log[3]^2)/(94143178827*Sqrt[3]) + 
       CF*((837741259129321318969*CF*NC)/5584335372 - 4303728*CF*lm*NC + 
         CA*(-52359601162811597619421/698041921500 + 1315028*lm)*NC + 
         (24266987211561533591*NM*NC)/87297210 - 239096*lm*NM*NC - 
         (908765*NC*NL)/3 - 239096*lm*NC*NL - (5840876293277*NC*NH)/
          95611230 - 239096*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-9619874659950247*CA + 100*(192313236355787*CF + 
            12474*(29113601147*NM + 59774*NL)))*Log[x]^3)/467775 + 
       (549934570675983505896859*CF^2*NC*PolyGamma[2, 1])/76255974849870 + 
       (3988129390697*CF*NM*NC*PolyGamma[2, 1])/216 - 
       (338602733338937498507*CF*NC*NH*PolyGamma[2, 1])/915071698198440 - 
       (36052212832827610451005733*CF^2*NC*Zeta[3])/5871710063439990 - 
       (204047618551*CF*NM*NC*Zeta[3])/108 - (822068*CF*NC*NL*Zeta[3])/3 + 
       (806356937167707392053*CF*NC*NH*Zeta[3])/457535849099220 + 
       CA*CF*NC*(13788706820750401241202368161840378911257341247/
          1085596699470811521582901625913600000 + (207350*lm^2)/9 - 
         (601528155511630397*Pi^2)/96228000 + (27753421400139480875*Pi^3)/
          (298245590523936*Sqrt[3]) + (1736059*Pi^4)/810 + 
         lm*(3080960475101/41912640 - (1859*Pi^2)/18) - 
         (1431996255329141194018709*Im[PolyLog[2, (-1)^(1/3)]])/
          (2009429666155018800*Sqrt[3]) + (659464*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/3 + (5550684280027896175*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1610894393262*Sqrt[3]) + 
         (5550684280027896175*Pi*Log[3]^2)/(77322930876576*Sqrt[3]) - 
         (549934570675983505896859*PolyGamma[2, 1])/152511949699740 + 
         (36054691163602269121331897*Zeta[3])/11743420126879980) + 
       CF*Log[x]*((710554037350562207993751763*NM*NC)/5080535249189400 - 
         (1047323264*lm*NM*NC)/10395 - (52052*lm^2*NM*NC)/3 - 
         (25394329629173*NC*NL)/52390800 - (1047323264*lm*NC*NL)/10395 - 
         (52052*lm^2*NC*NL)/3 - (2344360283373544341719942068206137*NC*NH)/
          297495007251258637901480400 - (1047323264*lm*NC*NH)/10395 - 
         (52052*lm^2*NC*NH)/3 + (174681542818*NM*NC*Pi^2)/9 - 
         (410696*NC*NL*Pi^2)/9 + (1257012494771438608*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(12493843092868971029475350687293378247/
            155445503279946106178952000 - (1824106258*lm)/1155 - 
           312312*lm^2 + (3847764009869851*Pi^2)/374220 + 
           (5550684280027896175*Im[PolyLog[2, (-1)^(1/3)]])/
            (2416341589893*Sqrt[3]) - 208208*Zeta[3]) + 
         CA*NC*(-567892692133833546548037884468588219/
            14131409389086009652632000 + (638436292*lm)/945 + 
           (286286*lm^2)/3 - (3847739387965159*Pi^2)/748440 - 
           (5550684280027896175*Im[PolyLog[2, (-1)^(1/3)]])/
            (4832683179786*Sqrt[3]) + 104104*Zeta[3])), 
      (11164109188278454528388537519476591356407188322261*CF^2*NC)/
        84676542558723298683466326821260800000 - (24020190706003*CF^2*lm*NC)/
        2305195200 - (363987*CF^2*lm^2*NC)/10 + 
       (29112796172236790177068767211195608901*CF*NM*NC)/
        425775890458453806311040000 - (86949772100683*CF*lm*NM*NC)/
        41493513600 - (40443*CF*lm^2*NM*NC)/20 + 
       (193166076940149149*CF*NC*NL)/1697461920000 - 
       (86949772100683*CF*lm*NC*NL)/41493513600 - (40443*CF*lm^2*NC*NL)/
        20 + (3246614071172322722030028072880032401906875673*CF*NC*NH)/
        2006999012945428003405976880066779520000 - 
       (86949772100683*CF*lm*NC*NH)/41493513600 - (40443*CF*lm^2*NC*NH)/
        20 - (1909938434655161900663347*CF^2*NC*Pi^2)/30566888352000 - 
       (169*CF^2*lm*NC*Pi^2)/90 - (774317723377707011*CF*NM*NC*Pi^2)/
        22453200 - (169*CF*lm*NM*NC*Pi^2)/1620 - 
       (34553255243*CF*NC*NL*Pi^2)/5613300 - (169*CF*lm*NC*NL*Pi^2)/1620 - 
       (169*CF*lm*NC*NH*Pi^2)/1620 - (952316701049155885499*CF^2*NC*Pi^3)/
        (8947367715718080*Sqrt[3]) - (14247034337312170247*CF*NC*NH*Pi^3)/
        (61004779879896*Sqrt[3]) - (25476893*CF^2*NC*Pi^4)/10800 + 
       (265074770067475137115759*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2460526121822472000*Sqrt[3]) + (540937387641615818485*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(213516729579636*Sqrt[3]) - 
       (4060693*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (136045243007022269357*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (34519165569900*Sqrt[3]) - (4070581239232048642*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) - 
       (136045243007022269357*CF^2*NC*Pi*Log[3]^2)/(1656919947355200*
         Sqrt[3]) - (2035290619616024321*CF*NC*NH*Pi*Log[3]^2)/
        (11297181459240*Sqrt[3]) - 
       (CF*NC*(-253*CA*(4948506331886869439621237 + 8661755086711927200*lm) + 
          6*(23*CF*(18144531182067760771773733 + 51970530520271563200*lm) + 
            4620*(23*(2167574179868381961811 + 624946254452520*lm)*NM + 
              6380456082*(2535701 + 2252780*lm)*NL + (4144384587779123 + 
                14373763852407960*lm)*NH)))*Log[x]^2)/3339432552456000 + 
       (CF*NC*(194139433016422613*CA - 8*(48537048976436476*CF + 
            1155*(22831389837986*NM - 16107377*NL)))*Log[x]^3)/1871100 - 
       (371708265868237101864003287*CF^2*NC*PolyGamma[2, 1])/
        9150716981984400 - (73808214453737*CF*NM*NC*PolyGamma[2, 1])/4050 - 
       (2938436497279993831403*CF*NC*NH*PolyGamma[2, 1])/13726075472976600 + 
       CA*CF*NC*(-446565333709674671930358227277181512951496544051/
          6774123404697863894677306145700864000 + (444873*lm^2)/40 + 
         (8642256746442360473303*Pi^2)/276623424000 + 
         (952316701049155885499*Pi^3)/(17894735431436160*Sqrt[3]) + 
         (76425271*Pi^4)/64800 + lm*(193739364770443/7544275200 + 
           (1859*Pi^2)/3240) - (265074770067475137115759*
           Im[PolyLog[2, (-1)^(1/3)]])/(4921052243644944000*Sqrt[3]) + 
         (4060693*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (136045243007022269357*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (69038331139800*Sqrt[3]) + (136045243007022269357*Pi*Log[3]^2)/
          (3313839894710400*Sqrt[3]) + (371708265868237101864003287*
           PolyGamma[2, 1])/18301433963968800 - (3966545802915271738516517893*
           Zeta[3])/352302603806399400) + (991647663246291353969576977*CF^2*
         NC*Zeta[3])/44037825475799925 + (40349741699683*CF*NM*NC*Zeta[3])/
        2025 - (18449548*CF*NC*NL*Zeta[3])/135 - 
       (4070688228198313208483*CF*NC*NH*Zeta[3])/6863037736488300 + 
       CF*Log[x]*((-103433241142401868825300280363*NM*NC)/
          457248172427046000 - (156962849069*lm*NM*NC)/3742200 - 
         (26026*lm^2*NM*NC)/3 - (3866823044729*NC*NL)/17496000 - 
         (156962849069*lm*NC*NL)/3742200 - (26026*lm^2*NC*NL)/3 - 
         (107593944924391002493964178988647847*NC*NH)/
          62473951522764313959310884000 - (156962849069*lm*NC*NH)/3742200 - 
         (26026*lm^2*NC*NH)/3 - (22831439126797*NM*NC*Pi^2)/810 - 
         (18449717*NC*NL*Pi^2)/810 + (4070581239232048642*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(-11791729908549703797385914406731517609681/
            30311873139589490704895640000 - (132614224769*lm)/207900 - 
           156156*lm^2 - (388280778247856863*Pi^2)/7484400 + 
           (136045243007022269357*Im[PolyLog[2, (-1)^(1/3)]])/
            (103557496709700*Sqrt[3]) - 104104*Zeta[3]) + 
         CA*NC*(47167008826875960894534720108562300692691/
            242494985116715925639165120000 + (198281726669*lm)/680400 + 
           (143143*lm^2)/3 + (388281062521160023*Pi^2)/14968800 - 
           (136045243007022269357*Im[PolyLog[2, (-1)^(1/3)]])/
            (207114993419400*Sqrt[3]) + 52052*Zeta[3])), 
      (-21271889496827408892510482787641885869520736240919*CF^2*NC)/
        72579893621762827442971137275366400000 - (1219414334933*CF^2*lm*NC)/
        9408960 - (221949*CF^2*lm^2*NC)/2 - 
       (47099672862227724248615789194788876541*CF*NM*NC)/
        85155178091690761262208000 - (2002530308573*CF*lm*NM*NC)/169361280 - 
       (24661*CF*lm^2*NM*NC)/4 + (6903677492774085523*CF*NC*NL)/
        17971878078000 - (2002530308573*CF*lm*NC*NL)/169361280 - 
       (24661*CF*lm^2*NC*NL)/4 + 
       (1988326731497332816529618628838103387469291617303*CF*NC*NH)/
        150524925970907100255448266005008464000000 - 
       (2002530308573*CF*lm*NC*NH)/169361280 - (24661*CF*lm^2*NC*NH)/4 + 
       (25484665202710401955913*CF^2*NC*Pi^2)/181945764000 + 
       (8281*CF^2*lm*NC*Pi^2)/18 + (224934998436724861*CF*NM*NC*Pi^2)/
        898128 + (8281*CF*lm*NM*NC*Pi^2)/324 - (6440305781*CF*NC*NL*Pi^2)/
        320760 + (8281*CF*lm*NC*NL*Pi^2)/324 + (8281*CF*lm*NC*NH*Pi^2)/
        324 - (1057580764064292999209*CF^2*NC*Pi^3)/(3355262893394280*
         Sqrt[3]) - (338422306919034574985*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) - (6165341*CF^2*NC*Pi^4)/900 + 
       (30913039078652839836903671*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (12917762139567978000*Sqrt[3]) + (282220228583793962021269*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(35230260380639940*Sqrt[3]) - 
       (10409308*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (302165932589797999774*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (25889374177425*Sqrt[3]) - (19338417538230547142*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (151082966294898999887*CF^2*NC*Pi*Log[3]^2)/(621344980258200*
         Sqrt[3]) - (9669208769115273571*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) - 
       (CF*NC*(-23*CA*(-1743137812945596045340799 + 4728035634565042800*lm) + 
          12*(46*CF*(-145261152684254972246809 + 644732131986142200*lm) + 
            33*(6325*(-57242529297688826249 + 7893873669864*lm)*NM + 
              14501036550*(4347067 + 3443116*lm)*NL + 3*(4502882269191429 + 
                16642916987296600*lm)*NH)))*Log[x]^2)/47706179320800 + 
       (CF*NC*(-62013672052002337*CA + 8*(15502294405887356*CF + 
            825*(34096258233248*NM + 11190127*NL)))*Log[x]^3)/267300 + 
       (1123290664448805829487984587*CF^2*NC*PolyGamma[2, 1])/
        13726075472976600 + (624166266482933*CF*NM*NC*PolyGamma[2, 1])/
        3240 - (2567764470124749759113*CF*NC*NH*PolyGamma[2, 1])/
        4117822641892980 - (2579029301091185344318469519*CF^2*NC*Zeta[3])/
        37746707550685650 - (57754148134387*CF*NM*NC*Zeta[3])/1620 - 
       (12688988*CF*NC*NL*Zeta[3])/27 + (6201638424096250932547*CF*NC*NH*
         Zeta[3])/2058911320946490 + CA*CF*NC*
        (21271840873787635687072428880015956780673638281017/
          145159787243525654885942274550732800000 + (271271*lm^2)/8 - 
         (3920717008292921732453*Pi^2)/55983312000 + 
         (1057580764064292999209*Pi^3)/(6710525786788560*Sqrt[3]) + 
         (55819309*Pi^4)/16200 + lm*(3331454385053/30792960 - 
           (91091*Pi^2)/648) - (30913039078652839836903671*
           Im[PolyLog[2, (-1)^(1/3)]])/(25835524279135956000*Sqrt[3]) + 
         (5204654*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (151082966294898999887*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (25889374177425*Sqrt[3]) + (151082966294898999887*Pi*Log[3]^2)/
          (1242689960516400*Sqrt[3]) - (1123290664448805829487984587*
           PolyGamma[2, 1])/27452150945953200 + (257905625923131841697655647*
           Zeta[3])/7549341510137130) + CF*Log[x]*
        ((273286421944197289380925778113*NM*NC)/182899268970818400 - 
         (17232814417*lm*NM*NC)/106920 - (82810*lm^2*NM*NC)/3 - 
         (3430341843643571*NC*NL)/4149351360 - (17232814417*lm*NC*NL)/
          106920 - (82810*lm^2*NC*NL)/3 - 
         (12621374837242870358888541916625594813*NC*NH)/
          937109272841464709389663260000 - (17232814417*lm*NC*NH)/106920 - 
         (82810*lm^2*NC*NH)/3 + (34096257495667*NM*NC*Pi^2)/162 - 
         (12680707*NC*NL*Pi^2)/162 + (19338417538230547142*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(22844119971771315185614035911898280739741/
            25981605548219563461339120000 - (15019303117*lm)/5940 - 
           496860*lm^2 + (62013209838547423*Pi^2)/534600 + 
           (302165932589797999774*Im[PolyLog[2, (-1)^(1/3)]])/
            (77668122532275*Sqrt[3]) - 331240*Zeta[3]) + 
         CA*NC*(-45688127244265148067483402568829421465823/
            103926422192878253845356480000 + (20989076017*lm)/19440 + 
           (455455*lm^2)/3 - (62013149746531747*Pi^2)/1069200 - 
           (151082966294898999887*Im[PolyLog[2, (-1)^(1/3)]])/
            (77668122532275*Sqrt[3]) + 165620*Zeta[3])), 
      (27827643021096184581341598967557718474628746698748304531*CF^2*NC)/
        18785510761169206111879943597425056307200000 - 
       (30286638511027*CF^2*lm*NC)/1987642800 - (264348*CF^2*lm^2*NC)/5 + 
       (1040146335003065356029748938247451580030167*CF*NM*NC)/
        1295103814802001865346605920000 - (109101048345187*CF*lm*NM*NC)/
        35777570400 - (14686*CF*lm^2*NM*NC)/5 + 
       (5978416919396261879431*CF*NC*NL)/30372473951820000 - 
       (109101048345187*CF*lm*NC*NL)/35777570400 - (14686*CF*lm^2*NC*NL)/
        5 + (5915549544367695502790264612010254422726009321*CF*NC*NH)/
        2213601852513339709638945088308948000000 - 
       (109101048345187*CF*lm*NC*NH)/35777570400 - (14686*CF*lm^2*NC*NH)/
        5 - (1559604025225463736829487*CF^2*NC*Pi^2)/2270683134720 - 
       (98*CF^2*lm*NC*Pi^2)/45 - (28528424786103039293*CF*NM*NC*Pi^2)/
        72972900 - (49*CF*lm*NM*NC*Pi^2)/405 - (50191541869*CF*NC*NL*Pi^2)/
        5212350 - (49*CF*lm*NC*NL*Pi^2)/405 - (49*CF*lm*NC*NH*Pi^2)/405 - 
       (27352783495222227410179*CF^2*NC*Pi^3)/(157026303410852304*Sqrt[3]) - 
       (17835039985564337291*CF*NC*NH*Pi^3)/(45753584909922*Sqrt[3]) - 
       (10147249*CF^2*NC*Pi^4)/2700 + (794570685759983718843874889*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3929583242856578907600*Sqrt[3]) + 
       (7274942086513444477187*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1761513019031997*Sqrt[3]) - (1258964*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (3907540499317461058597*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(605811355751745*Sqrt[3]) - 
       (20382902840644956904*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1412147682405*Sqrt[3]) - (3907540499317461058597*CF^2*NC*Pi*
         Log[3]^2)/(29078945076083760*Sqrt[3]) - 
       (2547862855080619613*CF*NC*NH*Pi*Log[3]^2)/(8472886094430*Sqrt[3]) - 
       (CF*NC*(-(CA*(1277901724127660328578671213 + 346524276202594570080*
              lm)) + 9*(CF*(283978180284864748415949037 + 
              126008827710034389120*lm) + 1144*(3*(47097261991135697680511 + 
                2039769938326120*lm)*NM + 17*(34120086*(11805961 + 
                  10549780*lm)*NL + (109748601832913 + 359959400881080*lm)*
                 NH))))*Log[x]^2)/310090165585200 + 
       (CF*NC*(996025959134128271*CA - 1430*(1393053718152475*CF + 
            783010820956272*NM - 82288284*NL))*Log[x]^3)/868725 - 
       (27362153045074540925172753161*CF^2*NC*PolyGamma[2, 1])/
        61767339628394700 - (1727929468502233*CF*NM*NC*PolyGamma[2, 1])/
        8100 - (1201027564199094917039*CF*NC*NH*PolyGamma[2, 1])/
        3431518868244150 + CA*CF*NC*
        (-76526042480713375123944459510910116433526687484856837909/
          103320309186430633615339689785837809689600000 + (80773*lm^2)/5 + 
         (4873762690485989872226797*Pi^2)/14191769592000 + 
         (27352783495222227410179*Pi^3)/(314052606821704608*Sqrt[3]) + 
         (30440179*Pi^4)/16200 + lm*(242846713518307/6505012800 + 
           (539*Pi^2)/810) - (794570685759983718843874889*
           Im[PolyLog[2, (-1)^(1/3)]])/(7859166485713157815200*Sqrt[3]) + 
         (629482*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (3907540499317461058597*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1211622711503490*Sqrt[3]) + (3907540499317461058597*Pi*Log[3]^2)/
          (58157890152167520*Sqrt[3]) + (27362153045074540925172753161*
           PolyGamma[2, 1])/123534679256789400 - 
         (575379116182210437464500949539*Zeta[3])/4416364783430221050) + 
       (2301520201780200608030155344763*CF^2*NC*Zeta[3])/
        8832729566860442100 + (882109969183127*CF*NM*NC*Zeta[3])/4050 - 
       (31098352*CF*NC*NL*Zeta[3])/135 - (1550038926239429550119*CF*NC*NH*
         Zeta[3])/1715759434122075 + CF*Log[x]*
        ((-301586336395636683825692110225279*NM*NC)/120942141606953667000 - 
         (114841240451*lm*NM*NC)/1737450 - (40768*lm^2*NM*NC)/3 - 
         (125598996095521733*NC*NL)/337134798000 - (114841240451*lm*NC*NL)/
          1737450 - (40768*lm^2*NC*NL)/3 - 
         (39600826442429990055586001134801381*NC*NH)/
          13781018718256833961612695000 - (114841240451*lm*NC*NH)/1737450 - 
         (40768*lm^2*NC*NH)/3 - (130501844585894*NM*NC*Pi^2)/405 - 
         (15549274*NC*NL*Pi^2)/405 + (20382902840644956904*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) + 
         CF*NC*(-26992444829946248088528156441273091900324703243/
            6432318048783813765250648616640000 - (97133150051*lm)/96525 - 
           244608*lm^2 - (3984106891806948677*Pi^2)/6949800 + 
           (3907540499317461058597*Im[PolyLog[2, (-1)^(1/3)]])/
            (1817434067255235*Sqrt[3]) - 163072*Zeta[3]) + 
         CA*NC*(613464830404579465001010698900265773736426283/
            292378093126536989329574937120000 + (144891333251*lm)/315900 + 
           (224224*lm^2)/3 + (1992053668488451453*Pi^2)/6949800 - 
           (3907540499317461058597*Im[PolyLog[2, (-1)^(1/3)]])/
            (3634868134510470*Sqrt[3]) + 81536*Zeta[3])), 
      (-13704753107519871792107252565831843822909100268683718797*CF^2*NC)/
        4132812367457225344613587591433512387584000 - 
       (6554042730745*CF^2*lm*NC)/35335872 - (317695*CF^2*lm^2*NC)/2 - 
       (76948155913231300214373153892146166012207*CF*NM*NC)/
        12791148788167919657744256000 - (10763803926385*CF*lm*NM*NC)/
        636045696 - (317695*CF*lm^2*NM*NC)/36 + 
       (44042789021158866023*CF*NC*NL)/67494386559600 - 
       (10763803926385*CF*lm*NC*NL)/636045696 - (317695*CF*lm^2*NC*NL)/36 + 
       (9808204698359766069556929549635504874405302117537*CF*NC*NH)/
        451574777912721300766344798015025392000000 - 
       (10763803926385*CF*lm*NC*NH)/636045696 - (317695*CF*lm^2*NC*NH)/36 + 
       (200129128027745677179387427*CF^2*NC*Pi^2)/129428938679040 + 
       (1225*CF^2*lm*NC*Pi^2)/2 + (1936223770475812877*CF*NM*NC*Pi^2)/
        720720 + (1225*CF*lm*NM*NC*Pi^2)/36 - (2862186985*CF*NC*NL*Pi^2)/
        92664 + (1225*CF*lm*NC*NL*Pi^2)/36 + (1225*CF*lm*NC*NH*Pi^2)/36 - 
       (29327402294454105482165*CF^2*NC*Pi^3)/(57100473967582656*Sqrt[3]) - 
       (1671817367289855555035*CF*NC*NH*Pi^3)/(549043018919064*Sqrt[3]) - 
       (13794361*CF^2*NC*Pi^4)/1296 + (221823258826227866595347719*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(57157574441550238656*Sqrt[3]) + 
       (1407959946471516767847487*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (105690781141919820*Sqrt[3]) - 
       (3181255*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (837925779841545870919*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (44059007691036*Sqrt[3]) - (95532420987991746002*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (837925779841545870919*CF^2*NC*Pi*Log[3]^2)/(2114832369169728*
         Sqrt[3]) - (47766210493995873001*CF*NC*NH*Pi*Log[3]^2)/
        (20334926626632*Sqrt[3]) + CF*((2301481541409251870588300761*CF*NC)/
          124036066234080 - 12421890*CF*lm*NC + 
         CA*(-11507411672511555152693976839/1240360662340800 + 
           (7591155*lm)/2)*NC + (258915701684848415155439*NM*NC)/
          8031343320 - 690105*lm*NM*NC - (3474965*NC*NL)/4 - 
         690105*lm*NC*NL - (23634576234556171*NC*NH)/120470149800 - 
         690105*lm*NC*NH)*Log[x]^2 + (CF*NC*(-1790722176059672191*CA + 
          4*(895350662563257917*CF + 115830*(13590524736716*NM + 
              690105*NL)))*Log[x]^3)/694980 + 
       (37614995503030086918479619991*CF^2*NC*PolyGamma[2, 1])/
        41178226418929800 + (48167240176405*CF*NM*NC*PolyGamma[2, 1])/24 - 
       (37555181065764128314471*CF*NC*NH*PolyGamma[2, 1])/
        37060403777036820 - (4414665535410423239486637267749*CF^2*NC*Zeta[3])/
        5888486377906961400 - (6194799895187*CF*NM*NC*Zeta[3])/12 - 
       (2326340*CF*NC*NL*Zeta[3])/3 + (91753348504404574415309*CF*NC*NH*
         Zeta[3])/18530201888518410 + CA*CF*NC*
        (68523742715798114118706166684624190361300558086941712719/
          41328123674572253446135875914335123875840000 + (3494645*lm^2)/72 - 
         (52665558652323224578133201*Pi^2)/68120494041600 + 
         (29327402294454105482165*Pi^3)/(114200947935165312*Sqrt[3]) + 
         (13864921*Pi^4)/2592 + lm*(17907641106865/115644672 - 
           (13475*Pi^2)/72) - (221823258826227866595347719*
           Im[PolyLog[2, (-1)^(1/3)]])/(114315148883100477312*Sqrt[3]) + 
         (3181255*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (837925779841545870919*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (88118015382072*Sqrt[3]) + (837925779841545870919*Pi*Log[3]^2)/
          (4229664738339456*Sqrt[3]) - (37614995503030086918479619991*
           PolyGamma[2, 1])/82356452837859600 + 
         (4414672399165122521147756900729*Zeta[3])/11776972755813922800) + 
       CF*Log[x]*((34030200880921150981841319890887*NM*NC)/
          2150082517456954080 - (7695702329*lm*NM*NC)/30888 - 
         (127400*lm^2*NM*NC)/3 - (8136679345426991*NC*NL)/5993507520 - 
         (7695702329*lm*NC*NL)/30888 - (127400*lm^2*NC*NL)/3 - 
         (62339342404043463984315814005343425977*NC*NH)/
          2811327818524394128168989780000 - (7695702329*lm*NC*NH)/30888 - 
         (127400*lm^2*NC*NH)/3 + (40771574281115*NM*NC*Pi^2)/18 - 
         (2325115*NC*NL*Pi^2)/18 + (95532420987991746002*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(6111907729941266019416944175233078554074456611/
            643231804878381376525064861664000 - (6711919529*lm)/1716 - 
           764400*lm^2 + (3581440336068738569*Pi^2)/2779920 + 
           (837925779841545870919*Im[PolyLog[2, (-1)^(1/3)]])/
            (132177023073108*Sqrt[3]) - 509600*Zeta[3]) + 
         CA*NC*(-1527976375719589380217742776057259771887718089/
            321615902439190688262532430832000 + (9365151929*lm)/5616 + 
           (700700*lm^2)/3 - (3581439822122057321*Pi^2)/5559840 - 
           (837925779841545870919*Im[PolyLog[2, (-1)^(1/3)]])/
            (264354046146216*Sqrt[3]) + 254800*Zeta[3])), 
      (97093043389374883195472088920313756724273339076957219310751*CF^2*NC)/
        5917435889768299925242182233188892736768000000 - 
       (187674693048047*CF^2*lm*NC)/8657288640 - (149629*CF^2*lm^2*NC)/2 + 
       (132536327719633741173973375533849804551230601*CF*NM*NC)/
        14390042386688909614962288000000 - (673442733766007*CF*lm*NM*NC)/
        155831195520 - (149629*CF*lm^2*NM*NC)/36 + 
       (588880735588785990893*CF*NC*NL)/1799850308256000 - 
       (673442733766007*CF*lm*NC*NL)/155831195520 - (149629*CF*lm^2*NC*NL)/
        36 + (5784287481016232065340402741422220998130149225957*CF*NC*NH)/
        1354724333738163902299034394045076176000000 - 
       (673442733766007*CF*lm*NC*NH)/155831195520 - (149629*CF*lm^2*NC*NH)/
        36 - (6761487274196966506066830389*CF^2*NC*Pi^2)/906002570753280 - 
       (5*CF^2*lm*NC*Pi^2)/2 - (28254312177448543187*CF*NM*NC*Pi^2)/
        6486480 - (5*CF*lm*NM*NC*Pi^2)/36 - (4735186847*CF*NC*NL*Pi^2)/
        324324 - (5*CF*lm*NC*NL*Pi^2)/36 - (5*CF*lm*NC*NH*Pi^2)/36 - 
       (389022791584011885436267*CF^2*NC*Pi^3)/(1413236730697670736*
         Sqrt[3]) - (1034975639840916879595*CF*NC*NH*Pi^3)/
        (1647129056757192*Sqrt[3]) - (4687789*CF^2*NC*Pi^4)/810 + 
       (3545250987264316052292216737*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (9902549771998578847152*Sqrt[3]) + (2069338947064565045487977*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(317072343425759460*Sqrt[3]) - 
       (1893784*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (389022791584011885436267*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(38166115412359935*Sqrt[3]) - 
       (59141465133766678834*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2541865828329*Sqrt[3]) - (389022791584011885436267*CF^2*NC*Pi*
         Log[3]^2)/(1831973539793276880*Sqrt[3]) - 
       (29570732566883339417*CF*NC*NH*Pi*Log[3]^2)/(61004779879896*
         Sqrt[3]) - (CF*NC*(-1001*CA*(194198587468821625999983217 + 
            7946267219897806800*lm) + 4*(CF*(97196394030991493513808915913 + 
              6507992853096303769200*lm) + 
            9009*(9*(699670955970470889330983 + 4459184747417400*lm)*NM + 
              43503109650*(1027273 + 922524*lm)*NL + (12843271942680037 + 
                40132662726756600*lm)*NH)))*Log[x]^2)/4341262318192800 + 
       (CF*NC*(60897320861586525083*CA - 308*(395437623649720997*CF + 
            45630*(5006236822462*NM - 76877*NL)))*Log[x]^3)/4864860 - 
       (425875842452535452692046145119*CF^2*NC*PolyGamma[2, 1])/
        88944969064888368 - (4386497003868781*CF*NM*NC*PolyGamma[2, 1])/
        1800 - (102673556156149608677767*CF*NC*NH*PolyGamma[2, 1])/
        185302018885184100 + CA*CF*NC*
        (-267005881437253492423125807908058671626791494717433874669559/
          32545897393725649588832002282538910052224000000 + 
         (1645919*lm^2)/72 + (177933876207330315938481601*Pi^2)/
          47684345829120 + (389022791584011885436267*Pi^3)/
          (2826473461395341472*Sqrt[3]) + (4687609*Pi^4)/1620 + 
         lm*(1497776378620727/28332944640 + (55*Pi^2)/72) - 
         (3545250987264316052292216737*Im[PolyLog[2, (-1)^(1/3)]])/
          (19805099543997157694304*Sqrt[3]) + 
         (946892*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (389022791584011885436267*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (76332230824719870*Sqrt[3]) + (389022791584011885436267*Pi*
           Log[3]^2)/(3663947079586553760*Sqrt[3]) + 
         (425875842452535452692046145119*PolyGamma[2, 1])/
          177889938129776736 - (50366429281959872645835991154623*Zeta[3])/
          34243813089982021680) + (50366440919231776939693815293683*CF^2*NC*
         Zeta[3])/17121906544991010840 + (2121612071422619*CF*NM*NC*Zeta[3])/
        900 - (1123156*CF*NC*NL*Zeta[3])/3 - 
       (124108573081825374094267*CF*NC*NH*Zeta[3])/92651009442592050 + 
       CF*Log[x]*((-3644080400346439269347353773065419*NM*NC)/
          134380157341059630000 - (21805498277*lm*NM*NC)/216216 - 
         (61880*lm^2*NM*NC)/3 - (123451463101123*NC*NL)/203860800 - 
         (21805498277*lm*NC*NL)/216216 - (61880*lm^2*NC*NL)/3 - 
         (39051531232421514650490398637884517397*NC*NH)/
          8433983455573182384506969340000 - (21805498277*lm*NC*NH)/216216 - 
         (61880*lm^2*NC*NH)/3 - (21693693876413*NM*NC*Pi^2)/6 - 
         (374387*NC*NL*Pi^2)/6 + (59141465133766678834*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(-18157363796356574408369679434244530086788832459361/
            405236037073380267210790862848320000 - (18460636757*lm)/12012 - 
           371280*lm^2 - (2342204920573954243*Pi^2)/374220 + 
           (389022791584011885436267*Im[PolyLog[2, (-1)^(1/3)]])/
            (114498346237079805*Sqrt[3]) - 247520*Zeta[3]) + 
         CA*NC*(4539341140376051604267399063286078184937793072199/
            202618018536690133605395431424160000 + (27481626917*lm)/39312 + 
           (340340*lm^2)/3 + (936881983819016743*Pi^2)/299376 - 
           (389022791584011885436267*Im[PolyLog[2, (-1)^(1/3)]])/
            (228996692474159610*Sqrt[3]) + 123760*Zeta[3])), 
      (-13055485512345256507416613556081072266097802402614812672451*CF^2*NC)/
        353759754279626625965565242201509891872000000 - 
       (28039993996195*CF^2*lm*NC)/108216108 - 221960*CF^2*lm^2*NC - 
       (29170858790033426229352373257337884604295317*CF*NM*NC)/
        449688824584028425467571500000 - (46054729494955*CF*lm*NM*NC)/
        1947889944 - (110980*CF*lm^2*NM*NC)/9 + 
       (45416977558376852159*CF*NC*NL)/42541916376960 - 
       (46054729494955*CF*lm*NC*NL)/1947889944 - (110980*CF*lm^2*NC*NL)/9 + 
       (128519193266181228235852702988647217288531184512518343*CF*NC*NH)/
        3717041824748258933981754356591103321352200000 - 
       (46054729494955*CF*lm*NC*NH)/1947889944 - (110980*CF*lm^2*NC*NH)/9 + 
       (136312016684524694042655601*CF^2*NC*Pi^2)/8089308667440 + 
       800*CF^2*lm*NC*Pi^2 + (11591849313499179247*CF*NM*NC*Pi^2)/405405 + 
       (400*CF*lm*NM*NC*Pi^2)/9 - (3742732745*CF*NC*NL*Pi^2)/81081 + 
       (400*CF*lm*NC*NL*Pi^2)/9 + (400*CF*lm*NC*NH*Pi^2)/9 - 
       (52001410097112681273035*CF^2*NC*Pi^3)/(64238033213530488*Sqrt[3]) - 
       (8994264644105016209920*CF*NC*NH*Pi^3)/(1853020188851841*Sqrt[3]) - 
       (1299571*CF^2*NC*Pi^4)/81 + (13740151521573631528152543371*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2250579493636040647080*Sqrt[3]) + 
       (15300656615055187166630764*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (713412772707958785*Sqrt[3]) - 
       (4726480*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (20800564038845072509214*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(693929371133817*Sqrt[3]) - 
       (4111663837305150267392*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (10400282019422536254607*CF^2*NC*Pi*Log[3]^2)/(16654304907211608*
         Sqrt[3]) - (256978989831571891712*CF*NC*NH*Pi*Log[3]^2)/
        (68630377364883*Sqrt[3]) + CF*((1192729884124434412199094383*CF*NC)/
          5898454236675 - 19978320*CF*lm*NC + 
         CA*(-954183955843730106455471323/9437526778680 + (18313460*lm)/3)*
          NC + (191368550892394591374598*NM*NC)/557732175 - 
         (3329720*lm*NM*NC)/3 - (12543694*NC*NL)/9 - (3329720*lm*NC*NL)/
          3 - (3197382156688696*NC*NH)/9704539845 - (3329720*lm*NC*NH)/3)*
        Log[x]^2 + (4*CF*NC*(-8583420151114660618*CA + 17166808997258951951*
           CF + 540540*(54421001215213*NM + 416215*NL))*Log[x]^3)/1216215 + 
       (1396935608734727688928984512644*CF^2*NC*PolyGamma[2, 1])/
        138976514163888075 + (1877223359858641*CF*NM*NC*PolyGamma[2, 1])/
        90 - (266094728389620740366473*CF*NC*NH*PolyGamma[2, 1])/
        166771816996665690 - (1130556168379953080477108984700262*CF^2*NC*
         Zeta[3])/139115490678051963075 - (299616332270639*CF*NM*NC*Zeta[3])/
        45 - (3712120*CF*NC*NL*Zeta[3])/3 + (656364812145084743354807*CF*NC*
         NH*Zeta[3])/83385908498332845 + 
       CA*CF*NC*(1631935611062528771063749343938606572966357894529485424147/
          88439938569906656491391310550377472968000000 + (610390*lm^2)/9 - 
         (1363120161988826924260190077*Pi^2)/161786173348800 + 
         (52001410097112681273035*Pi^3)/(128476066427060976*Sqrt[3]) + 
         (1305331*Pi^4)/162 + lm*(76625189735275/354161808 - (2200*Pi^2)/9) - 
         (13740151521573631528152543371*Im[PolyLog[2, (-1)^(1/3)]])/
          (4501158987272081294160*Sqrt[3]) + 
         (2363240*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (10400282019422536254607*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (693929371133817*Sqrt[3]) + (10400282019422536254607*Pi*Log[3]^2)/
          (33308609814423216*Sqrt[3]) - (698467804367363844464492256322*
           PolyGamma[2, 1])/138976514163888075 + 
         (1130556424825482602406930129857347*Zeta[3])/
          278230981356103926150) + CF*Log[x]*
        ((11177244030031015050760510958849293*NM*NC)/67190078670529815000 - 
         (10105727134*lm*NM*NC)/27027 - (190400*lm^2*NM*NC)/3 - 
         (1273353983744809*NC*NL)/590269680 - (10105727134*lm*NC*NL)/
          27027 - (190400*lm^2*NC*NL)/3 - 
         (8677078688291470076715448503529162374601*NC*NH)/
          245526233750897759493589426671000 - (10105727134*lm*NC*NH)/27027 - 
         (190400*lm^2*NC*NH)/3 + (72561335022368*NM*NC*Pi^2)/3 - 
         206140*NC*NL*Pi^2 + (4111663837305150267392*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(223739883062582465712306749221022346322741979891/
            2202369766703153626145602515480000 - (17638483868*lm)/3003 - 
           1142400*lm^2 + (34333674936708760681*Pi^2)/2432430 + 
           (20800564038845072509214*Im[PolyLog[2, (-1)^(1/3)]])/
            (2081788113401451*Sqrt[3]) - 761600*Zeta[3]) + 
         CA*NC*(-13983741953482665384025476461147018347986454061/
            275296220837894203268200314435000 + (6144426767*lm)/2457 + 
           (1047200*lm^2)/3 - (34333674221037194071*Pi^2)/4864860 - 
           (10400282019422536254607*Im[PolyLog[2, (-1)^(1/3)]])/
            (2081788113401451*Sqrt[3]) + 380800*Zeta[3])), 
      (3284935613248293403100813720674197549370913404855599879899201*CF^2*NC)/
        18307067283970677893718001283928136904376000000 - 
       (916703907361061*CF^2*lm*NC)/30435780375 - (517472*CF^2*lm^2*NC)/5 + 
       (2829487870147608989046019971556835628788334053*CF*NM*NC)/
        27318596093479726847154968625000 - (3279153528692861*CF*lm*NM*NC)/
        547844046750 - (258736*CF*lm^2*NM*NC)/45 + 
       (207466745336231190852533*CF*NC*NL)/394842161373660000 - 
       (3279153528692861*CF*lm*NC*NL)/547844046750 - (258736*CF*lm^2*NC*NL)/
        45 + (11543926120924906917616512037672458603984809779766357*CF*NC*
         NH)/1742363355350746375303947354652079681883843750 - 
       (3279153528692861*CF*lm*NC*NH)/547844046750 - (258736*CF*lm^2*NC*NH)/
        45 - (5163439195878311456818849859*CF^2*NC*Pi^2)/64346773491000 - 
       (128*CF^2*lm*NC*Pi^2)/45 - (96938956766401826924*CF*NM*NC*Pi^2)/
        2027025 - (64*CF*lm*NM*NC*Pi^2)/405 - (393038234588*CF*NC*NL*Pi^2)/
        18243225 - (64*CF*lm*NC*NL*Pi^2)/405 - (64*CF*lm*NC*NH*Pi^2)/405 - 
       (51610182974764200618277*CF^2*NC*Pi^3)/(122299332464221506*Sqrt[3]) - 
       (5462262484037082159520*CF*NC*NH*Pi^3)/(5559060566555523*Sqrt[3]) - 
       (3505148*CF^2*NC*Pi^4)/405 + (32381899521730927534402325111*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(53559463911050005783875*Sqrt[3]) + 
       (1396026703271995124233033904*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (139115490678051963075*Sqrt[3]) - 
       (4625088*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (412881463798113604946216*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(26422695285479955*Sqrt[3]) - 
       (2497034278416951844352*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (51610182974764200618277*CF^2*NC*Pi*Log[3]^2)/(158536171712879730*
         Sqrt[3]) - (156064642401059490272*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) - 
       (CF*NC*(-145*CA*(65317507159604454314675719493 + 394390673899610628240*
             lm) + 2*(29*CF*(326587536296423729685647922467 + 
              3226832786451359685600*lm) + 20020*
             (145*(1944430678662759859018651 + 1790893987374492*lm)*NM + 
              5822723907*(49449919 + 44597620*lm)*NL + (86705485117706269 + 
                259679628169301340*lm)*NH)))*Log[x]^2)/19671344879311125 - 
       (16*CF*NC*(-51378764772907461258*CA + 102757548873577572211*CF + 
          60060*(1010897733123797*NM - 2229881*NL))*Log[x]^3)/6081075 - 
       (64180174723476554027054448099286*CF^2*NC*PolyGamma[2, 1])/
        1250788627474992675 - (18424312903545293*CF*NM*NC*PolyGamma[2, 1])/
        675 - (1066609437641601287037757*CF*NC*NH*PolyGamma[2, 1])/
        1250788627474992675 + CA*CF*NC*
        (-205308477147517860650295253190222689902515695382982353621831/
          2288383410496334736714750160491017113047000000 + 
         (1423048*lm^2)/45 + (516343919815626850007363921*Pi^2)/
          12869354698200 + (51610182974764200618277*Pi^3)/
          (244598664928443012*Sqrt[3]) + (8762614*Pi^4)/2025 + 
         lm*(7288158946710461/99608008500 + (352*Pi^2)/405) - 
         (32381899521730927534402325111*Im[PolyLog[2, (-1)^(1/3)]])/
          (107118927822100011567750*Sqrt[3]) + 
         (2312544*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (206440731899056802473108*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (26422695285479955*Sqrt[3]) + (51610182974764200618277*Pi*Log[3]^2)/
          (317072343425759460*Sqrt[3]) + (32090087361738277013527224049643*
           PolyGamma[2, 1])/1250788627474992675 - 
         (20383107815720786642548778583829012*Zeta[3])/
          1252039416102467667675) + (8153243391709718215417913497544068*CF^2*
         NC*Zeta[3])/250407883220493533535 + 
       (17065921371483494*CF*NM*NC*Zeta[3])/675 - 
       (26527072*CF*NC*NL*Zeta[3])/45 - (2426359355906551818343034*CF*NC*NH*
         Zeta[3])/1250788627474992675 + CF*Log[x]*
        ((-396523955898528590999997171993748429*NM*NC)/
          1360599093078228753750 - (909912309304*lm*NM*NC)/6081075 - 
         30464*lm^2*NM*NC - (1044972814266137623*NC*NL)/1095688093500 - 
         (909912309304*lm*NC*NL)/6081075 - 30464*lm^2*NC*NL - 
         (86629455444093232064058205764924426445151*NC*NH)/
          11969403895356265775312484550211250 - (909912309304*lm*NC*NH)/
          6081075 - 30464*lm^2*NC*NH - (3234872766598400*NM*NC*Pi^2)/81 - 
         (39790736*NC*NL*Pi^2)/405 + (2497034278416951844352*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-54030815106121729191414431691360184800393978330833/
            113972635426888200153034930176090000 - (1541943815408*lm)/
            675675 - 548352*lm^2 - (45670013916418852742*Pi^2)/675675 + 
           (412881463798113604946216*Im[PolyLog[2, (-1)^(1/3)]])/
            (79268085856439865*Sqrt[3]) - 365568*Zeta[3]) + 
         CA*NC*(1039054142991439149544723564552498602626491852991/
            4383562901034161544347497314465000 + (572844980252*lm)/552825 + 
           167552*lm^2 + (13701004208176289639*Pi^2)/405405 - 
           (206440731899056802473108*Im[PolyLog[2, (-1)^(1/3)]])/
            (79268085856439865*Sqrt[3]) + 182784*Zeta[3])), 
      (-49418408188969779104245693136645519265751494858645748223452507*CF^2*
         NC)/122047115226471185958120008559520912695840000000 - 
       (8629665085916131*CF^2*lm*NC)/24348624300 - 303688*CF^2*lm^2*NC - 
       (6590762262092936168260761801519462100991999929*CF*NM*NC)/
        9502120380340774555532163000000 - (14175453848229931*CF*lm*NM*NC)/
        438275237400 - (151844*CF*lm^2*NM*NC)/9 + 
       (534026718894569413842247*CF*NC*NL)/315873729098928000 - 
       (14175453848229931*CF*lm*NC*NL)/438275237400 - 
       (151844*CF*lm^2*NC*NL)/9 + 
       (555374841930629062386689142581955173285061943791398604911*CF*NC*NH)/
        10381349343850817053335979128488021160600317831250 - 
       (14175453848229931*CF*lm*NC*NH)/438275237400 - 
       (151844*CF*lm^2*NC*NH)/9 + (16064306808489396786367419151*CF^2*NC*
         Pi^2)/88476813550125 + (9248*CF^2*lm*NC*Pi^2)/9 + 
       (367351053946136605361*CF*NM*NC*Pi^2)/1216215 + 
       (4624*CF*lm*NM*NC*Pi^2)/81 - (245412277933*CF*NC*NL*Pi^2)/3648645 + 
       (4624*CF*lm*NC*NL*Pi^2)/81 + (4624*CF*lm*NC*NH*Pi^2)/81 - 
       (2627369220905706671552927*CF^2*NC*Pi^3)/(2119855096046506104*
         Sqrt[3]) - (41803775011558340009600*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (47697631*CF^2*NC*Pi^4)/2025 + 
       (17359294871601977363407794520061*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1856728082249733533841000*Sqrt[3]) + 
       (186736124856195257351742676*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5564619627122078523*Sqrt[3]) - 
       (11419376*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (5254738441811413343105854*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(114498346237079805*
         Sqrt[3]) - (19110297148140955432960*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (2627369220905706671552927*CF^2*NC*Pi*Log[3]^2)/(2747960309689915320*
         Sqrt[3]) - (1194393571758809714560*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + 
       CF*((2955832358957209138090577234251*CF*NC)/1356644474435250 - 
         (93519856*CF*lm*NC)/3 + CA*(-5911664761482827509437202805611/
            5426577897741000 + (257179604*lm)/27)*NC + 
         (21357790253446538457708028*NM*NC)/5892561675 - 
         (46759928*lm*NM*NC)/27 - (58592642*NC*NL)/27 - 
         (46759928*lm*NC*NL)/27 - (169019928916659566*NC*NH)/316468825335 - 
         (46759928*lm*NC*NH)/27)*Log[x]^2 + 
       (4*CF*NC*(-464610510443584614255*CA + 7*(132745823048253955979*CF + 
            42900*(5190290108849801*NM + 5844991*NL)))*Log[x]^3)/6081075 + 
       (45541173831658624024820225676668*CF^2*NC*PolyGamma[2, 1])/
        416929542491664225 + (58350328970341397*CF*NM*NC*PolyGamma[2, 1])/
        270 - (1222571383593880116189277*CF*NC*NH*PolyGamma[2, 1])/
        500315450989997070 - (36372143148817837209327144384752854*CF^2*NC*
         Zeta[3])/417346472034155889225 - (10853537473658923*CF*NM*NC*
         Zeta[3])/135 - (17257448*CF*NC*NL*Zeta[3])/9 + 
       (3040092935493451238372003*CF*NC*NH*Zeta[3])/250157725494998535 + 
       CA*CF*NC*
        (6177300981860318937357878145094765587670733159452060388162279/
          30511778806617796489530002139880228173960000000 + (835142*lm^2)/9 - 
         (30238695154234658898019133017*Pi^2)/333089180424000 + 
         (2627369220905706671552927*Pi^3)/(4239710192093012208*Sqrt[3]) + 
         (47882591*Pi^4)/4050 + lm*(23586489323671531/79686406800 - 
           (25432*Pi^2)/81) - (17359294871601977363407794520061*
           Im[PolyLog[2, (-1)^(1/3)]])/(3713456164499467067682000*Sqrt[3]) + 
         (5709688*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (2627369220905706671552927*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (114498346237079805*Sqrt[3]) + (2627369220905706671552927*Pi*
           Log[3]^2)/(5495920619379830640*Sqrt[3]) - 
         (22770586915829312012410112838334*PolyGamma[2, 1])/
          416929542491664225 + (36372144332200059426706271460484453*Zeta[3])/
          834692944068311778450) + CF*Log[x]*
        ((37343440696540556059357033630458851*NM*NC)/21511448111908755000 - 
         (665091228446*lm*NM*NC)/1216215 - 92480*lm^2*NM*NC - 
         (2919515149614999389*NC*NL)/876550474800 - (665091228446*lm*NC*NL)/
          1216215 - 92480*lm^2*NC*NL - 
         (503744623018946049540522505859905215979034957*NC*NH)/
          9202077714749897128060238122202409000 - (665091228446*lm*NC*NH)/
          1216215 - 92480*lm^2*NC*NH + (20761160440179808*NM*NC*Pi^2)/81 - 
         (25876924*NC*NL*Pi^2)/81 + (19110297148140955432960*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(817469922799292925466668535416838544504782558676647/
            759817569512588001020232867840600000 - (1161469112092*lm)/
            135135 - 1664640*lm^2 + (619480665817430527931*Pi^2)/4054050 + 
           (5254738441811413343105854*Im[PolyLog[2, (-1)^(1/3)]])/
            (343495038711239415*Sqrt[3]) - 1109760*Zeta[3]) + 
         CA*NC*(-204367479164583030180148880351905346936341364713543/
            379908784756294000510116433920300000 + (404120972623*lm)/110565 + 
           508640*lm^2 - (123896132794638529289*Pi^2)/1621620 - 
           (2627369220905706671552927*Im[PolyLog[2, (-1)^(1/3)]])/
            (343495038711239415*Sqrt[3]) + 554880*Zeta[3])), 
      (639640691280995784217542090295688058342499678777898642106889226293391*
         CF^2*NC)/329716478022469560479917538447057229017225548800000000 - 
       (319388450793928259*CF^2*lm*NC)/7791559776000 - 
       (1403503*CF^2*lm^2*NC)/10 + 
       (12026519442833006415782345790472114712571331779060641*CF*NM*NC)/
        10496366121336155499524135854003200000 - 
       (1139549264816077859*CF*lm*NM*NC)/140248075968000 - 
       (1403503*CF*lm^2*NM*NC)/180 + (940556534893193957552399*CF*NC*NL)/
        1148631742177920000 - (1139549264816077859*CF*lm*NC*NL)/
        140248075968000 - (1403503*CF*lm^2*NC*NL)/180 + 
       (227223259848136341091562956003236596400176135420820009097*CF*NC*NH)/
        22678403686620238213580890938819698492703414312960 - 
       (1139549264816077859*CF*lm*NC*NH)/140248075968000 - 
       (1403503*CF*lm^2*NC*NH)/180 - (541481766394045209535074546259*CF^2*NC*
         Pi^2)/633568231296000 - (289*CF^2*lm*NC*Pi^2)/90 - 
       (25220073518062058887529*CF*NM*NC*Pi^2)/48648600 - 
       (289*CF*lm*NM*NC*Pi^2)/1620 - (18122717593069*CF*NC*NL*Pi^2)/
        583783200 - (289*CF*lm*NC*NL*Pi^2)/1620 - (289*CF*lm*NC*NH*Pi^2)/
        1620 - (14793011342813691325489297*CF^2*NC*Pi^3)/
        (23481471833130529152*Sqrt[3]) - (5544437506659946140085*CF*NC*NH*
         Pi^3)/(3706040377703682*Sqrt[3]) - (408761821*CF^2*NC*Pi^4)/32400 + 
       (40374219360799856488142001924599*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (41133668283686404442016000*Sqrt[3]) + 
       (2793404092677985290183827993*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (185487320904069284100*Sqrt[3]) - 
       (6623149*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (14793011342813691325489297*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(634144686851518920*
         Sqrt[3]) - (1267300001522273403448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (14793011342813691325489297*CF^2*NC*Pi*Log[3]^2)/
        (30438944968872908160*Sqrt[3]) - (158412500190284175431*CF*NC*NH*Pi*
         Log[3]^2)/(137260754729766*Sqrt[3]) - 
       (CF*NC*(-31*CA*(129117681281314418586948453914873923 + 
            112852796223080384767296000*lm) + 
          26*(31*CF*(9932129331530699329473037807282871 + 
              14205247077031097383296000*lm) + 
            15400*(31*(391207525894954269610391323997 + 51245480075869759680*
                 lm)*NM + 49097207983824*(35743639 + 32356420*lm)*NL + 
              (550712130515040345629 + 1588609882351962550080*lm)*NH)))*
         Log[x]^2)/780558964811065440000 + 
       (CF*NC*(70322646404756449213785*CA - 364*(386388178180062143351*CF + 
            1320*(176258304555727163*NM - 55005914*NL)))*Log[x]^3)/
        48648600 - (10915976029639588106027575361435041*CF^2*NC*
         PolyGamma[2, 1])/20012618039599882800 - 
       (90228421004606419*CF*NM*NC*PolyGamma[2, 1])/300 - 
       (38424652746804784671053179*CF*NC*NH*PolyGamma[2, 1])/
        30018927059399824200 + CA*CF*NC*(-83153289941257814219525673454318922\
67771693798964215283686369881921333/
          8572628428584208572477855999623487954447864268800000000 + 
         (15438533*lm^2)/360 + (31851868613319436712654132903*Pi^2)/
          74537438976000 + (14793011342813691325489297*Pi^3)/
          (46962943666261058304*Sqrt[3]) + (408752573*Pi^4)/64800 + 
         lm*(2531337312853665059/25499650176000 + (3179*Pi^2)/3240) - 
         (40374219360799856488142001924599*Im[PolyLog[2, (-1)^(1/3)]])/
          (82267336567372808884032000*Sqrt[3]) + 
         (6623149*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (14793011342813691325489297*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1268289373703037840*Sqrt[3]) + (14793011342813691325489297*Pi*
           Log[3]^2)/(60877889937745816320*Sqrt[3]) + 
         (10915976029639588106027575361435041*PolyGamma[2, 1])/
          40025236079199765600 - (546448835480782674745919472872770481*
           Zeta[3])/3081943178098381951200) + 
       (546448837962179262396838402945214537*CF^2*NC*Zeta[3])/
        1540971589049190975600 + (40333286550049891*CF*NM*NC*Zeta[3])/150 - 
       (40624033*CF*NC*NL*Zeta[3])/45 - (41294005515388067216877139*CF*NC*
         NH*Zeta[3])/15009463529699912100 + 
       CF*Log[x]*((-90800599081488478465273250053711685302237*NM*NC)/
          29293154234337033776736000 - (21077889574831*lm*NM*NC)/97297200 - 
         43928*lm^2*NM*NC - (582083244692758703*NC*NL)/398432034000 - 
         (21077889574831*lm*NC*NL)/97297200 - 43928*lm^2*NC*NL - 
         (216236064138158267798379285234332908445302973*NC*NH)/
          19631099124799780539861841327365139200 - (21077889574831*lm*NC*NH)/
          97297200 - 43928*lm^2*NC*NH - (35251660942391861*NM*NC*Pi^2)/81 - 
         (60936194*NC*NL*Pi^2)/405 + (1267300001522273403448*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-176057435248629245831857405979453692136155236438617960417/
            35391133437789406644443954318064624000000 - (17872336023631*lm)/
            5405400 - 790704*lm^2 - (3606289568208952701677*Pi^2)/4989600 + 
           (14793011342813691325489297*Im[PolyLog[2, (-1)^(1/3)]])/
            (1902434060554556760*Sqrt[3]) - 527136*Zeta[3]) + 
         CA*NC*(416135756403099863894373003375186465885854473689712764797/
            167303539887731740501007784049032768000000 + (26517616813231*lm)/
            17690400 + 241604*lm^2 + (400698841051412213257*Pi^2)/1108800 - 
           (14793011342813691325489297*Im[PolyLog[2, (-1)^(1/3)]])/
            (3804868121109113520*Sqrt[3]) + 263568*Zeta[3])), 
      (-171406299859189439741917312663922965615497106564806294152487635251*
         CF^2*NC)/39064153240301702312498774206532184800400384000000 - 
       (9154947517920461*CF^2*lm*NC)/19238419200 - (815745*CF^2*lm^2*NC)/2 - 
       (19230978617487925941481782711477581461952545127428601*CF*NM*NC)/
        2614037539796360565015589388928000000 - 
       (15040064119284461*CF*lm*NM*NC)/346291545600 - 
       (271915*CF*lm^2*NM*NC)/12 + (60883503257845877502913*CF*NC*NL)/
        23398054007328000 - (15040064119284461*CF*lm*NC*NL)/346291545600 - 
       (271915*CF*lm^2*NC*NL)/12 + 
       (4982337910844808655622476902726629991966999497775411434668253*CF*NC*
         NH)/61725493905115567718415731385900389042640341376000000 - 
       (15040064119284461*CF*lm*NC*NH)/346291545600 - 
       (271915*CF*lm^2*NC*NH)/12 + (835544467656496633427818038871*CF^2*NC*
         Pi^2)/431429795596800 + (2601*CF^2*lm*NC*Pi^2)/2 + 
       (856220123547117473461*CF*NM*NC*Pi^2)/270270 + 
       (289*CF*lm*NM*NC*Pi^2)/4 - (15350819919*CF*NC*NL*Pi^2)/160160 + 
       (289*CF*lm*NC*NL*Pi^2)/4 + (289*CF*lm*NC*NH*Pi^2)/4 - 
       (23528230615973464746181075*CF^2*NC*Pi^3)/(12719130576279036624*
         Sqrt[3]) - (1136767419500658189257615*CF*NC*NH*Pi^3)/
        (100063090197999414*Sqrt[3]) - (9122659*CF^2*NC*Pi^4)/270 + 
       (8898978043707766039472194429249*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (636592485342765783031200*Sqrt[3]) + (51277041662186687712534890911*
         CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1001631532881974134140*
         Sqrt[3]) - 3239656*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (672235160456384707033745*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9814143963178269*Sqrt[3]) - 
       (259832553028721871830312*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (672235160456384707033745*CF^2*NC*Pi*Log[3]^2)/(471078910232556912*
         Sqrt[3]) - (32479069128590233978789*CF*NC*NH*Pi*Log[3]^2)/
        (3706040377703682*Sqrt[3]) + 
       CF*((3142715173375230258959499379613*CF*NC)/135227290255200 - 
         47362680*CF*lm*NC + CA*(-1539930436570893735137839656357461/
            132522744450096000 + 14471930*lm)*NC + 
         (9159637387494348424818949309*NM*NC)/240940299600 - 
         2631260*lm*NM*NC - (9873005*NC*NL)/3 - 2631260*lm*NC*NL - 
         (651708569850535031*NC*NH)/776363187600 - 2631260*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-53085327985382246493783*CA + 
          30800*(3447099075199188601*CF + 702*(8089271011505929*NM + 
              1315630*NL)))*Log[x]^3)/16216200 + 
       (105721757589169955723632897327606307*CF^2*NC*PolyGamma[2, 1])/
        90056781178199472600 + (133885175917180073*CF*NM*NC*PolyGamma[2, 1])/
        60 - (39463578656719563116456231*CF*NC*NH*PolyGamma[2, 1])/
        10806813741383936712 - (11921370424980588853268857785484234663*CF^2*
         NC*Zeta[3])/12878119708482524581800 - 
       (9300081248759679*CF*NM*NC*Zeta[3])/10 - 2895695*CF*NC*NL*Zeta[3] + 
       (98809224925806958675798849*CF*NC*NH*Zeta[3])/5403406870691968356 + 
       CA*CF*NC*
        (1015252698207223710482410989632760739131577504398544453189333108559/
          462759969154343242778831632908150496866281472000000 + 
         (2991065*lm^2)/24 - (81916124274697825030430861593*Pi^2)/
          84594077568000 + (23528230615973464746181075*Pi^3)/
          (25438261152558073248*Sqrt[3]) + (9153871*Pi^4)/540 + 
         lm*(25026928654932461/62962099200 - (3179*Pi^2)/8) - 
         (8898978043707766039472194429249*Im[PolyLog[2, (-1)^(1/3)]])/
          (1273184970685531566062400*Sqrt[3]) + 
         1619828*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (672235160456384707033745*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (19628287926356538*Sqrt[3]) + (672235160456384707033745*Pi*
           Log[3]^2)/(942157820465113824*Sqrt[3]) - 
         (105721757589169955723632897327606307*PolyGamma[2, 1])/
          180113562356398945200 + (2384274095956513400956073315696558591*
           Zeta[3])/5151247883393009832720) + 
       CF*Log[x]*((10099424082597097545049989180008300339449*NM*NC)/
          561171537056265014880000 - (187824046321*lm*NM*NC)/240240 - 
         131784*lm^2*NM*NC - (325521601326642989*NC*NL)/64929664800 - 
         (187824046321*lm*NC*NL)/240240 - 131784*lm^2*NC*NL - 
         (35343955541147830758636293247978764488693746037*NC*NH)/
          427451351910962963367959448257144160000 - (187824046321*lm*NC*NH)/
          240240 - 131784*lm^2*NC*NH + (8089271011870783*NM*NC*Pi^2)/3 - 
         (1447414*NC*NL*Pi^2)/3 + (259832553028721871830312*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*(1042150409026428861253605179925064170053966167130137759/
            92247565852884668947924091455607040000 - (492237615603*lm)/
            40040 - 2372112*lm^2 + (1516723651584557052119*Pi^2)/926640 + 
           (672235160456384707033745*Im[PolyLog[2, (-1)^(1/3)]])/
            (29442431889534807*Sqrt[3]) - 1581408*Zeta[3]) + 
         CA*NC*(-70144738995194362198952910661772243650298020277249483/
            12417941557119090050682089234408640000 + (228118322161*lm)/
            43680 + 724812*lm^2 - (2527872751581982174889*Pi^2)/3088800 - 
           (672235160456384707033745*Im[PolyLog[2, (-1)^(1/3)]])/
            (58884863779069614*Sqrt[3]) + 790704*Zeta[3])), 
      (4055922485776962844639838825270028242318953910176093236957459733046108\
5465837*CF^2*NC)/
        1953711877397034005507561731848592471829815881903429120000000 - 
       (380740256184564019*CF^2*lm*NC)/6949878936000 - 
       (935076*CF^2*lm^2*NC)/5 + 
       (15509490657621021903801606554869890967407977297362309849*CF*NM*NC)/
        1240862075875894478120331473121465600000 - 
       (1355540005578434419*CF*lm*NM*NC)/125097820848000 - 
       (155846*CF*lm^2*NM*NC)/15 + (428753217084450348455539*CF*NC*NL)/
        345001918781520000 - (1355540005578434419*CF*lm*NC*NL)/
        125097820848000 - (155846*CF*lm^2*NC*NL)/15 + 
       (1416829228222754068382907916061405071282475962732041041055461*CF*NC*
         NH)/95674515552929129963544383648145603016092529132800000 - 
       (1355540005578434419*CF*lm*NC*NH)/125097820848000 - 
       (155846*CF*lm^2*NC*NH)/15 - (1158326336820257591764746305634859*CF^2*
         NC*Pi^2)/128350364190048000 - (18*CF^2*lm*NC*Pi^2)/5 - 
       (5803272741854408279174*CF*NM*NC*Pi^2)/1044225 - 
       (CF*lm*NM*NC*Pi^2)/5 - (1341608001857*CF*NC*NL*Pi^2)/30630600 - 
       (CF*lm*NC*NL*Pi^2)/5 - (CF*lm*NC*NH*Pi^2)/5 - 
       (243794392929665603345911885*CF^2*NC*Pi^3)/(265367315205094445928*
         Sqrt[3]) - (111299422701980664170810*CF*NC*NH*Pi^3)/
        (50031545098999707*Sqrt[3]) - (12137953*CF^2*NC*Pi^4)/675 + 
       (108727103058603170811476961926344*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (70558681294454565411824625*Sqrt[3]) + 
       (2129991322802620372753552453*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (96310724315574435975*Sqrt[3]) - 
       (9292976*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (13931108167409463048337822*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(409517461736256861*
         Sqrt[3]) - (50879736092334017906656*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (6965554083704731524168911*CF^2*NC*Pi*Log[3]^2)/(9828419081670164664*
         Sqrt[3]) - (3179983505770876119166*CF*NC*NH*Pi*Log[3]^2)/
        (1853020188851841*Sqrt[3]) + 
       CF*((-71852141031626650571301935593393350923*CF*NC)/
          663475120089405624000 - (110243232*CF*lm*NC)/5 + 
         CA*(160384243369102044222494784079064111/2961942500399132250 + 
           (33685432*lm)/5)*NC - (3611347564544154365591758269307*NM*NC)/
          54151332335100 - (6124624*lm*NM*NC)/5 - (101155372*NC*NL)/75 - 
         (6124624*lm*NC*NL)/5 - (23776773960290535059*NC*NH)/
          54151332335100 - (6124624*lm*NC*NH)/5)*Log[x]^2 - 
       (CF*NC*(-1055783417038045919266821*CA + 
          17*(124209814305538885116793*CF + 4324320*(17576811222447601*NM - 
              765578*NL)))*Log[x]^3)/68918850 - 
       (259113963933100696882579107957253199*CF^2*NC*PolyGamma[2, 1])/
        45028390589099736300 - (294156719583240979*CF*NM*NC*PolyGamma[2, 1])/
        90 - (253835736333100120166598391*CF*NC*NH*PolyGamma[2, 1])/
        135085171767299208900 + CA*CF*NC*
        (-1843601130127638741493121440574484938004188530464112665625862259216\
505995421/177610170672457636864323793804417497439074171082129920000000 + 
         (857153*lm^2)/15 + (38610877894317671585576894449441*Pi^2)/
          8556690946003200 + (243794392929665603345911885*Pi^3)/
          (530734630410188891856*Sqrt[3]) + (12137737*Pi^4)/1350 + 
         lm*(3009745640913487219/22745058336000 + (11*Pi^2)/10) - 
         (54363551529301585405738480963172*Im[PolyLog[2, (-1)^(1/3)]])/
          (70558681294454565411824625*Sqrt[3]) + 
         (4646488*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (6965554083704731524168911*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (409517461736256861*Sqrt[3]) + (6965554083704731524168911*Pi*
           Log[3]^2)/(19656838163340329328*Sqrt[3]) + 
         (259113963933100696882579107957253199*PolyGamma[2, 1])/
          90056781178199472600 - (14598216451729537495711331032071763348*
           Zeta[3])/7662481226547102126171) + 
       (2919643292177225291477556081208913042591*CF^2*NC*Zeta[3])/
        766248122654710212617100 + (127686749967197249*CF*NM*NC*Zeta[3])/
        45 - (6744772*CF*NC*NL*Zeta[3])/5 - (258681619682874091227626311*CF*
         NC*NH*Zeta[3])/67542585883649604450 + 
       CF*Log[x]*((-1965004960189050655198607143826219478125777*NM*NC)/
          60151113716234806537272000 - (522315693941*lm*NM*NC)/1701700 - 
         62016*lm^2*NM*NC - (3012953427988461689*NC*NL)/1379755377000 - 
         (522315693941*lm*NC*NL)/1701700 - 62016*lm^2*NC*NL - 
         (10847170798129498749538863586813238227417947229*NC*NH)/
          662549595461992593220337144798573448000 - (522315693941*lm*NC*NH)/
          1701700 - 62016*lm^2*NC*NH - (14061448979671436*NM*NC*Pi^2)/3 - 
         (3372392*NC*NL*Pi^2)/15 + (50879736092334017906656*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*
          (-701011997245302845606079210066210546989818304482175128003642193/
            13529527759172073550596572631644789237539200000 - 
           (3988496011869*lm)/850850 - 1116288*lm^2 - 
           (2111566834826610223435691*Pi^2)/275675400 + 
           (13931108167409463048337822*Im[PolyLog[2, (-1)^(1/3)]])/
            (1228552385208770583*Sqrt[3]) - 744192*Zeta[3]) + 
         CA*NC*
          (175252999332622284296252409065966341700586707456576420599087277/
            6764763879586036775298286315822394618769600000 + 
           (656629946741*lm)/309400 + 341088*lm^2 + 
           (70385561164338002639467*Pi^2)/18378360 - 
           (6965554083704731524168911*Im[PolyLog[2, (-1)^(1/3)]])/
            (1228552385208770583*Sqrt[3]) + 372096*Zeta[3])), 
      (-879297196322318287520333490819233978919257491192516819538672569877044\
669357*CF^2*NC)/18695807439206067038349873032043947098849912745487360000000 - 
       (3494309629600206101*CF^2*lm*NC)/5559903148800 - 
       (1077699*CF^2*lm^2*NC)/2 - 
       (11659346769123605464704004361035354382958781247837330432641*CF*NM*
         NC)/150557931872941863345266885405404492800000 - 
       (5741272903434685301*CF*lm*NM*NC)/100078256678400 - 
       (359233*CF*lm^2*NM*NC)/12 + (7545288368838596805089693*CF*NC*NL)/
        1932010745176512000 - (5741272903434685301*CF*lm*NC*NL)/
        100078256678400 - (359233*CF*lm^2*NC*NL)/12 + 
       (2050871145301282571447334709313283917293290459188496386690647759*CF*
         NC*NH)/17221412799527243393437989056666208542896655243904000000 - 
       (5741272903434685301*CF*lm*NC*NH)/100078256678400 - 
       (359233*CF*lm^2*NC*NH)/12 + (241741719504444294048082240812944491*
         CF^2*NC*Pi^2)/11808233505484416000 + (3249*CF^2*lm*NC*Pi^2)/2 + 
       (3888562510309904820683*CF*NM*NC*Pi^2)/117810 + 
       (361*CF*lm*NM*NC*Pi^2)/4 - (3281248936607*CF*NC*NL*Pi^2)/24504480 + 
       (361*CF*lm*NC*NL*Pi^2)/4 + (361*CF*lm*NC*NH*Pi^2)/4 - 
       (126064955917783288634053805245*CF^2*NC*Pi^3)/(46704647476096622483328*
         Sqrt[3]) - (15112877945586985363972585*CF*NC*NH*Pi^3)/
        (900567811781994726*Sqrt[3]) - (512799607*CF^2*NC*Pi^4)/10800 + 
       (4064907109295675609835482315725372309*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(198693246525184056199698144000*
         Sqrt[3]) + (688264193871802769861344158143*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9014683795937767207260*Sqrt[3]) - 
       (22537781*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (3601855883365236818115823007*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(36037536632790603768*
         Sqrt[3]) - (3454372101848453797479448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (3601855883365236818115823007*CF^2*NC*Pi*Log[3]^2)/
        (1729801758373948980864*Sqrt[3]) - (431796512731056724684931*CF*NC*
         NH*Pi*Log[3]^2)/(33354363399333138*Sqrt[3]) + 
       CF*((686292017990635984220079790422164843*CF*NC)/2793579453008023680 - 
         70279632*CF*lm*NC + CA*(-3431460090459119874078068625286299433/
            27935794530080236800 + 21474332*lm)*NC + 
         (5719605216459318663485484092789*NM*NC)/14440355289360 - 
         3904424*lm*NM*NC - (14626409*NC*NL)/3 - 3904424*lm*NC*NL - 
         (278124618282906301133*NC*NH)/216605329340400 - 3904424*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-9575797804460983150066155*CA + 
          88*(217631766935057283966511*CF + 4176900*(84519241014485535*NM + 
              1952212*NL)))*Log[x]^3)/275675400 + 
       (3375370760246588902643709244909557791*CF^2*NC*PolyGamma[2, 1])/
        270170343534598417800 + (275457948586484179*CF*NM*NC*
         PolyGamma[2, 1])/12 - (173100792600593500562527811*CF*NC*NH*
         PolyGamma[2, 1])/32420441224151810136 - 
       (89639902627979388430317088212618585745351*CF^2*NC*Zeta[3])/
        9194977471856522551405200 - (62619015302928227*CF*NM*NC*Zeta[3])/6 - 
       4273727*CF*NC*NL*Zeta[3] + (435989136754174645708923973*CF*NC*NH*
         Zeta[3])/16210220612075905068 + CA*CF*NC*
        (96722691582842967755964713431036459593195872413808628546485736158147\
42655227/411307763662533474843697206704966836174698080400721920000000 + 
         (3951563*lm^2)/24 - (184394904273337520054119063079141*Pi^2)/
          18014086202112000 + (126064955917783288634053805245*Pi^3)/
          (93409294952193244966656*Sqrt[3]) + (514359127*Pi^4)/21600 + 
         lm*(9554301489335619701/18196046668800 - (3971*Pi^2)/8) - 
         (4064907109295675609835482315725372309*Im[PolyLog[2, (-1)^(1/3)]])/
          (397386493050368112399396288000*Sqrt[3]) + 
         (22537781*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (3601855883365236818115823007*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (72075073265581207536*Sqrt[3]) + (3601855883365236818115823007*Pi*
           Log[3]^2)/(3459603516747897961728*Sqrt[3]) - 
         (3375370760246588902643709244909557791*PolyGamma[2, 1])/
          540340687069196835600 + (17927980537085102714659255533469285912643*
           Zeta[3])/3677990988742609020562080) + 
       CF*Log[x]*((27621542436339388632344580873168154399314617*NM*NC)/
          148945614916390949520864000 - (4473880787017*lm*NM*NC)/4084080 - 
         184110*lm^2*NM*NC - (1017959466227792201*NC*NL)/137975537700 - 
         (4473880787017*lm*NC*NL)/4084080 - 184110*lm^2*NC*NL - 
         (2080538421847215576945046086172091130450998000873*NC*NH)/
          17036989597594095254237240866249031520000 - 
         (4473880787017*lm*NC*NH)/4084080 - 184110*lm^2*NC*NH + 
         28173080338385361*NM*NC*Pi^2 - (2136322*NC*NL*Pi^2)/3 + 
         (3454372101848453797479448*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*(4191437910710146101114324406800711153455084723268288817574859\
7/356040204188738777647278227148547085198400000 - (11729822431251*lm)/
            680680 - 3313980*lm^2 + (19151595599829863119859419*Pi^2)/
            1102701600 + (3601855883365236818115823007*
             Im[PolyLog[2, (-1)^(1/3)]])/(108112609898371811304*Sqrt[3]) - 
           2209320*Zeta[3]) + CA*NC*
          (-167657516403966258800923433674279715544349710541073305375803133/
            2848321633509910221178225817188376681587200000 + 
           (5430869838217*lm)/742560 + 1012605*lm^2 - 
           (1276773039914386207852693*Pi^2)/147026880 - 
           (3601855883365236818115823007*Im[PolyLog[2, (-1)^(1/3)]])/
            (216225219796743622608*Sqrt[3]) + 1104660*Zeta[3])), 
      (1658756607619345247153583744607948465459280049092015241749785668266737\
0799751691*CF^2*NC)/
        75357458128171311641005952514159995342007184016275123200000000 - 
       (162229106088046220539*CF^2*lm*NC)/2251760775264000 - 
       (2453261*CF^2*lm^2*NC)/10 + 
       (391134031458561416816251819523114085126013251977421186940067*CF*NM*
         NC)/2903617257549593078801575647104229504000000 - 
       (576540872934416413339*CF*lm*NM*NC)/40531693954752000 - 
       (2453261*CF*lm^2*NM*NC)/180 + (747470507935017434840327911*CF*NC*NL)/
        405722256487067520000 - (576540872934416413339*CF*lm*NC*NL)/
        40531693954752000 - (2453261*CF*lm^2*NC*NL)/180 + 
       (132946478863588464747220348004242430229333884777423399618271721*CF*NC*
         NH)/6199708607829807621637676060399835075442795887805440000 - 
       (576540872934416413339*CF*lm*NC*NH)/40531693954752000 - 
       (2453261*CF*lm^2*NC*NH)/180 - (418697408436482579571006372690201313*
         CF^2*NC*Pi^2)/4428087564556656000 - (361*CF^2*lm*NC*Pi^2)/90 - 
       (6098757648315286656392809*CF*NM*NC*Pi^2)/103378275 - 
       (361*CF*lm*NM*NC*Pi^2)/1620 - (200635172470519*CF*NC*NL*Pi^2)/
        3308104800 - (361*CF*lm*NC*NL*Pi^2)/1620 - (361*CF*lm*NC*NH*Pi^2)/
        1620 - (75210237707197285283737565597*CF^2*NC*Pi^3)/
        (57319340084300400320448*Sqrt[3]) - (52501125552348205954968845*CF*NC*
         NH*Pi^3)/(16210220612075905068*Sqrt[3]) - (407026189*CF^2*NC*Pi^4)/
        16200 + (802326021617884714685044326481008811*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(341391123575088969288572265600*
         Sqrt[3]) + (12920724810066513540539167259689*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(405660770817199524326700*Sqrt[3]) - 
       (7682422*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (75210237707197285283737565597*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1547976005363050934580*
         Sqrt[3]) - (6000128634554080680567868*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (75210237707197285283737565597*CF^2*NC*Pi*Log[3]^2)/
        (74302848257426444859840*Sqrt[3]) - (1500032158638520170141967*CF*NC*
         NH*Pi*Log[3]^2)/(600378541187996484*Sqrt[3]) - 
       (CF*NC*(-17*CA*(332125561946864186350000671249664268779 + 
            5796436232525196993422688000*lm) + 
          CF*(11292269106243495902058431328240280029991 + 
            322492634027765505452244096000*lm) + 
          5105100*((1380082306174370180594421309744829 + 
              3509482173901974990720*lm)*NM + 2798540855077968*
             (1376803 + 1254040*lm)*NL + (1296327796306602999151 + 
              3509482173901974990720*lm)*NH))*Log[x]^2)/
        9952126801341084360000 + (CF*NC*(44393136840651730577188031*CA - 
          120*(739885614481937642300333*CF + 68068*(6744689436921273649*NM - 
              40505492*NL)))*Log[x]^3)/275675400 - 
       (879436982359444650136245195552113234411*CF^2*NC*PolyGamma[2, 1])/
        14589198550868314561200 - (22742789131984583503*CF*NM*NC*
         PolyGamma[2, 1])/648 - (4931241742842550644218810537*CF*NC*NH*
         PolyGamma[2, 1])/1823649818858539320150 + 
       CA*CF*NC*(-11611296253532721770015368609100421626206561538385788611400\
6447414678628032521837/
          1055004413794398362974083335198239934788100576227851724800000000 + 
         (26985871*lm^2)/360 + (958117639443767047281647766984809*Pi^2)/
          20265846977376000 + (75210237707197285283737565597*Pi^3)/
          (114638680168600800640896*Sqrt[3]) + (135673471*Pi^4)/10800 + 
         lm*(1279615386370680982939/7369398900864000 + (3971*Pi^2)/3240) - 
         (802326021617884714685044326481008811*Im[PolyLog[2, (-1)^(1/3)]])/
          (682782247150177938577144531200*Sqrt[3]) + 
         (3841211*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (75210237707197285283737565597*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3095952010726101869160*Sqrt[3]) + 
         (75210237707197285283737565597*Pi*Log[3]^2)/
          (148605696514852889719680*Sqrt[3]) + 
         (879436982359444650136245195552113234411*PolyGamma[2, 1])/
          29178397101736629122400 - 
         (5024135926795836136093345176839740986374011*Zeta[3])/
          248264391740126108887940400) + 
       (5024135927227066811285973938058754681526713*CF^2*NC*Zeta[3])/
        124132195870063054443970200 + (48158600837235083857*CF*NM*NC*
         Zeta[3])/1620 - (266230451*CF*NC*NL*Zeta[3])/135 - 
       (4780931080839807611293928867*CF*NC*NH*Zeta[3])/
        911824909429269660075 + CF*Log[x]*
        ((-48064165929534116711103087524379898419329814301*NM*NC)/
          140753606095989447297216480000 - (235210840699621*lm*NM*NC)/
          551350800 - 85918*lm^2*NM*NC - (475864953529201451623*NC*NL)/
          149013580716000 - (235210840699621*lm*NC*NL)/551350800 - 
         85918*lm^2*NC*NL - 
         (1022907075011705977442790652917633378024614509439*NC*NH)/
          42933213785937120040677846982947559430400 - 
         (235210840699621*lm*NC*NH)/551350800 - 85918*lm^2*NC*NH - 
         (149881987489622258*NM*NC*Pi^2)/3 - (44371802*NC*NL*Pi^2)/135 + 
         (6000128634554080680567868*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*
          (
           -19580857282108965912373199262435298750967989644924015928986258615\
23/3652972494976459858661074610544093094135584000000 - (199682622173821*lm)/
            30630600 - 1546524*lm^2 - (22196568421433778062561809*Pi^2)/
            275675400 + (75210237707197285283737565597*
             Im[PolyLog[2, (-1)^(1/3)]])/(4643928016089152803740*Sqrt[3]) - 
           1031016*Zeta[3]) + CA*NC*
          (122380358015237539261302010945789977629616527725965094211770367603/
            456621561872057482332634326318011636766948000000 + 
           (295501150925221*lm)/100245600 + 472549*lm^2 + 
           (22196568421585158545703697*Pi^2)/551350800 - 
           (75210237707197285283737565597*Im[PolyLog[2, (-1)^(1/3)]])/
            (9287856032178305607480*Sqrt[3]) + 515508*Zeta[3])), 
      (-263359222491842922351317019854214661191222838761780011196630938604161\
7631512143*CF^2*NC)/
        5275022068971991814870416675991199673940502881139258624000000 - 
       (3683465542121966285*CF^2*lm*NC)/4503521550528 - 701480*CF^2*lm^2*NC - 
       (822597828443268636391071097752680651190681784250610503512343*CF*NM*
         NC)/1016266040142357577580551476486480326400000 - 
       (6052813265070252365*CF*lm*NM*NC)/81063387909504 - 
       (350740*CF*lm^2*NM*NC)/9 + (63255309353703658407658223*CF*NC*NL)/
        11035645376448236544 - (6052813265070252365*CF*lm*NC*NL)/
        81063387909504 - (350740*CF*lm^2*NC*NL)/9 + 
       (101395557875584377158461313433530953385252666777976243732799018386230\
9*CF*NC*NH)/5888134502107560852352747602889365863932573876968917856000000 - 
       (6052813265070252365*CF*lm*NC*NH)/81063387909504 - 
       (350740*CF*lm^2*NC*NH)/9 + (76042037810019155408867822360145961*CF^2*
         NC*Pi^2)/354247005164532480 + (18050*CF^2*lm*NC*Pi^2)/9 + 
       (28264544811930755902070977*CF*NM*NC*Pi^2)/82702620 + 
       (9025*CF*lm*NM*NC*Pi^2)/81 - (6080015147275*CF*NC*NL*Pi^2)/
        33081048 + (9025*CF*lm*NC*NL*Pi^2)/81 + (9025*CF*lm*NC*NH*Pi^2)/
        81 - (1216864806619316312958364512545*CF^2*NC*Pi^3)/
        (315256370463652201762464*Sqrt[3]) - (295373692017831488164760755*CF*
         NC*NH*Pi^3)/(12157665459056928801*Sqrt[3]) - 
       (21226553*CF^2*NC*Pi^4)/324 + (11028610979535746096845179495988869593*
         CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(375530235932597866217429492160*
         Sqrt[3]) + (16487678235717150562572948516197*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(147776423654836969576155*Sqrt[3]) - 
       (18492700*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (243372961323863262591672902509*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1702773605899356028038*
         Sqrt[3]) - (135027973493865823161033488*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) - (243372961323863262591672902509*CF^2*NC*Pi*Log[3]^2)/
        (81733133083169089345824*Sqrt[3]) - (8439248343366613947564593*CF*NC*
         NH*Pi*Log[3]^2)/(450283905890997363*Sqrt[3]) + 
       CF*((14648955425405173015095596411061473873*CF*NC)/
          5686929600766333920 - 102108280*CF*lm*NC + 
         CA*(-39439495376896802365256460378332027089/30621928619511028800 + 
           (280797770*lm)/9)*NC + (79949475852609518694738561009449*NM*NC)/
          19494479640636 - (51054140*lm*NM*NC)/9 - (63660260*NC*NL)/9 - 
         (51054140*lm*NC*NL)/9 - (4939029330106287110047*NC*NH)/
          2576056238226900 - (51054140*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-5037458771020301759621633*CA + 
          12*(839576461080581000900757*CF + 340340*(3948498629512922312*NM + 
              12763535*NL)))*Log[x]^3)/13783770 + 
       (240346143946746618889581326300058250769*CF^2*NC*PolyGamma[2, 1])/
        1823649818858539320150 + (762170755697241319123*CF*NM*NC*
         PolyGamma[2, 1])/3240 - (33504840630069909023976167351*CF*NC*NH*
         PolyGamma[2, 1])/4376759565260494368360 - 
       (53134325907259427558012436004783686314357*CF^2*NC*Zeta[3])/
        521563848193542245562900 - (185468915319631024397*CF*NM*NC*Zeta[3])/
        1620 - (166844320*CF*NC*NL*Zeta[3])/27 + 
       (84825098700912622179619437769*CF*NC*NH*Zeta[3])/
        2188379782630247184180 + CA*CF*NC*(2213102709976058853163538964292964\
0026690063157652282390919993827183916323997/
          88655833091966248989418767663717641578831981195617792000000 + 
         (1929070*lm^2)/9 - (20011062581561135660600933576766911*Pi^2)/
          186445792191859200 + (1216864806619316312958364512545*Pi^3)/
          (630512740927304403524928*Sqrt[3]) + (7094771*Pi^4)/216 + 
         lm*(10073524552497646925/14738797801728 - (99275*Pi^2)/162) - 
         (11028610979535746096845179495988869593*Im[PolyLog[2, (-1)^(1/3)]])/
          (751060471865195732434858984320*Sqrt[3]) + 
         (9246350*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (243372961323863262591672902509*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3405547211798712056076*Sqrt[3]) + 
         (243372961323863262591672902509*Pi*Log[3]^2)/
          (163466266166338178691648*Sqrt[3]) - 
         (240346143946746618889581326300058250769*PolyGamma[2, 1])/
          3647299637717078640300 + (53134325911949784863261112075109636668077*
           Zeta[3])/1043127696387084491125800) + 
       CF*Log[x]*((6686553017219869856268092870260881220433244041*NM*NC)/
          3518840152399736182430412000 - (8311659684397*lm*NM*NC)/5513508 - 
         252700*lm^2*NM*NC - (431253298224109375757*NC*NL)/40531693954752 - 
         (8311659684397*lm*NC*NL)/5513508 - 252700*lm^2*NC*NL - 
         (17709337336290549734450942339376130188532723549618073*NC*NH)/
          100185630124343040913104498613048651466280000 - 
         (8311659684397*lm*NC*NH)/5513508 - 252700*lm^2*NC*NH + 
         (2632332419678717666*NM*NC*Pi^2)/9 - (27801370*NC*NL*Pi^2)/27 + 
         (135027973493865823161033488*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CF*NC*
          (22251655442458622493018280416114530912274880653391333753106447411/
            18264862474882299293305373052720465470677920000 - 
           (7266712080697*lm)/306306 - 4548600*lm^2 + 
           (84663172616632011429167*Pi^2)/463320 + 
           (243372961323863262591672902509*Im[PolyLog[2, (-1)^(1/3)]])/
            (5108320817698068084114*Sqrt[3]) - 3032400*Zeta[3]) + 
         CA*NC*
          (-44503310884030100222205664649176007633136780234054270421206352567/
            73059449899529197173221492210881861882711680000 + 
           (10084904102797*lm)/1002456 + 1389850*lm^2 - 
           (84663172615956145990919*Pi^2)/926640 - 
           (243372961323863262591672902509*Im[PolyLog[2, (-1)^(1/3)]])/
            (10216641635396136168228*Sqrt[3]) + 1516200*Zeta[3])), 
      (2609737559668650486653005270878305182887971828990413750187050765263013\
919472916741*CF^2*NC)/
        1127535967242763250428551564493118930304782490843516530880000000 - 
       (189791154259545622099*CF^2*lm*NC)/2032214099675760 - 
       317336*CF^2*lm^2*NC + 
       (62923282658223461738612843638869432768198338609030990177047*CF*NM*
         NC)/43804570695791274895713425710624152000000 - 
       (673462174410575853619*CF*lm*NM*NC)/36579853794163680 - 
       (158668*CF*lm^2*NM*NC)/9 + (16647732652528182141378081851*CF*NC*NL)/
        6224793720152833425600 - (673462174410575853619*CF*lm*NC*NL)/
        36579853794163680 - (158668*CF*lm^2*NC*NL)/9 + 
       (44874645122819104301113927781736353294377750361677862148442183110749*
         CF*NC*NH)/
        1472033625526890213088186900722341465983143469242229464000000 - 
       (673462174410575853619*CF*lm*NC*NH)/36579853794163680 - 
       (158668*CF*lm^2*NC*NH)/9 - (662067417532723173778570565618672411*CF^2*
         NC*Pi^2)/673069309812611712 - (40*CF^2*lm*NC*Pi^2)/9 - 
       (243868391253599674325676866*CF*NM*NC*Pi^2)/392837445 - 
       (20*CF*lm*NM*NC*Pi^2)/81 - (12976605935071*CF*NC*NL*Pi^2)/
        157134978 - (20*CF*lm*NC*NL*Pi^2)/81 - (20*CF*lm*NC*NH*Pi^2)/81 - 
       (49580448831045817157217537303749*CF^2*NC*Pi^3)/
        (26954419674642263250690672*Sqrt[3]) - 
       (56250090946886212956447910*CF*NC*NH*Pi^3)/(12157665459056928801*
         Sqrt[3]) - (27934097*CF^2*NC*Pi^4)/810 + 
       (1522868565962121342483480089256618490579*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(435749191623218024050153007152800*
         Sqrt[3]) + (46623108606386576113302287952848*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1034434965583858787033085*Sqrt[3]) - 
       (10413592*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (7082921261577973879602505329107*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(103990816645996385998035*
         Sqrt[3]) - (25714327290005125922947616*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) - (7082921261577973879602505329107*CF^2*NC*Pi*Log[3]^2)/
        (4991559199007826527905680*Sqrt[3]) - 
       (1607145455625320370184226*CF*NC*NH*Pi*Log[3]^2)/
        (450283905890997363*Sqrt[3]) + 
       CF*((-111599739068831855761703485091488831408043*CF*NC)/
          9454520461274030142000 - 46673728*CF*lm*NC + 
         CA*(10145430824433014682574333311106926237073/
            1719003720231641844000 + (128352752*lm)/9)*NC - 
         (31298069333499488762687065916963*NM*NC)/4201396474275 - 
         (23336864*lm*NM*NC)/9 - (25555304*NC*NL)/9 - (23336864*lm*NC*NL)/
          9 - (4436467636957733175499*NC*NH)/4508098416897075 - 
         (23336864*lm*NC*NH)/9)*Log[x]^2 + 
       (2*CF*NC*(110013576080417880808414525*CA - 
          912*(241257842303919310438053*CF + 170170*(890432188364436977*NM - 
              729277*NL)))*Log[x]^3)/130945815 - 
       (411833270025029183681343893814600424319*CF^2*NC*PolyGamma[2, 1])/
        656513934789074155254 - (3021121245038488654841*CF*NM*NC*
         PolyGamma[2, 1])/8100 - (41818757211784282812021134149*CF*NC*NH*
         PolyGamma[2, 1])/10941898913151235920900 + 
       CA*CF*NC*(-26097375596746588484376480158954942580630396665491616667590\
49285933882061742200741/
          2255071934485526500857103128986237860609564981687033061760000000 + 
         (872674*lm^2)/9 + (16551685438320377594387186816847732539*Pi^2)/
          33653465490630585600 + (49580448831045817157217537303749*Pi^3)/
          (53908839349284526501381344*Sqrt[3]) + (3103753*Pi^4)/180 + 
         lm*(1494237238909293822259/6650882508029760 + (110*Pi^2)/81) - 
         (1522868565962121342483480089256618490579*
           Im[PolyLog[2, (-1)^(1/3)]])/(871498383246436048100306014305600*
           Sqrt[3]) + (5206796*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (7082921261577973879602505329107*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(207981633291992771996070*Sqrt[3]) + 
         (7082921261577973879602505329107*Pi*Log[3]^2)/
          (9983118398015653055811360*Sqrt[3]) + 
         (411833270025029183681343893814600424319*PolyGamma[2, 1])/
          1313027869578148310508 - 
         (26576038529179919176842526361407524093305237*Zeta[3])/
          124862385257534013587758260) + 
       (26576038529489303295848458903765697295604721*CF^2*NC*Zeta[3])/
        62431192628767006793879130 + (1252953259150075827559*CF*NM*NC*
         Zeta[3])/4050 - (76330672*CF*NC*NL*Zeta[3])/27 - 
       (38684154431585940897211838149*CF*NC*NH*Zeta[3])/
        5470949456575617960450 + CF*Log[x]*
        ((-1074860624829752894959073968871982460590292313*NM*NC)/
          303348288999977257106070000 - (15263771497753*lm*NM*NC)/26189163 - 
         117040*lm^2*NM*NC - (314879703310405791587*NC*NL)/68759123673240 - 
         (15263771497753*lm*NC*NL)/26189163 - 117040*lm^2*NC*NL - 
         (1171658476245662358796457170235162358516652373742551*NC*NH)/
          34438810355242920313879671398235473941533750 - 
         (15263771497753*lm*NC*NH)/26189163 - 117040*lm^2*NC*NH - 
         (4748971671287585936*NM*NC*Pi^2)/9 - (12721792*NC*NL*Pi^2)/27 + 
         (25714327290005125922947616*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CF*NC*
          (-86065201726253366747138464719905476740503034868627126132360017870\
553/15616457416024365895776093960075997977429621600000 - (25929773539226*lm)/
            2909907 - 2106720*lm^2 - (25885547313218539935357881*Pi^2)/
            30810780 + (7082921261577973879602505329107*
             Im[PolyLog[2, (-1)^(1/3)]])/(311972449937989157994105*Sqrt[3]) - 
           1404480*Zeta[3]) + CA*NC*(8606520172645102489469470240378719594682\
7475239159760467247639870253/
            31232914832048731791552187920151995954859243200000 + 
           (19164909218233*lm)/4761666 + 643720*lm^2 + 
           (25885547313242797727352317*Pi^2)/61621560 - 
           (7082921261577973879602505329107*Im[PolyLog[2, (-1)^(1/3)]])/
            (623944899875978315988210*Sqrt[3]) + 702240*Zeta[3]))}, 0, 39, 1]
 
CbarLSeries["v", 2, 2, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-1347334788170*NM + 78976450560*lm*NM + 
         86704128000*lm^2*NM + 400301654016*NL + 78976450560*lm*NL + 
         86704128000*lm^2*NL - 1347334788170*NH + 78976450560*lm*NH + 
         86704128000*lm^2*NH + 420*CF*(3231875895374 + 597786624*lm + 
           3715891200*lm^2 - 2685567744405*Zeta[3]) + 1132665447375*NM*
          Zeta[3] + 1132665447375*NH*Zeta[3] - 
         6*CA*(-22228514268502 + 173549895680*lm + 79478784000*lm^2 + 
           18659802456225*Zeta[3])))/655483207680000, 
      -(CF*NC*(-313652016160*NM + 68389601280*lm*NM + 43352064000*lm^2*
           NM + 213313568768*NL + 68389601280*lm*NL + 
          43352064000*lm^2*NL - 1007357288490*NH + 68389601280*lm*NH + 
          43352064000*lm^2*NH + 210*CF*(3232075157582 + 3075047424*lm + 
            3715891200*lm^2 - 2685567744405*Zeta[3]) + 308706174000*NM*
           Zeta[3] + 823959273375*NH*Zeta[3] - CA*(-66511992909826 + 
            679607255040*lm + 238436352000*lm^2 + 55979407368675*Zeta[3])))/
       109247201280000, 
      (CF*NC*(36*CF*(588948951809799674 + 115512730583040*lm + 
           88958435328000*lm^2 - 489859697707961175*Zeta[3]) - 
         14*CA*(-94810326952098458 + 232140373032960*lm + 
           69895913472000*lm^2 + 79107171139938375*Zeta[3]) + 
         7*(262144*(524809871 + 198616635*lm + 96957000*lm^2)*NL + 
           315*NM*(-134092975934 + 165289394176*lm + 80687923200*lm^2 + 
             299307548925*Zeta[3]) + 315*NH*(-2750352860150 + 
             165289394176*lm + 80687923200*lm^2 + 2242547809425*Zeta[3]))))/
       259571350241280000, 
      -(CF*NC*(72*CF*(536679953387362094 + 45890616360960*lm + 
            28872474624000*lm^2 - 446434067280932325*Zeta[3]) - 
          140*CA*(-16332349703526454 + 16388704862208*lm + 
            4537103155200*lm^2 + 13604649696188145*Zeta[3]) + 
          7*(65536*(1500221917 + 588945420*lm + 251748000*lm^2)*NL + 
            45*NM*(447700266290 + 857713934336*lm + 366634598400*lm^2 + 
              975483587925*Zeta[3]) + 315*NH*(-2561540554582 + 
              122530562048*lm + 52376371200*lm^2 + 2096511365025*Zeta[3]))))/
       129785675120640000, 
      (CF*NC*(22*CF*(410846929332353968455454 + 10915761575087308800*lm + 
           6415120513105920000*lm^2 - 341778706678950797458125*Zeta[3]) - 
         121*CA*(-3641194628543956223462 + 1327322266376601600*lm + 
           356395584061440000*lm^2 + 3030653618702003093625*Zeta[3]) + 
         5*(262144*(38583008657411 + 14665232472660*lm + 5981981544000*lm^2)*
            NL + 3465*NM*(411970232852882 + 1109495729094656*lm + 
             452565821030400*lm^2 + 1939330622153925*Zeta[3]) + 
           3465*NH*(-31347438704519806 + 1109495729094656*lm + 
             452565821030400*lm^2 + 25783020643304925*Zeta[3]))))/
       8166114678590668800000, 
      -(CF*NC*(-6164631484825964766*NM + 3502997277345054720*lm*NM + 
          1477496606294016000*lm^2*NM + 10007906320315580416*NL + 
          3502997277345054720*lm*NL + 1477496606294016000*lm^2*NL - 
          144130109538182161086*NH + 3502997277345054720*lm*NH + 
          1477496606294016000*lm^2*NH + 110*CF*(49661338117227374407526 + 
            391888607338561536*lm + 241772171939020800*lm^2 - 
            41313362744495311029945*Zeta[3]) + 14466197882473462125*NM*
           Zeta[3] + 119053915773083416125*NH*Zeta[3] - 
          121*CA*(-1915055951863170494534 + 244702159251701760*lm + 
            67158936649728000*lm^2 + 1593440446052759394825*Zeta[3])))/
       1633222935718133760000, 
      (CF*NC*(624*CF*(3835440265299630418681078154 + 7658481878407367884800*
            lm + 5840009285295144960000*lm^2 - 3190726446229348625315091375*
            Zeta[3]) - 88*CA*(-1006754906029507941635778094 + 
           42187660520967792230400*lm + 12653353451472814080000*lm^2 + 
           837577220026062820916737125*Zeta[3]) + 
         5*(16777216*(16386392863985929 + 4975012300838580*lm + 
             2413435640616000*lm^2)*NL + 9009*NH*(-619396257996388132546 + 
             9264830277924945920*lm + 4494475640438784000*lm^2 + 
             513299080524314959875*Zeta[3]) + 9009*NM*
            (9264830277924945920*lm + 4494475640438784000*lm^2 + 
             143*(-570384264288243742 + 706609561318786125*Zeta[3])))))/
       264974089090910021222400000, 
      -(CF*NC*(832*CF*(4708585472099362143731378662 + 1559103335309928038400*
             lm + 2237727528808611840000*lm^2 - 3917106620446279341558101625*
             Zeta[3]) - 1056*CA*(-120906201939645633470823698 + 
            1465007516257930444800*lm + 538712182861332480000*lm^2 + 
            100584347140877481745738875*Zeta[3]) + 
          15*(67108864*(645221459501833 + 148653760715460*lm + 
              102751194546000*lm^2)*NL + 429*NM*(-834291351584956445578 + 
              23254044314550927360*lm + 16073463731060736000*lm^2 + 
              823527633956383731375*Zeta[3]) + 1287*NH*
             (7751348104850309120*lm + 5357821243686912000*lm^2 + 
              4719*(-224173559524898174 + 186201117310060125*Zeta[3])))))/
       176649392727273347481600000, 
      (CF*NC*(2*CF*(16948545451631908137961403228172262 - 
           958659186795818305506508800*lm + 2464691387198991488778240000*
            lm^2 - 14099622106342253154970863323381625*Zeta[3]) - 
         165*CA*(-5939409423912912998513146071698 + 
           14913849262768875173314560*lm + 9128486619255524032512000*lm^2 + 
           4941045246691760123103141030075*Zeta[3]) + 
         105*(536870912*(23463452284399319 + 1753960008981180*lm + 
             4858037520336000*lm^2)*NL + 429*NM*
            (-829600921429348027259222 + 2194988600543716311040*lm + 
             6079578168002347008000*lm^2 + 738811762476411437438625*
              Zeta[3]) + 143*NH*(-5319208666234527922626626 + 
             6584965801631148933120*lm + 18238734504007041024000*lm^2 + 
             4424891625043169645239875*Zeta[3]))))/
       672680887505456907209932800000, 
      (CF*NC*(11*CA*(-72626987077669081568412268054442 - 
           12248290694440651692441600*lm + 36376951202978967060480000*lm^2 + 
           60418788384089044184302205553375*Zeta[3]) - 
         2*(3*CF*(5156828774384354276313705796641766 - 
             514973651948252283115929600*lm + 218261707217873802362880000*
              lm^2 - 4290004446646807127675848993205625*Zeta[3]) + 
           35*(429*NM*(-901856131594587469333958 - 3899182723219524157440*
                lm + 2422707372825772032000*lm^2 + 765974244926707959767625*
                Zeta[3]) + 16*(16777216*(5700908876701427 - 6231477067847460*
                  lm + 3871848668688000*lm^2)*NL + 1287*NH*
                (-23090261353016334488726 - 81232973400406753280*lm + 
                 50473070267203584000*lm^2 + 19225829545899089738625*
                  Zeta[3]))))))/288291808930910103089971200000, 
      (CF*NC*(68*CF*(141033000571418096334382938253647995306 - 
           10142651758730370866899373260800*lm + 
           1543268389766515272135475200000*lm^2 - 
           117326401995350688763876956299791569375*Zeta[3]) - 
         110*CA*(-2022598255147751126491812904901452538 - 
           1326196576215550454974686167040*lm + 
           291506251400341773625589760000*lm^2 + 
           1682610220272514129747991399397813975*Zeta[3]) + 
         105*(6442450944*(-59404797098541997819 - 50179203012611012340*lm + 
             8618614367322960000*lm^2)*NL + 17017*NM*
            (-3815033044231997740359241106 - 18997299983414436172922880*lm + 
             3262913572705633566720000*lm^2 + 3177508213012714830208834875*
              Zeta[3]) + 17017*NH*(-18997299983414436172922880*lm + 
             3262913572705633566720000*lm^2 + 
             2431*(-1094759083115992163108006 + 911984784721587721769625*
                Zeta[3])))))/44324289039509566529876892057600000, 
      -(CF*NC*(-44*CA*(-548980422915337990544329993255635778 - 
            305528523308070310589025484800*lm + 15732007852353519951544320000*
             lm^2 + 456700014504985182297020587473415875*Zeta[3]) + 
          5*(136*CF*(1694918661307171157652681672645064066 - 
              71438841454401610948898979840*lm + 3331484015792510107385856000*
               lm^2 - 1410015383139382658314149215955888675*Zeta[3]) + 
            21*(1610612736*(-29269514727227414483 - 15400282861529846280*lm + 
                744206936224752000*lm^2)*NL + 19448*NM*(
                -337215634562204672946591442 - 1275395501582810307624960*lm + 
                61632515924677361664000*lm^2 + 279153104293856709344302875*
                 Zeta[3]) + 2431*NH*(-10203164012662482460999680*lm + 
                493060127397418893312000*lm^2 + 2431*
                 (-428523467954588582728066 + 357045483467413341475875*
                   Zeta[3]))))))/2770268064969347908117305753600000, 
      -(CF*NC*(-2*CA*(934937853340468254774605212187591529274382 + 
            345277979327644492145082625739980800*lm + 
            3685678869305576539337030369280000*lm^2 - 
            777780755248305213202149765964012788451125*Zeta[3]) + 
          5*(76*CF*(-258619007526101271225170909720305065171278 + 
              5818958287926639933947096932024320*lm + 
              63485377653110409290015834112000*lm^2 + 
              215147062465340491867373049660044850933525*Zeta[3]) + 
            7*(103079215104*(80876763780278915778073 + 
                34328622198418188721080*lm + 371488737420728928000*lm^2)*
               NL + 29393*NM*(49684573064289884370896354037758 + 
                120388100289684545426675466240*lm + 
                1302785271095318317891584000*lm^2 - 
                41108869816072631438139561412125*Zeta[3]) + 
              4199*NH*(842716702027791817986728263680*lm + 
                9119496897667228225241088000*lm^2 - 79781*
                 (-908213677541728408981076746 + 756704154064745959941243375*
                   Zeta[3]))))))/128008546746103628138284464262348800000, 
      (CF*NC*(-6*CA*(168598419033242136599303052782786972590414 + 
           37176862332586917254537877336883200*lm + 
           1674819792543671906642574704640000*lm^2 - 
           140258165388676581210351204843379019791125*Zeta[3]) + 
         228*CF*(-255706590757654668975638378552695134777542 + 
           2910071080877976954235819288166400*lm + 
           144242852946344948897446625280000*lm^2 + 
           212724199265199823182381917537861615399625*Zeta[3]) + 
         35*(34359738368*(86923651758146499818173 + 31790702288419860665880*
              lm + 1519283260917598176000*lm^2)*NL + 
           29393*NM*(26454657203953428293828086769666 + 
             37162596984489003797320826880*lm + 1776007054469110092005376000*
              lm^2 - 21915703848685651038601431739875*Zeta[3]) + 
           4199*NH*(260138178891423026581245788160*lm + 
             12432049381283770644037632000*lm^2 - 
             4199*(-4853607936704163350573341618 + 
               4043272180948147725671968875*Zeta[3])))))/
       42669515582034542712761488087449600000, 
      -(CF*NC*(-4*CA*(1211722627683362382389203646624581328872166698 + 
            150368490526033868275075514421687091200*lm + 
            10393420852814016138880219757936640000*lm^2 - 
            1008040560881407695721696741189095807819417375*Zeta[3]) + 
          7*(104*CF*(-419056533484911693035786937921700064443570274 + 
              2325891932849213736703607650752921600*lm + 
              186894680669982308191652303339520000*lm^2 + 
              348616220197995267806522077894838868459253875*Zeta[3]) + 
            165*(1924145348608*(139041929711237294435329 + 
                44879000066678237957640*lm + 3401229643737333408000*lm^2)*
               NL + 4199*NM*(27015292197956165664572470511119786 + 
                20565305841504418532881732730880*lm + 
                1558575898677026681190875136000*lm^2 - 
                22411606311002371350247057500177375*Zeta[3]) + 
              4199*NH*(20565305841504418532881732730880*lm + 
                1558575898677026681190875136000*lm^2 - 4199*
                 (-368472794486189748215541271334 + 
                  306880152976615344742632641625*Zeta[3]))))))/
       129544649307056871675943877833496985600000, 
      (CF*NC*(385*(1099511627776*(664646497445076548635196 + 
             190877097879976670617455*lm + 19226790298370488333500*lm^2)*
            NL + 20995*NM*(9996265234349703633603378806784*lm + 
             1006910192801578487634513100800*lm^2 + 
             65*(391681903739834719995326809645226 - 
               325287079949638243784311345315935*Zeta[3])) + 
           20995*NH*(752080615408155646490648683691038 + 
             9996265234349703633603378806784*lm + 
             1006910192801578487634513100800*lm^2 - 
             626189097982848282136520938997325*Zeta[3])) - 
         240*CA*(31088258900878004021242240661145169954956022 + 
           2089065012904308758656632771638722560*lm + 
           186517159736407936194374503759872000*lm^2 - 
           25862545621919963196884324938620617714084625*Zeta[3]) + 
         32*CF*(-15967777165534350295876968637923263676087481238 + 
           42016704555448977987789210747351859200*lm + 
           4578148466257285706589192365015040000*lm^2 + 
           13283711545077397734252557545649903433338714625*Zeta[3])))/
       129544649307056871675943877833496985600000, 
      -(CF*NC*(-34*CA*(3728259313763754100508318405285695956291190446182 + 
            131903660093637510821757829264218626457600*lm + 
            14352723293228369526388151916265734144000*lm^2 - 
            3101566003424456325570555508080363135877770605625*Zeta[3]) + 
          5*(3927*(1099511627776*(127408434706402070759994241 + 
                32538952278457833459331080*lm + 4109791669800581311747200*
                 lm^2)*NL + 2185*NM*(
                84035895659791519943967623585718953926 + 
                16373893082751833631966788497440768*lm + 
                2068084086353630324663711296389120*lm^2 - 
                69840757737283683370679685453975172425*Zeta[3]) + 
              111435*NH*(25027343050259230520879805313295266 + 
                321056727112781051607191931322368*lm + 
                40550668359875104405170809733120*lm^2 - 
                20831926195055312638547558837800275*Zeta[3])) + 
            460*CF*(-4092592878348590242814242321399949591423365676102 + 
              4976891172594157491996020423736466341888*lm + 
              694376810707965387363600709308666347520*lm^2 + 
              3404658186487996889232787329122400246767187250185*Zeta[3]))))/
       1461954548979905815820251975976957981491200000, 
      (CF*NC*(-(CA*(25505032461610435824133156797406600254291342666578 + 
            464359515988482910338844081933923228057600*lm + 
            60390654264601563310354436579659874304000*lm^2 - 
            21217823037635720110908599153908772376427838950875*Zeta[3])) + 
         5*(46*CF*(-8900584683802622433321625507328113588567873016602 + 
             4869330013133071515723620292688682680320*lm + 
             859313657520022244732316093623618764800*lm^2 + 
             7404462014639317717064878400480756118591407936775*Zeta[3]) + 
           21*(549755813888*(5413174518882367078452877361 + 
               1220529868032884946416759880*lm + 190216381264955205867907200*
                lm^2)*NL + 520030*NM*
              (13785500415807238387924976690340366562 + 
               1290297465482821947322287362408448*lm + 
               201089478486136500151479561093120*lm^2 - 
               11461874276711712005553316196432826675*Zeta[3]) + 
             37145*NH*(18064164516759507262512023073718272*lm + 
               2815252698805911002120713855303680*lm^2 - 7429*
                (-203348127840245523052918694296546 + 
                 169213105690636584176642772004275*Zeta[3]))))))/
       199357438497259883975488905815039724748800000}, 2, 20, 1]
 
CbarLSeries["v", 2, 3, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(CF*(-1157360400*lm^2 + 16218036*Pi^2 + 793800*Pi^4 + 
            7144200*lm*(-221 + 12*Pi^2) + 35*(-35804493 + 124743552*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] - 9797760*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 20790592*PolyGamma[2, 1] - 
              207349952*Zeta[3])) + 35*CA*(21043251 + 6735960*lm^2 - 
            2241432*Pi^2 + 61236*Pi^4 - 15120*lm*(-1645 + 33*Pi^2) - 
            62371776*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            4898880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 10395296*PolyGamma[2, 1] + 
            109713040*Zeta[3]) + 70*(9*NL*(-131005 - 68040*lm^2 - 
              4932*Pi^2 + 1680*lm*(-98 + 3*Pi^2) - 60480*Zeta[3]) + 
            9*NM*(-131005 - 68040*lm^2 - 4932*Pi^2 + 1680*lm*(-98 + 
                3*Pi^2) + 5040*PolyGamma[2, 1] - 50400*Zeta[3]) + 
            NH*(3319767 - 612360*lm^2 + 15120*lm*(-98 + 3*Pi^2) - 
              257432016*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              42905336*PolyGamma[2, 1] + 459939952*Zeta[3]))))/10287648000, 
      -(CF*NC*(-49*CA*(-15970032 + 5773680*lm^2 - 2768823*Pi^2 + 96228*Pi^4 - 
            3240*lm*(-4501 + 132*Pi^2) - 12578388*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 7698240*Im[PolyLog[2, (-1)^(1/3)]]^
              2 + 2143378*PolyGamma[2, 1] + 21321380*Zeta[3]) + 
          2*(-98*(NH*(83733093 - 262440*lm^2 + 1620*lm*(-203 + 12*Pi^2) + 
                32125776*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 5354296*
                 PolyGamma[2, 1] - 127193072*Zeta[3]) + 27*NL*(25795 - 
                9720*lm^2 - 516*Pi^2 + 60*lm*(-203 + 12*Pi^2) - 
                8640*Zeta[3]) + 27*NM*(25795 - 9720*lm^2 - 516*Pi^2 + 
                60*lm*(-203 + 12*Pi^2) + 720*PolyGamma[2, 1] - 
                7200*Zeta[3])) + CF*(694416240*lm^2 + 2492829*Pi^2 + 
              1666980*Pi^4 - 17146080*lm*(-8 + 3*Pi^2) + 7*(87103341 - 
                88048716*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 53887680*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 + 15003646*PolyGamma[2, 1] + 
                93534620*Zeta[3])))))/2057529600, 
      -(CF*NC*(CF*(52081218000*lm^2 + 5138715006*Pi^2 - 547722000*Pi^4 + 
            21432600*lm*(-1519 + 60*Pi^2) + 35*(1319307453 + 3276553608*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 2057529600*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 505821332*PolyGamma[2, 1] - 
              8176386856*Zeta[3])) + 35*CA*(1545748893 - 303118200*lm^2 - 
            97541739*Pi^2 + 8913240*Pi^4 - 22680*lm*(22763 + 330*Pi^2) - 
            1638276804*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            1028764800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 252910666*
             PolyGamma[2, 1] + 3705159332*Zeta[3]) + 
          70*(135*NL*(-808045 + 204120*lm^2 + 93708*Pi^2 + 168*lm*(523 + 
                30*Pi^2) - 60480*Zeta[3]) + 135*NM*(-1291381 + 204120*lm^2 + 
              154188*Pi^2 + 168*lm*(523 + 30*Pi^2) + 11088*PolyGamma[2, 1] - 
              38304*Zeta[3]) + NH*(-5975737335 + 27556200*lm^2 + 
              22680*lm*(523 + 30*Pi^2) - 14293401840*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 2468044312*PolyGamma[2, 1] + 30796731824*Zeta[
                3]))))/30862944000, 
      -(CF*NC*(30269340725085*CF + 29281218120000*CF*lm + 
          25248974486400*CF*lm^2 - 2680761031200*NM + 2071589385600*lm*NM + 
          935147203200*lm^2*NM + 1122068052000*NL + 2071589385600*lm*NL + 
          935147203200*lm^2*NL - 141176810043360*NH + 2071589385600*lm*
           NH + 935147203200*lm^2*NH - 1277351945424*CF*Pi^2 - 
          444426393600*CF*lm*Pi^2 + 368777888640*NM*Pi^2 - 
          16460236800*lm*NM*Pi^2 + 430503776640*NL*Pi^2 - 
          16460236800*lm*NL*Pi^2 - 16460236800*lm*NH*Pi^2 + 
          111125140000*Sqrt[3]*CF*Pi^3 + 5185034960000*Sqrt[3]*NH*Pi^3 + 
          45248505120*CF*Pi^4 - 15707566459200*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] - 52848078097920*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 20036223244800*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 4114805184000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 191994437376000*Sqrt[3]*
           NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 85725108000*Sqrt[3]*CF*
           Pi*Log[3]^2 + 3999884112000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          61725888000*(-2*CA*(76 + 33*lm) + 9*CF*(61 + 36*lm) + 
            4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          246903552000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          2935385967920*CF*PolyGamma[2, 1] + 131681894400*NM*
           PolyGamma[2, 1] + 11663501987200*NH*PolyGamma[2, 1] + 
          14312688513760*CF*Zeta[3] + 90531302400*NM*Zeta[3] + 
          2049299481600*NL*Zeta[3] + 56527301600000*NH*Zeta[3] - 
          529200*Log[x]*(-4*(243*NM*(4859 + 4800*lm + 1080*lm^2 + 
                600*Pi^2) + 243*NL*(9179 + 4800*lm + 1080*lm^2 + 600*Pi^2) + 
              NH*(53023659 + 1166400*lm + 262440*lm^2 - 30233440*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + CF*(-97433481 - 96053040*lm - 
              28343520*lm^2 + 1102248*Pi^2 + 2591840*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 8398080*Zeta[3]) + 
            4*CA*(14923374 + 8252280*lm + 1443420*lm^2 + 2187*Pi^2 - 
              323980*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1049760*Zeta[3])) - 
          140*CA*(36737925840*lm^2 - 6725758374*Pi^2 + 396875500*Sqrt[3]*
             Pi^3 + 255660300*Pi^4 - 1224720*lm*(-104629 + 528*Pi^2) + 
            306161100*Sqrt[3]*Pi*Log[3]^2 + 7*(10194408567 - 8014064520*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 10222562880*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 2099390400*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 1497645902*PolyGamma[2, 1] + 
              12698293468*Zeta[3]))))/555532992000, 
      -(CF*NC*(162*CF*(7 + 5*lm) - 5*CA*(76 + 33*lm) + 
           10*(3*(2 + lm)*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2)/15 - 
       (2*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/3 + 
       (CF*NC*Log[x]*(-4*(243*NL*(23119 + 12492*lm + 3240*lm^2 + 
              1800*Pi^2) + 243*NM*(7193 + 12492*lm + 3240*lm^2 + 
              2640*Pi^2) + NH*(78472599 + 3035556*lm + 787320*lm^2 - 
              44756800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          3*CF*(-79365759 - 79361856*lm - 28343520*lm^2 + 2618568*Pi^2 + 
            10544608*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 8398080*Zeta[3]) - 
          12*CA*(-14060505 - 7402266*lm - 1443420*lm^2 + 220401*Pi^2 + 
            1318076*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1049760*Zeta[3])))/
        2099520 + (CF*NC*(3*CF*(-22749076022400*lm^2 + 1050455139408*Pi^2 - 
            452100068000*Sqrt[3]*Pi^3 + 18729234720*Pi^4 + 
            514382400*lm*(-24409 + 24*Pi^2) - 348762909600*Sqrt[3]*Pi*
             Log[3]^2 - 35*(344574821277 + 34267717824*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 770691801600*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 478303418880*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 14648594672*PolyGamma[2, 1] - 
              917705303456*Zeta[3])) - 420*CA*(34254407457 - 
            33100507440*lm^2 + 2249226954*Pi^2 - 1614643100*Sqrt[3]*Pi^3 + 
            64277388*Pi^4 + 544320*lm*(-175147 + 33*Pi^2) - 
            4283464728*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            96336475200*Im[PolyLog[2, (-1)^(1/3)]]^2 - 59787927360*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1245581820*Sqrt[3]*Pi*
             Log[3]^2 - 1831074334*PolyGamma[2, 1] + 74294638564*Zeta[3]) + 
          1120*(486*NL*(1299655 - 4643730*lm^2 - 2591586*Pi^2 + 
              420*lm*(-17773 + 6*Pi^2) - 10236240*Zeta[3]) + 
            243*NM*(47953955 - 9287460*lm^2 - 7522992*Pi^2 + 
              840*lm*(-17773 + 6*Pi^2) - 2610234*PolyGamma[2, 1] + 
              8327052*Zeta[3]) - NH*(-271127954259 + 2256852780*lm^2 + 
              6853385000*Sqrt[3]*Pi^3 - 204120*lm*(-17773 + 6*Pi^2) - 
              306267222048*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              253771056000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              5286897000*Sqrt[3]*Pi*Log[3]^2 + 58239022474*PolyGamma[2, 1] + 
              576522067988*Zeta[3]))))/1111065984000, 
      (-3740747964181*CF^2*NC)/10581580800 - (66931*CF^2*lm*NC)/120 - 
       (1809*CF^2*lm^2*NC)/4 + (414269*CF*NM*NC)/4860 - 
       (15527*CF*lm*NM*NC)/405 - (67*CF*lm^2*NM*NC)/4 - 
       (339583*CF*NC*NL)/19440 - (15527*CF*lm*NC*NL)/405 - 
       (67*CF*lm^2*NC*NL)/4 + (180234769231*CF*NC*NH)/59049000 - 
       (15527*CF*lm*NC*NH)/405 - (67*CF*lm^2*NC*NH)/4 + 
       (4335887267*CF^2*NC*Pi^2)/95256000 + 5*CF^2*lm*NC*Pi^2 - 
       (1993*CF*NM*NC*Pi^2)/324 + (5*CF*lm*NM*NC*Pi^2)/27 - 
       (1727*CF*NC*NL*Pi^2)/162 + (5*CF*lm*NC*NL*Pi^2)/27 + 
       (5*CF*lm*NC*NH*Pi^2)/27 - (143417323*CF^2*NC*Pi^3)/
        (5668704*Sqrt[3]) - (294995155*CF*NC*NH*Pi^3)/(708588*Sqrt[3]) - 
       (18811*CF^2*NC*Pi^4)/10800 + (566409779*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(590490*Sqrt[3]) + 
       (892082351*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
       (6691*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (20488189*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (21870*Sqrt[3]) - (33713732*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (20488189*CF^2*NC*Pi*Log[3]^2)/(1049760*Sqrt[3]) - 
       (8428433*CF*NC*NH*Pi*Log[3]^2)/(26244*Sqrt[3]) - 
       (CF*NC*(-3*CA*(6763 + 3300*lm) + 2*(38391*CF + 24300*CF*lm + 
            2070*NM + 900*lm*NM + 1350*NL + 900*lm*NL + 16*NH + 
            900*lm*NH))*Log[x]^2)/60 - 10*CF*NC*(13*CA + 46*CF - 
         2*(2*NM + NL))*Log[x]^3 - (29913748039*CF^2*NC*PolyGamma[2, 1])/
        425152800 - (16931*CF*NM*NC*PolyGamma[2, 1])/5400 - 
       (26001901517*CF*NC*NH*PolyGamma[2, 1])/106288200 + 
       (CF*NC*Log[x]*(2*(-16*(14580*NM*(15280 + 9567*lm + 2025*lm^2 + 
                525*Pi^2) + 10935*NL*(26035 + 12756*lm + 2700*lm^2 + 
                1800*Pi^2) + 2*NH*(2961461823 + 69743430*lm + 14762250*
                 lm^2 - 1685686600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            5*CF*(-9618891519 - 9359030304*lm - 2550916800*lm^2 + 
              181171080*Pi^2 + 655622048*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              755827200*Zeta[3])) - 5*CA*(-12128834145 - 6232635072*lm - 
            1039262400*lm^2 + 56179656*Pi^2 + 655622048*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 755827200*Zeta[3])))/62985600 - 
       (82118348393*CF^2*NC*Zeta[3])/297606960 + (202069*CF*NM*NC*Zeta[3])/
        2700 - (560*CF*NC*NL*Zeta[3])/9 - (9861841517*CF*NC*NH*Zeta[3])/
        53144100 + (CA*CF*NC*(17546906361600*lm^2 - 4047183293040*Pi^2 + 
          803137008800*Sqrt[3]*Pi^3 + 194092645824*Pi^4 - 
          117573120*lm*(-531539 + 1650*Pi^2) + 619562835360*Sqrt[3]*Pi*
           Log[3]^2 + 7*(3086755153605 - 4350027102720*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 6068687754240*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 4248430871040*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 957239937248*
             PolyGamma[2, 1] + 6675519388096*Zeta[3])))/190468454400, 
      -(CF*NC*(-825*CA*(267 + 98*lm) + 14*CF*(46283 + 28350*lm) + 
           3*(17939*NM + 4900*lm*NM + 7075*NL + 4900*lm*NL + 108*NH + 
             4900*lm*NH))*Log[x]^2)/405 - 
       (20*CF*NC*(449*CA + 2783*CF - 151*NM - 98*NL)*Log[x]^3)/81 + 
       (CF*NC*Log[x]*(-8*(10404481185*NL + 5174748180*lm*NL + 
            1240029000*lm^2*NL + 133639937139*NH + 5174748180*lm*NH + 
            1240029000*lm^2*NH + 841995000*NL*Pi^2 + 
            3645*NM*(2042947 + 1419684*lm + 340200*lm^2 + 292800*Pi^2) - 
            75934812800*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
            5*CF*(-21641434869 - 20875474872*lm - 6696156600*lm^2 + 
              360347616*Pi^2 + 3460496624*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 1984046400*Zeta[3])) + 
          5*CA*(120973230921 + 59426108784*lm + 10912255200*lm^2 - 
            385121952*Pi^2 - 13841986496*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            7936185600*Zeta[3])))/566870400 - 
       (CF*NC*(-5*CA*(-194505443588205 + 168528869308800*lm^2 - 
            17185551675840*Pi^2 + 16956433457600*Sqrt[3]*Pi^3 + 
            1078196948640*Pi^4 - 3879912960*lm*(-130912 + 75*Pi^2) - 
            81001411759680*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            557263080460800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            627872507458560*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
            13080677238720*Sqrt[3]*Pi*Log[3]^2 + 46236666329392*
             PolyGamma[2, 1] - 379458746490016*Zeta[3]) + 
          8*(5*CF*(33179412400335 + 103415442530400*lm^2 - 7115862247848*Pi^
                2 + 4239108364400*Sqrt[3]*Pi^3 + 258967656360*Pi^4 - 
              297606960*lm*(-238241 + 600*Pi^2) - 20250352939920*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 139315770115200*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 156968126864640*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 3270169309680*Sqrt[3]*Pi*Log[3]^
                2 + 11559166582348*PolyGamma[2, 1] - 155429885433544*Zeta[
                3]) - 8*(984150*NL*(1163547 - 2432430*lm^2 - 1723570*Pi^2 + 
                28*lm*(-151259 + 150*Pi^2) - 9752400*Zeta[3]) + 
              32805*NM*(407825005 - 72972900*lm^2 - 81787080*Pi^2 + 
                840*lm*(-151259 + 150*Pi^2) - 43238502*PolyGamma[2, 1] + 
                383754996*Zeta[3]) - NH*(-328546178117487 + 2393875984500*
                 lm^2 + 11627518210000*Sqrt[3]*Pi^3 - 27556200*lm*
                 (-151259 + 150*Pi^2) - 256604944771200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 430550388576000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 8969799762000*
                 Sqrt[3]*Pi*Log[3]^2 + 53062243630490*PolyGamma[2, 1] + 
                393533448764980*Zeta[3])))))/8571080448000, 
      (-11780095057729*CF^2*NC)/15872371200 - (121827*CF^2*lm*NC)/40 - 
       (9693*CF^2*lm^2*NC)/4 + (17689789*CF*NM*NC)/19440 - 
       (37357*CF*lm*NM*NC)/180 - (359*CF*lm^2*NM*NC)/4 - 
       (390751*CF*NC*NL)/19440 - (37357*CF*lm*NC*NL)/180 - 
       (359*CF*lm^2*NC*NL)/4 + (861996695617583*CF*NC*NH)/40507614000 - 
       (37357*CF*lm*NC*NH)/180 - (359*CF*lm^2*NC*NH)/4 + 
       (54883263443*CF^2*NC*Pi^2)/142884000 + 20*CF^2*lm*NC*Pi^2 + 
       (142103*CF*NM*NC*Pi^2)/1620 + (20*CF*lm*NM*NC*Pi^2)/27 - 
       (7769*CF*NC*NL*Pi^2)/108 + (20*CF*lm*NC*NL*Pi^2)/27 + 
       (20*CF*lm*NC*NH*Pi^2)/27 - (762462505*CF^2*NC*Pi^3)/
        (2834352*Sqrt[3]) - (6522686065*CF*NC*NH*Pi^3)/(2125764*Sqrt[3]) - 
       (158321*CF^2*NC*Pi^4)/10800 + (42454454941*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7085880*Sqrt[3]) + 
       (5618385323*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
       (42601*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (21784643*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2187*Sqrt[3]) - (745449836*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (21784643*CF^2*NC*Pi*Log[3]^2)/(104976*Sqrt[3]) - 
       (186362459*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) - 
       (CF*NC*(-105*CA*(111217 + 57200*lm) + 4*(189*CF*(60701 + 39000*lm) + 
            168*(-3177 + 1625*lm)*NM + 386050*NL + 273000*lm*NL + 
            11502*NH + 273000*lm*NH))*Log[x]^2)/3780 - 
       (10*CF*NC*(3609*CA + 20*(791*CF - 26*(6*NM + NL)))*Log[x]^3)/27 - 
       (7926377723*CF^2*NC*PolyGamma[2, 1])/15746400 + 
       (222553*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (64420010177*CF*NC*NH*PolyGamma[2, 1])/39858075 - 
       (CF*NC*Log[x]*(4*(535815*NM*(630379 + 560440*lm + 113400*lm^2 - 
              196680*Pi^2) + 535815*NL*(1234937 + 560440*lm + 113400*lm^2 + 
              89800*Pi^2) + NH*(12856238837727 + 300292158600*lm + 
              60761421000*lm^2 - 7305408392800*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]])) - 735*CF*(-35476895253 - 34700341680*lm - 
            8928208800*lm^2 + 787582440*Pi^2 + 3485542880*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2645395200*Zeta[3]) + 
          1470*CA*(-11342519751 - 5651528760*lm - 909354600*lm^2 + 
            77295870*Pi^2 + 871385720*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            661348800*Zeta[3])))/2314720800 - (85160458217*CF^2*NC*Zeta[3])/
        55112400 + (1321453*CF*NM*NC*Zeta[3])/1350 - 
       (4570*CF*NC*NL*Zeta[3])/9 + (62732650346*CF*NC*NH*Zeta[3])/
        39858075 + (CA*CF*NC*(2938124712600*lm^2 - 976453855875*Pi^2 + 
          266861876750*Sqrt[3]*Pi^3 + 47154445002*Pi^4 - 
          5511240*lm*(-1911291 + 4400*Pi^2) + 205864876350*Sqrt[3]*Pi*
           Log[3]^2 + 7*(9512429115 - 849089098820*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 1207462295520*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 1411644866400*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 214012198521*
             PolyGamma[2, 1] + 1255702420242*Zeta[3])))/5952139200, 
      (-711769888668973*CF^2*NC)/2857026816000 - (527741*CF^2*lm*NC)/320 - 
       (35937*CF^2*lm^2*NC)/16 + (1052823911*CF*NM*NC)/1944000 - 
       (1286411*CF*lm*NM*NC)/8640 - (1331*CF*lm^2*NM*NC)/16 + 
       (109673893*CF*NC*NL)/933120 - (1286411*CF*lm*NC*NL)/8640 - 
       (1331*CF*lm^2*NC*NL)/16 + (30826623701056663*CF*NC*NH)/
        2187411156000 - (1286411*CF*lm*NC*NH)/8640 - (1331*CF*lm^2*NC*NH)/
        16 - (683976521*CF^2*NC*Pi^2)/19051200 + (95*CF^2*lm*NC*Pi^2)/24 - 
       (39902659*CF*NM*NC*Pi^2)/272160 + (95*CF*lm*NM*NC*Pi^2)/648 - 
       (3905591*CF*NC*NL*Pi^2)/54432 + (95*CF*lm*NC*NL*Pi^2)/648 + 
       (95*CF*lm*NC*NH*Pi^2)/648 - (67553205937*CF^2*NC*Pi^3)/
        (153055008*Sqrt[3]) - (130366685155*CF*NC*NH*Pi^3)/
        (76527504*Sqrt[3]) - (154373*CF^2*NC*Pi^4)/12960 + 
       (3914222509349*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1785641760*Sqrt[3]) + (11830806419239*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(446410440*Sqrt[3]) - 
       (20671*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (9650457991*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (590490*Sqrt[3]) - (3724762433*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (9650457991*CF^2*NC*Pi*Log[3]^2)/(28343520*Sqrt[3]) - 
       (3724762433*CF*NC*NH*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (CF*NC*(-7*CA*(39552817 + 10659660*lm) + 
          2*(28*CF*(13394396 + 6541155*lm) + 420*(83582 + 16151*lm)*NM + 
            9111165*NL + 6783420*lm*NL + 346032*NH + 6783420*lm*NH))*
         Log[x]^2)/45360 - (CF*NC*(84095*CA + 1322865*CF - 94172*NM - 
          32302*NL)*Log[x]^3)/162 - (31617104639597*CF^2*NC*PolyGamma[2, 1])/
        53569252800 - (11742721*CF*NM*NC*PolyGamma[2, 1])/226800 - 
       (929007322207*CF*NC*NH*PolyGamma[2, 1])/478296900 + 
       (CA*CF*NC*(23529222907344000*lm^2 + 3230121749911200*Pi^2 + 
          3782979532472000*Sqrt[3]*Pi^3 + 312314695963200*Pi^4 - 
          10912255200*lm*(-6603513 + 3800*Pi^2) + 2918298496478400*Sqrt[3]*Pi*
           Log[3]^2 + 3*(-13078995168722631 - 6262756014958400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 29528800656768000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 46692775943654400*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 5058736742335520*
             PolyGamma[2, 1] - 25707654962432960*Zeta[3])))/51426482688000 + 
       (122304108494143*CF^2*NC*Zeta[3])/26784626400 + 
       (106302479*CF*NM*NC*Zeta[3])/113400 - (13793*CF*NC*NL*Zeta[3])/27 - 
       (2607726105457*CF*NC*NH*Zeta[3])/239148450 - 
       (CF*NC*Log[x]*(-49*CA*(26690252463327 + 11127398788080*lm + 
            1964205936000*lm^2 + 427046042160*Pi^2 - 3088146557120*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 1428513408000*Zeta[3]) + 
          2*(4*(428652*NM*(85798397 + 22414215*lm + 5103000*lm^2 + 
                1722750*Pi^2) + 535815*NL*(39420973 + 17931372*lm + 
                4082400*lm^2 + 3298920*Pi^2) + 2*NH*(128875205125389 + 
                4803949044090*lm + 1093705578000*lm^2 - 73005343686800*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            49*CF*(19851760567047 + 16087512688560*lm + 4821232752000*lm^2 + 
              183056623920*Pi^2 - 3088146557120*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 1428513408000*Zeta[3]))))/166659897600, 
      (2017794036685283*CF^2*NC)/918330048000 - (1870163*CF^2*lm*NC)/160 - 
       (73773*CF^2*lm^2*NC)/8 + (1701946541*CF*NM*NC)/388800 - 
       (1142531*CF*lm*NM*NC)/1440 - (8197*CF*lm^2*NM*NC)/24 + 
       (59731261*CF*NC*NL)/155520 - (1142531*CF*lm*NC*NL)/1440 - 
       (8197*CF*lm^2*NC*NL)/24 + (826171547446019221*CF*NC*NH)/
        7874680161600 - (1142531*CF*lm*NC*NH)/1440 - (8197*CF*lm^2*NC*NH)/
        24 + (384082575241*CF^2*NC*Pi^2)/149688000 + (245*CF^2*lm*NC*Pi^2)/
        4 + (19172807*CF*NM*NC*Pi^2)/6480 + (245*CF*lm*NM*NC*Pi^2)/108 - 
       (47429*CF*NC*NL*Pi^2)/144 + (245*CF*lm*NC*NL*Pi^2)/108 + 
       (245*CF*lm*NC*NH*Pi^2)/108 - (561146336779*CF^2*NC*Pi^3)/
        (344373768*Sqrt[3]) - (5300585675735*CF*NC*NH*Pi^3)/
        (344373768*Sqrt[3]) - (4946291*CF^2*NC*Pi^4)/64800 + 
       (15291275260169*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (573956280*Sqrt[3]) + (25008080101379*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(286978140*Sqrt[3]) - 
       (374857*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
       (160327524794*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2657205*Sqrt[3]) - (302890610042*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (80163762397*CF^2*NC*Pi*Log[3]^2)/(63772920*Sqrt[3]) - 
       (151445305021*CF*NC*NH*Pi*Log[3]^2)/(12754584*Sqrt[3]) - 
       (CF*NC*(-21*CA*(11056547 + 6871480*lm) + 
          2*(7*CF*(72460807 + 50599080*lm) + 2*(42*(-2798347 + 156170*lm)*
               NM + 245*(36581 + 26772*lm)*NL + 10*(44921 + 655914*lm)*
               NH)))*Log[x]^2)/15120 - 
       (7*CF*NC*(103738*CA + 499351*CF - 6*(34278*NM + 2231*NL))*Log[x]^3)/
        81 - (477391060256449*CF^2*NC*PolyGamma[2, 1])/206624260800 + 
       (13894091*CF*NM*NC*PolyGamma[2, 1])/5400 - 
       (48956400374941*CF*NC*NH*PolyGamma[2, 1])/6457008150 + 
       (CF*NC*Log[x]*(2*(20*(-8680203*NL*(12897273 + 5406428*lm + 
                1058400*lm^2 + 977480*Pi^2) + 34720812*NM*(5495792 - 
                1351607*lm - 264600*lm^2 + 2122050*Pi^2) - 
              2*NH*(1046190705420783 + 23464446272442*lm + 4593563427600*
                 lm^2 - 593665595682320*Sqrt[3]*Im[PolyLog[2, (-1)^
                    (1/3)]])) + 49*CF*(-375126405180387 - 410304891158640*
               lm - 101245887792000*lm^2 + 13096340716320*Pi^2 + 
              51304807934080*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              29998781568000*Zeta[3])) - 49*CA*(-497394580388937 - 
            263199017945520*lm - 41248324656000*lm^2 + 7012697031360*Pi^2 + 
            51304807934080*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            29998781568000*Zeta[3])))/749969539200 - 
       (132725166063893*CF^2*NC*Zeta[3])/20662426080 + 
       (16414091*CF*NM*NC*Zeta[3])/2700 - (24682*CF*NC*NL*Zeta[3])/9 + 
       (46723307243309*CF*NC*NH*Zeta[3])/3228504075 + 
       (CA*CF*NC*(-46068811932404457 + 31051149539256000*lm^2 - 
          18452762461877400*Pi^2 + 4489170694232000*Sqrt[3]*Pi^3 + 
          660877622047440*Pi^4 - 1913187600*lm*(-58359963 + 107800*Pi^2) - 
          73398121248811200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          103272734040940800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          166227577706419200*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          3463074535550400*Sqrt[3]*Pi*Log[3]^2 + 19095642410257960*
           PolyGamma[2, 1] + 107377046196771920*Zeta[3]))/16529940864000, 
      (101558019215173631569*CF^2*NC)/31498720646400000 - 
       (47135309*CF^2*lm*NC)/8000 - (621621*CF^2*lm^2*NC)/80 + 
       (438287113799*CF*NM*NC)/416745000 - (112750859*CF*lm*NM*NC)/216000 - 
       (23023*CF*lm^2*NM*NC)/80 + (97306588313*CF*NC*NL)/116640000 - 
       (112750859*CF*lm*NC*NL)/216000 - (23023*CF*lm^2*NC*NL)/80 + 
       (48648767176219619*CF*NC*NH)/803538792000 - (112750859*CF*lm*NC*NH)/
        216000 - (23023*CF*lm^2*NC*NH)/80 - (382802450353*CF^2*NC*Pi^2)/
        74844000 + (1519*CF^2*lm*NC*Pi^2)/120 - (300477281*CF*NM*NC*Pi^2)/
        194400 + (1519*CF*lm*NM*NC*Pi^2)/3240 - (56924321*CF*NC*NL*Pi^2)/
        194400 + (1519*CF*lm*NC*NL*Pi^2)/3240 + (1519*CF*lm*NC*NH*Pi^2)/
        3240 - (14961964181899*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) - 
       (5380203227287*CF*NC*NH*Pi^3)/(688747536*Sqrt[3]) - 
       (100009*CF^2*NC*Pi^4)/1620 + (580150195938661*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(57395628000*Sqrt[3]) + 
       (56537720338201*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (573956280*Sqrt[3]) - (201292*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        15 - (2137423454557*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) - (768600461041*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (2137423454557*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) - 
       (768600461041*CF*NC*NH*Pi*Log[3]^2)/(127545840*Sqrt[3]) - 
       (CF*NC*(-30*CA*(1159793538 + 166904815*lm) + 
          CF*(83063496247 + 24580527300*lm) + 15*(723413924*NM + 
            60692660*lm*NM + 78172507*NL + 60692660*lm*NL + 4887540*NH + 
            60692660*lm*NH))*Log[x]^2)/567000 + 
       (CF*NC*(17330035*CA - 273142357*CF + 14205500*NM + 4335190*NL)*
         Log[x]^3)/4050 - (4248095494150993*CF^2*NC*PolyGamma[2, 1])/
        723184912800 + (10075409*CF*NM*NC*PolyGamma[2, 1])/226800 - 
       (681420133489859*CF*NC*NH*PolyGamma[2, 1])/90398114100 + 
       (CA*CF*NC*(-112851474420611225259 + 35897154749382326400*lm^2 + 
          62547445910945858688*Pi^2 + 8211125943026171200*Sqrt[3]*Pi^3 + 
          708540621878960640*Pi^4 - 192492181728*lm*(-575598777 + 
            303800*Pi^2) - 38206371303736458816*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 152170571432523571200*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 304046263490340510720*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6334297156048760640*
           Sqrt[3]*Pi*Log[3]^2 + 66610137348287570240*PolyGamma[2, 1] - 
          186113632021631753600*Zeta[3]))/22679078865408000 + 
       (8311995815450297*CF^2*NC*Zeta[3])/361592456400 + 
       (691643009*CF*NM*NC*Zeta[3])/113400 - (336589*CF*NC*NL*Zeta[3])/
        135 - (1476687051639269*CF*NC*NH*Zeta[3])/45199057050 - 
       (CF*NC*Log[x]*(-5*CA*(417102278286540783 + 105975081590459760*lm + 
            18190511173296000*lm^2 + 19561279803644880*Pi^2 - 
            33514799767453760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            13229462671488000*Zeta[3]) + 
          2*(20*(78732*NM*(313700545741 + 23908357095*lm + 5250987000*lm^2 + 
                161971950*Pi^2) + 49*(19683*NL*(4688058049 + 1951702620*lm + 
                  428652000*lm^2 + 402995400*Pi^2) + 10*NH*
                 (108790344587397 + 3841536266946*lm + 843715731600*lm^2 - 
                  61488036883280*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
            CF*(1741550191029421971 + 780820692398031600*lm + 
              223247182581360000*lm^2 + 84671293625427600*Pi^2 - 
              167573998837268800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              66147313357440000*Zeta[3]))))/37498476960000, 
      (316291410506445914773*CF^2*NC)/15749360323200000 - 
       (17890431*CF^2*lm*NC)/500 - (281043*CF^2*lm^2*NC)/10 - 
       (2251586045501*CF*NM*NC)/104186250 - (2726938*CF*lm*NM*NC)/1125 - 
       (10409*CF*lm^2*NM*NC)/10 + (7545588649*CF*NC*NL)/2430000 - 
       (2726938*CF*lm*NC*NL)/1125 - (10409*CF*lm^2*NC*NL)/10 + 
       (1776220146247472357363*CF*NC*NH)/4367166372954000 - 
       (2726938*CF*lm*NC*NH)/1125 - (10409*CF*lm^2*NC*NH)/10 + 
       (4877440724393*CF^2*NC*Pi^2)/224532000 + (784*CF^2*lm*NC*Pi^2)/5 + 
       (201707237*CF*NM*NC*Pi^2)/4050 + (784*CF*lm*NM*NC*Pi^2)/135 - 
       (1583071*CF*NC*NL*Pi^2)/1350 + (784*CF*lm*NC*NL*Pi^2)/135 + 
       (784*CF*lm*NC*NH*Pi^2)/135 - (16271406301577*CF^2*NC*Pi^3)/
        (2295825120*Sqrt[3]) - (2581057946033*CF*NC*NH*Pi^3)/
        (43046721*Sqrt[3]) - (1595713*CF^2*NC*Pi^4)/5400 + 
       (2716197925163227*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (28697814000*Sqrt[3]) + (7664393188918*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) - 
       (647794*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (2324486614511*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (8857350*Sqrt[3]) - (5899561019504*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (2324486614511*CF^2*NC*Pi*Log[3]^2)/(425152800*Sqrt[3]) - 
       (368722563719*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-275*CA*(19175665 + 638476608*lm) + 
          8*(33*CF*(2602032563 + 3264937200*lm) + 
            20*(33*(-452894803 + 6046180*lm)*NM + 77*(3465319 + 2591220*lm)*
               NL + 30*(626909 + 6650798*lm)*NH)))*Log[x]^2)/4158000 - 
       (4*CF*NC*(28334865*CA + 102583166*CF - 107307900*NM - 2591220*NL)*
         Log[x]^3)/2025 - (647060741089379*CF^2*NC*PolyGamma[2, 1])/
        154968195600 + (5529143*CF*NM*NC*PolyGamma[2, 1])/135 - 
       (545606024901269*CF*NC*NH*PolyGamma[2, 1])/19371024450 + 
       (CA*CF*NC*(1338939860677212024000*lm^2 - 2382639341045843129670*Pi^2 + 
          276264071891325094500*Sqrt[3]*Pi^3 + 35642336005363071600*Pi^4 - 
          34648592711040*lm*(-139171479 + 215600*Pi^2) + 
          213117998316165072900*Sqrt[3]*Pi*Log[3]^2 - 
          11*(354934988915469451371 + 335396119799155269960*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 459105350454315936000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 929969447197811227200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 44388366838731399400*
             PolyGamma[2, 1] - 545984361022294670000*Zeta[3])))/
        233878000799520000 - (2087264611768967*CF^2*NC*Zeta[3])/77484097800 + 
       (3169606*CF*NM*NC*Zeta[3])/135 - (507392*CF*NC*NL*Zeta[3])/45 + 
       (677388051910651*CF*NC*NH*Zeta[3])/9685512225 + 
       CF*Log[x]*((390648468649*NM*NC)/1323000 - (6235852*lm*NM*NC)/675 - 
         1764*lm^2*NM*NC - (643429361*NC*NL)/27000 - (6235852*lm*NC*NL)/
          675 - 1764*lm^2*NC*NL - (822733737722295253*NC*NH)/
          1890548213400 - (6235852*lm*NC*NH)/675 - 1764*lm^2*NC*NH + 
         (2303012*NM*NC*Pi^2)/45 - (252128*NC*NL*Pi^2)/135 + 
         (5899561019504*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7971615*Sqrt[3]) + CF*NC*(-66602674175114963/1041624360000 - 
           (4979002*lm)/25 - 47628*lm^2 + (242298931*Pi^2)/16200 + 
           (2324486614511*Im[PolyLog[2, (-1)^(1/3)]])/(26572050*Sqrt[3]) - 
           14112*Zeta[3]) + CA*NC*(13103608486538261/208324872000 + 
           (42632086*lm)/675 + 9702*lm^2 - (63508327*Pi^2)/10800 - 
           (2324486614511*Im[PolyLog[2, (-1)^(1/3)]])/(53144100*Sqrt[3]) + 
           7056*Zeta[3])), (642974482348166892683*CF^2*NC)/8099671023360000 - 
       (61415759*CF^2*lm*NC)/3600 - (88389*CF^2*lm^2*NC)/4 - 
       (159335905432663*CF*NM*NC)/15431472000 - (145385309*CF*lm*NM*NC)/
        97200 - (9821*CF*lm^2*NM*NC)/12 + (3896301497*CF*NC*NL)/972000 - 
       (145385309*CF*lm*NC*NL)/97200 - (9821*CF*lm^2*NC*NL)/12 + 
       (39940960717842674931317*CF*NC*NH)/188661587311612800 - 
       (145385309*CF*lm*NC*NH)/97200 - (9821*CF*lm^2*NC*NH)/12 - 
       (44553031774693*CF^2*NC*Pi^2)/449064000 + (98*CF^2*lm*NC*Pi^2)/3 - 
       (69872551*CF*NM*NC*Pi^2)/2430 + (98*CF*lm*NM*NC*Pi^2)/81 - 
       (2332601*CF*NC*NL*Pi^2)/2430 + (98*CF*lm*NC*NL*Pi^2)/81 + 
       (98*CF*lm*NC*NH*Pi^2)/81 - (22615719792631*CF^2*NC*Pi^3)/
        (2754990144*Sqrt[3]) - (3663383042480*CF*NC*NH*Pi^3)/
        (129140163*Sqrt[3]) - (1506211*CF^2*NC*Pi^4)/6480 + 
       (3716714930178959*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (103312130400*Sqrt[3]) + (40191968915480*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(129140163*Sqrt[3]) - 
       42483*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (3230817113233*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10628820*Sqrt[3]) - (1674689390848*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (3230817113233*CF^2*NC*Pi*Log[3]^2)/(510183360*Sqrt[3]) - 
       (104668086928*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) - 
       (CF*NC*(-1155*CA*(46487804413 + 2328242400*lm) + 
          8*(924*CF*(15524280349 + 1785867750*lm) + 
            25*(77*(1706686159 + 31748760*lm)*NM + 1386*(2211779 + 
                1763820*lm)*NL + 5*(53064863 + 488930904*lm)*NH)))*
         Log[x]^2)/74844000 + (4*CF*NC*(67446990*CA - 275736064*CF + 
          25*(-642550*NM + 88191*NL))*Log[x]^3)/2025 - 
       (16408201821259741*CF^2*NC*PolyGamma[2, 1])/241061637600 - 
       (22343431*CF*NM*NC*PolyGamma[2, 1])/12600 - 
       (493009856176531*CF*NC*NH*PolyGamma[2, 1])/20088469800 + 
       (CA*CF*NC*(-153612694839949387629 + 13672118130071940000*lm^2 + 
          152771129415881775225*Pi^2 + 4155638511895946250*Sqrt[3]*Pi^3 + 
          355943746096155000*Pi^4 - 15624365400*lm*(-2712939799 + 
            1293600*Pi^2) - 18211903157876899100*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 64518435766013040000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 153877357469061324000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3205778280605444250*
           Sqrt[3]*Pi*Log[3]^2 + 103371671473936368300*PolyGamma[2, 1] - 
          139099494188551541400*Zeta[3]))/3037376633760000 + 
       (13760090138683487*CF^2*NC*Zeta[3])/120530818800 + 
       (284886569*CF*NM*NC*Zeta[3])/6300 - (256154*CF*NC*NL*Zeta[3])/27 - 
       (839096493948931*CF*NC*NH*Zeta[3])/10044234900 + 
       CF*Log[x]*((-2485029859559*NM*NC)/6123600 - (5567863*lm*NM*NC)/810 - 
         1470*lm^2*NM*NC - (1747532687*NC*NL)/97200 - (5567863*lm*NC*NL)/
          810 - 1470*lm^2*NC*NL - (469239323224350667*NC*NH)/
          2268657856080 - (5567863*lm*NC*NH)/810 - 1470*lm^2*NC*NH - 
         (915068*NM*NC*Pi^2)/81 - (14209*NC*NL*Pi^2)/9 + 
         (1674689390848*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CF*NC*(-918355793876340131/892820880000 - 
           (4311013*lm)/30 - 39690*lm^2 - (2505711041*Pi^2)/32400 + 
           (3230817113233*Im[PolyLog[2, (-1)^(1/3)]])/(31886460*Sqrt[3]) - 
           11760*Zeta[3]) + CA*NC*(97683426207327953/178564176000 + 
           (77916293*lm)/1620 + 8085*lm^2 + (518380927*Pi^2)/12960 - 
           (3230817113233*Im[PolyLog[2, (-1)^(1/3)]])/(63772920*Sqrt[3]) + 
           5880*Zeta[3])), (-3832357142913824500943*CF^2*NC)/
        141744242908800000 - (280292351*CF^2*lm*NC)/3000 - 
       (731997*CF^2*lm^2*NC)/10 - (22880245029847273*CF*NM*NC)/30005640000 - 
       (512091401*CF*lm*NM*NC)/81000 - (27111*CF*lm^2*NM*NC)/10 + 
       (734212828*CF*NC*NL)/50625 - (512091401*CF*lm*NC*NL)/81000 - 
       (27111*CF*lm^2*NC*NL)/10 + (39114856831012204316758751*CF*NC*NH)/
        29606393380258094400 - (512091401*CF*lm*NC*NH)/81000 - 
       (27111*CF*lm^2*NC*NH)/10 + (132093853667389*CF^2*NC*Pi^2)/486486000 + 
       (1764*CF^2*lm*NC*Pi^2)/5 + (2827722547*CF*NM*NC*Pi^2)/4050 + 
       (196*CF*lm*NM*NC*Pi^2)/15 - (1572037*CF*NC*NL*Pi^2)/450 + 
       (196*CF*lm*NC*NL*Pi^2)/15 + (196*CF*lm*NC*NH*Pi^2)/15 - 
       (169849519748167*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) - 
       (2795484489581*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) - 
       (1680539*CF^2*NC*Pi^4)/1800 + (73907802913555441*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(258280326000*Sqrt[3]) + 
       (129501079517710*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (129140163*Sqrt[3]) - (628614*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (24264217106881*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) - (6389678833328*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(885735*Sqrt[3]) - 
       (24264217106881*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) - 
       (399354927083*CF*NC*NH*Pi*Log[3]^2)/(2657205*Sqrt[3]) - 
       (CF*NC*(-143*CA*(-1327102821431 + 170859981600*lm) + 
          4*(143*CF*(-497682685417 + 209691795600*lm) + 
            30*(143*(-78373248661 + 258878760*lm)*NM + 7*(6971777098*NL + 
                5288523240*lm*NL + 626503715*NH + 5288523240*lm*NH))))*
         Log[x]^2)/162162000 - (CF*NC*(653013639*CA + 425065922*CF - 
          80*(41490690*NM + 308189*NL))*Log[x]^3)/1350 + 
       (35527098696395947*CF^2*NC*PolyGamma[2, 1])/464904586800 + 
       (1437827003*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (410203075455589*CF*NC*NH*PolyGamma[2, 1])/4649045868 - 
       (43077407276897057*CF^2*NC*Zeta[3])/232452293400 + 
       (20564603*CF*NM*NC*Zeta[3])/1350 - (1716092*CF*NC*NL*Zeta[3])/45 + 
       (2939090694326359*CF*NC*NH*Zeta[3])/11622614670 + 
       (CA*CF*NC*(-56978266441101813594 + 95109997195136800800*lm^2 - 
          852174033059630288637*Pi^2 + 26216273373129576450*Sqrt[3]*Pi^3 + 
          3044260594785697560*Pi^4 - 39373400808*lm*(-8707392811 + 
            11642400*Pi^2) - 304204516792194195156*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 400960869803425814400*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 970751151187883745120*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 20223982316414244690*
           Sqrt[3]*Pi*Log[3]^2 - 243715897057276196420*PolyGamma[2, 1] + 
          836391330088528001480*Zeta[3]))/6378490930896000 + 
       CF*Log[x]*((14643605640259*NM*NC)/2976750 - (2119358*lm*NM*NC)/75 - 
         5292*lm^2*NM*NC - (1061066783*NC*NL)/13500 - (2119358*lm*NC*NL)/
          75 - 5292*lm^2*NC*NL - (107647262778546758*NC*NH)/76072059063 - 
         (2119358*lm*NC*NH)/75 - 5292*lm^2*NC*NH + (9143564*NM*NC*Pi^2)/
          15 - (854518*NC*NL*Pi^2)/135 + (6389678833328*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) + 
         CF*NC*(1079468824636197517/624974616000 - (15303672*lm)/25 - 
           142884*lm^2 + (116072297*Pi^2)/600 + 
           (24264217106881*Im[PolyLog[2, (-1)^(1/3)]])/(79716150*Sqrt[3]) - 
           42336*Zeta[3]) + CA*NC*(-7466485828108043/9765228375 + 
           (14434769*lm)/75 + 29106*lm^2 - (987292891*Pi^2)/10800 - 
           (24264217106881*Im[PolyLog[2, (-1)^(1/3)]])/(159432300*Sqrt[3]) + 
           21168*Zeta[3])), (1637153210582346378910227913*CF^2*NC)/
        1131969523869676800000 - (37595254931*CF^2*lm*NC)/882000 - 
       (1091961*CF^2*lm^2*NC)/20 + (12751463535004396969*CF*NM*NC)/
        718875123120000 - (88426039481*CF*lm*NM*NC)/23814000 - 
       (40443*CF*lm^2*NM*NC)/20 + (74825602896293*CF*NC*NL)/5000940000 - 
       (88426039481*CF*lm*NC*NL)/23814000 - (40443*CF*lm^2*NC*NL)/20 + 
       (358699712483411434017066493*CF*NC*NH)/565212964532199984000 - 
       (88426039481*CF*lm*NC*NH)/23814000 - (40443*CF*lm^2*NC*NH)/20 - 
       (4840304722169359*CF^2*NC*Pi^2)/3143448000 + (366*CF^2*lm*NC*Pi^2)/5 - 
       (3369602698*CF*NM*NC*Pi^2)/6075 + (122*CF*lm*NM*NC*Pi^2)/45 - 
       (12693824*CF*NC*NL*Pi^2)/4725 + (122*CF*lm*NC*NL*Pi^2)/45 + 
       (122*CF*lm*NC*NH*Pi^2)/45 - (638592391263959*CF^2*NC*Pi^3)/
        (24794911296*Sqrt[3]) - (33747171466918*CF*NC*NH*Pi^3)/
        (387420489*Sqrt[3]) - (7699813*CF^2*NC*Pi^4)/10800 + 
       (1642410589171914997*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (15186883168800*Sqrt[3]) + (2349462551497318*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2711943423*Sqrt[3]) - 
       115699*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (638592391263959*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (669615660*Sqrt[3]) - (77136391924384*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23914845*Sqrt[3]) - 
       (638592391263959*CF^2*NC*Pi*Log[3]^2)/(32141551680*Sqrt[3]) - 
       (4821024495274*CF*NC*NH*Pi*Log[3]^2)/(71744535*Sqrt[3]) - 
       (CF*NC*(-13*CA*(5050879597358813 + 62950227832800*lm) + 
          8*(13*CF*(1284579561486281 + 38628548897400*lm) + 
            35*(91*(1786477540949 + 5839538760*lm)*NM + 
              11*(234*(254175573 + 206448340*lm)*NL + 5*(1298781121 + 
                  9661782312*lm)*NH))))*Log[x]^2)/6810804000 + 
       (CF*NC*(63781728331*CA - 157606536922*CF - 37162431600*NM + 
          412896680*NL)*Log[x]^3)/28350 - (17484291148835908309*CF^2*NC*
         PolyGamma[2, 1])/19525992645600 - 
       (2147694487*CF*NM*NC*PolyGamma[2, 1])/16200 - 
       (340422732775742231*CF*NC*NH*PolyGamma[2, 1])/4881498161400 + 
       CA*CF*NC*((444873*lm^2)/40 + (647044530861649*Pi^2)/838252800 + 
         (638592391263959*Pi^3)/(49589822592*Sqrt[3]) + 
         (7746661*Pi^4)/21600 + lm*(1646863155691/47628000 - (671*Pi^2)/45) + 
         (638592391263959*Pi*Log[3]^2)/(64283103360*Sqrt[3]) + 
         (-67237805765963617620621012 - 1606745643228046862840145*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 5156854838974035858276000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 14168771107820177115544200*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           39910779455257518640163485*PolyGamma[2, 1] - 
           34294582029372374748306730*Zeta[3])/89142600004737048000) + 
       (8163819881884054679*CF^2*NC*Zeta[3])/9762996322800 + 
       (4070997113*CF*NM*NC*Zeta[3])/8100 - (4076314*CF*NC*NL*Zeta[3])/
        135 - (460805033500816871*CF*NC*NH*Zeta[3])/2440749080700 + 
       CF*Log[x]*((-163548653216436683*NM*NC)/25933446000 - 
         (62519699*lm*NM*NC)/3150 - 4158*lm^2*NM*NC - (446745693211*NC*NL)/
          7938000 - (62519699*lm*NC*NL)/3150 - 4158*lm^2*NC*NL - 
         (332440428697063171553*NC*NH)/522822515014800 - 
         (62519699*lm*NC*NH)/3150 - 4158*lm^2*NC*NH - 
         (45663436*NM*NC*Pi^2)/135 - (2035961*NC*NL*Pi^2)/405 + 
         (77136391924384*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (71744535*Sqrt[3]) + CF*NC*(-131106608802560791833899/
            9528362995536000 - (146083047*lm)/350 - 112266*lm^2 - 
           (12562203427*Pi^2)/10800 + (638592391263959*
             Im[PolyLog[2, (-1)^(1/3)]])/(2008846980*Sqrt[3]) - 
           33264*Zeta[3]) + CA*NC*(1356939677125502282479/194456387664000 + 
           (871084489*lm)/6300 + 22869*lm^2 + (29524634029*Pi^2)/50400 - 
           (638592391263959*Im[PolyLog[2, (-1)^(1/3)]])/(4017693960*
             Sqrt[3]) + 16632*Zeta[3])), 
      (-19875492709165258246355423473*CF^2*NC)/7131408000378963840000 - 
       (637102477*CF^2*lm*NC)/2940 - (339039*CF^2*lm^2*NC)/2 - 
       (4879524207163514407*CF*NM*NC)/399375068400 - 
       (290794498*CF*lm*NM*NC)/19845 - (12557*CF*lm^2*NM*NC)/2 + 
       (81978583987*CF*NC*NL)/1587600 - (290794498*CF*lm*NC*NL)/19845 - 
       (12557*CF*lm^2*NC*NL)/2 + (936031015624406415602918723*CF*NC*NH)/
        249803944145927671500 - (290794498*CF*lm*NC*NH)/19845 - 
       (12557*CF*lm^2*NC*NH)/2 + (80561491251011753*CF^2*NC*Pi^2)/
        20432412000 + 720*CF^2*lm*NC*Pi^2 + (52626362963*CF*NM*NC*Pi^2)/
        5670 + (80*CF*lm*NM*NC*Pi^2)/3 - (1147453*CF*NC*NL*Pi^2)/126 + 
       (80*CF*lm*NC*NL*Pi^2)/3 + (80*CF*lm*NC*NH*Pi^2)/3 - 
       (40705809795314467*CF^2*NC*Pi^3)/(557885504160*Sqrt[3]) - 
       (1923902656435025*CF*NC*NH*Pi^3)/(3486784401*Sqrt[3]) - 
       (13727161*CF^2*NC*Pi^4)/5400 + (261513978223420261613*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(341704871298000*Sqrt[3]) + 
       (48288784249382734*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (17433922005*Sqrt[3]) - (1608694*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (40705809795314467*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(15066352350*Sqrt[3]) - 
       (879498357227440*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) - (40705809795314467*CF^2*NC*Pi*Log[3]^2)/
        (723184912800*Sqrt[3]) - (54968647326715*CF*NC*NH*Pi*Log[3]^2)/
        (129140163*Sqrt[3]) - 
       (CF*NC*(CA*(75890202087369631 - 1559993467032000*lm) + 
          32*(52*CF*(-87550234337452 + 4602253453875*lm) + 
            1575*(78*(-96254553289 + 72149770*lm)*NM + 
              7*(143*(7337197 + 5622060*lm)*NL + 3*(37735431 + 267984860*lm)*
                 NH))))*Log[x]^2)/3405402000 + 
       (CF*NC*(-86041458599*CA + 48*(2289165702*CF + 
            175*(50702757*NM + 93701*NL)))*Log[x]^3)/14175 + 
       (21500265194899760869*CF^2*NC*PolyGamma[2, 1])/12552423843600 + 
       (8839797457*CF*NM*NC*PolyGamma[2, 1])/1350 - 
       (190313159549917867*CF*NC*NH*PolyGamma[2, 1])/784526490225 - 
       (95686519999872953993*CF^2*NC*Zeta[3])/43933483452600 - 
       (917968343*CF*NM*NC*Zeta[3])/675 - (1001968*CF*NC*NL*Zeta[3])/9 + 
       (596893687720514266*CF*NC*NH*Zeta[3])/784526490225 + 
       CF*Log[x]*((4018121437567913*NM*NC)/57629880 - (7892362*lm*NM*NC)/
          105 - 13860*lm^2*NM*NC - (1698323549*NC*NL)/7560 - 
         (7892362*lm*NC*NL)/105 - 13860*lm^2*NC*NL - 
         (14824769774524449818011*NC*NH)/3697102070461800 - 
         (7892362*lm*NC*NH)/105 - 13860*lm^2*NC*NH + 7499508*NM*NC*Pi^2 - 
         (499544*NC*NL*Pi^2)/27 + (879498357227440*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(129140163*Sqrt[3]) + 
         CF*NC*(7151465916001458842177393/214388167399560000 - 
           (57205908*lm)/35 - 374220*lm^2 + (21799909267*Pi^2)/7560 + 
           (40705809795314467*Im[PolyLog[2, (-1)^(1/3)]])/
            (45199057050*Sqrt[3]) - 110880*Zeta[3]) + 
         CA*NC*(-28133957657461635586517/1715105339196480 + 
           (53595091*lm)/105 + 76230*lm^2 - (323529785723*Pi^2)/226800 - 
           (40705809795314467*Im[PolyLog[2, (-1)^(1/3)]])/
            (90398114100*Sqrt[3]) + 55440*Zeta[3])) + 
       CA*CF*NC*((138127*lm^2)/4 - (17848870077662929*Pi^2)/9081072000 + 
         (40705809795314467*Pi^3)/(1115771008320*Sqrt[3]) + 
         (13957561*Pi^4)/10800 + lm*(4943095133/39690 - (440*Pi^2)/3) + 
         (40705809795314467*Pi*Log[3]^2)/(1446369825600*Sqrt[3]) + 
         (21293819932551319224470069073 - 2046681617490389525056589640*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 2581256983896368292515616000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 7225282476124935670059796800*
            Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
           13741812798312441540330047800*PolyGamma[2, 1] + 
           19184893764808585492130729200*Zeta[3])/16045668000852668640000), 
      (3026559610092068187571112200624483*CF^2*NC)/
        125341627014660668451840000 - (53850295979*CF^2*lm*NC)/564480 - 
       (1940679*CF^2*lm^2*NC)/16 + (23578186507593947196411401*CF*NM*NC)/
        5053979665582848000 - (126121181939*CF*lm*NM*NC)/15240960 - 
       (71877*CF*lm^2*NM*NC)/16 + (299041719103447*CF*NC*NL)/6401203200 - 
       (126121181939*CF*lm*NC*NL)/15240960 - (71877*CF*lm^2*NC*NL)/16 + 
       (503646101826843078817091098327*CF*NC*NH)/298432445273001591552000 - 
       (126121181939*CF*lm*NC*NH)/15240960 - (71877*CF*lm^2*NC*NH)/16 - 
       (291284043689087507*CF^2*NC*Pi^2)/13076743680 + 
       (1185*CF^2*lm*NC*Pi^2)/8 - (2599541627989*CF*NM*NC*Pi^2)/272160 + 
       (395*CF*lm*NM*NC*Pi^2)/72 - (1260281*CF*NC*NL*Pi^2)/189 + 
       (395*CF*lm*NC*NL*Pi^2)/72 + (395*CF*lm*NC*NH*Pi^2)/72 - 
       (31386428814233129*CF^2*NC*Pi^3)/(446308403328*Sqrt[3]) - 
       (2189459521141585*CF*NC*NH*Pi^3)/(9298091736*Sqrt[3]) - 
       (8162047*CF^2*NC*Pi^4)/4320 + (22446053332090916639*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(78103970582400*Sqrt[3]) + 
       (709079457887570267*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (325433210760*Sqrt[3]) - (561869*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 - (4483775544890447*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1721868840*Sqrt[3]) - 
       (125111972636662*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) - (4483775544890447*CF^2*NC*Pi*Log[3]^2)/
        (82649704320*Sqrt[3]) - (62555986318331*CF*NC*NH*Pi*Log[3]^2)/
        (344373768*Sqrt[3]) - 
       (CF*NC*(-(CA*(734457350801565689 + 1890537626577600*lm)) + 
          2*CF*(737111738802421709 + 4640410537963200*lm) + 
          280*((2232169204077991 + 1227621835440*lm)*NM + 
            5148*(289736031 + 238465780*lm)*NL + 
            (194133654653 + 1227621835440*lm)*NH))*Log[x]^2)/5448643200 + 
       (CF*NC*(757640742065*CA - 1593165373652*CF - 596215124400*NM + 
          953863120*NL)*Log[x]^3)/22680 - (2160347097386360731627*CF^2*NC*
         PolyGamma[2, 1])/175733933810400 - 
       (47343680798*CF*NM*NC*PolyGamma[2, 1])/14175 - 
       (5208563457509373271*CF*NC*NH*PolyGamma[2, 1])/29288988968400 + 
       CA*CF*NC*(-12435746922799867790065972097261/
          1023196955221719742464000 + (790647*lm^2)/32 + 
         (485693587998243341*Pi^2)/43589145600 + (31386428814233129*Pi^3)/
          (892616806656*Sqrt[3]) + (8199967*Pi^4)/8640 + 
         lm*(2345873173009/30481920 - (4345*Pi^2)/144) - 
         (22446053332090916639*Im[PolyLog[2, (-1)^(1/3)]])/
          (156207941164800*Sqrt[3]) + (561869*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 + (4483775544890447*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3443737680*Sqrt[3]) + (4483775544890447*Pi*Log[3]^2)/
          (165299408640*Sqrt[3]) + (2160347097386360731627*PolyGamma[2, 1])/
          351467867620800 - (213177233994069390797*Zeta[3])/43933483452600) + 
       (434082528520513773709*CF^2*NC*Zeta[3])/43933483452600 + 
       (192546002533*CF*NM*NC*Zeta[3])/28350 - (4532869*CF*NC*NL*Zeta[3])/
        54 - (5652276995886149071*CF*NC*NH*Zeta[3])/14644494484200 + 
       CF*Log[x]*((-665003662599333986987*NM*NC)/7012403798400 - 
         (254206103*lm*NM*NC)/5040 - 10395*lm^2*NM*NC - 
         (196044518653*NC*NL)/1270080 - (254206103*lm*NC*NL)/5040 - 
         10395*lm^2*NC*NL - (237437990985289474471093*NC*NH)/
          138025143963907200 - (254206103*lm*NC*NH)/5040 - 
         10395*lm^2*NC*NH - (178219361*NM*NC*Pi^2)/27 - 
         (2264657*NC*NL*Pi^2)/162 + (125111972636662*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(-136936702903013627495725817/724632005810512800 - 
           (596714109*lm)/560 - 280665*lm^2 - (33905805427*Pi^2)/2016 + 
           (4483775544890447*Im[PolyLog[2, (-1)^(1/3)]])/(5165606520*
             Sqrt[3]) - 83160*Zeta[3]) + CA*NC*(10984991143616295980997753487/
            115941120929682048000 + (3529738333*lm)/10080 + (114345*lm^2)/2 + 
           (509295361621*Pi^2)/60480 - (4483775544890447*
             Im[PolyLog[2, (-1)^(1/3)]])/(10331213040*Sqrt[3]) + 
           41580*Zeta[3])), (-5412213921293020647374675743247951*CF^2*NC)/
        94006220260995501338880000 - (43130433917*CF^2*lm*NC)/94080 - 
       (2866347*CF^2*lm^2*NC)/8 - (48150751713092260747582783*CF*NM*NC)/
        280776648087936000 - (78711354677*CF*lm*NM*NC)/2540160 - 
       (106161*CF*lm^2*NM*NC)/8 + (10957303144717*CF*NC*NL)/71124480 - 
       (78711354677*CF*lm*NC*NL)/2540160 - (106161*CF*lm^2*NC*NL)/8 + 
       (62973742098750302956219758836615383*CF*NC*NH)/
        6597893716318155686827392000 - (78711354677*CF*lm*NC*NH)/2540160 - 
       (106161*CF*lm^2*NC*NH)/8 + (11562034264539919*CF^2*NC*Pi^2)/
        202176000 + (5445*CF^2*lm*NC*Pi^2)/4 + (5504381006671*CF*NM*NC*Pi^2)/
        45360 + (605*CF*lm*NM*NC*Pi^2)/12 - (10783597*CF*NC*NL*Pi^2)/504 + 
       (605*CF*lm*NC*NL*Pi^2)/12 + (605*CF*lm*NC*NH*Pi^2)/12 - 
       (1277072074503528319*CF^2*NC*Pi^3)/(6694626049920*Sqrt[3]) - 
       (58691583656372555*CF*NC*NH*Pi^3)/(41841412812*Sqrt[3]) - 
       (44466653*CF^2*NC*Pi^4)/7200 + (15235665120613376341927*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8200916911152000*Sqrt[3]) + 
       (10142535375419879221*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1464449448420*Sqrt[3]) - (7445493*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/10 - (1277072074503528319*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(180796228200*Sqrt[3]) - 
       (6707609560728292*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) - (1277072074503528319*CF^2*NC*Pi*Log[3]^2)/
        (8678218953600*Sqrt[3]) - (1676902390182073*CF*NC*NH*Pi*Log[3]^2)/
        (1549681956*Sqrt[3]) - 
       (CF*NC*(CA*(52409979931698764437 - 189962833460400000*lm) + 
          34*CF*(-3060986910949866869 + 27427788788400000*lm) + 
          8400*(17*(-1573495902307837 + 241867626000*lm)*NM + 
            26206180*(203263 + 156900*lm)*NL + (663253074881 + 
              4111749642000*lm)*NH))*Log[x]^2)/154378224000 + 
       (CF*NC*(-814204930956*CA + 1504531251749*CF + 
          1400*(2580257481*NM + 1006775*NL))*Log[x]^3)/9450 + 
       (153192097208181704051*CF^2*NC*PolyGamma[2, 1])/5578855041600 + 
       (54072870074*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (3774880764616288741*CF*NC*NH*PolyGamma[2, 1])/6276211921800 - 
       (584705781784049519569*CF^2*NC*Zeta[3])/19525992645600 - 
       (19810616627*CF*NM*NC*Zeta[3])/675 - (2607055*CF*NC*NL*Zeta[3])/9 + 
       (6295809637077477059*CF*NC*NH*Zeta[3])/3138105960900 + 
       CA*CF*NC*(336192319069534327362180290771327/
          11750777532624437667360000 + (1167771*lm^2)/16 - 
         (566255314980822911*Pi^2)/19813248000 + (1277072074503528319*Pi^3)/
          (13389252099840*Sqrt[3]) + (45047453*Pi^4)/14400 + 
         lm*(1337740271527/5080320 - (6655*Pi^2)/24) - 
         (15235665120613376341927*Im[PolyLog[2, (-1)^(1/3)]])/
          (16401833822304000*Sqrt[3]) + (7445493*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/20 + (1277072074503528319*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(361592456400*Sqrt[3]) + 
         (1277072074503528319*Pi*Log[3]^2)/(17356437907200*Sqrt[3]) - 
         (153192097208181704051*PolyGamma[2, 1])/11157710083200 + 
         (595132552942052687977*Zeta[3])/39051985291200) + 
       CF*Log[x]*((51510687650177755243*NM*NC)/55653998400 - 
         (30144301*lm*NM*NC)/168 - 32670*lm^2*NM*NC - (24307328153*NC*NL)/
          42336 - (30144301*lm*NC*NL)/168 - 32670*lm^2*NC*NL - 
         (1830470592625779143077893053*NC*NH)/179501699725061313600 - 
         (30144301*lm*NC*NH)/168 - 32670*lm^2*NC*NH + 
         95540920*NM*NC*Pi^2 - (1300805*NC*NL*Pi^2)/27 + 
         (6707609560728292*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(423628131277146198492861982333/
            869558406972615360000 - (219157389*lm)/56 - 882090*lm^2 + 
           (61436904997*Pi^2)/1440 + (1277072074503528319*
             Im[PolyLog[2, (-1)^(1/3)]])/(542388684600*Sqrt[3]) - 
           261360*Zeta[3]) + CA*NC*(-84487312130977131019654329887/
            347823362789046144000 + (408427151*lm)/336 + 179685*lm^2 - 
           (6438968611309*Pi^2)/302400 - (1277072074503528319*
             Im[PolyLog[2, (-1)^(1/3)]])/(1084777369200*Sqrt[3]) + 
           130680*Zeta[3])), (549646980029301651939402284354010691*CF^2*NC)/
        1450381684026787734942720000 - (995583268031*CF^2*lm*NC)/5080320 - 
       (3966039*CF^2*lm^2*NC)/16 + (624176272193786505129732181*CF*NM*NC)/
        5053979665582848000 - (2324840899271*CF*lm*NM*NC)/137168640 - 
       (440671*CF*lm^2*NM*NC)/48 + (12250219403946721*CF*NC*NL)/
        96018048000 - (2324840899271*CF*lm*NC*NL)/137168640 - 
       (440671*CF*lm^2*NC*NL)/48 + (1452689174051506128297684427048297817*CF*
         NC*NH)/356286260681180407088679168000 - 
       (2324840899271*CF*lm*NC*NH)/137168640 - (440671*CF*lm^2*NC*NH)/48 - 
       (15205096866713804009*CF^2*NC*Pi^2)/49037788800 + 
       (6655*CF^2*lm*NC*Pi^2)/24 - (122116282582327*CF*NM*NC*Pi^2)/816480 + 
       (6655*CF*lm*NM*NC*Pi^2)/648 - (614748013*CF*NC*NL*Pi^2)/40824 + 
       (6655*CF*lm*NC*NL*Pi^2)/648 + (6655*CF*lm*NC*NH*Pi^2)/648 - 
       (3115459182420241987*CF^2*NC*Pi^3)/(18075490334784*Sqrt[3]) - 
       (1300667453407112875*CF*NC*NH*Pi^3)/(2259436291848*Sqrt[3]) - 
       (29045753*CF^2*NC*Pi^4)/6480 + (15363704407513853433103*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22142475660110400*Sqrt[3]) + 
       (398800930618221276473*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (79080270214680*Sqrt[3]) - (1869131*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (3115459182420241987*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(488149816140*Sqrt[3]) - 
       (74323854480406450*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (3115459182420241987*CF^2*NC*Pi*Log[3]^2)/
        (23431191174720*Sqrt[3]) - (37161927240203225*CF*NC*NH*Pi*Log[3]^2)/
        (83682825624*Sqrt[3]) - 
       (CF*NC*(-51*CA*(5076334231447289849 + 2434895172309600*lm) + 
          34*CF*(15239348221785572141 + 17929682632461600*lm) + 
          420*(51*(11643372866267249 + 1054067174160*lm)*NM + 
            962676*(67176909 + 55841660*lm)*NL + 
            (9665382324617 + 53757425882160*lm)*NH))*Log[x]^2)/
        138940401600 + (CF*NC*(32093245633789*CA - 
          840*(77207042749*CF + 35180105898*NM - 8775118*NL))*Log[x]^3)/
        68040 - (4796907730099338333041039*CF^2*NC*PolyGamma[2, 1])/
        28468897277284800 - (195654175391*CF*NM*NC*PolyGamma[2, 1])/3150 - 
       (2955531508923242383387*CF*NC*NH*PolyGamma[2, 1])/7117224319321200 + 
       CA*CF*NC*(-110040727396603106045322383187402017/
          580152673610715093977088000 + (4847381*lm^2)/96 + 
         (1382384778395787253*Pi^2)/8915961600 + (3115459182420241987*Pi^3)/
          (36150980669568*Sqrt[3]) + (3239137*Pi^4)/1440 + 
         lm*(43203403737901/274337280 - (73205*Pi^2)/1296) - 
         (15363704407513853433103*Im[PolyLog[2, (-1)^(1/3)]])/
          (44284951320220800*Sqrt[3]) + (1869131*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/6 + (3115459182420241987*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(976299632280*Sqrt[3]) + 
         (3115459182420241987*Pi*Log[3]^2)/(46862382349440*Sqrt[3]) + 
         (4796907730099338333041039*PolyGamma[2, 1])/56937794554569600 - 
         (1949375938662840236730001*Zeta[3])/28468897277284800) + 
       (1955385744502763234571901*CF^2*NC*Zeta[3])/14234448638642400 + 
       (295417075843*CF*NM*NC*Zeta[3])/3150 - (11330033*CF*NC*NL*Zeta[3])/
        54 - (2580614364177034396387*CF*NC*NH*Zeta[3])/3558612159660600 + 
       CF*Log[x]*((-353788344073895113597*NM*NC)/259718659200 - 
         (15788388209*lm*NM*NC)/136080 - 23595*lm^2*NM*NC - 
         (7268789407267*NC*NL)/19051200 - (15788388209*lm*NC*NL)/136080 - 
         23595*lm^2*NC*NL - (40785543070786855004054694811*NC*NH)/
          9693091785153310934400 - (15788388209*lm*NC*NH)/136080 - 
         23595*lm^2*NC*NH - (325951751*NM*NC*Pi^2)/3 - 
         (5661689*NC*NL*Pi^2)/162 + (74323854480406450*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-11926512809415673661023774651879/4695615397652122944000 - 
           (12399202409*lm)/5040 - 637065*lm^2 - (3213504887977*Pi^2)/13608 + 
           (3115459182420241987*Im[PolyLog[2, (-1)^(1/3)]])/
            (1464449448420*Sqrt[3]) - 188760*Zeta[3]) + 
         CA*NC*(5966157388805867150294903272709/4695615397652122944000 + 
           (218623576699*lm)/272160 + (259545*lm^2)/2 + (3214299867055*Pi^2)/
            27216 - (3115459182420241987*Im[PolyLog[2, (-1)^(1/3)]])/
            (2928898896840*Sqrt[3]) + 94380*Zeta[3])), 
      (-99424903163946279602038529494548091*CF^2*NC)/
        103598691716199123924480000 - (11921053999*CF^2*lm*NC)/13230 - 
       (2815263*CF^2*lm^2*NC)/4 - (14869397729859504000807191*CF*NM*NC)/
        6381287456544000 - (86999363791*CF*lm*NM*NC)/1428840 - 
       (104269*CF*lm^2*NM*NC)/4 + (9702545926308733*CF*NC*NL)/24004512000 - 
       (86999363791*CF*lm*NC*NL)/1428840 - (104269*CF*lm^2*NC*NL)/4 + 
       (618722769269977064834814744812306454341*CF*NC*NH)/
        27770084795593368320696027424000 - (86999363791*CF*lm*NC*NH)/
        1428840 - (104269*CF*lm^2*NC*NH)/4 + 
       (131075320660378910869*CF^2*NC*Pi^2)/163459296000 + 
       2420*CF^2*lm*NC*Pi^2 + (26667347669453*CF*NM*NC*Pi^2)/17010 + 
       (2420*CF*lm*NM*NC*Pi^2)/27 - (314676527*CF*NC*NL*Pi^2)/6804 + 
       (2420*CF*lm*NC*NL*Pi^2)/27 + (2420*CF*lm*NC*NH*Pi^2)/27 - 
       (40875353310611443229*CF^2*NC*Pi^3)/(90377451673920*Sqrt[3]) - 
       (3691690035116949635*CF*NC*NH*Pi^3)/(1129718145924*Sqrt[3]) - 
       (148058647*CF^2*NC*Pi^4)/10800 + (461414878511921874768227*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(110712378300552000*Sqrt[3]) + 
       (157799626084926622444*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) - (23837407*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (40875353310611443229*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2440749080700*Sqrt[3]) - 
       (421907432584794244*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (40875353310611443229*CF^2*NC*Pi*Log[3]^2)/
        (117155955873600*Sqrt[3]) - (105476858146198561*CF*NC*NH*Pi*
         Log[3]^2)/(41841412812*Sqrt[3]) - 
       (CF*NC*(-323*CA*(-21806114675377449343 + 13595816746512000*lm) + 
          2*(323*CF*(-21779282624829941137 + 33371550195984000*lm) + 
            61600*(323*(-693289276415059 + 20064664620*lm)*NM + 
              1939938*(4303913 + 3340770*lm)*NL + (1167003118009 + 
                6480886672260*lm)*NH)))*Log[x]^2)/1466593128000 + 
       (CF*NC*(-51791581640242*CA + 102089422008353*CF + 
          138600*(1508830008*NM + 111359*NL))*Log[x]^3)/42525 + 
       (816670795625271114730373*CF^2*NC*PolyGamma[2, 1])/2033492662663200 + 
       (664952508499*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (348529024444735841527*CF*NC*NH*PolyGamma[2, 1])/254186582832900 - 
       (2928480274965021833280991*CF^2*NC*Zeta[3])/7117224319321200 - 
       (327184948852*CF*NM*NC*Zeta[3])/675 - (2061202*CF*NC*NL*Zeta[3])/3 + 
       (607734362647206219473*CF*NC*NH*Zeta[3])/127093291416450 + 
       CA*CF*NC*(608435880331161663728147269493801831/
          1269083973523439268074880000 + (1146959*lm^2)/8 - 
         (567380673574488719*Pi^2)/1415232000 + (40875353310611443229*Pi^3)/
          (180754903347840*Sqrt[3]) + (49869149*Pi^4)/7200 + 
         lm*(1478436014561/2857680 - (13310*Pi^2)/27) - 
         (461414878511921874768227*Im[PolyLog[2, (-1)^(1/3)]])/
          (221424756601104000*Sqrt[3]) + (23837407*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/30 + (40875353310611443229*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4881498161400*Sqrt[3]) + 
         (40875353310611443229*Pi*Log[3]^2)/(234311911747200*Sqrt[3]) - 
         (816670795625271114730373*PolyGamma[2, 1])/4066985325326400 + 
         (2937232870764475258727347*Zeta[3])/14234448638642400) + 
       CF*Log[x]*((630894869414901290777*NM*NC)/53124271200 - 
         (1113792746*lm*NM*NC)/2835 - 70785*lm^2*NM*NC - 
         (12776132112917*NC*NL)/9525600 - (1113792746*lm*NC*NL)/2835 - 
         70785*lm^2*NC*NL - (75589025879690017655929724705*NC*NH)/
          3181096485854859315744 - (1113792746*lm*NC*NH)/2835 - 
         70785*lm^2*NC*NH + 1229375301*NM*NC*Pi^2 - (3086963*NC*NL*Pi^2)/
          27 + (421907432584794244*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (10460353203*Sqrt[3]) + CF*NC*(77598075162779948282546558337203/
            11739038494130307360000 - (1803937267*lm)/210 - 1911195*lm^2 + 
           (16545385495693*Pi^2)/27216 + (40875353310611443229*
             Im[PolyLog[2, (-1)^(1/3)]])/(7322247242100*Sqrt[3]) - 
           566280*Zeta[3]) + CA*NC*(-15512276920219253938752238003459/
            4695615397652122944000 + (7530588428*lm)/2835 + (778635*lm^2)/2 - 
           (413508629970733*Pi^2)/1360800 - (40875353310611443229*
             Im[PolyLog[2, (-1)^(1/3)]])/(14644494484200*Sqrt[3]) + 
           283140*Zeta[3])), (468915814020723581068538275999079928078727*CF^2*
         NC)/83133460825608761654025139200000 - (477285036349*CF^2*lm*NC)/
        1270080 - (18942363*CF^2*lm^2*NC)/40 + 
       (16155334034232359285166747297677*CF*NM*NC)/6897278360280147840000 - 
       (1112157274657*CF*lm*NM*NC)/34292160 - (701569*CF*lm^2*NM*NC)/40 + 
       (2789982852177869*CF*NC*NL)/8890560000 - (1112157274657*CF*lm*NC*NL)/
        34292160 - (701569*CF*lm^2*NC*NL)/40 + 
       (162190776025227217784572485040032631603*CF*NC*NH)/
        17811716195424317873332728960000 - (1112157274657*CF*lm*NC*NH)/
        34292160 - (701569*CF*lm^2*NC*NH)/40 - 
       (586375371489022509643*CF^2*NC*Pi^2)/140107968000 + 
       (14641*CF^2*lm*NC*Pi^2)/30 - (79761307419067*CF*NM*NC*Pi^2)/36450 + 
       (14641*CF*lm*NM*NC*Pi^2)/810 - (4019129719*CF*NC*NL*Pi^2)/127575 + 
       (14641*CF*lm*NC*NL*Pi^2)/810 + (14641*CF*lm*NC*NH*Pi^2)/810 - 
       (7780199243967983897*CF^2*NC*Pi^3)/(20083878149760*Sqrt[3]) - 
       (1465333381961357461*CF*NC*NH*Pi^3)/(1129718145924*Sqrt[3]) - 
       (126309733*CF^2*NC*Pi^4)/12960 + (114409656075227154681229*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(73808252200368000*Sqrt[3]) + 
       (107650686674569702928*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) - (38514619*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - (7780199243967983897*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(542388684600*Sqrt[3]) - 
       (837333361120775692*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (17433922005*Sqrt[3]) - (7780199243967983897*CF^2*NC*Pi*Log[3]^2)/
        (26034656860800*Sqrt[3]) - (209333340280193923*CF*NC*NH*Pi*Log[3]^2)/
        (209207064060*Sqrt[3]) - 
       (CF*NC*(-19*CA*(34898811042616966758617 + 2918553896837779200*lm) + 
          2*(19*CF*(34902974341202340031963 + 7163723201329094400*lm) + 
            840*(19*(21717273417829774699 + 315860811346080*lm)*NM + 
              9*(2032316*(391681191 + 328107080*lm)*NL + 7*(19012311436407 + 
                  95259609771040*lm)*NH))))*Log[x]^2)/26398676304000 + 
       (CF*NC*(547778920415153*CA - 1097711344677935*CF - 
          555775903990440*NM + 21655067280*NL)*Log[x]^3)/85050 - 
       (193910556497265856296341779*CF^2*NC*PolyGamma[2, 1])/
        85406691831854400 - (32386689440941*CF*NM*NC*PolyGamma[2, 1])/
        32400 - (19247678348212317293219*CF*NC*NH*PolyGamma[2, 1])/
        21351672957963600 + CA*CF*NC*
        (-5862332900618699026648200126578495278871/
          2078336520640219041350628480000 + (7717259*lm^2)/80 + 
         (74630466445599306679*Pi^2)/35663846400 + (7780199243967983897*Pi^3)/
          (40167756299520*Sqrt[3]) + (633422713*Pi^4)/129600 - 
         (11*lm*(-1877649160081 + 619841376*Pi^2))/68584320 - 
         (114409656075227154681229*Im[PolyLog[2, (-1)^(1/3)]])/
          (147616504400736000*Sqrt[3]) + (38514619*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/60 + (7780199243967983897*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1084777369200*Sqrt[3]) + 
         (7780199243967983897*Pi*Log[3]^2)/(52069313721600*Sqrt[3]) + 
         (193910556497265856296341779*PolyGamma[2, 1])/170813383663708800 - 
         (81352459526566159605957539*Zeta[3])/85406691831854400) + 
       (81392538195458863822007591*CF^2*NC*Zeta[3])/42703345915927200 + 
       (20576599488179*CF*NM*NC*Zeta[3])/16200 - 
       (21655777*CF*NC*NL*Zeta[3])/45 - (13512886704778061096579*CF*NC*NH*
         Zeta[3])/10675836478981800 + CF*Log[x]*
        ((-13565692380736306936609177*NM*NC)/723780249192000 - 
         (20953131067*lm*NM*NC)/85050 - (99099*lm^2*NM*NC)/2 - 
         (3058797080809*NC*NL)/3528000 - (20953131067*lm*NC*NL)/85050 - 
         (99099*lm^2*NC*NL)/2 - (11852213572367366641508332503653*NC*NH)/
          1249716476585837588328000 - (20953131067*lm*NC*NH)/85050 - 
         (99099*lm^2*NC*NH)/2 - (220567137869*NM*NC*Pi^2)/135 - 
         (64938049*NC*NL*Pi^2)/810 + (837333361120775692*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(52301766015*Sqrt[3]) + 
         CF*NC*(-25035138935705243516573686478415289/
            753907138845257517120000 - (33009649409*lm)/6300 - 
           (2675673*lm^2)/2 - (4383237567344519*Pi^2)/1360800 + 
           (7780199243967983897*Im[PolyLog[2, (-1)^(1/3)]])/
            (1627166053800*Sqrt[3]) - 396396*Zeta[3]) + 
         CA*NC*(5007437165108700779186042462215337/301562855538103006848000 + 
           (289483031387*lm)/170100 + (1090089*lm^2)/4 + 
           (4383419576286791*Pi^2)/2721600 - (7780199243967983897*
             Im[PolyLog[2, (-1)^(1/3)]])/(3254332107600*Sqrt[3]) + 
           198198*Zeta[3])), (-98197260119783885141465305696798690133294599*
         CF^2*NC)/6733810326874309693976036275200000 - 
       (1764826305569*CF^2*lm*NC)/1058400 - (26039871*CF^2*lm^2*NC)/20 - 
       (35770767628780747456076473551067*CF*NM*NC)/1149546393380024640000 - 
       (3219413499629*CF*lm*NM*NC)/28576800 - (2893319*CF*lm^2*NM*NC)/60 + 
       (19210582438050821*CF*NC*NL)/20003760000 - 
       (3219413499629*CF*lm*NC*NL)/28576800 - (2893319*CF*lm^2*NC*NL)/60 + 
       (3990433296376215739360150700588604308359361*CF*NC*NH)/
        82477151842912303912467201449280000 - (3219413499629*CF*lm*NC*NH)/
        28576800 - (2893319*CF*lm^2*NC*NH)/60 + 
       (8232045397207063533749*CF^2*NC*Pi^2)/757856736000 + 
       (20449*CF^2*lm*NC*Pi^2)/5 + (1698480247339243*CF*NM*NC*Pi^2)/85050 + 
       (20449*CF*lm*NM*NC*Pi^2)/135 - (15880713563*CF*NC*NL*Pi^2)/170100 + 
       (20449*CF*lm*NC*NL*Pi^2)/135 + (20449*CF*lm*NC*NH*Pi^2)/135 - 
       (483394281479733144215*CF^2*NC*Pi^3)/(488038239039168*Sqrt[3]) - 
       (216041497787140438693*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) - 
       (916220591*CF^2*NC*Pi^4)/32400 + (26172017772697498280460127*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2989234214114904000*Sqrt[3]) + 
       (9175029884408976943268*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (266895911974545*Sqrt[3]) - (9521369*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (96678856295946628843*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2636009007156*Sqrt[3]) - 
       (123452284449794536396*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) - 
       (96678856295946628843*CF^2*NC*Pi*Log[3]^2)/(126528432343488*Sqrt[3]) - 
       (30863071112448634099*CF*NC*NH*Pi*Log[3]^2)/(5648590729620*Sqrt[3]) - 
       (CF*NC*(-95*CA*(-9052541021281707162727 + 933887758063740480*lm) + 
          2*(19*CF*(-45253453629029221516937 + 11461349758054996800*lm) + 
            2520*(19*(-33031537066873899479 + 168450172810920*lm)*NM + 
              1109644536*(3699811 + 2884305*lm)*NL + (631317701539519 + 
                3200553283407480*lm)*NH)))*Log[x]^2)/13199338152000 + 
       (CF*NC*(-1420188033388747*CA + 2833052246441420*CF + 
          5346461718995040*NM + 69292543320*NL)*Log[x]^3)/85050 + 
       (307095243966860075135413889*CF^2*NC*PolyGamma[2, 1])/
        54904301891906400 + (13108189182367*CF*NM*NC*PolyGamma[2, 1])/1080 - 
       (40020171952592706231833*CF*NC*NH*PolyGamma[2, 1])/
        13726075472976600 - (151106230427216389281159241*CF^2*NC*Zeta[3])/
        27452150945953200 - (3859922187737*CF*NM*NC*Zeta[3])/540 - 
       (7550972*CF*NC*NL*Zeta[3])/5 + (72159884467241397085927*CF*NC*NH*
         Zeta[3])/6863037736488300 + CA*CF*NC*
        (19636873052951968019085553777496292854151809/
          2693524130749723877590414510080000 + (31826509*lm^2)/120 - 
         (5321232360067129147*Pi^2)/979776000 + (483394281479733144215*Pi^3)/
          (976076478078336*Sqrt[3]) + (924073007*Pi^4)/64800 + 
         lm*(54705968122399/57153600 - (224939*Pi^2)/270) - 
         (26172017772697498280460127*Im[PolyLog[2, (-1)^(1/3)]])/
          (5978468428229808000*Sqrt[3]) + (9521369*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/6 + (96678856295946628843*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(5272018014312*Sqrt[3]) + 
         (96678856295946628843*Pi*Log[3]^2)/(253056864686976*Sqrt[3]) - 
         (307095243966860075135413889*PolyGamma[2, 1])/109808603783812800 + 
         (1058251250013911403068338579*Zeta[3])/384330113243344800) + 
       CF*Log[x]*((62855475395758143979579807*NM*NC)/422205145362000 - 
         (22723907921*lm*NM*NC)/28350 - 143143*lm^2*NM*NC - 
         (69294221732833*NC*NL)/23814000 - (22723907921*lm*NC*NL)/28350 - 
         143143*lm^2*NC*NL - (380202922423701266318245499807209*NC*NH)/
          7381137939835103256062250 - (22723907921*lm*NC*NH)/28350 - 
         143143*lm^2*NC*NH + (707201224523*NM*NC*Pi^2)/45 - 
         (33938476*NC*NL*Pi^2)/135 + (123452284449794536396*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(1978897015406113365303922016257170403/
            22899929342424697082520000 - (9220176823*lm)/525 - 3864861*lm^2 + 
           (5679166453398433*Pi^2)/680400 + (96678856295946628843*
             Im[PolyLog[2, (-1)^(1/3)]])/(7908027021468*Sqrt[3]) - 
           1145144*Zeta[3]) + CA*NC*(-197874509520233537638160646795342817/
            4579985868484939416504000 + (306776443831*lm)/56700 + 
           (1574573*lm^2)/2 - (5678891373437761*Pi^2)/1360800 - 
           (96678856295946628843*Im[PolyLog[2, (-1)^(1/3)]])/
            (15816054042936*Sqrt[3]) + 572572*Zeta[3])), 
      (36318861828721106798575464692570391534297622591*CF^2*NC)/
        452815735608145982264525811878400000 - (104655175155277*CF^2*lm*NC)/
        153679680 - (6846255*CF^2*lm^2*NC)/8 + 
       (361746652433564825974811232893544463*CF*NM*NC)/
        9461686454632306806912000 - (243477920116177*CF*lm*NM*NC)/
        4149351360 - (253565*CF*lm^2*NM*NC)/8 + 
       (1373868203837882971*CF*NC*NL)/1936363968000 - 
       (243477920116177*CF*lm*NC*NL)/4149351360 - (253565*CF*lm^2*NC*NL)/
        8 + (57116064034271901449646431064015573513413*CF*NC*NH)/
        2999169157924083778635170961792000 - (243477920116177*CF*lm*NC*NH)/
        4149351360 - (253565*CF*lm^2*NC*NH)/8 - 
       (10080136869083119504569331*CF^2*NC*Pi^2)/183401330112000 + 
       (4901*CF^2*lm*NC*Pi^2)/6 - (8547100926467987*CF*NM*NC*Pi^2)/280665 + 
       (4901*CF*lm*NM*NC*Pi^2)/162 - (69466456111*CF*NC*NL*Pi^2)/1122660 + 
       (4901*CF*lm*NC*NL*Pi^2)/162 + (4901*CF*lm*NC*NH*Pi^2)/162 - 
       (2902301236410501452107*CF^2*NC*Pi^3)/(3578947086287232*Sqrt[3]) - 
       (41658883844654155555*CF*NC*NH*Pi^3)/(15251194969974*Sqrt[3]) - 
       (255892429*CF^2*NC*Pi^4)/12960 + (22365915966890753268831461*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(6889473141102921600*Sqrt[3]) + 
       (1183759363122858695000*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (53379182394909*Sqrt[3]) - (14934647*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - (414614462344357350301*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13807666227960*Sqrt[3]) - 
       (9522030593063806984*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) - (414614462344357350301*CF^2*NC*Pi*Log[3]^2)/
        (662767978942080*Sqrt[3]) - (1190253824132975873*CF*NC*NH*Pi*
         Log[3]^2)/(564859072962*Sqrt[3]) - 
       (CF*NC*(-85*CA*(1126653993403874120515201 + 15643642743455126400*lm) + 
          2*(17*CF*(5633382222339322482558103 + 191990160942403824000*lm) + 
            46200*((1148461086176464004621 + 2616508526551920*lm)*NM + 
              9*(26420108*(13055757 + 11003860*lm)*NL + (63289330134189 + 
                  290723169616880*lm)*NH))))*Log[x]^2)/290385439344000 + 
       (CF*NC*(79960327047180940*CA - 159976916579075563*CF - 
          86706134629468200*NM + 519272153400*NL)*Log[x]^3)/935550 - 
       (511548341592390978513732131*CF^2*NC*PolyGamma[2, 1])/
        17081338366370880 - (3350365279472341*CF*NM*NC*PolyGamma[2, 1])/
        226800 - (50519865579055985661251*CF*NC*NH*PolyGamma[2, 1])/
        27452150945953200 + CA*CF*NC*
        (-159806538045793839356852254050916762558987027637/
          3984778473351684643927827144529920000 + (2789215*lm^2)/16 + 
         (9122311918888810936351*Pi^2)/331948108800 + 
         (2902301236410501452107*Pi^3)/(7157894172574464*Sqrt[3]) + 
         (256519757*Pi^4)/25920 + lm*(410862282461377/754427520 - 
           (53911*Pi^2)/324) - (22365915966890753268831461*
           Im[PolyLog[2, (-1)^(1/3)]])/(13778946282205843200*Sqrt[3]) + 
         (14934647*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (414614462344357350301*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27615332455920*Sqrt[3]) + (414614462344357350301*Pi*Log[3]^2)/
          (1325535957884160*Sqrt[3]) + (511548341592390978513732131*
           PolyGamma[2, 1])/34162676732741760 - (2403606927717030456385434401*
           Zeta[3])/187894722030079680) + (2403790720317375871596551357*CF^2*
         NC*Zeta[3])/93947361015039840 + (1905043087096859*CF*NM*NC*Zeta[3])/
        113400 - (9253127*CF*NC*NL*Zeta[3])/9 - 
       (28365084351069293898851*CF*NC*NH*Zeta[3])/13726075472976600 + 
       CF*Log[x]*((-90940987208230307251662468809*NM*NC)/
          365798537941636800 - (45824988521*lm*NM*NC)/93555 - 
         (195195*lm^2*NM*NC)/2 - (6113210147081*NC*NL)/3326400 - 
         (45824988521*lm*NC*NL)/93555 - (195195*lm^2*NC*NL)/2 - 
         (943647771605514804167518010201267*NC*NH)/
          47239282814944660838798400 - (45824988521*lm*NC*NH)/93555 - 
         (195195*lm^2*NC*NH)/2 - (625594195594*NM*NC*Pi^2)/27 - 
         (27749579*NC*NL*Pi^2)/162 + (9522030593063806984*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(-1207367315326908988089409839605060864989/
            2852882177843716772225472000 - (144747965609*lm)/13860 - 
           (5270265*lm^2)/2 - (127941438504360149*Pi^2)/2993760 + 
           (414614462344357350301*Im[PolyLog[2, (-1)^(1/3)]])/
            (41422998683880*Sqrt[3]) - 780780*Zeta[3]) + 
         CA*NC*(1207383234746409005396637632362180308361/
            5705764355687433544450944000 + (28722961423*lm)/8505 + 
           (2147145*lm^2)/4 + (127942292652576389*Pi^2)/5987520 - 
           (414614462344357350301*Im[PolyLog[2, (-1)^(1/3)]])/
            (82845997367760*Sqrt[3]) + 390390*Zeta[3])), 
      (-249837279899409196735492742287025650468009263929*CF^2*NC)/
        1196371872886200452356667097945600000 - (239661244261*CF^2*lm*NC)/
        81675 - (45815679*CF^2*lm^2*NC)/20 - 
       (689302843682844335806372572586384711*CF*NM*NC)/
        1689586866898626215520000 - (3497243644403*CF*lm*NM*NC)/17641800 - 
       (1696877*CF*lm^2*NM*NC)/20 + (4372085024861892893*CF*NC*NL)/
        2074675680000 - (3497243644403*CF*lm*NC*NL)/17641800 - 
       (1696877*CF*lm^2*NC*NL)/20 + 
       (148805627280388198794965385704462516190265006843*CF*NC*NH)/
        1505249259709071002554482660050084640000 - 
       (3497243644403*CF*lm*NC*NH)/17641800 - (1696877*CF*lm^2*NC*NH)/20 + 
       (5327443976579907049921*CF^2*NC*Pi^2)/37322208000 + 
       (33124*CF^2*lm*NC*Pi^2)/5 + (33464889839111909*CF*NM*NC*Pi^2)/
        133650 + (33124*CF*lm*NM*NC*Pi^2)/135 - (47578344229*CF*NC*NL*Pi^2)/
        267300 + (33124*CF*lm*NC*NL*Pi^2)/135 + (33124*CF*lm*NC*NH*Pi^2)/
        135 - (14868764026648253110361*CF^2*NC*Pi^3)/(7320573585587520*
         Sqrt[3]) - (1322075191876031322359*CF*NC*NH*Pi^3)/
        (91507169819844*Sqrt[3]) - (118556711*CF^2*NC*Pi^4)/2160 + 
       (49035529756452347831719583*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2818420830451195200*Sqrt[3]) + (55954089720114846699892*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(800687735923635*Sqrt[3]) - 
       (89932843*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (2124109146664036158623*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (28242953648100*Sqrt[3]) - (755471538214875041348*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1412147682405*Sqrt[3]) - 
       (2124109146664036158623*CF^2*NC*Pi*Log[3]^2)/(1355661775108800*
         Sqrt[3]) - (188867884553718760337*CF*NC*NH*Pi*Log[3]^2)/
        (16945772188860*Sqrt[3]) - 
       (CF*NC*(-108537*CA*(-1254751650384064378121 + 20669707272614400*lm) + 
          10*(299*CF*(-91091986526760549744553 + 3683341835979886080*lm) + 
            2112*(644*(-35129680229263547959 + 29989530641070*lm)*NM + 
              44663192574*(552779 + 432420*lm)*NL + (4114102720425109 + 
                19313257732849080*lm)*NH)))*Log[x]^2)/159020597736000 + 
       (CF*NC*(-14830900942695107*CA + 29648703264121273*CF + 
          27720*(1911135066603*NM + 4122404*NL))*Log[x]^3)/66825 + 
       (12375333126326309945711244113*CF^2*NC*PolyGamma[2, 1])/
        164712905675719200 + (402389886560131*CF*NM*NC*PolyGamma[2, 1])/
        2700 - (1203726090284301372394*CF*NC*NH*PolyGamma[2, 1])/
        205891132094649 - (64914032418404079169435790759*CF^2*NC*Zeta[3])/
        905920981216455600 - (132702533626529*CF*NM*NC*Zeta[3])/1350 - 
       (46718126*CF*NC*NL*Zeta[3])/15 + (22275750610511742607664*CF*NC*NH*
         Zeta[3])/1029455660473245 + CA*CF*NC*
        (27325425633046865702318459772274110560411203667/
          261706347193856348953020927675600000 + (18665647*lm^2)/40 - 
         (5327434559425465287821*Pi^2)/74644416000 + 
         (14868764026648253110361*Pi^3)/(14641147171175040*Sqrt[3]) + 
         (199007809*Pi^4)/7200 + lm*(5402259577223/3207600 - 
           (182182*Pi^2)/135) - (49035529756452347831719583*
           Im[PolyLog[2, (-1)^(1/3)]])/(5636841660902390400*Sqrt[3]) + 
         (89932843*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (2124109146664036158623*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (56485907296200*Sqrt[3]) + (2124109146664036158623*Pi*Log[3]^2)/
          (2711323550217600*Sqrt[3]) - (12375333126326309945711244113*
           PolyGamma[2, 1])/329425811351438400 + 
         (64918878740507398098344738459*Zeta[3])/1811841962432911200) + 
       CF*Log[x]*((79728707571364618417852911137*NM*NC)/43547444993052000 - 
         (34345090559*lm*NM*NC)/22275 - 273273*lm^2*NM*NC - 
         (444088398188423*NC*NL)/74844000 - (34345090559*lm*NC*NL)/22275 - 
         273273*lm^2*NC*NL - (19694390106198665993640858679797759983*NC*NH)/
          187421854568292941877932652000 - (34345090559*lm*NC*NH)/22275 - 
         273273*lm^2*NC*NH + (8918627426933*NM*NC*Pi^2)/45 - 
         (70010941*NC*NL*Pi^2)/135 + (755471538214875041348*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) + 
         CF*NC*(13178961259656003747393690266134541268571/
            11991510253024413905233440000 - (55839518293*lm)/1650 - 
           7378371*lm^2 + (118641928178838989*Pi^2)/1069200 + 
           (2124109146664036158623*Im[PolyLog[2, (-1)^(1/3)]])/
            (84728860944300*Sqrt[3]) - 2186184*Zeta[3]) + 
         CA*NC*(-13178802251879354748836809202830432291783/
            23983020506048827810466880000 + (42092380109*lm)/4050 + 
           (3006003*lm^2)/2 - (118641041649975197*Pi^2)/2138400 - 
           (2124109146664036158623*Im[PolyLog[2, (-1)^(1/3)]])/
            (169457721888600*Sqrt[3]) + 1093092*Zeta[3])), 
      (171981851465953284916977067044234624136133211547093*CF^2*NC)/
        156772570223007707276817656514791424000 - (73828593091343*CF^2*lm*NC)/
        62726400 - (118076049*CF^2*lm^2*NC)/80 + 
       (486568575460389316733177619853511284579*CF*NM*NC)/
        851551780916907612622080000 - (171553054285703*CF*lm*NM*NC)/
        1693612800 - (4373187*CF*lm^2*NM*NC)/80 + 
       (195600286929577304081*CF*NC*NL)/130704567840000 - 
       (171553054285703*CF*lm*NC*NL)/1693612800 - (4373187*CF*lm^2*NC*NL)/
        80 + (53024148400345190516928788504718570400112934757*CF*NC*NH)/
        1407505801286404054336659110696183040000 - 
       (171553054285703*CF*lm*NC*NH)/1693612800 - (4373187*CF*lm^2*NC*NH)/
        80 - (2050176097930237898618147*CF^2*NC*Pi^2)/2911132224000 + 
       (157339*CF^2*lm*NC*Pi^2)/120 - (2033985937777823321*CF*NM*NC*Pi^2)/
        4989600 + (157339*CF*lm*NM*NC*Pi^2)/3240 - 
       (369668184587*CF*NC*NL*Pi^2)/3207600 + (157339*CF*lm*NC*NL*Pi^2)/
        3240 + (157339*CF*lm*NC*NH*Pi^2)/3240 - 
       (463727213838800357589703*CF^2*NC*Pi^3)/(289894713989265792*Sqrt[3]) - 
       (17899271409286457050511*CF*NC*NH*Pi^3)/(3294258113514384*Sqrt[3]) - 
       (271617437*CF^2*NC*Pi^4)/7200 + (3591877124637436092972718943*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(558047324429336649600*Sqrt[3]) + 
       (353643198601790169100871*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (8235645283785960*Sqrt[3]) - (27507571*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - (66246744834114336798529*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1118420964464760*Sqrt[3]) - 
       (2557038772755208150073*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(12709329141645*Sqrt[3]) - 
       (66246744834114336798529*CF^2*NC*Pi*Log[3]^2)/(53684206294308480*
         Sqrt[3]) - (2557038772755208150073*CF*NC*NH*Pi*Log[3]^2)/
        (610047798798960*Sqrt[3]) - 
       (CF*NC*(-23*CA*(35058260730420923948739769 + 77769692945468203680*
             lm) + 6*(23*CF*(11686124307426658433815283 + 
              63629748773564893920*lm) + 44*(23*(153732812038330860876427 + 
                53560394590542840*lm)*NM + 7*(2734481178*(75979169 + 
                  64357420*lm)*NL + (41235862289240393 + 175984153654640760*
                   lm)*NH))))*Log[x]^2)/190824717283200 + 
       (CF*NC*(591028258566255829*CA - 1182127738131285916*CF - 
          14520*(46348771431394*NM - 41832323*NL))*Log[x]^3)/534600 - 
       (8021860498976617928158434651523*CF^2*NC*PolyGamma[2, 1])/
        20753826115140619200 - (46748170765965443*CF*NM*NC*PolyGamma[2, 1])/
        226800 - (9248335189733686591951549*CF*NC*NH*PolyGamma[2, 1])/
        2594228264392577400 + CA*CF*NC*
        (-4299560116402215057884696193934955322099127720393411/
          7838628511150385363840882825739571200000 + (48105057*lm^2)/160 + 
         (157705894442844262660451*Pi^2)/447866496000 + 
         (463727213838800357589703*Pi^3)/(579789427978531584*Sqrt[3]) + 
         (2449591781*Pi^4)/129600 + lm*(289383505103783/307929600 - 
           (1730729*Pi^2)/6480) - (3591877124637436092972718943*
           Im[PolyLog[2, (-1)^(1/3)]])/(1116094648858673299200*Sqrt[3]) + 
         (27507571*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (66246744834114336798529*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2236841928929520*Sqrt[3]) + (66246744834114336798529*Pi*Log[3]^2)/
          (107368412588616960*Sqrt[3]) + (8021860498976617928158434651523*
           PolyGamma[2, 1])/41507652230281238400 - 
         (3450600432441041241228747446147*Zeta[3])/20753826115140619200) + 
       (3450640493336080107815349826271*CF^2*NC*Zeta[3])/
        10376913057570309600 + (24629939164550197*CF*NM*NC*Zeta[3])/113400 - 
       (279345586*CF*NC*NL*Zeta[3])/135 - (4107393460106576327160889*CF*NC*
         NH*Zeta[3])/1297114132196288700 + CF*Log[x]*
        ((-487422850602289913287237892087*NM*NC)/152416057475682000 - 
         (985451344423*lm*NM*NC)/1069200 - 182182*lm^2*NM*NC - 
         (69295269464391259*NC*NL)/18860688000 - (985451344423*lm*NC*NL)/
          1069200 - 182182*lm^2*NC*NL - 
         (19151830112198842655894853120935155813*NC*NH)/
          481941911747038993400398248000 - (985451344423*lm*NC*NH)/1069200 - 
         182182*lm^2*NC*NH - (509837522979103*NM*NC*Pi^2)/1620 - 
         (558533833*NC*NL*Pi^2)/1620 + (2557038772755208150073*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(38127987424935*Sqrt[3]) + 
         CF*NC*(-14796669314454720700538117063546960495610703/
            2806013399207712853824624960000 - (779840739223*lm)/39600 - 
           4918914*lm^2 - (107460346297230091*Pi^2)/194400 + 
           (66246744834114336798529*Im[PolyLog[2, (-1)^(1/3)]])/
            (3355262893394280*Sqrt[3]) - 1457456*Zeta[3]) + 
         CA*NC*(3699174935490872507844362720936737609637737/
            1403006699603856426912312480000 + (1233364610023*lm)/194400 + 
           1002001*lm^2 + (21492091556105183*Pi^2)/77760 - 
           (66246744834114336798529*Im[PolyLog[2, (-1)^(1/3)]])/
            (6710525786788560*Sqrt[3]) + 728728*Zeta[3])), 
      (-467128076510590901749697282212844514227542585584269*CF^2*NC)/
        163304760648966361746685058869574400000 - (2069248062533*CF^2*lm*NC)/
        418176 - (30901689*CF^2*lm^2*NC)/8 - 
       (16537292522501430737801213641613917103*CF*NM*NC)/
        3153895484877435602304000 - (3774279654797*CF*lm*NM*NC)/11290752 - 
       (1144507*CF*lm^2*NM*NC)/8 + (415156065215789045471*CF*NC*NL)/
        95850016416000 - (3774279654797*CF*lm*NC*NL)/11290752 - 
       (1144507*CF*lm^2*NC*NL)/8 + 
       (418326349391565239300197289169500497932686366537*CF*NC*NH)/
        2181520666245030438484757478333456000000 - 
       (3774279654797*CF*lm*NC*NH)/11290752 - (1144507*CF*lm^2*NC*NH)/8 + 
       (60637703141395586151599779*CF^2*NC*Pi^2)/33186907353600 + 
       (41405*CF^2*lm*NC*Pi^2)/4 + (4623848259710414039*CF*NM*NC*Pi^2)/
        1496880 + (41405*CF*lm*NM*NC*Pi^2)/108 - (3456637639*CF*NC*NL*Pi^2)/
        10692 + (41405*CF*lm*NC*NL*Pi^2)/108 + (41405*CF*lm*NC*NH*Pi^2)/
        108 - (1903812541951485558316651*CF^2*NC*Pi^3)/(483157856648776320*
         Sqrt[3]) - (5121591396584796022855*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) - (2186033941*CF^2*NC*Pi^4)/21600 + 
       (6130981969556560182110538139*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (186015774809778883200*Sqrt[3]) + (317527448742843173064283*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2348684025375996*Sqrt[3]) - 
       (324090221*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
       (271973220278783651188093*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1864034940774600*Sqrt[3]) - 
       (292662365519131201306*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (271973220278783651188093*CF^2*NC*Pi*Log[3]^2)/(89473677157180800*
         Sqrt[3]) - (146331182759565600653*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((4331210827362198917071073*CF*NC)/
          197541115200 - 137334717*CF*lm*NC + 
         CA*(-16843683369014300843619467/1536430896000 + (55951181*lm)/2)*
          NC + (38831062503987455577143*NM*NC)/1047566520 - 
         5086471*lm*NM*NC - (1167148151*NC*NL)/180 - 5086471*lm*NC*NL - 
         (6061606223344799*NC*NH)/5237832600 - 5086471*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-383516586383614828*CA + 25*(30679086797196479*CF + 
            1188*(44288689608370*NM + 15259413*NL)))*Log[x]^3)/133650 + 
       (968124682598193564760639235947*CF^2*NC*PolyGamma[2, 1])/
        988277434054315200 + (3269861609673379*CF*NM*NC*PolyGamma[2, 1])/
        1800 - (229561184758659329615917*CF*NC*NH*PolyGamma[2, 1])/
        20589113209464900 - (197920873464568986517904492725*CF^2*NC*Zeta[3])/
        217421035491949344 - (1158973454459221*CF*NM*NC*Zeta[3])/900 - 
       (54763124*CF*NC*NL*Zeta[3])/9 + (433694773347615124441583*CF*NC*NH*
         Zeta[3])/10294556604732450 + CA*CF*NC*
        (467126768640309867425618798006823684163220748241787/
          326609521297932723493370117739148800000 + (12589577*lm^2)/16 - 
         (49099342321611816869057*Pi^2)/53743979520 + 
         (1903812541951485558316651*Pi^3)/(966315713297552640*Sqrt[3]) + 
         (2199283541*Pi^4)/43200 + lm*(5830107220589/2052864 - 
           (455455*Pi^2)/216) - (6130981969556560182110538139*
           Im[PolyLog[2, (-1)^(1/3)]])/(372031549619557766400*Sqrt[3]) + 
         (324090221*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (271973220278783651188093*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3728069881549200*Sqrt[3]) + (271973220278783651188093*Pi*Log[3]^2)/
          (178947354314361600*Sqrt[3]) - (968124682598193564760639235947*
           PolyGamma[2, 1])/1976554868108630400 + 
         (989615563406922209899483128881*Zeta[3])/2174210354919493440) + 
       CF*Log[x]*((337386544216835025464338147117*NM*NC)/15241605747568200 - 
         (100569427049*lm*NM*NC)/35640 - 496860*lm^2*NM*NC - 
         (79378945110243743*NC*NL)/6915585600 - (100569427049*lm*NC*NL)/
          35640 - 496860*lm^2*NC*NL - (8293046615129836114752528659229967781*
           NC*NH)/40743881427889769973463620000 - (100569427049*lm*NC*NH)/
          35640 - 496860*lm^2*NC*NH + (44288689292821*NM*NC*Pi^2)/18 - 
         (6080191*NC*NL*Pi^2)/6 + (292662365519131201306*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(2554994093533578290806678339728197631353411/
            187067559947180856921641664000 - (81877553849*lm)/1320 - 
           13415220*lm^2 + (3068111595164565823*Pi^2)/2138400 + 
           (271973220278783651188093*Im[PolyLog[2, (-1)^(1/3)]])/
            (5592104822323800*Sqrt[3]) - 3974880*Zeta[3]) + 
         CA*NC*(-12774946910066904812346795748673581139186773/
            1870675599471808569216416640000 + (123106996649*lm)/6480 + 
           2732730*lm^2 - (3068108147087497519*Pi^2)/4276800 - 
           (271973220278783651188093*Im[PolyLog[2, (-1)^(1/3)]])/
            (11184209644647600*Sqrt[3]) + 1987440*Zeta[3])), 
      (771317350257644565249343844227667596662809514853143206329*CF^2*NC)/
        53136159010164325859317554747002302126080000 - 
       (828541192380179*CF^2*lm*NC)/424030464 - (39139821*CF^2*lm^2*NC)/16 + 
       (2380912826104671811625324444203352729111147*CF*NM*NC)/
        296023729097600426364938496000 - (1923447625472651*CF*lm*NM*NC)/
        11448822528 - (1449623*CF*lm^2*NM*NC)/16 + 
       (72350698468597002228503*CF*NC*NL)/24297979161456000 - 
       (1923447625472651*CF*lm*NC*NL)/11448822528 - (1449623*CF*lm^2*NC*NL)/
        16 + (577476235928629534785466104240378452862300802985543*CF*NC*NH)/
        8128346002428983413794206364270457056000000 - 
       (1923447625472651*CF*lm*NC*NH)/11448822528 - (1449623*CF*lm^2*NC*NH)/
        16 - (204020800186215027344114147*CF^2*NC*Pi^2)/23112310478400 + 
       (48755*CF^2*lm*NC*Pi^2)/24 - (17638292190266213515*CF*NM*NC*Pi^2)/
        3335904 + (48755*CF*lm*NM*NC*Pi^2)/648 - 
       (342182598377*CF*NC*NL*Pi^2)/1667952 + (48755*CF*lm*NC*NL*Pi^2)/
        648 + (48755*CF*lm*NC*NH*Pi^2)/648 - 
       (4239929715266363633782463*CF^2*NC*Pi^3)/(1413236730697670736*
         Sqrt[3]) - (101729603445433916108345*CF*NC*NH*Pi^3)/
        (9882774340543152*Sqrt[3]) - (27783637*CF^2*NC*Pi^4)/405 + 
       (861051546841973123114538690569*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (70732498371418420336800*Sqrt[3]) + (13765197772236711121942571*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(172948550959505160*Sqrt[3]) - 
       (24245984*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (605704245038051947683209*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5452302201765705*Sqrt[3]) - 
       (2906560098440969031667*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (605704245038051947683209*CF^2*NC*Pi*Log[3]^2)/(261710505684753840*
         Sqrt[3]) - (2906560098440969031667*CF*NC*NH*Pi*Log[3]^2)/
        (366028679279376*Sqrt[3]) - 
       (CF*NC*(200*CF*(164237005938253747728786314 + 138448481137997521491*
             lm) - 3*CA*(5474564140019250436658590661 + 
            1880164558664163872100*lm) + 
          429*(105*(436782945740582786304337 + 22767106332021480*lm)*NM + 
            8700621930*(323039471 + 274755780*lm)*NL + 
            (596700654264118123 + 2390546164862255400*lm)*NH))*Log[x]^2)/
        310090165585200 + (CF*NC*(19426526481356898099*CA - 
          104*(373590765416662862*CF + 220853975978079510*NM - 
            29467557405*NL))*Log[x]^3)/1389960 - 
       (8450634184524758265347322650857*CF^2*NC*PolyGamma[2, 1])/
        1729485509595051600 - (208405094924622719*CF*NM*NC*PolyGamma[2, 1])/
        75600 - (1902540266303382286792951*CF*NC*NH*PolyGamma[2, 1])/
        288247584932508600 + CA*CF*NC*
        (-5399223937501206018822632276623485525553222120279557265453/
          743906226142300562030445766458032229765120000 + 
         (15945853*lm^2)/32 + (150331121473797353859524239*Pi^2)/
          34060247020800 + (4239929715266363633782463*Pi^3)/
          (2826473461395341472*Sqrt[3]) + (1546244*Pi^4)/45 + 
         lm*(3243621889297067/2081604096 - (536305*Pi^2)/1296) - 
         (861051546841973123114538690569*Im[PolyLog[2, (-1)^(1/3)]])/
          (141464996742836840673600*Sqrt[3]) + 
         (12122992*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (605704245038051947683209*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (10904604403531410*Sqrt[3]) + (605704245038051947683209*Pi*
           Log[3]^2)/(523421011369507680*Sqrt[3]) + 
         (8450634184524758265347322650857*PolyGamma[2, 1])/
          3458971019190103200 - (259925843744854079830749762541877*Zeta[3])/
          123658213936046189400) + (519852586136297879609519739101509*CF^2*NC*
         Zeta[3])/123658213936046189400 + (103914304376174281*CF*NM*NC*
         Zeta[3])/37800 - (106862986*CF*NC*NL*Zeta[3])/27 - 
       (656095897741307875601251*CF*NC*NH*Zeta[3])/144123792466254300 + 
       CF*Log[x]*((-494694811555590027285752078639*NM*NC)/
          12341034857852415 - (4600643315891*lm*NM*NC)/2779920 - 
         324870*lm^2*NM*NC - (3768930024663567677*NC*NL)/539415676800 - 
         (4600643315891*lm*NC*NL)/2779920 - 324870*lm^2*NC*NL - 
         (3809703513516573905388800409000593412953*NC*NH)/
          50603900733439094307041816040000 - (4600643315891*lm*NC*NH)/
          2779920 - 324870*lm^2*NC*NH - (1338509332402375*NM*NC*Pi^2)/324 - 
         (7913971*NC*NL*Pi^2)/12 + (2906560098440969031667*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-372859309441036260915607029249184254250994462941/
            5789086243905432388725583754976000 - (3647357782691*lm)/102960 - 
           8771490*lm^2 - (19426545094376282141*Pi^2)/2779920 + 
           (605704245038051947683209*Im[PolyLog[2, (-1)^(1/3)]])/
            (16356906605297115*Sqrt[3]) - 2598960*Zeta[3]) + 
         CA*NC*(745718851495931252124477436587952854439199182277/
            23156344975621729554902335019904000 + (5750059365491*lm)/505440 + 
           1786785*lm^2 + (19426548140319357173*Pi^2)/5559840 - 
           (605704245038051947683209*Im[PolyLog[2, (-1)^(1/3)]])/
            (32713813210594230*Sqrt[3]) + 1299480*Zeta[3])), 
      (-316448249832467134029395059264171572918965901771572756791511*CF^2*NC)/
        8368945044100881322842514872652862584857600000 - 
       (22207970880257*CF^2*lm*NC)/2760615 - 6279651*CF^2*lm^2*NC - 
       (475350230870296942324763299574305861989943*CF*NM*NC)/
        7195021193344454807481144000 - (81013528000729*CF*lm*NM*NC)/
        149073210 - (697739*CF*lm^2*NM*NC)/3 + 
       (974913533823590262157*CF*NC*NL)/115704662673600 - 
       (81013528000729*CF*lm*NC*NL)/149073210 - (697739*CF*lm^2*NC*NL)/3 + 
       (58071059594922830577649036184921270713075396431623*CF*NC*NH)/
        163292665227367970366401467139361860500000 - 
       (81013528000729*CF*lm*NC*NH)/149073210 - (697739*CF*lm^2*NC*NH)/3 + 
       (284486581565380132826258771*CF^2*NC*Pi^2)/12445090257600 + 
       15680*CF^2*lm*NC*Pi^2 + (45624071450446569929*CF*NM*NC*Pi^2)/
        1216215 + (15680*CF*lm*NM*NC*Pi^2)/27 - (19571454481*CF*NC*NL*Pi^2)/
        34749 + (15680*CF*lm*NC*NL*Pi^2)/27 + (15680*CF*lm*NC*NH*Pi^2)/27 - 
       (927293495386715661023280797*CF^2*NC*Pi^3)/(127191305762790366240*
         Sqrt[3]) - (288157482762597372997100*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (1446648091*CF^2*NC*Pi^4)/8100 + 
       (38130920305848268289472452330447*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (636592485342765783031200*Sqrt[3]) + (76596919731124750465874348*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(305748331160553765*Sqrt[3]) - 
       (280340228*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (132470499340959380146182971*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(490707198158913450*
         Sqrt[3]) - (131729134977187370512960*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (132470499340959380146182971*CF^2*NC*Pi*Log[3]^2)/
        (23553945511627845600*Sqrt[3]) - (8233070936074210657060*CF*NC*NH*Pi*
         Log[3]^2)/(205891132094649*Sqrt[3]) - 
       (CF*NC*(CA*(425306972765366711367273527249 - 163849948335647814240000*
             lm) + 3520*(CF*(-241651502944060132347310267 + 
              228509741997029493000*lm) + 117*(5*(-677882413567445260123003 + 
                14467220132765400*lm)*NM + 154*(4237315875*(140989 + 
                  110852*lm)*NL + 2*(56574863282107 + 234857469687750*lm)*
                 NH))))*Log[x]^2)/3100901655852000 + 
       (CF*NC*(-62931227223327203059*CA + 40*(3146524492250983271*CF + 
            154440*(33824954119169*NM + 1801345*NL)))*Log[x]^3)/1737450 + 
       (124593178549919084138038812922531*CF^2*NC*PolyGamma[2, 1])/
        10006309019799941400 + (548218674189198*CF*NM*NC*PolyGamma[2, 1])/
        25 - (25466801214780969318857879*CF*NC*NH*PolyGamma[2, 1])/
        1250788627474992675 - (8097096168602587262630591066623609*CF^2*NC*
         Zeta[3])/715451094915695810100 - (3662029383060836*CF*NM*NC*
         Zeta[3])/225 - (102121040*CF*NC*NL*Zeta[3])/9 + 
       (97854665493625843109066642*CF*NC*NH*Zeta[3])/1250788627474992675 + 
       CA*CF*NC*(1412714833727966460375273473005145353378876677739983796897/
          74722723608043583239665311362971987364800000 + (7675129*lm^2)/6 - 
         (568973142867277126737270949*Pi^2)/49780361030400 + 
         (927293495386715661023280797*Pi^3)/(254382611525580732480*Sqrt[3]) + 
         (1454174491*Pi^4)/16200 + lm*(125140761170749/27104220 - 
           (86240*Pi^2)/27) - (38130920305848268289472452330447*
           Im[PolyLog[2, (-1)^(1/3)]])/(1273184970685531566062400*Sqrt[3]) + 
         (140170114*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (132470499340959380146182971*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (981414396317826900*Sqrt[3]) + (132470499340959380146182971*Pi*
           Log[3]^2)/(47107891023255691200*Sqrt[3]) - 
         (124593178549919084138038812922531*PolyGamma[2, 1])/
          20012618039599882800 + (1012138718155905585325893300509858*Zeta[3])/
          178862773728923952525) + CF*Log[x]*
        ((2124829647939995995032034751611759*NM*NC)/8062809440463577800 - 
         (57316007048*lm*NM*NC)/11583 - 866320*lm^2*NM*NC - 
         (851644513667821*NC*NL)/40135095 - (57316007048*lm*NC*NL)/11583 - 
         866320*lm^2*NC*NL - (235857708126665752198826869120151108203*NC*
           NH)/625597673902406385663978495000 - (57316007048*lm*NC*NH)/
          11583 - 866320*lm^2*NC*NH + 30066626035696*NM*NC*Pi^2 - 
         (17009720*NC*NL*Pi^2)/9 + (131729134977187370512960*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(13607100125499649246633776776892146900273419283/
            81792427307926046308524731232000 - (46723945568*lm)/429 - 
           23390640*lm^2 + (125862324155582021411*Pi^2)/6949800 + 
           (132470499340959380146182971*Im[PolyLog[2, (-1)^(1/3)]])/
            (1472121594476740350*Sqrt[3]) - 6930560*Zeta[3]) + 
         CA*NC*(-5417325246482381844307924756679000118288330174431/
            65127220243936114373162817243480000 + (35043648244*lm)/1053 + 
           4764760*lm^2 - (125862303338370963053*Pi^2)/13899600 - 
           (132470499340959380146182971*Im[PolyLog[2, (-1)^(1/3)]])/
            (2944243188953480700*Sqrt[3]) + 3465280*Zeta[3])), 
      (109381989225777706757469905352016810529327571162134010805976207*CF^2*
         NC)/585826153087061692598976041085700380940032000000 - 
       (4068873776885399*CF^2*lm*NC)/1298593296 - (7835157*CF^2*lm^2*NC)/2 + 
       (637504144060191689210759741022959670397472297*CF*NM*NC)/
        5886835521827281206120936000000 - (9438845018908787*CF*lm*NM*NC)/
        35062018992 - (290191*CF*lm^2*NM*NC)/2 + 
       (101653208011806263083*CF*NC*NL)/18031895481600 - 
       (9438845018908787*CF*lm*NC*NL)/35062018992 - (290191*CF*lm^2*NC*NL)/
        2 + (2350722433291415273810913939389467364289363140268059*CF*NC*NH)/
        18288778505465212681036964319608528376000000 - 
       (9438845018908787*CF*lm*NC*NH)/35062018992 - (290191*CF*lm^2*NC*NH)/
        2 - (14454452965346641359538303607*CF^2*NC*Pi^2)/133235672169600 + 
       (9160*CF^2*lm*NC*Pi^2)/3 - (243721170870764505916*CF*NM*NC*Pi^2)/
        3648645 + (9160*CF*lm*NM*NC*Pi^2)/81 - (36610672646*CF*NC*NL*Pi^2)/
        104247 + (9160*CF*lm*NC*NL*Pi^2)/81 + (9160*CF*lm*NC*NH*Pi^2)/81 - 
       (274116952594066418070432421*CF^2*NC*Pi^3)/(50876522305116146496*
         Sqrt[3]) - (103925690891781070492460*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (387457331*CF^2*NC*Pi^4)/3240 + 
       (196926491251366154718496902995021*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8912294794798720962436800*Sqrt[3]) + 
       (789301407215266729107440*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5559060566555523*Sqrt[3]) - (41152274*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (274116952594066418070432421*CF^2*
         NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1373980154844957660*
         Sqrt[3]) - (47508887264814203653696*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (274116952594066418070432421*CF^2*NC*Pi*Log[3]^2)/
        (65951047432557967680*Sqrt[3]) - (2969305454050887728356*CF*NC*NH*Pi*
         Log[3]^2)/(205891132094649*Sqrt[3]) - 
       (CF*NC*(-9*CA*(89709397458498895021598413847 + 4646360078051362070400*
             lm) + 8*(CF*(201846159491129072497459948217 + 
              25660579521965476888800*lm) + 
            858*(21*(6897541335604686565993343 + 52746799541950800*lm)*NM + 
              2485891980*(522085351 + 445587660*lm)*NL + 
              (292119013695418051 + 1107682790380966800*lm)*NH)))*Log[x]^2)/
        1240360662340800 - (CF*NC*(-842098238360687857215*CA + 
          16*(105262447625076338627*CF + 30030*(2135270784103570*NM - 
              41375997*NL)))*Log[x]^3)/4864860 - 
       (8487743425498166837749019143539347*CF^2*NC*PolyGamma[2, 1])/
        140088326277199179600 - (32097570785722189*CF*NM*NC*PolyGamma[2, 1])/
        900 - (411417656850673743936696671*CF*NC*NH*PolyGamma[2, 1])/
        35022081569299794900 + CA*CF*NC*
        (-262937491219767742821291839629845978973529494077169017638677/
          2816471889841642752879692505219713369904000000 + (3192101*lm^2)/4 + 
         (491451403358769164096361350141*Pi^2)/9060025707532800 + 
         (274116952594066418070432421*Pi^3)/(101753044610232292992*Sqrt[3]) + 
         (129347857*Pi^4)/2160 + lm*(15913642880104451/6374912544 - 
           (50380*Pi^2)/81) - (196926491251366154718496902995021*
           Im[PolyLog[2, (-1)^(1/3)]])/(17824589589597441924873600*Sqrt[3]) + 
         (20576137*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (274116952594066418070432421*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2747960309689915320*Sqrt[3]) + (274116952594066418070432421*Pi*
           Log[3]^2)/(131902094865115935360*Sqrt[3]) + 
         (8487743425498166837749019143539347*PolyGamma[2, 1])/
          280176652554398359200 - (130014778702314633541630967636868821*
           Zeta[3])/5008157664409870670700) + 
       (520059246313510107460731191518635329*CF^2*NC*Zeta[3])/
        10016315328819741341400 + (5117635085923937*CF*NM*NC*Zeta[3])/150 - 
       (195614308*CF*NC*NL*Zeta[3])/27 - (106918462658933308337418671*CF*NC*
         NH*Zeta[3])/17511040784649897450 + 
       CF*Log[x]*((-1188731617805588548091281689502912667*NM*NC)/
          2418842832139073340000 - (3471413382473*lm*NM*NC)/1216215 - 
         556920*lm^2*NM*NC - (14182997168635229*NC*NL)/1114495200 - 
         (3471413382473*lm*NC*NL)/1216215 - 556920*lm^2*NC*NL - 
         (31133822090875726056432973962972309562453*NC*NH)/
          227717553300475924381688172180000 - (3471413382473*lm*NC*NH)/
          1216215 - 556920*lm^2*NC*NH - (4270541741117488*NM*NC*Pi^2)/81 - 
         (10865426*NC*NL*Pi^2)/9 + (47508887264814203653696*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-2818790754399203033864615144971168820874065781999467/
            3647124333660422404897117765634880000 - (2756449232573*lm)/
            45045 - 15036840*lm^2 - (240599531505719851757*Pi^2)/2779920 + 
           (274116952594066418070432421*Im[PolyLog[2, (-1)^(1/3)]])/
            (4121940464534872980*Sqrt[3]) - 4455360*Zeta[3]) + 
         CA*NC*(352348860585892268551335480478280026475234876411179/
            911781083415105601224279441408720000 + (4333475419673*lm)/
            221130 + 3063060*lm^2 + (1684196759532808601837*Pi^2)/38918880 - 
           (274116952594066418070432421*Im[PolyLog[2, (-1)^(1/3)]])/
            (8243880929069745960*Sqrt[3]) + 2227680*Zeta[3])), 
      (-142159018059606269071163320811011522515456770294749658076868657*CF^2*
         NC)/292913076543530846299488020542850190470016000000 - 
       (2742043501773227*CF^2*lm*NC)/216432216 - 9890073*CF^2*lm^2*NC - 
       (11524444022732147709705794184797258406225781*CF*NM*NC)/
        14107884692832264328394400000 - (5001492273997871*CF*lm*NM*NC)/
        5843669832 - 366299*CF*lm^2*NM*NC + (329340514226151338341709*CF*NC*
         NL)/21058248606595200 - (5001492273997871*CF*lm*NC*NL)/
        5843669832 - 366299*CF*lm^2*NC*NL + 
       (349220193366922756718229385669060529244586417042307837*CF*NC*NH)/
        550672862925667990219519163939422714274400000 - 
       (5001492273997871*CF*lm*NC*NH)/5843669832 - 366299*CF*lm^2*NC*NH + 
       (105812702722785200482428098161*CF^2*NC*Pi^2)/377501071147200 + 
       23120*CF^2*lm*NC*Pi^2 + (109180146860616003187*CF*NM*NC*Pi^2)/
        243243 + (23120*CF*lm*NM*NC*Pi^2)/27 - (230188257121*CF*NC*NL*Pi^2)/
        243243 + (23120*CF*lm*NC*NL*Pi^2)/27 + (23120*CF*lm*NC*NH*Pi^2)/
        27 - (1646797926424093166435150897*CF^2*NC*Pi^3)/
        (127191305762790366240*Sqrt[3]) - (171112937206446949114660*CF*NC*NH*
         Pi^3)/(1853020188851841*Sqrt[3]) - (819277277*CF^2*NC*Pi^4)/2700 + 
       (93541527465448341293190518107477*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (891229479479872096243680*Sqrt[3]) + (153551365835692400625151612*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(343495038711239415*Sqrt[3]) - 
       (468129748*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (1646797926424093166435150897*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3434950387112394150*
         Sqrt[3]) - (78223057008661462452416*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (1646797926424093166435150897*CF^2*NC*Pi*Log[3]^2)/
        (164877618581394919200*Sqrt[3]) - (4888941063041341403276*CF*NC*NH*
         Pi*Log[3]^2)/(68630377364883*Sqrt[3]) + 
       CF*((202807624382587853250998900441*CF*NC)/60295309974900 - 
         469696536*CF*lm*NC + CA*(-4056152950101186178169189712067/
            2411812398996000 + 95678924*lm)*NC + 
         (1908468950551982405033729*NM*NC)/354323970 - 17396168*lm*NM*NC - 
         (993749246*NC*NL)/45 - 17396168*lm*NC*NL - 
         (9994527900747167*NC*NH)/2268593730 - 17396168*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-5444266656311626045243*CA + 
          20*(544425667762367317387*CF + 18378360*(47896437669442*NM + 
              383739*NL)))*Log[x]^3)/12162150 + 
       (4647064298537625047612486329993697*CF^2*NC*PolyGamma[2, 1])/
        30018927059399824200 + (39277301939836303*CF*NM*NC*PolyGamma[2, 1])/
        150 - (268656477363486437898806651*CF*NC*NH*PolyGamma[2, 1])/
        7504731764849956050 - (414768872643424885699001566532893153*CF^2*NC*
         Zeta[3])/3004894598645922402420 - (45015952865797091*CF*NM*NC*
         Zeta[3])/225 - (182876072*CF*NC*NL*Zeta[3])/9 + 
       (523352876744577590741547349*CF*NC*NH*Zeta[3])/3752365882424978025 + 
       CA*CF*NC*
        (8884938123267014604704975682913093631196477003466978362300847/
          36614134567941355787436002567856273808752000000 + 
         (4029289*lm^2)/2 - (1778364742902925524154179419*Pi^2)/
          12689111635200 + (1646797926424093166435150897*Pi^3)/
          (254382611525580732480*Sqrt[3]) + (822976477*Pi^4)/5400 + 
         lm*(7725803712278303/1062485424 - (127160*Pi^2)/27) - 
         (93541527465448341293190518107477*Im[PolyLog[2, (-1)^(1/3)]])/
          (1782458958959744192487360*Sqrt[3]) + 
         (234064874*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (1646797926424093166435150897*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6869900774224788300*Sqrt[3]) + (1646797926424093166435150897*Pi*
           Log[3]^2)/(329755237162789838400*Sqrt[3]) - 
         (4647064298537625047612486329993697*PolyGamma[2, 1])/
          60037854118799648400 + (103692243437413398805288777432255771*
           Zeta[3])/1502447299322961201210) + 
       CF*Log[x]*((14672275012767389758633055327789579*NM*NC)/
          4742829082625634000 - (3389839723492*lm*NM*NC)/405405 - 
         1456560*lm^2*NM*NC - (11017803093060363239*NC*NL)/292183491600 - 
         (3389839723492*lm*NC*NL)/405405 - 1456560*lm^2*NC*NL - 
         (4287292997961919065318383466359517538561607*NC*NH)/
          6383682077523341746833325093446000 - (3389839723492*lm*NC*NH)/
          405405 - 1456560*lm^2*NC*NH + (3256957766713040*NM*NC*Pi^2)/9 - 
         (10154644*NC*NL*Pi^2)/3 + (78223057008661462452416*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(3630361848065867280519269951547197539564822734153517/
            1823562166830211202448558882817440000 - (2766537644092*lm)/
            15015 - 39327120*lm^2 + (10888531652827973766337*Pi^2)/48648600 + 
           (1646797926424093166435150897*Im[PolyLog[2, (-1)^(1/3)]])/
            (10304851161337182450*Sqrt[3]) - 11652480*Zeta[3]) + 
         CA*NC*(-453795212744382933993722181859903226476685654453381/
            455890541707552800612139720704360000 + (2070690493346*lm)/36855 + 
           8011080*lm^2 - (10888531392715441792471*Pi^2)/97297200 - 
           (1646797926424093166435150897*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) + 5826240*Zeta[3])), 
      (8826436109930810655590669383791910203731891339881399135359161989*CF^2*
         NC)/3766025269845396595279131692693788163185920000000 - 
       (791333457438817739*CF^2*lm*NC)/162324162000 - (60889257*CF^2*lm^2*NC)/
        10 + (2461905872555874588503931346634433239047670607377*CF*NM*NC)/
        1748390149982702518217917992000000 - (1834623205934512439*CF*lm*NM*
         NC)/4382752374000 - (6765473*CF*lm^2*NM*NC)/30 + 
       (10765846271533558514640719*CF*NC*NL)/1052912430329760000 - 
       (1834623205934512439*CF*lm*NC*NL)/4382752374000 - 
       (6765473*CF*lm^2*NC*NL)/30 + 
       (180033626789145272444996666789821890337463467688808245491*CF*NC*NH)/
        802881034145623929740058941023678317412075200000 - 
       (1834623205934512439*CF*lm*NC*NH)/4382752374000 - 
       (6765473*CF*lm^2*NC*NH)/30 - (14835776001810589459964028647171*CF^2*
         NC*Pi^2)/11325032134416000 + (67048*CF^2*lm*NC*Pi^2)/15 - 
       (1157895765210312660856*CF*NM*NC*Pi^2)/1403325 + 
       (67048*CF*lm*NM*NC*Pi^2)/405 - (10600158103099*CF*NC*NL*Pi^2)/
        18243225 + (67048*CF*lm*NC*NL*Pi^2)/405 + (67048*CF*lm*NC*NH*Pi^2)/
        405 - (4266445020657433720098255277*CF^2*NC*Pi^3)/
        (457888700746045318464*Sqrt[3]) - (1637126126888018432232280*CF*NC*
         NH*Pi^3)/(50031545098999707*Sqrt[3]) - (651129971*CF^2*NC*Pi^4)/
        3240 + (2216219670582805673390988938858287*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(57293323680848920472808000*Sqrt[3]) + 
       (306588223334216986683646166768*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1252039416102467667675*Sqrt[3]) - 
       (112619934*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (609492145808204817156893611*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1766545913372088420*
         Sqrt[3]) - (748400515148808426163328*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (609492145808204817156893611*CF^2*NC*Pi*Log[3]^2)/
        (84794203841860244160*Sqrt[3]) - (46775032196800526635208*CF*NC*NH*
         Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) - 
       (CF*NC*(-29*CA*(341222856295531040210145567821693 + 
            2606516083873877910134400*lm) + 
          8*(29*CF*(85305715025228932549987092535879 + 
              1599453051468061444855200*lm) + 
            10010*(203*(766807539511880336929010263 + 845426029773433680*lm)*
               NM + 56563603668*(3544596931 + 3034132780*lm)*NL + 
              (47501546271073626517 + 171621484044007037040*lm)*NH)))*
         Log[x]^2)/1258966072275912000 - 
       (CF*NC*(-51197403148336710843567*CA + 8*(12799353973137237095881*CF + 
            60060*(133038218976560098*NM - 368430409*NL)))*Log[x]^3)/
        24324300 - (930605271930541741673870464960694939*CF^2*NC*
         PolyGamma[2, 1])/1260794936494792616400 - 
       (25461488684716742477*CF*NM*NC*PolyGamma[2, 1])/56700 - 
       (6365336852768754124597277929*CF*NC*NH*PolyGamma[2, 1])/
        315198734123698154100 + CA*CF*NC*
        (-1930782916625864504041152817844124269427746942253735861784685789/
          1647636055557361010434620115553532321393840000000 + 
         (74420203*lm^2)/60 + (1745385413216719252503587357153*Pi^2)/
          2664713443392000 + (4266445020657433720098255277*Pi^3)/
          (915777401492090636928*Sqrt[3]) + (3259940927*Pi^4)/32400 + 
         lm*(3092561084503484039/796864068000 - (368764*Pi^2)/405) - 
         (2216219670582805673390988938858287*Im[PolyLog[2, (-1)^(1/3)]])/
          (114586647361697840945616000*Sqrt[3]) + 
         (56309967*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (609492145808204817156893611*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3533091826744176840*Sqrt[3]) + (609492145808204817156893611*Pi*
           Log[3]^2)/(169588407683720488320*Sqrt[3]) + 
         (930605271930541741673870464960694939*PolyGamma[2, 1])/
          2521589872989585232800 - (14165775659966664606323984735407806257*
           Zeta[3])/45073418979688836036300) + 
       (56663104702233942131535890691289329497*CF^2*NC*Zeta[3])/
        90146837959377672072600 + (11789214211313670403*CF*NM*NC*Zeta[3])/
        28350 - (1723061588*CF*NC*NL*Zeta[3])/135 - 
       (1186418856142200661930796089*CF*NC*NH*Zeta[3])/
        157599367061849077050 + CF*Log[x]*
        ((-128670985233371393364591917026239229459*NM*NC)/
          21769585489251660060000 - (28904072501147*lm*NM*NC)/6081075 - 
         922488*lm^2*NM*NC - (65218173458742673739*NC*NL)/2921834916000 - 
         (28904072501147*lm*NC*NL)/6081075 - 922488*lm^2*NC*NL - 
         (82484986430599844246910105188270500352942113*NC*NH)/
          344718832186260454328999555046084000 - (28904072501147*lm*NC*NH)/
          6081075 - 922488*lm^2*NC*NH - (53215287888181472*NM*NC*Pi^2)/81 - 
         (861396698*NC*NL*Pi^2)/405 + (748400515148808426163328*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*(-1498289493530736441839773753156342859338879757229026623/
            164120595014719008220370299453569600000 - (22982702746847*lm)/
            225225 - 24907176*lm^2 - (34131602828383453751789*Pi^2)/
            32432400 + (609492145808204817156893611*Im[PolyLog[2, (-1)^
                (1/3)]])/(5299637740116265260*Sqrt[3]) - 7379904*Zeta[3]) + 
         CA*NC*(187286187948575747788016311856038180434695301689635241/
            41030148753679752055092574863392400000 + (36043714501547*lm)/
            1105650 + 5073684*lm^2 + (11377200980926607820089*Pi^2)/
            21621600 - (609492145808204817156893611*Im[PolyLog[2, (-1)^
                (1/3)]])/(10599275480232530520*Sqrt[3]) + 3689952*Zeta[3])), 
      (-80087611103614602844423825103546252557058252391480342060227894273*
         CF^2*NC)/13181088444458888083476960924428258571150720000000 - 
       (7291304934157873*CF^2*lm*NC)/375750375 - (75744639*CF^2*lm^2*NC)/5 - 
       (1324290644464583504802231494471517326221241179*CF*NM*NC)/
        133424156744711730633235500000 - (26599508838566921*CF*lm*NM*NC)/
        20290520250 - (2805357*CF*lm^2*NM*NC)/5 + 
       (7337240478476369836866719*CF*NC*NL)/263228107582440000 - 
       (26599508838566921*CF*lm*NC*NL)/20290520250 - 
       (2805357*CF*lm^2*NC*NL)/5 + 
       (653290376713923637675848171377853791855493006596913963050039*CF*NC*
         NH)/597965722205807062272152397800910018850578307080000 - 
       (26599508838566921*CF*lm*NC*NH)/20290520250 - 
       (2805357*CF*lm^2*NC*NH)/5 + (78676361503622808390021151363*CF^2*NC*
         Pi^2)/23302535256000 + (166464*CF^2*lm*NC*Pi^2)/5 + 
       (10736845822024801918727*CF*NM*NC*Pi^2)/2027025 + 
       (18496*CF*lm*NM*NC*Pi^2)/15 - (1040765710273*CF*NC*NL*Pi^2)/675675 + 
       (18496*CF*lm*NC*NL*Pi^2)/15 + (18496*CF*lm*NC*NH*Pi^2)/15 - 
       (25395202917009591845018140853*CF^2*NC*Pi^3)/(1144721751865113296160*
         Sqrt[3]) - (7952678788683866983813340*CF*NC*NH*Pi^3)/
        (50031545098999707*Sqrt[3]) - (448841939*CF^2*NC*Pi^4)/900 + 
       (35708100068138860198358684403668173*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(200526632882971221654828000*Sqrt[3]) + 
       (74298791318431049864226680644*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (96310724315574435975*Sqrt[3]) - 
       (252599532*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (25395202917009591845018140853*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(30914553484011547350*
         Sqrt[3]) - (3635510303398339192600384*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (25395202917009591845018140853*CF^2*NC*Pi*Log[3]^2)/
        (1483898567232554272800*Sqrt[3]) - (227219393962396199537524*CF*NC*
         NH*Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) - 
       (CF*NC*(-11687*CA*(-2254985508762788853247743262741 + 
            18586337502177325520640*lm) + 
          16*(899*CF*(-3664351391083301373077825604383 + 
              74134141628002741565280*lm) + 12012*
             (395560*(-1087691284258829439583301 + 519501133182213*lm)*NM + 
              681905666442*(381929143 + 301352340*lm)*NL + 
              (54396358447798290179 + 205493868241556174280*lm)*NH)))*
         Log[x]^2)/1300931608018442400 + 
       (CF*NC*(-7337939097301706667041*CA + 8*(1834484259928805373509*CF + 
            40040*(72465514655066049*NM + 85383163*NL)))*Log[x]^3)/
        1351350 + (56663599731034569562858039028239577*CF^2*NC*
         PolyGamma[2, 1])/30018927059399824200 + 
       (417383333200172981*CF*NM*NC*PolyGamma[2, 1])/135 - 
       (228421510224624465637822786*CF*NC*NH*PolyGamma[2, 1])/
        3752365882424978025 - (4972765914388127709328831544577705577*CF^2*NC*
         Zeta[3])/3004894598645922402420 - (324681537144420086*CF*NM*NC*
         Zeta[3])/135 - (1580286544*CF*NC*NL*Zeta[3])/45 + 
       (900339600885051206408650108*CF*NC*NH*Zeta[3])/3752365882424978025 + 
       CA*CF*NC*
        (227521620641376892724994696093125685316589503960711784902308899/
          74892547979880045928846368888796923699720000000 + 
         (30858927*lm^2)/10 - (35701878305523276099338885893*Pi^2)/
          21148519392000 + (25395202917009591845018140853*Pi^3)/
          (2289443503730226592320*Sqrt[3]) + (90123511*Pi^4)/360 + 
         lm*(41088784151979821/3689185500 - (101728*Pi^2)/15) - 
         (35708100068138860198358684403668173*Im[PolyLog[2, (-1)^(1/3)]])/
          (401053265765942443309656000*Sqrt[3]) + 
         (126299766*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (25395202917009591845018140853*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(61829106968023094700*Sqrt[3]) + 
         (25395202917009591845018140853*Pi*Log[3]^2)/(2967797134465108545600*
           Sqrt[3]) - (56663599731034569562858039028239577*PolyGamma[2, 1])/
          60037854118799648400 + (621595760960570473709010276879634346*
           Zeta[3])/751223649661480600605) + 
       CF*Log[x]*((1667604216207959197696939541590507079*NM*NC)/
          46516208310366795000 - (3080715784724*lm*NM*NC)/225225 - 
         2372112*lm^2*NM*NC - (23639715593678951087*NC*NL)/365229364500 - 
         (3080715784724*lm*NC*NL)/225225 - 2372112*lm^2*NC*NL - 
         (19147467058327907033177810393159428568549417203*NC*NH)/
          16563739886549814830508428619964336200 - (3080715784724*lm*NC*NH)/
          225225 - 2372112*lm^2*NC*NH + 4294252721782704*NM*NC*Pi^2 - 
         (789810344*NC*NL*Pi^2)/135 + (3635510303398339192600384*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*(174952822938953000308177987645752341360062772161287523/
            7460027046123591282744104520616800000 - (7550327424372*lm)/
            25025 - 64047024*lm^2 + (2935175574283189226809*Pi^2)/1081080 + 
           (25395202917009591845018140853*Im[PolyLog[2, (-1)^(1/3)]])/
            (92743660452034642050*Sqrt[3]) - 18976896*Zeta[3]) + 
         CA*NC*(-240560130150168465432831707641664036478335400208886161/
            20515074376839876027546287431696200000 + (1880340844762*lm)/
            20475 + 13046616*lm^2 - (14675877821603442942451*Pi^2)/10810800 - 
           (25395202917009591845018140853*Im[PolyLog[2, (-1)^(1/3)]])/
            (185487320904069284100*Sqrt[3]) + 9488448*Zeta[3])), 
      (3418492964241452042433838679214834766759899653808581797377949036689749\
3*CF^2*NC)/1186979320880890417727703138409406024462011975680000000 - 
       (1705235566208065039*CF^2*lm*NC)/230861030400 - 
       (147486339*CF^2*lm^2*NC)/16 + 
       (63071158852686686678332737071120785260200418280034953*CF*NM*NC)/
        3544227521490130428410747171481600000 - 
       (3951513745506017839*CF*lm*NM*NC)/6233247820800 - 
       (5462457*CF*lm^2*NM*NC)/16 + (45142342172686211490544193*CF*NC*NL)/
        2526989832791424000 - (3951513745506017839*CF*lm*NC*NL)/
        6233247820800 - (5462457*CF*lm^2*NC*NL)/16 + 
       (869824917617546123626194431145353351651814769256691575379545353*CF*NC*
         NH)/2296188373270299119125065207555494472386220699187200000 - 
       (3951513745506017839*CF*lm*NC*NH)/6233247820800 - 
       (5462457*CF*lm^2*NC*NH)/16 - (940405692586307251363815442463339*CF^2*
         NC*Pi^2)/60400171383552000 + (51153*CF^2*lm*NC*Pi^2)/8 - 
       (10805522432464115052797*CF*NM*NC*Pi^2)/1081080 + 
       (17051*CF*lm*NM*NC*Pi^2)/72 - (24205794619189*CF*NC*NL*Pi^2)/
        25945920 + (17051*CF*lm*NC*NL*Pi^2)/72 + (17051*CF*lm*NC*NH*Pi^2)/
        72 - (85654903486012082890266589973*CF^2*NC*Pi^3)/
        (5494664408952543821568*Sqrt[3]) - (33283797489144095512309775*CF*NC*
         NH*Pi^3)/(600378541187996484*Sqrt[3]) - (1412997347*CF^2*NC*Pi^4)/
        4320 + (126244009803073619437943663184116519*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1925055675676523727886348800*Sqrt[3]) + 
       (2462817994238026232711038037887*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (6009789197291844804840*Sqrt[3]) - 
       (71841337*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (85654903486012082890266589973*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(148389856723255427280*
         Sqrt[3]) - (3803862570187896629978260*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (85654903486012082890266589973*CF^2*NC*Pi*Log[3]^2)/
        (7122713122716260509440*Sqrt[3]) - (950965642546974157494565*CF*NC*
         NH*Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) + 
       CF*((-940875900237205588003151563923820577*CF*NC)/
          5035864289103648000 - 506832526*CF*lm*NC + 
         CA*(940875898714341668663682835541209871/10071728578207296000 + 
           (2787578893*lm)/27)*NC - (3017026516389376547965392857617*NM*NC)/
          25154167278240 - (506832526*lm*NM*NC)/27 - (13780849213*NC*NL)/
          630 - (506832526*lm*NC*NL)/27 - (4228833551715617783033*NC*NH)/
          779779185625440 - (506832526*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-816455012952501150628095*CA + 
          8*(204113760995128522140069*CF + 100100*(1299200509567916847*NM - 
              506832526*NL)))*Log[x]^3)/32432400 - 
       (33465845963873234359401596702561965003*CF^2*NC*PolyGamma[2, 1])/
        3782384809484377849200 - (626752328461382102597*CF*NM*NC*
         PolyGamma[2, 1])/113400 - (18190134404536802530320201269*CF*NC*NH*
         PolyGamma[2, 1])/540340687069196835600 + 
       CA*CF*NC*(-44440408591120421381004953480030423722792067353409161563155\
6214743484209/30861462342903150860920281598644556636012311367680000000 + 
         (60087027*lm^2)/32 + (3687865461477503795769279839093*Pi^2)/
          473726834380800 + (85654903486012082890266589973*Pi^3)/
          (10989328817905087643136*Sqrt[3]) + (1414634243*Pi^4)/8640 + 
         lm*(6659944851645176239/1133317785600 - (187561*Pi^2)/144) - 
         (126244009803073619437943663184116519*Im[PolyLog[2, (-1)^(1/3)]])/
          (3850111351353047455772697600*Sqrt[3]) + 
         (71841337*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (85654903486012082890266589973*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(296779713446510854560*Sqrt[3]) + 
         (85654903486012082890266589973*Pi*Log[3]^2)/(14245426245432521018880*
           Sqrt[3]) + (33465845963873234359401596702561965003*
           PolyGamma[2, 1])/7564769618968755698400 - 
         (8089873581814278427426288994052437635489*Zeta[3])/
          2163524111025064129742400) + 
       (8089873623582218078478596406313924574197*CF^2*NC*Zeta[3])/
        1081762055512532064871200 + (282688033651952666953*CF*NM*NC*Zeta[3])/
        56700 - (1173936071*CF*NC*NL*Zeta[3])/54 - 
       (2223711277797803699167709069*CF*NC*NH*Zeta[3])/
        270170343534598417800 + CF*Log[x]*
        ((-315015897003625863278938558123213546735513*NM*NC)/
          4506639112974928273344000 - (33189943403371*lm*NM*NC)/4324320 - 
         1482570*lm^2*NM*NC - (132785865659859119789*NC*NL)/3506201899200 - 
         (33189943403371*lm*NC*NL)/4324320 - 1482570*lm^2*NC*NL - 
         (585949474916728887039981705361703786405083599667*NC*NH)/
          1445562753735256567026190134105978432000 - 
         (33189943403371*lm*NC*NH)/4324320 - 1482570*lm^2*NC*NH - 
         (433066836852948235*NM*NC*Pi^2)/54 - (293445653*NC*NL*Pi^2)/81 + 
         (3803862570187896629978260*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CF*NC*(-4002104972137611866940462506791311099062858215256954668597/
            37643296474739641612726751411032372800000 - (26422663684171*lm)/
            160160 - 40029390*lm^2 - (1632910030956447182962261*Pi^2)/
            129729600 + (85654903486012082890266589973*
             Im[PolyLog[2, (-1)^(1/3)]])/(445169570169766281840*Sqrt[3]) - 
           11860560*Zeta[3]) + CA*NC*
          (352185237885555796004635289062073204476417035822942290548291/
            6625220179554176923839908248341697612800000 + (41349534260971*lm)/
            786240 + 8154135*lm^2 + (326582006347059290888737*Pi^2)/
            51891840 - (85654903486012082890266589973*
             Im[PolyLog[2, (-1)^(1/3)]])/(890339140339532563680*Sqrt[3]) + 
           5930280*Zeta[3])), (-646233198913994969363589143816899564733712132\
5898919239267093432278372501*CF^2*NC)/
        86797862839415111796338291996187815538784625721600000000 - 
       (5578763782274059061*CF^2*lm*NC)/192384192000 - 
       (905614803*CF^2*lm^2*NC)/40 - 
       (71976302917262464938989341156590035312551037799669671*CF*NM*NC)/
        606456709232755651083616738231296000 - 
       (10176393602592794261*CF*lm*NM*NC)/5194373184000 - 
       (33541289*CF*lm^2*NM*NC)/40 + (201939024864713830294634399*CF*NC*NL)/
        4211649721319040000 - (10176393602592794261*CF*lm*NC*NL)/
        5194373184000 - (33541289*CF*lm^2*NC*NL)/40 + 
       (5547506901056780646250900620208763169014428371363985528159598497*CF*
         NC*NH)/3039072846975395892959645127646977978158233278336000000 - 
       (10176393602592794261*CF*lm*NC*NH)/5194373184000 - 
       (33541289*CF*lm^2*NC*NH)/40 + (55607050926483619199471223794683489*
         CF^2*NC*Pi^2)/1389203941821696000 + (938961*CF^2*lm*NC*Pi^2)/20 + 
       (1000744274010160609929061*CF*NM*NC*Pi^2)/16216200 + 
       (104329*CF*lm*NM*NC*Pi^2)/60 - (52708681813691*CF*NC*NL*Pi^2)/
        21621600 + (104329*CF*lm*NC*NL*Pi^2)/60 + (104329*CF*lm*NC*NH*Pi^2)/
        60 - (700520255752161483683033959001*CF^2*NC*Pi^3)/
        (19019992184835728613120*Sqrt[3]) - (717047896167453135981601745*CF*
         NC*NH*Pi^3)/(2701703435345984178*Sqrt[3]) - 
       (17194533227*CF^2*NC*Pi^4)/21600 + 
       (1956074859051138365599393369906987139*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(6663654261957197519606592000*Sqrt[3]) + 
       (174739668888997582983433981486061*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(135220256939066508108900*Sqrt[3]) - 
       (795622321*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (700520255752161483683033959001*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(513657196349730325200*
         Sqrt[3]) - (163896661981132145367223256*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (700520255752161483683033959001*CF^2*NC*Pi*Log[3]^2)/
        (24655545424787055609600*Sqrt[3]) - (20487082747641518170902907*CF*NC*
         NH*Pi*Log[3]^2)/(100063090197999414*Sqrt[3]) + 
       CF*((12094533507963196223706488160195630283*CF*NC)/
          25179321445518240000 - (6922958484*CF*lm*NC)/5 + 
         CA*(-12094533536542883240670214479036701503/50358642891036480000 + 
           (12692090554*lm)/45)*NC + (5174432330378849754649331722871*NM*NC)/
          6987268688400 - (2307652828*lm*NM*NC)/45 - (43809637619*NC*NL)/
          675 - (2307652828*lm*NC*NL)/45 - (179920056431058714457*NC*NH)/
          12741489961200 - (2307652828*lm*NC*NH)/45)*Log[x]^2 + 
       (CF*NC*(-1050570593418860474113713*CA + 
          16*(131321318652792175787219*CF + 30030*(6789141169373103387*NM + 
              1153826414*NL)))*Log[x]^3)/16216200 + 
       (440075601765912104195492278793890835279*CF^2*NC*PolyGamma[2, 1])/
        19452264734491086081600 + (97469690036234348659*CF*NM*NC*
         PolyGamma[2, 1])/2700 - (48869207560874963889771046343*CF*NC*NH*
         PolyGamma[2, 1])/486306618362277152040 - 
       (95112179898161926393913004981328392305047*CF^2*NC*Zeta[3])/
        4867929249806394291920400 - (38313132826343587871*CF*NM*NC*Zeta[3])/
        1350 - (2646617749*CF*NC*NL*Zeta[3])/45 + 
       (97263466622627019053490604801*CF*NC*NH*Zeta[3])/
        243153309181138576020 + CA*CF*NC*(64623319820141319842886808539897381\
43308941371146844001452813876063633751/
          173595725678830223592676583992375631077569251443200000000 + 
         (368954179*lm^2)/80 - (2495044237515131486507859022511*Pi^2)/
          124664956416000 + (700520255752161483683033959001*Pi^3)/
          (38039984369671457226240*Sqrt[3]) + (17254626731*Pi^4)/43200 + 
         lm*(15719947261541699861/944431488000 - (1147619*Pi^2)/120) - 
         (1956074859051138365599393369906987139*Im[PolyLog[2, (-1)^(1/3)]])/
          (13327308523914395039213184000*Sqrt[3]) + 
         (795622321*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (700520255752161483683033959001*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1027314392699460650400*Sqrt[3]) + 
         (700520255752161483683033959001*Pi*Log[3]^2)/
          (49311090849574111219200*Sqrt[3]) - 
         (440075601765912104195492278793890835279*PolyGamma[2, 1])/
          38904529468982172163200 + (2717490867573240578174175367119526384601*
           Zeta[3])/278167385703222530966880) + 
       CF*Log[x]*((38181421392123999574246171035711810222629*NM*NC)/
          92994140426466773894400 - (78356429457209*lm*NM*NC)/3603600 - 
         3755844*lm^2*NM*NC - (39349161190527376577*NC*NL)/365229364500 - 
         (78356429457209*lm*NC*NL)/3603600 - 3755844*lm^2*NC*NL - 
         (3124508988312459103438388952366697879828625027501*NC*NH)/
          1618899464024778282076841892268007520000 - 
         (78356429457209*lm*NC*NH)/3603600 - 3755844*lm^2*NC*NH + 
         (150869803773550997*NM*NC*Pi^2)/3 - (1322839394*NC*NL*Pi^2)/135 + 
         (163896661981132145367223256*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CF*NC*(5801123550145270138432782567171827752998298207336308899822981/
            21295350577138425826628276512526885184000000 - 
           (192209850150027*lm)/400400 - 101407788*lm^2 + 
           (4202282360527162451122861*Pi^2)/129729600 + 
           (700520255752161483683033959001*Im[PolyLog[2, (-1)^(1/3)]])/
            (1540971589049190975600*Sqrt[3]) - 30046752*Zeta[3]) + 
         CA*NC*(-369162407434616583411549986020641487017558280457284402350864\
7/27103173461812541961163261015943308416000000 + (95582232378809*lm)/655200 + 
           20657142*lm^2 - (22234298193278628485233*Pi^2)/1372800 - 
           (700520255752161483683033959001*Im[PolyLog[2, (-1)^(1/3)]])/
            (3081943178098381951200*Sqrt[3]) + 15023376*Zeta[3])), 
      (7227990587412727792924315615234413806399722027141911773720593605911052\
19574521*CF^2*NC)/
        2080876555807491840185568708477790798398620465932646400000000 - 
       (3646759531793601786071*CF^2*lm*NC)/333594188928000 - 
       (1090629279*CF^2*lm^2*NC)/80 + 
       (255055998713946481043833910945442045229861109333884432970657*CF*NM*
         NC)/1161446903019837231520630258841691801600000 - 
       (8447262452094680977271*CF*lm*NM*NC)/9007043101056000 - 
       (40393677*CF*lm^2*NM*NC)/80 + (27568335836643399226255448143*CF*NC*
         NL)/912875077095901920000 - (8447262452094680977271*CF*lm*NC*NL)/
        9007043101056000 - (40393677*CF*lm^2*NC*NL)/80 + 
       (34492222717098920919314293245906755930524144079340956205890903*CF*NC*
         NH)/55463487277060365196257613709069914791937698048000000 - 
       (8447262452094680977271*CF*lm*NC*NH)/9007043101056000 - 
       (40393677*CF*lm^2*NC*NH)/80 - (1077034906554600299034601775002793447*
         CF^2*NC*Pi^2)/5904116752742208000 + (358473*CF^2*lm*NC*Pi^2)/40 - 
       (1367140741671394451218298*CF*NM*NC*Pi^2)/11486475 + 
       (119491*CF*lm*NM*NC*Pi^2)/360 - (3216797218043413*CF*NC*NL*Pi^2)/
        2205403200 + (119491*CF*lm*NC*NL*Pi^2)/360 + 
       (119491*CF*lm*NC*NH*Pi^2)/360 - (10646104397490572650768357858201*
         CF^2*NC*Pi^3)/(420341827284869602349952*Sqrt[3]) - 
       (54780479509300987667394295*CF*NC*NH*Pi^3)/(600378541187996484*
         Sqrt[3]) - (5589112523*CF^2*NC*Pi^4)/10800 + 
       (270478200064982455388570211208738721339*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2503534906217319108116196614400*
         Sqrt[3]) + (2228948359532253167104416789883*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3338771776273247113800*Sqrt[3]) - 
       55819853*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (10646104397490572650768357858201*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11351824039329040186920*
         Sqrt[3]) - (6260626229634398590559348*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (10646104397490572650768357858201*CF^2*NC*Pi*Log[3]^2)/
        (544887553887793928972160*Sqrt[3]) - (1565156557408599647639837*CF*NC*
         NH*Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) - 
       (CF*NC*(-(CA*(7261907861037440048560113272036028205111 + 
             1141938315379736987984503632000*lm)) + 
          11*(CF*(1320346884129913520027727987108514649887 + 
              509625363888477664059199968000*lm) + 
            154700*((5568642568996453030247414481767063 + 
                122010429717847605654720*lm)*NM + 23*(5794080445296*
                 (1064549793 + 915555340*lm)*NL + 5*(318475799185300692547 + 
                  1060960258416066136128*lm)*NH))))*Log[x]^2)/
        6634751200894056240000 + (CF*NC*(163556111514087527324271843*CA - 
          136*(2405236947716064261080007*CF + 20020*(77881948321920363927*
               NM - 4224633926*NL)))*Log[x]^3)/551350800 - 
       (14230727831684088260244211565262582529333*CF^2*NC*PolyGamma[2, 1])/
        136165853141437602571200 - (7564778544430191201839*CF*NM*NC*
         PolyGamma[2, 1])/113400 - (206508071273750165049536801741*CF*NC*NH*
         PolyGamma[2, 1])/3782384809484377849200 + 
       CA*CF*NC*(-12215304094835648332448299820210561553468651498612806999167\
0312208964676110588049/
          703336275862932241982722223465493289858733717485234483200000000 + 
         (444330447*lm^2)/160 + (821536923393180581623458827616737*Pi^2)/
          9007043101056000 + (10646104397490572650768357858201*Pi^3)/
          (840683654569739204699904*Sqrt[3]) + (5594848091*Pi^4)/21600 + 
         lm*(14235428652649092250871/1637644200192000 - (1314401*Pi^2)/720) - 
         (270478200064982455388570211208738721339*Im[PolyLog[2, (-1)^(1/3)]])/
          (5007069812434638216232393228800*Sqrt[3]) + 
         (55819853*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (10646104397490572650768357858201*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(22703648078658080373840*Sqrt[3]) + 
         (10646104397490572650768357858201*Pi*Log[3]^2)/
          (1089775107775587857944320*Sqrt[3]) + 
         (14230727831684088260244211565262582529333*PolyGamma[2, 1])/
          272331706282875205142400 - 
         (14502890526916846721440211168939156569258541*Zeta[3])/
          331019188986834811850587200) + 
       (14502890537398888244774526391581983505637313*CF^2*NC*Zeta[3])/
        165509594493417405925293600 + (3338694229622495975671*CF*NM*NC*
         Zeta[3])/56700 - (9703027711*CF*NC*NL*Zeta[3])/270 - 
       (13591744238530909912074746261*CF*NC*NH*Zeta[3])/
        1891192404742188924600 + CF*Log[x]*
        ((-45854857415371745121441651147120587893417220521*NM*NC)/
          56301442438395778918886592000 - (4432979402428867*lm*NM*NC)/
          367567200 - 2319786*lm^2*NM*NC - (18593922788610001705883*NC*NL)/
          298027161432000 - (4432979402428867*lm*NC*NL)/367567200 - 
         2319786*lm^2*NC*NL - 
         (2305802931288571535367100932347554886027457252583*NC*NH)/
          3456780498062570051584367711992557120000 - 
         (4432979402428867*lm*NC*NH)/367567200 - 2319786*lm^2*NC*NH - 
         (5192129888662243135*NM*NC*Pi^2)/54 - (2425488073*NC*NL*Pi^2)/
          405 + (6260626229634398590559348*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CF*NC*
          (-42528329217650953702800375089672822945714690448211515531528478475\
3/347902142378710462729626153385151723251008000000 - (3532931199775267*lm)/
            13613600 - 62634222*lm^2 - (1460322424875683107564993*Pi^2)/
            9845550 + (10646104397490572650768357858201*
             Im[PolyLog[2, (-1)^(1/3)]])/(34055472117987120560760*Sqrt[3]) - 
           18558288*Zeta[3]) + CA*NC*(148849152281827634370783026237073640240\
8641340068094991256529859873/
            2435314996650973239107383073696062062757056000000 + 
           (5518204986489667*lm)/66830400 + 12758823*lm^2 + 
           (4088902789925340645067391*Pi^2)/55135080 - 
           (10646104397490572650768357858201*Im[PolyLog[2, (-1)^(1/3)]])/
            (68110944235974241121520*Sqrt[3]) + 9279144*Zeta[3])), 
      (-843467322764679862997005073533046025768443053857763132417583964199420\
8285806063*CF^2*NC)/
        9419682266021413955125744064269999417750898002034390400000000 - 
       (1178557342780101421*CF^2*lm*NC)/27799515744 - 
       (132414021*CF^2*lm^2*NC)/4 - 
       (9289797263153252662231177374450709102483697880985020915779*CF*NM*NC)/
        6642261700276846912291186120826668800000 - 
       (2149944392346783169*CF*lm*NM*NC)/750586925088 - 
       (4904223*CF*lm^2*NM*NC)/4 + (1556725910048070945531965087*CF*NC*NL)/
        19474668311379240960 - (2149944392346783169*CF*lm*NC*NL)/
        750586925088 - (4904223*CF*lm^2*NC*NL)/4 + 
       (6764064709438732924697939121193671908014030176636663856898972473*CF*
         NC*NH)/2279304635231546919719733845735233483618674958752000000 - 
       (2149944392346783169*CF*lm*NC*NH)/750586925088 - 
       (4904223*CF*lm^2*NC*NH)/4 + (629554315318271096366304666097873*CF^2*
         NC*Pi^2)/1345667635952640 + 64980*CF^2*lm*NC*Pi^2 + 
       (39176728629825940724187829*CF*NM*NC*Pi^2)/55135080 + 
       (7220*CF*lm*NM*NC*Pi^2)/3 - (6915454396133*CF*NC*NL*Pi^2)/1837836 + 
       (7220*CF*lm*NC*NL*Pi^2)/3 + (7220*CF*lm*NC*NH*Pi^2)/3 - 
       (374873629574844518021560171895789*CF^2*NC*Pi^3)/
        (6305127409273044035249280*Sqrt[3]) - 
       (6990772857269965400959318465*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) - (4457035523*CF^2*NC*Pi^4)/3600 + 
       (17708308379878815555228846210718150217707*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(37553023593259786621742949216000*
         Sqrt[3]) + (85498584205488004265362573407173*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40566077081719952432670*Sqrt[3]) - 
       (611328363*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (374873629574844518021560171895789*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(170277360589935602803800*
         Sqrt[3]) - (798945469402281760109636396*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (374873629574844518021560171895789*CF^2*NC*Pi*Log[3]^2)/
        (8173313308316908934582400*Sqrt[3]) - 
       (199736367350570440027409099*CF*NC*NH*Pi*Log[3]^2)/
        (600378541187996484*Sqrt[3]) + 
       CF*((12415952155404263154285550264757507370317*CF*NC)/
          2211583733631352080000 - 2272068564*CF*lm*NC + 
         CA*(-12415952159530691552660859926942247392177/
            4423167467262704160000 + (4165459034*lm)/9)*NC + 
         (46173261417972713968436368394203*NM*NC)/5415133233510 - 
         (757356188*lm*NM*NC)/9 - (14360892664*NC*NL)/135 - 
         (757356188*lm*NC*NL)/9 - (649999413356193732959*NC*NH)/
          27075666167550 - (757356188*lm*NC*NH)/9)*Log[x]^2 + 
       (4*CF*NC*(-2186841464524065158601377*CA + 4373682901915003606639064*
           CF + 850850*(7854470303941190382*NM + 189339047*NL))*Log[x]^3)/
        11486475 + (2596990401538269867829855219070336933359*CF^2*NC*
         PolyGamma[2, 1])/9726132367245543040800 + 
       (281464230135454355842*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (65469177996029930090614912843*CF*NC*NH*PolyGamma[2, 1])/
        405255515301897626700 - (4706945832686079716035691341870048084017917*
         CF^2*NC*Zeta[3])/20688699311677175740661700 - 
       (222518569690934550166*CF*NM*NC*Zeta[3])/675 - 
       (862006478*CF*NC*NL*Zeta[3])/9 + (131405970860949858083418142157*CF*
         NC*NH*Zeta[3])/202627757650948813350 + 
       CA*CF*NC*(168693464527447581820409981989528759995723687637123756268180\
14246223762676670501/
          37678729064085655820502976257079997671003592008137561600000000 + 
         (53946453*lm^2)/8 - (573480651598895882065130829392791*Pi^2)/
          2451621199104000 + (374873629574844518021560171895789*Pi^3)/
          (12610254818546088070498560*Sqrt[3]) + (4470897923*Pi^4)/7200 + 
         lm*(3321186193738188913/136470350016 - (39710*Pi^2)/3) - 
         (17708308379878815555228846210718150217707*
           Im[PolyLog[2, (-1)^(1/3)]])/(75106047186519573243485898432000*
           Sqrt[3]) + (611328363*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (374873629574844518021560171895789*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(340554721179871205607600*Sqrt[3]) + 
         (374873629574844518021560171895789*Pi*Log[3]^2)/
          (16346626616633817869164800*Sqrt[3]) - 
         (2596990401538269867829855219070336933359*PolyGamma[2, 1])/
          19452264734491086081600 + 
         (168105208424943369841247612274767748192047*Zeta[3])/
          1477764236548369695761550) + CF*Log[x]*
        ((7274869074351459152052566987556501489063754609*NM*NC)/
          1563928956622104969969072000 - (25802907961037*lm*NM*NC)/765765 - 
         5799465*lm^2*NM*NC - (6933560478300723116011*NC*NL)/
          39736954857600 - (25802907961037*lm*NC*NL)/765765 - 
         5799465*lm^2*NC*NL - 
         (1682886108443258907669915159049830539004012122694203*NC*NH)/
          536665172324214000508473087286844492880000 - 
         (25802907961037*lm*NC*NH)/765765 - 5799465*lm^2*NC*NH + 
         (1745437845339470863*NM*NC*Pi^2)/3 - (430873279*NC*NL*Pi^2)/27 + 
         (798945469402281760109636396*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*
          (877980486224828923467575310915063613267190022454961635886585594999/
            280997884228958450666236508503391776471968000000 - 
           (126690941433297*lm)/170170 - 156585555*lm^2 + 
           (139957853668226538541179637*Pi^2)/367567200 + 
           (374873629574844518021560171895789*Im[PolyLog[2, (-1)^(1/3)]])/
            (510832081769806808411400*Sqrt[3]) - 46395720*Zeta[3]) + 
         CA*NC*
          (-11413746319620592765431841924737885306823339252286470547218394700\
287/7305944989952919717322149221088186188271168000000 + (31455124544687*lm)/
            139230 + (63794115*lm^2)/2 - (19993979094146924192518547*Pi^2)/
            105019200 - (374873629574844518021560171895789*
             Im[PolyLog[2, (-1)^(1/3)]])/(1021664163539613616822800*
             Sqrt[3]) + 23197860*Zeta[3])), 
      (4514588827384832407837131747569727171883407707068770809009911765131026\
39472967483*CF^2*NC)/
        109558150663264445385770192501355685535687367531353832960000000 - 
       (95133308526379681169*CF^2*lm*NC)/6004695400704 - 
       (157973049*CF^2*lm^2*NC)/8 + 
       (53970767359677703106966312299465223353946610361202267235878137*CF*NM*
         NC)/20325320802847151551611029529729606528000000 - 
       (220293175016270409665*CF*lm*NM*NC)/162126775819008 - 
       (17552561*CF*lm^2*NM*NC)/24 + (1158711217708696454152604047*CF*NC*
         NL)/23369601973655089152 - (220293175016270409665*CF*lm*NC*NL)/
        162126775819008 - (17552561*CF*lm^2*NC*NL)/24 + 
       (4164265222787183684774103904667680892563028844938579732367794120041*
         CF*NC*NH)/
        4184803310285120144605431340769888675923887224268672000000 - 
       (220293175016270409665*CF*lm*NC*NH)/162126775819008 - 
       (17552561*CF*lm^2*NC*NH)/24 - (2299713039735754861478087668018939399*
         CF^2*NC*Pi^2)/1089990785121638400 + (74005*CF^2*lm*NC*Pi^2)/6 - 
       (115449052485337921530848351*CF*NM*NC*Pi^2)/82702620 + 
       (74005*CF*lm*NM*NC*Pi^2)/162 - (21048129585715*CF*NC*NL*Pi^2)/
        9451728 + (74005*CF*lm*NC*NL*Pi^2)/162 + (74005*CF*lm*NC*NH*Pi^2)/
        162 - (209988211239876262515375419104963*CF^2*NC*Pi^3)/
        (5238105847703759660053248*Sqrt[3]) - 
       (64045767739186151695253937005*CF*NC*NH*Pi^3)/(437675956526049436836*
         Sqrt[3]) - (10348376467*CF^2*NC*Pi^4)/12960 + 
       (22088318528908039158781426544177431537*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(127338353157678397335894458880*
         Sqrt[3]) + (1162642054693997754951105311746621*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1095284081206438715682090*Sqrt[3]) - 
       (508535209*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (29998315891410894645053631300709*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(20208741696387961651440*
         Sqrt[3]) - (7319516313049845908029021372*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (29998315891410894645053631300709*CF^2*NC*Pi*Log[3]^2)/
        (970019601426622159269120*Sqrt[3]) - (1829879078262461477007255343*CF*
         NC*NH*Pi*Log[3]^2)/(16210220612075905068*Sqrt[3]) - 
       (CF*NC*(-(CA*(201575597229383795937807555596134167925663 + 
             4444362030176021998028432448000*lm)) + 
          182*(7*CF*(316445207591722924852888688047520434399 + 
              17125413845404965598225728000*lm) + 
            44880*(7*(4665153713837755215670702034482499 + 
                14132677960491323032800*lm)*NM + 666319251209040*(
                172300383 + 148470490*lm)*NL + (30736689910743526170541 + 
                98928745723439261229600*lm)*NH)))*Log[x]^2)/
        15923402882145734976000 + (CF*NC*(95077918167370326853518677*CA - 
          104*(1828421504749669005052059*CF + 13090*(91900712955958807137*
               NM - 685085261*NL)))*Log[x]^3)/27567540 - 
       (13434096780078076150889395984373270322632987*CF^2*NC*PolyGamma[2, 1])/
        11029434104456445808267200 - (179529742303869055508561*CF*NM*NC*
         PolyGamma[2, 1])/226800 - (34029702279570980650449005839957*CF*NC*
         NH*PolyGamma[2, 1])/393908360873444493152400 + 
       CA*CF*NC*(-29344827378688887516175896246904087570554134268651917447739\
91581766478370179142827/
          1424255958622437790015012502517623911963935777907599828480000000 + 
         (193078171*lm^2)/48 + (121037528407351040901168711656375773*Pi^2)/
          114735872118067200 + (209988211239876262515375419104963*Pi^3)/
          (10476211695407519320106496*Sqrt[3]) + (383624041*Pi^4)/960 + 
         lm*(371203636047143441153/29477595603456 - (814055*Pi^2)/324) - 
         (22088318528908039158781426544177431537*Im[PolyLog[2, (-1)^(1/3)]])/
          (254676706315356794671788917760*Sqrt[3]) + 
         (508535209*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (29998315891410894645053631300709*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(40417483392775923302880*Sqrt[3]) + 
         (29998315891410894645053631300709*Pi*Log[3]^2)/
          (1940039202853244318538240*Sqrt[3]) + 
         (13434096780078076150889395984373270322632987*PolyGamma[2, 1])/
          22058868208912891616534400 - 
         (130564726938310158104484392340611057917473107*Zeta[3])/
          257813022191669420768245800) + 
       (261129453902725515968018046219403728326797219*CF^2*NC*Zeta[3])/
        257813022191669420768245800 + (77792254001810468283439*CF*NM*NC*
         Zeta[3])/113400 - (520566959*CF*NC*NL*Zeta[3])/9 - 
       (537959528753944472528955881557*CF*NC*NH*Zeta[3])/
        196954180436722246576200 + CF*Log[x]*
        ((-101391882385871671670861565825792708383164557071*NM*NC)/
          10827200468922265176708960000 - (1019764087412897*lm*NM*NC)/
          55135080 - (7088235*lm^2*NM*NC)/2 - (2652018409917079648267*NC*
           NL)/26491303238400 - (1019764087412897*lm*NC*NL)/55135080 - 
         (7088235*lm^2*NC*NL)/2 - 
         (30996458485540784160557538813275319880756089890804339*NC*NH)/
          28979919305507556027457546713489602615520000 - 
         (1019764087412897*lm*NC*NH)/55135080 - (7088235*lm^2*NC*NH)/2 - 
         (3403730109526728445*NM*NC*Pi^2)/3 - (1561552867*NC*NL*Pi^2)/162 + 
         (7319516313049845908029021372*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4052555153018976267*Sqrt[3]) + 
         CF*NC*
          (-42164028134783650828393210409317102115346355976921786149647059720\
903/3034777149672751267195354291836631185897254400000 - (813503040971447*lm)/
            2042040 - (191382345*lm^2)/2 - (19503162702202247007399223*Pi^2)/
            11309760 + (29998315891410894645053631300709*
             Im[PolyLog[2, (-1)^(1/3)]])/(60626225089163884954320*Sqrt[3]) - 
           28352940*Zeta[3]) + CA*NC*(548132365762428139830868461887718860919\
743711697753172921723070298539/
            78904205891491532947079211587752410833328614400000 + 
           (1268461617093497*lm)/10024560 + (77970585*lm^2)/4 + 
           (19503162702382698384078247*Pi^2)/22619520 - 
           (29998315891410894645053631300709*Im[PolyLog[2, (-1)^(1/3)]])/
            (121252450178327769908640*Sqrt[3]) + 14176470*Zeta[3])), 
      (-489864287823166469804846311073405212115910591649542817739427940024965\
368541561397*CF^2*NC)/
        46242076578650577597890016315507269868958953828168825600000000 - 
       (6206450146671332957*CF^2*lm*NC)/102120670080 - 
       (189845397*CF^2*lm^2*NC)/4 - 
       (291497684368585628689193760594762314308376079353912555730743*CF*NM*
         NC)/17923563318207364683960343500643392000000 - 
       (11322500756555066477*CF*lm*NM*NC)/2757258092160 - 
       (7031311*CF*lm^2*NM*NC)/4 + (15324667511183288497519273699*CF*NC*NL)/
        118239057604802534400 - (11322500756555066477*CF*lm*NC*NL)/
        2757258092160 - (7031311*CF*lm^2*NC*NL)/4 + 
       (498918227006655498358721003837712902435738840125700244479986104930641\
531*CF*NC*NH)/
        105986421037936095342349456852008585550786329785440521408000000 - 
       (11322500756555066477*CF*lm*NC*NH)/2757258092160 - 
       (7031311*CF*lm^2*NC*NH)/4 + (1092718360241487204357435190966007581*
         CF^2*NC*Pi^2)/202426860094018560 + 88445*CF^2*lm*NC*Pi^2 + 
       (21247217359430870356167097*CF*NM*NC*Pi^2)/2625480 + 
       (88445*CF*lm*NM*NC*Pi^2)/27 - (8946629765713*CF*NC*NL*Pi^2)/
        1575288 + (88445*CF*lm*NC*NL*Pi^2)/27 + (88445*CF*lm*NC*NH*Pi^2)/
        27 - (15934516221991751370851992227053653*CF^2*NC*Pi^3)/
        (170238440050372188951730560*Sqrt[3]) - 
       (299291847282892334736265401575*CF*NC*NH*Pi^3)/(437675956526049436836*
         Sqrt[3]) - (20318346559*CF^2*NC*Pi^4)/10800 + 
       (107195475310278877430126077326475443126257*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(144847376716859176969579946976000*
         Sqrt[3]) + (12496511635269161770121473530340879*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3723965876101891633319106*Sqrt[3]) - 
       (2757031879*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (2276359460284535910121713175293379*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(656784105132608753671800*
         Sqrt[3]) - (34204782546616266827001760180*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (2276359460284535910121713175293379*CF^2*NC*Pi*Log[3]^2)/
        (31525637046365220176246400*Sqrt[3]) - 
       (8551195636654066706750440045*CF*NC*NH*Pi*Log[3]^2)/
        (16210220612075905068*Sqrt[3]) + 
       CF*((61397112859312745628152037719974556162203*CF*NC)/
          947821600127722320000 - 3632986770*CF*lm*NC + 
         CA*(-61397112862144992382770036142728263927743/
            1895643200255444640000 + (6660475745*lm)/9)*NC + 
         (500834733207017651813347567827391*NM*NC)/5157269746200 - 
         (1210995590*lm*NM*NC)/9 - (4587785657*NC*NL)/27 - 
         (1210995590*lm*NC*NL)/9 - (52939441008701492138867*NC*NH)/
          1335732864265800 - (1210995590*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-86962080799748611032670629*CA + 
          44*(3952821850972958651973097*CF + 232050*(25672418753970453012*
               NM + 86499685*NL)))*Log[x]^3)/9845550 + 
       (2448677700361842586202262161649484855916381*CF^2*NC*PolyGamma[2, 1])/
        787816721746888986304800 + (953430506572284439787*CF*NM*NC*
         PolyGamma[2, 1])/200 - (49946431146615536647401783005033*CF*NC*NH*
         PolyGamma[2, 1])/196954180436722246576200 - 
       (626327899376016312925633647301005780655523773*CF^2*NC*Zeta[3])/
        239397806320835890713371100 - (1133195841703696402039*CF*NM*NC*
         Zeta[3])/300 - (1368958360*CF*NC*NL*Zeta[3])/9 + 
       (100983909892718784058643094525367*CF*NC*NH*Zeta[3])/
        98477090218361123288100 + CA*CF*NC*(269425358297216726676136475920613\
6239172078777258645731472478878105429107641731371/
          508662842365156353576790179470579968558548492109857081600000000 + 
         (77344421*lm^2)/8 - (1437787316104976368015402670700793303*Pi^2)/
          532702263405312000 + (15934516221991751370851992227053653*Pi^3)/
          (340476880100744377903461120*Sqrt[3]) + (6791650453*Pi^4)/7200 + 
         lm*(17491135941678037037/501319653120 - (972895*Pi^2)/54) - 
         (107195475310278877430126077326475443126257*
           Im[PolyLog[2, (-1)^(1/3)]])/(289694753433718353939159893952000*
           Sqrt[3]) + (2757031879*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (2276359460284535910121713175293379*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1313568210265217507343600*
           Sqrt[3]) + (2276359460284535910121713175293379*Pi*Log[3]^2)/
          (63051274092730440352492800*Sqrt[3]) - 
         (2448677700361842586202262161649484855916381*PolyGamma[2, 1])/
          1575633443493777972609600 + 
         (15658197485868698257455382690395161758952194*Zeta[3])/
          11969890316041794535668555) + CF*Log[x]*
        ((9714981885333742542636596721737478256084333783*NM*NC)/
          186182018645488686901080000 - (13400055271385*lm*NM*NC)/262548 - 
         8756055*lm^2*NM*NC - (532166486483495031221*NC*NL)/1930080664512 - 
         (13400055271385*lm*NC*NL)/262548 - 8756055*lm^2*NC*NL - 
         (3793282296233231846134512589793516399831910631381115927*NC*NH)/
          762952106331535465415180412514755115012440000 - 
         (13400055271385*lm*NC*NH)/262548 - 8756055*lm^2*NC*NH + 
         (59902310426037612239*NM*NC*Pi^2)/9 - (684302290*NC*NL*Pi^2)/27 + 
         (34204782546616266827001760180*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4052555153018976267*Sqrt[3]) + CF*NC*(4992065587090620129029920389\
90096086087443990407236744876374055505997/
            14090036766337773740549859212098644791665824000000 - 
           (10973454725015*lm)/9724 - 236413485*lm^2 + 
           (695696646355865526487012123*Pi^2)/157528800 + 
           (2276359460284535910121713175293379*Im[PolyLog[2, (-1)^(1/3)]])/
            (1970352315397826261015400*Sqrt[3]) - 70048440*Zeta[3]) + 
         CA*NC*(-499206558701213380155180967342282602920722056706801196362731\
336989797/28180073532675547481099718424197289583331648000000 + 
           (16325908561745*lm)/47736 + (96316605*lm^2)/2 - 
           (695696646349616130395058251*Pi^2)/315057600 - 
           (2276359460284535910121713175293379*Im[PolyLog[2, (-1)^(1/3)]])/
            (3940704630795652522030800*Sqrt[3]) + 35024220*Zeta[3])), 
      (1862178640587525884192326601139477731670881262691690440060618493865182\
34168044888981*CF^2*NC)/
        3865837601975188287183605363976407761044968540034913820160000000 - 
       (996839341824293108833*CF^2*lm*NC)/44238674278656 - 
       (224573769*CF^2*lm^2*NC)/8 + 
       (213723249530817606754319831395052989081047881836262058860143687*CF*
         NM*NC)/6775106934282383850537009843243202176000000 - 
       (2307687053963887201297*CF*lm*NM*NC)/1194444205523712 - 
       (8317547*CF*lm^2*NM*NC)/8 + (21873101682484159464214007357609*CF*NC*
         NL)/275806244831387081011200 - (2307687053963887201297*CF*lm*NC*
         NL)/1194444205523712 - (8317547*CF*lm^2*NC*NL)/8 + 
       (157048220611067288198264241766543771404318998613720059592241262447897\
33*CF*NC*NH)/
        10093944860755818604033281604953198623884412360518144896000000 - 
       (2307687053963887201297*CF*lm*NC*NH)/1194444205523712 - 
       (8317547*CF*lm^2*NC*NH)/8 - (309183899290355690521780027547816695637*
         CF^2*NC*Pi^2)/12820367805954508800 + (100205*CF^2*lm*NC*Pi^2)/6 - 
       (50760496628264955639649422689*CF*NM*NC*Pi^2)/3142699560 + 
       (100205*CF*lm*NM*NC*Pi^2)/162 - (597669847929677*CF*NC*NL*Pi^2)/
        179582832 + (100205*CF*lm*NC*NL*Pi^2)/162 + 
       (100205*CF*lm*NC*NH*Pi^2)/162 - (7290466601355992485606806669281663*
         CF^2*NC*Pi^3)/(117619285852984421457559296*Sqrt[3]) - 
       (16724062831787671930453602985*CF*NC*NH*Pi^3)/(72945992754341572806*
         Sqrt[3]) - (15611719627*CF^2*NC*Pi^4)/12960 + 
       (517375954926026498962985174473297102213909*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1901451017992224104946122213030400*
         Sqrt[3]) + (66545838996725908458330972911467*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40302660996773718975315*Sqrt[3]) - 
       (756222929*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (1041495228765141783658115238468809*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(453778109000711502536880*
         Sqrt[3]) - (3822642932980039298389394968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) - (1041495228765141783658115238468809*CF^2*NC*Pi*Log[3]^2)/
        (21781349232034152121770240*Sqrt[3]) - 
       (477830366622504912298674371*CF*NC*NH*Pi*Log[3]^2)/
        (2701703435345984178*Sqrt[3]) + 
       CF*((-6254017322983562862746818503422696200066927*CF*NC)/
          21610332482912068896000 - 2167546600*CF*lm*NC + 
         CA*(6254017322955400080399866901189312404211067/
            43220664965824137792000 + (11921506300*lm)/27)*NC - 
         (125948974653994127524983727971811463*NM*NC)/649815988021200 - 
         (2167546600*lm*NM*NC)/27 - (4185292336*NC*NL)/45 - 
         (2167546600*lm*NC*NL)/27 - (9820291564549149269293*NC*NH)/
          381637961218800 - (2167546600*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(2963966593844052599134955269*CA - 
          304*(19499780225024668192517176*CF + 
            12155*(1069163337110501893287*NM - 1083773300*NL)))*Log[x]^3)/
        74826180 - (463988392890369160320113461908287057369981581*CF^2*NC*
         PolyGamma[2, 1])/33088302313369337424801600 - 
       (699531891113156801581013*CF*NM*NC*PolyGamma[2, 1])/75600 - 
       (1105852808370653613956744190864983*CF*NC*NH*PolyGamma[2, 1])/
        8272075578342334356200400 + CA*CF*NC*
        (-2327723300741746946437739749963624690377009102176012440467826090775\
8303508695374857/
          966459400493797071795901340994101940261242135008728455040000000 + 
         (91493017*lm^2)/16 + (309183899290424635758470156257336662709*Pi^2)/
          25640735611909017600 + (7290466601355992485606806669281663*Pi^3)/
          (235238571705968842915118592*Sqrt[3]) + (15624545867*Pi^4)/25920 + 
         lm*(3888230706878613092689/217171673731584 - (1102255*Pi^2)/324) - 
         (517375954926026498962985174473297102213909*
           Im[PolyLog[2, (-1)^(1/3)]])/(3802902035984448209892244426060800*
           Sqrt[3]) + (756222929*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (1041495228765141783658115238468809*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(907556218001423005073760*
           Sqrt[3]) + (1041495228765141783658115238468809*Pi*Log[3]^2)/
          (43562698464068304243540480*Sqrt[3]) + 
         (463988392890369160320113461908287057369981581*PolyGamma[2, 1])/
          66176604626738674849603200 - 
         (2209542029153320416580205190474673473289634284619*Zeta[3])/
          382078898888054081578540275600) + 
       (552385507295885535924460163661972967808835653561*CF^2*NC*Zeta[3])/
        47759862361006760197317534450 + (298353890205194748650587*CF*NM*NC*
         Zeta[3])/37800 - (2453931755*CF*NC*NL*Zeta[3])/27 + 
       (31843940440573803299018042735017*CF*NC*NH*Zeta[3])/
        4136037789171167178100200 + CF*Log[x]*
        ((-383994152987711359073805109101882491324214354671*NM*NC)/
          3609066822974088392236320000 - (4153307179066801*lm*NM*NC)/
          149652360 - (10599435*lm^2*NM*NC)/2 - 
         (929280322404268061286967*NC*NL)/5923862962617600 - 
         (4153307179066801*lm*NC*NL)/149652360 - (10599435*lm^2*NC*NL)/2 - 
         (41108437091468095648117710511614203438637308383522993*NC*NH)/
          24535256356981969203209264966460894236640000 - 
         (4153307179066801*lm*NC*NH)/149652360 - (10599435*lm^2*NC*NH)/2 - 
         (356387779037482146370*NM*NC*Pi^2)/27 - (2453731345*NC*NL*Pi^2)/
          162 + (3822642932980039298389394968*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1350851717672992089*Sqrt[3]) + 
         CF*NC*(-167325158744642666949268771806072281876531631105919578267134\
70747667271/107084279424167080428178930011949700416660262400000 - 
           (3316129990569151*lm)/5542680 - (286184745*lm^2)/2 - 
           (23711732750954763594555936917*Pi^2)/1197218880 + 
           (1041495228765141783658115238468809*Im[PolyLog[2, (-1)^(1/3)]])/
            (1361334327002134507610640*Sqrt[3]) - 42397740*Zeta[3]) + 
         CA*NC*(1287116605731316353842434506016767018545390898803942827104308\
942552867/16474504526794935450489066155684569294870809600000 + 
           (5162726564241001*lm)/27209520 + (116593785*lm^2)/4 + 
           (878212324110546859563218143*Pi^2)/88682880 - 
           (1041495228765141783658115238468809*Im[PolyLog[2, (-1)^(1/3)]])/
            (2722668654004269015221280*Sqrt[3]) + 21198870*Zeta[3]))}, 0, 39, 
     1]
 
CbarLSeries["v", 2, 3, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-1601525942907030*NM + 123832156815360*lm*NM + 
         84276412416000*lm^2*NM + 376663249780736*NL + 
         123832156815360*lm*NL + 84276412416000*lm^2*NL - 
         1601525942907030*NH + 123832156815360*lm*NH + 
         84276412416000*lm^2*NH + 36*CF*(294232533634027642 + 
           26155291115520*lm + 63207309312000*lm^2 - 244741896826385175*
            Zeta[3]) + 1301908056458625*NM*Zeta[3] + 1301908056458625*NH*
          Zeta[3] - 10*CA*(-71548384747112638 + 127101174939648*lm + 
           46352026828800*lm^2 + 59616002432440125*Zeta[3])))/
       3114856202895360000, -(CF*NC*(-3771482548799070*NM + 
          663881452093440*lm*NM + 337105649664000*lm^2*NM + 
          1630485155938304*NL + 663881452093440*lm*NL + 
          337105649664000*lm^2*NL - 8793060680826450*NH + 
          663881452093440*lm*NH + 337105649664000*lm^2*NH + 
          144*CF*(294239072456806522 + 57758945771520*lm + 
            63207309312000*lm^2 - 244741896826385175*Zeta[3]) + 
          3316577868190125*NM*Zeta[3] + 7098686583478875*NH*Zeta[3] - 
          40*CA*(-71516609453377726 + 150277188354048*lm + 
            46352026828800*lm^2 + 59616002432440125*Zeta[3])))/
       3114856202895360000, 
      (CF*NC*(22*CF*(1592081067287276434159558 + 75869725055149670400*lm + 
           58069819211120640000*lm^2 - 1324420722263510313143625*Zeta[3]) - 
         121*CA*(-13255738823222550575854 + 7817506961699635200*lm + 
           2150734044856320000*lm^2 + 11034391685840756533125*Zeta[3]) + 
         5*(2097152*(23915518533359 + 10658702840940*lm + 4512419604000*lm^2)*
            NL + 3465*NH*(-96670925991103310 + 6451059157368832*lm + 
             2731090850611200*lm^2 + 78211011658504725*Zeta[3]) + 
           3465*NM*(6451059157368832*lm + 2731090850611200*lm^2 + 
             583*(-25049728898258 + 28131302274075*Zeta[3])))))/
       195986752286176051200000, 
      -(CF*NC*(22*CF*(1410308575610258249414278 + 30443508594848563200*lm + 
            19022871810539520000*lm^2 - 1173228968080042607435625*Zeta[3]) - 
          121*CA*(-11024965308000481461934 + 2767930902813081600*lm + 
            704550807797760000*lm^2 + 9174372409948624633125*Zeta[3]) + 
          5*(16777216*(1072368545977 + 490749564690*lm + 184775802750*lm^2)*
             NL + 231*NM*(-18631611594999598 + 35642473803939840*lm + 
              13420015386624000*lm^2 + 51197156975089125*Zeta[3]) + 
            693*NH*(11880824601313280*lm + 4473338462208000*lm^2 + 
              693*(-305815384023034 + 248629322316375*Zeta[3])))))/
       39197350457235210240000, 
      (CF*NC*(34944*CF*(400098070858026311512753846 + 3119231460982652928000*
            lm + 1733973701233213440000*lm^2 - 332842757046901840842728625*
            Zeta[3]) - 704*CA*(-727603719220038909355984894 + 
           72359283504163848192000*lm + 17532400756913602560000*lm^2 + 
           605372314872009614512708125*Zeta[3]) + 
         25*(134217728*(4214755785816263 + 1909077411821580*lm + 
             668808012272400*lm^2)*NL + 45045*NH*(5688356816312860672*lm + 
             1992804792438620160*lm^2 + 1573*(-79580925907109026 + 
               65036051610750675*Zeta[3])) + 3003*NM*
            (85325352244692910080*lm + 29892071886579302400*lm^2 + 
             1001*(15125275131685946 + 100755918646007625*Zeta[3])))))/
       4239585425454560339558400000, 
      -(CF*NC*(93184*CF*(1028573936790838064079126422 + 
            2857945078648170086400*lm + 1503307474922373120000*lm^2 - 
            855676606381133969049242625*Zeta[3]) - 
          5632*CA*(-550585799103227181178173386 + 21429050936691209011200*
             lm + 5066702971034664960000*lm^2 + 458059385866774961573679375*
             Zeta[3]) + 5*(1073741824*(6524729743152347 + 2857307411698740*
               lm + 966396898467000*lm^2)*NL + 3003*NM*
             (-123062281177213968686 + 1021648508813228113920*lm + 
              345541381441191936000*lm^2 + 1802755199542629457125*Zeta[3]) + 
            9009*NH*(-9537835748309540339382 + 340549502937742704640*lm + 
              115180460480397312000*lm^2 + 7830600067745206376625*Zeta[3]))))/
       8479170850909120679116800000, 
      (CF*NC*(-385*CA*(-5888422136321254915504691316194 + 
           87883262852229564695838720*lm + 20781451036527182217216000*lm^2 + 
           4898720134085458858746563869875*Zeta[3]) + 
         2*(7*CF*(5645091931905497743822996634352754 + 
             5332252579706197368845107200*lm + 2805495889931169599324160000*
              lm^2 - 4696190622512684002351905959572875*Zeta[3]) + 
           5*(4294967296*(240684877697071237 + 100126257971479740*lm + 
               33869910346272000*lm^2)*NL + 3003*NM*
              (-280871349800789732545054 + 143203131354766827847680*lm + 
               48441610807755669504000*lm^2 + 523991598226912845154125*
                Zeta[3]) + 3003*NH*(-5279829140384996324787374 + 
               143203131354766827847680*lm + 48441610807755669504000*lm^2 + 
               4351227858891923669785125*Zeta[3])))))/
       2306334471447280824719769600000, 
      -(CF*NC*(-11*CA*(-504065208940492649536920832667978 + 
            2803490658955645727381913600*lm + 681797243245484184698880000*
             lm^2 + 419338771103215052630036400279375*Zeta[3]) + 
          2*(3*CF*(36081701643234359901982562878622534 + 
              10944664606229529312519782400*lm + 6136175189209357662289920000*
               lm^2 - 30016627986833371092118375800959625*Zeta[3]) + 
            10*(2147483648*(232006193398891451 + 90140323760306820*lm + 
                31748658197256000*lm^2)*NL + 858*NM*(
                -1620745462008954161358326 + 225611738112686209105920*lm + 
                79463548163809345536000*lm^2 + 1901575582700172718964625*
                 Zeta[3]) + 429*NH*(-22870896878535615816417082 + 
                451223476225372418211840*lm + 158927096327618691072000*lm^2 + 
                18904925523070112151000375*Zeta[3])))))/
       2306334471447280824719769600000, 
      (CF*NC*(68*CF*(616915142701093845636412047825967667474 + 
           54681100641693619222644523008000*lm + 
           35884770112013755996333670400000*lm^2 - 
           513216233020539878537787553792341898875*Zeta[3]) - 
         22*CA*(-43870800663418071994824883551899794474 + 
           87034329990234292563914784768000*lm + 
           22594114514971624145839718400000*lm^2 + 
           36496541096706116490828415628651049375*Zeta[3]) + 
         175*(4294967296*(874571830172277678941 + 310147363394002674540*lm + 
             120242336578516152000*lm^2)*NL + 7293*NM*
            (-3961240934309775065961349042 + 182650868328242019701882880*lm + 
             70812683833724312223744000*lm^2 + 3844914075859194854658016875*
              Zeta[3]) + 7293*NH*(182650868328242019701882880*lm + 
             70812683833724312223744000*lm^2 + 75361*
              (-180151972202308739825546 + 149254703873993442099375*
                Zeta[3])))))/177297156158038266119507568230400000, 
      CA*CF*NC*((174900603707*lm)/23029371565200 + (7879*lm^2)/3527160 + 
         (-23287061599691169663317971933199977946 + 
           19372694221448356795139012124844974375*Zeta[3])/
          2014740410886798478630767820800000) - 
       (CF*NC*(5984*CF*(32958778605479638460997190712140813766 + 
            696334286682020400435560448000*lm + 
            649811203531461103630417920000*lm^2 - 
            27418650821297993661939438459514583625*Zeta[3]) + 
          175*(68719476736*(82270419575532999929 + 25473892123272312720*lm + 
              11975595625105912800*lm^2)*NL + 21879*NH*
             (-9772853756244495097104442662 + 80010628325818608627220480*lm + 
              37613998124192566031155200*lm^2 + 8110687341381422252095265625*
               Zeta[3]) + 2431*NM*(-48886289074433312686744634218 + 
              720095654932367477644984320*lm + 338525983117733094280396800*lm^
                2 + 43472660677995248771766069375*Zeta[3]))))/
        354594312316076532239015136460800000, 
      (CF*NC*(1216*CF*(1037434566922876488106920635502123406438814 + 
           2219096946715778416321950960844800*lm + 
           6782460147922956339325949706240000*lm^2 - 
           863049468972850645823681506126171668586125*Zeta[3]) - 
         11616*CA*(-2048579822077304426768049250277337356114 + 
           384064047598328588796830102323200*lm + 
           144631585645944074575974236160000*lm^2 + 
           1704228943514064923775340375304536870875*Zeta[3]) + 
         35*(1099511627776*(46418855036785558100959 + 10975614877975133876490*
              lm + 7937599649247305037000*lm^2)*NL + 
           46189*NM*(-71614297320251970523553494623958 + 
             261270349657384291917795164160*lm + 
             188951549307802962056183808000*lm^2 + 
             61152552359936364914860342694625*Zeta[3]) + 
           138567*NH*(87090116552461430639265054720*lm + 
             62983849769267654018727936000*lm^2 + 
             4199*(-5439625387878574267376667214 + 
               4520142784467194585294719125*Zeta[3])))))/
       1024068373968829025106275714098790400000, 
      CA*CF*NC*((506209932376961*lm)/332544125401488000 + 
         (2207*lm^2)/2015520 + (-129671702667792056730954217533983647000754 + 
           107874842227472461127311795240472171344875*Zeta[3])/
          2909285153320537003142828733235200000) - 
       (CF*NC*(1216*CF*(62354614311966011370616626259426460267882 - 
            121339248417944149105732516577280*lm + 
            129343208731236193216040534016000*lm^2 - 
            51873263596249887637155740001938120930175*Zeta[3]) + 
          11*(274877906944*(7051308973116381171469 + 226248818081370133140*
               lm + 1926552822497845542000*lm^2)*NL + 37791*NH*
             (1645651122297923952191733760*lm + 14013040339373484071190528000*
               lm^2 + 46189*(-161673690348138848320854422 + 
                134465821160133909880058625*Zeta[3])) + 
            4199*NM*(14810860100681315569725603840*lm + 
              126117363054361356640714752000*lm^2 + 
              17*(-7870701261487181414094866563886 + 
                6603588139401690931808190001125*Zeta[3])))))/
        29259096399109400717322163259965440000, 
      (CF*NC*(52*CF*(311603138959649674585023464961054653791412064862 - 
           632774510242916548265163285415015219200*lm + 
           187291908439049949709458547031408640000*lm^2 - 
           259224949363626792001579568164093091700631774125*Zeta[3]) + 
         CA*(255155485926566241723404649799346767586815451764 + 
           2083626263745024060188251951847807385600*lm - 
           1983906881984010578403894238925291520000*lm^2 - 
           212265715442694665667875028595827294060894576750*Zeta[3]) + 
         1155*(274877906944*(-1400076596576713194431741 - 
             2639273396587773864478560*lm + 1136152883416171673052000*lm^2)*
            NL + 4199*NH*(-64234530850914825198038091674777122 - 
             172773981211485808870743720591360*lm + 
             74375643382192835906148237312000*lm^2 + 
             53457481761160323743685787653529875*Zeta[3]) + 
           37791*NM*(-19197109023498423207860413399040*lm + 
             8263960375799203989572026368000*lm^2 + 
             323*(-85598202708875638155941465393126 + 
               71331180851123497899123397493625*Zeta[3])))))/
       3109071583369364920222653068003927654400000, 
      -(CF*NC*(16*CF*(3914767991596901364769125881644313474292798309278 - 
            5383493706612120922728897211124416512000*lm + 
            543731468832297638858634706708070400000*lm^2 - 
            3256724359187667735780256025653427547647253322125*Zeta[3]) - 
          8*CA*(-113304382399951661203477160918967644643971972194 - 
            1677513470735618788449570057634185216000*lm + 
            221520228042787926942406732362547200000*lm^2 + 
            94258745520855859984323996217612171387069621875*Zeta[3]) + 
          5775*(3298534883328*(-264128359297042659527239 - 
              149619444572921666222880*lm + 16914829226536236996000*lm^2)*
             NL + 46189*NM*(-16440376237441809018730405385251906 - 
              10684902404207545759435598069760*lm + 
              1207953284315870683088289792000*lm^2 + 
              13670928161002004020367082408439875*Zeta[3]) + 
            4199*NH*(-117533926446283003353791578767360*lm + 
              13287486127474577513971187712000*lm^2 + 
              4199*(-5594073260539742133882208402838 + 
                4657386125637883335849929402625*Zeta[3])))))/
       6218143166738729840445306136007855308800000, 
      CF*((-5637273023262630715880908828373382913*NM*NC)/
         4444725479823430119287742447747072000 - (235324215047263*lm*NM*NC)/
         425291047409067840 + (58*lm^2*NM*NC)/9784775 - 
        (649948939551677805275294297*NC*NL)/518041525920800746138642368000 - 
        (235324215047263*lm*NC*NL)/425291047409067840 + 
        (58*lm^2*NC*NL)/9784775 - (197741618838553443608152052340361*NC*NH)/
         2428369411668237180452235902976000 - (235324215047263*lm*NC*NH)/
         425291047409067840 + (58*lm^2*NC*NH)/9784775 + 
        CF*NC*((-1189926063349787*lm)/78757601372049600 + 
          (1566*lm^2)/9784775 + 
          (977408675141370842927371495070864118483974612742674 - 
            813113483487120377562967962533964765179682497530875*Zeta[3])/
           52006288303633013210997105864792971673600000) + 
        CA*NC*((1160578697223899*lm)/386628224917334400 - (29*lm^2)/889525 + 
          (54545538253916052213974050574761460958850157163622 - 
            45376833555359574923786446767614436742870030253625*Zeta[3])/
           217480841997010782518715169980043336089600000) + 
        (128194028978139299*NM*NC*Zeta[3])/121597189939003392 + 
        (916183516742291*NC*NH*Zeta[3])/13510798882111488), 
      (CF*NC*(-5*CA*(40134428319872985839827335132144488488196013401318 + 
           318378221357259084973330085401087954649088*lm + 
           12702346745944790241786922825756610396160*lm^2 - 
           33388125948526619482048581240033016369441201676025*Zeta[3]) + 
         14*(115*CF*(-10096177682348288077088457956176169925251332477658 + 
             4402990553271655756115362570202372898816*lm + 
             193655201660366649648925418574493777920*lm^2 + 
             8399084651658329186969269972153776618111566952615*Zeta[3]) + 
           3*(2199023255552*(7757394415536313185039369269 + 
               2974673673170209722442250520*lm + 125029405470988987566998400*
                lm^2)*NL + 37145*NM*
              (692159305708463566390258794868913920906 + 
               176103825144153469389354154120445952*lm + 
               7401872937368292995792738545827840*lm^2 - 
               575426278368216547581797015129217190575*Zeta[3]) + 
             4680270*NH*(1397649405905979915788525032701952*lm + 
               58745023312446769807878877347840*lm^2 - 7429*
                (-23150939568965651119009479647042 + 
                 19281421287376878191699580718275*Zeta[3]))))))/
       478457852393423721541173373956095339397120000}, 2, 18, 1]
 
CbarLSeries["v", 2, 4, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(3*CF*(-21946982400*lm^2 + 758015568*Pi^2 + 8467200*Pi^4 + 
            5080320*lm*(-6499 + 240*Pi^2) - 35*(763887201 + 170003328*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 104509440*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 28333888*PolyGamma[2, 1] - 
              576208256*Zeta[3])) + 60*CA*(167650560*lm^2 - 49399236*Pi^2 + 
            1143072*Pi^4 - 3528*lm*(-189389 + 2640*Pi^2) + 
            7*(107513337 + 21250416*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              13063680*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3541736*PolyGamma[2, 
                1] - 55543504*Zeta[3])) + 
          280*(9*NL*(-1868447 - 725760*lm^2 - 81936*Pi^2 + 168*lm*(-11719 + 
                240*Pi^2) - 483840*Zeta[3]) + 9*NM*(-1868447 - 725760*lm^2 - 
              81936*Pi^2 + 168*lm*(-11719 + 240*Pi^2) + 40320*PolyGamma[2, 
                1] - 403200*Zeta[3]) + NH*(259270353 - 6531840*lm^2 + 
              1512*lm*(-11719 + 240*Pi^2) - 4036636608*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 672772768*PolyGamma[2, 1] + 
              7038406976*Zeta[3]))))/576108288000, 
      -(CF*NC*(-80*CA*(2640496320*lm^2 - 1125368073*Pi^2 + 37292724*Pi^4 - 
            79380*lm*(-100229 + 1848*Pi^2) - 14*(251836254 + 97053738*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] - 213101280*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 18063733*PolyGamma[2, 1] - 
              158447834*Zeta[3])) - 47040*(NH*(304716771 - 816480*lm^2 + 
              270*lm*(-5263 + 168*Pi^2) + 226315104*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 37719184*PolyGamma[2, 1] - 659312288*Zeta[
                3]) + 9*NL*(130649 - 90720*lm^2 - 9072*Pi^2 + 
              30*lm*(-5263 + 168*Pi^2) - 60480*Zeta[3]) + 
            9*NM*(130649 - 90720*lm^2 - 9072*Pi^2 + 30*lm*(-5263 + 
                168*Pi^2) + 5040*PolyGamma[2, 1] - 50400*Zeta[3])) + 
          CF*(1382659891200*lm^2 - 39095186544*Pi^2 + 2552860800*Pi^4 - 
            457228800*lm*(-1609 + 168*Pi^2) - 35*(-26593798239 + 
              6211439232*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              13638481920*Im[PolyLog[2, (-1)^(1/3)]]^2 - 1156078912*PolyGamma[
                2, 1] + 3556233856*Zeta[3]))))/1728324864000, 
      -(CF*NC*(CF*(4740548198400*lm^2 + 262328799312*Pi^2 - 
            31777401600*Pi^4 + 1097349120*lm*(-259 + 60*Pi^2) + 
            35*(66888225261 + 96152989440*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 121335459840*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              10571236352*PolyGamma[2, 1] - 287599554304*Zeta[3])) + 
          560*CA*(4243735755 - 1293304320*lm^2 - 296012394*Pi^2 + 
            30985416*Pi^4 - 27216*lm*(115051 + 660*Pi^2) - 3004780920*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 3791733120*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 330351136*PolyGamma[2, 1] + 
            7597423040*Zeta[3]) + 3360*(27*NL*(-3443083 + 1451520*lm^2 + 
              596592*Pi^2 + 336*lm*(4961 + 60*Pi^2) - 241920*Zeta[3]) + 
            27*NM*(-5596675 + 1451520*lm^2 + 898992*Pi^2 + 336*lm*(4961 + 
                60*Pi^2) + 40320*PolyGamma[2, 1] - 161280*Zeta[3]) + 
            NH*(-9166528257 + 39191040*lm^2 + 9072*lm*(4961 + 60*Pi^2) - 
              25653766592*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              4387756560*PolyGamma[2, 1] + 53893109280*Zeta[3]))))/
       1728324864000, -(CF*NC*(740710656000*(-14*CA*(76 + 33*lm) + 
            27*CF*(179 + 112*lm) + 28*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 
              3*lm*NH))*Log[x]^2 + 20739898368000*(11*CA + 36*CF - 
            2*(NM + NL))*Log[x]^3 + 846720*Log[x]*
           (12*(729*NM*(45743 + 37000*lm + 8400*lm^2 + 4200*Pi^2) + 
              729*NL*(70943 + 37000*lm + 8400*lm^2 + 4200*Pi^2) + 
              NH*(1465911399 + 26973000*lm + 6123600*lm^2 - 836208800*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            2*CA*(-2044181037 - 1147300200*lm - 202078800*lm^2 + 
              7064010*Pi^2 - 1412560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              110224800*Zeta[3]) + 5*CF*(1532268069 + 1691163360*lm + 
              529079040*lm^2 - 21170160*Pi^2 + 1130048*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 88179840*Zeta[3])) - 
          80*CA*(7984860871680*lm^2 - 1337804930169*Pi^2 - 2422540400*Sqrt[3]*
             Pi^3 + 39643451568*Pi^4 - 15002820*lm*(-2020091 + 6600*Pi^2) - 
            1868816880*Sqrt[3]*Pi*Log[3]^2 + 7*(3251789551557 - 
              1315380392724*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1855480193280*Im[PolyLog[2, (-1)^(1/3)]]^2 - 12814744320*Sqrt[
                3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 236650358822*
               PolyGamma[2, 1] + 2499132814444*Zeta[3])) + 
          7*(-6720*(243*NL*(-20274007 - 10160640*lm^2 - 4338720*Pi^2 + 
                1050*lm*(-24413 + 120*Pi^2) - 17841600*Zeta[3]) + 
              1215*NM*(2173105 - 2032128*lm^2 - 777024*Pi^2 + 
                210*lm*(-24413 + 120*Pi^2) - 240912*PolyGamma[2, 1] - 
                784224*Zeta[3]) - NH*(-350877255237 + 2469035520*lm^2 + 
                14633654000*Sqrt[3]*Pi^3 - 255150*lm*(-24413 + 120*Pi^2) - 
                208131997920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                541863302400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                11288818800*Sqrt[3]*Pi*Log[3]^2 + 42893490832*PolyGamma[2, 
                  1] + 225796972064*Zeta[3])) + CF*(597309072998400*lm^2 - 
              27985688903664*Pi^2 - 55372352000*Sqrt[3]*Pi^3 + 
              576931299840*Pi^4 - 12345177600*lm*(-63601 + 600*Pi^2) - 
              42715814400*Sqrt[3]*Pi*Log[3]^2 + 5*(122949814718025 - 
                42092172567168*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                59375366184960*Im[PolyLog[2, (-1)^(1/3)]]^2 - 410071818240*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                7572811482304*PolyGamma[2, 1] + 49733906543744*Zeta[3])))))/
       46664771328000, (-2*CF*NC*(-70*CA*(76 + 33*lm) + 
          108*CF*(191 + 140*lm) + 35*(23*NM + 12*lm*NM + 20*NL + 
            12*lm*NL + 12*lm*NH))*Log[x]^2)/315 - 
       (8*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       (CF*NC*Log[x]*(2*(-2*(8748*NL*(91927 + 49605*lm + 12600*lm^2 + 
                6300*Pi^2) + 10935*NM*(37579 + 39684*lm + 10080*lm^2 + 
                6720*Pi^2) + NH*(13780943877 + 433944540*lm + 110224800*
                 lm^2 - 7871393600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            9*CF*(-2124251733 - 2406049920*lm - 881798400*lm^2 + 
              58305420*Pi^2 + 150128240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              146966400*Zeta[3])) - 9*CA*(-2596078353 - 1403674920*lm - 
            269438400*lm^2 + 37805940*Pi^2 + 150128240*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 146966400*Zeta[3])))/165337200 + 
       (CF*NC*(-288*CA*(-2407001002560*lm^2 + 200730671964*Pi^2 - 
            64367482900*Sqrt[3]*Pi^3 + 4526565120*Pi^4 + 
            1786050*lm*(-4521953 + 2640*Pi^2) - 49654915380*Sqrt[3]*Pi*
             Log[3]^2 + 7*(-253770197553 + 112198051488*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 804200140800*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 340490848320*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 38127433670*PolyGamma[2, 1] + 
              171499340180*Zeta[3])) + 9*CF*(-504157300899840*lm^2 + 
            19516120644240*Pi^2 - 4119518905600*Sqrt[3]*Pi^3 + 
            333594132480*Pi^4 + 4115059200*lm*(-107119 + 240*Pi^2) - 
            3177914584320*Sqrt[3]*Pi*Log[3]^2 + 7*(-41938450022727 + 
              7180675295232*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              51468809011200*Im[PolyLog[2, (-1)^(1/3)]]^2 - 21791414292480*
               Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              2440155754880*PolyGamma[2, 1] + 32126329095680*Zeta[3])) + 
          112*(2187*NL*(-449799119 - 514563840*lm^2 - 252778320*Pi^2 + 
              840*lm*(-1275791 + 1200*Pi^2) - 926553600*Zeta[3]) + 
            2187*NM*(1432859113 - 514563840*lm^2 - 329164560*Pi^2 + 
              840*lm*(-1275791 + 1200*Pi^2) - 103029264*PolyGamma[2, 1] + 
              86664672*Zeta[3]) - NH*(-131318581201515 + 1125351118080*lm^
                2 + 3856982864000*Sqrt[3]*Pi^3 - 1837080*lm*(-1275791 + 
                1200*Pi^2) - 159337547171520*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 142818565478400*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 2975386780800*Sqrt[3]*Pi*Log[3]^
                2 + 29952399742192*PolyGamma[2, 1] + 281828766409184*Zeta[
                3]))))/27998862796800, 
      -(CF*NC*(141995107611710451*CF + 242847136508659200*CF*lm + 
          179416712801894400*CF*lm^2 - 12674800940397120*NM + 
          12767842531785600*lm*NM + 4983797577830400*lm^2*NM + 
          9687459311449920*NL + 12767842531785600*lm*NL + 
          4983797577830400*lm^2*NL - 795905757513510336*NH + 
          12767842531785600*lm*NH + 4983797577830400*lm^2*NH - 
          13421205164277648*CF*Pi^2 - 1399943139840000*CF*lm*Pi^2 + 
          1693671950476800*NM*Pi^2 - 38887309440000*lm*NM*Pi^2 + 
          2776294645286400*NL*Pi^2 - 38887309440000*lm*NL*Pi^2 - 
          38887309440000*lm*NH*Pi^2 + 1209362911456000*Sqrt[3]*CF*Pi^3 + 
          40555931778880000*Sqrt[3]*NH*Pi^3 + 371766381799680*CF*Pi^4 - 
          75722814560749440*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          382095699479961600*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          108851578878873600*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          44780980949913600*Sqrt[3]*CF*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]] + 1501728216726528000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 932937103123200*Sqrt[3]*CF*
           Pi*Log[3]^2 + 31286004515136000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          666639590400*(-6*CA*(16133 + 8085*lm) + CF*(473091 + 317520*lm) + 
            14*(7*(179 + 90*lm)*NM + 945*NL + 630*lm*NL + 8*NH + 
              630*lm*NH))*Log[x]^2 + 1959920395776000*(13*CA + 46*CF - 
            2*(2*NM + NL))*Log[x]^3 + 15523584147341760*CF*
           PolyGamma[2, 1] + 737925583933440*NM*PolyGamma[2, 1] + 
          86671311173457920*NH*PolyGamma[2, 1] + 211680*Log[x]*
           (2*(4*(15309*NL*(1408403 + 701460*lm + 151200*lm^2 + 
                  88200*Pi^2) + 2187*NM*(8406683 + 4910220*lm + 1058400*
                   lm^2 + 289800*Pi^2) + NH*(518718690717 + 10738651140*lm + 
                  2314720800*lm^2 - 295597170400*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]])) - 5*CF*(-208157226105 - 228720868992*lm - 
                66663959040*lm^2 + 3959904672*Pi^2 + 7051678784*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 11110659840*Zeta[3])) + 
            5*CA*(-227940529215 - 120425002992*lm - 20369543040*lm^2 + 
              1657676016*Pi^2 + 7051678784*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 11110659840*Zeta[3])) + 91809468800407680*CF*
           Zeta[3] - 12336921145221120*NM*Zeta[3] + 14186090483712000*NL*
           Zeta[3] + 131779866017443840*NH*Zeta[3] - 
          10*CA*(2741088667806720*lm^2 - 564105839771448*Pi^2 + 
            60468145572800*Sqrt[3]*Pi^3 + 21699303845184*Pi^4 - 
            1388832480*lm*(-7568207 + 15400*Pi^2) + 46646855156160*Sqrt[3]*Pi*
             Log[3]^2 + 21*(304757192946279 - 180292415620832*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 259170425902080*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 106621383214080*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 36960914636528*PolyGamma[2, 1] + 
              340525832483296*Zeta[3]))))/139994313984000, 
      -(CF*NC*(-21*CA*(129951 + 49390*lm) + CF*(10268581 + 6788880*lm) + 
           42*(14721*NM + 4490*lm*NM + 6515*NL + 4490*lm*NL + 72*NH + 
             4490*lm*NH))*Log[x]^2)/2835 - 
       (4*CF*NC*(4435*CA + 24718*CF - 1472*NM - 898*NL)*Log[x]^3)/81 + 
       (CF*NC*Log[x]*(4*(-2*(10935*NL*(12081847 + 6142092*lm + 
                1451520*lm^2 + 861000*Pi^2) + 2187*NM*(53025161 + 
                30710460*lm + 7257600*lm^2 + 4615800*Pi^2) + 
              NH*(2053408835967 + 67163776020*lm + 15872371200*lm^2 - 
                1170101178400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            3*CF*(-1070886503679 - 1151631859680*lm - 380936908800*lm^2 + 
              19514163600*Pi^2 + 99617668480*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 63489484800*Zeta[3])) + 
          CA*(7722085811409 + 3844058932080*lm + 698384332800*lm^2 - 
            51568935120*Pi^2 - 597706010880*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 380936908800*Zeta[3])))/2976069600 - 
       (CF*NC*(-60*CA*(5752033041807360*lm^2 - 650680553061432*Pi^2 + 
            341688602886400*Sqrt[3]*Pi^3 + 24113927994912*Pi^4 - 
            925888320*lm*(-21430559 + 14300*Pi^2) + 263588350798080*Sqrt[3]*
             Pi*Log[3]^2 - 7*(-508856139893025 + 631502990982048*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 2140113077061120*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 1807462976901120*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 204754126790528*PolyGamma[2, 1] + 
              151982697488384*Zeta[3])) + 3*CF*(752993416382054400*lm^2 - 
            40605313836618288*Pi^2 + 13667544115456000*Sqrt[3]*Pi^3 + 
            887523211572480*Pi^4 - 1333279180800*lm*(-547009 + 1300*Pi^2) + 
            10543534031923200*Sqrt[3]*Pi*Log[3]^2 - 
            35*(-9774979202407797 + 5052023927856384*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 17120904616488960*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 14459703815208960*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                   Sqrt[3])]] - 1638033014324224*PolyGamma[2, 1] + 
              8470890129262336*Zeta[3])) - 
          224*(492075*NL*(-476848939 - 569286144*lm^2 - 344083440*Pi^2 + 
              1008*lm*(-1229437 + 1300*Pi^2) - 1751500800*Zeta[3]) + 
            295245*NM*(3088796627 - 948810240*lm^2 - 751586000*Pi^2 + 
              1680*lm*(-1229437 + 1300*Pi^2) - 344670576*PolyGamma[2, 1] + 
              2832207648*Zeta[3]) - NH*(-35966019264400647 + 
              280131479308800*lm^2 + 1433373943540000*Sqrt[3]*Pi^3 - 
              496011600*lm*(-1229437 + 1300*Pi^2) - 29031010406846400*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 53075789452224000*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1105745613588000*Sqrt[
                3]*Pi*Log[3]^2 + 5940397800389120*PolyGamma[2, 1] + 
              39647842416202240*Zeta[3]))))/1259948825856000, 
      (-40717276338060013*CF^2*NC)/8571080448000 - (2281729*CF^2*lm*NC)/180 - 
       (46508*CF^2*lm^2*NC)/5 + (49783333*CF*NM*NC)/30240 - 
       (4304827*CF*lm*NM*NC)/6480 - (11627*CF*lm^2*NM*NC)/45 - 
       (1539372707*CF*NC*NL)/4082400 - (4304827*CF*lm*NC*NL)/6480 - 
       (11627*CF*lm^2*NC*NL)/45 + (12499592091870827*CF*NC*NH)/
        243045684000 - (4304827*CF*lm*NC*NH)/6480 - (11627*CF*lm^2*NC*NH)/
        45 + (296334081367*CF^2*NC*Pi^2)/299376000 + (490*CF^2*lm*NC*Pi^2)/
        9 + (6330403*CF*NM*NC*Pi^2)/34020 + (245*CF*lm*NM*NC*Pi^2)/162 - 
       (853139*CF*NC*NL*Pi^2)/4860 + (245*CF*lm*NC*NL*Pi^2)/162 + 
       (245*CF*lm*NC*NH*Pi^2)/162 - (6253407734*CF^2*NC*Pi^3)/
        (14348907*Sqrt[3]) - (17410729385*CF*NC*NH*Pi^3)/(2125764*Sqrt[3]) - 
       (986503*CF^2*NC*Pi^4)/32400 + (26268616341683*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1913187600*Sqrt[3]) + 
       (393169141762*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (6200145*Sqrt[3]) - (33047*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (14293503392*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (885735*Sqrt[3]) - (1989797644*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (893343962*CF^2*NC*Pi*Log[3]^2)/(2657205*Sqrt[3]) - 
       (497449411*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) - 
       (CF*NC*(-3*CA*(10512217 + 5621770*lm) + 
          7*CF*(23197813 + 15770160*lm) + 6*((-1601687 + 511070*lm)*NM + 
            245*(2951 + 2086*lm)*NL + 2*(8019 + 255535*lm)*NH))*Log[x]^2)/
        5670 - (14*CF*NC*(14509*CA + 63502*CF - 12392*NM - 2086*NL)*
         Log[x]^3)/81 - (1783348091248883*CF^2*NC*PolyGamma[2, 1])/
        1687431463200 + (2017166*CF*NM*NC*PolyGamma[2, 1])/14175 - 
       (4242623507422*CF*NC*NH*PolyGamma[2, 1])/837019575 + 
       (CF*NC*Log[x]*(2*(108*(-1701*NM*(371696261 + 430385340*lm + 
                88905600*lm^2 - 107826600*Pi^2) - 1701*NL*(914128031 + 
                430385340*lm + 88905600*lm^2 + 60299400*Pi^2) - 
              5*NH*(6852263918865 + 146417092668*lm + 30245685120*lm^2 - 
                3900003382240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            7*CF*(-276573525009519 - 305125305428160*lm - 83996588390400*lm^
                2 + 5921233740720*Pi^2 + 16008723799040*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 13999431398400*Zeta[3])) - 
          35*CA*(-61025395394445 - 31382140284432*lm - 5133124846080*lm^2 + 
            559200328560*Pi^2 + 3201744759808*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2799886279680*Zeta[3])))/
        124994923200 - (4535342722348457*CF^2*NC*Zeta[3])/843715731600 + 
       (24022132*CF*NM*NC*Zeta[3])/14175 - (29204*CF*NC*NL*Zeta[3])/27 + 
       (902971209856*CF*NC*NH*Zeta[3])/837019575 + 
       (CA*CF*NC*(540894642961622859 + 383675416620249600*lm^2 - 
          107693354060562600*Pi^2 + 19610686653824000*Sqrt[3]*Pi^3 + 
          4436915623348320*Pi^4 - 229157359200*lm*(-6435739 + 9800*Pi^2) - 
          617837856356384160*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          892232761029926400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          726155711524454400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          15128243990092800*Sqrt[3]*Pi*Log[3]^2 + 142667847299910640*
           PolyGamma[2, 1] + 1157340705772467680*Zeta[3]))/269989034112000, 
      (-15693492281544071*CF^2*NC)/4285540224000 - (623935*CF^2*lm*NC)/56 - 
       (55596*CF^2*lm^2*NC)/5 + (6819092767*CF*NM*NC)/6048000 - 
       (6881671*CF*lm*NM*NC)/10080 - (4633*CF*lm^2*NM*NC)/15 - 
       (1016006293*CF*NC*NL)/10886400 - (6881671*CF*lm*NC*NL)/10080 - 
       (4633*CF*lm^2*NC*NL)/15 + (2508428477678609341*CF*NC*NH)/
        52497867744000 - (6881671*CF*lm*NC*NH)/10080 - 
       (4633*CF*lm^2*NC*NH)/15 + (10052682707*CF^2*NC*Pi^2)/39293100 + 
       (70*CF^2*lm*NC*Pi^2)/3 - (1875407*CF*NM*NC*Pi^2)/6480 + 
       (35*CF*lm*NM*NC*Pi^2)/54 - (1440947*CF*NC*NL*Pi^2)/6480 + 
       (35*CF*lm*NC*NL*Pi^2)/54 + (35*CF*lm*NC*NH*Pi^2)/54 - 
       (228822642833*CF^2*NC*Pi^3)/(229582512*Sqrt[3]) - 
       (91322311535*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) - 
       (4043*CF^2*NC*Pi^4)/135 + (142597553140817*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(13392313200*Sqrt[3]) + 
       (60629796941827*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (669615660*Sqrt[3]) - 9936*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (228822642833*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6200145*Sqrt[3]) - (41747342416*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (228822642833*CF^2*NC*Pi*Log[3]^2)/(297606960*Sqrt[3]) - 
       (2609208901*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) - 
       (CF*NC*(-5*CA*(10376447 + 3001152*lm) + CF*(175201333 + 98219520*lm) + 
          24*(70*(6037 + 1624*lm)*NM + 245*(629 + 464*lm)*NL + 
            (4359 + 113680*lm)*NH))*Log[x]^2)/3780 - 
       (56*CF*NC*(2430*CA + 27161*CF - 2364*NM - 696*NL)*Log[x]^3)/81 - 
       (532521599326513*CF^2*NC*PolyGamma[2, 1])/337486292640 - 
       (18712243*CF*NM*NC*PolyGamma[2, 1])/264600 - 
       (462506810182471*CF*NC*NH*PolyGamma[2, 1])/70309644300 + 
       (CA*CF*NC*(53799983769177639 + 229324185757497600*lm^2 + 
          2767079487870900*Pi^2 + 22424618997634000*Sqrt[3]*Pi^3 + 
          2091415054982400*Pi^4 - 11160261000*lm*(-71571387 + 43120*Pi^2) - 
          239563889276572560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          670652760734208000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          830351606312390400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          17298991798174800*Sqrt[3]*Pi*Log[3]^2 + 106504319865302600*
           PolyGamma[2, 1] - 93858217978454000*Zeta[3]))/134994517056000 + 
       (976915977210587*CF^2*NC*Zeta[3])/168743146320 + 
       (285783557*CF*NM*NC*Zeta[3])/132300 - (12614*CF*NC*NL*Zeta[3])/9 - 
       (1093173903309871*CF*NC*NH*Zeta[3])/35154822150 + 
       (CF*NC*Log[x]*(-78884546379597*NM - 23340164779260*lm*NM - 
          5249786774400*lm^2*NM - 49029976050867*NL - 23340164779260*lm*
           NL - 5249786774400*lm^2*NL - 719529320564499*NH - 
          23340164779260*lm*NH - 5249786774400*lm^2*NH - 
          245360404800*NM*Pi^2 - 3629482214400*NL*Pi^2 + 
          409123955676800*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          14*CF*(-46929946810893 - 43705729097640*lm - 13499451705600*lm^2 + 
            173000480805*Pi^2 + 4576452856660*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2249908617600*Zeta[3]) + 
          35*CA*(11062777974024 + 4717697534478*lm + 824966493120*lm^2 + 
            58908404331*Pi^2 - 915290571332*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 449981723520*Zeta[3])))/15624365400, 
      (-45543050223216239*CF^2*NC)/6428310336000 - (11313977*CF^2*lm*NC)/
        180 - (230048*CF^2*lm^2*NC)/5 + (200835184283*CF*NM*NC)/13608000 - 
       (4264213*CF*lm*NM*NC)/1296 - (57512*CF*lm^2*NM*NC)/45 - 
       (242145103*CF*NC*NL)/291600 - (4264213*CF*lm*NC*NL)/1296 - 
       (57512*CF*lm^2*NC*NL)/45 + (2517755913408745357*CF*NC*NH)/
        7874680161600 - (4264213*CF*lm*NC*NH)/1296 - (57512*CF*lm^2*NC*NH)/
        45 + (3526642868279*CF^2*NC*Pi^2)/449064000 + (1960*CF^2*lm*NC*Pi^2)/
        9 + (135524273*CF*NM*NC*Pi^2)/17010 + (490*CF*lm*NM*NC*Pi^2)/81 - 
       (2486491*CF*NC*NL*Pi^2)/2430 + (490*CF*lm*NC*NL*Pi^2)/81 + 
       (490*CF*lm*NC*NH*Pi^2)/81 - (414768911473*CF^2*NC*Pi^3)/
        (114791256*Sqrt[3]) - (4406210920265*CF*NC*NH*Pi^3)/
        (86093442*Sqrt[3]) - (418684*CF^2*NC*Pi^4)/2025 + 
       (3148816460463643*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (40176939600*Sqrt[3]) + (176796194615996*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(502211745*Sqrt[3]) - 
       (186816*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (118505403278*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (885735*Sqrt[3]) - (1007133924632*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (59252701639*CF^2*NC*Pi*Log[3]^2)/(21257640*Sqrt[3]) - 
       (125891740579*CF*NC*NH*Pi*Log[3]^2)/(3188646*Sqrt[3]) - 
       (CF*NC*(-5*CA*(156474551 + 104497008*lm) + 
          12*(45*CF*(8682425 + 6333152*lm) - 163255593*NM + 7916440*lm*NM + 
            10831450*NL + 7916440*lm*NL + 416695*NH + 7916440*lm*NH))*
         Log[x]^2)/22680 - (28*CF*NC*(62933*CA + 301761*CF - 122212*NM - 
          8078*NL)*Log[x]^3)/81 - (15812647630803019*CF^2*NC*
         PolyGamma[2, 1])/2531147194800 + 
       (161204689*CF*NM*NC*PolyGamma[2, 1])/28350 - 
       (52645213481257*CF*NC*NH*PolyGamma[2, 1])/1807962282 - 
       (CF*NC*Log[x]*(-8*(-275562*NL*(3010524319 + 1334326560*lm + 
              266716800*lm^2 + 207652200*Pi^2) + 964467*NM*
             (1923896329 - 381236160*lm - 76204800*lm^2 + 448323600*Pi^2) - 
            NH*(17361233576088693 + 367689695526720*lm + 73497014841600*lm^
                2 - 9869912461393600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          21*CA*(-1768849076125911 - 966389496871680*lm - 153993745382400*
             lm^2 + 27477148348080*Pi^2 + 132726051671360*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 83996588390400*Zeta[3]) - 
          42*CF*(-1579443129867009 - 1912325503495680*lm - 
            503979530342400*lm^2 + 48196900771920*Pi^2 + 132726051671360*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 83996588390400*Zeta[3])))/
        374984769600 - (38554777372833487*CF^2*NC*Zeta[3])/1265573597400 + 
       (190195189*CF*NM*NC*Zeta[3])/14175 - (199724*CF*NC*NL*Zeta[3])/27 + 
       (31200131052071*CF*NC*NH*Zeta[3])/903981141 + 
       (CA*CF*NC*(31314012148529510400*lm^2 - 14633574868581122340*Pi^2 + 
          2682725319407364000*Sqrt[3]*Pi^3 + 482092819294141440*Pi^4 - 
          343736038800*lm*(-350475907 + 431200*Pi^2) + 2069530960685680800*
           Sqrt[3]*Pi*Log[3]^2 + 11*(405243667722028779 - 5290011653578920240*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 7565740709500108800*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 9030680555719334400*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1265011810464241520*
             PolyGamma[2, 1] + 10030204778912873440*Zeta[3])))/
        4454819062848000, (-6828519277537993163*CF^2*NC)/492167510100000 - 
       (791696491*CF^2*lm*NC)/15750 - (246784*CF^2*lm^2*NC)/5 - 
       (132959453359*CF*NM*NC)/61740000 - (1731018091*CF*lm*NM*NC)/567000 - 
       (61696*CF*lm^2*NM*NC)/45 + (1454619319*CF*NC*NL)/1822500 - 
       (1731018091*CF*lm*NC*NL)/567000 - (61696*CF*lm^2*NC*NL)/45 + 
       (611571969310164259*CF*NC*NH)/2362404048480 - 
       (1731018091*CF*lm*NC*NH)/567000 - (61696*CF*lm^2*NC*NH)/45 - 
       (18439981390289*CF^2*NC*Pi^2)/1571724000 + (4144*CF^2*lm*NC*Pi^2)/45 - 
       (125977862*CF*NM*NC*Pi^2)/42525 + (1036*CF*lm*NM*NC*Pi^2)/405 - 
       (6966311*CF*NC*NL*Pi^2)/6075 + (1036*CF*lm*NC*NL*Pi^2)/405 + 
       (1036*CF*lm*NC*NH*Pi^2)/405 - (5504994911381*CF^2*NC*Pi^3)/
        (860934420*Sqrt[3]) - (1558853630789*CF*NC*NH*Pi^3)/
        (43046721*Sqrt[3]) - (821539*CF^2*NC*Pi^4)/4050 + 
       (5847159259772251*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (100442349000*Sqrt[3]) + (627593615283644*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1506635235*Sqrt[3]) - 
       (245656*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (3145711377932*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (13286025*Sqrt[3]) - (3563094013232*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (786427844483*CF^2*NC*Pi*Log[3]^2)/(159432300*Sqrt[3]) - 
       (222693375827*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-5*CA*(9559989169 + 1538885040*lm) + 
          CF*(133086054767 + 50363510400*lm) + 
          60*((173844691 + 23316440*lm)*NM + 14*(2173067 + 1665460*lm)*NL + 
            5*(289411 + 4663288*lm)*NH))*Log[x]^2)/283500 + 
       (4*CF*NC*(2711165*CA - 96807338*CF + 8281400*NM + 1665460*NL)*
         Log[x]^3)/2025 - (2549229782325964*CF^2*NC*PolyGamma[2, 1])/
        158196699675 + (20381972*CF*NM*NC*PolyGamma[2, 1])/19845 - 
       (30050793981858463*CF*NC*NH*PolyGamma[2, 1])/949180198050 + 
       (6381400452266407*CF^2*NC*Zeta[3])/158196699675 + 
       (356408224*CF*NM*NC*Zeta[3])/19845 - (1154168*CF*NC*NL*Zeta[3])/
        135 - (50645744996306623*CF*NC*NH*Zeta[3])/474590099025 - 
       (CF*NC*Log[x]*(-40*(-19683*NM*(472826784361 + 49170612120*lm + 
              10668672000*lm^2 - 9021742800*Pi^2) - 551124*NL*
             (3945274873 + 1756093290*lm + 381024000*lm^2 + 301881300*Pi^2) - 
            5*NH*(6152189385766335 + 193565031671592*lm + 41998294195200*lm^
                2 - 3491832132967360*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
          5*CA*(195104642705322459 + 54343829342406240*lm + 
            9239624722944000*lm^2 + 5326375363409520*Pi^2 - 
            12331188601493440*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            5039795303424000*Zeta[3]) + CF*(1747677626581940583 + 
            1028283068537222400*lm + 302387718205440000*lm^2 + 
            41377426059236400*Pi^2 - 123311886014934400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 50397953034240000*Zeta[3])))/
        4687309620000 + (CA*CF*NC*(587861883372589056000*lm^2 + 
          521386844524501338180*Pi^2 + 83081383202562052000*Sqrt[3]*Pi^3 + 
          8066529244448136000*Pi^4 - 68747207760*lm*(-29924373401 + 
            15954400*Pi^2) + 64091352756262154400*Sqrt[3]*Pi*Log[3]^2 - 
          11*(1272942090185984163 + 68762592894921671760*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 174101618680020864000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 279671357481871219200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 57102747124101593600*
             PolyGamma[2, 1] + 60510062496078809600*Zeta[3])))/
        77959333599840000, (1005361681373763914827*CF^2*NC)/
        15749360323200000 - (362481991*CF^2*lm*NC)/1500 - 
       (883512*CF^2*lm^2*NC)/5 + (15838073698193*CF*NM*NC)/370440000 - 
       (682755091*CF*lm*NM*NC)/54000 - (24542*CF*lm^2*NM*NC)/5 + 
       (1870451357*CF*NC*NL)/810000 - (682755091*CF*lm*NC*NL)/54000 - 
       (24542*CF*lm^2*NC*NL)/5 + (6856620592582695070973*CF*NC*NH)/
        4491942555038400 - (682755091*CF*lm*NC*NH)/54000 - 
       (24542*CF*lm^2*NC*NH)/5 + (5735640001777*CF^2*NC*Pi^2)/75816000 + 
       (3528*CF^2*lm*NC*Pi^2)/5 + (509464649*CF*NM*NC*Pi^2)/3150 + 
       (98*CF*lm*NM*NC*Pi^2)/5 - (6107969*CF*NC*NL*Pi^2)/1350 + 
       (98*CF*lm*NC*NL*Pi^2)/5 + (98*CF*lm*NC*NH*Pi^2)/5 - 
       (139733758064579*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) - 
       (20931392916259*CF*NC*NH*Pi^3)/(86093442*Sqrt[3]) - 
       (5457221*CF^2*NC*Pi^4)/5400 + (1237903107611141*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3587226750*Sqrt[3]) + 
       (2328585354044504*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1506635235*Sqrt[3]) - (806078*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (19961965437797*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) - (23921591904296*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (19961965437797*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) - 
       (2990198988037*CF*NC*NH*Pi*Log[3]^2)/(15943230*Sqrt[3]) - 
       (CF*NC*(-2695*CA*(-119880067 + 591196320*lm) + 
          8*(11*CF*(102176540953 + 118507989600*lm) + 
            45*(11*(-5907127813 + 73153080*lm)*NM + 
              7*(66*(2335013 + 1741740*lm)*NL + 5*(1705919 + 22990968*lm)*
                 NH))))*Log[x]^2)/12474000 - 
       (4*CF*NC*(28753465*CA + 103715003*CF - 90*(1175910*NM + 29029*NL))*
         Log[x]^3)/675 - (120679442686072741*CF^2*NC*PolyGamma[2, 1])/
        7593441584400 + (1029550157*CF*NM*NC*PolyGamma[2, 1])/9450 - 
       (5899958495894579*CF*NC*NH*PolyGamma[2, 1])/45199057050 - 
       (573327007930113061*CF^2*NC*Zeta[3])/3796720792200 + 
       (222765857*CF*NM*NC*Zeta[3])/4725 - (187852*CF*NC*NL*Zeta[3])/5 + 
       (5296679598040141*CF*NC*NH*Zeta[3])/22599528525 + 
       CF*Log[x]*((1606733319701*NM*NC)/1323000 - (8149096*lm*NM*NC)/225 - 
         7056*lm^2*NM*NC - (2052587701*NC*NL)/23625 - (8149096*lm*NC*NL)/
          225 - 7056*lm^2*NC*NL - (95132292603863321*NC*NH)/54015663240 - 
         (8149096*lm*NC*NH)/225 - 7056*lm^2*NC*NH + (754722*NM*NC*Pi^2)/
          5 - (93338*NC*NL*Pi^2)/15 + (23921591904296*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-1194129635579063291/3124873080000 - (24922984*lm)/25 - 
           254016*lm^2 + (5838456061*Pi^2)/113400 + 
           (19961965437797*Im[PolyLog[2, (-1)^(1/3)]])/(79716150*Sqrt[3]) - 
           42336*Zeta[3]) + CA*NC*(19015856354441311/78121827000 + 
           (55933228*lm)/225 + 38808*lm^2 - (4532627023*Pi^2)/226800 - 
           (19961965437797*Im[PolyLog[2, (-1)^(1/3)]])/(159432300*Sqrt[3]) + 
           21168*Zeta[3])) + (CA*CF*NC*(12627634570368003648000*lm^2 - 
          16263241538394719806560*Pi^2 + 1581646407532969701000*Sqrt[3]*
           Pi^3 + 243690698808990972000*Pi^4 - 4331074088880*lm*
           (-11221056401 + 11642400*Pi^2) + 1220127228668290912200*Sqrt[3]*Pi*
           Log[3]^2 + 11*(-1962051263851121651583 - 2445700411645179050880*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 3427707475063190592000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 5324191543279814889600*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 337902439521003674800*
             PolyGamma[2, 1] + 5081490464122777191200*Zeta[3])))/
        467756001599040000, (-4436657512798001079917*CF^2*NC)/
        70872121454400000 - (4250399374*CF^2*lm*NC)/23625 - 
       (875184*CF^2*lm^2*NC)/5 - (11756794264812829*CF*NM*NC)/67512690000 - 
       (2311788256*CF*lm*NM*NC)/212625 - (72932*CF*lm^2*NM*NC)/15 + 
       (110707679063*CF*NC*NL)/12757500 - (2311788256*CF*lm*NC*NL)/212625 - 
       (72932*CF*lm^2*NC*NL)/15 + (98533316370460084206659*CF*NC*NH)/
        88435119052318500 - (2311788256*CF*lm*NC*NH)/212625 - 
       (72932*CF*lm^2*NC*NH)/15 - (6463522318505957*CF^2*NC*Pi^2)/
        20432412000 + (1456*CF^2*lm*NC*Pi^2)/5 - (951435127*CF*NM*NC*Pi^2)/
        12150 + (364*CF*lm*NM*NC*Pi^2)/45 - (9386497*CF*NC*NL*Pi^2)/2025 + 
       (364*CF*lm*NC*NL*Pi^2)/45 + (364*CF*lm*NC*NH*Pi^2)/45 - 
       (34930156266833*CF^2*NC*Pi^3)/(1147912560*Sqrt[3]) - 
       (61923416295041*CF*NC*NH*Pi^3)/(387420489*Sqrt[3]) - 
       (2591431*CF^2*NC*Pi^4)/2700 + (55416154023933541*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(225995285250*Sqrt[3]) + 
       (21645236495742166*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (13559717115*Sqrt[3]) - (961556*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (34930156266833*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31000725*Sqrt[3]) - (141539237245808*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23914845*Sqrt[3]) - 
       (34930156266833*CF^2*NC*Pi*Log[3]^2)/(1488034800*Sqrt[3]) - 
       (8846202327863*CF*NC*NH*Pi*Log[3]^2)/(71744535*Sqrt[3]) - 
       (CF*NC*(-495*CA*(89735540101 + 5178071360*lm) + 
          2*(33*CF*(1538741093497 + 254196230400*lm) + 
            40*(44*(5125844053 + 132393870*lm)*NM + 1386*(5355881 + 
                4202980*lm)*NL + 5*(99377669 + 1165066056*lm)*NH)))*
         Log[x]^2)/18711000 + (16*CF*NC*(47645855*CA - 229338457*CF - 
          1984200*NM + 2101490*NL)*Log[x]^3)/2025 - 
       (2278283033928936667*CF^2*NC*PolyGamma[2, 1])/11390162376600 + 
       (2295510293*CF*NM*NC*PolyGamma[2, 1])/396900 - 
       (427996869334769639*CF*NC*NH*PolyGamma[2, 1])/3417048712980 + 
       (CA*CF*NC*(3752581877948330380800*lm^2 + 22680378774524933978544*
           Pi^2 + 711673989811708908600*Sqrt[3]*Pi^3 + 68250148261093260000*
           Pi^4 - 1319946388992*lm*(-9975756554 + 4729725*Pi^2) + 
          549005649283318300920*Sqrt[3]*Pi*Log[3]^2 + 
          11*(18135182316972827133 - 521355177057166753728*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 1226655245109726835200*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 2395661015054479858560*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1275838499000204533520*
             PolyGamma[2, 1] - 1304275511466224746400*Zeta[3])))/
        140326800479712000 + (1722801741072330713*CF^2*NC*Zeta[3])/
        5695081188300 + (29661206693*CF*NM*NC*Zeta[3])/198450 - 
       (5371328*CF*NC*NL*Zeta[3])/135 - (102770635938122011*CF*NC*NH*
         Zeta[3])/341704871298 - 
       (CF*NC*Log[x]*(-81675*CA*(71387327724523431 + 7634910194421048*lm + 
            1270448399404800*lm^2 + 3682745399659914*Pi^2 - 
            1956088750942648*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            692971854220800*Zeta[3]) + 
          2*(10*(450130527*NL*(23831777099 + 9926780820*lm + 2095632000*
                 lm^2 + 1875378400*Pi^2) + 2381643*NM*(78559841337289 + 
                1876161574980*lm + 396074448000*lm^2 + 838098802800*Pi^2) + 
              5*NH*(29613341153500379601 + 893669416384018428*lm + 
                188661587311612800*lm^2 - 16783722752607912640*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 3267*CF*
             (1709735097357653379 + 366778695160231200*lm + 
              103945778133120000*lm^2 + 87495353836452450*Pi^2 - 
              48902218773566200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              17324296355520000*Zeta[3]))))/2552240088090000, 
      (169806487321063148254007*CF^2*NC)/255139637235840000 - 
       (418234991*CF^2*lm*NC)/540 - (2830296*CF^2*lm^2*NC)/5 - 
       (49178947546654039*CF*NM*NC)/54010152000 - (787588619*CF*lm*NM*NC)/
        19440 - (235858*CF*lm^2*NM*NC)/15 + (304894508189*CF*NC*NL)/
        10206000 - (787588619*CF*lm*NC*NL)/19440 - (235858*CF*lm^2*NC*NL)/
        15 + (886489157655117277096302451*CF*NC*NH)/148031966901290472000 - 
       (787588619*CF*lm*NC*NH)/19440 - (235858*CF*lm^2*NC*NH)/15 + 
       (706586319261811*CF^2*NC*Pi^2)/648648000 + 1960*CF^2*lm*NC*Pi^2 + 
       (23003328127*CF*NM*NC*Pi^2)/8505 + (490*CF*lm*NM*NC*Pi^2)/9 - 
       (6642083*CF*NC*NL*Pi^2)/405 + (490*CF*lm*NC*NL*Pi^2)/9 + 
       (490*CF*lm*NC*NH*Pi^2)/9 - (16360971752397377*CF^2*NC*Pi^3)/
        (185961834720*Sqrt[3]) - (244465031236825*CF*NC*NH*Pi^3)/
        (258280326*Sqrt[3]) - (7077091*CF^2*NC*Pi^4)/1800 + 
       (10256641678883679917*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8135830269000*Sqrt[3]) + (25731926092291022*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4519905705*Sqrt[3]) - 
       (2864022*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (2337281678913911*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (717445350*Sqrt[3]) - (55877721425560*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (2337281678913911*CF^2*NC*Pi*Log[3]^2)/(34437376800*Sqrt[3]) - 
       (6984715178195*CF*NC*NH*Pi*Log[3]^2)/(9565938*Sqrt[3]) - 
       (CF*NC*(-429*CA*(-5369962117651 + 632952012000*lm) + 
          8*(1287*CF*(-286416124627 + 172623276000*lm) + 
            25*(143*(-546664109657 + 1726232760*lm)*NM + 
              7*(2574*(18125463 + 13700260*lm)*NL + (3351261631 + 
                  35264469240*lm)*NH))))*Log[x]^2)/486486000 - 
       (2*CF*NC*(1816721413*CA + 1202759098*CF - 
          100*(89495328*NM + 685013*NL))*Log[x]^3)/2025 + 
       (53629870173423692657*CF^2*NC*PolyGamma[2, 1])/205022922778800 + 
       (9515963983*CF*NM*NC*PolyGamma[2, 1])/5670 - 
       (197917135673136479*CF*NC*NH*PolyGamma[2, 1])/406791513450 + 
       (CA*CF*NC*(14198698159736338632384000*lm^2 - 
          87518507552278459280988840*Pi^2 + 2407467910450016833419000*Sqrt[3]*
           Pi^3 + 329910353190919903802400*Pi^4 - 4222797236658000*lm*
           (-12942882361 + 11642400*Pi^2) + 1857189530918584414351800*Sqrt[3]*
           Pi*Log[3]^2 - 143*(456206022502041048642423 + 
            241236212287344151647840*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            328826490351959226816000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
            623392290098545817404800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                 Sqrt[3])]] + 150163636485586339439600*PolyGamma[2, 1] - 
            747636803242807479797600*Zeta[3])))/164182356561263040000 - 
       (3961266226538857639*CF^2*NC*Zeta[3])/4100458455576 - 
       (1119677957*CF*NM*NC*Zeta[3])/2835 - (4154780*CF*NC*NL*Zeta[3])/27 + 
       (218470318384806721*CF*NC*NH*Zeta[3])/203395756725 + 
       CF*Log[x]*((124422820290187*NM*NC)/5358150 - (3659773*lm*NM*NC)/27 - 
         25872*lm^2*NM*NC - (7834781117*NC*NL)/22680 - 
         (3659773*lm*NC*NL)/27 - 25872*lm^2*NC*NL - 
         (234897903701552096503*NC*NH)/34232426578350 - 
         (3659773*lm*NC*NH)/27 - 25872*lm^2*NC*NH + (59126302*NM*NC*Pi^2)/
          27 - (2068570*NC*NL*Pi^2)/81 + (55877721425560*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(617214987774513855199/84371573160000 - (11262796*lm)/3 - 
           931392*lm^2 + (3355221133*Pi^2)/4536 + 
           (2337281678913911*Im[PolyLog[2, (-1)^(1/3)]])/(2152336050*
             Sqrt[3]) - 155232*Zeta[3]) + 
         CA*NC*(-29093679824808719921/8437157316000 + (50037119*lm)/54 + 
           142296*lm^2 - (78629802479*Pi^2)/226800 - 
           (2337281678913911*Im[PolyLog[2, (-1)^(1/3)]])/(4304672100*
             Sqrt[3]) + 77616*Zeta[3])), 
      (194349967014968522902440773*CF^2*NC)/519998500027632780000 - 
       (16829454667*CF^2*lm*NC)/30870 - (18457344*CF^2*lm^2*NC)/35 - 
       (221094304647346892863*CF*NM*NC)/83868764364000 - 
       (7300073807*CF*lm*NM*NC)/222264 - (512704*CF*lm^2*NM*NC)/35 + 
       (3522524264078*CF*NC*NL)/72930375 - (7300073807*CF*lm*NC*NL)/
        222264 - (512704*CF*lm^2*NC*NL)/35 + 
       (22782785657775741418075919*CF*NC*NH)/5652129645321999840 - 
       (7300073807*CF*lm*NC*NH)/222264 - (512704*CF*lm^2*NC*NH)/35 - 
       (19315557785372269*CF^2*NC*Pi^2)/3178375200 + (5520*CF^2*lm*NC*Pi^2)/
        7 - (40782141251*CF*NM*NC*Pi^2)/19845 + (460*CF*lm*NM*NC*Pi^2)/21 - 
       (34581476*CF*NC*NL*Pi^2)/2205 + (460*CF*lm*NC*NL*Pi^2)/21 + 
       (460*CF*lm*NC*NH*Pi^2)/21 - (3814380080581421*CF^2*NC*Pi^3)/
        (32543321076*Sqrt[3]) - (227182713312725*CF*NC*NH*Pi^3)/
        (387420489*Sqrt[3]) - (151369*CF^2*NC*Pi^4)/42 + 
       (68693388467665316869*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (79731136636200*Sqrt[3]) + (100602510341986784*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(18983603961*Sqrt[3]) - 
       (4439160*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/7 - 
       (15257520322325684*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3515482215*Sqrt[3]) - (726984682600720*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(33480783*Sqrt[3]) - 
       (3814380080581421*CF^2*NC*Pi*Log[3]^2)/(42185786580*Sqrt[3]) - 
       (45436542662545*CF*NC*NH*Pi*Log[3]^2)/(100442349*Sqrt[3]) - 
       (CF*NC*(-91*CA*(167395634677741 + 2429221410000*lm) + 
          13*CF*(2429152009250639 + 111302508240000*lm) + 
          140*(13*(5414456771011 + 22083831000*lm)*NM + 
            11*(234*(139916583 + 111534500*lm)*NL + 7*(400198243 + 
                3728439000*lm)*NH)))*Log[x]^2)/397296900 + 
       (8*CF*NC*(6787240936*CA - 17630842055*CF - 3469317600*NM + 
          55767250*NL)*Log[x]^3)/6615 - (7840361921113451624*CF^2*NC*
         PolyGamma[2, 1])/2562786534735 - (8942830487*CF*NM*NC*
         PolyGamma[2, 1])/22050 - (111189186173186252*CF*NC*NH*
         PolyGamma[2, 1])/261508830075 + CA*CF*NC*
        (-175682918991068958482996033/594284000031580320000 + 
         (2819872*lm^2)/35 + (298336211721853*Pi^2)/97796160 + 
         (3814380080581421*Pi^3)/(65086642152*Sqrt[3]) + (50947*Pi^4)/28 + 
         lm*(629415343097/2222640 - (2530*Pi^2)/21) - 
         (68693388467665316869*Im[PolyLog[2, (-1)^(1/3)]])/
          (159462273272400*Sqrt[3]) + (2219580*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          7 + (7628760161162842*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3515482215*Sqrt[3]) + (3814380080581421*Pi*Log[3]^2)/
          (84371573160*Sqrt[3]) + (3920180960556725812*PolyGamma[2, 1])/
          2562786534735 - (3887486362228833526*Zeta[3])/2562786534735) + 
       (8668740787126836029*CF^2*NC*Zeta[3])/2562786534735 + 
       (20254064513*CF*NM*NC*Zeta[3])/11025 - (9583304*CF*NC*NL*Zeta[3])/
        63 - (1311901446322094728*CF*NC*NH*Zeta[3])/1830561810525 + 
       CF*Log[x]*((-42777824357059373*NM*NC)/1512784350 - 
         (30053672*lm*NM*NC)/245 - 25344*lm^2*NM*NC - (58178243551*NC*NL)/
          185220 - (30053672*lm*NC*NL)/245 - 25344*lm^2*NC*NL - 
         (55701223023121079941*NC*NH)/13070562875370 - (30053672*lm*NC*NH)/
          245 - 25344*lm^2*NC*NH - (68818700*NM*NC*Pi^2)/63 - 
         (4783372*NC*NL*Pi^2)/189 + (726984682600720*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) + 
         CF*NC*(-3302719832196308102926541/50023905726564000 - 
           (811828512*lm)/245 - 912384*lm^2 - (56393627567*Pi^2)/13230 + 
           (15257520322325684*Im[PolyLog[2, (-1)^(1/3)]])/
            (10546446645*Sqrt[3]) - 152064*Zeta[3]) + 
         CA*NC*(238412422930949197072291/7146272246652000 + 
           (208760156*lm)/245 + 139392*lm^2 + (28490855641*Pi^2)/13230 - 
           (7628760161162842*Im[PolyLog[2, (-1)^(1/3)]])/(10546446645*
             Sqrt[3]) + 76032*Zeta[3])), 
      (18062781047209311686808436661*CF^2*NC)/10697112000568445760000 - 
       (11450439607*CF^2*lm*NC)/5292 - (7905216*CF^2*lm^2*NC)/5 - 
       (253699749563833659557*CF*NM*NC)/10269644616000 - 
       (107802101747*CF*lm*NM*NC)/952560 - (658768*CF*lm^2*NM*NC)/15 + 
       (11420378861501*CF*NC*NL)/71442000 - (107802101747*CF*lm*NC*NL)/
        952560 - (658768*CF*lm^2*NC*NL)/15 + 
       (62744403023891526989174121577*CF*NC*NH)/3108671304927099912000 - 
       (107802101747*CF*lm*NC*NH)/952560 - (658768*CF*lm^2*NC*NH)/15 + 
       (1772871245506803619*CF^2*NC*Pi^2)/95351256000 + 
       4840*CF^2*lm*NC*Pi^2 + (361747775944*CF*NM*NC*Pi^2)/8505 + 
       (1210*CF*lm*NM*NC*Pi^2)/9 - (144974962*CF*NC*NL*Pi^2)/2835 + 
       (1210*CF*lm*NC*NL*Pi^2)/9 + (1210*CF*lm*NC*NH*Pi^2)/9 - 
       (926901874705034393*CF^2*NC*Pi^3)/(2928898896840*Sqrt[3]) - 
       (817383428962835*CF*NC*NH*Pi^3)/(258280326*Sqrt[3]) - 
       (40700341*CF^2*NC*Pi^4)/3150 + (28675503823832817103633*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7175802297258000*Sqrt[3]) + 
       (247971108297205526*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (13559717115*Sqrt[3]) - (61479528*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/35 - (1853803749410068786*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(158196699675*Sqrt[3]) - 
       (186830498048648*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) - (926901874705034393*CF^2*NC*Pi*Log[3]^2)/
        (3796720792200*Sqrt[3]) - (23353812256081*CF*NC*NH*Pi*Log[3]^2)/
        (9565938*Sqrt[3]) - 
       (CF*NC*(-91*CA*(-1967586430457533 + 38168345754000*lm) + 
          4*(52*CF*(-1618806570908183 + 109300262841000*lm) + 
            175*(13*(-95273356933021 + 69396992280*lm)*NM + 
              5*(18018*(13129441 + 10013996*lm)*NL + (20698037519 + 
                  180432179928*lm)*NH))))*Log[x]^2)/1702701000 + 
       (4*CF*NC*(-95250196571*CA + 120779758249*CF + 456998677800*NM + 
          876224650*NL)*Log[x]^3)/14175 + (1933323062311744291187*CF^2*NC*
         PolyGamma[2, 1])/263600900715600 + 
       (692377122953*CF*NM*NC*PolyGamma[2, 1])/28350 - 
       (5753357143760975953*CF*NC*NH*PolyGamma[2, 1])/3661123621050 - 
       (10055240344525265886607*CF^2*NC*Zeta[3])/922603152504600 - 
       (185358203347*CF*NM*NC*Zeta[3])/14175 - (14448404*CF*NC*NL*Zeta[3])/
        27 + (7195119382238530847*CF*NC*NH*Zeta[3])/1830561810525 + 
       CF*Log[x]*((49480882137750257*NM*NC)/129667230 - 
         (409333111*lm*NM*NC)/945 - 81312*lm^2*NM*NC - 
         (5311370731*NC*NL)/4536 - (409333111*lm*NC*NL)/945 - 
         81312*lm^2*NC*NL - (2750547043780471130257*NC*NH)/
          119813493024225 - (409333111*lm*NC*NH)/945 - 81312*lm^2*NC*NH + 
         (868978930*NM*NC*Pi^2)/27 - (7202422*NC*NL*Pi^2)/81 + 
         (186830498048648*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CF*NC*(404396614747908224687112479/
            2251075757695380000 - (1265939884*lm)/105 - 2927232*lm^2 + 
           (10397864057*Pi^2)/810 + (1853803749410068786*
             Im[PolyLog[2, (-1)^(1/3)]])/(474590099025*Sqrt[3]) - 
           487872*Zeta[3]) + CA*NC*(-16047089378982934054250243/
            180086060615630400 + (5578421981*lm)/1890 + 447216*lm^2 - 
           (2515984206149*Pi^2)/396900 - (926901874705034393*
             Im[PolyLog[2, (-1)^(1/3)]])/(474590099025*Sqrt[3]) + 
           243936*Zeta[3])) + CA*CF*NC*((3623224*lm^2)/15 - 
         (160523302115685079*Pi^2)/17336592000 + (926901874705034393*Pi^3)/
          (5857797793680*Sqrt[3]) + (4597549*Pi^4)/700 + 
         lm*(354300952445/381024 - (6655*Pi^2)/9) + 
         (926901874705034393*Pi*Log[3]^2)/(7593441584400*Sqrt[3]) + 
         (-14988977841199235563789130727 - 9160102941485155095584525520*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           12079348103719906108501248000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           26861242602116015639272742400*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
           50435758720363860370769981200*PolyGamma[2, 1] + 
           82587792149048933400102988000*Zeta[3])/13753429715016573120000), 
      (549531505282444977121774152063181*CF^2*NC)/
        18278987272971347482560000 - (215711128457*CF^2*lm*NC)/148176 - 
       (49097004*CF^2*lm^2*NC)/35 - (25362052701131565437828611*CF*NM*NC)/
        1105558051846248000 - (2334358810597*CF*lm*NM*NC)/26671680 - 
       (4091417*CF*lm^2*NM*NC)/105 + (4467056862445651*CF*NC*NL)/
        22404211200 - (2334358810597*CF*lm*NC*NL)/26671680 - 
       (4091417*CF*lm^2*NC*NL)/105 + (12819609267866730246815704469573*CF*NC*
         NH)/1007209502796380371488000 - (2334358810597*CF*lm*NC*NH)/
        26671680 - (4091417*CF*lm^2*NC*NH)/105 - 
       (60308127291009106577*CF^2*NC*Pi^2)/572107536000 + 
       (13310*CF^2*lm*NC*Pi^2)/7 - (42303397598131*CF*NM*NC*Pi^2)/952560 + 
       (6655*CF*lm*NM*NC*Pi^2)/126 - (2939979845*CF*NC*NL*Pi^2)/63504 + 
       (6655*CF*lm*NC*NL*Pi^2)/126 + (6655*CF*lm*NC*NH*Pi^2)/126 - 
       (501409855388980621*CF^2*NC*Pi^3)/(1301732843040*Sqrt[3]) - 
       (234340281194346155*CF*NC*NH*Pi^3)/(125524238436*Sqrt[3]) - 
       (433295819*CF^2*NC*Pi^4)/37800 + (4213464720708278565133*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1594622732724000*Sqrt[3]) + 
       (481993443211537843039*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (30753438416820*Sqrt[3]) - (64153826*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - (501409855388980621*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(35154822150*Sqrt[3]) - 
       (187472224955476924*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2711943423*Sqrt[3]) - (501409855388980621*CF^2*NC*Pi*Log[3]^2)/
        (1687431463200*Sqrt[3]) - (46868056238869231*CF*NC*NH*Pi*Log[3]^2)/
        (32543321076*Sqrt[3]) - 
       (CF*NC*(-(CA*(7614080747463607553 + 22860027797607000*lm)) + 
          CF*(15344616178707166909 + 149629272857064000*lm) + 
          1750*((3633587121032254 + 2375067823128*lm)*NM + 
            1287*(2289746553 + 1845429544*lm)*NL + 
            56*(5426402428 + 42411925413*lm)*NH))*Log[x]^2)/11918907000 + 
       (CF*NC*(14686174996109*CA - 31257297975361*CF - 
          700*(15988288092*NM - 32954099*NL))*Log[x]^3)/99225 - 
       (61958715078849848613547*CF^2*NC*PolyGamma[2, 1])/1230137536672800 - 
       (5755357149289*CF*NM*NC*PolyGamma[2, 1])/396900 - 
       (3533845427823702736163*CF*NC*NH*PolyGamma[2, 1])/2767809457513800 + 
       CA*CF*NC*(-281170207800140954800997023577351/
          18278987272971347482560000 + (45005587*lm^2)/210 + 
         (1828769666271487489*Pi^2)/34673184000 + (501409855388980621*Pi^3)/
          (2603465686080*Sqrt[3]) + (436490219*Pi^4)/75600 + 
         lm*(8045588449195/10668672 - (73205*Pi^2)/252) - 
         (4213464720708278565133*Im[PolyLog[2, (-1)^(1/3)]])/
          (3189245465448000*Sqrt[3]) + (32076913*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/35 + (501409855388980621*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(70309644300*Sqrt[3]) + 
         (501409855388980621*Pi*Log[3]^2)/(3374862926400*Sqrt[3]) + 
         (61958715078849848613547*PolyGamma[2, 1])/2460275073345600 - 
         (31103744338575988238441*Zeta[3])/1230137536672800) + 
       (129683180998414500121*CF^2*NC*Zeta[3])/2510484768720 + 
       (5822973723911*CF*NM*NC*Zeta[3])/198450 - 
       (94568500*CF*NC*NL*Zeta[3])/189 - (2016215698532878140563*CF*NC*NH*
         Zeta[3])/1383904728756900 + CF*Log[x]*
        ((-3180750428818103583509*NM*NC)/6135853323600 - 
         (9839621077*lm*NM*NC)/26460 - 75504*lm^2*NM*NC - 
         (4503880581169*NC*NL)/4445280 - (9839621077*lm*NC*NL)/26460 - 
         75504*lm^2*NC*NL - (6325573381492265357098739*NC*NH)/
          465834860878186800 - (9839621077*lm*NC*NH)/26460 - 
         75504*lm^2*NC*NH - (5355454387*NM*NC*Pi^2)/189 - 
         (47224355*NC*NL*Pi^2)/567 + (187472224955476924*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(8135830269*Sqrt[3]) + 
         CF*NC*(-178668408972899688479565650543/169080801355786320000 - 
           (7425569437*lm)/735 - 2718144*lm^2 - (3946930538533*Pi^2)/52920 + 
           (501409855388980621*Im[PolyLog[2, (-1)^(1/3)]])/
            (105464466450*Sqrt[3]) - 453024*Zeta[3]) + 
         CA*NC*(4476067431663555506956472051/8454040067789316000 + 
           (136205533607*lm)/52920 + 415272*lm^2 + (59319344233153*Pi^2)/
            1587600 - (501409855388980621*Im[PolyLog[2, (-1)^(1/3)]])/
            (210928932900*Sqrt[3]) + 226512*Zeta[3])), 
      (-3844142656797244988024328727205203*CF^2*NC)/
        46043862984977388410880000 - (12765517217*CF^2*lm*NC)/2352 - 
       (19828116*CF^2*lm^2*NC)/5 - (21989816299144540049287393*CF*NM*NC)/
        46796108014656000 - (120179091757*CF*lm*NM*NC)/423360 - 
       (550781*CF*lm^2*NM*NC)/5 + (812586548837*CF*NC*NL)/1296000 - 
       (120179091757*CF*lm*NC*NL)/423360 - (550781*CF*lm^2*NC*NL)/5 + 
       (17041420664973679068480967347856753*CF*NC*NH)/
        282766873556492386578316800 - (120179091757*CF*lm*NC*NH)/423360 - 
       (550781*CF*lm^2*NC*NH)/5 + (12928638497143813721*CF^2*NC*Pi^2)/
        40864824000 + 10890*CF^2*lm*NC*Pi^2 + (492703662229*CF*NM*NC*Pi^2)/
        756 + (605*CF*lm*NM*NC*Pi^2)/2 - (1070864993*CF*NC*NL*Pi^2)/7560 + 
       (605*CF*lm*NC*NL*Pi^2)/2 + (605*CF*lm*NC*NH*Pi^2)/2 - 
       (9910641365619476621*CF^2*NC*Pi^3)/(10041939074880*Sqrt[3]) - 
       (588659909640795895*CF*NC*NH*Pi^3)/(62762119218*Sqrt[3]) - 
       (402520327*CF^2*NC*Pi^4)/10800 + (139287771795741222571433*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12301375366728000*Sqrt[3]) + 
       (8256427671913736533*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (156905298045*Sqrt[3]) - (23987909*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (9910641365619476621*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(271194342300*Sqrt[3]) - 
       (134550836489324776*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) - (9910641365619476621*CF^2*NC*Pi*Log[3]^2)/
        (13017328430400*Sqrt[3]) - (16818854561165597*CF*NC*NH*Pi*Log[3]^2)/
        (2324522934*Sqrt[3]) + CF*((12655924498642681283*CF*NC)/3405402000 - 
         42447024*CF*lm*NC + CA*(-179100308809743004633/95351256000 + 
           6484962*lm)*NC + (201203265695569*NM*NC)/25740 - 
         1179084*lm*NM*NC - (13824175*NC*NL)/9 - 1179084*lm*NC*NL - 
         (160249466191*NC*NH)/1021020 - 1179084*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-14876258521511*CA + 294*(93364643291*CF + 
            900*(241641135*NM + 98257*NL)))*Log[x]^3)/33075 + 
       (1543602288637738471743439*CF^2*NC*PolyGamma[2, 1])/
        11071237830055200 + (239051635927*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (223708582291422554581*CF*NC*NH*PolyGamma[2, 1])/49425168884175 - 
       (920714289752845368713927*CF^2*NC*Zeta[3])/5535618915027600 - 
       (168648592396*CF*NM*NC*Zeta[3])/675 - 1635738*CF*NC*NL*Zeta[3] + 
       (608179298255518159738*CF*NC*NH*Zeta[3])/49425168884175 + 
       CA*CF*NC*(80812610302587468935327240568452719/
          1974130625480905528116480000 + (6058591*lm^2)/10 - 
         (10962430670698474421*Pi^2)/69346368000 + (9910641365619476621*Pi^3)/
          (20083878149760*Sqrt[3]) + (407747527*Pi^4)/21600 + 
         lm*(394974042595/169344 - (6655*Pi^2)/4) - 
         (139287771795741222571433*Im[PolyLog[2, (-1)^(1/3)]])/
          (24602750733456000*Sqrt[3]) + (23987909*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/10 + (9910641365619476621*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(542388684600*Sqrt[3]) + 
         (9910641365619476621*Pi*Log[3]^2)/(26034656860800*Sqrt[3]) - 
         (1543602288637738471743439*PolyGamma[2, 1])/22142475660110400 + 
         (187758975496678873463191*Zeta[3])/2214247566011040) + 
       CF*Log[x]*((76153081462810676087*NM*NC)/12985932960 - 
         (1541474209*lm*NM*NC)/1260 - 226512*lm^2*NM*NC - 
         (1372364941*NC*NL)/392 - (1541474209*lm*NC*NL)/1260 - 
         226512*lm^2*NC*NL - (18327687749734157343109512517*NC*NH)/
          269252549587591970400 - (1541474209*lm*NC*NH)/1260 - 
         226512*lm^2*NC*NH + 483153584*NM*NC*Pi^2 - 272018*NC*NL*Pi^2 + 
         (134550836489324776*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(8113338055715659513232772458959/
            2608675220917846080000 - (1196609689*lm)/35 - 8154432*lm^2 + 
           (1444444918291*Pi^2)/6480 + (9910641365619476621*
             Im[PolyLog[2, (-1)^(1/3)]])/(813583026900*Sqrt[3]) - 
           1359072*Zeta[3]) + CA*NC*(-115744220797609151470419892147/
            74533577740509888000 + (20951887979*lm)/2520 + 1245816*lm^2 - 
           (353127766661777*Pi^2)/3175200 - (9910641365619476621*
             Im[PolyLog[2, (-1)^(1/3)]])/(1627166053800*Sqrt[3]) + 
           679536*Zeta[3])), (13547076788616530060250545866754087021*CF^2*NC)/
        15793045003847244224931840000 - (11730378159061*CF^2*lm*NC)/3333960 - 
       (118341344*CF^2*lm^2*NC)/35 - (375534681520311074439857*CF*NM*NC)/
        54595459350432000 - (5070317038961*CF*lm*NM*NC)/24004512 - 
       (29585336*CF*lm^2*NM*NC)/315 + (19051963239496811*CF*NC*NL)/
        28005264000 - (5070317038961*CF*lm*NC*NL)/24004512 - 
       (29585336*CF*lm^2*NC*NL)/315 + (106940691105586698424130359518575353*
         CF*NC*NH)/2969052172343170059072326400 - 
       (5070317038961*CF*lm*NC*NH)/24004512 - (29585336*CF*lm^2*NC*NH)/
        315 - (91310491104870140311*CF^2*NC*Pi^2)/52809926400 + 
       (263780*CF^2*lm*NC*Pi^2)/63 - (598325481025421*CF*NM*NC*Pi^2)/
        714420 + (65945*CF*lm*NM*NC*Pi^2)/567 - (21904091374*CF*NC*NL*Pi^2)/
        178605 + (65945*CF*lm*NC*NL*Pi^2)/567 + (65945*CF*lm*NC*NH*Pi^2)/
        567 - (7859113986629429395*CF^2*NC*Pi^3)/(7029357352416*Sqrt[3]) - 
       (55540208311590340*CF*NC*NH*Pi^3)/(10460353203*Sqrt[3]) - 
       (728537359*CF^2*NC*Pi^4)/22680 + (62702444812158042808223*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8610962756709600*Sqrt[3]) + 
       (972114162332610185393*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (23065078812615*Sqrt[3]) - (100183226*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/21 - (1571822797325885879*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37967207922*Sqrt[3]) - 
       (177728666597089088*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (903981141*Sqrt[3]) - (1571822797325885879*CF^2*NC*Pi*Log[3]^2)/
        (1822425980256*Sqrt[3]) - (11108041662318068*CF*NC*NH*Pi*Log[3]^2)/
        (2711943423*Sqrt[3]) - 
       (CF*NC*(-51*CA*(99099953945423957231 + 55422754292505600*lm) + 
          7*(119*CF*(12152143212324191393 + 22210231775846400*lm) + 
            240*(85*(34230748489733569 + 3598880148864*lm)*NM + 
              9*(4862*(8604740377 + 6990831680*lm)*NL + 35*(142850999651 + 
                  971126389376*lm)*NH))))*Log[x]^2)/486291405600 + 
       (CF*NC*(147494482948124*CA - 3*(99597898054537*CF + 
            560*(80790850203*NM - 24967256*NL)))*Log[x]^3)/59535 - 
       (114137280569374618960997*CF^2*NC*PolyGamma[2, 1])/138390472875690 - 
       (32639339385356*CF*NM*NC*PolyGamma[2, 1])/99225 - 
       (14398355371011579042973*CF*NC*NH*PolyGamma[2, 1])/4151714186270700 + 
       CA*CF*NC*(-424350467403939683028262063620904159/
          987065312740452764058240000 + (162719348*lm^2)/315 + 
         (53962240850675871811*Pi^2)/62411731200 + (7859113986629429395*Pi^3)/
          (14058714704832*Sqrt[3]) + (244252613*Pi^4)/15120 + 
         lm*(436685560039751/240045120 - (725395*Pi^2)/1134) - 
         (62702444812158042808223*Im[PolyLog[2, (-1)^(1/3)]])/
          (17221925513419200*Sqrt[3]) + (50091613*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/21 + (1571822797325885879*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(75934415844*Sqrt[3]) + 
         (1571822797325885879*Pi*Log[3]^2)/(3644851960512*Sqrt[3]) + 
         (114137280569374618960997*PolyGamma[2, 1])/276780945751380 - 
         (46389247632376902191123*Zeta[3])/110712378300552) + 
       (116394644074950640538831*CF^2*NC*Zeta[3])/138390472875690 + 
       (48424468461788*CF*NM*NC*Zeta[3])/99225 - 
       (92036620*CF*NC*NL*Zeta[3])/63 - (5153660872905925594573*CF*NC*NH*
         Zeta[3])/2075857093135350 + CF*Log[x]*
        ((-54429342862214496800929*NM*NC)/6135853323600 - 
         (119783376691*lm*NM*NC)/119070 - 201344*lm^2*NM*NC - 
         (16164059362421*NC*NL)/5556600 - (119783376691*lm*NC*NL)/119070 - 
         201344*lm^2*NC*NL - (1734197921830455814666602379*NC*NH)/
          44875424931265328400 - (119783376691*lm*NC*NH)/119070 - 
         201344*lm^2*NC*NH - (107794124084*NM*NC*Pi^2)/189 - 
         (137923040*NC*NL*Pi^2)/567 + (177728666597089088*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2711943423*Sqrt[3]) + 
         CF*NC*(-12094517742852200126763383463739/730429061856996902400 - 
           (181629514022*lm)/6615 - 7248384*lm^2 - (295424030145271*Pi^2)/
            238140 + (1571822797325885879*Im[PolyLog[2, (-1)^(1/3)]])/
            (113901623766*Sqrt[3]) - 1208064*Zeta[3]) + 
         CA*NC*(15123842061238733466627448623581/1826072654642492256000 + 
           (1653253564721*lm)/238140 + 1107392*lm^2 + (84435602095379*Pi^2)/
            136080 - (1571822797325885879*Im[PolyLog[2, (-1)^(1/3)]])/
            (227803247532*Sqrt[3]) + 604032*Zeta[3])), 
      (-103513608992111900416482612792223338433*CF^2*NC)/
        38764746827625054006650880000 - (11889399237349*CF^2*lm*NC)/952560 - 
       (45598696*CF^2*lm^2*NC)/5 - (1155353947348431627894233497*CF*NM*NC)/
        140388324043968000 - (22386310253941*CF*lm*NM*NC)/34292160 - 
       (11399674*CF*lm^2*NM*NC)/45 + (218734553333867*CF*NC*NL)/107163000 - 
       (22386310253941*CF*lm*NC*NL)/34292160 - (11399674*CF*lm^2*NC*NL)/
        45 + (14226239149097418631776144318900775827649*CF*NC*NH)/
        87277409357579157579330371904000 - (22386310253941*CF*lm*NC*NH)/
        34292160 - (11399674*CF*lm^2*NC*NH)/45 + 
       (300945741885831656362129*CF^2*NC*Pi^2)/58354968672000 + 
       (204490*CF^2*lm*NC*Pi^2)/9 + (997329166396223*CF*NM*NC*Pi^2)/102060 + 
       (102245*CF*lm*NM*NC*Pi^2)/162 - (72779958823*CF*NC*NL*Pi^2)/204120 + 
       (102245*CF*lm*NC*NL*Pi^2)/162 + (102245*CF*lm*NC*NH*Pi^2)/162 - 
       (2608525070592151643801*CF^2*NC*Pi^3)/(948963242576160*Sqrt[3]) - 
       (7116684471900375610*CF*NC*NH*Pi^3)/(282429536481*Sqrt[3]) - 
       (10987026193*CF^2*NC*Pi^4)/113400 + (1063834838364772074686389*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(36327499129868625*Sqrt[3]) + 
       (1367039917405340617007*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) - (1252839302*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - (2608525070592151643801*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(25627865347350*Sqrt[3]) - 
       (3253341472868743136*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (2608525070592151643801*CF^2*NC*Pi*Log[3]^2)/
        (1230137536672800*Sqrt[3]) - (203333842054296446*CF*NC*NH*Pi*
         Log[3]^2)/(10460353203*Sqrt[3]) - 
       (CF*NC*(-447678*CA*(-3187373421999156451 + 1902185581296000*lm) + 
          3553*CF*(-801722648091527198003 + 1568784326683392000*lm) + 
          29400*(2261*(-81488264386136749 + 2329206834240*lm)*NM + 
            151315164*(45126459 + 34803760*lm)*NL + 
            3*(263720495087957 + 1755445550738880*lm)*NH))*Log[x]^2)/
        46197683532000 + (CF*NC*(-2207127151711132*CA + 4349303191376193*CF + 
          999600*(8629015593*NM + 665366*NL))*Log[x]^3)/297675 + 
       (711350863661105554664237641*CF^2*NC*PolyGamma[2, 1])/
        298923421411490400 + (72962752096544*CF*NM*NC*PolyGamma[2, 1])/
        14175 - (1055852884627288011907*CF*NC*NH*PolyGamma[2, 1])/
        88965303991515 - (15790220426090328571926539*CF^2*NC*Zeta[3])/
        5978468428229808 - (59097271649762*CF*NM*NC*Zeta[3])/14175 - 
       (40537718*CF*NC*NL*Zeta[3])/9 + (3045919198593483362866*CF*NC*NH*
         Zeta[3])/88965303991515 + CF*Log[x]*
        ((151820436732982427579489*NM*NC)/1753100949600 - 
         (106431132379*lm*NM*NC)/34020 - 572572*lm^2*NM*NC - 
         (6434483305711*NC*NL)/680400 - (106431132379*lm*NC*NL)/34020 - 
         572572*lm^2*NC*NL - (32006729586659529933401425570969*NC*NH)/
          174960306722017262365920 - (106431132379*lm*NC*NH)/34020 - 
         572572*lm^2*NC*NH + (195584297990*NM*NC*Pi^2)/27 - 
         (60704332*NC*NL*Pi^2)/81 + (3253341472868743136*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(2198550667689347569233430089187003/44821783341224809920000 - 
           (82894128889*lm)/945 - 20612592*lm^2 + (220369607388928*Pi^2)/
            59535 + (2608525070592151643801*Im[PolyLog[2, (-1)^(1/3)]])/
            (76883596042050*Sqrt[3]) - 3435432*Zeta[3]) + 
         CA*NC*(-5495061440982847878290113463719/224108916706124049600 + 
           (1443447048329*lm)/68040 + 3149146*lm^2 - (8811669261836719*Pi^2)/
            4762800 - (2608525070592151643801*Im[PolyLog[2, (-1)^(1/3)]])/
            (153767192084100*Sqrt[3]) + 1717716*Zeta[3])) + 
       CA*CF*NC*((62698207*lm^2)/45 - (15472759155845354513*Pi^2)/
          6001128000 + (2608525070592151643801*Pi^3)/(1897926485152320*
           Sqrt[3]) + (3700513531*Pi^4)/75600 + 
         lm*(367868795606279/68584320 - (1124695*Pi^2)/324) + 
         (2608525070592151643801*Pi*Log[3]^2)/(2460275073345600*Sqrt[3]) + 
         (8303302958693520147420548926314681777 - 
           30407372290323938275258969315599360*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 37167855886016699218932238665984000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           105687290876509520095487187012595200*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
           7412852478088630839542856117404266400*PolyGamma[2, 1] + 
           8254527111361788693382601363186878400*Zeta[3])/
          6230048597296883679640320000), 
      (5569595132792941009766556041466275193815453*CF^2*NC)/
        299280458972191541954490501120000 - (43581900958189*CF^2*lm*NC)/
        5556600 - (52657176*CF^2*lm^2*NC)/7 + 
       (834057598545368362646028604981*CF*NM*NC)/167642182367920260000 - 
       (94089347747989*CF*lm*NM*NC)/200037600 - (4388098*CF*lm^2*NM*NC)/
        21 + (566249953908896597*CF*NC*NL)/280052640000 - 
       (94089347747989*CF*lm*NC*NL)/200037600 - (4388098*CF*lm^2*NC*NL)/
        21 + (106684663972024323119904205929440416784839*CF*NC*NH)/
        1145515997818226443228711131240000 - (94089347747989*CF*lm*NC*NH)/
        200037600 - (4388098*CF*lm^2*NC*NH)/21 - 
       (527978800303683295061827*CF^2*NC*Pi^2)/19451656224000 + 
       (899756*CF^2*lm*NC*Pi^2)/105 - (34331982031715653*CF*NM*NC*Pi^2)/
        2381400 + (224939*CF*lm*NM*NC*Pi^2)/945 - 
       (708365427341*CF*NC*NL*Pi^2)/2381400 + (224939*CF*lm*NC*NL*Pi^2)/
        945 + (224939*CF*lm*NC*NH*Pi^2)/945 - 
       (199036197031902811513*CF^2*NC*Pi^3)/(67783088755440*Sqrt[3]) - 
       (23337768818970359003*CF*NC*NH*Pi^3)/(1694577218886*Sqrt[3]) - 
       (1538799119*CF^2*NC*Pi^4)/18900 + (15275159751616372928311*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(830342837254140*Sqrt[3]) + 
       (43452962973623114117167*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (415171418627070*Sqrt[3]) - (56992364*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (199036197031902811513*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1830561810525*Sqrt[3]) - 
       (186702150551762872024*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(366112362105*Sqrt[3]) - 
       (199036197031902811513*CF^2*NC*Pi*Log[3]^2)/(87866966905200*Sqrt[3]) - 
       (23337768818970359003*CF*NC*NH*Pi*Log[3]^2)/(2196674172630*Sqrt[3]) - 
       (CF*NC*(-38*CA*(22006002432584020448657 + 2144522630660810400*lm) + 
          35*(19*CF*(2515607272427503369277 + 802107165753653760*lm) + 
            16*(38*(41731847372732326739 + 696273581383380*lm)*NM + 
              3*(1801371*(5989930921 + 4895973880*lm)*NL + 
                14*(103855034601121 + 629961811727820*lm)*NH))))*Log[x]^2)/
        5133075948000 + (CF*NC*(3920001990930665*CA - 7859044100046541*CF - 
          840*(4799876819934*NM - 227313073*NL))*Log[x]^3)/99225 - 
       (1959129127495073258605915561*CF^2*NC*PolyGamma[2, 1])/
        149461710705745200 - (329199129690409*CF*NM*NC*PolyGamma[2, 1])/
        52920 - (647561207528243035331089*CF*NC*NH*PolyGamma[2, 1])/
        74730855352872600 + CA*CF*NC*
        (-69640169237942692964497693447691372190559/
          7482011474304788548862262528000 + (24134539*lm^2)/21 + 
         (27148705485690583297*Pi^2)/2000376000 + 
         (199036197031902811513*Pi^3)/(135566177510880*Sqrt[3]) + 
         (171777463*Pi^4)/4200 + lm*(1620172553551079/400075200 - 
           (2474329*Pi^2)/1890) - (15275159751616372928311*
           Im[PolyLog[2, (-1)^(1/3)]])/(1660685674508280*Sqrt[3]) + 
         (28496182*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (199036197031902811513*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3661123621050*Sqrt[3]) + (199036197031902811513*Pi*Log[3]^2)/
          (175733933810400*Sqrt[3]) + (1959129127495073258605915561*
           PolyGamma[2, 1])/298923421411490400 - 
         (995268454451526233841057611*Zeta[3])/149461710705745200) + 
       (995852485421282340047417597*CF^2*NC*Zeta[3])/74730855352872600 + 
       (208826241938903*CF*NM*NC*Zeta[3])/26460 - 
       (406446976*CF*NC*NL*Zeta[3])/105 - (121819722189615050024209*CF*NC*
         NH*Zeta[3])/37365427676436300 + CF*Log[x]*
        ((-210971834272231638589714169*NM*NC)/1477718008767000 - 
         (492518690521*lm*NM*NC)/198450 - 490776*lm^2*NM*NC - 
         (422145227939861*NC*NL)/55566000 - (492518690521*lm*NC*NL)/
          198450 - 490776*lm^2*NC*NL - (328985459684605686257607397984117*NC*
           NH)/3280505751037823669361000 - (492518690521*lm*NC*NH)/198450 - 
         490776*lm^2*NC*NH - (3200226940682*NM*NC*Pi^2)/315 - 
         (609220586*NC*NL*Pi^2)/945 + (186702150551762872024*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1098337086315*Sqrt[3]) + 
         CF*NC*(-35656591149188317308781061500279934737/
            142488449241753670735680000 - (749667346142*lm)/11025 - 
           17667936*lm^2 - (15684091661413789*Pi^2)/793800 + 
           (199036197031902811513*Im[PolyLog[2, (-1)^(1/3)]])/
            (5491685431575*Sqrt[3]) - 2944656*Zeta[3]) + 
         CA*NC*(445735917152744437641552503902672211/
            3562211231043841768392000 + (6781228556531*lm)/396900 + 
           2699268*lm^2 + (7842488209620079*Pi^2)/793800 - 
           (199036197031902811513*Im[PolyLog[2, (-1)^(1/3)]])/
            (10983370863150*Sqrt[3]) + 1472328*Zeta[3])), 
      (-13364197536406113189413511012949621380195887*CF^2*NC)/
        230873496921404903793464100864000 - (2597070641921*CF^2*lm*NC)/
        97200 - 19523504*CF^2*lm^2*NC - (52651225648562877866413138705391*CF*
         NM*NC)/383182131126674880000 - (4890106186721*CF*lm*NM*NC)/
        3499200 - (4880876*CF*lm^2*NM*NC)/9 + (528275030692943*CF*NC*NL)/
        90720000 - (4890106186721*CF*lm*NC*NL)/3499200 - 
       (4880876*CF*lm^2*NC*NL)/9 + 
       (33485697308101118175842963401923205630260139*CF*NC*NH)/
        82477151842912303912467201449280000 - (4890106186721*CF*lm*NC*NH)/
        3499200 - (4880876*CF*lm^2*NC*NH)/9 + 
       (804970333265138671187*CF^2*NC*Pi^2)/10007712000 + 
       (2004002*CF^2*lm*NC*Pi^2)/45 + (73038162997120117*CF*NM*NC*Pi^2)/
        510300 + (1002001*CF*lm*NM*NC*Pi^2)/810 - 
       (120912582791*CF*NC*NL*Pi^2)/145800 + (1002001*CF*lm*NC*NL*Pi^2)/
        810 + (1002001*CF*lm*NC*NH*Pi^2)/810 - 
       (6390175394274149141489*CF^2*NC*Pi^3)/(915071698198440*Sqrt[3]) - 
       (1903156551801193100657*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) - 
       (1873794923*CF^2*NC*Pi^4)/8100 + (1284756450888403290090259*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(18301433963968800*Sqrt[3]) + 
       (89904030966412572915133*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (266895911974545*Sqrt[3]) - (411967556*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (1825764398364042611854*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7060738412025*Sqrt[3]) - 
       (1087518029600681771804*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) - 
       (912882199182021305927*CF^2*NC*Pi*Log[3]^2)/(169457721888600*
         Sqrt[3]) - (271879507400170442951*CF*NC*NH*Pi*Log[3]^2)/
        (5648590729620*Sqrt[3]) - 
       (CF*NC*(-57*CA*(-55861839248058133138117 + 5533698303218685600*lm) + 
          5*(19*CF*(-67013379869012822680243 + 21732342427186110720*lm) + 
            168*(19*(-710211224877951895663 + 3593310586505640*lm)*NM + 
              9*(235379144*(41638787 + 32228335*lm)*NL + (1260238185570827 + 
                  7585877904845240*lm)*NH))))*Log[x]^2)/6599669076000 + 
       (CF*NC*(-4991438061960340*CA + 9956578131765273*CF + 
          18170863542667080*NM + 246353392740*NL)*Log[x]^3)/42525 + 
       (61771720305131709127626223723*CF^2*NC*PolyGamma[2, 1])/
        1614186475622048160 + (2108791047514537*CF*NM*NC*PolyGamma[2, 1])/
        28350 - (691134232248426924094111*CF*NC*NH*PolyGamma[2, 1])/
        24020632077709050 - (164657698502979581181862689409*CF^2*NC*Zeta[3])/
        4035466189055120400 - (918766322195483*CF*NM*NC*Zeta[3])/14175 - 
       (511945252*CF*NC*NL*Zeta[3])/45 + (1041892245432716057363009*CF*NC*
         NH*Zeta[3])/12010316038854525 + 
       CA*CF*NC*(116911276602363208130828173570596213664936477/
          4040286196124585816385621765120000 + (26844818*lm^2)/9 - 
         (2344509392651112436003*Pi^2)/58296672000 + 
         (6390175394274149141489*Pi^3)/(1830143396396880*Sqrt[3]) + 
         (209980771*Pi^4)/1800 - (847*lm*(-94874559973 + 56216160*Pi^2))/
          6998400 - (1284756450888403290090259*Im[PolyLog[2, (-1)^(1/3)]])/
          (36602867927937600*Sqrt[3]) + (205983778*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/15 + (912882199182021305927*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(7060738412025*Sqrt[3]) + 
         (912882199182021305927*Pi*Log[3]^2)/(338915443777200*Sqrt[3]) - 
         (61771720305131709127626223723*PolyGamma[2, 1])/
          3228372951244096320 + (164744546115583045375322127001*Zeta[3])/
          8070932378110240800) + CF*Log[x]*
        ((392778576297118550066842511*NM*NC)/316653859021500 - 
         (179143783247*lm*NM*NC)/24300 - (4008004*lm^2*NM*NC)/3 - 
         (53273188288319*NC*NL)/2268000 - (179143783247*lm*NC*NL)/24300 - 
         (4008004*lm^2*NC*NL)/3 - (13377418313930056730591759411638679*NC*
           NH)/29524551759340413024249000 - (179143783247*lm*NC*NH)/24300 - 
         (4008004*lm^2*NC*NH)/3 + (14421269023891*NM*NC*Pi^2)/135 - 
         (766915877*NC*NL*Pi^2)/405 + (1087518029600681771804*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(404843986097241539164310879602874698859/
            549598304218192729980480000 - (139915444097*lm)/675 - 
           48096048*lm^2 + (19960572489922177*Pi^2)/340200 + 
           (1825764398364042611854*Im[PolyLog[2, (-1)^(1/3)]])/
            (21182215236075*Sqrt[3]) - 8016008*Zeta[3]) + 
         CA*NC*(-10120695745403652818904412868184844979/
            27479915210909636499024000 + (2425089269317*lm)/48600 + 
           (22044022*lm^2)/3 - (1247466063480214*Pi^2)/42525 - 
           (912882199182021305927*Im[PolyLog[2, (-1)^(1/3)]])/
            (21182215236075*Sqrt[3]) + 4008004*Zeta[3])), 
      (6455942555831203934556641510816636418206559006793*CF^2*NC)/
        18474882012812356076392653124638720000 - (96155687067743*CF^2*lm*NC)/
        5880600 - 15659488*CF^2*lm^2*NC + 
       (1670359332159370388619137713896912749*CF*NM*NC)/
        11827108068290383508640000 - (207427702436543*CF*lm*NM*NC)/
        211701600 - (3914872*CF*lm^2*NM*NC)/9 + 
       (1400661344437285943*CF*NC*NL)/259334460000 - 
       (207427702436543*CF*lm*NC*NL)/211701600 - (3914872*CF*lm^2*NC*NL)/
        9 + (82862945099651881447008385438693982754986441*CF*NC*NH)/
        371147183293105367606102406521760000 - (207427702436543*CF*lm*NC*NH)/
        211701600 - (3914872*CF*lm^2*NC*NH)/9 - 
       (37608423661513443241509353*CF^2*NC*Pi^2)/91700665056000 + 
       (742924*CF^2*lm*NC*Pi^2)/45 - (186364345182293903*CF*NM*NC*Pi^2)/
        801900 + (185731*CF*lm*NM*NC*Pi^2)/405 - 
       (268830134963*CF*NC*NL*Pi^2)/400950 + (185731*CF*lm*NC*NL*Pi^2)/
        405 + (185731*CF*lm*NC*NH*Pi^2)/405 - 
       (95313183476873158425059*CF^2*NC*Pi^3)/(13421051573577120*Sqrt[3]) - 
       (4540789498699543877893*CF*NC*NH*Pi^3)/(137260754729766*Sqrt[3]) - 
       (3080264447*CF^2*NC*Pi^4)/16200 + (6381896421042956247908269*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(147631567309348320*Sqrt[3]) + 
       (583463847273130152025831*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2402063207770905*Sqrt[3]) - (380434522*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (95313183476873158425059*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(362451238483950*Sqrt[3]) - 
       (5189473712799478717592*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4236443047215*Sqrt[3]) - 
       (95313183476873158425059*CF^2*NC*Pi*Log[3]^2)/(17397659447229600*
         Sqrt[3]) - (648684214099934839699*CF*NC*NH*Pi*Log[3]^2)/
        (25418658283290*Sqrt[3]) - 
       (CF*NC*(-3*CA*(59549730851212544148073019 + 963042791522832820800*
             lm) + 5*(CF*(71462694974795728957003901 + 3782131690344216168960*
               lm) + 3696*(7*(1565095671512719412399 + 4060730272907880*lm)*
               NM + 3*(3602742*(3202540557 + 2629951660*lm)*NL + 
                (1718075446386991 + 9475037303451720*lm)*NH))))*Log[x]^2)/
        72596359836000 + (CF*NC*(283090324317162380*CA - 
          33*(17164424588271833*CF + 9503620410238080*NM - 68378743160*NL))*
         Log[x]^3)/467775 - (33843694100185883660670001217*CF^2*NC*
         PolyGamma[2, 1])/168144424543963350 - 
       (42155071078060379*CF*NM*NC*PolyGamma[2, 1])/396900 - 
       (3052992593634073655419486*CF*NC*NH*PolyGamma[2, 1])/
        151329982089567015 + CA*CF*NC*
        (-8877259286677344759870848676173096271250061034379/
          50805925535233979210079796092756480000 + (21531796*lm^2)/9 + 
         (206640233098800193597477*Pi^2)/1007699616000 + 
         (95313183476873158425059*Pi^3)/(26842103147154240*Sqrt[3]) + 
         (343572359*Pi^4)/3600 + lm*(324629574423743/38491200 - 
           (2043041*Pi^2)/810) - (6381896421042956247908269*
           Im[PolyLog[2, (-1)^(1/3)]])/(295263134618696640*Sqrt[3]) + 
         (190217261*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (95313183476873158425059*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (724902476967900*Sqrt[3]) + (95313183476873158425059*Pi*Log[3]^2)/
          (34795318894459200*Sqrt[3]) + (33843694100185883660670001217*
           PolyGamma[2, 1])/336288849087926700 - 
         (749820618021143357384593985201*Zeta[3])/7398354679934387400) + 
       (374944749989738429491085998729*CF^2*NC*Zeta[3])/1849588669983596850 + 
       (24378593975554261*CF*NM*NC*Zeta[3])/198450 - 
       (425800544*CF*NC*NL*Zeta[3])/45 - (304498881439441301549108*CF*NC*NH*
         Zeta[3])/151329982089567015 + CF*Log[x]*
        ((-62423088444558593618107203902*NM*NC)/28578010776690375 - 
         (5307684027529*lm*NM*NC)/935550 - (3331328*lm^2*NM*NC)/3 - 
         (686276508976187*NC*NL)/37422000 - (5307684027529*lm*NC*NL)/
          935550 - (3331328*lm^2*NC*NL)/3 - 
         (16008169272328302754062542224487663*NC*NH)/
          66430241458515929304560250 - (5307684027529*lm*NC*NH)/935550 - 
         (3331328*lm^2*NC*NH)/3 - (22627977793498*NM*NC*Pi^2)/135 - 
         (638329354*NC*NL*Pi^2)/405 + (5189473712799478717592*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) + 
         CF*NC*(-2656666189461418916389665816858311959608079/
            727484955350147776917495360000 - (8104754349458*lm)/51975 - 
           39975936*lm^2 - (566205349392076453*Pi^2)/1871100 + 
           (95313183476873158425059*Im[PolyLog[2, (-1)^(1/3)]])/
            (1087353715451850*Sqrt[3]) - 6662656*Zeta[3]) + 
         CA*NC*(132834694692533951078286406744106108973263/
            72748495535014777691749536000 + (6629888110729*lm)/170100 + 
           (18322304*lm^2)/3 + (1132420860457732007*Pi^2)/7484400 - 
           (95313183476873158425059*Im[PolyLog[2, (-1)^(1/3)]])/
            (2174707430903700*Sqrt[3]) + 3331328*Zeta[3])), 
      (-1400219447723237872347754302041376686741745094046281*CF^2*NC)/
        1306438085191730893973480470956595200000 - (2815238751977*CF^2*lm*NC)/
        52272 - (196786044*CF^2*lm^2*NC)/5 - 
       (138478220584646676227127037571350037*CF*NM*NC)/
        63077909697548712046080 - (26505593871013*CF*lm*NM*NC)/9408960 - 
       (5466279*CF*lm^2*NM*NC)/5 + (296655683297628881*CF*NC*NL)/
        19758816000 - (26505593871013*CF*lm*NC*NL)/9408960 - 
       (5466279*CF*lm^2*NC*NL)/5 + 
       (1703699705177159953288734691849309600338795764923*CF*NC*NH)/
        1806299111650885203065379192060101568000 - 
       (26505593871013*CF*lm*NC*NH)/9408960 - (5466279*CF*lm^2*NC*NH)/5 + 
       (2676147649398707534879*CF^2*NC*Pi^2)/2218376160 + 
       82810*CF^2*lm*NC*Pi^2 + (51041416411916555*CF*NM*NC*Pi^2)/24948 + 
       (41405*CF*lm*NM*NC*Pi^2)/18 - (64326472301*CF*NC*NL*Pi^2)/35640 + 
       (41405*CF*lm*NC*NL*Pi^2)/18 + (41405*CF*lm*NC*NH*Pi^2)/18 - 
       (3970353397219598073426539*CF^2*NC*Pi^3)/(241578928324388160*
         Sqrt[3]) - (39587012056590013863995*CF*NC*NH*Pi^3)/
        (274521509459532*Sqrt[3]) - (1852326203*CF^2*NC*Pi^4)/3600 + 
       (14676298049276401101401457479*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (93007887404889441600*Sqrt[3]) + (369457685912236946770733*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(480412641554181*Sqrt[3]) - 
       (296164323*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (567193342459942581918077*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(932017470387300*Sqrt[3]) - 
       (4524229949324573013028*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (567193342459942581918077*CF^2*NC*Pi*Log[3]^2)/(44736838578590400*
         Sqrt[3]) - (1131057487331143253257*CF*NC*NH*Pi*Log[3]^2)/
        (10167463313316*Sqrt[3]) - 
       (CF*NC*(CA*(2685566840580586325517074689 - 42577134385792334328000*
             lm) + 20*(23*CF*(-11675794226779759886465597 + 
              605840647386768393600*lm) + 4620*(23*(-4286446311326666492303 + 
                3642620535033480*lm)*NM + 16241160936*(6646484 + 5158515*lm)*
               NL + (15155623235682899 + 83780272305770040*lm)*NH)))*
         Log[x]^2)/371048061384000 + (CF*NC*(-278337247913783113*CA + 
          60*(9273720246599152*CF + 1155*(13862439363060*NM + 
              31294991*NL)))*Log[x]^3)/155925 + 
       (4747942859258089398595969235723*CF^2*NC*PolyGamma[2, 1])/
        8070932378110240800 + (2004749054778301*CF*NM*NC*PolyGamma[2, 1])/
        1890 - (2015678843190691859897533*CF*NC*NH*PolyGamma[2, 1])/
        30883669814197350 - (27008000438627878611847928155781*CF^2*NC*
         Zeta[3])/44390128079606324400 - (906213624898079*CF*NM*NC*Zeta[3])/
        945 - (80162264*CF*NC*NL*Zeta[3])/3 + 
       (3143670972921883931273567*CF*NC*NH*Zeta[3])/15441834907098675 + 
       CA*CF*NC*(2450313348545625962265112746422982436822219218905779/
          4572533298171058128907181648348083200000 + (60129069*lm^2)/10 - 
         (3033682616838563990761*Pi^2)/5029516800 + 
         (3970353397219598073426539*Pi^3)/(483157856648776320*Sqrt[3]) + 
         (621858601*Pi^4)/2400 + lm*(7919475161249/342144 - 
           (455455*Pi^2)/36) - (14676298049276401101401457479*
           Im[PolyLog[2, (-1)^(1/3)]])/(186015774809778883200*Sqrt[3]) + 
         (296164323*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (567193342459942581918077*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1864034940774600*Sqrt[3]) + (567193342459942581918077*Pi*Log[3]^2)/
          (89473677157180800*Sqrt[3]) - (4747942859258089398595969235723*
           PolyGamma[2, 1])/16141864756220481600 + 
         (27010201759680797802894065528321*Zeta[3])/88780256159212648800) + 
       CF*Log[x]*((3995304289308996373079189093*NM*NC)/230933420417700 - 
         (19271794789*lm*NM*NC)/1188 - 2914912*lm^2*NM*NC - 
         (90417861794189*NC*NL)/1663200 - (19271794789*lm*NC*NL)/1188 - 
         2914912*lm^2*NC*NL - (5889107638655074400715054544062520757*NC*NH)/
          5622655637048788256337979560 - (19271794789*lm*NC*NH)/1188 - 
         2914912*lm^2*NC*NH + 1540270694371*NM*NC*Pi^2 - 
         (40039727*NC*NL*Pi^2)/9 + (4524229949324573013028*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(13961600222866068351668757461276455041460961/
            1309472919630265998451491648000 - (15087438613*lm)/33 - 
           104936832*lm^2 + (2226605430136197853*Pi^2)/2494800 + 
           (567193342459942581918077*Im[PolyLog[2, (-1)^(1/3)]])/
            (2796052411161900*Sqrt[3]) - 17489472*Zeta[3]) + 
         CA*NC*(-3173070543745537010735703985054988706581479/
            595214963468302726568859840000 + (23679141733*lm)/216 + 
           16032016*lm^2 - (247398481863916171*Pi^2)/554400 - 
           (567193342459942581918077*Im[PolyLog[2, (-1)^(1/3)]])/
            (5592104822323800*Sqrt[3]) + 8744736*Zeta[3])), 
      (32784218706963438537022684351085906420871324164571457*CF^2*NC)/
        5487039957805269754688617978017699840000 - 
       (530480319078329*CF^2*lm*NC)/16465680 - (154097788*CF^2*lm^2*NC)/5 + 
       (15422731067891738569547928192630412423*CF*NM*NC)/
        5322198630730672578888000 - (1143667161674657*CF*lm*NM*NC)/
        592764480 - (38524447*CF*lm^2*NM*NC)/45 + 
       (692141855802633863411*CF*NC*NL)/52281827136000 - 
       (1143667161674657*CF*lm*NC*NL)/592764480 - (38524447*CF*lm^2*NC*NL)/
        45 + (239948187933442566815106573689129079791429687483*CF*NC*NH)/
        478138000142881377282012139074732768000 - 
       (1143667161674657*CF*lm*NC*NH)/592764480 - (38524447*CF*lm^2*NC*NH)/
        45 - (2087390301639849621180145469*CF^2*NC*Pi^2)/348462527212800 + 
       (272090*CF^2*lm*NC*Pi^2)/9 - (15993568647819592721*CF*NM*NC*Pi^2)/
        4490640 + (136045*CF*lm*NM*NC*Pi^2)/162 - 
       (911303458091*CF*NC*NL*Pi^2)/641520 + (136045*CF*lm*NC*NL*Pi^2)/
        162 + (136045*CF*lm*NC*NH*Pi^2)/162 - 
       (36299925156267338769967*CF^2*NC*Pi^3)/(2264802453041139*Sqrt[3]) - 
       (183961575364461493236085*CF*NC*NH*Pi^3)/(2470693585135788*Sqrt[3]) - 
       (167980891*CF^2*NC*Pi^4)/405 + (9328726439090870362529563999*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(97658281775133913680*Sqrt[3]) + 
       (9197930886593845615570219*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (17294855095950516*Sqrt[3]) - 53132144*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (580798802500277420319472*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(978618343906665*Sqrt[3]) - 
       (21024180041652742084124*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (36299925156267338769967*CF^2*NC*Pi*Log[3]^2)/(2935855031719995*
         Sqrt[3]) - (5256045010413185521031*CF*NC*NH*Pi*Log[3]^2)/
        (91507169819844*Sqrt[3]) + CF*((-1043710723869957437133670981*CF*NC)/
          14519271967200 - 607582872*CF*lm*NC + 
         CA*(104370364169804956232095907/2903854393440 + 92825161*lm)*NC - 
         (11192841141858616421407*NM*NC)/261891630 - 16877302*lm*NM*NC - 
         (11056798649*NC*NL)/540 - 16877302*lm*NC*NL - 
         (352717240125997*NC*NH)/106297191 - 16877302*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(837234012370448823*CA - 1674591988327782754*CF - 
          978621960496303200*NM + 1052637325740*NL)*Log[x]^3)/93555 - 
       (43430373653965005737837416670381*CF^2*NC*PolyGamma[2, 1])/
        14527678280598433440 - (49792595615178149*CF*NM*NC*PolyGamma[2, 1])/
        29400 - (301080563554096871181544402*CF*NC*NH*PolyGamma[2, 1])/
        6809849194030515675 + CA*CF*NC*
        (-409804839669222118135905432089704476335403671979719/
          137175998945131743867215449450442496000 + (423768917*lm^2)/90 + 
         (528186007481038465386557*Pi^2)/176347432800 + 
         (36299925156267338769967*Pi^3)/(4529604906082278*Sqrt[3]) + 
         (168525071*Pi^4)/810 + lm*(1789531672998689/107775360 - 
           (1496495*Pi^2)/324) - (9328726439090870362529563999*
           Im[PolyLog[2, (-1)^(1/3)]])/(195316563550267827360*Sqrt[3]) + 
         26566072*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (290399401250138710159736*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (978618343906665*Sqrt[3]) + (36299925156267338769967*Pi*Log[3]^2)/
          (5871710063439990*Sqrt[3]) + (43430373653965005737837416670381*
           PolyGamma[2, 1])/29055356561196866880 - 
         (237332748757487400395186620657721*Zeta[3])/159804461086582767840) + 
       (47467215346513623515591342410549*CF^2*NC*Zeta[3])/
        15980446108658276784 + (9030910022867017*CF*NM*NC*Zeta[3])/4900 - 
       (583382540*CF*NC*NL*Zeta[3])/27 + (38870017987282394940494296*CF*NC*
         NH*Zeta[3])/6809849194030515675 + CF*Log[x]*
        ((-266456178302104275211040580991*NM*NC)/8313603135037200 - 
         (650223581449*lm*NM*NC)/53460 - (7079072*lm^2*NM*NC)/3 - 
         (39058713813227519*NC*NL)/943034400 - (650223581449*lm*NC*NL)/
          53460 - (7079072*lm^2*NC*NL)/3 - 
         (16148904425108525687827089433155460241*NC*NH)/
          29767000431434761357083421200 - (650223581449*lm*NC*NH)/53460 - 
         (7079072*lm^2*NC*NH)/3 - (211823342076455*NM*NC*Pi^2)/81 - 
         (32395025*NC*NL*Pi^2)/9 + (21024180041652742084124*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-18446095733069974519662432860028738864749903/
            357128978080981635941315904000 - (497793463609*lm)/1485 - 
           84948864*lm^2 - (372106613629967819*Pi^2)/83160 + 
           (580798802500277420319472*Im[PolyLog[2, (-1)^(1/3)]])/
            (2935855031719995*Sqrt[3]) - 14158144*Zeta[3]) + 
         CA*NC*(50726846595340723103941525495326113482872193/
            1964209379445398997677237472000 + (810776934409*lm)/9720 + 
           (38934896*lm^2)/3 + (111632138348785181*Pi^2)/49896 - 
           (290399401250138710159736*Im[PolyLog[2, (-1)^(1/3)]])/
            (2935855031719995*Sqrt[3]) + 7079072*Zeta[3])), 
      (-22749382094484126019235778159475950236149703280552383*CF^2*NC)/
        1259779582149169076331570454136716800000 - 
       (60651900353071*CF^2*lm*NC)/588060 - (376891424*CF^2*lm^2*NC)/5 - 
       (407098768553498656065730877836369379*CF*NM*NC)/
        12095905978933346770200 - (114213636629119*CF*lm*NM*NC)/21170160 - 
       (94222856*CF*lm^2*NM*NC)/45 + (733043793406555485521*CF*NC*NL)/
        20539289232000 - (114213636629119*CF*lm*NC*NL)/21170160 - 
       (94222856*CF*lm^2*NC*NL)/45 + 
       (1820553779806419409891512555548108007570177475357*CF*NC*NH)/
        881981988110783790559267183623096468750 - 
       (114213636629119*CF*lm*NC*NH)/21170160 - (94222856*CF*lm^2*NC*NH)/
        45 + (217605572077798945758432383*CF^2*NC*Pi^2)/12445090257600 + 
       (1324960*CF^2*lm*NC*Pi^2)/9 + (16028563040013590113*CF*NM*NC*Pi^2)/
        561330 + (331240*CF*lm*NM*NC*Pi^2)/81 - 
       (148826717221*CF*NC*NL*Pi^2)/40095 + (331240*CF*lm*NC*NL*Pi^2)/81 + 
       (331240*CF*lm*NC*NH*Pi^2)/81 - (59126983403043955914398779*CF^2*NC*
         Pi^3)/(1630657766189620080*Sqrt[3]) - 
       (21561509394641080816420*CF*NC*NH*Pi^3)/(68630377364883*Sqrt[3]) - 
       (4364788883*CF^2*NC*Pi^4)/4050 + (13169078506591775808474859528*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(39237702498937733175*Sqrt[3]) + 
       (6267333293833959852653098*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3774670755068565*Sqrt[3]) - (604223256*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (8446711914720565130628397*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6291117925114275*Sqrt[3]) - 
       (9856690008978779801792*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (8446711914720565130628397*CF^2*NC*Pi*Log[3]^2)/(301973660405485200*
         Sqrt[3]) - (616043125561173737612*CF*NC*NH*Pi*Log[3]^2)/
        (2541865828329*Sqrt[3]) + CF*((761608089999427983251165671*CF*NC)/
          3629817991800 - 1689306528*CF*lm*NC + 
         CA*(-1904035046970786433680723293/18149089959000 + (774265492*lm)/3)*
          NC + (6409895890052545580221*NM*NC)/18706545 - 
         (140775544*lm*NM*NC)/3 - (1628912714*NC*NL)/27 - 
         (140775544*lm*NC*NL)/3 - (412589636424429307*NC*NH)/45176306175 - 
         (140775544*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-12254131654215387933*CA + 10*(2450643412574406263*CF + 
            64680*(62742376547311*NM + 22624641*NL)))*Log[x]^3)/467775 + 
       (1423355148530466148886784755459851*CF^2*NC*PolyGamma[2, 1])/
        163436380656732376200 + (23407084700927359*CF*NM*NC*PolyGamma[2, 1])/
        1575 - (45343118030705197354212397*CF*NC*NH*PolyGamma[2, 1])/
        324278533049072175 - (717368860997391583439246823515621*CF^2*NC*
         Zeta[3])/81718190328366188100 - (21504739301930882*CF*NM*NC*
         Zeta[3])/1575 - (1592655064*CF*NC*NL*Zeta[3])/27 + 
       (145281951777768975842696806*CF*NC*NH*Zeta[3])/324278533049072175 + 
       CA*CF*NC*(34834854639761155367657435456523679752991555387058233/
          3858074970331830296265434515793695200000 + (518225708*lm^2)/45 - 
         (7323262020144917215623917*Pi^2)/837650305800 + 
         (59126983403043955914398779*Pi^3)/(3261315532379240160*Sqrt[3]) + 
         (4391288083*Pi^4)/8100 + lm*(170629760104831/3849120 - 
           (1821820*Pi^2)/81) - (6584539253295887904237429764*
           Im[PolyLog[2, (-1)^(1/3)]])/(39237702498937733175*Sqrt[3]) + 
         (302111628*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (8446711914720565130628397*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (12582235850228550*Sqrt[3]) + (8446711914720565130628397*Pi*
           Log[3]^2)/(603947320810970400*Sqrt[3]) - 
         (1423355148530466148886784755459851*PolyGamma[2, 1])/
          326872761313464752400 + (717377668889952601367093233763711*Zeta[3])/
          163436380656732376200) + CF*Log[x]*
        ((21543363056170780374824554609151*NM*NC)/91449634485409200 - 
         (450072919088*lm*NM*NC)/13365 - (18019456*lm^2*NM*NC)/3 - 
         (12538952221162621*NC*NL)/105850800 - (450072919088*lm*NC*NL)/
          13365 - (18019456*lm^2*NC*NL)/3 - 
         (3208003834588182420991919933325813270007*NC*NH)/
          1405663909262197064084494890000 - (450072919088*lm*NC*NH)/13365 - 
         (18019456*lm^2*NC*NH)/3 + (1756786572223760*NM*NC*Pi^2)/81 - 
         (29469076*NC*NL*Pi^2)/3 + (9856690008978779801792*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(1322264519226100500228494446526148643052254513/
            8838942207504295489547568624000 - (1412287740032*lm)/1485 - 
           216233472*lm^2 + (247556619473289923*Pi^2)/18900 + 
           (8446711914720565130628397*Im[PolyLog[2, (-1)^(1/3)]])/
            (18873353775342825*Sqrt[3]) - 36038912*Zeta[3]) + 
         CA*NC*(-3305657968080755604447684504608562611298251029/
            44194711037521477447737843120000 + (276121617304*lm)/1215 + 
           (99107008*lm^2)/3 - (742668905449556507*Pi^2)/113400 - 
           (8446711914720565130628397*Im[PolyLog[2, (-1)^(1/3)]])/
            (37746707550685650*Sqrt[3]) + 18019456*Zeta[3])), 
      (233066250164431022688595297009448256860711034483985609292579*CF^2*NC)/
        2440942304529423719162400171190418253916800000 - 
       (1001885644798403*CF^2*lm*NC)/16563690 - (289060608*CF^2*lm^2*NC)/5 + 
       (554876871728388930464734371068592251499107*CF*NM*NC)/
        10792531790016682211221716000 - (2158963967811587*CF*lm*NM*NC)/
        596292840 - (24088384*CF*lm^2*NM*NC)/15 + 
       (24477407899046266244789*CF*NC*NL)/809932638715200 - 
       (2158963967811587*CF*lm*NC*NL)/596292840 - (24088384*CF*lm^2*NC*NL)/
        15 + (50824755337032944958921489044033023891544254477181*CF*NC*NH)/
        47627027357982324690200427915647209312500 - 
       (2158963967811587*CF*lm*NC*NH)/596292840 - (24088384*CF*lm^2*NC*NH)/
        15 - (356106041627182289278252817*CF^2*NC*Pi^2)/4194456346080 + 
       (159040*CF^2*lm*NC*Pi^2)/3 - (63714203993605620781*CF*NM*NC*Pi^2)/
        1216215 + (39760*CF*lm*NM*NC*Pi^2)/27 - (99178634108*CF*NC*NL*Pi^2)/
        34749 + (39760*CF*lm*NC*NL*Pi^2)/27 + (39760*CF*lm*NC*NH*Pi^2)/27 - 
       (45182502551421271851009469*CF^2*NC*Pi^3)/(1324909435029066315*
         Sqrt[3]) - (293650754435007794431600*CF*NC*NH*Pi^3)/
        (1853020188851841*Sqrt[3]) - (576428536*CF^2*NC*Pi^4)/675 + 
       (14868291119199850276526804914411*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (74269123289989341353640*Sqrt[3]) + (789687881753593036229269396*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(713412772707958785*Sqrt[3]) - 
       (528500352*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (722920040822740349616151504*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(572491731185399025*
         Sqrt[3]) - (134240344884574991740160*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (45182502551421271851009469*CF^2*NC*Pi*Log[3]^2)/
        (1717475193556197075*Sqrt[3]) - (8390021555285936983760*CF*NC*NH*Pi*
         Log[3]^2)/(68630377364883*Sqrt[3]) + 
       CF*((-184285301437501263739170073303*CF*NC)/180885929924700 - 
         1332706752*CF*lm*NC + CA*(921425534357830026800683261577/
            1808859299247000 + 203607976*lm)*NC - 
         (90158643098844687328814*NM*NC)/143416845 - 37019632*lm*NM*NC - 
         (2820984296*NC*NL)/63 - 37019632*lm*NC*NL - 
         (10683731487132698*NC*NH)/1368978975 - 37019632*lm*NC*NH)*
        Log[x]^2 + (2*CF*NC*(43327582701554118689*CA - 
          65*(1333172655919624911*CF + 6160*(131752797553639*NM - 
              20823543*NL)))*Log[x]^3)/675675 - 
       (879703122017915469610410854994964*CF^2*NC*PolyGamma[2, 1])/
        20429547582091547025 - (848986301750741888*CF*NM*NC*PolyGamma[2, 1])/
        33075 - (69570702517279896361153673*CF*NC*NH*PolyGamma[2, 1])/
        756649910447835075 + CA*CF*NC*
        (-58266603335409907786613525954828073107520363945979242186323/
          1220471152264711859581200085595209126958400000 + 
         (132486112*lm^2)/15 + (16024772748023206332402289463*Pi^2)/
          377501071147200 + (45182502551421271851009469*Pi^3)/
          (2649818870058132630*Sqrt[3]) + (289009468*Pi^4)/675 + 
         lm*(3377704771988483/108416880 - (218680*Pi^2)/27) - 
         (14868291119199850276526804914411*Im[PolyLog[2, (-1)^(1/3)]])/
          (148538246579978682707280*Sqrt[3]) + 
         (264250176*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (361460020411370174808075752*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (572491731185399025*Sqrt[3]) + (45182502551421271851009469*Pi*
           Log[3]^2)/(3434950387112394150*Sqrt[3]) + 
         (439851561008957734805205427497482*PolyGamma[2, 1])/
          20429547582091547025 - (61539041018169459009020879093005774*
           Zeta[3])/2921425304239091224575) + 
       (123078339743664928116544088325728918*CF^2*NC*Zeta[3])/
        2921425304239091224575 + (884389387447116224*CF*NM*NC*Zeta[3])/
        33075 - (418878640*CF*NC*NL*Zeta[3])/9 + 
       (22345988936101237839884654*CF*NC*NH*Zeta[3])/756649910447835075 + 
       CF*Log[x]*((-3661101006237409973972634424098431*NM*NC)/
          8062809440463577800 - (10007355186284*lm*NM*NC)/405405 - 
         4752384*lm^2*NM*NC - (198586499529575011*NC*NL)/2247565320 - 
         (10007355186284*lm*NC*NL)/405405 - 4752384*lm^2*NC*NL - 
         (129674219037248542425203729751083573081*NC*NH)/
          112286761982483197426867935000 - (10007355186284*lm*NC*NH)/
          405405 - 4752384*lm^2*NC*NH - (1054022660207104*NM*NC*Pi^2)/27 - 
         (23262200*NC*NL*Pi^2)/3 + (134240344884574991740160*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-3085264901909450768355271711445801321006558686069/
            4341814682929074291544187816232000 - (30717326273456*lm)/45045 - 
           171085824*lm^2 - (129982889624819846884*Pi^2)/2027025 + 
           (722920040822740349616151504*Im[PolyLog[2, (-1)^(1/3)]])/
            (1717475193556197075*Sqrt[3]) - 28514304*Zeta[3]) + 
         CA*NC*(26996074684606723980034068182444878882159112190041/
            75981756951258800102023286784060000 + (6229721379382*lm)/36855 + 
           26138112*lm^2 + (2407091047391557148*Pi^2)/75075 - 
           (361460020411370174808075752*Im[PolyLog[2, (-1)^(1/3)]])/
            (1717475193556197075*Sqrt[3]) + 14257152*Zeta[3])), 
      (-2383188054162599091310176889405194037770541479894106903031461*CF^2*
         NC)/8368945044100881322842514872652862584857600000 - 
       (18780924905015959*CF^2*lm*NC)/99382140 - (690639824*CF^2*lm^2*NC)/5 - 
       (4023313700393850494836214852893258883633563*CF*NM*NC)/
        8094398842512511658416287000 - (35368263627282271*CF*lm*NM*NC)/
        3577757040 - (172659956*CF*lm^2*NM*NC)/45 + 
       (275345211021763777542971*CF*NC*NL)/3471139880208000 - 
       (35368263627282271*CF*lm*NC*NL)/3577757040 - 
       (172659956*CF*lm^2*NC*NL)/45 + 
       (4903030494204752581759676571835733562444734467156649*CF*NC*NH)/
        1143048656591575792564810269975533023500000 - 
       (35368263627282271*CF*lm*NC*NH)/3577757040 - 
       (172659956*CF*lm^2*NC*NH)/45 + (795866084734866247970746975*CF^2*NC*
         Pi^2)/3235723466976 + (2265760*CF^2*lm*NC*Pi^2)/9 + 
       (568632614632229018363*CF*NM*NC*Pi^2)/1459458 + 
       (566440*CF*lm*NM*NC*Pi^2)/81 - (3789059533147*CF*NC*NL*Pi^2)/
        521235 + (566440*CF*lm*NC*NL*Pi^2)/81 + (566440*CF*lm*NC*NH*Pi^2)/
        81 - (875171636678776473110753777*CF^2*NC*Pi^3)/
        (11562845978435487840*Sqrt[3]) - (3615086051779491737430500*CF*NC*NH*
         Pi^3)/(5559060566555523*Sqrt[3]) - (17365772221*CF^2*NC*Pi^4)/8100 + 
       (39373004837010957259608639166529*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (57872044122069616639200*Sqrt[3]) + (208783839685393027451988550*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(61149666232110753*Sqrt[3]) - 
       (1174963636*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (125024519525539496158679111*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(44609745287173950*Sqrt[3]) - 
       (1652610766527767651396800*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (125024519525539496158679111*CF^2*NC*Pi*Log[3]^2)/
        (2141267773784349600*Sqrt[3]) - (103288172907985478212300*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) - 
       (CF*NC*(CA*(32033575313925869001260047341463 - 
            11912139564206196723408000*lm) + 
          20*(CF*(-3203353747954745546738770096199 + 
              3898518402831118927660800*lm) + 
            24024*(1155*(-182873221354280214864683 + 3902741481333240*lm)*
               NM + 739552864050*(7822739 + 6095124*lm)*NL + 
              (934926227611070029 + 4507666410939892200*lm)*NH)))*Log[x]^2)/
        21706311590964000 + (CF*NC*(-4531601563893113739243*CA + 
          20*(453154729998208544489*CF + 840840*(863418022751161*NM + 
              48107943*NL)))*Log[x]^3)/12162150 + 
       (2266323563418776715478621533553279*CF^2*NC*PolyGamma[2, 1])/
        18159597850748041800 + (965058132750258451*CF*NM*NC*PolyGamma[2, 1])/
        4725 - (2495861031901344098308274093*CF*NC*NH*PolyGamma[2, 1])/
        8755520392324948725 - (159701492798151271596979827795212617*CF^2*NC*
         Zeta[3])/1298411246328484988700 - (890378947148252698*CF*NM*NC*
         Zeta[3])/4725 - (3332535976*CF*NC*NL*Zeta[3])/27 + 
       (8171883904717105749575189414*CF*NC*NH*Zeta[3])/8755520392324948725 + 
       CA*CF*NC*
        (1042644212893701030613632825323970041304663551127029335771201/
          7322826913588271157487200513571254761750400000 + 
         (949629758*lm^2)/45 - (32770954910310322878409970867*Pi^2)/
          266471344339200 + (875171636678776473110753777*Pi^3)/
          (23125691956870975680*Sqrt[3]) + (17456402621*Pi^4)/16200 + 
         lm*(52839567109042399/650501280 - (3115420*Pi^2)/81) - 
         (39373004837010957259608639166529*Im[PolyLog[2, (-1)^(1/3)]])/
          (115744088244139233278400*Sqrt[3]) + 
         (587481818*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (125024519525539496158679111*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (89219490574347900*Sqrt[3]) + (125024519525539496158679111*Pi*
           Log[3]^2)/(4282535547568699200*Sqrt[3]) - 
         (2266323563418776715478621533553279*PolyGamma[2, 1])/
          36319195701496083600 + (19962722738171304113546817692963279*
           Zeta[3])/324602811582121247175) + 
       CF*Log[x]*((151820428238806843582138634626008353*NM*NC)/
          48376856642781466800 - (11551666256192*lm*NM*NC)/173745 - 
         11781952*lm^2*NM*NC - (337156543986597307*NC*NL)/1376060400 - 
         (11551666256192*lm*NC*NL)/173745 - 11781952*lm^2*NC*NL - 
         (537915546806714961862444770601315624472189*NC*NH)/
          113858776650237962190844086090000 - (11551666256192*lm*NC*NH)/
          173745 - 11781952*lm^2*NC*NH + (24175704874051472*NM*NC*Pi^2)/
          81 - (185015012*NC*NL*Pi^2)/9 + (1652610766527767651396800*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(744994915330452425134046031393943066938056225029651/
            364712433366042240489711776563488000 - (36312564648608*lm)/
            19305 - 424150272*lm^2 + (1007021589937930712843*Pi^2)/5405400 + 
           (125024519525539496158679111*Im[PolyLog[2, (-1)^(1/3)]])/
            (133829235861521850*Sqrt[3]) - 70691712*Zeta[3]) + 
         CA*NC*(-8954264432133039761093932782032517495943458419971/
            8767125802068323088694994628930000 + (7078504650976*lm)/15795 + 
           64800736*lm^2 - (3021064202006766178927*Pi^2)/32432400 - 
           (125024519525539496158679111*Im[PolyLog[2, (-1)^(1/3)]])/
            (267658471723043700*Sqrt[3]) + 35345856*Zeta[3])), 
      (296995391633652460073206925102267857339835315548102548924791089*CF^2*
         NC)/205039153580471592409641614379995133329011200000 - 
       (1856370173692386013*CF^2*lm*NC)/17044037010 - 
       (3640986016*CF^2*lm^2*NC)/35 + 
       (94649196801547901412045335413358655785897785811*CF*NM*NC)/
        113321583795175163217828018000000 - (3998817687833215909*CF*lm*NM*
         NC)/613585332360 - (910246504*CF*lm^2*NM*NC)/315 + 
       (345309893907833075782307*CF*NC*NL)/5315182941568500 - 
       (3998817687833215909*CF*lm*NC*NL)/613585332360 - 
       (910246504*CF*lm^2*NC*NL)/315 + 
       (207608225352960099471719579822466410309643172492462073*CF*NC*NH)/
        96016087153692366575444062677944773974000000 - 
       (3998817687833215909*CF*lm*NC*NH)/613585332360 - 
       (910246504*CF*lm^2*NC*NH)/315 - (2321601669885617048353648264973*CF^2*
         NC*Pi^2)/1981880623522800 + (5641280*CF^2*lm*NC*Pi^2)/63 - 
       (19016913247313697367349*CF*NM*NC*Pi^2)/25540515 + 
       (1410320*CF*lm*NM*NC*Pi^2)/567 - (139881437611823*CF*NC*NL*Pi^2)/
        25540515 + (1410320*CF*lm*NC*NL*Pi^2)/567 + 
       (1410320*CF*lm*NC*NH*Pi^2)/567 - (6139910629087581662835049411*CF^2*
         NC*Pi^3)/(89033914033953256368*Sqrt[3]) - 
       (5358198653296317683682620*CF*NC*NH*Pi^3)/(16677181699666569*
         Sqrt[3]) - (1897299025*CF^2*NC*Pi^4)/1134 + 
       (6248282344974361752119097727237169*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15596515890897761684264400*Sqrt[3]) + 
       (1800763866503627299482521828*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (817181903283661881*Sqrt[3]) - (1407383080*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/7 - (6139910629087581662835049411*CF^2*
         NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2404465270978675905*
         Sqrt[3]) - (17146235690548216587784384*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1441237924662543*Sqrt[3]) - 
       (6139910629087581662835049411*CF^2*NC*Pi*Log[3]^2)/
        (115414333006976443440*Sqrt[3]) - (1071639730659263536736524*CF*NC*
         NH*Pi*Log[3]^2)/(4323713773987629*Sqrt[3]) - 
       (CF*NC*(-(CA*(106793696811281018686735465604317 + 
             6435435796271311983753600*lm)) + 
          52*(CF*(4107450534233100992999981847097 + 810054855474710599353600*
               lm) + 924*(21*(134549191329584886714323599 + 
                1159633259286044400*lm)*NM + 21130081830*(1390577303 + 
                1152494280*lm)*NL + (5455788004051105619 + 
                24352298445006932400*lm)*NH)))*Log[x]^2)/15194418113674800 - 
       (CF*NC*(-2173794078104804760081*CA + 4347596637964737165202*CF + 
          68640*(39821636915479226*NM - 909647271*NL))*Log[x]^3)/1216215 - 
       (29576750204279355270403923702481151*CF^2*NC*PolyGamma[2, 1])/
        49030914197019712860 - (915439945280984623*CF*NM*NC*PolyGamma[2, 1])/
        2450 - (67165413460815169415239235087*CF*NC*NH*PolyGamma[2, 1])/
        367731856477647846450 + CA*CF*NC*
        (-421868494343243719587593947790664289578472484185781147318111/
          582497595399067023891027313579531628775600000 + 
         (5006355772*lm^2)/315 + (546259220607457028335900556161*Pi^2)/
          932649705187200 + (6139910629087581662835049411*Pi^3)/
          (178067828067906512736*Sqrt[3]) + (1901812049*Pi^4)/2268 + 
         lm*(6255439520909450533/111560969520 - (7756760*Pi^2)/567) - 
         (6248282344974361752119097727237169*Im[PolyLog[2, (-1)^(1/3)]])/
          (31193031781795523368528800*Sqrt[3]) + 
         (703691540*Im[PolyLog[2, (-1)^(1/3)]]^2)/7 + 
         (6139910629087581662835049411*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4808930541957351810*Sqrt[3]) + (6139910629087581662835049411*Pi*
           Log[3]^2)/(230828666013952886880*Sqrt[3]) + 
         (29576750204279355270403923702481151*PolyGamma[2, 1])/
          98061828394039425720 - (1018218128286389335862658687123959089*
           Zeta[3])/3505710365086909469490) + 
       (407287376211698374994521278531428209*CF^2*NC*Zeta[3])/
        701142073017381893898 + (4149999174269477593*CF*NM*NC*Zeta[3])/
        11025 - (18013792688*CF*NC*NL*Zeta[3])/189 + 
       (16269243380960056902682992913*CF*NC*NH*Zeta[3])/
        183865928238823923225 + CF*Log[x]*
        ((-13213715329085148335280296009335863443*NM*NC)/
          2116487478121689172500 - (406785862100146*lm*NM*NC)/8513505 - 
         9137024*lm^2*NM*NC - (4233554478873808657*NC*NL)/23599435860 - 
         (406785862100146*lm*NC*NL)/8513505 - 9137024*lm^2*NC*NL - 
         (1399726822071278704126529408046485433049583*NC*NH)/
          597758577413749301501931451972500 - (406785862100146*lm*NC*NH)/
          8513505 - 9137024*lm^2*NC*NH - (318573106848796400*NM*NC*Pi^2)/
          567 - (1000452856*NC*NL*Pi^2)/63 + (17146235690548216587784384*NC*
           NH*Im[PolyLog[2, (-1)^(1/3)]])/(4323713773987629*Sqrt[3]) + 
         CF*NC*(-2435222170926779744241914388488778153474442360031747/
            255298703356229568342798243594441600 - (1251167634106504*lm)/
            945945 - 328932864*lm^2 - (3381458011021860226129*Pi^2)/3783780 + 
           (6139910629087581662835049411*Im[PolyLog[2, (-1)^(1/3)]])/
            (7213395812936027715*Sqrt[3]) - 54822144*Zeta[3]) + 
         CA*NC*(3044027828238208812050073167251863282377684125595353/
            638246758390573920856995608986104000 + (252894448919513*lm)/
            773955 + 50253632*lm^2 + (10144374341327967809657*Pi^2)/
            22702680 - (6139910629087581662835049411*Im[PolyLog[2, (-1)^
                (1/3)]])/(14426791625872055430*Sqrt[3]) + 27411072*Zeta[3])), 
      (-1750849940964554769347357247999643249347536736688788224979431797*CF^2*
         NC)/410078307160943184819283228759990266658022400000 - 
       (1335355734339177*CF^2*lm*NC)/4008004 - (1217764944*CF^2*lm^2*NC)/5 - 
       (41745591303730570061418136530588213815454527*CF*NM*NC)/
        5878285288680110136831000000 - (4191473393783927*CF*lm*NM*NC)/
        240480240 - (33826804*CF*lm^2*NM*NC)/5 + 
       (1948662873806510475036539*CF*NC*NL)/11699027003664000 - 
       (4191473393783927*CF*lm*NC*NL)/240480240 - (33826804*CF*lm^2*NC*NL)/
        5 + (284980134738270856824111458300059644856034658079878834919*CF*NC*
         NH)/33453376422734330405835789209319929892169800000 - 
       (4191473393783927*CF*lm*NC*NH)/240480240 - (33826804*CF*lm^2*NC*NH)/
        5 + (58581069412695344824574383159*CF^2*NC*Pi^2)/17384917750200 + 
       416160*CF^2*lm*NC*Pi^2 + (468960352499116042307*CF*NM*NC*Pi^2)/
        90090 + 11560*CF*lm*NM*NC*Pi^2 - (1843559687636*CF*NC*NL*Pi^2)/
        135135 + 11560*CF*lm*NC*NL*Pi^2 + 11560*CF*lm*NC*NH*Pi^2 - 
       (134072387054784426416361104917*CF^2*NC*Pi^3)/(890339140339532563680*
         Sqrt[3]) - (21465069034092619131031640*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) - (77078209457*CF^2*NC*Pi^4)/18900 + 
       (41240644601573131268341765465477159*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(31193031781795523368528800*Sqrt[3]) + 
       (112290050593335278481083602174*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (16693858881366235569*Sqrt[3]) - (15337861516*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - (134072387054784426416361104917*
         CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (24044652709786759050*Sqrt[3]) - (9812602987013768745614464*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (134072387054784426416361104917*CF^2*NC*Pi*Log[3]^2)/
        (1154143330069764434400*Sqrt[3]) - (613287686688360546600904*CF*NC*
         NH*Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((102399675157221242004684228691417*CF*NC)/2532403018945800 - 
         7274041056*CF*lm*NC + CA*(-1023996930940161168025585943218591/
            50648060378916000 + 1111311828*lm)*NC + 
         (6148070160766385793954193*NM*NC)/98423325 - 202056696*lm*NM*NC - 
         (1294818838*NC*NL)/5 - 202056696*lm*NC*NL - 
         (1290219372019463267*NC*NH)/29113619535 - 202056696*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-146297258110602151904371*CA + 
          20*(14629698420118196876261*CF + 385945560*(59112097249751*NM + 
              495237*NL)))*Log[x]^3)/28378350 + 
       (2556665251628373779402450643017290943*CF^2*NC*PolyGamma[2, 1])/
        1470927425910591385800 + (13007302527276826907*CF*NM*NC*
         PolyGamma[2, 1])/4725 - (2922896359588732735207797571*CF*NC*NH*
         PolyGamma[2, 1])/5253312235394969235 - 
       (176580313038237707550249721880627541713*CF^2*NC*Zeta[3])/
        105171310952607284084700 - (11970821157386193386*CF*NM*NC*Zeta[3])/
        4725 - 246474840*CF*NC*NL*Zeta[3] + (9741653118791665862983581178*CF*
         NC*NH*Zeta[3])/5253312235394969235 + 
       CA*CF*NC*
        (109428113245438508994422746526721150394244559772105172560542121/
          51259788395117898102410403594998783332252800000 + 
         (186047422*lm^2)/5 - (55135123801047259410326624929*Pi^2)/
          32724551059200 + (134072387054784426416361104917*Pi^3)/
          (1780678280679065127360*Sqrt[3]) + (77427783857*Pi^4)/37800 + 
         lm*(1252423737742027/8744736 - 63580*Pi^2) - 
         (41240644601573131268341765465477159*Im[PolyLog[2, (-1)^(1/3)]])/
          (62386063563591046737057600*Sqrt[3]) + 
         (7668930758*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
         (134072387054784426416361104917*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(48089305419573518100*Sqrt[3]) + 
         (134072387054784426416361104917*Pi*Log[3]^2)/(2308286660139528868800*
           Sqrt[3]) - (2556665251628373779402450643017290943*PolyGamma[2, 1])/
          2941854851821182771600 + (22072544913230062121837036721063364816*
           Zeta[3])/26292827738151821021175) + 
       CF*Log[x]*((1333088367765426523883429755957579*NM*NC)/
          32529691924730000 - (5660185764566*lm*NM*NC)/45045 - 
         22139712*lm^2*NM*NC - (748608465528648623*NC*NL)/1545944400 - 
         (5660185764566*lm*NC*NL)/45045 - 22139712*lm^2*NC*NL - 
         (537252356813818817933173430192847132855332683*NC*NH)/
          57453138697710075721499925841014000 - (5660185764566*lm*NC*NH)/
          45045 - 22139712*lm^2*NC*NH + 4019622622873600*NM*NC*Pi^2 - 
         41056020*NC*NL*Pi^2 + (9812602987013768745614464*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(69520993001433615278723948125440189945669004758517069/
            2552987033562295683427982435944416000 - (17820540310904*lm)/
            5005 - 797029632*lm^2 + (292594474221988680262559*Pi^2)/
            113513400 + (134072387054784426416361104917*
             Im[PolyLog[2, (-1)^(1/3)]])/(72133958129360277150*Sqrt[3]) - 
           132838272*Zeta[3]) + CA*NC*
          (-5431327453455240213404920181717133213602329650281969/
            398904223994108700535622255616315000 + (3464727726763*lm)/4095 + 
           121768416*lm^2 - (13933069824488087978557*Pi^2)/10810800 - 
           (134072387054784426416361104917*Im[PolyLog[2, (-1)^(1/3)]])/
            (144267916258720554300*Sqrt[3]) + 66419136*Zeta[3])), 
      (2670824977677325688937634641363650241925386674583396012800293873*CF^2*
         NC)/126741235042873923879586162734887101645680000000 - 
       (8952328377510807407*CF^2*lm*NC)/47344547250 - 
       (6317628672*CF^2*lm^2*NC)/35 + 
       (9758371562347460425104027895665043864826217939299*CF*NM*NC)/
        764920690617432351720339121500000 - (19278581717884978607*CF*lm*NM*
         NC)/1704403701000 - (526469056*CF*lm^2*NM*NC)/105 + 
       (733204133840701759974440837*CF*NC*NL)/5527790259231240000 - 
       (19278581717884978607*CF*lm*NC*NL)/1704403701000 - 
       (526469056*CF*lm^2*NC*NL)/105 + 
       (11062000989432154665197738121835014471397942027739677491349*CF*NC*
         NH)/2634453393290328519459568400233944479008371750000 - 
       (19278581717884978607*CF*lm*NC*NH)/1704403701000 - 
       (526469056*CF*lm^2*NC*NH)/105 - (104246080824322558176470277208013*
         CF^2*NC*Pi^2)/6606268745076000 + (5123392*CF^2*lm*NC*Pi^2)/35 - 
       (145812421638470286081233*CF*NM*NC*Pi^2)/14189175 + 
       (1280848*CF*lm*NM*NC*Pi^2)/315 - (143240424294854*CF*NC*NL*Pi^2)/
        14189175 + (1280848*CF*lm*NC*NL*Pi^2)/315 + 
       (1280848*CF*lm*NC*NH*Pi^2)/315 - (66811189499834925550443392839*CF^2*
         NC*Pi^3)/(500815766440987067070*Sqrt[3]) - 
       (93690503651232483812431240*CF*NC*NH*Pi^3)/(150094635296999121*
         Sqrt[3]) - (14834581004*CF^2*NC*Pi^4)/4725 + 
       (270119470069042164279672269080961657*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(350921607545199637895949000*Sqrt[3]) + 
       (110891770695813772605619012668476*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(26292827738151821021175*Sqrt[3]) - 
       (12869291584*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
       (534489515998679404403547142712*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(108200937194040415725*
         Sqrt[3]) - (299809611683943948199779968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(12971141321962887*Sqrt[3]) - 
       (66811189499834925550443392839*CF^2*NC*Pi*Log[3]^2)/
        (649205623164242494350*Sqrt[3]) - (18738100730246496762486248*CF*NC*
         NH*Pi*Log[3]^2)/(38913423965888661*Sqrt[3]) - 
       (CF*NC*(-1827*CA*(57087141066436523619118607738269 + 
            507214067173303296206400*lm) + 
          2*(87*CF*(1198829990781348297871529225049191 + 
              34859439525728844721094400*lm) + 
            40040*(1015*(1671285316561839699447023779 + 2072893744691549208*
                 lm)*NM + 11*(10284291576*(22394407169 + 18598418545*lm)*
                 NL + (45211470804543282307 + 191271559169265676920*lm)*
                 NH))))*Log[x]^2)/1101595313241423000 + 
       (2*CF*NC*(34473429761944745485131*CA - 7*(9849554355223409989271*CF + 
            2288*(2778146272111237803*NM - 9033517579*NL)))*Log[x]^3)/
        2837835 - (4545811640574849626097601990784280844*CF^2*NC*
         PolyGamma[2, 1])/551597784716471769675 - 
       (20878644694520405939*CF*NM*NC*PolyGamma[2, 1])/3969 - 
       (576616866326319521194182821408*CF*NC*NH*PolyGamma[2, 1])/
        1654793354149415309025 + CA*CF*NC*
        (-60761269032915395853674753875851683427699371845612239660967947517/
          5766726194450763536521170404437363124878440000000 + 
         (2895579808*lm^2)/105 + (2044040802615838167445636338521*Pi^2)/
          259069362552000 + (66811189499834925550443392839*Pi^3)/
          (1001631532881974134140*Sqrt[3]) + (7432660678*Pi^4)/4725 + 
         lm*(30155136960410751407/309891582000 - (7044664*Pi^2)/315) - 
         (270119470069042164279672269080961657*Im[PolyLog[2, (-1)^(1/3)]])/
          (701843215090399275791898000*Sqrt[3]) + 
         (6434645792*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
         (267244757999339702201773571356*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(108200937194040415725*Sqrt[3]) + 
         (66811189499834925550443392839*Pi*Log[3]^2)/(1298411246328484988700*
           Sqrt[3]) + (2272905820287424813048800995392140422*PolyGamma[2, 1])/
          551597784716471769675 - (308148413513028293520898273517265075172*
           Zeta[3])/78878483214455463063525) + 
       (616296854233849427651860866570319243118*CF^2*NC*Zeta[3])/
        78878483214455463063525 + (102365953338510210562*CF*NM*NC*Zeta[3])/
        19845 - (176463577072*CF*NC*NL*Zeta[3])/945 + 
       (360215080386856931681091871424*CF*NC*NH*Zeta[3])/
        1654793354149415309025 + CF*Log[x]*
        ((-3186505629676577964149074629736194387007*NM*NC)/
          38096774606190405105000 - (46635497898488*lm*NM*NC)/525525 - 
         16868352*lm^2*NM*NC - (5350209797669130255577*NC*NL)/
          15339633309000 - (46635497898488*lm*NC*NL)/525525 - 
         16868352*lm^2*NC*NL - 
         (41169149480565602778384450390493481394975962291*NC*NH)/
          9048869344889336926136238319959705000 - (46635497898488*lm*NC*NH)/
          525525 - 16868352*lm^2*NC*NH - (1481678019005391520*NM*NC*Pi^2)/
          189 - (88208733272*NC*NL*Pi^2)/2835 + 
         (299809611683943948199779968*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (38913423965888661*Sqrt[3]) + 
         CF*NC*(-17989023421040280143863814301850936214221710811472674301/
            143605520637879132192824012021873400000 - (431087234852256*lm)/
            175175 - 607260672*lm^2 - (34473430598786444624006*Pi^2)/
            2837835 + (534489515998679404403547142712*
             Im[PolyLog[2, (-1)^(1/3)]])/(324602811582121247175*Sqrt[3]) - 
           101210112*Zeta[3]) + CA*NC*
          (642465125724694218170115349379414769240076811333736767/
            10257537188419938013773143715848100000 + (28958947566844*lm)/
            47775 + 92775936*lm^2 + (86183576873787467253083*Pi^2)/14189175 - 
           (267244757999339702201773571356*Im[PolyLog[2, (-1)^(1/3)]])/
            (324602811582121247175*Sqrt[3]) + 50605056*Zeta[3])), 
      (-728580772215238643492191542466331195814571998638813072660404003*CF^2*
         NC)/11851128471541457817311952879106326387648000000 - 
       (7681053197967135671*CF^2*lm*NC)/13527013500 - 
       (2075706528*CF^2*lm^2*NC)/5 - 
       (21537195941646586096296465718195010479081719354169*CF*NM*NC)/
        218548768747837814777239749000000 - (14466596502654883271*CF*lm*NM*
         NC)/486972486000 - (172975544*CF*lm^2*NM*NC)/15 + 
       (526070624812466168540669591*CF*NC*NL)/1579368645494640000 - 
       (14466596502654883271*CF*lm*NC*NL)/486972486000 - 
       (172975544*CF*lm^2*NC*NL)/15 + 
       (14293634466161908627968640037080313438262870923650815417043621*CF*NC*
         NH)/879361356185010385694341761471926498309673981000000 - 
       (14466596502654883271*CF*lm*NC*NH)/486972486000 - 
       (172975544*CF*lm^2*NC*NH)/15 + (1957519032337093340634496023602203*
         CF^2*NC*Pi^2)/43412623181928000 + (3338528*CF^2*lm*NC*Pi^2)/5 + 
       (4389211435683877149667*CF*NM*NC*Pi^2)/64350 + 
       (834632*CF*lm*NM*NC*Pi^2)/45 - (16661952220262*CF*NC*NL*Pi^2)/
        675675 + (834632*CF*lm*NC*NL*Pi^2)/45 + (834632*CF*lm*NC*NH*Pi^2)/
        45 - (1479764781214567152110048583937*CF^2*NC*Pi^3)/
        (5151247883393009832720*Sqrt[3]) - (122507238079709032943238440*CF*NC*
         NH*Pi^3)/(50031545098999707*Sqrt[3]) - (3356620199*CF^2*NC*Pi^4)/
        450 + (1116633662265314462610971715799098937*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(451184923986685248723363000*Sqrt[3]) + 
       (1452029788777486323354932942378*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (113821765100224333425*Sqrt[3]) - 
       (3938194296*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (1479764781214567152110048583937*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(139115490678051963075*
         Sqrt[3]) - (56003308836438415059766144*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (1479764781214567152110048583937*CF^2*NC*Pi*Log[3]^2)/
        (6677543552546494227600*Sqrt[3]) - (3500206802277400941235384*CF*NC*
         NH*Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) - 
       (CF*NC*(-107880*CA*(-85641455706966056403261569254541 + 
            682501036715925414967980*lm) + 
          7*(2697*CF*(-978759468862348790844316412494469 + 
              25527311503141106429971200*lm) + 
            40040*(9889*(-10084595519558793530896854797 + 4829888199516602040*
                 lm)*NM + 221*(527628366342*(524363781 + 409608580*lm)*NL + 
                5*(9961663767221500769 + 43224221181013282872*lm)*NH))))*
         Log[x]^2)/34149454710484113000 + 
       (CF*NC*(-197515251387363452071435*CA + 
          154*(2565132400594158927767*CF + 728*(5372661367318261941*NM + 
              6615178567*NL)))*Log[x]^3)/2837835 + 
       (937448073447087570847287073096140399329*CF^2*NC*PolyGamma[2, 1])/
        39715040499585967416600 + (516142706847978688139*CF*NM*NC*
         PolyGamma[2, 1])/14175 - (82343861041880234429003944099*CF*NC*NH*
         PolyGamma[2, 1])/78799683530924538525 - 
       (63584784255135282279005459013726418269497*CF^2*NC*Zeta[3])/
        2839625395720396670286900 - (472059725286789263882*CF*NM*NC*Zeta[3])/
        14175 - (63768306008*CF*NC*NL*Zeta[3])/135 + 
       (278534763440082277834065248122*CF*NC*NH*Zeta[3])/
        78799683530924538525 + CA*CF*NC*
        (45581834103270050279645336084944963195064822498858963030685988583/
          1482872450001624909391158103998179089254456000000 + 
         (951365492*lm^2)/15 - (922239414086007804768092564129*Pi^2)/
          40905688824000 + (1479764781214567152110048583937*Pi^3)/
          (10302495766786019665440*Sqrt[3]) + (3369974311*Pi^4)/900 + 
         lm*(21613751832984297671/88540452000 - (4590476*Pi^2)/45) - 
         (1116633662265314462610971715799098937*Im[PolyLog[2, (-1)^(1/3)]])/
          (902369847973370497446726000*Sqrt[3]) + 
         (1969097148*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (1479764781214567152110048583937*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(278230981356103926150*Sqrt[3]) + 
         (1479764781214567152110048583937*Pi*Log[3]^2)/
          (13355087105092988455200*Sqrt[3]) - 
         (937448073447087570847287073096140399329*PolyGamma[2, 1])/
          79430080999171934833200 + 
         (63584786627860424646607257909920612602139*Zeta[3])/
          5679250791440793340573800) + CF*Log[x]*
        ((5719612438781948531413270734839123444567*NM*NC)/
          10884792744625830030000 - (154422824922458*lm*NM*NC)/675675 - 
         40062336*lm^2*NM*NC - (4029635411736241830091*NC*NL)/
          4382752374000 - (154422824922458*lm*NC*NL)/675675 - 
         40062336*lm^2*NC*NL - 
         (866692245197147993306003239911178981716074246647*NC*NH)/
          48716882019264161266201260646953930000 - 
         (154422824922458*lm*NC*NH)/675675 - 40062336*lm^2*NC*NH + 
         (1432709698658201344*NM*NC*Pi^2)/27 - (31869129628*NC*NL*Pi^2)/
          405 + (56003308836438415059766144*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*(5248792107336860471207236240535945931630814766908881931/
            14770853551324710739833326950821264000 - (486857225118632*lm)/
            75075 - 1442244096*lm^2 + (56432927796043869517807*Pi^2)/
            1621620 + (1479764781214567152110048583937*
             Im[PolyLog[2, (-1)^(1/3)]])/(417346472034155889225*Sqrt[3]) - 
           240374016*Zeta[3]) + CA*NC*
          (-66802808413885556086638820294835830290161830691991583/
            375985363124629000650302867839086720 + (94437215382829*lm)/
            61425 + 220342848*lm^2 - (1975152465308051525686063*Pi^2)/
            113513400 - (1479764781214567152110048583937*
             Im[PolyLog[2, (-1)^(1/3)]])/(834692944068311778450*Sqrt[3]) + 
           120187008*Zeta[3])), (59973575328358857177041461573387221660879560\
51187897743186055827024178761*CF^2*NC)/
        20252834662530192752478934799110490292383079335040000000 - 
       (12348425739948015941*CF^2*lm*NC)/38846808000 - 
       (10615770972*CF^2*lm^2*NC)/35 + 
       (148011364350579697161037687918549056384284976952522083277*CF*NM*NC)/
        795974430867991792047246968928576000000 - 
       (26585658698181901541*CF*lm*NM*NC)/1398485088000 - 
       (294882527*CF*lm^2*NM*NC)/35 + (15267916076269002649825727033*CF*NC*
         NL)/58963096098466560000 - (26585658698181901541*CF*lm*NC*NL)/
        1398485088000 - (294882527*CF*lm^2*NC*NL)/35 + 
       (52595452738100535889800344602984610380099284472746627309818052419*CF*
         NC*NH)/6697216088705039097448106855370192211126477039296000000 - 
       (26585658698181901541*CF*lm*NC*NH)/1398485088000 - 
       (294882527*CF*lm^2*NC*NH)/35 - (24084304890883427749738229110660219*
         CF^2*NC*Pi^2)/115766995151808000 + (8137662*CF^2*lm*NC*Pi^2)/35 - 
       (1162468896666060515963239*CF*NM*NC*Pi^2)/8408400 + 
       (1356277*CF*lm*NM*NC*Pi^2)/210 - (6533584867421*CF*NC*NL*Pi^2)/
        363825 + (1356277*CF*lm*NC*NL*Pi^2)/210 + 
       (1356277*CF*lm*NC*NH*Pi^2)/210 - (35798131415586620911369644599947*
         CF^2*NC*Pi^3)/(144234940735004275316160*Sqrt[3]) - 
       (38952809306427051801272615*CF*NC*NH*Pi^3)/(33354363399333138*
         Sqrt[3]) - (23825287823*CF^2*NC*Pi^4)/4200 + 
       (72083885511637098475788902970462669553*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(50532711486508747857016656000*
         Sqrt[3]) + (273223243366537024045500573945763*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(35057103650869094694900*Sqrt[3]) - 
       (22732455114*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
       (35798131415586620911369644599947*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3895233738985454966100*
         Sqrt[3]) - (62324494890283282882036184*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1441237924662543*Sqrt[3]) - 
       (35798131415586620911369644599947*CF^2*NC*Pi*Log[3]^2)/
        (186971219471301838372800*Sqrt[3]) - (7790561861285410360254523*CF*NC*
         NH*Pi*Log[3]^2)/(8647427547975258*Sqrt[3]) - 
       (CF*NC*(-31*CA*(7333670868257738250581345544153106579 + 
            9424670822474787458068089600*lm) + 
          4*(31*CF*(3666835446734415051336469748888651861 + 
              15422188618595106749565964800*lm) + 
            20020*(217*(17387931766055005712027081282417 + 
                3056901158086973889120*lm)*NM + 33315962560452*(
                23933120439 + 19910802520*lm)*NL + 
              (164447835839620975842793 + 663347551304873333939040*lm)*NH)))*
         Log[x]^2)/182130425122581936000 - 
       (CF*NC*(-1221962981172753568183457*CA + 2443926075603406868949922*CF + 
          32032*(50315185471975593849*NM - 22968532907*NL))*Log[x]^3)/
        3783780 - (17485847696844042331609267128029311957093*CF^2*NC*
         PolyGamma[2, 1])/158860161998343869666400 - 
       (793618474183750694201*CF*NM*NC*PolyGamma[2, 1])/11025 - 
       (5094011903690480765007239263087*CF*NC*NH*PolyGamma[2, 1])/
        7943008099917193483320 + CA*CF*NC*
        (-2398943017366104608101766076545933314352884657962779120012252568649\
5226169/162022677300241542019831478392883922339064634680320000000 + 
         (3243707797*lm^2)/70 + (22693516524438505704551297291539*Pi^2)/
          218163673728000 + (35798131415586620911369644599947*Pi^3)/
          (288469881470008550632320*Sqrt[3]) + (23868688687*Pi^4)/8400 + 
         lm*(41581615669863987941/254270016000 - (14919047*Pi^2)/420) - 
         (72083885511637098475788902970462669553*Im[PolyLog[2, (-1)^(1/3)]])/
          (101065422973017495714033312000*Sqrt[3]) + 
         (11366227557*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
         (35798131415586620911369644599947*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(7790467477970909932200*Sqrt[3]) + 
         (35798131415586620911369644599947*Pi*Log[3]^2)/
          (373942438942603676745600*Sqrt[3]) + 
         (17485847696844042331609267128029311957093*PolyGamma[2, 1])/
          317720323996687739332800 - 
         (1167725571418920245910588880658180412853603*Zeta[3])/
          22717003165763173362295200) + 
       (1167725578728106216707057993460634361127219*CF^2*NC*Zeta[3])/
        11358501582881586681147600 + (253601686400093765896*CF*NM*NC*
         Zeta[3])/3675 - (110827998374*CF*NC*NL*Zeta[3])/315 + 
       (1900953861601373732382009888449*CF*NC*NH*Zeta[3])/
        3971504049958596741660 + CF*Log[x]*
        ((-187174725361780138747065907389890659769273873*NM*NC)/
          170876733033632697030960000 - (154179228515369*lm*NM*NC)/970200 - 
         30046752*lm^2*NM*NC - (26697564359084562608437*NC*NL)/
          40905688824000 - (154179228515369*lm*NC*NL)/970200 - 
         30046752*lm^2*NC*NL - 
         (10122649365397509214433425052077359944507053167509*NC*NH)/
          1189191581598448244241630772715388240000 - 
         (154179228515369*lm*NC*NH)/970200 - 30046752*lm^2*NC*NH - 
         (6708691400606841188*NM*NC*Pi^2)/63 - (55401792694*NC*NL*Pi^2)/
          945 + (62324494890283282882036184*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4323713773987629*Sqrt[3]) + 
         CF*NC*
          (-28052486798826200859091956774373995631540938127775015605393411/
            17391202971329714425079759151896956233600000 - 
           (118954669976969*lm)/26950 - 1081683072*lm^2 - 
           (2443925970928201519967341*Pi^2)/15135120 + 
           (35798131415586620911369644599947*Im[PolyLog[2, (-1)^(1/3)]])/
            (11685701216956364898300*Sqrt[3]) - 180280512*Zeta[3]) + 
         CA*NC*(2805248682111516707459505071489618862089340175176635109654621\
1/34782405942659428850159518303793912467200000 + (191280957884969*lm)/
            176400 + 165257136*lm^2 + (12219629862203041355941247*Pi^2)/
            151351200 - (35798131415586620911369644599947*
             Im[PolyLog[2, (-1)^(1/3)]])/(23371402433912729796600*Sqrt[3]) + 
           90140256*Zeta[3])), (-13568869929545420899614851597647005918911663\
3109898154509468484475643986889*CF^2*NC)/
        158500445185018899802009054949560358809954533926400000000 - 
       (1626073528610603209*CF^2*lm*NC)/1731457728 - 
       (3433426692*CF^2*lm^2*NC)/5 - 
       (1855557085861018497509678573092377323003799682225575649*CF*NM*NC)/
        1392375097728265525447079245939200000 - 
       (15313707734809740941*CF*lm*NM*NC)/311662391040 - 
       (286118891*CF*lm^2*NM*NC)/15 + (322630706174302017398817829*CF*NC*
         NL)/505397966558284800 - (15313707734809740941*CF*lm*NC*NL)/
        311662391040 - (286118891*CF*lm^2*NC*NL)/15 + 
       (36818401894927694665081761571468780000410729905287415315999220977*CF*
         NC*NH)/1230100914251945956674142075476157753064046803136000000 - 
       (15313707734809740941*CF*lm*NC*NH)/311662391040 - 
       (286118891*CF*lm^2*NC*NH)/15 + (574539678518545452599164669443543047*
         CF^2*NC*Pi^2)/972442759275187200 + 1043290*CF^2*lm*NC*Pi^2 + 
       (2847276454404879804695669*CF*NM*NC*Pi^2)/3243240 + 
       (521645*CF*lm*NM*NC*Pi^2)/18 - (279670101376181*CF*NC*NL*Pi^2)/
        6486480 + (521645*CF*lm*NC*NL*Pi^2)/18 + (521645*CF*lm*NC*NH*Pi^2)/
        18 - (1370855302432930315788318541809617*CF^2*NC*Pi^3)/
        (2596228933230076955690880*Sqrt[3]) - 
       (2025000437204647914639598250*CF*NC*NH*Pi^3)/(450283905890997363*
         Sqrt[3]) - (332082960583*CF^2*NC*Pi^4)/25200 + 
       (4075530772929836042360177416974169253123*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(909588806757157461426299808000*
         Sqrt[3]) + (52704939219003805168648908140657*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2253670948984441801815*Sqrt[3]) - 
       (47953026063*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
       (1370855302432930315788318541809617*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(70114207301738189389800*
         Sqrt[3]) - (925714485579267618120959200*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (1370855302432930315788318541809617*CF^2*NC*Pi*Log[3]^2)/
        (3365481950483433090710400*Sqrt[3]) - 
       (57857155348704226132559950*CF*NC*NH*Pi*Log[3]^2)/
        (16677181699666569*Sqrt[3]) + 
       CF*((3880819230359866108578874360380264023*CF*NC)/547376553163440000 - 
         (79082813536*CF*lm*NC)/3 + 
         CA*(-2469612246494278156567031841516750181/696661067662560000 + 
           (108738868612*lm)/27)*NC + (66249369340913578573406761612577*NM*
           NC)/6288541819560 - (19770703384*lm*NM*NC)/27 - 
         (126426523678*NC*NL)/135 - (19770703384*lm*NC*NL)/27 - 
         (171932572121386215377377*NC*NH)/974723982031800 - 
         (19770703384*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-52177697910382295120643653*CA + 
          26*(4013668897763058547717751*CF + 215600*(27852045098637078801*
               NM + 4942675846*NL)))*Log[x]^3)/56756700 + 
       (448116461609408426794379000884835137772063*CF^2*NC*PolyGamma[2, 1])/
        1429741457985094826997600 + (76645986071088631339*CF*NM*NC*
         PolyGamma[2, 1])/162 - (2689938469269335231339936523253*CF*NC*NH*
         PolyGamma[2, 1])/1418394303556641693450 - 
       (1494922804276886251547452225699825017980737*CF^2*NC*Zeta[3])/
        5111325712296714006516420 - (34762193852241098255*CF*NM*NC*Zeta[3])/
        81 - (23565983746*CF*NC*NL*Zeta[3])/27 + 
       (4606636768162147856155326867047*CF*NC*NH*Zeta[3])/
        709197151778320846725 + CA*CF*NC*(67844349555146794422391162263241340\
120567289916582297176752365856492769257/
          158500445185018899802009054949560358809954533926400000000 + 
         (3147307801*lm^2)/30 - (8893803072010789289333686583706773*Pi^2)/
          30106586974464000 + (1370855302432930315788318541809617*Pi^3)/
          (5192457866460153911381760*Sqrt[3]) + (333251445383*Pi^4)/50400 + 
         lm*(4575971810805371113/11333177856 - (5738095*Pi^2)/36) - 
         (4075530772929836042360177416974169253123*
           Im[PolyLog[2, (-1)^(1/3)]])/(1819177613514314922852599616000*
           Sqrt[3]) + (47953026063*Im[PolyLog[2, (-1)^(1/3)]]^2)/70 + 
         (1370855302432930315788318541809617*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(140228414603476378779600*
           Sqrt[3]) + (1370855302432930315788318541809617*Pi*Log[3]^2)/
          (6730963900966866181420800*Sqrt[3]) - 
         (448116461609408426794379000884835137772063*PolyGamma[2, 1])/
          2859482915970189653995200 + 
         (1868653515136015347477085859622543028059779*Zeta[3])/
          12778314280741785016291050) + CF*Log[x]*
        ((97053729275719224344033362671095749265707649*NM*NC)/
          14646577117168516888368000 - (28958337592819*lm*NM*NC)/72072 - 
         70109088*lm^2*NM*NC - (421918450960640829511*NC*NL)/250442992800 - 
         (28958337592819*lm*NC*NL)/72072 - 70109088*lm^2*NC*NL - 
         (149874271232694393282621039629188108144351879020787*NC*NH)/
          4586881814736871799217718694759354640000 - 
         (28958337592819*lm*NC*NH)/72072 - 70109088*lm^2*NC*NH + 
         (18568030067399320186*NM*NC*Pi^2)/27 - (11778297068*NC*NL*Pi^2)/
          81 + (925714485579267618120959200*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CF*NC*(4422538119241937242434756589343052674692573261334101271999112\
1/9721790480867542225199865364414447584000000 - (22852747446163*lm)/2002 - 
           2523927168*lm^2 + (208710791025234614246419423*Pi^2)/454053600 + 
           (1370855302432930315788318541809617*Im[PolyLog[2, (-1)^(1/3)]])/
            (210342621905214568169400*Sqrt[3]) - 420654528*Zeta[3]) + 
         CA*NC*
          (-309577668196683805960711768982814636737320675370399231721164647/
            136105066732145591152798115101802266176000000 + 
           (35389304016883*lm)/13104 + 385599984*lm^2 - 
           (29815827273411509507759213*Pi^2)/129729600 - 
           (1370855302432930315788318541809617*Im[PolyLog[2, (-1)^(1/3)]])/
            (420685243810429136338800*Sqrt[3]) + 210327264*Zeta[3])), 
      (1657777738526826902704672547483230202553587520961786830915640287107948\
49558903659*CF^2*NC)/
        41027949425337714115658796368820441908426133519972011520000000 - 
       (4547445983360722264649*CF^2*lm*NC)/8756847459360 - 
       (17336366688*CF^2*lm^2*NC)/35 + 
       (7143778999735845764960475975387914804046763830656734041222409*CF*NM*
         NC)/2736100877306347324255330898232831648000000 - 
       (9788571744079815117257*CF*lm*NM*NC)/315246508536960 - 
       (1444697224*CF*lm^2*NM*NC)/105 + (62112831936659047975420396273*CF*NC*
         NL)/127802510793426268800 - (9788571744079815117257*CF*lm*NC*NL)/
        315246508536960 - (1444697224*CF*lm^2*NC*NL)/105 + 
       (679854315752115835834909469210829991051041795302027043197469872209*CF*
         NC*NH)/47865397339862485314114410760439903155992174133792000000 - 
       (9788571744079815117257*CF*lm*NC*NH)/315246508536960 - 
       (1444697224*CF*lm^2*NC*NH)/105 - 
       (4447137222866776653752971119586509431*CF^2*NC*Pi^2)/
        1653152690767818240 + (2519780*CF^2*lm*NC*Pi^2)/7 - 
       (9748155253097022184040291*CF*NM*NC*Pi^2)/5360355 + 
       (629945*CF*lm*NM*NC*Pi^2)/63 - (3981925041919453*CF*NC*NL*Pi^2)/
        128648520 + (629945*CF*lm*NC*NL*Pi^2)/63 + 
       (629945*CF*lm*NC*NH*Pi^2)/63 - (31248494096266009751701169554967*CF^2*
         NC*Pi^3)/(70056971214144933724992*Sqrt[3]) - 
       (25685815619878949239360794910*CF*NC*NH*Pi^3)/(12157665459056928801*
         Sqrt[3]) - (74934546557*CF^2*NC*Pi^4)/7560 + 
       (1067941957180590701383853364978090115453*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(417255817702886518019366102400*
         Sqrt[3]) + (457249205561854690253832646705933*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(32764908412158423118695*Sqrt[3]) - 
       1112358914*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (31248494096266009751701169554967*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1891970673221506697820*
         Sqrt[3]) - (82194609983612637565954543712*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1050662447078993847*
         Sqrt[3]) - (31248494096266009751701169554967*CF^2*NC*Pi*Log[3]^2)/
        (90814592314632321495360*Sqrt[3]) - (5137163123975789847872158982*CF*
         NC*NH*Pi*Log[3]^2)/(3151987341236981541*Sqrt[3]) - 
       (CF*NC*(-(CA*(149924113709818586491377292981052713439497 + 
             27406663453375301222023792896000*lm)) + 
          32*(CF*(9370257111461256130027591609875115825012 + 
              5605908433644947977232139456000*lm) + 
            85085*(7*(10635594888254072929515806930134439 + 
                261452293441616645596800*lm)*NM + 333159625604520*(
                6593358903 + 5493360880*lm)*NL + (473478943089575548720297 + 
                1830166054091316519177600*lm)*NH)))*Log[x]^2)/
        9288651681251678736000 + (CF*NC*(405932635524884427211887621*CA - 
          17*(47756780980842204269447003*CF + 160160*(200261533387755739059*
               NM - 12673968316*NL)))*Log[x]^3)/96486390 - 
       (8580691113441611197302292746406413565921*CF^2*NC*PolyGamma[2, 1])/
        5957256074937895112490 - (95357736110636939044358*CF*NM*NC*
         PolyGamma[2, 1])/99225 - (612834839087548538292341518894517*CF*NC*
         NH*PolyGamma[2, 1])/536153046744410560124100 + 
       CA*CF*NC*(-41444443473023699864550736525984189906507870417700548609356\
560658972084848205821/
          20513974712668857057829398184410220954213066759986005760000000 + 
         (7945834732*lm^2)/105 + (2229141465138296805721600906897543*Pi^2)/
          1657295930594304 + (31248494096266009751701169554967*Pi^3)/
          (140113942428289867449984*Sqrt[3]) + (75055495997*Pi^4)/15120 + 
         lm*(15309005147219674673609/57317547006720 - (6929395*Pi^2)/126) - 
         (1067941957180590701383853364978090115453*
           Im[PolyLog[2, (-1)^(1/3)]])/(834511635405773036038732204800*
           Sqrt[3]) + 556179457*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (31248494096266009751701169554967*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3783941346443013395640*Sqrt[3]) + 
         (31248494096266009751701169554967*Pi*Log[3]^2)/
          (181629184629264642990720*Sqrt[3]) + 
         (8580691113441611197302292746406413565921*PolyGamma[2, 1])/
          11914512149875790224980 - 
         (76835963062468775253901918838542161378938221*Zeta[3])/
          115856716145392184147705520) + 
       (10976566161390776265540033066322481555022721*CF^2*NC*Zeta[3])/
        8275479724670870296264680 + (89650674834061256726984*CF*NM*NC*
         Zeta[3])/99225 - (121011976676*CF*NC*NL*Zeta[3])/189 + 
       (261297806745315427831102292685883*CF*NC*NH*Zeta[3])/
        268076523372205280062050 + CF*Log[x]*
        ((-314816515817538575930637843895836696712227757513*NM*NC)/
          22392619151634684797284440000 - (17722720750981417*lm*NM*NC)/
          64324260 - 51845376*lm^2*NM*NC - (15390789846184643185357*NC*NL)/
          13038688312650 - (17722720750981417*lm*NC*NL)/64324260 - 
         51845376*lm^2*NC*NL - 
         (86773674741076475122487886283151231263905096882575137*NC*NH)/
          5634984309404247005338967416511867175240000 - 
         (17722720750981417*lm*NC*NH)/64324260 - 51845376*lm^2*NC*NH - 
         (267015377873091115732*NM*NC*Pi^2)/189 - (60494649328*NC*NL*Pi^2)/
          567 + (82194609983612637565954543712*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3151987341236981541*Sqrt[3]) + 
         CF*NC*
          (-36235038143326617628740490242865739498139479167893403085174135982\
1/17757505183913346535158001579033785874270200000 - (13693031254188457*lm)/
            1786785 - 1866433536*lm^2 - (33137358018579385189215823*Pi^2)/
            15752880 + (31248494096266009751701169554967*
             Im[PolyLog[2, (-1)^(1/3)]])/(5675912019664520093460*Sqrt[3]) - 
           311072256*Zeta[3]) + CA*NC*(57976061035854169173244549758551449423\
10020252613245311537783825211/
            568240165885227089125056050529081147976646400000 + 
           (21967158590863657*lm)/11695320 + 285149568*lm^2 + 
           (1623730543050577878255301597*Pi^2)/1543782240 - 
           (31248494096266009751701169554967*Im[PolyLog[2, (-1)^(1/3)]])/
            (11351824039329040186920*Sqrt[3]) + 155536128*Zeta[3])), 
      (-569466803932733598858405735308459623385066053352236633297813980488920\
02597571807*CF^2*NC)/
        4914616834445955107022127337879999696217859827148377600000000 - 
       (2859670828370642991*CF^2*lm*NC)/1891123520 - 
       (5529010032*CF^2*lm^2*NC)/5 - 
       (288247663212000364721784401596411515214494862564286988202141*CF*NM*
         NC)/16364992594884985146224661457109184000000 - 
       (598505264727389431*CF*lm*NM*NC)/7564494080 - 
       (153583612*CF*lm^2*NM*NC)/5 + (9107757781715713858378547*CF*NC*NL)/
        7728042980706048 - (598505264727389431*CF*lm*NC*NL)/7564494080 - 
       (153583612*CF*lm^2*NC*NL)/5 + 
       (369021145879388421760949108466943571510664612020897992858721897*CF*NC*
         NH)/6912117520250268643122130288835850017217328550400000 - 
       (598505264727389431*CF*lm*NC*NH)/7564494080 - 
       (153583612*CF*lm^2*NC*NH)/5 + (7280635138870501193256792059960363*
         CF^2*NC*Pi^2)/958460511808800 + 1592010*CF^2*lm*NC*Pi^2 + 
       (204282148144708512541742633*CF*NM*NC*Pi^2)/18378360 + 
       (88445*CF*lm*NM*NC*Pi^2)/2 - (384255765439889*CF*NC*NL*Pi^2)/
        5250960 + (88445*CF*lm*NC*NL*Pi^2)/2 + (88445*CF*lm*NC*NH*Pi^2)/2 - 
       (1110092164334608965478361172072167*CF^2*NC*Pi^3)/
        (1182211389238695756609240*Sqrt[3]) - 
       (194602922347877513292824520155*CF*NC*NH*Pi^3)/(24315330918113857602*
         Sqrt[3]) - (15236745734*CF^2*NC*Pi^4)/675 + 
       (31673621485855347261852106970759711057767*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4023538242134977138043887416000*
         Sqrt[3]) + (2530240767259964435947087334570206*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(60849115622579928649005*Sqrt[3]) - 
       (11572885408*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (317169189809888275850960334877762*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9122001460175121578775*
         Sqrt[3]) - (44480667965229145895502747464*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) - (158584594904944137925480167438881*CF^2*NC*Pi*Log[3]^2)/
        (218928035044202917890600*Sqrt[3]) - (5560083495653643236937843433*CF*
         NC*NH*Pi*Log[3]^2)/(900567811781994726*Sqrt[3]) + 
       CF*((13147497540812339006546701877718497651311*CF*NC)/
          144233721758566440000 - 47604613392*CF*lm*NC + 
         CA*(-1643437193444171308056362619156704902877/36058430439641610000 + 
           7272927046*lm)*NC + (209360602341720091575975472903769*NM*NC)/
          1569603835800 - 1322350372*lm*NM*NC - (15208431098*NC*NL)/9 - 
         1322350372*lm*NC*NL - (1513765455913070681*NC*NH)/4566842280 - 
         1322350372*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-1641129257708393123492037871*CA + 
          3282258494657459754197007682*CF + 367567200*
           (13144367869221346236*NM + 330587593*NL))*Log[x]^3)/137837700 + 
       (17493990389994023200999682119329746662848497*CF^2*NC*PolyGamma[2, 1])/
        4289224373955284480992800 + (57134520960469928208907*CF*NM*NC*
         PolyGamma[2, 1])/9450 - (127819966068485881764307970283253*CF*NC*NH*
         PolyGamma[2, 1])/38296646196029325723150 - 
       (19545933075478570047528523355776886511670465561*CF^2*NC*Zeta[3])/
        5213552226542648286646748400 - (25674996565711535300543*CF*NM*NC*
         Zeta[3])/4725 - 1561045738*CF*NC*NL*Zeta[3] + 
       (221241094956520293291705575283347*CF*NC*NH*Zeta[3])/
        19148323098014662861575 + CA*CF*NC*(199313381339795757587291030733563\
994639898866418944584014872330089400388018339637/
          34402317841121685749154891365159997873525018790038643200000000 + 
         (844709866*lm^2)/5 - (107293570465917224220865792761048073*Pi^2)/
          28249362453312000 + (1110092164334608965478361172072167*Pi^3)/
          (2364422778477391513218480*Sqrt[3]) + (7642253017*Pi^4)/675 + 
         lm*(894231674411502839/1375362560 - (972895*Pi^2)/4) - 
         (31673621485855347261852106970759711057767*
           Im[PolyLog[2, (-1)^(1/3)]])/(8047076484269954276087774832000*
           Sqrt[3]) + (5786442704*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (158584594904944137925480167438881*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(9122001460175121578775*Sqrt[3]) + 
         (158584594904944137925480167438881*Pi*Log[3]^2)/
          (437856070088405835781200*Sqrt[3]) - 
         (17493990389994023200999682119329746662848497*PolyGamma[2, 1])/
          8578448747910568961985600 + 
         (19545933089673654325780977479999164927851602329*Zeta[3])/
          10427104453085296573293496800) + CF*Log[x]*
        ((9326449581370551761161914682848962779358780489*NM*NC)/
          113328185262471374635440000 - (599745248354881*lm*NM*NC)/875160 - 
         119082348*lm^2*NM*NC - (37721216931611253277*NC*NL)/12614906304 - 
         (599745248354881*lm*NC*NL)/875160 - 119082348*lm^2*NC*NL - 
         (19483506930565634733969580598482442041877639223061*NC*NH)/
          335066704885045161607787567504793648000 - 
         (599745248354881*lm*NC*NH)/875160 - 119082348*lm^2*NC*NH + 
         8762911912943685348*NM*NC*Pi^2 - (780257534*NC*NL*Pi^2)/3 + 
         (44480667965229145895502747464*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + CF*NC*(13636802499276576761055875153\
293717880602315283052790569878113918721/
            238237336628899555999635300687658245269712000000 - 
           (473817451580101*lm)/24310 - 4286964528*lm^2 + 
           (1641129257029453006749337489*Pi^2)/275675400 + 
           (317169189809888275850960334877762*Im[PolyLog[2, (-1)^(1/3)]])/
            (27366004380525364736325*Sqrt[3]) - 714494088*Zeta[3]) + 
         CA*NC*
          (-13636802498336708161664253447284373560954861125913536031476240887\
371/476474673257799111999270601375316490539424000000 + (732383930851201*lm)/
            159120 + 654952914*lm^2 - (273521542818136644983350723*Pi^2)/
            91891800 - (158584594904944137925480167438881*
             Im[PolyLog[2, (-1)^(1/3)]])/(27366004380525364736325*Sqrt[3]) + 
           357247044*Zeta[3])), (12759649852257189722987687539680481010768313\
3987778602818898726602581472673309740233*CF^2*NC)/
        2373759931037396316691687504196039853273226296512666380800000000 - 
       (1330023659546876565221*CF^2*lm*NC)/1608400553760 - 
       (3942545144*CF^2*lm^2*NC)/5 + 
       (60203995100311466079746936629055810071922065887656220095819723*CF*NM*
         NC)/1693776733570595962634252460810800544000000 - 
       (2862478342814947976069*CF*lm*NM*NC)/57902419935360 - 
       (985636286*CF*lm^2*NM*NC)/45 + (11697405426913198444865812111*CF*NC*
         NL)/13278182939576755200 - (2862478342814947976069*CF*lm*NC*NL)/
        57902419935360 - (985636286*CF*lm^2*NC*NL)/45 + 
       (208621396681171480539533723697706659499778572378189896124941580567*CF*
         NC*NH)/8369606620570240289210862681539777351847774448537344000 - 
       (2862478342814947976069*CF*lm*NC*NH)/57902419935360 - 
       (985636286*CF*lm^2*NC*NH)/45 - 
       (60538348615596076834919243938447763213*CF^2*NC*Pi^2)/
        1771235025822662400 + (4902380*CF^2*lm*NC*Pi^2)/9 - 
       (775682596401992228906338367*CF*NM*NC*Pi^2)/33081048 + 
       (1225595*CF*lm*NM*NC*Pi^2)/81 - (61270833289493*CF*NC*NL*Pi^2)/
        1181466 + (1225595*CF*lm*NC*NL*Pi^2)/81 + 
       (1225595*CF*lm*NC*NH*Pi^2)/81 - (501179751589975462283167900219439*
         CF^2*NC*Pi^3)/(644842575948379503605040*Sqrt[3]) - 
       (405784987872316425582431446420*CF*NC*NH*Pi^3)/(109418989131512359209*
         Sqrt[3]) - (68080262813*CF^2*NC*Pi^4)/4050 + 
       (778693104352268161075466697721724252161*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(174575006373625041113474454000*
         Sqrt[3]) + (292341758415765069377090043149003*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(12036088804466359512990*Sqrt[3]) - 
       (27795393208*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (71597107369996494611881128602777*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2487818580047760430575*
         Sqrt[3]) - (185501708741630365980540089792*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (71597107369996494611881128602777*CF^2*NC*Pi*Log[3]^2)/
        (119415291842292500667600*Sqrt[3]) - (11593856796351897873783755612*
         CF*NC*NH*Pi*Log[3]^2)/(4052555153018976267*Sqrt[3]) - 
       (CF*NC*(-4*CA*(510224769465701314829055070898660650894159 + 
            13074108039735890308284483360000*lm) + 
          7*(CF*(583114022286743962178687323966691674035191 + 
              48900559940830342971245859840000*lm) + 
            8751600*((45710548780830551296338743587870357 + 
                155211491298195450518400*lm)*NM + 45*(6169622696380*
                 (670144943 + 559052704*lm)*NL + (927287871945789225163 + 
                  3449144251071010011520*lm)*NH))))*Log[x]^2)/
        9952126801341084360000 - (CF*NC*(-3709097920036934341807232719*CA + 
          7418195847626503874531287343*CF + 462862400*
           (10932825522786091935*NM - 94839298*NL))*Log[x]^3)/68918850 - 
       (119043217637555702015715117409508627771529391*CF^2*NC*
         PolyGamma[2, 1])/6433836560932926721489200 - 
       (3322030908731887481115607*CF*NM*NC*PolyGamma[2, 1])/264600 - 
       (19100393649210155347678224766550161*CF*NC*NH*PolyGamma[2, 1])/
        9650754841399390082233800 + CA*CF*NC*
        (-6379824926331750000518219253291136760385974429694335156556085301548\
1846128844782679/
          2373759931037396316691687504196039853273226296512666380800000000 + 
         (5420999573*lm^2)/45 + (7965572186282552863133304231878775731*Pi^2)/
          466114480479648000 + (501179751589975462283167900219439*Pi^3)/
          (1289685151896759007210080*Sqrt[3]) + (22726103471*Pi^4)/2700 + 
         lm*(4476599890081631342981/10527712715520 - (13481545*Pi^2)/162) - 
         (778693104352268161075466697721724252161*Im[PolyLog[2, (-1)^(1/3)]])/
          (349150012747250082226948908000*Sqrt[3]) + 
         (13897696604*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (71597107369996494611881128602777*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4975637160095520861150*Sqrt[3]) + 
         (71597107369996494611881128602777*Pi*Log[3]^2)/
          (238830583684585001335200*Sqrt[3]) + 
         (119043217637555702015715117409508627771529391*PolyGamma[2, 1])/
          12867673121865853442978400 - 
         (131483006884242333549249308115190092591760905551*Zeta[3])/
          15640656679627944859940245200) + 
       (26296601380029239941906128654377152118760734677*CF^2*NC*Zeta[3])/
        1564065667962794485994024520 + (1535059044266306005586393*CF*NM*NC*
         Zeta[3])/132300 - (30496438300*CF*NC*NL*Zeta[3])/27 + 
       (9039537546491276065188677542622639*CF*NC*NH*Zeta[3])/
        4825377420699695041116900 + CF*Log[x]*
        ((-2078767820081964777833330951098096855469556791617*NM*NC)/
          11729467174665787274768040000 - (12793332615417301*lm*NM*NC)/
          27567540 - 86949016*lm^2*NM*NC - (112203145110474355829*NC*NL)/
          54186756624 - (12793332615417301*lm*NC*NL)/27567540 - 
         86949016*lm^2*NC*NL - 
         (7833179319564355758569616354113101807865171201360161*NC*NH)/
          289799193055075560274575467134896026155200 - 
         (12793332615417301*lm*NC*NH)/27567540 - 86949016*lm^2*NC*NH - 
         (495621423705140258264*NM*NC*Pi^2)/27 - (15245767960*NC*NL*Pi^2)/
          81 + (185501708741630365980540089792*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CF*NC*(-245632867728701365092409265813843242133176203485890621646613\
134874121/966963307493768786116166808673436407271184000000 - 
           (9896993289597361*lm)/765765 - 3130164576*lm^2 - 
           (2472731946864254923936390579*Pi^2)/91891800 + 
           (71597107369996494611881128602777*Im[PolyLog[2, (-1)^(1/3)]])/
            (7463455740143281291725*Sqrt[3]) - 521694096*Zeta[3]) + 
         CA*NC*(1043939687863429416090003268689777966480140513136719867757371\
340768683/8219188113697034681987417873724209461805064000000 + 
           (15844022312832661*lm)/5012280 + 478219588*lm^2 + 
           (17171749631205992877681332*Pi^2)/1276275 - 
           (71597107369996494611881128602777*Im[PolyLog[2, (-1)^(1/3)]])/
            (14926911480286562583450*Sqrt[3]) + 260847048*Zeta[3])), 
      (-128669993796918550502388976898834523995616065271934273641314212996392\
2647860210379*CF^2*NC)/
        8407650287027377745070912057364958157992537059667059200000000 - 
       (9027082778759452013*CF^2*lm*NC)/3797876160 - 
       (8691776632*CF^2*lm^2*NC)/5 - 
       (772663474689062733415589876966047605356944893897435705366357997*CF*
         NM*NC)/3387553467141191925268504921621601088000000 - 
       (17004569832949609517*CF*lm*NM*NC)/136723541760 - 
       (2172944158*CF*lm^2*NM*NC)/45 + (1493166166076246184248446018447*CF*
         NC*NL)/709434345628815206400 - (17004569832949609517*CF*lm*NC*NL)/
        136723541760 - (2172944158*CF*lm^2*NC*NL)/45 + 
       (140104324634499756566447771435876912786852827386632849564845424285345\
7739*CF*NC*NH)/
        15140917291133727906049922407429797935826618540777217344000000 - 
       (17004569832949609517*CF*lm*NC*NH)/136723541760 - 
       (2172944158*CF*lm^2*NC*NH)/45 + 
       (4416780301815097845364262331438852017*CF^2*NC*Pi^2)/
        46006104566822400 + (21403690*CF^2*lm*NC*Pi^2)/9 + 
       (11464310143660080965640229403*CF*NM*NC*Pi^2)/82702620 + 
       (10701845*CF*lm*NM*NC*Pi^2)/162 - (519541021771079*CF*NC*NL*Pi^2)/
        4296240 + (10701845*CF*lm*NC*NL*Pi^2)/162 + 
       (10701845*CF*lm*NC*NH*Pi^2)/162 - (107218484204999749678134080539357*
         CF^2*NC*Pi^3)/(66137700097269692677440*Sqrt[3]) - 
       (6059258680389511073445763678765*CF*NC*NH*Pi^3)/
        (437675956526049436836*Sqrt[3]) - (609288202831*CF^2*NC*Pi^4)/16200 + 
       (524402898893663322987617636782232034239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(38958412242296712471646032000*
         Sqrt[3]) + (1339185140248750192069531527656177503*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(18619829380509458166595530*Sqrt[3]) - 
       (57130907834*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (15316926314999964239733440077051*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(255160880004898505700*
         Sqrt[3]) - (692486706330229836965230134716*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (15316926314999964239733440077051*CF^2*NC*Pi*Log[3]^2)/
        (12247722240235128273600*Sqrt[3]) - (173121676582557459241307533679*
         CF*NC*NH*Pi*Log[3]^2)/(16210220612075905068*Sqrt[3]) + 
       CF*((521152470667550624276962710608674388877827*CF*NC)/
          452369400060958380000 - (250206757528*CF*lm*NC)/3 + 
         CA*(-94754994673577432404767064159769374270109/
            164497963658530320000 + (344034291601*lm)/27)*NC + 
         (540468393114171626964546195338019383*NM*NC)/324907994010600 - 
         (62551689382*lm*NM*NC)/27 - (8875538875*NC*NL)/3 - 
         (62551689382*lm*NC*NL)/27 - (804120745388320656456001*NC*NH)/
          1335732864265800 - (62551689382*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-1898168599627621705859938521*CA + 
          3796337195771013916084043442*CF + 618800*
           (8904446954491216796034*NM + 31275844691*NL))*Log[x]^3)/
        12530700 + (2011871548987327099968743669240379253237186813*CF^2*NC*
         PolyGamma[2, 1])/38603019365597560328935200 + 
       (51349124799764984515649*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (984625423025475706970065885927682*CF*NC*NH*PolyGamma[2, 1])/
        172334907882131965754175 - 
       (201540754561169467900904515014431710709699561749*CF^2*NC*Zeta[3])/
        4265633639898530416347339600 - (45709199629438144376102*CF*NM*NC*
         Zeta[3])/675 - (73206446264*CF*NC*NL*Zeta[3])/27 + 
       (3439941395660606614360391579390636*CF*NC*NH*Zeta[3])/
        172334907882131965754175 + CA*CF*NC*(49537947610593744843722610628177\
529715548320031124515729508004379198419013834507779/
          647389072101108086370460228417101778165425353594363558400000000 + 
         (11951192869*lm^2)/45 - (8136174240169322865352879401619395163*Pi^2)/
          169496174719872000 + (107218484204999749678134080539357*Pi^3)/
          (132275400194539385354880*Sqrt[3]) + (203666832677*Pi^4)/10800 + 
         lm*(279479083686855805423/273447083520 - (117720295*Pi^2)/324) - 
         (524402898893663322987617636782232034239*Im[PolyLog[2, (-1)^(1/3)]])/
          (77916824484593424943292064000*Sqrt[3]) + 
         (28565453917*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (15316926314999964239733440077051*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(510321760009797011400*Sqrt[3]) + 
         (15316926314999964239733440077051*Pi*Log[3]^2)/
          (24495444480470256547200*Sqrt[3]) - 
         (2011871548987327099968743669240379253237186813*PolyGamma[2, 1])/
          77206038731195120657870400 + 
         (201540754581229128442482011769914195960217084541*Zeta[3])/
          8531267279797060832694679200) + CF*Log[x]*
        ((1477702980563364139846777377554223639665126687693*NM*NC)/
          1466183396833223409346005000 - (814472282357327*lm*NM*NC)/716040 - 
         196913948*lm^2*NM*NC - (298641956222842208226121*NC*NL)/
          57902419935360 - (814472282357327*lm*NC*NL)/716040 - 
         196913948*lm^2*NC*NL - 
         (997617715728136739765687479123438944671570011249026084583*NC*NH)/
          9918377382309961050397345362691816495161720000 - 
         (814472282357327*lm*NC*NH)/716040 - 196913948*lm^2*NC*NH + 
         (2968148984837385009905*NM*NC*Pi^2)/27 - (36592521287*NC*NL*Pi^2)/
          81 + (692486706330229836965230134716*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CF*NC*(1766061802012012157737172366617401653134510342029930739378789\
62036749/249066306475667717635982359809824529145608000000 - 
           (644099380838507*lm)/19890 - 7088902128*lm^2 + 
           (140605081445855168759671609*Pi^2)/1856400 + 
           (15316926314999964239733440077051*Im[PolyLog[2, (-1)^(1/3)]])/
            (765482640014695517100*Sqrt[3]) - 1181483688*Zeta[3]) + 
         CA*NC*(-176606180199495558942530011378457700870745453484490755176757\
822804099/498132612951335435271964719619649058291216000000 + 
           (10933170792493477*lm)/1432080 + 1083026714*lm^2 - 
           (421815244333341364473646069*Pi^2)/11138400 - 
           (15316926314999964239733440077051*Im[PolyLog[2, (-1)^(1/3)]])/
            (1530965280029391034200*Sqrt[3]) + 590741844*Zeta[3])), 
      (5045700056805239585629059509740992285701141422123304489370172680062634\
116785868113*CF^2*NC)/
        7214306375320266065125363249222835064600047928617541120000000 - 
       (158326857761498952031*CF^2*lm*NC)/123041449440 - 
       (6133500384*CF^2*lm^2*NC)/5 + 
       (20471626286868773933743944800480617904784837117300780813838189*CF*NM*
         NC)/43430172655656306734211601559251296000000 - 
       (340706595630303460063*CF*lm*NM*NC)/4429492179840 - 
       (511125032*CF*lm^2*NM*NC)/15 + (462506498004000956313030430689263*CF*
         NC*NL)/298790098567336004428800 - (340706595630303460063*CF*lm*NC*
         NL)/4429492179840 - (511125032*CF*lm^2*NC*NL)/15 + 
       (173532546979583632936052499613708863850702075141944795293821588867833\
649*CF*NC*NH)/
        4076400809151388282398056032769560982722551145593866208000000 - 
       (340706595630303460063*CF*lm*NC*NH)/4429492179840 - 
       (511125032*CF*lm^2*NC*NH)/15 - 
       (871661570269046634602797635888932005343*CF^2*NC*Pi^2)/
        2039603969129126400 + (2422420*CF^2*lm*NC*Pi^2)/3 - 
       (31108573958651425553478513623*CF*NM*NC*Pi^2)/104756652 + 
       (605605*CF*lm*NM*NC*Pi^2)/27 - (88646183764567*CF*NC*NL*Pi^2)/
        1046520 + (605605*CF*lm*NC*NL*Pi^2)/27 + (605605*CF*lm*NC*NH*Pi^2)/
        27 - (12910181237267456039037835354030229*CF^2*NC*Pi^3)/
        (9801607154415368454796608*Sqrt[3]) - 
       (462111878147969456181497493085*CF*NC*NH*Pi^3)/(72945992754341572806*
         Sqrt[3]) - (29975203577*CF^2*NC*Pi^4)/1080 + 
       (25194325321641747169144507414054442957090767*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3327539281486392183655713872803200*
         Sqrt[3]) + (383548691996011852633295322158580406*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9309914690254729083297765*Sqrt[3]) - 
       3010752118*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (12910181237267456039037835354030229*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(264703896917081709813180*
         Sqrt[3]) - (105625572148107304270056569848*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) - (12910181237267456039037835354030229*CF^2*NC*Pi*Log[3]^2)/
        (12705787052019922071032640*Sqrt[3]) - 
       (13203196518513413033757071231*CF*NC*NH*Pi*Log[3]^2)/
        (2701703435345984178*Sqrt[3]) + 
       CF*((-23698298942171951711914266750916661252021*CF*NC)/
          4620977742558177000 - 59506037680*CF*lm*NC + 
         CA*(189586391535560872609347524624438469282163/
            73935643880930832000 + (81820801810*lm)/9)*NC - 
         (10156294480161835457850333438401057*NM*NC)/2850070122900 - 
         (14876509420*lm*NM*NC)/9 - (89065046456*NC*NL)/45 - 
         (14876509420*lm*NC*NL)/9 - (102438023924677547990003*NC*NH)/
          222622144044300 - (14876509420*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-3224365888226413275573126027*CA + 
          19*(339406935652797387712624369*CF + 
            74256*(3160304101792588780284*NM - 3719127355*NL)))*Log[x]^3)/
        4761666 - (7518275129917585294291519122642535196202437*CF^2*NC*
         PolyGamma[2, 1])/32169182804664633607446 - 
       (21285002779447557432955171*CF*NM*NC*PolyGamma[2, 1])/132300 - 
       (12082157467393300759872099696963124*CF*NC*NH*PolyGamma[2, 1])/
        3619033065524771280837675 + CA*CF*NC*
        (-1387567515627321806524064041472147229467541015662554073026671276248\
1240740283937217/
          39678685064261463358189497870725592855300263607396476160000000 + 
         (2811187676*lm^2)/15 + (871661570269331747127222695185057052581*
           Pi^2)/4079207938258252800 + (12910181237267456039037835354030229*
           Pi^3)/(19603214308830736909593216*Sqrt[3]) + (10004654099*Pi^4)/
          720 + lm*(5860861928620176498581/8858984359680 - 
           (6661655*Pi^2)/54) - (25194325321641747169144507414054442957090767*
           Im[PolyLog[2, (-1)^(1/3)]])/(6655078562972784367311427745606400*
           Sqrt[3]) + 1505376059*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (12910181237267456039037835354030229*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(529407793834163419626360*
           Sqrt[3]) + (12910181237267456039037835354030229*Pi*Log[3]^2)/
          (25411574104039844142065280*Sqrt[3]) + 
         (7518275129917585294291519122642535196202437*PolyGamma[2, 1])/
          64338365609329267214892 - 
         (566599392599128383482587278326238880405890659357*Zeta[3])/
          5403135943871471860706630160) + 
       (566599392608493671577477123550140087679945303991*CF^2*NC*Zeta[3])/
        2701567971935735930353315080 + (9685977418761066179583629*CF*NM*NC*
         Zeta[3])/66150 - (17437332608*CF*NC*NL*Zeta[3])/9 + 
       (12441517960790900178896685276804352*CF*NC*NH*Zeta[3])/
        3619033065524771280837675 + CF*Log[x]*
        ((-613910572182198970846272735161608509897097722427*NM*NC)/
          279273027968233030351620000 - (132835494146377*lm*NM*NC)/174420 - 
         142133376*lm^2*NM*NC - (22678706133743041787565733*NC*NL)/
          6417518209502400 - (132835494146377*lm*NC*NL)/174420 - 
         142133376*lm^2*NC*NL - 
         (2008475353939860338687446208624371209736701682821153593*NC*NH)/
          43501655185570004607005900713560598662990000 - 
         (132835494146377*lm*NC*NH)/174420 - 142133376*lm^2*NC*NH - 
         (2106869401198082495470*NM*NC*Pi^2)/9 - (8717455094*NC*NL*Pi^2)/
          27 + (105625572148107304270056569848*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1350851717672992089*Sqrt[3]) + 
         CF*NC*
          (
           -50971759050964715669972343687281403798002085041928266605948951838\
77/1635573671556804136549653745294930663744200000 - (102879819154057*lm)/
            4845 - 5116801536*lm^2 - (64487317765151781330766442203*Pi^2)/
            190466640 + (12910181237267456039037835354030229*
             Im[PolyLog[2, (-1)^(1/3)]])/(794111690751245129439540*Sqrt[3]) - 
           852800256*Zeta[3]) + CA*NC*(57088370137204750764091940077742266624\
4959250321979227366278759941349/
            366368502428724126587122438946064468678700800000 + 
           (1808263083797027*lm)/348840 + 781733568*lm^2 + 
           (3070824655488392287458351613*Pi^2)/18139680 - 
           (12910181237267456039037835354030229*Im[PolyLog[2, (-1)^(1/3)]])/
            (1588223381502490258879080*Sqrt[3]) + 426400128*Zeta[3]))}, 0, 
     39, 1]
 
CbarLSeries["v", 2, 4, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(154*CF*(91765720064166711671482 + 2198695693831372800*lm + 
           3559835660451840000*lm^2 - 76339191300539469600375*Zeta[3]) - 
         363*CA*(-1888226181988659916714 + 714963388937011200*lm + 
           230730089103360000*lm^2 + 1571328489709983729375*Zeta[3]) + 
         135*(8388608*(61908656339 + 24553807740*lm + 13446972000*lm^2)*NL + 
           3465*NM*(-749944326770650 + 59443655999488*lm + 
             32554509926400*lm^2 + 604774512116775*Zeta[3]) + 
           3465*NH*(-749944326770650 + 59443655999488*lm + 
             32554509926400*lm^2 + 604774512116775*Zeta[3]))))/
       2743814532006464716800000, 
      -(CF*NC*(154*CF*(91766159803305477946042 + 3622629958012108800*lm + 
            3559835660451840000*lm^2 - 76339191300539469600375*Zeta[3]) - 
          363*CA*(-1888083189310872514474 + 807255424578355200*lm + 
            230730089103360000*lm^2 + 1571328489709983729375*Zeta[3]) + 
          135*(8388608*(66819417887 + 29932596540*lm + 13446972000*lm^2)*
             NL + 693*NM*(-2507264388156238 + 362327299850240*lm + 
              162772549632000*lm^2 + 2121489131887125*Zeta[3]) + 
            693*NH*(-4873291567551286 + 362327299850240*lm + 
              162772549632000*lm^2 + 3926255989280625*Zeta[3]))))/
       548762906401292943360000, 
      (CF*NC*(-88*CA*(-4057125338787094963904811466 + 
           538902421488216834048000*lm + 140688133290951966720000*lm^2 + 
           3375602012133448009897359375*Zeta[3]) + 
         7*(624*CF*(2351305799839775768844441394 + 25034721262395457536000*
              lm + 18552281313092567040000*lm^2 - 
             1956056905304581469844328875*Zeta[3]) + 
           25*(536870912*(129171342995371 + 61281203763780*lm + 
               23959046311200*lm^2)*NL + 1287*NM*(-93490290494429205806 + 
               25563399963572961280*lm + 9994494983484211200*lm^2 + 
               88832472048692497125*Zeta[3]) + 1287*NH*
              (-385817680563046176302 + 25563399963572961280*lm + 
               9994494983484211200*lm^2 + 311815026813374209125*Zeta[3])))))/
       29677097978181922376908800000, 
      -(CF*NC*(5824*CF*(18274779859708119575676051226 + 
            88946066906935197696000*lm + 54978101940018216960000*lm^2 - 
            15202881189426261514971162375*Zeta[3]) - 
          1056*CA*(-3284968030716257184523714946 + 189878299575862689792000*
             lm + 46324141449459793920000*lm^2 + 2732960086411858864257571875*
             Zeta[3]) + 75*(1073741824*(645275362982147 + 312138322275780*
               lm + 110445359824800*lm^2)*NL + 3003*NM*
             (-189425961945244844126 + 111607050116781834240*lm + 
              39490443593279078400*lm^2 + 238384149326676478125*Zeta[3]) + 
            9009*NH*(-649013311241278223526 + 37202350038927278080*lm + 
              13163481197759692800*lm^2 + 526847272058684201625*Zeta[3]))))/
       59354195956363844753817600000, 
      (CF*NC*(56*CF*(2394002355658670454319599508102046 + 
           4528235538776804428873728000*lm + 2480221004142048486359040000*
            lm^2 - 1991585936237932539768167165386125*Zeta[3]) - 
         396*CA*(-9631322367629560808285814229754 + 
           230779935695506300207104000*lm + 53585021694426973470720000*lm^2 + 
           8012590263080469820876071324375*Zeta[3]) + 
         75*(8589934592*(37720816864797239 + 18169822228177620*lm + 
             5988592843833600*lm^2)*NL + 3003*NH*
            (-1071097285518049191472642 + 51973887608495989063680*lm + 
             17130076865351280230400*lm^2 + 873408080508860585563875*
              Zeta[3]) + 9009*NM*(17324629202831996354560*lm + 
             5710025621783760076800*lm^2 + 117*(-88248108201599981918 + 
               220529780099694190125*Zeta[3])))))/
       16144341300130965773038387200000, 
      -(CF*NC*(36*CF*(1018358372160627185663023744804034 + 
            742173646099495131493171200*lm + 375973594839585977794560000*
             lm^2 - 847179453079833003876500223343875*Zeta[3]) - 
          22*CA*(-42403522886985041598996330059338 + 
            418746730293745767206092800*lm + 93993398709896494448640000*
             lm^2 + 35276230384996127987011376199375*Zeta[3]) + 
          5*(4294967296*(117973786922291737 + 55715212281668940*lm + 
              17507634816672000*lm^2)*NL + 429*NM*
             (-134980997804878650000118 + 557797236921831323074560*lm + 
              175279065193280176128000*lm^2 + 811650778188795372452625*Zeta[
                3]) + 2574*NH*(-2304934385781852973440578 + 
              92966206153638553845760*lm + 29213177532213362688000*lm^2 + 
              1887247233271633333975875*Zeta[3]))))/
       1153167235723640412359884800000, 
      (CF*NC*(-33*CA*(-183715313270868565671758736728334502718 + 
           740488363931509656964300800000000*lm + 
           163008924884958721078072442880000*lm^2 + 
           152834916185256902322043694950937488125*Zeta[3]) + 
         7*(34*CF*(1114657779613221036556515234857461566862 + 
             304989587664031812143598796800000*lm + 
             147940873004836486356569948160000*lm^2 - 
             927291864255621157599370783761376459125*Zeta[3]) + 
           525*(17179869184*(110599541341493377297 + 50654678504046516900*
                lm + 15491213429506214400*lm^2)*NL + 36465*NM*
              (-19811465148713457206747926 + 23865096675088330590781440*lm + 
               7298423699995633322557440*lm^2 + 52621247661769523732220225*
                Zeta[3]) + 7293*NH*(-3623858629777397905450124854 + 
               119325483375441652953907200*lm + 36492118499978166612787200*
                lm^2 + 2977675218684010864194800625*Zeta[3])))))/
       2482160186212535725673105955225600000, 
      -(CF*NC*(-1188*CA*(-6965817771625975162509652612108314046 + 
            11319299854830379983288926208000*lm + 
            2479040753254376154542899200000*lm^2 + 
            5794927749965733945225014198286568125*Zeta[3]) + 
          7*(136*CF*(421172851554087002493631657201148339326 + 
              42217876597319296670503010304000*lm + 
              20248971530783643884165529600000*lm^2 - 
              350376778297146747815707142248695676125*Zeta[3]) + 
            75*(34359738368*(221972872042576544017 + 97758820149582632040*
                 lm + 29684399360111496000*lm^2)*NL + 109395*NM*(
                -95121156177930350498946674 + 30704945230623208202305536*lm + 
                9323535770598817293926400*lm^2 + 133932663313047395118196875*
                 Zeta[3]) + 7293*NH*(460574178459348123034583040*lm + 
                139853036558982259408896000*lm^2 + 2431*
                 (-7189940586832322533131422 + 5925346440661362455866125*
                   Zeta[3]))))))/1241080093106267862836552977612800000, 
      (CF*NC*(110808*CF*(115739923391714107208765194096037102119466 + 
           4123306454747768740076584960000000*lm + 
           2023841876795241904713404252160000*lm^2 - 
           96284893507539316559861874964914344777375*Zeta[3]) - 
         23716*CA*(-10130067253308494235820200476881320038722 + 
           6527601977624562661380115660800000*lm + 
           1444662638398829912501822423040000*lm^2 + 
           8427285087592437336839404168356103591875*Zeta[3]) + 
         1925*(1374389534720*(18185390370164688367259 + 
             7642103141385511442280*lm + 2354532123727679575680*lm^2)*NL + 
           12597*NM*(-7605460598350459484576570293846 + 
             833787932108524525466733772800*lm + 
             256890077797362785107889356800*lm^2 + 
             8059051919996947247832908078625*Zeta[3]) + 
           12597*NH*(833787932108524525466733772800*lm + 
             256890077797362785107889356800*lm^2 + 
             4199*(-9650509315325069739598185466 + 
               7972375431866241484357644375*Zeta[3])))))/
       14336957235563606351487859997383065600000, 
      -(CF*NC*(152*CF*(216962040020526759296333155578016519028131658 + 
            2631585445568543379577884779741184000*lm + 
            1379927615069934358533105222942720000*lm^2 - 
            180492319472791122455501560914761360123703375*Zeta[3]) - 
          132*CA*(-4266968912446345817243741893178215107497282 + 
            1065278891853154695703814693978112000*lm + 
            242765043391932896408601844776960000*lm^2 + 
            3549724126070210582264529770761605372391875*Zeta[3]) + 
          11025*(274877906944*(15067266498348226280113 + 
              5989490699867390996280*lm + 1922555826857255990400*lm^2)*NL + 
            138567*NH*(-764180051698918967412970605442 + 
              11881462882505229494869032960*lm + 3813809360594613350223052800*
               lm^2 + 632526292256685296170910083875*Zeta[3]) + 
            46189*NM*(-883937127634624871554736294294 + 
              35644388647515688484607098880*lm + 
              11441428081783840050669158400*lm^2 + 
              821313557558972804878777850625*Zeta[3]))))/
       14336957235563606351487859997383065600000, 
      (CF*NC*(-26*CA*(-4403661001695617800226758654221171352056401878 + 
           411554002817396510949600456172004966400*lm + 
           99056665111982545671187154526535680000*lm^2 + 
           3663438521241896402510032545444057418721558625*Zeta[3]) + 
         3*(4*CF*(610222840892565904676546387347857829465535385782 + 
             2351181133226336566896157623094503014400*lm + 
             1404803614315388829518654191467233280000*lm^2 - 
             507648879419053187935143054554900970880557896625*Zeta[3]) + 
           455*(4398046511104*(605257434803023258814653 + 
               224800225603265211779880*lm + 78001309172851420356000*lm^2)*
              NL + 46189*NH*(21405136459110018799690768711680*lm + 
               7427166331143857225141846016000*lm^2 + 323*
                (-5917461833354314658853102028058 + 
                 4905588905179681493725682106375*Zeta[3])) + 
             3553*NM*(278266773968430244395979993251840*lm + 
               96553162304870143926843998208000*lm^2 + 19*
                (-999698644236157326571441430418898 + 
                 873045230616725890934580766270875*Zeta[3]))))))/
       1319000065671851784336883119759242035200000, 
      -(CF*NC*(8*CF*(2091008340502813571013550249281917164868554677058 + 
            2240624537518916504199299382210723840000*lm + 
            1722146785233044004071458668061655040000*lm^2 - 
            1739525254273364437097925098283288720975552775875*Zeta[3]) - 
          12*CA*(-20029337990175481430189729191547985873133909738 + 
            663399314132962106394838142162042880000*lm + 
            175403839236698926340611531006279680000*lm^2 + 
            16662554646766114645243161848823082706810109375*Zeta[3]) + 
          175*(1099511627776*(14708797538102937714012851 + 
              4991020392664456744393800*lm + 1988931272183789780246400*lm^2)*
             NL + 12597*NH*(-58395075803823856461354372932071834 + 
              435634274525816267746857870950400*lm + 
              173601100310660412123466904371200*lm^2 + 
              48468671352468588047924471777778375*Zeta[3]) + 
            4199*NM*(-265579941190511825971098277576328378 + 
              1306902823577448803240573612851200*lm + 
              520803300931981236370400713113600*lm^2 + 
              225398999901209167526127068002944375*Zeta[3]))))/
       1319000065671851784336883119759242035200000, 
      (CF*NC*(-216*CA*(-29708482805046040230698805512179072659316636242126 + 
           316099576542163625695549529045384298496000*lm + 
           98751126805583152368346301986901065728000*lm^2 + 
           24714706145229910688727396196904092966551985687125*Zeta[3]) + 
         25*(1840*CF*(10529069329670073680683749500894318502181866983026 + 
             2185026679277632515948283258629481562112*lm + 
             3035133446799267165281663416008469118976*lm^2 - 
             8759210403066503697517836514343119139806068863115*Zeta[3]) + 
           231*(8796093022208*(501625364959841156434384759 + 
               147215465622683643796851240*lm + 76346884497195770347169280*
                lm^2)*NL + 289731*NM*
              (-3197483397002523506185439012865348766 + 
               4469390330771609875935039659704320*lm + 
               2317854485688807363016270062551040*lm^2 + 
               2680062803207310666375109259529274125*Zeta[3]) + 
             96577*NH*(13408170992314829627805118979112960*lm + 
               6953563457066422089048810187653120*lm^2 + 7429*
                (-423080237299150990206844089006706 + 
                 351494723982780310575018153652875*Zeta[3]))))))/
       17543454587758869789843023711723495777894400000, 
      -(CF*NC*(-68*CA*(-57937511275544699656537324460869091460059802303358 + 
            158469341689065437885796918527778619392000*lm + 
            70058047093281894254921246865742626816000*lm^2 + 
            48198642812454353251977061075828877424394568716125*Zeta[3]) + 
          7*(184*CF*(249574487724056384350992910306114033902984704274274 - 
              5304087229852282272246664454907887616000*lm + 
              24209782507672794626771204450499428352000*lm^2 - 
              207622856378872051976549726995779591122609637253875*Zeta[3]) + 
            8925*(13194139533312*(5170337019834522389777191 + 
                1039490828411105760329640*lm + 1050792375145713105185280*
                 lm^2)*NL + 2726880*NM*(
                -20227030148050491573798376781581414 + 
                5029626178509582829854482497536*lm + 
                5084309253877276278254544617472*lm^2 + 
                16868425958021403986391697352852025*Zeta[3]) + 
              96577*NH*(-91207701459584323920432173027419438 + 
                142012974452035279901773623459840*lm + 
                143556967168299565503657730375680*lm^2 + 
                75830279866085299730971744096273125*Zeta[3])))))/
       5582008277923276751313689362821112292966400000}, 2, 16, 1]

CbarLTable["v", 2, -1] = {{0., -0.000038580246913580246*CF*NC*
       (-3.*CA*(5160.430157209292 + 198.04533104651125*lm + 7140.*lm^2 + 
          1320.*lm^3) + 2.*(CF*(-135.93938964079425 + 116.1865557539944*lm + 
            5670.*lm^2 - 3240.*lm^3) - 
          15.*((-288.8434648794611 - 83.04316479128514*lm - 84.*lm^2 - 
              24.*lm^3)*NM + (-288.8434648794611 - 83.04316479128514*lm - 
              84.*lm^2 - 24.*lm^3)*NL - 1.*(-114.9438057198067 + 
              83.04316479128514*lm + 84.*lm^2 + 24.*lm^3)*NH)))}, 
     {0.005, CF*NC*(CA*(0.5664774200036408 + 0.003356097763197313*lm + 
          0.8158552042480709*lm^2 + 0.15125381944444444*lm^3) + 
        CF*(-0.01558513398902728 - 0.022629959009972937*lm - 
          0.4368839555486113*lm^2 + 0.24750625*lm^3) - 0.32733325531830904*
         NM - 0.09217020295303943*lm*NM - 0.09583598410570986*lm^2*NM - 
        0.027500694444444446*lm^3*NM - 0.32735256979168037*NL - 
        0.09217020295303943*lm*NL - 0.09583598410570986*lm^2*NL - 
        0.027500694444444446*lm^3*NL + 0.12972238143883777*NH - 
        0.09217020295303943*lm*NH - 0.09583598410570986*lm^2*NH - 
        0.027500694444444446*lm^3*NH)}, 
     {0.01, CF*NC*(CA*(0.536329482279015 - 0.01601206510541221*lm + 
          0.8053688181047581*lm^2 + 0.1497375*lm^3) + 
        CF*(-0.040455436970460626 - 0.03602049392769377*lm - 
          0.436280002192214*lm^2 + 0.245025*lm^3) - 0.32043677262231235*NM - 
        0.08826478246883106*lm*NM - 0.09445569420086511*lm^2*NM - 
        0.027225*lm^3*NM - 0.32050850824036714*NL - 0.08826478246883106*lm*
         NL - 0.09445569420086511*lm^2*NL - 0.027225*lm^3*NL + 
        0.1264272935503567*NH - 0.08826478246883106*lm*NH - 
        0.09445569420086511*lm^2*NH - 0.027225*lm^3*NH)}, 
     {0.015, CF*NC*(CA*(0.5070050486652662 - 0.035117010335685525*lm + 
          0.7949339563090598*lm^2 + 0.14822881944444444*lm^3) + 
        CF*(-0.06390161331279477 - 0.04906233220384228*lm - 
          0.4356812249033566*lm^2 + 0.24255625*lm^3) - 
        0.3136522436280296*NM - 0.08440945562952411*lm*NM - 
        0.0930821208440715*lm^2*NM - 0.026950694444444444*lm^3*NM - 
        0.3138034831347268*NL - 0.08440945562952411*lm*NL - 
        0.0930821208440715*lm^2*NL - 0.026950694444444444*lm^3*NL + 
        0.12315443904339582*NH - 0.08440945562952411*lm*NH - 
        0.0930821208440715*lm^2*NH - 0.026950694444444444*lm^3*NH)}, 
     {0.02, CF*NC*(CA*(0.4785911992835258 - 0.05391513666436514*lm + 
          0.7845540475263827*lm^2 + 0.1467277777777778*lm^3) + 
        CF*(-0.08585765307317896 - 0.06171090391018802*lm - 
          0.4350820131386465*lm^2 + 0.2401*lm^3) - 0.30699626988511974*NM - 
        0.08061135652735234*lm*NM - 0.09171588742903929*lm^2*NM - 
        0.02667777777777778*lm^3*NM - 0.3072496161471598*NL - 
        0.08061135652735234*lm*NL - 0.09171588742903929*lm^2*NL - 
        0.02667777777777778*lm^3*NL + 0.11990617926838798*NH - 
        0.08061135652735234*lm*NH - 0.09171588742903929*lm^2*NH - 
        0.02667777777777778*lm^3*NH)}, 
     {0.025, CF*NC*(CA*(0.4511351562853828 - 0.07237450626402925*lm + 
          0.7742320195644943*lm^2 + 0.145234375*lm^3) + 
        CF*(-0.10631672581015288 - 0.07393681308401141*lm - 
          0.4344775759399185*lm^2 + 0.23765625*lm^3) - 0.30047850872667237*
         NM - 0.07687561453079332*lm*NM - 0.0903575262844535*lm^2*NM - 
        0.02640625*lm^3*NM - 0.30085299440123664*NL - 
        0.07687561453079332*lm*NL - 0.0903575262844535*lm^2*NL - 
        0.02640625*lm^3*NL + 0.11668453955459814*NH - 
        0.07687561453079332*lm*NH - 0.0903575262844535*lm^2*NH - 
        0.02640625*lm^3*NH)}, 
     {0.03, CF*NC*(CA*(0.4246612208801571 - 0.09047082997679144*lm + 
          0.7639704305647425*lm^2 + 0.14374861111111112*lm^3) + 
        CF*(-0.12530182127743314 - 0.0857202927030997*lm - 
          0.43386372725769423*lm^2 + 0.235225*lm^3) - 0.2941045942353024*
         NM - 0.07320605388377893*lm*NM - 0.08900750252692285*lm^2*NM - 
        0.02613611111111111*lm^3*NM - 0.29461631365179725*NL - 
        0.07320605388377893*lm*NL - 0.08900750252692285*lm^2*NL - 
        0.02613611111111111*lm^3*NL + 0.11349129462703932*NH - 
        0.07320605388377893*lm*NH - 0.08900750252692285*lm^2*NH - 
        0.02613611111111111*lm^3*NH)}, 
     {0.035, CF*NC*(CA*(0.39917902682384926 - 0.1081853168489714*lm + 
          0.7537715456275406*lm^2 + 0.14227048611111112*lm^3) + 
        CF*(-0.14285245941517885 - 0.09704828418118791*lm - 
          0.43323676056402455*lm^2 + 0.23280625*lm^3) - 
        0.2878775659545826*NM - 0.06960556696787441*lm*NM - 
        0.08766622799288616*lm^2*NM - 0.025867361111111112*lm^3*NM - 
        0.288540147133707*NL - 0.06960556696787441*lm*NL - 
        0.08766622799288616*lm^2*NL - 0.025867361111111112*lm^3*NL + 
        0.11032801851072618*NH - 0.06960556696787441*lm*NH - 
        0.08766622799288616*lm^2*NH - 0.025867361111111112*lm^3*NH)}, 
     {0.04, CF*NC*(CA*(0.37468824454810407 - 0.1255033466046701*lm + 
          0.7436373876217103*lm^2 + 0.1408*lm^3) + 
        CF*(-0.1590176297729148 - 0.10791266186875846*lm - 
          0.4325933657099287*lm^2 + 0.2304*lm^3) - 0.28179868631989946*NM - 
        0.06607634391318533*lm*NM - 0.08633407047667459*lm^2*NM - 
        0.0256*lm^3*NM - 0.28262365896205577*NL - 0.06607634391318533*lm*
         NL - 0.08633407047667459*lm^2*NL - 0.0256*lm^3*NL + 
        0.1071961176723827*NH - 0.06607634391318533*lm*NH - 
        0.08633407047667459*lm^2*NH - 0.0256*lm^3*NH)}, 
     {0.045, CF*NC*(CA*(0.35118152462745983 - 0.142413576996117*lm + 
          0.7335697735664539*lm^2 + 0.13933715277777778*lm^3) + 
        CF*(-0.17385167624358244 - 0.11830905649380934*lm - 
          0.4319305693912572*lm^2 + 0.22800625*lm^3) - 
        0.2758679541011062*NM - 0.0626200264793256*lm*NM - 
        0.08501136034541587*lm^2*NM - 0.025334027777777778*lm^3*NM - 
        0.2768650447312624*NL - 0.0626200264793256*lm*NL - 
        0.08501136034541587*lm^2*NL - 0.025334027777777778*lm^3*NL + 
        0.10409685481440628*NH - 0.0626200264793256*lm*NH - 
        0.08501136034541587*lm^2*NH - 0.025334027777777778*lm^3*NH)}, 
     {0.05, CF*NC*(CA*(0.3286464585453007 - 0.15890730780442103*lm + 
          0.7235703420767308*lm^2 + 0.13788194444444443*lm^3) + 
        CF*(-0.1874117516226072 - 0.12823602878192605*lm - 
          0.431245690238077*lm^2 + 0.225625*lm^3) - 0.27008444771580076*NM - 
        0.05923781734064855*lm*NM - 0.08369839552910255*lm^2*NM - 
        0.025069444444444443*lm^3*NM - 0.27126182126175474*NL - 
        0.05923781734064855*lm*NL - 0.08369839552910255*lm^2*NL - 
        0.025069444444444443*lm^3*NL + 0.10103136688938583*NH - 
        0.05923781734064855*lm*NH - 0.08369839552910255*lm^2*NH - 
        0.025069444444444443*lm^3*NH)}, 
     {0.055, CF*NC*(CA*(0.30706694478409013 - 0.17497800828332735*lm + 
          0.7136405748650718*lm^2 + 0.136434375*lm^3) + 
        CF*(-0.1997561797139207 - 0.13769446410983266*lm - 
          0.43053630362988254*lm^2 + 0.22325625*lm^3) - 
        0.2644465652986506*NM - 0.055930561029937056*lm*NM - 
        0.08239544543001305*lm^2*NM - 0.02480625*lm^3*NM - 
        0.2658110258720564*NL - 0.055930561029937056*lm*NL - 
        0.08239544543001305*lm^2*NL - 0.02480625*lm^3*NL + 
        0.09800067927656295*NH - 0.055930561029937056*lm*NH - 
        0.08239544543001305*lm^2*NH - 0.02480625*lm^3*NH)}, 
     {0.06, CF*NC*(CA*(0.2864241730755986 - 0.19062095468609797*lm + 
          0.7037818140774228*lm^2 + 0.13499444444444444*lm^3) + 
        CF*(-0.21094337386820802 - 0.14668711475905377*lm - 
          0.42980021332785356*lm^2 + 0.2209*lm^3) - 0.258952198287004*NM - 
        0.052698805831007306*lm*NM - 0.08110275407468294*lm^2*NM - 
        0.024544444444444445*lm^3*NM - 0.26050935806374714*NL - 
        0.052698805831007306*lm*NL - 0.08110275407468294*lm^2*NL - 
        0.024544444444444445*lm^3*NL + 0.09500571727100725*NH - 
        0.052698805831007306*lm*NH - 0.08110275407468294*lm^2*NH - 
        0.024544444444444445*lm^3*NH)}, 
     {0.065, CF*NC*(CA*(0.26669735207944173 - 0.20583294520274326*lm + 
          0.693995276588349*lm^2 + 0.13356215277777778*lm^3) + 
        CF*(-0.22103111209856155 - 0.1552182450939385*lm - 
          0.42903542808270156*lm^2 + 0.21855625*lm^3) - 
        0.2535988602048282*NM - 0.049542852300321655*lm*NM - 
        0.07982054271303315*lm^2*NM - 0.02428402777777778*lm^3*NM - 
        0.2553532828459744*NL - 0.049542852300321655*lm*NL - 
        0.07982054271303315*lm^2*NL - 0.02428402777777778*lm^3*NL + 
        0.09204731561261552*NH - 0.049542852300321655*lm*NH - 
        0.07982054271303315*lm^2*NH - 0.02428402777777778*lm^3*NH)}, 
     {0.07, CF*NC*(CA*(0.247864258357066 - 0.2206120712293837*lm + 
          0.6842820660042827*lm^2 + 0.1321375*lm^3) + 
        CF*(-0.23007604861931208 - 0.16329335101953046*lm - 
          0.428240141992992*lm^2 + 0.216225*lm^3) - 0.24838378415280538*NM - 
        0.04646279207676644*lm*NM - 0.07854901200077867*lm^2*NM - 
        0.024025*lm^3*NM - 0.25033910757258754*NL - 0.04646279207676644*lm*
         NL - 0.07854901200077867*lm^2*NL - 0.024025*lm^3*NL + 
        0.08912622653776106*NH - 0.04646279207676644*lm*NH - 
        0.07854901200077867*lm^2*NH - 0.024025*lm^3*NH)}, 
     {0.075, CF*NC*(CA*(0.22990165720343606 - 0.23495753079060422*lm + 
          0.6746431828931374*lm^2 + 0.13072048611111112*lm^3) + 
        CF*(-0.2381333863662115 - 0.17091893456513746*lm - 
          0.42741271776577516*lm^2 + 0.21390625*lm^3) - 
        0.24330399779610695*NM - 0.04345853943767679*lm*NM - 
        0.07728834385935832*lm^2*NM - 0.02376736111111111*lm^3*NM - 
        0.24546303995178287*NL - 0.04345853943767679*lm*NL - 
        0.07728834385935832*lm^2*NL - 0.02376736111111111*lm^3*NL + 
        0.08624312668725813*NH - 0.04345853943767679*lm*NH - 
        0.07728834385935832*lm^2*NH - 0.02376736111111111*lm^3*NH)}, 
     {0.08, CF*NC*(CA*(0.21278562936306195 - 0.24886947424353426*lm + 
          0.6650795336110699*lm^2 + 0.1293111111111111*lm^3) + 
        CF*(-0.24525666143348415 - 0.17810232033637666*lm - 
          0.4265516722727947*lm^2 + 0.2116*lm^3) - 0.23835638178027177*NM - 
        0.04052985731008381*lm*NM - 0.07603870308080059*lm^2*NM - 
        0.02351111111111111*lm^3*NM - 0.24072123235006884*NL - 
        0.04052985731008381*lm*NL - 0.07603870308080059*lm^2*NL - 
        0.02351111111111111*lm^3*NL + 0.08339862310892081*NH - 
        0.04052985731008381*lm*NH - 0.07603870308080059*lm^2*NH - 
        0.02351111111111111*lm^3*NH)}, 
     {0.085, CF*NC*(CA*(0.1964918272218588 - 0.2623488751913524*lm + 
          0.6555919379989865*lm^2 + 0.127909375*lm^3) + 
        CF*(-0.25149760657949416 - 0.18485150439180933*lm - 
          0.42565566395620386*lm^2 + 0.20930625*lm^3) - 
        0.2335377156967591*NM - 0.03767637895997669*lm*NM - 
        0.07480023872708846*lm^2*NM - 0.02325625*lm^3*NM - 
        0.23610981591890787*NL - 0.03767637895997669*lm*NL - 
        0.07480023872708846*lm^2*NL - 0.02325625*lm^3*NL + 
        0.08059325852962837*NH - 0.03767637895997669*lm*NH - 
        0.07480023872708846*lm^2*NH - 0.02325625*lm^3*NH)}, 
     {0.09, CF*NC*(CA*(0.18099567724933588 - 0.27539742141425305*lm + 
          0.6461811361539306*lm^2 + 0.12651527777777777*lm^3) + 
        CF*(-0.2569060712715862 - 0.19117502865031452*lm - 
          0.42472348174811353*lm^2 + 0.207025*lm^3) - 0.22884471453583094*
         NM - 0.03489762625610348*lm*NM - 0.07357308536132072*lm^2*NM - 
        0.023002777777777778*lm^3*NM - 0.23162492703674378*NL - 
        0.03489762625610348*lm*NL - 0.07357308536132072*lm^2*NL - 
        0.023002777777777778*lm^3*NL + 0.0778275160283409*NH - 
        0.03489762625610348*lm*NH - 0.07357308536132072*lm^2*NH - 
        0.023002777777777778*lm^3*NH)}, 
     {0.095, CF*NC*(CA*(0.16627254087916482 - 0.28801742192560664*lm + 
          0.6368477944328439*lm^2 + 0.12512881944444446*lm^3) + 
        CF*(-0.26152998250114545 - 0.19708187569005242*lm - 
          0.4237540352462554*lm^2 + 0.20475625*lm^3) - 0.22427405776631687*
         NM - 0.03219302517955077*lm*NM - 0.07235736413930495*lm^2*NM - 
        0.022750694444444445*lm^3*NM - 0.22726272786586588*NL - 
        0.03219302517955077*lm*NL - 0.07235736413930495*lm^2*NL - 
        0.022750694444444445*lm^3*NL + 0.07510182321086388*NH - 
        0.03219302517955077*lm*NH - 0.07235736413930495*lm^2*NH - 
        0.022750694444444445*lm^3*NH)}, 
     {0.1, CF*NC*(CA*(0.1522978428510928 - 0.30021172718176387*lm + 
          0.6275925108117488*lm^2 + 0.12375*lm^3) + 
        CF*(-0.26541533514116844 - 0.202581380037457*lm - 
          0.4227463459444111*lm^2 + 0.2025*lm^3) - 0.21982241262994107*NM - 
        0.0295619190909108*lm*NM - 0.07115318378395433*lm^2*NM - 
        0.0225*lm^3*NM - 0.22301942234756375*NL - 0.0295619190909108*lm*
         NL - 0.07115318378395433*lm^2*NL - 0.0225*lm^3*NL + 
        0.07241655596503856*NH - 0.0295619190909108*lm*NH - 
        0.07115318378395433*lm^2*NH - 0.0225*lm^3*NH)}, 
     {0.105, CF*NC*(CA*(0.13904717380410692 - 0.3119836601403465*lm + 
          0.6184158196979671*lm^2 + 0.12237881944444444*lm^3) + 
        CF*(-0.26860620373568606 - 0.20768315293656417*lm - 
          0.42169953935787197*lm^2 + 0.20025625*lm^3) - 
        0.2154864528477285*NM - 0.027003580151566255*lm*NM - 
        0.06996064146023645*lm^2*NM - 0.022250694444444444*lm^3*NM - 
        0.21889126862489044*NL - 0.027003580151566255*lm*NL - 
        0.06996064146023645*lm^2*NL - 0.022250694444444444*lm^3*NL + 
        0.06977204185873194*NH - 0.027003580151566255*lm*NH - 
        0.06996064146023645*lm^2*NH - 0.022250694444444444*lm^3*NH)}, 
     {0.11, CF*NC*(CA*(0.12649637230434368 - 0.3233369563533877*lm + 
          0.609318196273879*lm^2 + 0.12101527777777778*lm^3) + 
        CF*(-0.27114476979044194 - 0.21239701824399906*lm - 
          0.4206128379154708*lm^2 + 0.198025*lm^3) - 0.2112628736547526*NM - 
        0.02451721921067939*lm*NM - 0.06877982356494769*lm^2*NM - 
        0.022002777777777777*lm^3*NM - 0.2148745886431982*NL - 
        0.02451721921067939*lm*NL - 0.06877982356494769*lm^2*NL - 
        0.022002777777777777*lm^3*NL + 0.06716856323076441*NH - 
        0.02451721921067939*lm*NH - 0.06877982356494769*lm^2*NH - 
        0.022002777777777777*lm^3*NH)}, 
     {0.115, CF*NC*(CA*(0.11462159031555462 - 0.3342757116503495*lm + 
          0.6003000604361185*lm^2 + 0.119659375*lm^3) + 
        CF*(-0.273071360184207 - 0.21673295758416558*lm - 
          0.41948555451362424*lm^2 + 0.19580625*lm^3) - 
        0.20714840387321276*NM - 0.022101994405821078*lm*NM - 
        0.06761080644293063*lm^2*NM - 0.02175625*lm^3*NM - 
        0.2109657755044731*NL - 0.022101994405821078*lm*NL - 
        0.06761080644293063*lm^2*NL - 0.02175625*lm^3*NL + 
        0.06460636001557987*NH - 0.022101994405821078*lm*NH - 
        0.06761080644293063*lm^2*NH - 0.02175625*lm^3*NH)}, 
     {0.12, CF*NC*(CA*(0.1033993452461863 - 0.3448043362467395*lm + 
          0.5913617803827886*lm^2 + 0.11831111111111112*lm^3) + 
        CF*(-0.2744244934381353 - 0.22070106327010267*lm - 
          0.41831708664634576*lm^2 + 0.1936*lm^3) - 0.20313981558021224*NM - 
        0.01975701867675952*lm*NM - 0.06645365703929491*lm^2*NM - 
        0.021511111111111113*lm^3*NM - 0.2071612990227426*NL - 
        0.01975701867675952*lm*NL - 0.06645365703929491*lm^2*NL - 
        0.021511111111111113*lm^3*NL + 0.062085632335239664*NH - 
        0.01975701867675952*lm*NH - 0.06645365703929491*lm^2*NH - 
        0.021511111111111113*lm^3*NH)}, 
     {0.125, CF*NC*(CA*(0.09280656104877721 - 0.35492751433066005*lm + 
          0.5825036758923854*lm^2 + 0.1169704861111111*lm^3) + 
        CF*(-0.2752409313973137 - 0.22431149778051185*lm - 
          0.4171069110397331*lm^2 + 0.19140625*lm^3) - 0.19923393181061627*
         NM - 0.017481366354601024*lm*NM - 0.06530843349558521*lm^2*NM - 
        0.021267361111111112*lm^3*NM - 0.2034577098313187*NL - 
        0.017481366354601024*lm*NL - 0.06530843349558521*lm^2*NL - 
        0.021267361111111112*lm^3*NL + 0.059606542886656746*NH - 
        0.017481366354601024*lm*NH - 0.06530843349558521*lm^2*NH - 
        0.021267361111111112*lm^3*NH)}, 
     {0.13, CF*NC*(CA*(0.08282060034512435 - 0.3646501683488308*lm + 
          0.5737260213310627*lm^2 + 0.1156375*lm^3) + 
        CF*(-0.2755557344820353 - 0.22757445880519606*lm - 
          0.4158545787309884*lm^2 + 0.189225*lm^3) - 0.19542763264670127*
         NM - 0.015274078959344359*lm*NM - 0.06417518569655685*lm^2*NM - 
        0.021025*lm^3*NM - 0.19985164231940114*NL - 0.015274078959344359*lm*
         NL - 0.06417518569655685*lm^2*NL - 0.021025*lm^3*NL + 
        0.05716921914749226*NH - 0.015274078959344359*lm*NH - 
        0.06417518569655685*lm^2*NH - 0.021025*lm^3*NH)}, 
     {0.135, CF*NC*(CA*(0.0734192891631928 - 0.3739774273472712*lm + 
          0.5650290484191988*lm^2 + 0.11431215277777777*lm^3) + 
        CF*(-0.27540231911648055 - 0.23050014904555396*lm - 
          0.4145597105413111*lm^2 + 0.18705625*lm^3) - 0.19171785997775986*
         NM - 0.01313417031592327*lm*NM - 0.06305395577318766*lm^2*NM - 
        0.020784027777777776*lm^3*NM - 0.19633981661936195*NL - 
        0.01313417031592327*lm*NL - 0.06305395577318766*lm^2*NL - 
        0.020784027777777776*lm^3*NL + 0.054773755420530486*NH - 
        0.01313417031592327*lm*NH - 0.06305395577318766*lm^2*NH - 
        0.020784027777777776*lm^3*NH)}, 
     {0.14, CF*NC*(CA*(0.06458093556973991 - 0.3829145988284588*lm + 
          0.5564129487836231*lm^2 + 0.11299444444444444*lm^3) + 
        CF*(-0.2748125162812491 - 0.2330987500953401*lm - 
          0.4132219928995258*lm^2 + 0.1849*lm^3) - 0.18810162115929502*NM - 
        0.011060631080488773*lm*NM - 0.06194477856671935*lm^2*NM - 
        0.020544444444444445*lm^3*NM - 0.19291903982246467*NL - 
        0.011060631080488773*lm*NL - 0.06194477856671935*lm^2*NL - 
        0.020544444444444445*lm^3*NL + 0.05242021473342723*NH - 
        0.011060631080488773*lm*NH - 0.06194477856671935*lm^2*NH - 
        0.020544444444444445*lm^3*NH)}, 
     {0.145, CF*NC*(CA*(0.05628434324504894 - 0.39146714367264146*lm + 
          0.5478778763181023*lm^2 + 0.111684375*lm^3) + 
        CF*(-0.2738166303930401 - 0.23538039983801326*lm - 
          0.4118411739794691*lm^2 + 0.18275625*lm^3) - 0.18457599175924258*
         NM - 0.00905243275394236*lm*NM - 0.06084768205783676*lm^2*NM - 
        0.02030625*lm^3*NM - 0.1895862065666875*NL - 0.00905243275394236*lm*
         NL - 0.06084768205783676*lm^2*NL - 0.02030625*lm^3*NL + 
        0.05010863060833872*NH - 0.00905243275394236*lm*NH - 
        0.06084768205783676*lm^2*NH - 0.02030625*lm^3*NH)}, 
     {0.15, CF*NC*(CA*(0.048508820857673614 - 0.39964065374071084*lm + 
          0.539423949371578*lm^2 + 0.11038194444444445*lm^3) + 
        CF*(-0.27244349791080275 - 0.2373551728868515*lm - 
          0.41041706011923595*lm^2 + 0.180625*lm^3) - 0.18113811754512227*
         NM - 0.007108531247771733*lm*NM - 0.05976268776452934*lm^2*NM - 
        0.020069444444444445*lm^3*NM - 0.18633829911342875*NL - 
        0.007108531247771733*lm*NL - 0.05976268776452934*lm^2*NL - 
        0.020069444444444445*lm^3*NL + 0.04783900871396882*NH - 
        0.007108531247771733*lm*NH - 0.05976268776452934*lm^2*NH - 
        0.020069444444444445*lm^3*NH)}, 
     {0.155, CF*NC*(CA*(0.04123418794637645 - 0.407440831833116*lm + 
          0.5310512527810697*lm^2 + 0.10908715277777778*lm^3) + 
        CF*(-0.2707205452181081 - 0.23903306366724333*lm - 
          0.4089495124946133*lm^2 + 0.17850625*lm^3) - 0.17778521583914889*
         NM - 0.0052278700574610445*lm*NM - 0.05868981111170963*lm^2*NM - 
        0.019834027777777777*lm^3*NM - 0.18317238700849342*NL - 
        0.0052278700574610445*lm*NL - 0.05868981111170963*lm^2*NL - 
        0.019834027777777777*lm^3*NL + 0.045611328410936604*NH - 
        0.0052278700574610445*lm*NH - 0.05868981111170963*lm^2*NH - 
        0.019834027777777777*lm^3*NH)}, 
     {0.16, CF*NC*(CA*(0.03444077789506032 - 0.4148734737263488*lm + 
          0.5227598397639902*lm^2 + 0.1078*lm^3) + 
        CF*(-0.2686738454474621 - 0.24042397180068262*lm - 
          0.40743844402256146*lm^2 + 0.1764*lm^3) - 0.17451457634666007*NM - 
        0.0034093830906930687*lm*NM - 0.05762906177527095*lm^2*NM - 
        0.0196*lm^3*NM - 0.18008562640564507*NL - 0.0034093830906930687*lm*
         NL - 0.05762906177527095*lm^2*NL - 0.0196*lm^3*NL + 
        0.043425544199997175*NH - 0.0034093830906930687*lm*NH - 
        0.05762906177527095*lm^2*NH - 0.0196*lm^3*NH)}, 
     {0.165, CF*NC*(CA*(0.028109438488089444 - 0.42194445204758124*lm + 
          0.5145497336828084*lm^2 + 0.10652048611111112*lm^3) + 
        CF*(-0.2663281740020086 - 0.24153768949967314*lm - 
          0.4058838164735863*lm^2 + 0.17430625*lm^3) - 0.17132356154561412*
         NM - 0.001651997190881776*lm*NM - 0.056580444002934854*lm^2*NM - 
        0.01936736111111111*lm^3*NM - 0.17707525911721236*NL - 
        0.001651997190881776*lm*NL - 0.056580444002934854*lm^2*NL - 
        0.01936736111111111*lm^3*NL + 0.04128158708149468*NH - 
        0.001651997190881776*lm*NH - 0.056580444002934854*lm^2*NH - 
        0.01936736111111111*lm^3*NH)}, 
     {0.17, CF*NC*(CA*(0.02222153045313405 - 0.4286597017806523*lm + 
          0.5064209296934404*lm^2 + 0.10524861111111111*lm^3) + 
        CF*(-0.26370706259968346 - 0.2423838907240576*lm - 
          0.40428563777437027*lm^2 + 0.172225*lm^3) - 0.16820960671053162*
         NM + 0.00004536560899855568*lm*NM - 0.05554395691395886*lm^2*NM - 
        0.01913611111111111*lm^3*NM - 0.17413861144506146*NL + 
        0.00004536560899855568*lm*NL - 0.05554395691395886*lm^2*NL - 
        0.01913611111111111*lm^3*NL + 0.03917936583344875*NH + 
        0.00004536560899855568*lm*NH - 0.05554395691395886*lm^2*NH - 
        0.01913611111111111*lm^3*NH)}, 
     {0.175, CF*NC*(CA*(0.016758924332839147 - 0.43502520722399374*lm + 
          0.4983733962874419*lm^2 + 0.103984375*lm^3) + 
        CF*(-0.260832851718977 - 0.2429721218838329*lm - 0.4026439594841859*
           lm^2 + 0.17015625*lm^3) - 0.16517021963244105*NM + 
        0.0016837860719979795*lm*NM - 0.0545195947795349*lm^2*NM - 
        0.01890625*lm^3*NM - 0.1712730928361318*NL + 0.0016837860719979795*
         lm*NL - 0.0545195947795349*lm^2*NL - 0.01890625*lm^3*NL + 
        0.0371187682148408*NH + 0.0016837860719979795*lm*NH - 
        0.0545195947795349*lm^2*NH - 0.01890625*lm^3*NH)}, 
     {0.18, CF*NC*(CA*(0.011703995972335996 - 0.44104699024422417*lm + 
          0.49040707673694034*lm^2 + 0.10272777777777778*lm^3) + 
        CF*(-0.2577267413675268 - 0.24331179390255903*lm - 
          0.40095887443046124*lm^2 + 0.1681*lm^3) - 0.16220298008663464*NM + 
        0.003264345955845215*lm*NM - 0.053507347285504304*lm^2*NM - 
        0.01867777777777778*lm^3*NM - 0.16847619439926925*NL + 
        0.003264345955845215*lm*NL - 0.053507347285504304*lm^2*NL - 
        0.01867777777777778*lm^3*NL + 0.03509966209995171*NH + 
        0.003264345955845215*lm*NH - 0.053507347285504304*lm^2*NH - 
        0.01867777777777778*lm^3*NH)}, 
     {0.185, CF*NC*(CA*(0.007039620864643238 - 0.44673109968878205*lm + 
          0.48252189045027466*lm^2 + 0.10147881944444445*lm^3) + 
        CF*(-0.2544088401274509 - 0.24341217548001517*lm - 
          0.39923051449045965*lm^2 + 0.16605625*lm^3) - 
        0.15930553909194825*NM + 0.004788126401673651*lm*NM - 
        0.05250719977883782*lm^2*NM - 0.018450694444444443*lm^3*NM - 
        0.16574548731394903*NL + 0.004788126401673651*lm*NL - 
        0.05250719977883782*lm^2*NL - 0.018450694444444443*lm^3*NL + 
        0.033121896548984994*NH + 0.004788126401673651*lm*NH - 
        0.05250719977883782*lm^2*NH - 0.018450694444444443*lm^3*NH)}, 
     {0.19, CF*NC*(CA*(0.002749167558578167 - 0.45208360183771756*lm + 
          0.47471773424547076*lm^2 + 0.1002375*lm^3) + 
        CF*(-0.2508982124566835 - 0.24328238741359248*lm - 
          0.3974590485074115*lm^2 + 0.164025*lm^3) - 0.15647561799853685*
         NM + 0.0062562064926719434*lm*NM - 0.0515191334991765*lm^2*NM - 
        0.018225*lm^3*NM - 0.1630786211564038*NL + 0.0062562064926719434*lm*
         NL - 0.0515191334991765*lm^2*NL - 0.018225*lm^3*NL + 
        0.031185302819675742*NH + 0.0062562064926719434*lm*NH - 
        0.0515191334991765*lm^2*NH - 0.018225*lm^3*NH)}, 
     {0.195, CF*NC*(CA*(-0.0011835096974759476 - 0.4571105717891171*lm + 
          0.4669944835479447*lm^2 + 0.09900381944444445*lm^3) + 
        CF*(-0.24721292424516328 - 0.2429313978556825*lm - 
          0.39564468033063593*lm^2 + 0.16200625*lm^3) - 
        0.1537110074354754*NM + 0.007669661964952108*lm*NM - 
        0.05054312579659601*lm^2*NM - 0.018000694444444444*lm^3*NM - 
        0.16047332216446278*NL + 0.007669661964952108*lm*NL - 
        0.05054312579659601*lm^2*NL - 0.018000694444444444*lm^3*NL + 
        0.02928969532412023*NH + 0.007669661964952108*lm*NH - 
        0.05054312579659601*lm^2*NH - 0.018000694444444444*lm^3*NH)}, 
     {0.2, NC*(CA*CF*(-0.004774078928836474 - 0.46181808568497906*lm + 
          0.4593519935181911*lm^2 + 0.09777777777777778*lm^3) + 
        CF^2*(-0.24337008663977497 - 0.24236801839953276*lm - 
          0.3937876469702327*lm^2 + 0.16*lm^3) + 
        CF*((-0.15100956614478192 + 0.009029564055024948*lm - 
            0.04957915033664081*lm^2 - 0.017777777777777778*lm^3)*NM + 
          (-0.15792739145890128 + 0.009029564055024948*lm - 
            0.04957915033664081*lm^2 - 0.017777777777777778*lm^3)*NL + 
          (0.027434872534654736 + 0.009029564055024948*lm - 
            0.04957915033664081*lm^2 - 0.017777777777777778*lm^3)*NH))}, 
     {0.205, NC*(CA*CF*(-0.008037738899794521 - 0.46621221369502264*lm + 
          0.45179010011465054*lm^2 + 0.096559375*lm^3) + 
        CF^2*(-0.239385898163414 - 0.2416009008991175*lm - 
          0.39188821685784453*lm^2 + 0.15800625*lm^3) + 
        CF*((-0.1483692197244495 + 0.010336978470081916*lm - 
            0.048627177293572826*lm^2 - 0.01755625*lm^3)*NM + 
          (-0.15543870323617234 + 0.010336978470081916*lm - 
            0.048627177293572826*lm^2 - 0.01755625*lm^3)*NL + 
          (0.025620617842255267 + 0.010336978470081916*lm - 
            0.048627177293572826*lm^2 - 0.01755625*lm^3)*NH))}, 
     {0.21, NC*(CA*CF*(-0.010989227964528482 - 0.47029901368515864*lm + 
          0.4443086210964604*lm^2 + 0.0953486111111111*lm^3) + 
        CF^2*(-0.23527568516215883 - 0.24063853493985043*lm - 
          0.38994668820579204*lm^2 + 0.156025*lm^3) + 
        CF*((-0.14578795929975227 + 0.011592964468849278*lm - 
            0.047687173532689774*lm^2 - 0.01733611111111111*lm^3)*NM + 
          (-0.15300520294493894 + 0.011592964468849278*lm - 
            0.047687173532689774*lm^2 - 0.01733611111111111*lm^3)*NL + 
          (0.02384670037061551 + 0.011592964468849278*lm - 
            0.047687173532689774*lm^2 - 0.01733611111111111*lm^3)*NH))}, 
     {0.215, NC*(CA*CF*(-0.013642833213079832 - 0.47408452550538893*lm + 
          0.4369073569703556*lm^2 + 0.0941454861111111*lm^3) + 
        CF^2*(-0.23105394062094586 - 0.2394892458867311*lm - 
          0.3879633874575999*lm^2 + 0.15405625*lm^3) + 
        CF*((-0.14326384013913715 + 0.012798574042142106*lm - 
            0.0467591027824889*lm^2 - 0.01711736111111111*lm^3)*NM + 
          (-0.15062490545676568 + 0.012798574042142106*lm - 
            0.0467591027824889*lm^2 - 0.01711736111111111*lm^3)*NL + 
          (0.02211287574878222 + 0.012798574042142106*lm - 0.0467591027824889*
             lm^2 - 0.01711736111111111*lm^3)*NH))}, 
     {0.22, NC*(CA*CF*(-0.01601239983525505 - 0.477574765838926*lm + 
          0.42958609188560315*lm^2 + 0.09295*lm^3) + 
        CF^2*(-0.22673436139270897 - 0.23816119344499384*lm - 
          0.3859386678235585*lm^2 + 0.1521*lm^3) + 
        CF*((-0.14079498022869846 + 0.013954851183432702*lm - 
            0.04584292579738239*lm^2 - 0.0169*lm^3)*NM + 
          (-0.1482958932395934 + 0.013954851183432702*lm - 
            0.04584292579738239*lm^2 - 0.0169*lm^3)*NL + 
          (0.02041888684498057 + 0.013954851183432702*lm - 
            0.04584292579738239*lm^2 - 0.0169*lm^3)*NH))}, 
     {0.225, NC*(CA*CF*(-0.018111340636735557 - 0.48077572356046583*lm + 
          0.42234459448051015*lm^2 + 0.09176215277777777*lm^3) + 
        CF^2*(-0.22232988388916833 - 0.23666237067571358*lm - 
          0.3838729078955288*lm^2 + 0.15015625*lm^3) + 
        CF*((-0.13837955881705827 + 0.015062831240786452*lm - 
            0.04493860051160791*lm^2 - 0.016684027777777777*lm^3)*NM + 
          (-0.14601631454115785 + 0.015062831240786452*lm - 
            0.04493860051160791*lm^2 - 0.016684027777777777*lm^3)*NL + 
          (0.018764464464042056 + 0.015062831240786452*lm - 
            0.04493860051160791*lm^2 - 0.016684027777777777*lm^3)*NH))}, 
     {0.23, NC*(CA*CF*(-0.019952645651443748 - 0.4836933555569482*lm + 
          0.41518261868374146*lm^2 + 0.09058194444444445*lm^3) + 
        CF^2*(-0.2178527182835185 - 0.23500060341527265*lm - 
          0.38176651033569586*lm^2 + 0.148225*lm^3) + 
        CF*((-0.13601581494074796 + 0.016123540342428883*lm - 
            0.04404608218492268*lm^2 - 0.016469444444444443*lm^3)*NM + 
          (-0.14378438158827528 + 0.016123540342428883*lm - 
            0.04404608218492268*lm^2 - 0.016469444444444443*lm^3)*NL + 
          (0.017149328010651416 + 0.016123540342428883*lm - 
            0.04404608218492268*lm^2 - 0.016469444444444443*lm^3)*NH))}, 
     {0.235, NC*(CA*CF*(-0.021548891802575836 - 0.48633358296889045*lm + 
          0.4080999044734089*lm^2 + 0.089409375*lm^3) + 
        CF^2*(-0.21331438127643568 - 0.233183550053243*lm - 
          0.37961990063442186*lm^2 + 0.14630625*lm^3) + 
        CF*((-0.13370204593873797 + 0.01713799488900888*lm - 
            0.04316532354061979*lm^2 - 0.01625625*lm^3)*NM + 
          (-0.14159836880687193 + 0.01713799488900888*lm - 
            0.04316532354061979*lm^2 - 0.01625625*lm^3)*NL + 
          (0.01557318612045288 + 0.01713799488900888*lm - 0.04316532354061979*
             lm^2 - 0.01625625*lm^3)*NH))}, 
     {0.24, NC*(CA*CF*(-0.02291225257183766 - 0.4887022878145788*lm + 
          0.401096178596652*lm^2 + 0.08824444444444444*lm^3) + 
        CF^2*(-0.20872572747739068 - 0.23121870162819913*lm - 
          0.3774335259327513*lm^2 + 0.1444*lm^3) + 
        CF*((-0.1314366059632816 + 0.01810720110632977*lm - 
            0.042296274896360966*lm^2 - 0.016044444444444445*lm^3)*NM + 
          (-0.13945661106674534 + 0.01810720110632977*lm - 
            0.042296274896360966*lm^2 - 0.016044444444444445*lm^3)*NL + 
          (0.014035737260898212 + 0.01810720110632977*lm - 
            0.042296274896360966*lm^2 - 0.016044444444444445*lm^3)*NH))}, 
     {0.245, NC*(CA*CF*(-0.024054507642606745 - 0.4908053099631168*lm + 
          0.39417115525220825*lm^2 + 0.08708715277777777*lm^3) + 
        CF^2*(-0.20409697945313032 - 0.2291133822053428*lm - 
          0.37520785390547745*lm^2 + 0.14250625*lm^3) + 
        CF*((-0.12921790449336226 + 0.019032154652944683*lm - 
            0.041438884288280284*lm^2 - 0.015834027777777777*lm^3)*NM + 
          (-0.137357501954293 + 0.019032154652944683*lm - 
            0.041438884288280284*lm^2 - 0.015834027777777777*lm^3)*NL + 
          (0.012536670303576337 + 0.019032154652944683*lm - 
            0.041438884288280284*lm^2 - 0.015834027777777777*lm^3)*NH))}, 
     {0.25, NC*(CA*CF*(-0.024987052487995015 - 0.49264844442562905*lm + 
          0.3873245367382748*lm^2 + 0.0859375*lm^3) + 
        CF^2*(-0.1994377564947964 - 0.2268747495036744*lm - 
          0.3729433717010048*lm^2 + 0.140625*lm^3) + 
        CF*((-0.1270444048558837 + 0.019913840277566534*lm - 
            0.040593097588777244*lm^2 - 0.015625*lm^3)*NM + 
          (-0.1352994920758033 + 0.019913840277566534*lm - 
            0.040593097588777244*lm^2 - 0.015625*lm^3)*NL + 
          (0.011075665069635775 + 0.019913840277566534*lm - 
            0.040593097588777244*lm^2 - 0.015625*lm^3)*NH))}, 
     {0.255, NC*(CA*CF*(-0.025720907879352745 - 0.49423743893684996*lm + 
          0.3805560140677852*lm^2 + 0.08479548611111111*lm^3) + 
        CF^2*(-0.1947571021543336 - 0.22450979574385038*lm - 
          0.3706405849345333*lm^2 + 0.13875625*lm^3) + 
        CF*((-0.1249146227590132 + 0.020753231521734916*lm - 
            0.03975885861838519*lm^2 - 0.01541736111111111*lm^3)*NM + 
          (-0.13328108739336067 + 0.020753231521734916*lm - 
            0.03975885861838519*lm^2 - 0.01541736111111111*lm^3)*NL + 
          (0.009652392849794472 + 0.020753231521734916*lm - 
            0.03975885861838519*lm^2 - 0.01541736111111111*lm^3)*NH))}, 
     {0.26, NC*(CA*CF*(-0.026266729294670825 - 0.4955779918019425*lm + 
          0.37386526755306143*lm^2 + 0.08366111111111112*lm^3) + 
        CF^2*(-0.19006351059981796 - 0.22202534869088475*lm - 
          0.368300016731354*lm^2 + 0.1369*lm^3) + 
        CF*((-0.12282712484135191 + 0.021551290463620126*lm - 
            0.03893610925207178*lm^2 - 0.015211111111111111*lm^3)*NM + 
          (-0.1313008475949544 + 0.021551290463620126*lm - 
            0.03893610925207178*lm^2 - 0.015211111111111111*lm^3)*NL + 
          (0.008266516900325819 + 0.021551290463620126*lm - 
            0.03893610925207178*lm^2 - 0.015211111111111111*lm^3)*NH))}, 
     {0.265, NC*(CA*CF*(-0.026634816209719057 - 0.49667574998572767*lm + 
          0.36725196736165855*lm^2 + 0.082534375*lm^3) + 
        CF^2*(-0.1853649518381301 - 0.21942807286852997*lm - 
          0.365922206817286*lm^2 + 0.13505625*lm^3) + 
        CF*((-0.12078052723999377 + 0.0223089674992354*lm - 
            0.03812478952030156*lm^2 - 0.01500625*lm^3)*NM + 
          (-0.12935738449998793 + 0.0223089674992354*lm - 0.03812478952030156*
             lm^2 - 0.01500625*lm^3)*NL + (0.0069176929163132835 + 
            0.0223089674992354*lm - 0.03812478952030156*lm^2 - 
            0.01500625*lm^3)*NH))}, 
     {0.27, NC*(CA*CF*(-0.026835121257674146 - 0.4975363074235944*lm + 
          0.3607157740450825*lm^2 + 0.08141527777777778*lm^3) + 
        CF^2*(-0.18066889585205992 - 0.21672447092455518*lm - 
          0.36350771065350146*lm^2 + 0.133225*lm^3) + 
        CF*((-0.11877349418000373 + 0.023027201157677618*lm - 
            0.03732483770516651*lm^2 - 0.014802777777777778*lm^3)*NM + 
          (-0.12744936050105268 + 0.023027201157677618*lm - 
            0.03732483770516651*lm^2 - 0.014802777777777778*lm^3)*NL + 
          (0.005605569483378322 + 0.023027201157677618*lm - 
            0.03732483770516651*lm^2 - 0.014802777777777778*lm^3)*NH))}, 
     {0.275, NC*(CA*CF*(-0.02687725924550858 - 0.49816520353523547*lm + 
          0.35425633904194287*lm^2 + 0.08030381944444444*lm^3) + 
        CF^2*(-0.17598233569750318 - 0.21392088512826088*lm - 
          0.3610570986131844*lm^2 + 0.13140625*lm^3) + 
        CF*((-0.11680473658739601 + 0.023706917947329518*lm - 
            0.0365361904318684*lm^2 - 0.014600694444444444*lm^3)*NM + 
          (-0.12557548704254637 + 0.023706917947329518*lm - 
            0.0365361904318684*lm^2 - 0.014600694444444444*lm^3)*NL + 
          (0.004329788509005909 + 0.023706917947329518*lm - 
            0.0365361904318684*lm^2 - 0.014600694444444444*lm^3)*NH))}, 
     {0.28, NC*(CA*CF*(-0.026770516017580903 - 0.4985679219240367*lm + 
          0.3478733051569924*lm^2 + 0.0792*lm^3) + 
        CF^2*(-0.17131180960493061 - 0.21102349898346237*lm - 
          0.35857095519764887*lm^2 + 0.1296*lm^3) + 
        CF*((-0.11487301072728973 + 0.024349032230237093*lm - 
            0.035758782755816794*lm^2 - 0.0144*lm^3)*NM + 
          (-0.12373452313647723 + 0.024349032230237093*lm - 
            0.035758782755816794*lm^2 - 0.0144*lm^3)*NL + 
          (0.0030899856345185774 + 0.024349032230237093*lm - 
            0.035758782755816794*lm^2 - 0.0144*lm^3)*NH))}, 
     {0.285, NC*(CA*CF*(-0.026523857158746292 - 0.4987498892464651*lm + 
          0.3415663070174014*lm^2 + 0.07810381944444444*lm^3) + 
        CF^2*(-0.16666342212778737 - 0.20803833894186613*lm - 
          0.35604987828970674*lm^2 + 0.12780625*lm^3) + 
        CF*((-0.11297711686858503 + 0.024954446122127966*lm - 
            0.034992548245588145*lm^2 - 0.014200694444444445*lm^3)*NM + 
          (-0.12192527391559202 + 0.024954446122127966*lm - 
            0.034992548245588145*lm^2 - 0.014200694444444445*lm^3)*NL + 
          (0.0018857906286824009 + 0.024954446122127966*lm - 
            0.034992548245588145*lm^2 - 0.014200694444444445*lm^3)*NH))}, 
     {0.29, NC*(CA*CF*(-0.026145936530934305 - 0.4987164742371633*lm + 
          0.33533497150752684*lm^2 + 0.07701527777777778*lm^3) + 
        CF^2*(-0.1620428643789296 - 0.20497127620327724*lm - 
          0.3534944784422288*lm^2 + 0.126025*lm^3) + 
        CF*((-0.11111589797620434 + 0.02552404941576355*lm - 
            0.034237419061974576*lm^2 - 0.014002777777777777*lm^3)*NM + 
          (-0.12014658922379462 + 0.02552404941576355*lm - 
            0.034237419061974576*lm^2 - 0.014002777777777777*lm^3)*NL + 
          (0.0007168277638663926 + 0.02552404941576355*lm - 
            0.034237419061974576*lm^2 - 0.014002777777777777*lm^3)*NH))}, 
     {0.295, NC*(CA*CF*(-0.025645104638573016 - 0.4984729868766953*lm + 
          0.3291789181833469*lm^2 + 0.075934375*lm^3) + 
        CF^2*(-0.15745543339460374 - 0.20182802859043242*lm - 
          0.35090537819997786*lm^2 + 0.12425625*lm^3) + 
        CF*((-0.10928823843169355 + 0.02605871952552233*lm - 
            0.03349332603333579*lm^2 - 0.01380625*lm^3)*NM + 
          (-0.11839736224367843 + 0.02605871952552233*lm - 
            0.03349332603333579*lm^2 - 0.01380625*lm^3)*NL + 
          (-0.000417283824380277 + 0.02605871952552233*lm - 
            0.03349332603333579*lm^2 - 0.01380625*lm^3)*NH))}, 
     {0.3, NC*(CA*CF*(-0.02502940439074442 - 0.49802467768999875*lm + 
          0.3230977596676586*lm^2 + 0.07486111111111111*lm^3) + 
        CF^2*(-0.15290607552135457 - 0.19861416248747152*lm - 
          0.3482832114529223*lm^2 + 0.1225*lm^3) + 
        CF*((-0.1074930627827535 + 0.026559321451296455*lm - 
            0.032760198727453074*lm^2 - 0.01361111111111111*lm^3)*NM + 
          (-0.11667652816087487 + 0.026559321451296455*lm - 
            0.032760198727453074*lm^2 - 0.01361111111111111*lm^3)*NL + 
          (-0.001516929793521453 + 0.026559321451296455*lm - 
            0.032760198727453074*lm^2 - 0.01361111111111111*lm^3)*NH))}, 
     {0.305, NC*(CA*CF*(-0.024306631297817446 - 0.4973767371646131*lm + 
          0.317091102027061*lm^2 + 0.07379548611111111*lm^3) + 
        CF^2*(-0.14839929978210517 - 0.19533509483215342*lm - 
          0.34562862281935475*lm^2 + 0.12075625*lm^3) + 
        CF*((-0.10572933452209023 + 0.02702670775995069*lm - 
            0.032037965520071696*lm^2 - 0.01341736111111111*lm^3)*NM + 
          (-0.11498306286481971 + 0.02702670775995069*lm - 
            0.032037965520071696*lm^2 - 0.01341736111111111*lm^3)*NL + 
          (-0.0025825002652343936 + 0.02702670775995069*lm - 
            0.032037965520071696*lm^2 - 0.01341736111111111*lm^3)*NH))}, 
     {0.31, NC*(CA*CF*(-0.023484259071410912 - 0.4965342952786641*lm + 
          0.31115854513168206*lm^2 + 0.0727375*lm^3) + 
        CF^2*(-0.14393935931576315 - 0.19199609515290686*lm - 
          0.3429422670572475*lm^2 + 0.119025*lm^3) + 
        CF*((-0.10399605489580466 + 0.027461718582744148*lm - 
            0.03132655366030584*lm^2 - 0.013225*lm^3)*NM + 
          (-0.1133159816854559 + 0.027461718582744148*lm - 
            0.03132655366030584*lm^2 - 0.013225*lm^3)*NL + 
          (-0.003614389510899198 + 0.027461718582744148*lm - 
            0.03132655366030584*lm^2 - 0.013225*lm^3)*NH))}, 
     {0.315, NC*(CA*CF*(-0.022569505038006876 - 0.4955024211294197*lm + 
          0.3052996829985475*lm^2 + 0.07168715277777778*lm^3) + 
        CF^2*(-0.13953015210187447 - 0.18860228764269243*lm - 
          0.34022480850237685*lm^2 + 0.11730625*lm^3) + 
        CF*((-0.10229226174140707 + 0.027865181627252125*lm - 
            0.030625889333069235*lm^2 - 0.013034027777777778*lm^3)*NM + 
          (-0.11167433816532274 + 0.027865181627252125*lm - 
            0.030625889333069235*lm^2 - 0.013034027777777778*lm^3)*NL + 
          (-0.0046129956507007346 + 0.027865181627252125*lm - 
            0.030625889333069235*lm^2 - 0.013034027777777778*lm^3)*NH))}, 
     {0.32, NC*(CA*CF*(-0.02156932235107296 - 0.49428612265398547*lm + 
          0.29951410411943163*lm^2 + 0.07064444444444444*lm^3) + 
        CF^2*(-0.13517526703269586 - 0.18515865326245068*lm - 
          0.33747692053183914*lm^2 + 0.1156*lm^3) + 
        CF*((-0.1006170283554204 + 0.028237912202449887*lm - 
            0.02993589771868454*lm^2 - 0.012844444444444445*lm^3)*NM + 
          (-0.1100572228664259 + 0.028237912202449887*lm - 
            0.02993589771868454*lm^2 - 0.012844444444444445*lm^3)*NL + 
          (-0.005578720365705223 + 0.028237912202449887*lm - 
            0.02993589771868454*lm^2 - 0.012844444444444445*lm^3)*NH))}, 
     {0.325, NC*(CA*CF*(-0.020490407296853995 - 0.4928903464343964*lm + 
          0.29380139177398173*lm^2 + 0.069609375*lm^3) + 
        CF^2*(-0.13087799877423129 - 0.18167003186763184*lm - 
          0.3346992850516663*lm^2 + 0.11390625*lm^3) + 
        CF*((-0.09896946239043625 + 0.02858071325573323*lm - 
            0.029256503049814857*lm^2 - 0.01265625*lm^3)*NM + 
          (-0.10846376221123738 + 0.02858071325573323*lm - 
            0.029256503049814857*lm^2 - 0.01265625*lm^3)*NL + 
          (-0.006511968622309521 + 0.02858071325573323*lm - 
            0.029256503049814857*lm^2 - 0.01265625*lm^3)*NH))}, 
     {0.33, NC*(CA*CF*(-0.019339206423421604 - 0.49131997757998896*lm + 
          0.2881611243288551*lm^2 + 0.06858194444444445*lm^3) + 
        CF^2*(-0.12664136198857462 - 0.17814112435195378*lm - 
          0.331892592007328*lm^2 + 0.112225*lm^3) + 
        CF*((-0.09734870478140022 + 0.028894375420753477*lm - 
            0.028587628665852443*lm^2 - 0.012469444444444444*lm^3)*NM + 
          (-0.10689311735714006 + 0.028894375420753477*lm - 
            0.028587628665852443*lm^2 - 0.012469444444444444*lm^3)*NL + 
          (-0.007413148408494618 + 0.028894375420753477*lm - 
            0.028587628665852443*lm^2 - 0.012469444444444444*lm^3)*NH))}, 
     {0.335, NC*(CA*CF*(-0.018121923494569602 - 0.48957983968050783*lm + 
          0.2825928755235682*lm^2 + 0.06756215277777777*lm^3) + 
        CF^2*(-0.12246810494545946 - 0.1745764948031226*lm - 
          0.3290575389159793*lm^2 + 0.11055625*lm^3) + 
        CF*((-0.09575392870083033 + 0.02917967707503823*lm - 
            0.027929197064891192*lm^2 - 0.012284027777777777*lm^3)*NM + 
          (-0.10534448310360325 + 0.02917967707503823*lm - 
            0.027929197064891192*lm^2 - 0.012284027777777777*lm^3)*NL + 
          (-0.008282670481345945 + 0.02917967707503823*lm - 
            0.027929197064891192*lm^2 - 0.012284027777777777*lm^3)*NH))}, 
     {0.34, NC*(CA*CF*(-0.01684452627049279 - 0.48767469482392434*lm + 
          0.27709621474371215*lm^2 + 0.06655*lm^3) + 
        CF^2*(-0.11836072254969186 - 0.1709805726657821*lm - 
          0.32619483041938013*lm^2 + 0.1089*lm^3) + 
        CF*((-0.09418433854261074 + 0.029437384406454607*lm - 
            0.02728112995340221*lm^2 - 0.0121*lm^3)*NM + 
          (-0.10381708683135618 + 0.029437384406454607*lm - 
            0.02728112995340221*lm^2 - 0.0121*lm^3)*NL + 
          (-0.00912094812533217 + 0.029437384406454607*lm - 
            0.02728112995340221*lm^2 - 0.0121*lm^3)*NH))}, 
     {0.345, NC*(CA*CF*(-0.015512753117481156 - 0.48560924367342156*lm + 
          0.27167070728215276*lm^2 + 0.0655454861111111*lm^3) + 
        CF^2*(-0.1143214688099646 - 0.1673576549074409*lm - 
          0.3233051778564773*lm^2 + 0.10725625*lm^3) + 
        CF*((-0.09263916893395135 + 0.02966825148764949*lm - 
            0.026643348293724747*lm^2 - 0.011917361111111111*lm^3)*NM + 
          (-0.10231018747281155 + 0.02966825148764949*lm - 
            0.026643348293724747*lm^2 - 0.011917361111111111*lm^3)*NL + 
          (-0.009928396920861225 + 0.02966825148764949*lm - 
            0.026643348293724747*lm^2 - 0.011917361111111111*lm^3)*NH))}, 
     {0.35, NC*(CA*CF*(-0.01413211944910753 - 0.4833881255984364*lm + 
          0.2663159145887974*lm^2 + 0.06454861111111111*lm^3) + 
        CF^2*(-0.11035236877341996 - 0.16371190818356074*lm - 
          0.32038929885469514*lm^2 + 0.105625*lm^3) + 
        CF*((-0.09111768377506127 + 0.029873020357672597*lm - 
            0.026015772349478314*lm^2 - 0.01173611111111111*lm^3)*NM + 
          (-0.10082307451298216 + 0.029873020357672597*lm - 
            0.026015772349478314*lm^2 - 0.01173611111111111*lm^3)*NL + 
          (-0.01070543452265769 + 0.029873020357672597*lm - 
            0.026015772349478314*lm^2 - 0.01173611111111111*lm^3)*NH))}, 
     {0.355, NC*(CA*CF*(-0.012707924001590003 - 0.48101591885504996*lm + 
          0.26103139450947627*lm^2 + 0.063559375*lm^3) + 
        CF^2*(-0.10645522994924354 - 0.16004737099838648*lm - 
          0.3174479169390389*lm^2 + 0.10400625*lm^3) + 
        CF*((-0.08961917530604903 + 0.030052421110053098*lm - 
            0.02539832172899568*lm^2 - 0.01155625*lm^3)*NM + 
          (-0.09935506702012889 + 0.030052421110053098*lm - 
            0.02539832172899568*lm^2 - 0.01155625*lm^3)*NL + 
          (-0.01145248044752935 + 0.030052421110053098*lm - 
            0.02539832172899568*lm^2 - 0.01155625*lm^3)*NH))}, 
     {0.36, NC*(CA*CF*(-0.011245254946177464 - 0.47849714081138406*lm + 
          0.25581670151445685*lm^2 + 0.06257777777777777*lm^3) + 
        CF^2*(-0.10263165324353102 - 0.1563679558584551*lm - 
          0.3144817611581615*lm^2 + 0.1024*lm^3) + 
        CF*((-0.08814296320053432 + 0.030207171986660196*lm - 
            0.024790915426870945*lm^2 - 0.011377777777777778*lm^3)*NM + 
          (-0.09790551270537687 + 0.030207171986660196*lm - 
            0.024790915426870945*lm^2 - 0.011377777777777778*lm^3)*NL + 
          (-0.012169955871112942 + 0.030207171986660196*lm - 
            0.024790915426870945*lm^2 - 0.011377777777777778*lm^3)*NH))}, 
     {0.365, NC*(CA*CF*(-0.009748995841540486 - 0.4758362482139982*lm + 
          0.25067138691708024*lm^2 + 0.061603819444444444*lm^3) + 
        CF^2*(-0.09888304342667421 - 0.15267745141604755*lm - 
          0.311491565726596*lm^2 + 0.10080625*lm^3) + 
        CF*((-0.0866883936854329 + 0.030337979476732366*lm - 
            0.024193471863711555*lm^2 - 0.011200694444444444*lm^3)*NM + 
          (-0.09647378701053912 + 0.030337979476732366*lm - 
            0.024193471863711555*lm^2 - 0.011200694444444444*lm^3)*NL + 
          (-0.012858283433209971 + 0.030337979476732366*lm - 
            0.024193471863711555*lm^2 - 0.011200694444444444*lm^3)*NH))}, 
     {0.37, NC*(CA*CF*(-0.008223831429256428 - 0.47303763749158984*lm + 
          0.24559499908298052*lm^2 + 0.0606375*lm^3) + 
        CF^2*(-0.09521061915355912 - 0.14897952460014227*lm - 
          0.3084780696823955*lm^2 + 0.099225*lm^3) + 
        CF*((-0.0852548386863604 + 0.030445538420510104*lm - 
            0.023605908924178277*lm^2 - 0.011025*lm^3)*NM + 
          (-0.09505929222339102 + 0.030445538420510104*lm - 
            0.023605908924178277*lm^2 - 0.011025*lm^3)*NL + 
          (-0.013517887051342985 + 0.030445538420510104*lm - 
            0.023605908924178277*lm^2 - 0.011025*lm^3)*NH))}, 
     {0.375, NC*(CA*CF*(-0.00667425327555831 - 0.4701056450925855*lm + 
          0.24058708363032533*lm^2 + 0.05967881944444445*lm^3) + 
        CF^2*(-0.09161542255595861 - 0.14527772273269624*lm - 
          0.3054420165594677*lm^2 + 0.09765625*lm^3) + 
        CF*((-0.08384169499808508 + 0.030530532116952717*lm - 
            0.023028143993392484*lm^2 - 0.010850694444444444*lm^3)*NM + 
          (-0.09366145661964662 + 0.030530532116952717*lm - 
            0.023028143993392484*lm^2 - 0.010850694444444444*lm^3)*NL + 
          (-0.014149191742181072 + 0.030530532116952717*lm - 
            0.023028143993392484*lm^2 - 0.010850694444444444*lm^3)*NH))}, 
     {0.38, NC*(CA*CF*(-0.005104565262578212 - 0.4670445478534714*lm + 
          0.23564718362148937*lm^2 + 0.058727777777777775*lm^3) + 
        CF^2*(-0.0880983284256294 - 0.14157547562832457*lm - 
          0.3023841540739265*lm^2 + 0.0961*lm^3) + 
        CF*((-0.08244838347945367 + 0.03059363243506177*lm - 
            0.02246009399178595*lm^2 - 0.010677777777777777*lm^3)*NM + 
          (-0.09227973363089587 + 0.03059363243506177*lm - 
            0.02246009399178595*lm^2 - 0.010677777777777777*lm^3)*NL + 
          (-0.014752623450500634 + 0.03059363243506177*lm - 
            0.02246009399178595*lm^2 - 0.010677777777777777*lm^3)*NH))}, 
     {0.385, NC*(CA*CF*(-0.0035188889323564602 - 0.4638585633949518*lm + 
          0.23077483974655336*lm^2 + 0.057784375*lm^3) + 
        CF^2*(-0.08466005300579242 - 0.13787609767566927*lm - 
          0.2993052338238218*lm^2 + 0.09455625*lm^3) + 
        CF*((-0.0810743482722059 + 0.030635499928372428*lm - 
            0.021901675408464244*lm^2 - 0.01050625*lm^3)*NM + 
          (-0.09091360103777286 + 0.030635499928372428*lm - 
            0.021901675408464244*lm^2 - 0.01050625*lm^3)*NL + 
          (-0.015328608885363679 + 0.030635499928372428*lm - 
            0.021901675408464244*lm^2 - 0.01050625*lm^3)*NH))}, 
     {0.39, NC*(CA*CF*(-0.0019211686869137564 - 0.46055185054324643*lm + 
          0.22596959049899773*lm^2 + 0.056848611111111114*lm^3) + 
        CF^2*(-0.08130116240787984 - 0.13418278989894974*lm - 
          0.29620601100164007*lm^2 + 0.093025*lm^3) + 
        CF*((-0.07971905604309175 + 0.03065678395220936*lm - 
            0.021352804333151103*lm^2 - 0.010336111111111112*lm^3)*NM + 
          (-0.08956256018763663 + 0.03065678395220936*lm - 
            0.021352804333151103*lm^2 - 0.010336111111111112*lm^3)*NL + 
          (-0.015877575363211216 + 0.03065678395220936*lm - 
            0.021352804333151103*lm^2 - 0.010336111111111112*lm^3)*NH))}, 
     {0.395, NC*(CA*CF*(-0.00031517684769425666 - 0.4571285097740401*lm + 
          0.22123097234394326*lm^2 + 0.05592048611111111*lm^3) + 
        CF^2*(-0.07802208066967367 - 0.13049864199837014*lm - 
          0.29308724411900194*lm^2 + 0.09150625*lm^3) + 
        CF*((-0.07838199524870446 + 0.0306581227833366*lm - 
            0.02081339648677756*lm^2 - 0.010167361111111111*lm^3)*NM + 
          (-0.0882261352360585 + 0.0306581227833366*lm - 0.02081339648677756*
             lm^2 - 0.010167361111111111*lm^3)*NL + 
          (-0.016399950657583786 + 0.0306581227833366*lm - 
            0.02081339648677756*lm^2 - 0.010167361111111111*lm^3)*NH))}, 
     {0.4, NC*(CA*CF*(0.0012954814223130752 - 0.45359258367678856*lm + 
          0.21655851987927066*lm^2 + 0.055*lm^3) + 
        CF^2*(-0.07482309747023667 - 0.126826634368224*lm - 
          0.28994969474301163*lm^2 + 0.09*lm^3) + 
        CF*((-0.07706267542244427 + 0.03064014374166063*lm - 
            0.020283367250776483*lm^2 - 0.01*lm^3)*NM + 
          (-0.08690387241142433 + 0.03064014374166063*lm - 
            0.020283367250776483*lm^2 - 0.01*lm^3)*NL + 
          (-0.016896162855194668 + 0.03064014374166063*lm - 
            0.020283367250776483*lm^2 - 0.01*lm^3)*NH))}, 
     {0.405, NC*(CA*CF*(0.002907363330479014 - 0.4499480574372556*lm + 
          0.21195176598993576*lm^2 + 0.05408715277777778*lm^3) + 
        CF^2*(-0.07170437551634494 - 0.12316964009168896*lm - 
          0.2867941272437415*lm^2 + 0.08850625*lm^3) + 
        CF*((-0.07576062648303084 + 0.03060346331367376*lm - 
            0.019762631695139837*lm^2 - 0.009834027777777778*lm^3)*NM + 
          (-0.0855953393019733 + 0.03060346331367376*lm - 
            0.019762631695139837*lm^2 - 0.009834027777777778*lm^3)*NL + 
          (-0.01736664021809422 + 0.03060346331367376*lm - 
            0.019762631695139837*lm^2 - 0.009834027777777778*lm^3)*NH))}, 
     {0.41, NC*(CA*CF*(0.0045171837971893485 - 0.4461988593363199*lm + 
          0.20741024199577945*lm^2 + 0.05318194444444444*lm^3) + 
        CF^2*(-0.06866595761447276 - 0.1195304269114396*lm - 
          0.2836213085523609*lm^2 + 0.087025*lm^3) + 
        CF*((-0.07447539806398788 + 0.030548687277350165*lm - 
            0.019251104605293237*lm^2 - 0.009669444444444444*lm^3)*NM + 
          (-0.08430012416461063 + 0.030548687277350165*lm - 
            0.019251104605293237*lm^2 - 0.009669444444444444*lm^3)*NL + 
          (-0.017811811051675976 + 0.030548687277350165*lm - 
            0.019251104605293237*lm^2 - 0.009669444444444444*lm^3)*NH))}, 
     {0.415, NC*(CA*CF*(0.0061218109260033834 - 0.4423488612632351*lm + 
          0.20293347779311763*lm^2 + 0.052284375*lm^3) + 
        CF^2*(-0.06570777344175094 - 0.11591165917533294*lm - 
          0.2804320079294439*lm^2 + 0.08555625*lm^3) + 
        CF*((-0.07320655886352954 + 0.03047641082823053*lm - 
            0.01874870050783957*lm^2 - 0.00950625*lm^3)*NM + 
          (-0.08301783525484618 + 0.03047641082823053*lm - 
            0.01874870050783957*lm^2 - 0.00950625*lm^3)*NL + 
          (-0.018232103578286418 + 0.03047641082823053*lm - 
            0.01874870050783957*lm^2 - 0.00950625*lm^3)*NH))}, 
     {0.42, NC*(CA*CF*(0.007718261598103706 - 0.43840187924166574*lm + 
          0.1985210019903812*lm^2 + 0.051394444444444444*lm^3) + 
        CF^2*(-0.06282964602872057 - 0.11231589975653306*lm - 
          0.2772269967430126*lm^2 + 0.0841*lm^3) + 
        CF*((-0.07195369601428545 + 0.030387218706452786*lm - 
            0.018255333695220824*lm^2 - 0.009344444444444445*lm^3)*NM + 
          (-0.08174810017722645 + 0.030387218706452786*lm - 
            0.018255333695220824*lm^2 - 0.009344444444444445*lm^3)*NL + 
          (-0.018627945816211418 + 0.030387218706452786*lm - 
            0.018255333695220824*lm^2 - 0.009344444444444445*lm^3)*NH))}, 
     {0.425, NC*(CA*CF*(0.009303697187864762 - 0.4343616739669486*lm + 
          0.19417234203806377*lm^2 + 0.05051215277777778*lm^3) + 
        CF^2*(-0.06003129796613147 - 0.10874561194754485*lm - 
          0.27400704825589567*lm^2 + 0.08265625*lm^3) + 
        CF*((-0.07071641447231056 + 0.030281685324506404*lm - 
            0.017770918249344927*lm^2 - 0.009184027777777777*lm^3)*NM + 
          (-0.0804905652556433 + 0.030281685324506404*lm - 
            0.017770918249344927*lm^2 - 0.009184027777777777*lm^3)*NL + 
          (-0.0189997654638224 + 0.030281685324506404*lm - 
            0.017770918249344927*lm^2 - 0.009184027777777777*lm^3)*NH))}, 
     {0.43, NC*(CA*CF*(0.010875419396413417 - 0.43023195135314374*lm + 
          0.18988702435322105*lm^2 + 0.0496375*lm^3) + 
        CF^2*(-0.05731235734748936 - 0.10520316132772019*lm - 
          0.2707729374220019*lm^2 + 0.081225*lm^3) + 
        CF*((-0.06949433642483367 + 0.030160374895506124*lm - 
            0.01729536806422201*lm^2 - 0.009025*lm^3)*NM + 
          (-0.07924489492291835 + 0.030160374895506124*lm - 
            0.01729536806422201*lm^2 - 0.009025*lm^3)*NL + 
          (-0.019347989788675145 + 0.030160374895506124*lm - 
            0.01729536806422201*lm^2 - 0.009025*lm^3)*NH))}, 
     {0.435, NC*(CA*CF*(0.01243086620010393 - 0.4260163630885517*lm + 
          0.18566457443875503*lm^2 + 0.04877048611111111*lm^3) + 
        CF^2*(-0.054672363458536336 - 0.10169081760388422*lm - 
          0.2675254406911281*lm^2 + 0.07980625*lm^3) + 
        CF*((-0.06828710071620991 + 0.030023841561797947*lm - 
            0.01682859686765243*lm^2 - 0.00886736111111111*lm^3)*NM + 
          (-0.07801077112907756 + 0.030023841561797947*lm - 
            0.01682859686765243*lm^2 - 0.00886736111111111*lm^3)*NL + 
          (-0.019673045521363237 + 0.030023841561797947*lm - 
            0.01682859686765243*lm^2 - 0.00886736111111111*lm^3)*NH))}, 
     {0.44, NC*(CA*CF*(0.013967607910881254 - 0.4217185071984706*lm + 
          0.18150451699770395*lm^2 + 0.04791111111111111*lm^3) + 
        CF^2*(-0.05211077222435194 - 0.0982107564238071*lm - 
          0.26426533582193895*lm^2 + 0.0784*lm^3) + 
        CF*((-0.06709436229155182 + 0.029872629523725925*lm - 
            0.01637051824200678*lm^2 - 0.00871111111111111*lm^3)*NM + 
          (-0.07678789276774636 + 0.029872629523725925*lm - 
            0.01637051824200678*lm^2 - 0.00871111111111111*lm^3)*NL + 
          (-0.0199753587539371 + 0.029872629523725925*lm - 
            0.01637051824200678*lm^2 - 0.00871111111111111*lm^3)*NH))}, 
     {0.445, NC*(CA*CF*(0.015483343345561909 - 0.41734192861406205*lm + 
          0.17740637604274934*lm^2 + 0.047059375*lm^3) + 
        CF^2*(-0.04962696142428917 - 0.0947650611623155*lm - 
          0.2609934017027738*lm^2 + 0.07700625*lm^3) + 
        CF*((-0.06591579165752481 + 0.02970727316840277*lm - 
            0.015921045644136243*lm^2 - 0.00855625*lm^3)*NM + 
          (-0.07557597512011126 + 0.02970727316840277*lm - 
            0.015921045644136243*lm^2 - 0.00855625*lm^3)*NL + 
          (-0.02025535484270747 + 0.02970727316840277*lm - 
            0.015921045644136243*lm^2 - 0.00855625*lm^3)*NH))}, 
     {0.45, NC*(CA*CF*(0.016975896101118923 - 0.4128901197462805*lm + 
          0.17336967500114048*lm^2 + 0.04621527777777778*lm^3) + 
        CF^2*(-0.04722023568450984 - 0.09135572467990176*lm - 
          0.25771041817995194*lm^2 + 0.075625*lm^3) + 
        CF*((-0.06475107435980382 + 0.029528297198340683*lm - 
            0.015480092424449783*lm^2 - 0.008402777777777778*lm^3)*NM + 
          (-0.07437474931590905 + 0.029528297198340683*lm - 
            0.015480092424449783*lm^2 - 0.008402777777777778*lm^3)*NL + 
          (-0.020513458315260573 + 0.029528297198340683*lm - 
            0.015480092424449783*lm^2 - 0.008402777777777778*lm^3)*NH))}, 
     {0.455, NC*(CA*CF*(0.018443210933116218 - 0.40836652106389976*lm + 
          0.16939393681522819*lm^2 + 0.04537881944444445*lm^3) + 
        CF^2*(-0.044889831257453564 - 0.08798465105374566*lm - 
          0.25441716589326296*lm^2 + 0.07425625*lm^3) + 
        CF*((-0.06359991047669956 + 0.02933621675981116*lm - 
            0.015047571845193003*lm^2 - 0.008250694444444444*lm^3)*NM + 
          (-0.07318396181092045 + 0.02933621675981116*lm - 
            0.015047571845193003*lm^2 - 0.008250694444444444*lm^3)*NL + 
          (-0.020750092781519153 + 0.02933621675981116*lm - 
            0.015047571845193003*lm^2 - 0.008250694444444444*lm^3)*NH))}, 
     {0.46, NC*(CA*CF*(0.019883350234496215 - 0.4037745216747476*lm + 
          0.16547868403878982*lm^2 + 0.04455*lm^3) + 
        CF^2*(-0.04263492059716125 - 0.0846536572811155*lm - 
          0.2511144261183439*lm^2 + 0.0729*lm^3) + 
        CF*((-0.06246201412847353 + 0.02913153757081397*lm - 
            0.014623397097961788*lm^2 - 0.0081*lm^3)*NM + 
          (-0.07200337388045931 + 0.02913153757081397*lm - 
            0.014623397097961788*lm^2 - 0.0081*lm^3)*NL + 
          (-0.020965680848691066 + 0.02913153757081397*lm - 
            0.014623397097961788*lm^2 - 0.0081*lm^3)*NH))}, 
     {0.465, NC*(CA*CF*(0.021294490611987675 - 0.39911745990932357*lm + 
          0.16162343892931985*lm^2 + 0.04372881944444444*lm^3) + 
        CF^2*(-0.04045461673898781 - 0.08136447495516157*lm - 
          0.24780298061565842*lm^2 + 0.07155625*lm^3) + 
        CF*((-0.06133711300187358 + 0.02891475604854612*lm - 
            0.014207481320482397*lm^2 - 0.007950694444444444*lm^3)*NM + 
          (-0.070832761128364 + 0.02891475604854612*lm - 0.014207481320482397*
             lm^2 - 0.007950694444444444*lm^3)*NL + 
          (-0.021160644039953606 + 0.02891475604854612*lm - 
            0.014207481320482397*lm^2 - 0.007950694444444444*lm^3)*NH))}, 
     {0.47, NC*(CA*CF*(0.02267491955746042 - 0.3943986239060443*lm + 
          0.15782772353645175*lm^2 + 0.042915277777777774*lm^3) + 
        CF^2*(-0.038347977491861765 - 0.07811875191315774*lm - 
          0.24448361148580625*lm^2 + 0.070225*lm^3) + 
        CF*((-0.060224947889432806 + 0.028686359436271253*lm - 
            0.013799737612688196*lm^2 - 0.007802777777777777*lm^3)*NM + 
          (-0.06967191301101161 + 0.028686359436271253*lm - 
            0.013799737612688196*lm^2 - 0.007802777777777777*lm^3)*NL + 
          (-0.021335402716728367 + 0.028686359436271253*lm - 
            0.013799737612688196*lm^2 - 0.007802777777777777*lm^3)*NH))}, 
     {0.475, NC*(CA*CF*(0.024023032211615607 - 0.3896212521974156*lm + 
          0.1540910597866698*lm^2 + 0.042109375*lm^3) + 
        CF^2*(-0.036314009450894365 - 0.07491805385728431*lm - 
          0.24115710103090396*lm^2 + 0.06890625*lm^3) + 
        CF*((-0.059125272243086176 + 0.02844682592949922*lm - 
            0.013400079052121781*lm^2 - 0.00765625*lm^3)*NM + 
          (-0.06852063237589016 + 0.02844682592949922*lm - 
            0.013400079052121781*lm^2 - 0.00765625*lm^3)*NL + 
          (-0.021490376004407206 + 0.02844682592949922*lm - 
            0.013400079052121781*lm^2 - 0.00765625*lm^3)*NH))}, 
     {0.48, NC*(CA*CF*(0.025337328217463005 - 0.3847885342964891*lm + 
          0.15041296956446176*lm^2 + 0.04131111111111111*lm^3) + 
        CF^2*(-0.03435167183780288 - 0.07176386594807951*lm - 
          0.23782423162178987*lm^2 + 0.0676*lm^3) + 
        CF*((-0.05803785174167134 + 0.02819662480139357*lm - 
            0.013008418708690015*lm^2 - 0.007511111111111111*lm^3)*NM + 
          (-0.0673787350142775 + 0.02819662480139357*lm - 
            0.013008418708690015*lm^2 - 0.007511111111111111*lm^3)*NL + 
          (-0.021625981721396282 + 0.02819662480139357*lm - 
            0.013008418708690015*lm^2 - 0.007511111111111111*lm^3)*NH))}, 
     {0.485, NC*(CA*CF*(0.02661640866109691 - 0.37990361128300953*lm + 
          0.1467929747900569*lm^2 + 0.04052048611111111*lm^3) + 
        CF^2*(-0.03245988017628637 - 0.06865759437071786*lm - 
          0.23448578557081598*lm^2 + 0.06630625*lm^3) + 
        CF*((-0.056962463871891335 + 0.027936216527332844*lm - 
            0.012624669658798222*lm^2 - 0.007367361111111111*lm^3)*NM + 
          (-0.06624604922758971 + 0.027936216527332844*lm - 
            0.012624669658798222*lm^2 - 0.007367361111111111*lm^3)*NL + 
          (-0.02174263631134995 + 0.027936216527332844*lm - 
            0.012624669658798222*lm^2 - 0.007367361111111111*lm^3)*NH))}, 
     {0.49, NC*(CA*CF*(0.027858973097345068 - 0.3749695763887084*lm + 
          0.14323059749388736*lm^2 + 0.0397375*lm^3) + 
        CF^2*(-0.03063750980918522 - 0.0656005678743006*lm - 
          0.2311425450100025*lm^2 + 0.065025*lm^3) + 
        CF*((-0.05589889752232825 + 0.02766605290855834*lm - 
            0.012248744998888611*lm^2 - 0.007225*lm^3)*NM + 
          (-0.06512241540697479 + 0.02766605290855834*lm - 
            0.012248744998888611*lm^2 - 0.007225*lm^3)*NL + 
          (-0.021840754778472186 + 0.02766605290855834*lm - 
            0.012248744998888611*lm^2 - 0.007225*lm^3)*NH))}, 
     {0.495, NC*(CA*CF*(0.029063816657924874 - 0.3699894755812443*lm + 
          0.13972535988790452*lm^2 + 0.03896215277777778*lm^3) + 
        CF^2*(-0.02888339926395965 - 0.06259403928436817*lm - 
          0.22779529177433805*lm^2 + 0.06375625*lm^3) + 
        CF*((-0.054846952590108494 + 0.02738657719484792*lm - 
            0.011880557858406884*lm^2 - 0.007084027777777778*lm^3)*NM + 
          (-0.06400768562574034 + 0.02738657719484792*lm - 
            0.011880557858406884*lm^2 - 0.007084027777777778*lm^3)*NL + 
          (-0.021920750625767878 + 0.02738657719484792*lm - 
            0.011880557858406884*lm^2 - 0.007084027777777778*lm^3)*NH))}, 
     {0.5, CF*NC*(CA*(0.030229827274025785 - 0.36496630812853487*lm + 
          0.13627678443478797*lm^2 + 0.03819444444444445*lm^3) + 
        CF*(-0.027196353455763513 - 0.05963918696687057*lm - 
          0.22444480728852878*lm^2 + 0.0625*lm^3) - 0.053806439606481786*
         NM + 0.02709822420313731*lm*NM - 0.011520021412385692*lm^2*NM - 
        0.006944444444444444*lm^3*NM - 0.06290172324884523*NL + 
        0.02709822420313731*lm*NL - 0.011520021412385692*lm^2*NL - 
        0.006944444444444444*lm^3*NL - 0.021983035795573053*NH + 
        0.02709822420313731*lm*NH - 0.011520021412385692*lm^2*NH - 
        0.006944444444444444*lm^3*NH)}, 
     {0.505, CF*NC*(CA*(0.031355982797648785 - 0.3599030272540145*lm + 
          0.13288439390948306*lm^2 + 0.037434375*lm^3) + 
        CF*(-0.02557514684001686 - 0.056737116381009096*lm - 
          0.22109187246630044*lm^2 + 0.06125625*lm^3) - 
        0.05277717933946292*NM + 0.026801420450897784*lm*NM - 
        0.011167048892633284*lm^2*NM - 0.00680625*lm^3*NM - 
        0.06180440253020548*NL + 0.026801420450897784*lm*NL - 
        0.011167048892633284*lm^2*NL - 0.00680625*lm^3*NL - 
        0.022028020615736478*NH + 0.026801420450897784*lm*NH - 
        0.011167048892633284*lm^2*NH - 0.00680625*lm^3*NH)}, 
     {0.51, CF*NC*(CA*(0.032441348575134844 - 0.3548025405935966*lm + 
          0.12954771146797975*lm^2 + 0.03668194444444445*lm^3) + 
        CF*(-0.024018526244345362 - 0.053888861364150276*lm - 
          0.21773726759785134*lm^2 + 0.060025*lm^3) - 0.05175900248114126*
         NM + 0.026496584255136058*lm*NM - 0.01082155360023874*lm^2*NM - 
        0.006669444444444445*lm^3*NM - 0.060715608272584966*NL + 
        0.026496584255136058*lm*NL - 0.01082155360023874*lm^2*NL - 
        0.006669444444444445*lm^3*NL - 0.022056113742288407*NH + 
        0.026496584255136058*lm*NH - 0.01082155360023874*lm^2*NH - 
        0.006669444444444445*lm^3*NH)}, 
     {0.515, CF*NC*(CA*(0.03348507469762582 - 0.34966771085586645*lm + 
          0.12626626070285443*lm^2 + 0.03593715277777778*lm^3) + 
        CF*(-0.022525213769407967 - 0.051095385645918964*lm - 
          0.21438177225896546*lm^2 + 0.05880625*lm^3) - 
        0.05075174926906153*NM + 0.026184125865282012*lm*NM - 
        0.010483448915670504*lm^2*NM - 0.0065340277777777775*lm^3*NM - 
        0.059635235445142105*NL + 0.026184125865282012*lm*NL - 
        0.010483448915670504*lm^2*NL - 0.0065340277777777775*lm^3*NL - 
        0.022067722111102875*NH + 0.026184125865282012*lm*NH - 
        0.010483448915670504*lm^2*NH - 0.0065340277777777775*lm^3*NH)}, 
     {0.52, CF*NC*(CA*(0.034486393533027807 - 0.3445013563698672*lm + 
          0.12303956570183362*lm^2 + 0.0352*lm^3) + 
        CF*(-0.021093909462363322 - 0.048357584201952*lm - 
          0.21102616521518136*lm^2 + 0.0576*lm^3) - 0.04975526915921894*NM + 
        0.02586444757633806*lm*NM - 0.010152648309424294*lm^2*NM - 
        0.0064*lm^3*NM - 0.058563188840334256*NL + 0.02586444757633806*lm*
         NL - 0.010152648309424294*lm^2*NL - 0.0064*lm^3*NL - 
        0.02206325088856747*NH + 0.02586444757633806*lm*NH - 
        0.010152648309424294*lm^2*NH - 0.0064*lm^3*NH)}, 
     {0.525, CF*NC*(CA*(0.03544461728284322 - 0.33930625165251826*lm + 
          0.11986715110270087*lm^2 + 0.03447048611111111*lm^3) + 
        CF*(-0.01972329389462526 - 0.04567628461122089*lm - 
          0.20767122433194404*lm^2 + 0.05640625*lm^3) - 
        0.048769420500853124*NM + 0.025537943844751873*lm*NM - 
        0.009829065352006219*lm^2*NM - 0.006267361111111111*lm^3*NM - 
        0.0574993827353989*NL + 0.025537943844751873*lm*NL - 
        0.009829065352006219*lm^2*NL - 0.006267361111111111*lm^3*NL - 
        0.022043103425319375*NH + 0.025537943844751873*lm*NH - 
        0.009829065352006219*lm^2*NH - 0.006267361111111111*lm^3*NH)}, 
     {0.53, CF*NC*(CA*(0.03635913560659957 - 0.3340851279721742*lm + 
          0.11674854214583404*lm^2 + 0.03374861111111111*lm^3) + 
        CF*(-0.01841203062648205 - 0.04305224838852931*lm - 
          0.20431772648863522*lm^2 + 0.055225*lm^3) - 0.04779407022139988*
         NM + 0.02520500140303898*lm*NM - 0.009512613723484976*lm^2*NM - 
        0.006136111111111111*lm^3*NM - 0.0564437405641273*NL + 
        0.02520500140303898*lm*NL - 0.009512613723484976*lm^2*NL - 
        0.006136111111111111*lm^3*NL - 0.02200768121223104*NH + 
        0.02520500140303898*lm*NH - 0.009512613723484976*lm^2*NH - 
        0.006136111111111111*lm^3*NH)}, 
     {0.535, CF*NC*(CA*(0.03722941331196703 - 0.3288406739080823*lm + 
          0.11368326472446466*lm^2 + 0.033034375*lm^3) + 
        CF*(-0.01715876856319097 - 0.040486172292511724*lm - 
          0.20096644749633055*lm^2 + 0.05405625*lm^3) - 
        0.04682909352128512*NM + 0.024865999373132622*lm*NM - 
        0.009203207222629937*lm^2*NM - 0.00600625*lm^3*NM - 
        0.05539619459861154*NL + 0.024865999373132622*lm*NL - 
        0.009203207222629937*lm^2*NL - 0.00600625*lm^3*NL - 
        0.021957383838560694*NH + 0.024865999373132622*lm*NH - 
        0.009203207222629937*lm^2*NH - 0.00600625*lm^3*NH)}, 
     {0.54, CF*NC*(CA*(0.03805498810870966 - 0.3235755359055202*lm + 
          0.11067084543274847*lm^2 + 0.032327777777777775*lm^3) + 
        CF*(-0.015962144206965366 - 0.03797868960946681*lm - 
          0.19761816201913887*lm^2 + 0.0529*lm^3) - 0.0458743735782547*NM + 
        0.024521309378441637*lm*NM - 0.008900759775651237*lm^2*NM - 
        0.005877777777777778*lm^3*NM - 0.05435668564065602*NL + 
        0.024521309378441637*lm*NL - 0.008900759775651237*lm^2*NL - 
        0.005877777777777778*lm^3*NL - 0.021892608952186334*NH + 
        0.024521309378441637*lm*NH - 0.008900759775651237*lm^2*NH - 
        0.005877777777777778*lm^3*NH)}, 
     {0.545, CF*NC*(CA*(0.03883546842466676 - 0.31829231882641495*lm + 
          0.10771081161173188*lm^2 + 0.03162881944444444*lm^3) + 
        CF*(-0.014820783809085624 - 0.035530371413364965*lm - 
          0.1942736434989842*lm^2 + 0.05175625*lm^3) - 0.04492980126094308*
         NM + 0.024171295654599873*lm*NM - 0.00860518544455731*lm^2*NM - 
        0.0057506944444444446*lm^3*NM - 0.05332516272255409*NL + 
        0.024171295654599873*lm*NL - 0.00860518544455731*lm^2*NL - 
        0.0057506944444444446*lm^3*NL - 0.02181375222184481*NH + 
        0.024171295654599873*lm*NH - 0.00860518544455731*lm^2*NH - 
        0.0057506944444444446*lm^3*NH)}, 
     {0.55, CF*NC*(CA*(0.0395705312820115 - 0.3129935864952664*lm + 
          0.10480269139329566*lm^2 + 0.0309375*lm^3) + 
        CF*(-0.013733305426187973 - 0.033141727802374094*lm - 
          0.190933664083698*lm^2 + 0.050625*lm^3) - 0.04399527485139313*NM + 
        0.02381631515889376*lm*NM - 0.008316398435144668*lm^2*NM - 
        0.005625*lm^3*NM - 0.05230158281694012*NL + 0.02381631515889376*lm*
         NL - 0.008316398435144668*lm^2*NL - 0.005625*lm^3*NL - 
        0.021721207301300866*NH + 0.02381631515889376*lm*NH - 
        0.008316398435144668*lm^2*NH - 0.005625*lm^3*NH)}, 
     {0.555, CF*NC*(CA*(0.040259920232083045 - 0.30768186224021404*lm + 
          0.10194601374215417*lm^2 + 0.030253819444444444*lm^3) + 
        CF*(-0.012698320884615475 - 0.030813209112251716*lm - 
          0.18759899455829315*lm^2 + 0.04950625*lm^3) - 
        0.043070699776247834*NM + 0.02345671767835694*lm*NM - 
        0.008034313104634093*lm^2*NM - 0.005500694444444444*lm^3*NM - 
        0.051285910555436645*NL + 0.02345671767835694*lm*NL - 
        0.008034313104634093*lm^2*NL - 0.005500694444444444*lm^3*NL - 
        0.02161536579537374*NH + 0.02345671767835694*lm*NH - 
        0.008034313104634093*lm^2*NH - 0.005500694444444444*lm^3*NH)}, 
     {0.56, CF*NC*(CA*(0.040903443347136643 - 0.30235962942910594*lm + 
          0.09914030849598446*lm^2 + 0.02957777777777778*lm^3) + 
        CF*(-0.01171443765655351 - 0.02854520710695428*lm - 
          0.18427040427929814*lm^2 + 0.0484*lm^3) - 0.04215598834634347*NM + 
        0.023092845936523408*lm*NM - 0.007758843968966872*lm^2*NM - 
        0.005377777777777778*lm^3*NM - 0.05027811795582485*NL + 
        0.023092845936523408*lm*NL - 0.007758843968966872*lm^2*NL - 
        0.005377777777777778*lm^3*NL - 0.02149661722775182*NH + 
        0.023092845936523408*lm*NH - 0.007758843968966872*lm^2*NH - 
        0.005377777777777778*lm^3*NH)}, 
     {0.565, CF*NC*(CA*(0.041500971267403104 - 0.2970293320004422*lm + 
          0.09638510640375741*lm^2 + 0.028909375*lm^3) + 
        CF*(-0.010780260651517144 - 0.026338056146816644*lm - 
          0.1809486611120333*lm^2 + 0.04730625*lm^3) - 0.04125105950444222*
         NM + 0.022725035698832732*lm*NM - 0.007489905709774076*lm^2*NM - 
        0.00525625*lm^3*NM - 0.049278184157475605*NL + 
        0.022725035698832732*lm*NL - 0.007489905709774076*lm^2*NL - 
        0.00525625*lm^3*NL - 0.021365349010528435*NH + 
        0.022725035698832732*lm*NH - 0.007489905709774076*lm^2*NH - 
        0.00525625*lm^3*NH)}, 
     {0.57, CF*NC*(CA*(0.04205243530189482 - 0.2916933749890817*lm + 
          0.09367993916233953*lm^2 + 0.02824861111111111*lm^3) + 
        CF*(-0.009894393926609703 - 0.024192034334656203*lm - 
          0.17763453137071714*lm^2 + 0.046225*lm^3) - 0.04035583858085011*
         NM + 0.022353615876682924*lm*NM - 0.00722741318103143*lm^2*NM - 
        0.005136111111111111*lm^3*NM - 0.04828609516478651*NL + 
        0.022353615876682924*lm*NL - 0.00722741318103143*lm^2*NL - 
        0.005136111111111111*lm^3*NL - 0.021221946415394474*NH + 
        0.022353615876682924*lm*NH - 0.00722741318103143*lm^2*NH - 
        0.005136111111111111*lm^3*NH)}, 
     {0.575, CF*NC*(CA*(0.042557825581440153 - 0.2863541250466142*lm + 
          0.09102433945143129*lm^2 + 0.027595486111111112*lm^3) + 
        CF*(-0.009055442318830336 - 0.02210736464015659*lm - 
          0.17432877976129427*lm^2 + 0.04515625*lm^3) - 
        0.03947025705667426*NM + 0.021978908630128413*lm*NM - 
        0.0069712814154117494*lm^2*NM - 0.005017361111111111*lm^3*NM - 
        0.047301843598378426*NL + 0.021978908630128413*lm*NL - 
        0.0069712814154117494*lm^2*NL - 0.005017361111111111*lm^3*NL - 
        0.021066792546425902*NH + 0.021978908630128413*lm*NH - 
        0.0069712814154117494*lm^2*NH - 0.005017361111111111*lm^3*NH)}, 
     {0.58, CF*NC*(CA*(0.043017189262471334 - 0.28101391095631145*lm + 
          0.08841784096690568*lm^2 + 0.02695*lm^3) + 
        CF*(-0.00826201300257292 - 0.020084216002886207*lm - 
          0.17103216932688162*lm^2 + 0.0441*lm^3) - 0.03859425233448102*NM + 
        0.021601229469222282*lm*NM - 0.006721425630346486*lm^2*NM - 
        0.0049*lm^3*NM - 0.04632542845381306*NL + 0.021601229469222282*lm*
         NL - 0.006721425630346486*lm^2*NL - 0.0049*lm^3*NL - 
        0.020900268314406698*NH + 0.021601229469222282*lm*NH - 
        0.006721425630346486*lm^2*NH - 0.0049*lm^3*NH)}, 
     {0.585, CF*NC*(CA*(0.0434306287801336 - 0.2756750241425852*lm + 
          0.08585997845260743*lm^2 + 0.026312152777777778*lm^3) + 
        CF*(-0.007512716975329305 - 0.018122704414306162*lm - 
          0.16774546139573332*lm^2 + 0.04305625*lm^3) - 
        0.037727767516123986*NM + 0.021220887354003456*lm*NM - 
        0.0064777612338074095*lm^2*NM - 0.004784027777777778*lm^3*NM - 
        0.045356854867600604*NL + 0.021220887354003456*lm*NL - 
        0.0064777612338074095*lm^2*NL - 0.004784027777777778*lm^3*NL - 
        0.020722752412629816*NH + 0.021220887354003456*lm*NH - 
        0.0064777612338074095*lm^2*NH - 0.004784027777777778*lm^3*NH)}, 
     {0.59, CF*NC*(CA*(0.04379830014932421 - 0.2703397191748885*lm + 
          0.08335028773067152*lm^2 + 0.025681944444444445*lm^3) + 
        CF*(-0.006806170474485988 - 0.01622289397912126*lm - 
          0.16446941553162842*lm^2 + 0.042025*lm^3) - 0.036870751187518265*
         NM + 0.02083818479313101*lm*NM - 0.006240203829819064*lm^2*NM - 
        0.004669444444444445*lm^3*NM - 0.04439613389027379*NL + 
        0.02083818479313101*lm*NL - 0.006240203829819064*lm^2*NL - 
        0.004669444444444445*lm^3*NL - 0.020534621294121102*NH + 
        0.02083818479313101*lm*NH - 0.006240203829819064*lm^2*NH - 
        0.004669444444444445*lm^3*NH)}, 
     {0.595, CF*NC*(CA*(0.044120411312310245 - 0.2650102142660091*lm + 
          0.08088830573041692*lm^2 + 0.025059375*lm^3) + 
        CF*(-0.006140996327984935 - 0.014384797956326306*lm - 
          0.1612047894865905*lm^2 + 0.04100625*lm^3) - 0.036023157210144166*
         NM + 0.020453417941169078*lm*NM - 0.006008669223712167*lm^2*NM - 
        0.00455625*lm^3*NM - 0.04344328226631196*NL + 
        0.020453417941169078*lm*NL - 0.006008669223712167*lm^2*NL - 
        0.00455625*lm^3*NL - 0.02033624915023303*NH + 
        0.020453417941169078*lm*NH - 0.006008669223712167*lm^2*NH - 
        0.00455625*lm^3*NH)}, 
     {0.6, CF*NC*(CA*(0.04439722053161314 - 0.2596886917647111*lm + 
          0.07847357051586934*lm^2 + 0.024444444444444446*lm^3) + 
        CF*(-0.005515825241505926 - 0.012608379780298102*lm - 
          0.15795233915585016*lm^2 + 0.04*lm^3) - 0.035184944519070546*NM + 
        0.020066876694527003*lm*NM - 0.005783073427127758*lm^2*NM - 
        0.0044444444444444444*lm^3*NM - 0.04249832222070556*NL + 
        0.020066876694527003*lm*NL - 0.005783073427127758*lm^2*NL - 
        0.0044444444444444444*lm^3*NL - 0.020128007890557183*NH + 
        0.020066876694527003*lm*NH - 0.005783073427127758*lm^2*NH - 
        0.0044444444444444444*lm^3*NH)}, 
     {0.605, CF*NC*(CA*(0.044629034826885565 - 0.25437729864269176*lm + 
          0.07610562131196477*lm^2 + 0.023837152777777777*lm^3) + 
        CF*(-0.004929297024719392 - 0.010893554062281215*lm - 
          0.15471281853496674*lm^2 + 0.03900625*lm^3) - 
        0.03435607692729451*NM + 0.019678844786060558*lm*NM - 
        0.005563332662781473*lm^2*NM - 0.004334027777777778*lm^3*NM - 
        0.041561281251958175*NL + 0.019678844786060558*lm*NL - 
        0.005563332662781473*lm^2*NL - 0.004334027777777778*lm^3*NL - 
        0.019910267124106238*NH + 0.019678844786060558*lm*NH - 
        0.005563332662781473*lm^2*NH - 0.004334027777777778*lm^3*NH)}, 
     {0.61, CF*NC*(CA*(0.04481620845454362 - 0.2490781469758274*lm + 
          0.07378399852948347*lm^2 + 0.0232375*lm^3) + 
        CF*(-0.00438006175905498 - 0.009240187572613197*lm - 
          0.15148697967902702*lm^2 + 0.038025*lm^3) - 0.03353652293620059*
         NM + 0.01928959987834103*lm*NM - 0.005349363368996996*lm^2*NM - 
        0.004225*lm^3*NM - 0.04063219193132959*NL + 0.01928959987834103*lm*
         NL - 0.005349363368996996*lm^2*NL - 0.004225*lm^3*NL - 
        0.019683394141718127*NH + 0.01928959987834103*lm*NH - 
        0.005349363368996996*lm^2*NH - 0.004225*lm^3*NH)}, 
     {0.615, CF*NC*(CA*(0.04495914142895262 - 0.2437933144196896*lm + 
          0.07150824378876208*lm^2 + 0.022645486111111113*lm^3) + 
        CF*(-0.0038667809093317312 - 0.007648100204031941*lm - 
          0.14827557266384386*lm^2 + 0.03705625*lm^3) - 
        0.032726255551948746*NM + 0.01889941365559982*lm*NM - 
        0.00514108220401735*lm^2*NM - 0.004117361111111111*lm^3*NM - 
        0.039711091708129885*NL + 0.01889941365559982*lm*NL - 
        0.00514108220401735*lm^2*NL - 0.004117361111111111*lm^3*NL - 
        0.019447753899636676*NH + 0.01889941365559982*lm*NH - 
        0.00514108220401735*lm^2*NH - 0.004117361111111111*lm^3*NH)}, 
     {0.62, CF*NC*(CA*(0.04505827808399998 - 0.23852484467932109*lm + 
          0.0692778999422297*lm^2 + 0.02206111111111111*lm^3) + 
        CF*(-0.0033881283815007826 - 0.006117065916404854*lm - 
          0.14507934554907867*lm^2 + 0.0361*lm^3) - 0.03192525210760666*NM + 
        0.018508551914357223*lm*NM - 0.0049384060501023695*lm^2*NM - 
        0.004011111111111111*lm^3*NM - 0.03879802272088022*NL + 
        0.018508551914357223*lm*NL - 0.0049384060501023695*lm^2*NL - 
        0.004011111111111111*lm^3*NL - 0.019203709004224828*NH + 
        0.018508551914357223*lm*NH - 0.0049384060501023695*lm^2*NH - 
        0.004011111111111111*lm^3*NH)}, 
     {0.625, CF*NC*(CA*(0.04511410567392258 - 0.23327474797326597*lm + 
          0.06709251109581207*lm^2 + 0.021484375*lm^3) + 
        CF*(-0.0029427915286604446 - 0.004646813663216103*lm - 
          0.1418990443432166*lm^2 + 0.03515625*lm^3) - 0.031133494090847497*
         NM + 0.018117274652744573*lm*NM - 0.004741252017420377*lm^2*NM - 
        0.00390625*lm^3*NM - 0.037893031614162076*NL + 
        0.018117274652744573*lm*NL - 0.004741252017420377*lm^2*NL - 
        0.00390625*lm^3*NL - 0.01895161969776808*NH + 
        0.018117274652744573*lm*NH - 0.004741252017420377*lm^2*NH - 
        0.00390625*lm^3*NH)}, 
     {0.63, CF*NC*(CA*(0.0451271530122885 - 0.2280450014918556*lm + 
          0.06495162262924631*lm^2 + 0.02091527777777778*lm^3) + 
        CF*(-0.0025294721074164326 - 0.003237028300144686*lm - 
          0.13873541297032424*lm^2 + 0.034225*lm^3) - 0.030350966977040036*
         NM + 0.01772583615852987*lm*NM - 0.004549537447741752*lm^2*NM - 
        0.0038027777777777778*lm^3*NM - 0.036996169360982475*NL + 
        0.01772583615852987*lm*NL - 0.004549537447741752*lm^2*NL - 
        0.0038027777777777778*lm^3*NL - 0.018691843845327346*NH + 
        0.01772583615852987*lm*NH - 0.004549537447741752*lm^2*NH - 
        0.0038027777777777778*lm^3*NH)}, 
     {0.635, CF*NC*(CA*(0.04509798914806546 - 0.22283754984975665*lm + 
          0.06285478121534666*lm^2 + 0.020353819444444445*lm^3) + 
        CF*(-0.0021468871865765807 - 0.0018873514760623029*lm - 
          0.13558919323852367*lm^2 + 0.03330625*lm^3) - 
        0.029577660067563547*NM + 0.017334485095857468*lm*NM - 
        0.0043631799179418155*lm^2*NM - 0.0037006944444444444*lm^3*NM - 
        0.03610749109048773*NL + 0.017334485095857468*lm*NL - 
        0.0043631799179418155*lm^2*NL - 0.0037006944444444444*lm^3*NL - 
        0.018424736922601968*NH + 0.017334485095857468*lm*NH - 
        0.0043631799179418155*lm^2*NH - 0.0037006944444444444*lm^3*NH)}, 
     {0.64, CF*NC*(CA*(0.04502722207773898 - 0.21765430553279283*lm + 
          0.060801534838260805*lm^2 + 0.0198*lm^3) + 
        CF*(-0.0017937700100894827 - 0.0005973825067761259*lm - 
          0.13246112481011868*lm^2 + 0.0324*lm^3) - 0.028813566333185152*
         NM + 0.016943464590712963*lm*NM - 0.004182097243320146*lm^2*NM - 
        0.0036*lm^3*NM - 0.03522705592086413*NL + 0.016943464590712963*lm*
         NL - 0.004182097243320146*lm^2*NL - 0.0036*lm^3*NL - 
        0.018150652004764976*NH + 0.016943464590712963*lm*NH - 
        0.004182097243320146*lm^2*NH - 0.0036*lm^3*NH)}, 
     {0.645, CF*NC*(CA*(0.04491549749247362 - 0.21249714933905708*lm + 
          0.05879143281075418*lm^2 + 0.019253819444444445*lm^3) + 
        CF*(-0.0014688708160599847 + 0.0006333207681624964*lm - 
          0.12935194517331136*lm^2 + 0.03150625*lm^3) - 
        0.02805868226234244*NM + 0.016553012315125078*lm*NM - 
        0.0040062074807431835*lm^2*NM - 0.0035006944444444443*lm^3*NM - 
        0.034354926797268696*NL + 0.016553012315125078*lm*NL - 
        0.0040062074807431835*lm^2*NL - 0.0035006944444444443*lm^3*NL - 
        0.017869939756234125*NH + 0.016553012315125078*lm*NH - 
        0.0040062074807431835*lm^2*NH - 0.0035006944444444443*lm^3*NH)}, 
     {0.65, CF*NC*(CA*(0.04476349755933978 - 0.20736793081433433*lm + 
          0.05682402579055854*lm^2 + 0.01871527777777778*lm^3) + 
        CF*(-0.0011709576136011393 + 0.0018052411452665115*lm - 
          0.12626238961544967*lm^2 + 0.030625*lm^3) - 0.027313007714179258*
         NM + 0.0161633605701166*lm*NM - 0.003835428931616705*lm^2*NM - 
        0.0034027777777777776*lm^3*NM - 0.033491170334638165*NL + 
        0.0161633605701166*lm*NL - 0.003835428931616705*lm^2*NL - 
        0.0034027777777777776*lm^3*NL - 0.017582948421343517*NH + 
        0.0161633605701166*lm*NH - 0.003835428931616705*lm^2*NH - 
        0.0034027777777777776*lm^3*NH)}, 
     {0.655, CF*NC*(CA*(0.04457193973565701 - 0.20226846868185966*lm + 
          0.054898865795819846*lm^2 + 0.018184375*lm^3) + 
        CF*(-0.0008988169192120182 + 0.0029189012332262003*lm - 
          0.12319319119774934*lm^2 + 0.02975625*lm^3) - 
        0.026576545776187226*NM + 0.015774736367416952*lm*NM - 
        0.003669680144694517*lm^2*NM - 0.00330625*lm^3*NM - 
        0.03263585666522934*NL + 0.015774736367416952*lm*NL - 
        0.003669680144694517*lm^2*NL - 0.00330625*lm^3*NL - 
        0.017290023815881905*NH + 0.015774736367416952*lm*NH - 
        0.003669680144694517*lm^2*NH - 0.00330625*lm^3*NH)}, 
     {0.66, CF*NC*(CA*(0.044341575615532425 - 0.19720055126644045*lm + 
          0.05301550621967875*lm^2 + 0.01766111111111111*lm^3) + 
        CF*(-0.0006512544543034785 + 0.003974862645018518*lm - 
          0.12014508073143478*lm^2 + 0.0289*lm^3) - 0.025849302626310407*
         NM + 0.015387361509949278*lm*NM - 0.00350887991872947*lm^2*NM - 
        0.003211111111111111*lm^3*NM - 0.0317890592907483*NL + 
        0.015387361509949278*lm*NL - 0.00350887991872947*lm^2*NL - 
        0.003211111111111111*lm^3*NL - 0.016991509319465026*NH + 
        0.015387361509949278*lm*NH - 0.00350887991872947*lm^2*NH - 
        0.003211111111111111*lm^3*NH)}, 
     {0.665, CF*NC*(CA*(0.044073189807699385 - 0.1921659369129734*lm + 
          0.051173501844016256*lm^2 + 0.01714548611111111*lm^3) + 
        CF*(-0.0004270958054295018 + 0.004973725205708904*lm - 
          0.11711878675524612*lm^2 + 0.02805625*lm^3) - 
        0.025131287399374924*NM + 0.015001452671105267*lm*NM - 
        0.003352947304972653*lm^2*NM - 0.003117361111111111*lm^3*NM - 
        0.03095085493893072*NL + 0.015001452671105267*lm*NL - 
        0.003352947304972653*lm^2*NL - 0.003117361111111111*lm^3*NL - 
        0.016687745868710385*NH + 0.015001452671105267*lm*NH - 
        0.003352947304972653*lm^2*NH - 0.003117361111111111*lm^3*NH)}, 
     {0.67, CF*NC*(CA*(0.043767598843787905 - 0.18716635439939147*lm + 
          0.04937240885239538*lm^2 + 0.0166375*lm^3) + 
        CF*(-0.00022518704871992847 + 0.005916126175646211*lm - 
          0.11411503551426211*lm^2 + 0.027225*lm^3) - 0.024422512057709768*
         NM + 0.014617221472821207*lm*NM - 0.003201801609526433*lm^2*NM - 
        0.003025*lm^3*NM - 0.030121323424439607*NL + 0.014617221472821207*
         lm*NL - 0.003201801609526433*lm^2*NL - 0.003025*lm^3*NL - 
        0.016379071951184185*NH + 0.014617221472821207*lm*NH - 
        0.003201801609526433*lm^2*NH - 0.003025*lm^3*NH)}, 
     {0.675, CF*NC*(CA*(0.043425650116183045 - 0.1822035033440782*lm + 
          0.04761178484222891*lm^2 + 0.016137152777777778*lm^3) + 
        CF*(-0.00004439533995117041 + 0.0068027394887559475*lm - 
          0.11113455093998906*lm^2 + 0.02640625*lm^3) - 
        0.023722991265829316*NM + 0.01423487456246896*lm*NM - 
        0.003055362395556771*lm^2*NM - 0.0029340277777777776*lm^3*NM - 
        0.029300547513951215*NL + 0.01423487456246896*lm*NL - 
        0.003055362395556771*lm^2*NL - 0.0029340277777777776*lm^3*NL - 
        0.016065823600091074*NH + 0.01423487456246896*lm*NH - 
        0.003055362395556771*lm^2*NH - 0.0029340277777777776*lm^3*NH)}, 
     {0.68, CF*NC*(CA*(0.04304822084465243 - 0.17727905460778892*lm + 
          0.04589118883620195*lm^2 + 0.015644444444444443*lm^3) + 
        CF*(0.00011639052836529215 + 0.007634275005641573*lm - 
          0.10817805463166955*lm^2 + 0.0256*lm^3) - 0.02303274226905209*NM + 
        0.013854613688575797*lm*NM - 0.0029135494853700507*lm^2*NM - 
        0.0028444444444444446*lm^3*NM - 0.028488612795303812*NL + 
        0.013854613688575797*lm*NL - 0.0029135494853700507*lm^2*NL - 
        0.0028444444444444446*lm^3*NL - 0.015748334389678424*NH + 
        0.013854613688575797*lm*NH - 0.0029135494853700507*lm^2*NH - 
        0.0028444444444444446*lm^3*NH)}, 
     {0.685, CF*NC*(CA*(0.042636217070947446 - 0.17239465069012147*lm + 
          0.04421018129297704*lm^2 + 0.015159375*lm^3) + 
        CF*(0.0002582596015512644 + 0.008411477781208208*lm - 
          0.10524626583876484*lm^2 + 0.02480625*lm^3) - 
        0.022351784775934375*NM + 0.013476635775387207*lm*NM - 
        0.002776282962359462*lm^2*NM - 0.00275625*lm^3*NM - 
        0.027685607550587858*NL + 0.013476635775387207*lm*NL - 
        0.002776282962359462*lm^2*NL - 0.00275625*lm^3*NL - 
        0.015426935431327969*NH + 0.013476635775387207*lm*NH - 
        0.002776282962359462*lm^2*NH - 0.00275625*lm^3*NH)}, 
     {0.69, CF*NC*(CA*(0.04219057268060592 - 0.16755190612058052*lm + 
          0.04256832411720856*lm^2 + 0.014681944444444444*lm^3) + 
        CF*(0.00038227826771387326 + 0.0091351273465277*lm - 
          0.10233990144456781*lm^2 + 0.024025*lm^3) - 0.021680140844401022*
         NM + 0.013101132996286869*lm*NM - 0.0026434831728257987*lm^2*NM - 
        0.0026694444444444443*lm^3*NM - 0.026891622633060098*NL + 
        0.013101132996286869*lm*NL - 0.0026434831728257987*lm^2*NL - 
        0.0026694444444444443*lm^3*NL - 0.015101955370308486*NH + 
        0.013101132996286869*lm*NH - 0.0026434831728257987*lm^2*NH - 
        0.0026694444444444443*lm^3*NH)}, 
     {0.695, CF*NC*(CA*(0.04171224845120638 - 0.1627524078442818*lm + 
          0.04096518066889204*lm^2 + 0.014212152777777778*lm^3) + 
        CF*(0.0004894897918581711 + 0.009806037004668646*lm - 
          0.09945967595090394*lm^2 + 0.02325625*lm^3) - 
        0.021017834771459652*NM + 0.012728292846088186*lm*NM - 
        0.0025150707276773406*lm^2*NM - 0.002584027777777778*lm^3*NM - 
        0.026106751347767593*NL + 0.012728292846088186*lm*NL - 
        0.0025150707276773406*lm^2*NL - 0.002584027777777778*lm^3*NL - 
        0.014773720383164154*NH + 0.012728292846088186*lm*NH - 
        0.0025150707276773406*lm^2*NH - 0.002584027777777778*lm^3*NH)}, 
     {0.7, CF*NC*(CA*(0.041202231126345516 - 0.15799771560234416*lm + 
          0.03940031577207328*lm^2 + 0.01375*lm^3) + 
        CF*(0.0005809138779851976 + 0.010425053140219527*lm - 
          0.09660630146388009*lm^2 + 0.0225*lm^3) - 0.020364892986387936*
         NM + 0.012358298212211781*lm*NM - 0.002390966504013323*lm^2*NM - 
        0.0025*lm^3*NM - 0.025331089335771384*NL + 0.012358298212211781*lm*
         NL - 0.002390966504013323*lm^2*NL - 0.0025*lm^3*NL - 
        0.014442554175714202*NH + 0.012358298212211781*lm*NH - 
        0.002390966504013323*lm^2*NH - 0.0025*lm^3*NH)}, 
     {0.705, CF*NC*(CA*(0.04066153251463184 - 0.15328936230701848*lm + 
          0.037873295722941014*lm^2 + 0.01329548611111111*lm^3) + 
        CF*(0.0006575462580464324 + 0.010993054542237785*lm - 
          0.09378048768064198*lm^2 + 0.02175625*lm^3) - 
        0.01972134394728715*NM + 0.011991327444763484*lm*NM - 
        0.0022710916465953353*lm^2*NM - 0.002417361111111111*lm^3*NM - 
        0.024564734461862782*NL + 0.011991327444763484*lm*NL - 
        0.0022710916465953353*lm^2*NL - 0.002417361111111111*lm^3*NL - 
        0.014108777981640197*NH + 0.011991327444763484*lm*NH - 
        0.0022710916465953353*lm^2*NH - 0.002417361111111111*lm^3*NH)}, 
     {0.71, CF*NC*(CA*(0.04009118861300859 - 0.14862885441160503*lm + 
          0.0363836882973262*lm^2 + 0.012848611111111111*lm^3) + 
        CF*(0.0007203583066697376 + 0.01151095174036223*lm - 
          0.09098294187710257*lm^2 + 0.021025*lm^3) - 0.01908721804089869*
         NM + 0.011627554425527363*lm*NM - 0.002155367569210825*lm^2*NM - 
        0.0023361111111111113*lm^3*NM - 0.023807786705668778*NL + 
        0.011627554425527363*lm*NL - 0.002155367569210825*lm^2*NL - 
        0.0023361111111111113*lm^3*NL - 0.013772710561638275*NH + 
        0.011627554425527363*lm*NH - 0.002155367569210825*lm^2*NH - 
        0.0023361111111111113*lm^3*NH)}, 
     {0.715, CF*NC*(CA*(0.03949225875373903 - 0.14401767227521034*lm + 
          0.03493106275763004*lm^2 + 0.012409375*lm^3) + 
        CF*(0.0007702966806142651 + 0.011979686353830732*lm - 
          0.08821436889660539*lm^2 + 0.02030625*lm^3) - 
        0.018462547485583253*NM + 0.011267148635888355*lm*NM - 
        0.0020437159559327346*lm^2*NM - 0.00225625*lm^3*NM - 
        0.023060348056046096*NL + 0.011267148635888355*lm*NL - 
        0.0020437159559327346*lm^2*NL - 0.00225625*lm^3*NL - 
        0.013434668203114312*NH + 0.011267148635888355*lm*NH - 
        0.0020437159559327346*lm^2*NH - 0.00225625*lm^3*NH)}, 
     {0.72, CF*NC*(CA*(0.038865824774406234 - 0.13945727052239743*lm + 
          0.03351498985920199*lm^2 + 0.011977777777777778*lm^3) + 
        CF*(0.0008082829819524543 + 0.012400230453149745*lm - 
          0.08547547113948765*lm^2 + 0.0196*lm^3) - 0.01784736623736586*NM + 
        0.01091027522369911*lm*NM - 0.00193605876227915*lm^2*NM - 
        0.0021777777777777776*lm^3*NM - 0.022322522408666647*NL + 
        0.01091027522369911*lm*NL - 0.00193605876227915*lm^2*NL - 
        0.0021777777777777776*lm^3*NL - 0.013094964720400906*NH + 
        0.01091027522369911*lm*NH - 0.00193605876227915*lm^2*NH - 
        0.0021777777777777776*lm^3*NH)}, 
     {0.725, CF*NC*(CA*(0.038212990210298343 - 0.1349490783977827*lm + 
          0.03213504185618852*lm^2 + 0.011553819444444445*lm^3) + 
        CF*(0.0008352134440162588 + 0.012773585934166687*lm - 
          0.0827669485535097*lm^2 + 0.01890625*lm^3) - 0.017241709898952653*
         NM + 0.010557095069105599*lm*NM - 0.0018323182162767004*lm^2*NM - 
        0.0021006944444444445*lm^3*NM - 0.0215944154667001*NL + 
        0.010557095069105599*lm*NL - 0.0018323182162767004*lm^2*NL - 
        0.0021006944444444445*lm^3*NL - 0.012753911455475683*NH + 
        0.010557095069105599*lm*NH - 0.0018323182162767004*lm^2*NH - 
        0.0021006944444444445*lm^3*NH)}, 
     {0.73, CF*NC*(CA*(0.03753487950856814 - 0.13049450011563496*lm + 
          0.030790792506872222*lm^2 + 0.0111375*lm^3) + 
        CF*(0.0008519586391821781 + 0.013100783904300708*lm - 
          0.08008949862511819*lm^2 + 0.018225*lm^3) - 0.01664561563162861*
         NM + 0.010207764849346063*lm*NM - 0.0017324168194313132*lm^2*NM - 
        0.002025*lm^3*NM - 0.020876134644502206*NL + 0.010207764849346063*
         lm*NL - 0.0017324168194313132*lm^2*NL - 0.002025*lm^3*NL - 
        0.012411817279161243*NH + 0.010207764849346063*lm*NH - 
        0.0017324168194313132*lm^2*NH - 0.002025*lm^3*NH)}, 
     {0.735, CF*NC*(CA*(0.036832637263573505 - 0.12609491520453167*lm + 
          0.02948181707852054*lm^2 + 0.010728819444444444*lm^3) + 
        CF*(0.0008593632076055997 + 0.013382884080691835*lm - 
          0.07744381637151183*lm^2 + 0.01755625*lm^3) - 
        0.016059122069947945*NM + 0.009862437102537782*lm*NM - 
        0.0016362773476097955*lm^2*NM - 0.0019506944444444444*lm^3*NM - 
        0.020167788974220325*NL + 0.009862437102537782*lm*NL - 
        0.0016362773476097955*lm^2*NL - 0.0019506944444444444*lm^3*NL - 
        0.012068988592787697*NH + 0.009862437102537782*lm*NH - 
        0.0016362773476097955*lm^2*NH - 0.0019506944444444444*lm^3*NH)}, 
     {0.74, CF*NC*(CA*(0.036107427472822154 - 0.12175167884712841*lm + 
          0.028207692351762428*lm^2 + 0.010327777777777778*lm^3) + 
        CF*(0.0008582456060494468 + 0.013620974200032861*lm - 
          0.07483059433347966*lm^2 + 0.0169*lm^3) - 0.015482269239132007*
         NM + 0.009521260290466165*lm*NM - 0.001543822851835593*lm^2*NM - 
        0.0018777777777777777*lm^3*NM - 0.019469489015230327*NL + 
        0.009521260290466165*lm*NL - 0.001543822851835593*lm^2*NL - 
        0.0018777777777777777*lm^3*NL - 0.011725729330299415*NH + 
        0.009521260290466165*lm*NH - 0.001543822851835593*lm^2*NH - 
        0.0018777777777777777*lm^3*NH)}, 
     {0.745, CF*NC*(CA*(0.035360432812960745 - 0.11746612221509868*lm + 
          0.026967996624510732*lm^2 + 0.009934375*lm^3) + 
        CF*(0.0008493978759852338 + 0.013816169439852758*lm - 
          0.07225052256898244*lm^2 + 0.01625625*lm^3) - 
        0.014915098475091863*NM + 0.009184378860390523*lm*NM - 
        0.0014549766590019513*lm^2*NM - 0.00180625*lm^3*NM - 
        0.018781346766321688*NL + 0.009184378860390523*lm*NL - 
        0.0014549766590019513*lm^2*NL - 0.00180625*lm^3*NL - 
        0.011382340960788297*NH + 0.009184378860390523*lm*NH - 
        0.0014549766590019513*lm^2*NH - 0.00180625*lm^3*NH)}, 
     {0.75, CF*NC*(CA*(0.03459285393526427 - 0.1132395527993005*lm + 
          0.025762309715447428*lm^2 + 0.009548611111111112*lm^3) + 
        CF*(0.0008335854301764165 + 0.01396961185102464*lm - 
          0.06970428864744967*lm^2 + 0.015625*lm^3) - 0.014357652346995615*
         NM + 0.008851933305880869*lm*NM - 0.001369662372505593*lm^2*NM - 
        0.001736111111111111*lm^3*NM - 0.01810347558055011*NL + 
        0.008851933305880869*lm*NL - 0.001369662372505593*lm^2*NL - 
        0.001736111111111111*lm^3*NL - 0.011039122491436413*NH + 
        0.008851933305880869*lm*NH - 0.001369662372505593*lm^2*NH - 
        0.001736111111111111*lm^3*NH)}, 
     {0.755, CF*NC*(CA*(0.033805908780097364 - 0.10907325473522736*lm + 
          0.02459021296708818*lm^2 + 0.009170486111111112*lm^3) + 
        CF*(0.0008115468569844427 + 0.014082469801275643*lm - 
          0.0671925776447648*lm^2 + 0.01500625*lm^3) - 0.013809974582302834*
         NM + 0.008524060226699975*lm*NM - 0.0012878038728039117*lm^2*NM - 
        0.0016673611111111112*lm^3*NM - 0.017435990082679546*NL + 
        0.008524060226699975*lm*NL - 0.0012878038728039117*lm^2*NL - 
        0.0016673611111111112*lm^3*NL - 0.010696370470851526*NH + 
        0.008524060226699975*lm*NH - 0.0012878038728039117*lm^2*NH - 
        0.0016673611111111112*lm^3*NH)}, 
     {0.76, CF*NC*(CA*(0.03300083190983408 - 0.10496848912380109*lm + 
          0.02345128924844216*lm^2 + 0.0088*lm^3) + 
        CF*(0.0007839937416672129 + 0.014155937429480271*lm - 
          0.06471607213891283*lm^2 + 0.0144*lm^3) - 0.013272109994191011*
         NM + 0.008200892387744843*lm*NM - 0.0012093253178985742*lm^2*NM - 
        0.0016*lm^3*NM - 0.016779006089137793*NL + 0.008200892387744843*lm*
         NL - 0.0012093253178985742*lm^2*NL - 0.0016*lm^3*NL - 
        0.01035437899277956*NH + 0.008200892387744843*lm*NH - 
        0.0012093253178985742*lm^2*NH - 0.0016*lm^3*NH)}, 
     {0.765, CF*NC*(CA*(0.03217887385973734 - 0.10092649434756422*lm + 
          0.02234512295728245*lm^2 + 0.008437152777777778*lm^3) + 
        CF*(0.0007516105039678021 + 0.014191234110522895*lm - 
          0.06227545220626508*lm^2 + 0.01380625*lm^3) - 
        0.012744104411301223*NM + 0.007882558777061606*lm*NM - 
        0.0011341511437483244*lm^2*NM - 0.0015340277777777778*lm^3*NM - 
        0.016132640530412225*NL + 0.007882558777061606*lm*NL - 
        0.0011341511437483244*lm^2*NL - 0.0015340277777777778*lm^3*NL - 
        0.010013439700178609*NH + 0.007882558777061606*lm*NH - 
        0.0011341511437483244*lm^2*NH - 0.0015340277777777778*lm^3*NH)}, 
     {0.77, CF*NC*(CA*(0.03134130050631356 - 0.09694848638232977*lm + 
          0.021271300022041886*lm^2 + 0.008081944444444444*lm^3) + 
        CF*(0.0007150542513183239 + 0.014189603930519256*lm - 
          0.059871395418476914*lm^2 + 0.013225*lm^3) - 0.01222600460973254*
         NM + 0.007569184662947825*lm*NM - 0.0010622060646136762*lm^2*NM - 
        0.0014694444444444444*lm^3*NM - 0.015497011375814393*NL + 
        0.007569184662947825*lm*NL - 0.0010622060646136762*lm^2*NL - 
        0.0014694444444444444*lm^3*NL - 0.009673841789639634*NH + 
        0.007569184662947825*lm*NH - 0.0010622060646136762*lm^2*NH - 
        0.0014694444444444444*lm^3*NH)}, 
     {0.775, CF*NC*(CA*(0.030489392452671512 - 0.0930356591043461*lm + 
          0.020229407903348526*lm^2 + 0.007734375*lm^3) + 
        CF*(0.000674954647009777 + 0.014152315172190823*lm - 
          0.05750457683997514*lm^2 + 0.01265625*lm^3) - 
        0.01171785824721682*NM + 0.007260891650155984*lm*NM - 
        0.0009934150733360955*lm^2*NM - 0.00140625*lm^3*NM - 
        0.014872237560544453*NL + 0.007260891650155984*lm*NL - 
        0.0009934150733360955*lm^2*NL - 0.00140625*lm^3*NL - 
        0.009335872016139548*NH + 0.007260891650155984*lm*NH - 
        0.0009934150733360955*lm^2*NH - 0.00140625*lm^3*NH)}, 
     {0.78, CF*NC*(CA*(0.029624444430427957 - 0.08918918459303496*lm + 
          0.01921903559521461*lm^2 + 0.007394444444444445*lm^3) + 
        CF*(0.0006319137927036528 + 0.014080659810189902*lm - 
          0.05517566902601245*lm^2 + 0.0121*lm^3) - 0.011219713799407782*
         NM + 0.006957797735211878*lm*NM - 0.0009277034415541716*lm^2*NM - 
        0.0013444444444444445*lm^3*NM - 0.014258438914988441*NL + 
        0.006957797735211878*lm*NL - 0.0009277034415541716*lm^2*NL - 
        0.0013444444444444445*lm^3*NL - 0.0089998146981128*NH + 
        0.006957797735211878*lm*NH - 0.0009277034415541716*lm^2*NH - 
        0.0013444444444444445*lm^3*NH)}, 
     {0.785, CF*NC*(CA*(0.028747764717715587 - 0.08541021342936009*lm + 
          0.018239773625892235*lm^2 + 0.0070621527777777774*lm^3) + 
        CF*(0.0005865061246850391 + 0.013975953016177262*lm - 
          0.052885342021267254*lm^2 + 0.01155625*lm^3) - 
        0.010731620498220185*NM + 0.006660017360861462*lm*NM - 
        0.0008649967198591941*lm^2*NM - 0.0012840277777777778*lm^3*NM - 
        0.013655736096183433*NL + 0.006660017360861462*lm*NL - 
        0.0008649967198591941*lm^2*NL - 0.0012840277777777778*lm^3*NL - 
        0.008665951722828118*NH + 0.006660017360861462*lm*NH - 
        0.0008649967198591941*lm^2*NH - 0.0012840277777777778*lm^3*NH)}, 
     {0.79, CF*NC*(CA*(0.027860674572861212 - 0.08169987498988414*lm + 
          0.017291214058408572*lm^2 + 0.0067375*lm^3) + 
        CF*(0.0005392783232799749 + 0.013839532673458*lm - 
          0.05063426335896779*lm^2 + 0.011025*lm^3) - 0.010253628272156997*
         NM + 0.006367661469659604*lm*NM - 0.0008052207378924674*lm^2*NM - 
        0.001225*lm^3*NM - 0.013064250521387627*NL + 0.006367661469659604*
         lm*NL - 0.0008052207378924674*lm^2*NL - 0.001225*lm^3*NL - 
        0.008334562552057516*NH + 0.006367661469659604*lm*NH - 
        0.0008052207378924674*lm^2*NH - 0.001225*lm^3*NH)}, 
     {0.795, CF*NC*(CA*(0.02696450768331444 - 0.07805927773657129*lm + 
          0.01637295049079301*lm^2 + 0.006420486111111111*lm^3) + 
        CF*(0.000490749234881923 + 0.013672758900985108*lm - 
          0.048423098060520524*lm^2 + 0.01050625*lm^3) - 
        0.009785787688564414*NM + 0.0060808375567140355*lm*NM - 
        0.0007483016043866084*lm^2*NM - 0.0011673611111111112*lm^3*NM - 
        0.012484104303694264*NL + 0.0060808375567140355*lm*NL - 
        0.0007483016043866084*lm^2*NL - 0.0011673611111111112*lm^3*NL - 
        0.008005924228025103*NH + 0.0060808375567140355*lm*NH - 
        0.0007483016043866084*lm^2*NH - 0.0011673611111111112*lm^3*NH)}, 
     {0.8, CF*NC*(CA*(0.026060609629418904 - 0.07448950950239282*lm + 
          0.015484578056008152*lm^2 + 0.006111111111111111*lm^3) + 
        CF*(0.00044140980605348495 + 0.01347701358654405*lm - 
          0.046252508635623024*lm^2 + 0.01*lm^3) - 0.009328149897756328*NM + 
        0.005799649721597651*lm*NM - 0.0006941657071529972*lm^2*NM - 
        0.0011111111111111111*lm^3*NM - 0.011915420189630141*NL + 
        0.005799649721597651*lm*NL - 0.0006941657071529972*lm^2*NL - 
        0.0011111111111111111*lm^3*NL - 0.007680311379623673*NH + 
        0.005799649721597651*lm*NH - 0.0006941657071529972*lm^2*NH - 
        0.0011111111111111111*lm^3*NH)}, 
     {0.805, CF*NC*(CA*(0.025150337362629567 - 0.07099163777279235*lm + 
          0.014625693421596114*lm^2 + 0.005809375*lm^3) + 
        CF*(0.0003917230291899006 + 0.013253699928935245*lm - 
          0.04412315508284272*lm^2 + 0.00950625*lm^3) - 
        0.008880766578951782*NM + 0.005524198719442182*lm*NM - 
        0.0006427397130174754*lm^2*NM - 0.00105625*lm^3*NM - 
        0.011358321498681259*NL + 0.005524198719442182*lm*NL - 
        0.0006427397130174754*lm^2*NL - 0.00105625*lm^3*NL - 
        0.007357996228887458*NH + 0.005524198719442182*lm*NH - 
        0.0006427397130174754*lm^2*NH - 0.00105625*lm^3*NH)}, 
     {0.81, CF*NC*(CA*(0.024235058697790714 - 0.06756670996306761*lm + 
          0.013795894789051365*lm^2 + 0.005515277777777778*lm^3) + 
        CF*(0.00034212389925050983 + 0.013004241988975087*lm - 
          0.04203569489064322*lm^2 + 0.009025*lm^3) - 0.008443689887970627*
         NM + 0.005254582011226098*lm*NM - 0.0005939505677063088*lm^2*NM - 
        0.0010027777777777778*lm^3*NM - 0.01081293206468988*NL + 
        0.005254582011226098*lm*NL - 0.0005939505677063088*lm^2*NL - 
        0.0010027777777777778*lm^3*NL - 0.00703924859770986*NH + 
        0.005254582011226098*lm*NH - 0.0005939505677063088*lm^2*NH - 
        0.0010027777777777778*lm^3*NH)}, 
     {0.815, CF*NC*(CA*(0.023316151819100153 - 0.06421575369172486*lm + 
          0.012994781892930681*lm^2 + 0.005228819444444445*lm^3) + 
        CF*(0.0002930193810832153 + 0.012730084249139672*lm - 
          0.0399907830388407*lm^2 + 0.00855625*lm^3) - 0.008016972406634293*
         NM + 0.004990893813269459*lm*NM - 0.0005477254956843662*lm^2*NM - 
        0.0009506944444444444*lm^3*NM - 0.01027937617906891*NL + 
        0.004990893813269459*lm*NL - 0.0005477254956843662*lm^2*NL - 
        0.0009506944444444444*lm^3*NL - 0.006724335914795313*NH + 
        0.004990893813269459*lm*NH - 0.0005477254956843662*lm^2*NH - 
        0.0009506944444444444*lm^3*NH)}, 
     {0.82, CF*NC*(CA*(0.022395004799395525 - 0.06093977704986192*lm + 
          0.012221955999710663*lm^2 + 0.00495*lm^3) + 
        CF*(0.000244788386885126 + 0.012432691181678895*lm - 
          0.03798907200047346*lm^2 + 0.0081*lm^3) - 0.007600667093820256*
         NM + 0.004733225145948278*lm*NM - 0.0005039919999473932*lm^2*NM - 
        0.0009*lm^3*NM - 0.009757778535781213*NL + 0.004733225145948278*lm*
         NL - 0.0005039919999473932*lm^2*NL - 0.0009*lm^3*NL - 
        0.006413523222834848*NH + 0.004733225145948278*lm*NH - 
        0.0005039919999473932*lm^2*NH - 0.0009*lm^3*NH)}, 
     {0.825, CF*NC*(CA*(0.0214730151324089 - 0.05773976886663552*lm + 
          0.011477019906402755*lm^2 + 0.004678819444444445*lm^3) + 
        CF*(0.0001977817633599922 + 0.012113546825032077*lm - 
          0.03603121174406822*lm^2 + 0.00765625*lm^3) - 
        0.007194827238120328*NM + 0.004481663881640802*lm*NM - 
        0.0004626778617701977*lm^2*NM - 0.0008506944444444444*lm^3*NM - 
        0.009248264178032886*NL + 0.004481663881640802*lm*NL - 
        0.0004626778617701977*lm^2*NL - 0.0008506944444444444*lm^3*NL - 
        0.00610707318589526*NH + 0.004481663881640802*lm*NH - 
        0.0004626778617701977*lm^2*NH - 0.0008506944444444444*lm^3*NH)}, 
     {0.83, CF*NC*(CA*(0.020551589277645596 - 0.054616698970867766*lm + 
          0.010759577938935411*lm^2 + 0.0044152777777777775*lm^3) + 
        CF*(0.0001523222881498071 + 0.011774154368379634*lm - 
          0.03411784973628751*lm^2 + 0.007225*lm^3) - 0.006799506412054483*
         NM + 0.004236294791917969*lm*NM - 0.0004237111404124991*lm^2*NM - 
        0.0008027777777777778*lm^3*NM - 0.008750958446631249*NL + 
        0.004236294791917969*lm*NL - 0.0004237111404124991*lm^2*NL - 
        0.0008027777777777778*lm^3*NL - 0.005805246097012149*NH + 
        0.004236294791917969*lm*NH - 0.0004237111404124991*lm^2*NH - 
        0.0008027777777777778*lm^3*NH)}, 
     {0.835, CF*NC*(CA*(0.01963214221755286 - 0.05157151844884674*lm + 
          0.01006923595031272*lm^2 + 0.004159375*lm^3) + 
        CF*(0.00010870467513406418 + 0.011416035744168681*lm - 
          0.03224963094494282*lm^2 + 0.00680625*lm^3) - 
        0.006414758427793356*NM + 0.003997199593990125*lm*NM - 
        0.0003870201727841308*lm^2*NM - 0.00075625*lm^3*NM - 
        0.008265986929959548*NL + 0.003997199593990125*lm*NL - 
        0.0003870201727841308*lm^2*NL - 0.00075625*lm^3*NL - 
        0.005508299885977424*NH + 0.003997199593990125*lm*NH - 
        0.0003870201727841308*lm^2*NH - 0.00075625*lm^3*NH)}, 
     {0.84, CF*NC*(CA*(0.018716097026653285 - 0.048605159898375244*lm + 
          0.00940560131855844*lm^2 + 0.003911111111111111*lm^3) + 
        CF*(0.00006719558820565775 + 0.011040731228453692*lm - 
          0.03042719784235892*lm^2 + 0.0064*lm^3) - 0.006040637294344045*
         NM + 0.0037644569964219565*lm*NM - 0.0003525335730712313*lm^2*
         NM - 0.0007111111111111111*lm^3*NM - 0.007793475415521981*NL + 
        0.0037644569964219565*lm*NL - 0.0003525335730712313*lm^2*NL - 
        0.0007111111111111111*lm^3*NL - 0.005216490127312189*NH + 
        0.0037644569964219565*lm*NH - 0.0003525335730712313*lm^2*NH - 
        0.0007111111111111111*lm^3*NH)}, 
     {0.845, CF*NC*(CA*(0.017804884452326843 - 0.04571853767912153*lm + 
          0.008768282944454147*lm^2 + 0.003670486111111111*lm^3) + 
        CF*(0.00002803366314731443 + 0.010649799048896581*lm - 
          0.02865119040907503*lm^2 + 0.00600625*lm^3) - 
        0.005677197176155213*NM + 0.003538142744127397*lm*NM - 
        0.0003201802323249966*lm^2*NM - 0.0006673611111111111*lm^3*NM - 
        0.0073335498430139095*NL + 0.003538142744127397*lm*NL - 
        0.0003201802323249966*lm^2*NL - 0.0006673611111111111*lm^3*NL - 
        0.004930070048416259*NH + 0.003538142744127397*lm*NH - 
        0.0003201802323249966*lm^2*NH - 0.0006673611111111111*lm^3*NH)}, 
     {0.85, CF*NC*(CA*(0.016899942506934267 - 0.04291254815932532*lm + 
          0.008156891249079845*lm^2 + 0.0034375*lm^3) + 
        CF*(-8.570462753225005*^-6 + 0.010244815000273725*lm - 
          0.026922246137869345*lm^2 + 0.005625*lm^3) - 0.005324492353098826*
         NM + 0.003318329662656143*lm*NM - 0.0002898893180145173*lm^2*NM - 
        0.000625*lm^3*NM - 0.006886336258873523*NL + 0.003318329662656143*
         lm*NL - 0.0002898893180145173*lm^2*NL - 0.000625*lm^3*NL - 
        0.004649290537885825*NH + 0.003318329662656143*lm*NH - 
        0.0002898893180145173*lm^2*NH - 0.000625*lm^3*NH)}, 
     {0.855, CF*NC*(CA*(0.016002716070982918 - 0.04018806995891165*lm + 
          0.007571038171165092*lm^2 + 0.0032121527777777777*lm^3) + 
        CF*(-0.00004243411369727138 + 0.009827372067340516*lm - 
          0.025241000038093486*lm^2 + 0.00525625*lm^3) - 
        0.004982577181787203*NM + 0.0031050877017832286*lm*NM - 
        0.0002615902735451682*lm^2*NM - 0.0005840277777777778*lm^3*NM - 
        0.006451960772272479*NL + 0.0031050877017832286*lm*NL - 
        0.0002615902735451682*lm^2*NL - 0.0005840277777777778*lm^3*NL - 
        0.004374400153991109*NH + 0.0031050877017832286*lm*NH - 
        0.0002615902735451682*lm^2*NH - 0.0005840277777777778*lm^3*NH)}, 
     {0.86, CF*NC*(CA*(0.015114656507044608 - 0.0375459641890651*lm + 
          0.007010337164258487*lm^2 + 0.0029944444444444445*lm^3) + 
        CF*(-0.00007340253131324148 + 0.009399080054907128*lm - 
          0.023608084640304294*lm^2 + 0.0049*lm^3) - 0.0046515060581852705*
         NM + 0.00289848397841296*lm*NM - 0.0002352128177439674*lm^2*NM - 
        0.0005444444444444444*lm^3*NM - 0.006030549512504318*NL + 
        0.00289848397841296*lm*NL - 0.0002352128177439674*lm^2*NL - 
        0.0005444444444444444*lm^3*NL - 0.004105645133306118*NH + 
        0.00289848397841296*lm*NH - 0.0002352128177439674*lm^2*NH - 
        0.0005444444444444444*lm^3*NH)}, 
     {0.865, CF*NC*(CA*(0.01423722128414281 - 0.03498707468831572*lm + 
          0.006474403193723011*lm^2 + 0.002784375*lm^3) + 
        CF*(-0.00010134882386069031 + 0.008961565224982088*lm - 
          0.022024130001180527*lm^2 + 0.00455625*lm^3) - 
        0.004331333381479184*NM + 0.002698582818808352*lm*NM - 
        0.00021068694431327465*lm^2*NM - 0.00050625*lm^3*NM - 
        0.0056222285877306575*NL + 0.002698582818808352*lm*NL - 
        0.00021068694431327465*lm^2*NL - 0.00050625*lm^3*NL - 
        0.0038432693994828755*NH + 0.002698582818808352*lm*NH - 
        0.00021068694431327465*lm^2*NH - 0.00050625*lm^3*NH)}, 
     {0.87, CF*NC*(CA*(0.013371873612334502 - 0.03251222825518811*lm + 
          0.005962852733564492*lm^2 + 0.0025819444444444444*lm^3) + 
        CF*(-0.00012617390901004412 + 0.00851646994084324*lm - 
          0.02048976370871265*lm^2 + 0.004225*lm^3) - 0.004022113519163626*
         NM + 0.0025054458001570455*lm*NM - 0.00018794292125415017*lm^2*
         NM - 0.0004694444444444444*lm^3*NM - 0.005227124045046332*NL + 
        0.0025054458001570455*lm*NL - 0.00018794292125415017*lm^2*NL - 
        0.0004694444444444444*lm^3*NL - 0.0035875145721627885*NH + 
        0.0025054458001570455*lm*NH - 0.00018794292125415017*lm^2*NH - 
        0.0004694444444444444*lm^3*NH)}, 
     {0.875, CF*NC*(CA*(0.012520082087219442 - 0.03012223487746404*lm + 
          0.005475303763100236*lm^2 + 0.002387152777777778*lm^3) + 
        CF*(-0.00014780645049595573 + 0.00806545231789853*lm - 
          0.01900561088765416*lm^2 + 0.00390625*lm^3) - 
        0.003723900773311259*NM + 0.002319131791484521*lm*NM - 
        0.0001669112902606489*lm^2*NM - 0.00043402777777777775*lm^3*NM - 
        0.004845361831825822*NL + 0.002319131791484521*lm*NL - 
        0.0001669112902606489*lm^2*NL - 0.00043402777777777775*lm^3*NL - 
        0.003338619976018037*NH + 0.002319131791484521*lm*NH - 
        0.0001669112902606489*lm^2*NH - 0.00043402777777777775*lm^3*NH)}, 
     {0.88, CF*NC*(CA*(0.011683320344116968 - 0.02781788795810867*lm + 
          0.005011375763474559*lm^2 + 0.0022*lm^3) + 
        CF*(-0.00016620278893085088 + 0.0076101858812018*lm - 
          0.017572294205223448*lm^2 + 0.0036*lm^3) - 0.0034367493479889183*
         NM + 0.002139696993925279*lm*NM - 0.0001475228660862834*lm^2*NM - 
        0.0004*lm^3*NM - 0.004477067758314377*NL + 0.002139696993925279*lm*
         NL - 0.0001475228660862834*lm^2*NL - 0.0004*lm^3*NL - 
        0.0030968226499161478*NH + 0.002139696993925279*lm*NH - 
        0.0001475228660862834*lm^2*NH - 0.0004*lm^3*NH)}, 
     {0.885, CF*NC*(CA*(0.0108630667216576 - 0.025599964537909876*lm + 
          0.004570689714027807*lm^2 + 0.002020486111111111*lm^3) + 
        CF*(-0.00018134686705431009 + 0.007152359229491681*lm - 
          0.016190433877045406*lm^2 + 0.00330625*lm^3) - 
        0.0031607133177861996*NM + 0.0019671949803624846*lm*NM - 
        0.00012970873588384366*lm^2*NM - 0.0003673611111111111*lm^3*NM - 
        0.0041223674614283305*NL + 0.0019671949803624846*lm*NL - 
        0.00012970873588384366*lm^2*NL - 0.0003673611111111111*lm^3*NL - 
        0.0028623573562011305*NH + 0.0019671949803624846*lm*NH - 
        0.00012970873588384366*lm^2*NH - 0.0003673611111111111*lm^3*NH)}, 
     {0.89, CF*NC*(CA*(0.010060803934543566 - 0.023469225514879493*lm + 
          0.004152868088525143*lm^2 + 0.0018486111111111112*lm^3) + 
        CF*(-0.00019325014968341972 + 0.006693675705624193*lm - 
          0.014860647673322494*lm^2 + 0.003025*lm^3) - 0.002895846597423138*
         NM + 0.0018016767344464267*lm*NM - 0.00011340025851972286*lm^2*
         NM - 0.00033611111111111114*lm^3*NM - 0.00378138636973015*NL + 
        0.0018016767344464267*lm*NL - 0.00011340025851972286*lm^2*NL - 
        0.00033611111111111114*lm^3*NL - 0.0026354565900847875*NH + 
        0.0018016767344464267*lm*NH - 0.00011340025851972286*lm^2*NH - 
        0.00033611111111111114*lm^3*NH)}, 
     {0.895, CF*NC*(CA*(0.009278018755239153 - 0.02142641586046477*lm + 
          0.003757534851251218*lm^2 + 0.001684375*lm^3) + 
        CF*(-0.0002019515386191118 + 0.0062358530732724675*lm - 
          0.01358355092522528*lm^2 + 0.00275625*lm^3) - 
        0.0026422029124046928*NM + 0.0016431906890019782*lm*NM - 
        0.00009852906386385776*lm^2*NM - 0.00030625*lm^3*NM - 
        0.00345424966954474*NL + 0.0016431906890019782*lm*NL - 
        0.00009852906386385776*lm^2*NL - 0.00030625*lm^3*NL - 
        0.002416350589142043*NH + 0.0016431906890019782*lm*NH - 
        0.00009852906386385776*lm^2*NH - 0.00030625*lm^3*NH)}, 
     {0.9, CF*NC*(CA*(0.008516201704358238 - 0.019472264832617735*lm + 
          0.0033843154529766173*lm^2 + 0.0015277777777777779*lm^3) + 
        CF*(-0.00020751728275377856 + 0.00578062319976953*lm - 
          0.012359756531492808*lm^2 + 0.0025*lm^3) - 0.002399835770690723*
         NM + 0.0014917827638350977*lm*NM - 0.00008502705205635464*lm^2*
         NM - 0.0002777777777777778*lm^3*NM - 0.00314108227218453*NL + 
        0.0014917827638350977*lm*NL - 0.00008502705205635464*lm^2*NL - 
        0.0002777777777777778*lm^3*NL - 0.0022052673429043324*NH + 
        0.0014917827638350977*lm*NH - 0.00008502705205635464*lm^2*NH - 
        0.0002777777777777778*lm^3*NH)}, 
     {0.905, CF*NC*(CA*(0.007776846749522739 - 0.017607486185769596*lm + 
          0.0030328368268017557*lm^2 + 0.0013788194444444444*lm^3) + 
        CF*(-0.00021004088361608066 + 0.005329731744972637*lm - 
          0.011189874965233491*lm^2 + 0.00225625*lm^3) - 
        0.0021687984353510764*NM + 0.0013474964029482504*lm*NM - 
        0.00007282639275183437*lm^2*NM - 0.00025069444444444445*lm^3*NM - 
        0.0028420087822517846*NL + 0.0013474964029482504*lm*NL - 
        0.00007282639275183437*lm^2*NL - 0.00025069444444444445*lm^3*NL - 
        0.002002432602545316*NH + 0.0013474964029482504*lm*NH - 
        0.00007282639275183437*lm^2*NH - 0.00025069444444444445*lm^3*NH)}, 
     {0.91, CF*NC*(CA*(0.00706145101247185 - 0.01583277837775669*lm + 
          0.0027027273838837245*lm^2 + 0.0012375*lm^3) + 
        CF*(-0.0002096429965798528 + 0.004884937856030176*lm - 
          0.01007451428091754*lm^2 + 0.002025*lm^3) - 0.0019491438981763499*
         NM + 0.0012103726111744766*lm*NM - 0.0000618595243424954*lm^2*
         NM - 0.000225*lm^3*NM - 0.0025571534669875185*NL + 
        0.0012103726111744766*lm*NL - 0.0000618595243424954*lm^2*NL - 
        0.000225*lm^3*NL - 0.0018080698906533731*NH + 
        0.0012103726111744766*lm*NH - 0.0000618595243424954*lm^2*NH - 
        0.000225*lm^3*NH)}, {0.915, 
      CF*NC*(CA*(0.006371514484207873 - 0.014148824773743874*lm + 
          0.0023936170090513866*lm^2 + 0.0011038194444444444*lm^3) + 
        CF*(-0.00020647132795533304 + 0.004448013867934559*lm - 
          0.009014280121552276*lm^2 + 0.00180625*lm^3) - 
        0.0017409248542157513*NM + 0.0010804499902396863*lm*NM - 
        0.00005205915316085821*lm^2*NM - 0.00020069444444444445*lm^3*NM - 
        0.002286640226637269*NL + 0.0010804499902396863*lm*NL - 
        0.00005205915316085821*lm^2*NL - 0.00020069444444444445*lm^3*NL - 
        0.001622400511085527*NH + 0.0010804499902396863*lm*NH - 
        0.00005205915316085821*lm^2*NH - 0.00020069444444444445*lm^3*NH)}, 
     {0.92, CF*NC*(CA*(0.005708539747970311 - 0.01255629384719074*lm + 
          0.002105137056313841*lm^2 + 0.0009777777777777777*lm^3) + 
        CF*(-0.0002007005281725901 + 0.004020745009746969*lm - 
          0.008009775726031896*lm^2 + 0.0016*lm^3) - 0.001544193677214356*
         NM + 0.0009577647742626045*lm*NM - 0.000043358252663122616*lm^2*
         NM - 0.00017777777777777779*lm^3*NM - 0.0020305925658048447*NL + 
        0.0009577647742626045*lm*NL - 0.000043358252663122616*lm^2*NL - 
        0.00017777777777777779*lm^3*NL - 0.0014456435588976388*NH + 
        0.0009577647742626045*lm*NH - 0.000043358252663122616*lm^2*NH - 
        0.00017777777777777779*lm^3*NH)}, 
     {0.925, CF*NC*(CA*(0.005074031709835462 - 0.011055839377905332*lm + 
          0.0018369203442672*lm^2 + 0.000859375*lm^3) + 
        CF*(-0.00019253208125898352 + 0.003604929116382127*lm - 
          0.007061601936653673*lm^2 + 0.00140625*lm^3) - 
        0.001359002395922889*NM + 0.000842350864701645*lm*NM - 
        0.00003569006259403635*lm^2*NM - 0.00015625*lm^3*NM - 
        0.0017891335657660094*NL + 0.000842350864701645*lm*NL - 
        0.00003569006259403635*lm^2*NL - 0.00015625*lm^3*NL - 
        0.0012780159303458943*NH + 0.000842350864701645*lm*NH - 
        0.00003569006259403635*lm^2*NH - 0.00015625*lm^3*NH)}, 
     {0.93, CF*NC*(CA*(0.004469497336744265 - 0.009648100647229532*lm + 
          0.0015886011514044541*lm^2 + 0.0007486111111111111*lm^3) + 
        CF*(-0.0001821941908047513 + 0.0032023763458435897*lm - 
          0.006170357206792712*lm^2 + 0.001225*lm^3) - 0.0011854026712539692*
         NM + 0.0007342398647578428*lm*NM - 0.00002898808813414317*lm^2*
         NM - 0.0001361111111111111*lm^3*NM - 0.001562385857714849*NL + 
        0.0007342398647578428*lm*NL - 0.00002898808813414317*lm^2*NL - 
        0.0001361111111111111*lm^3*NL - 0.00111973233295477*NH + 
        0.0007342398647578428*lm*NH - 0.00002898808813414317*lm^2*NH - 
        0.0001361111111111111*lm^3*NH)}, 
     {0.935, CF*NC*(CA*(0.0038964454017664453 - 0.008333702630399675*lm + 
          0.0013598152113330334*lm^2 + 0.0006454861111111111*lm^3) + 
        CF*(-0.00016994166260336994 + 0.0028149089018023026*lm - 
          0.0053366376087277635*lm^2 + 0.00105625*lm^3) - 
        0.0010234457742595222*NM + 0.0006334611132428295*lm*NM - 
        0.000023186099030248504*lm^2*NM - 0.0001173611111111111*lm^3*NM - 
        0.0013504715969163833*NL + 0.0006334611132428295*lm*NL - 
        0.000023186099030248504*lm^2*NL - 0.0001173611111111111*lm^3*NL - 
        0.0009710052956468486*NH + 0.0006334611132428295*lm*NH - 
        0.000023186099030248504*lm^2*NH - 0.0001173611111111111*lm^3*NH)}, 
     {0.94, CF*NC*(CA*(0.003356386236414165 - 0.007113256186125317*lm + 
          0.0011501997079045162*lm^2 + 0.00055*lm^3) + 
        CF*(-0.0001560557841461579 + 0.002444360761413369*lm - 
          0.0045610368416107916*lm^2 + 0.0009*lm^3) - 0.000873182564904849*
         NM + 0.0005400417179206901*lm*NM - 0.000018218128709912022*lm^2*
         NM - 0.0001*lm^3*NM - 0.0011535124377397164*NL + 
        0.0005400417179206901*lm*NL - 0.000018218128709912022*lm^2*NL - 
        0.0001*lm^3*NL - 0.0008320451789300054*NH + 0.0005400417179206901*
         lm*NH - 0.000018218128709912022*lm^2*NH - 0.0001*lm^3*NH)}, 
     {0.945, CF*NC*(CA*(0.002850831489823415 - 0.005987358243428513*lm + 
          0.0009593932702607833*lm^2 + 0.0004621527777777778*lm^3) + 
        CF*(-0.00014084420114368818 + 0.0020925774082681467*lm - 
          0.0038441462395732637*lm^2 + 0.00075625*lm^3) - 
        0.0007346634716155458*NM + 0.00045400658833240023*lm*NM - 
        0.00001401847338074848*lm^2*NM - 0.00008402777777777778*lm^3*NM - 
        0.000971629509546773*NL + 0.00045400658833240023*lm*NL - 
        0.00001401847338074848*lm^2*NL - 0.00008402777777777778*lm^3*NL - 
        0.0007030601851376519*NH + 0.00045400658833240023*lm*NH - 
        0.00001401847338074848*lm^2*NH - 0.00008402777777777778*lm^3*NH)}, 
     {0.95, CF*NC*(CA*(0.0023812938946262407 - 0.004956591985785433*lm + 
          0.0007870359678007699*lm^2 + 0.00038194444444444446*lm^3) + 
        CF*(-0.00012464079123992544 + 0.0017614155703808978*lm - 
          0.0031865547799623767*lm^2 + 0.000625*lm^3) - 
        0.0006079384715741992*NM + 0.00037537846811139616*lm*NM - 
        0.000010521691115291498*lm^2*NM - 0.00006944444444444444*lm^3*NM - 
        0.0008049433934123814*NL + 0.00037537846811139616*lm*NL - 
        0.000010521691115291498*lm^2*NL - 0.00006944444444444444*lm^3*NL - 
        0.0005842563687178743*NH + 0.00037537846811139616*lm*NH - 
        0.000010521691115291498*lm^2*NH - 0.00006944444444444444*lm^3*NH)}, 
     {0.955, CF*NC*(CA*(0.0019492870393416366 - 0.004021527032611432*lm + 
          0.0006327693050718184*lm^2 + 0.000309375*lm^3) + 
        CF*(-0.00010780553507860102 + 0.0014527429631112961*lm - 
          0.002588849091700661*lm^2 + 0.00050625*lm^3) - 
        0.000493057071744463*NM + 0.0003041779667986982*lm*NM - 
        7.662600922148807*^-6*lm^2*NM - 0.00005625*lm^3*NM - 
        0.00065357409965215*NL + 0.0003041779667986982*lm*NL - 
        7.662600922148807*^-6*lm^2*NL - 0.00005625*lm^3*NL - 
        0.0004758376465674497*NH + 0.0003041779667986982*lm*NH - 
        7.662600922148807*^-6*lm^2*NH - 0.00005625*lm^3*NH)}, 
     {0.96, CF*NC*(CA*(0.0015563251471175429 - 0.003182719618130244*lm + 
          0.0004962362165895053*lm^2 + 0.00024444444444444443*lm^3) + 
        CF*(-0.00009072438487517442 + 0.0011684380369261285*lm - 
          0.0020516134637626276*lm^2 + 0.0004*lm^3) - 0.00039006829060078853*
         NM + 0.00024042359116586235*lm*NM - 5.3762818041524805*^-6*lm^2*
         NM - 0.000044444444444444447*lm^3*NM - 0.0005176410461352668*NL + 
        0.00024042359116586235*lm*NL - 5.3762818041524805*^-6*lm^2*NL - 
        0.000044444444444444447*lm^3*NL - 0.0003780058084068682*NH + 
        0.00024042359116586235*lm*NH - 5.3762818041524805*^-6*lm^2*NH - 
        0.000044444444444444447*lm^3*NH)}, 
     {0.965, CF*NC*(CA*(0.0012039228606608443 - 0.0024407127676672876*lm + 
          0.0003770810615896751*lm^2 + 0.00018715277777777778*lm^3) + 
        CF*(-0.00007380913064179222 + 0.0009103897299055098*lm - 
          0.0015754298537623498*lm^2 + 0.00030625*lm^3) - 
        0.0002990206405427322*NM + 0.00018413177605390395*lm*NM - 
        3.5980718041833556*^-6*lm^2*NM - 0.000034027777777777775*lm^3*NM - 
        0.0003972630373599959*NL + 0.00018413177605390395*lm*NL - 
        3.5980718041833556*^-6*lm^2*NL - 0.000034027777777777775*lm^3*NL - 
        0.00029096052719262717*NH + 0.00018413177605390395*lm*NH - 
        3.5980718041833556*^-6*lm^2*NH - 0.000034027777777777775*lm^3*NH)}, 
     {0.97, CF*NC*(CA*(0.00089359503319661 - 0.001796036471406559*lm + 
          0.0002749496187162901*lm^2 + 0.0001375*lm^3) + 
        CF*(-0.000057497264206939166 + 0.0006804972249008818*lm - 
          0.0011608778966460708*lm^2 + 0.000225*lm^3) - 
        0.0002199621109733873*NM + 0.000135316914736202*lm*NM - 
        2.26356703932547*^-6*lm^2*NM - 0.000025*lm^3*NM - 
        0.00029255824427028266*NL + 0.000135316914736202*lm*NL - 
        2.26356703932547*^-6*lm^2*NL - 0.000025*lm^3*NL - 
        0.00021489936956319486*NH + 0.000135316914736202*lm*NH - 
        2.26356703932547*^-6*lm^2*NH - 0.000025*lm^3*NH)}, 
     {0.975, CF*NC*(CA*(0.0006268565253020459 - 0.0012492078556499853*lm + 
          0.00018948908064857686*lm^2 + 0.00009548611111111112*lm^3) + 
        CF*(-0.00004225184116597031 + 0.0004806697112539734*lm - 
          0.000808534913484147*lm^2 + 0.00015625*lm^3) - 
        0.00015294015202209555*NM + 0.00009399138881325858*lm*NM - 
        1.3086207239836701*^-6*lm^2*NM - 0.00001736111111111111*lm^3*NM - 
        0.00020364418479249059*NL + 0.00009399138881325858*lm*NL - 
        1.3086207239836701*^-6*lm^2*NL - 0.00001736111111111111*lm^3*NL - 
        0.0001500178063151735*NH + 0.00009399138881325858*lm*NH - 
        1.3086207239836701*^-6*lm^2*NH - 0.00001736111111111111*lm^3*NH)}, 
     {0.98, CF*NC*(CA*(0.0004052220074647153 - 0.0008007313516175595*lm + 
          0.00012034804867083286*lm^2 + 0.00006111111111111111*lm^3) + 
        CF*(-0.00002856134089341047 + 0.0003128261509877627*lm - 
          0.0005189759203568189*lm^2 + 0.0001*lm^3) - 0.00009800165889218257*
         NM + 0.00006016559764705854*lm*NM - 6.693421825756725*^-7*lm^2*
         NM - 0.000011111111111111112*lm^3*NM - 0.00013063770507189124*
         NL + 0.00006016559764705854*lm*NL - 6.693421825756725*^-7*lm^2*
         NL - 0.000011111111111111112*lm^3*NL - 0.0000965092229063129*NH + 
        0.00006016559764705854*lm*NH - 6.693421825756725*^-7*lm^2*NH - 
        0.000011111111111111112*lm^3*NH)}, 
     {0.985, CF*NC*(CA*(0.00023020576821858375 - 0.0004510988618260075*lm + 
          0.00006717652718813796*lm^2 + 0.000034375*lm^3) + 
        CF*(-0.000016939524742801062 + 0.0001788950493823142*lm - 
          0.0002927736373285015*lm^2 + 0.00005625*lm^3) - 
        0.00005519295681503255*NM + 0.000033847987342644915*lm*NM - 
        2.8209585238871915*^-7*lm^2*NM - 6.25*^-6*lm^3*NM - 
        0.00007365496138910313*NL + 0.000033847987342644915*lm*NL - 
        2.8209585238871915*^-7*lm^2*NL - 6.25*^-6*lm^3*NL - 
        0.00005456492998214964*NH + 0.000033847987342644915*lm*NH - 
        2.8209585238871915*^-7*lm^2*NH - 6.25*^-6*lm^3*NH)}, 
     {0.99, CF*NC*(CA*(0.00010332152771530674 - 0.00020078992408318916*lm + 
          0.00002962591819110457*lm^2 + 0.000015277777777777777*lm^3) + 
        CF*(-7.925292554955746*^-6 + 0.00008081422985014879*lm - 
          0.00013049849750546523*lm^2 + 0.000025*lm^3) - 
        0.00002455978659236999*NM + 0.000015045079284398375*lm*NM - 
        8.35002771705283*^-8*lm^2*NM - 2.777777777777778*^-6*lm^3*NM - 
        0.00003281140273723926*NL + 0.000015045079284398375*lm*NL - 
        8.35002771705283*^-8*lm^2*NL - 2.777777777777778*^-6*lm^3*NL - 
        0.00002437417392316149*NH + 0.000015045079284398375*lm*NH - 
        8.35002771705283*^-8*lm^2*NH - 2.777777777777778*^-6*lm^3*NH)}, 
     {0.995, CF*NC*(CA*(0.000026082256591951654 - 0.000050271873134874955*
           lm + 7.3490156726913885*^-6*lm^2 + 3.819444444444444*^-6*lm^3) + 
        CF*(-2.082537590749136*^-6 + 0.000020530613027559642*lm - 
          0.00003271865617195955*lm^2 + 6.25*^-6*lm^3) - 
        6.147290709152704*^-6*NM + 3.761498234383358*^-6*lm*NM - 
        1.0427092004494872*^-8*lm^2*NM - 6.944444444444445*^-7*lm^3*NM - 
        8.221754041065459*^-6*NL + 3.761498234383358*^-6*lm*NL - 
        1.0427092004494872*^-8*lm^2*NL - 6.944444444444445*^-7*lm^3*NL - 
        6.124147409440892*^-6*NH + 3.761498234383358*^-6*lm*NH - 
        1.0427092004494872*^-8*lm^2*NH - 6.944444444444445*^-7*lm^3*NH)}, 
     {1., 0.}}
 
CbarLTable["v", 2, 0] = {{0., -6.430041152263374*^-6*CF*NC*
       (2.*CA*(-2388.1522153911205 - 28035.755618875908*lm) + 
        15.*(-3103.0124357078876*CF + 
          4.*((-67.3596725935698 + 169.91367041742973*lm)*NM + 
            (-67.3596725935698 + 169.91367041742973*lm)*NL + 
            (-206.3135567749981 + 169.91367041742973*lm)*NH)))}, 
     {0.005, CF*NC*(0.27931741345026456*CF + CA*(0.015083731887545741 + 
          0.3509560685002628*lm) + 0.027784620629334792*NM - 
        0.06381019427277505*lm*NM + 0.02778146111558344*NL - 
        0.06381019427277505*lm*NL + 0.07841926150407559*NH - 
        0.06381019427277505*lm*NH)}, 
     {0.01, CF*NC*(0.26022661959768356*CF + CA*(-0.0001037408990463132 + 
          0.34146563951196546*lm) + 0.029512661376422115*NM - 
        0.06208466172944826*lm*NM + 0.029503701367234625*NL - 
        0.06208466172944826*lm*NL + 0.07724642349867773*NH - 
        0.06208466172944826*lm*NH)}, 
     {0.015, CF*NC*(0.24216226965082516*CF + CA*(-0.01470488294978726 + 
          0.33211303527109465*lm) + 0.03114803011019042*NM - 
        0.06038418823110812*lm*NM + 0.031133989708891197*NL - 
        0.06038418823110812*lm*NL + 0.07607917617036644*NH - 
        0.06038418823110812*lm*NH)}, 
     {0.02, CF*NC*(0.2251511566834125*CF + CA*(-0.028655916082525684 + 
          0.3229231343474215*lm) + 0.03268094682732246*NM - 
        0.05871329715407663*lm*NM + 0.0326645103346879*NL - 
        0.05871329715407663*lm*NL + 0.07491860950592591*NH - 
        0.05871329715407663*lm*NH)}, 
     {0.025, CF*NC*(0.20917795896275504*CF + CA*(-0.04192788609531017 + 
          0.3139121415311814*lm) + 0.03410746500951149*NM - 
        0.05707493482385116*lm*NM + 0.03409252132331541*NL - 
        0.05707493482385116*lm*NL + 0.07376561578742201*NH - 
        0.05707493482385116*lm*NH)}, 
     {0.03, CF*NC*(0.1942082331214658*CF + CA*(-0.0545110131462152 + 
          0.30509085765159344*lm) + 0.03542681283826301*NM - 
        0.055471065027562445*lm*NM + 0.035417971384607616*NL - 
        0.055471065027562445*lm*NL + 0.0726209437013112*NH - 
        0.055471065027562445*lm*NH)}, 
     {0.035, CF*NC*(0.18019834545765123*CF + CA*(-0.06640720975655091 + 
          0.29646638893950467*lm) + 0.03664012310016862*NM - 
        0.05390297980718267*lm*NM + 0.03664238485562213*NL - 
        0.05390297980718267*lm*NL + 0.0714852298577231*NH - 
        0.05390297980718267*lm*NH)}, 
     {0.04, CF*NC*(0.16710048537109817*CF + CA*(-0.07762590089282703 + 
          0.2880431780873665*lm) + 0.037749725055490756*NM - 
        0.05237148692497573*lm*NM + 0.037768251538985005*NL - 
        0.05237148692497573*lm*NL + 0.0703590196625396*NH - 
        0.05237148692497573*lm*NH)}, 
     {0.045, CF*NC*(0.15486541992570202*CF + CA*(-0.08818146484816011 + 
          0.27982368166248556*lm) + 0.038758712430815294*NM - 
        0.05087703302954283*lm*NM + 0.03879866084847648*NL - 
        0.05087703302954283*lm*NL + 0.06924278225355647*NH - 
        0.05087703302954283*lm*NH)}, 
     {0.05, CF*NC*(0.14344408062761463*CF + CA*(-0.09809156906185326 + 
          0.27180884142554396*lm) + 0.0396706639970728*NM - 
        0.04941978935009891*lm*NM + 0.03973706901483653*NL - 
        0.04941978935009891*lm*NL + 0.06813692176419518*NH - 
        0.04941978935009891*lm*NH)}, 
     {0.055, CF*NC*(0.1327884971971937*CF + CA*(-0.10737604138655388 + 
          0.26399842600247786*lm) + 0.04048945546856648*NM - 
        0.04799971381863234*lm*NM + 0.040587144825166316*NL - 
        0.04799971381863234*lm*NL + 0.0670417861450152*NH - 
        0.04799971381863234*lm*NH)}, 
     {0.06, CF*NC*(0.12285234560999722*CF + CA*(-0.11605608099452526 + 
          0.25639128629962604*lm) + 0.041219129307023504*NM - 
        0.04661659750902292*lm*NM + 0.041352664494202954*NL - 
        0.04661659750902292*lm*NL + 0.06595767427201281*NH - 
        0.04661659750902292*lm*NH)}, 
     {0.065, CF*NC*(0.11359125923127973*CF + CA*(-0.1241536944923974 + 
          0.24898555101476627*lm) + 0.04186380287638027*NM - 
        0.045270100184502955*lm*NM + 0.042037438655457206*NL - 
        0.045270100184502955*lm*NL + 0.06488484180244455*NH - 
        0.045270100184502955*lm*NH)}, 
     {0.07, CF*NC*(0.1049629904330494*CF + CA*(-0.13169128663467303 + 
          0.24177877911209616*lm) + 0.042427602868296437*NM - 
        0.043959778020381125*lm*NM + 0.04264526107908839*NL - 
        0.043959778020381125*lm*NL + 0.0638235060843943*NH - 
        0.043959778020381125*lm*NH)}, 
     {0.075, CF*NC*(0.09692747617253236*CF + CA*(-0.13869136013826738 + 
          0.234768080521304*lm) + 0.04291461820767137*NM - 
        0.042685105549327994*lm*NM + 0.04317987248682023*NL - 
        0.042685105549327994*lm*NL + 0.0627738503320127*NH - 
        0.042685105549327994*lm*NH)}, 
     {0.08, CF*NC*(0.08944684134220969*CF + CA*(-0.1451762942289953 + 
          0.22795021284021375*lm) + 0.043328866235214966*NM - 
        0.041445493243675226*lm*NM + 0.04364493508387607*NL - 
        0.041445493243675226*lm*NL + 0.06173602721807757*NH - 
        0.041445493243675226*lm*NH)}, 
     {0.085, CF*NC*(0.0824853618239899*CF + CA*(-0.15116818104774601 + 
          0.22132165957196995*lm) + 0.04367426859085059*NM - 
        0.04024030174035818*lm*NM + 0.044044014829143205*NL - 
        0.04024030174035818*lm*NL + 0.06071016199547354*NH - 
        0.04024030174035818*lm*NH)}, 
     {0.09, CF*NC*(0.07600940176477455*CF + CA*(-0.15668870521445077 + 
          0.21487869392556222*lm) + 0.0439546342800441*NM - 
        0.03906885344101131*lm*NM + 0.04438056936806543*NL - 
        0.03906885344101131*lm*NL + 0.05969635523170173*NH - 
        0.03906885344101131*lm*NH)}, 
     {0.095, CF*NC*(0.06998733483110027*CF + CA*(-0.16175905597599383 + 
          0.20861743117581386*lm) + 0.04417364811400297*NM - 
        0.03793044203196616*lm*NM + 0.044657940152278267*NL - 
        0.03793044203196616*lm*NL + 0.05869468522113502*NH - 
        0.03793044203196616*lm*NH)}, 
     {0.1, CF*NC*(0.06438945607376474*CF + CA*(-0.16639986419621186 + 
          0.20253387185130242*lm) + 0.0443348632014584*NM - 
        0.03682434033660044*lm*NM + 0.04487934767797072*NL - 
        0.03682434033660044*lm*NL + 0.057705210125714654*NH - 
        0.03682434033660044*lm*NH)}, 
     {0.105, CF*NC*(0.059187888938789214*CF + CA*(-0.1706311584318161 + 
          0.1966239374948082*lm) + 0.04444169651129322*NM - 
        0.03574980681723785*lm*NM + 0.04504788905865014*NL - 
        0.03574980681723785*lm*NL + 0.056727969884434626*NH - 
        0.03574980681723785*lm*NH)}, 
     {0.11, CF*NC*(0.05435649053492204*CF + CA*(-0.1744723357571712 + 
          0.1908835003565413*lm) + 0.04449742676947647*NM - 
        0.0347060909739166*lm*NM + 0.04516653734901614*NL - 
        0.0347060909739166*lm*NL + 0.05576298792417693*NH - 
        0.0347060909739166*lm*NH)}, 
     {0.115, CF*NC*(0.0498707572836732*CF + CA*(-0.17794214403221967 + 
          0.18530840809366064*lm) + 0.044505194131255664*NM - 
        0.033692437835211024*lm*NM + 0.04523814218147819*NL - 
        0.033692437835211024*lm*NL + 0.054810272698508626*NH - 
        0.033692437835211024*lm*NH)}, 
     {0.12, CF*NC*(0.04570773239119438*CF + CA*(-0.1810586730686211 + 
          0.1798945043324716*lm) + 0.04446800120044456*NM - 
        0.03270809169681302*lm*NM + 0.04526543138272337*NL - 
        0.03270809169681302*lm*NL + 0.053869819076432256*NH - 
        0.03270809169681302*lm*NH)}, 
     {0.125, CF*NC*(0.04184591609815537*CF + CA*(-0.18383935271783788 + 
          0.17463764578306834*lm) + 0.04438871506540662*NM - 
        0.03175229923328515*lm*NM + 0.045251013316138636*NL - 
        0.03175229923328515*lm*NL + 0.05294160959944687*NH - 
        0.03175229923328515*lm*NH)}, 
     {0.13, CF*NC*(0.038265179321729015*CF + CA*(-0.1863009563350013 + 
          0.16953371646677465*lm) + 0.04427007009518696*NM - 
        0.030824312084868116*lm*NM + 0.04519737975461216*NL - 
        0.030824312084868116*lm*NL + 0.052025615622383344*NH - 
        0.030824312084868116*lm*NH)}, 
     {0.135, CF*NC*(0.03494668106079365*CF + CA*(-0.18845960840115375 + 
          0.1645786395151315*lm) + 0.044114671295598665*NM - 
        0.02992338900275118*lm*NM + 0.04510690913266805*NL - 
        0.02992338900275118*lm*NL + 0.05112179835114731*NH - 
        0.02992338900275118*lm*NH)}, 
     {0.14, CF*NC*(0.03187278976267008*CF + CA*(-0.19033079534015002 + 
          0.15976838691861328*lm) + 0.043924998068454145*NM - 
        0.029048797621566053*lm*NM + 0.04498187006080871*NL - 
        0.029048797621566053*lm*NL + 0.05023010978860767*NH - 
        0.029048797621566053*lm*NH)}, 
     {0.145, CF*NC*(0.029027008727129912*CF + CA*(-0.19192937876393165 + 
          0.15509898753879778*lm) + 0.043703408250796494*NM - 
        0.02819981591614505*lm*NM + 0.044824425011042654*NL - 
        0.02819981591614505*lm*NL + 0.04935049359831226*NH - 
        0.02819981591614505*lm*NH)}, 
     {0.15, CF*NC*(0.026393905536995794*CF + CA*(-0.1932696105347145 + 
          0.1505665336457203*lm) + 0.0434521423372908*NM - 
        0.027375733390130965*lm*NM + 0.04463663410280474*NL - 
        0.027375733390130965*lm*NL + 0.048482885894423684*NH - 
        0.027375733390130965*lm*NH)}, 
     {0.155, CF*NC*(0.023959045444433554*CF + CA*(-0.19436514915488154 + 
          0.14616718619988808*lm) + 0.04317332780961463*NM - 
        0.02657585203634329*lm*NM + 0.04442045893424922*NL - 
        0.02657585203634329*lm*NL + 0.047627215965191774*NH - 
        0.02657585203634329*lm*NH)}, 
     {0.16, CF*NC*(0.021708928600869138*CF + CA*(-0.195229077092496 + 
          0.14189717906385169*lm) + 0.04286898351303131*NM - 
        0.02579948710251849*lm*NM + 0.04417776641626087*NL - 
        0.02579948710251849*lm*NL + 0.04678340693637534*NH - 
        0.02579948710251849*lm*NH)}, 
     {0.165, CF*NC*(0.01963093099118931*CF + CA*(-0.19587391872793694 + 
          0.13775282229975608*lm) + 0.042541024033306535*NM - 
        0.02504596769086474*lm*NM + 0.04391033257626627*NL - 
        0.02504596769086474*lm*NL + 0.045951376380258875*NH - 
        0.02504596769086474*lm*NH)}, 
     {0.17, CF*NC*(0.017713248915750015*CF + CA*(-0.1963116586694385 + 
          0.13373050468570763*lm) + 0.042191264037472274*NM - 
        0.024314637215583204*lm*NM + 0.0436198463066241*NL - 
        0.024314637215583204*lm*NL + 0.0451310368752581*NH - 
        0.024314637215583204*lm*NH)}, 
     {0.175, CF*NC*(0.01594484685397011*CF + CA*(-0.19655376023552482 + 
          0.1298266955641519*lm) + 0.041821422550213073*NM - 
        0.02360485373893671*lm*NM + 0.04330791303847585*NL - 
        0.02360485373893671*lm*NL + 0.04432229652054824*NH - 
        0.02360485373893671*lm*NH)}, 
     {0.18, CF*NC*(0.014315408538906886*CF + CA*(-0.19661118394296173 + 
          0.1260379461190191*lm) + 0.041433127144279665*NM - 
        0.022915990203458022*lm*NM + 0.04297605832678805*NL - 
        0.022915990203458022*lm*NL + 0.043525059409667284*NH - 
        0.022915990203458022*lm*NH)}, 
     {0.185, CF*NC*(0.012815291071696966*CF + CA*(-0.19649440587183134 + 
          0.122360890164574*lm) + 0.041027918028659814*NM - 
        0.02224743457537709*lm*NM + 0.04262573133617714*NL - 
        0.02224743457537709*lm*NL + 0.04273922606662887*NH - 
        0.02224743457537709*lm*NH)}, 
     {0.19, CF*NC*(0.011435481906991769*CF + CA*(-0.19621343580618453 + 
          0.11879224451723842*lm) + 0.040607252022517915*NM - 
        0.02159858991222517*lm*NM + 0.04225830822018263*NL - 
        0.02159858991222517*lm*NL + 0.04196469384771589*NH - 
        0.02159858991222517*lm*NH)}, 
     {0.195, CF*NC*(0.010167558544695652*CF + CA*(-0.1957778350706319 + 
          0.11532880901176462*lm) + 0.040172506406358964*NM - 
        0.020968874365775384*lm*NM + 0.04187509538910252*NL - 
        0.020968874365775384*lm*NL + 0.041201357311808594*NH - 
        0.020968874365775384*lm*NH)}, 
     {0.2, NC*(0.009003650768873562*CF^2 + CA*CF*(-0.1951967340011611 + 
          0.11196746621472206*lm) + 
        CF*((0.03972498264420397 - 0.020357721129949467*lm)*NM + 
          (0.0414773326634522 - 0.020357721129949467*lm)*NL + 
          (0.04044910856182185 - 0.020357721129949467*lm)*NH))}, 
     {0.205, NC*(0.007936405280730169*CF^2 + CA*CF*(-0.19447884900294968 + 
          0.10870518088107987*lm) + 
        CF*((0.03926590997528984 - 0.019764578342014522*lm)*NM + 
          (0.041066196311653425 - 0.019764578342014522*lm)*NL + 
          (0.03970783755958054 - 0.019764578342014522*lm)*NH))}, 
     {0.21, NC*(0.006958952580274284*CF^2 + CA*CF*(-0.1936324991603414 + 
          0.1055389991935159*lm) + 
        CF*((0.03879644886914378 - 0.01918890894427562*lm)*NM + 
          (0.04064280197178174 - 0.01918890894427562*lm)*NL + 
          (0.03897743241624483 - 0.01918890894427562*lm)*NH))}, 
     {0.215, NC*(0.006064875957247014*CF^2 + CA*CF*(-0.19266562237336704 + 
          0.10246604781880314*lm) + 
        CF*((0.038317694348733895 - 0.01863019051250966*lm)*NM + 
          (0.04020820745816109 - 0.01863019051250966*lm)*NL + 
          (0.03825777966020406 - 0.01863019051250966*lm)*NH))}, 
     {0.22, NC*(0.005248182460220958*CF^2 + CA*CF*(-0.19158579100375633 + 
          0.09948353281107693*lm) + 
        CF*((0.03783067917910773 - 0.018087915056559444*lm)*NM + 
          (0.03976341545434434 - 0.018087915056559444*lm)*NL + 
          (0.03754876448418613 - 0.018087915056559444*lm)*NH))}, 
     {0.225, NC*(0.004503275719384214*CF^2 + CA*CF*(-0.19040022701964132 + 
          0.09658873838786183*lm) + 
        CF*((0.03733637692436799 - 0.01756158879779306*lm)*NM + 
          (0.03930937609459695 - 0.01756158879779306*lm)*NL + 
          (0.03685027097317621 - 0.01756158879779306*lm)*NH))}, 
     {0.23, NC*(0.003824930505776088*CF^2 + CA*CF*(-0.189115816633588 + 
          0.09377902560134108*lm) + 
        CF*((0.03683570487513566 - 0.01705073192751656*lm)*NM + 
          (0.03884698943644189 - 0.01705073192751656*lm)*NL + 
          (0.03616218231460068 - 0.01705073192751656*lm)*NH))}, 
     {0.235, NC*(0.0032082689166438062*CF^2 + CA*CF*(-0.1877391244329512 + 
          0.09105183092440881*lm) + 
        CF*((0.03632952684945265 - 0.016554878349892513*lm)*NM + 
          (0.038377107827152375 - 0.016554878349892513*lm)*NL + 
          (0.035484380992109515 - 0.016554878349892513*lm)*NH))}, 
     {0.24, NC*(0.002648738083046721*CF^2 + CA*CF*(-0.1862764070049823 + 
          0.08840466476848782*lm) + 
        CF*((0.03581865587027669 - 0.016073575412452332*lm)*NM + 
          (0.037900538167316665 - 0.016073575412452332*lm)*NL + 
          (0.03481674896417865 - 0.016073575412452332*lm)*NH))}, 
     {0.245, NC*(0.0021420893023612634*CF^2 + CA*CF*(-0.18473362606203703 + 
          0.08583510994787107*lm) + 
        CF*((0.03530385672327715 - 0.015606383626885649*lm)*NM + 
          (0.03741804407476375 - 0.015606383626885649*lm)*NL + 
          (0.03415916782865409 - 0.015606383626885649*lm)*NH))}, 
     {0.25, NC*(0.0016843585042080145*CF^2 + CA*CF*(-0.18311646107440083 + 
          0.08334082010340652*lm) + 
        CF*((0.03478584839864053 - 0.01515287638243755*lm)*NM + 
          (0.03693034795224371 - 0.01515287638243755*lm)*NL + 
          (0.03351151897426864 - 0.01515287638243755*lm)*NH))}, 
     {0.255, NC*(0.001271847964120002*CF^2 + CA*CF*(-0.18143032142005885 + 
          0.08091951809665235*lm) + 
        CF*((0.03426530642083927 - 0.014712639653936791*lm)*NM + 
          (0.03643813296231403 - 0.014712639653936791*lm)*NL + 
          (0.032873683720080316 - 0.014712639653936791*lm)*NH))}, 
     {0.26, NC*(0.0009011091846559455*CF^2 + CA*CF*(-0.17968035806210364 + 
          0.07856899438415074*lm) + 
        CF*((0.033742865070369193 - 0.014285271706209225*lm)*NM + 
          (0.03594204491290208 - 0.014285271706209225*lm)*NL + 
          (0.03224554344370644 - 0.014285271706209225*lm)*NH))}, 
     {0.265, NC*(0.0005689268687552869*CF^2 + CA*CF*(-0.17787147476551643 + 
          0.07628710538017461*lm) + 
        CF*((0.033219119501500666 - 0.013870382796395384*lm)*NM + 
          (0.03544269405700247 - 0.013870382796395384*lm)*NL + 
          (0.03162697969916022 - 0.013870382796395384*lm)*NH))}, 
     {0.27, NC*(0.00027230391491176966*CF^2 + CA*CF*(-0.1760083388658225 + 
          0.07407177181516827*lm) + 
        CF*((0.03269462776007974 - 0.013467594875485142*lm)*NM + 
          (0.03494065680993252 - 0.013467594875485142*lm)*NL + 
          (0.031017874325034257 - 0.013467594875485142*lm)*NH))}, 
     {0.275, NC*(8.447368236426552*^-6*CF^2 + CA*CF*(-0.17409539160266052 + 
          0.07192097709610952*lm) + 
        CF*((0.032169912705396486 - 0.013076541290201731*lm)*NM + 
          (0.03443647738751389 - 0.013076541290201731*lm)*NL + 
          (0.030418109543719308 - 0.013076541290201731*lm)*NH))}, 
     {0.28, NC*(-0.00022524473434145734*CF^2 + 
        CA*CF*(-0.17213685803163814 + 0.06983276567414909*lm) + 
        CF*((0.031645463840066924 - 0.012696866486208925*lm)*NM + 
          (0.03393066936847925 - 0.012696866486208925*lm)*NL + 
          (0.02982756805229498 - 0.012696866486208925*lm)*NH))}, 
     {0.285, NC*(-0.0004311956825556679*CF^2 + 
        CA*CF*(-0.17013675652803634 + 0.06780524142411859*lm) + 
        CF*((0.03112173905181173 - 0.012328225713476106*lm)*NM + 
          (0.03342371718432202 - 0.012328225713476106*lm)*NL + 
          (0.029246133105681832 - 0.012328225713476106*lm)*NH))}, 
     {0.29, NC*(-0.000611661629116042*CF^2 + CA*CF*(-0.1680989078959795 + 
          0.06583656603982573*lm) + 
        CF*((0.030599166270918486 - 0.011970284734513769*lm)*NM + 
          (0.03291607753971792 - 0.011970284734513769*lm)*NL + 
          (0.028673688592600954 - 0.011970284734513769*lm)*NH))}, 
     {0.295, NC*(-0.0007687423944964897*CF^2 + 
        CA*CF*(-0.16602694409668023 + 0.06392495744846591*lm) + 
        CF*((0.030078145047079313 - 0.01162271953608471*lm)*NM + 
          (0.032408180766552164 - 0.01162271953608471*lm)*NL + 
          (0.028110119104847606 - 0.01162271953608471*lm)*NH))}, 
     {0.3, NC*(-0.0009044296188003005*CF^2 + CA*CF*(-0.16392429759365204 + 
          0.062068688246960206*lm) + 
        CF*((0.029559048049182378 - 0.011285216044901855*lm)*NM + 
          (0.031900432114486524 - 0.011285216044901855*lm)*NL + 
          (0.02755531000034867 - 0.011285216044901855*lm)*NH))}, 
     {0.305, NC*(-0.0010204572727417938*CF^2 + 
        CA*CF*(-0.1617942888443679 + 0.060266084162574354*lm) + 
        CF*((0.029042222491527245 - 0.010957469847740792*lm)*NM + 
          (0.031393212980898935 - 0.010957469847740792*lm)*NL + 
          (0.027009147460440332 - 0.010957469847740792*lm)*NH))}, 
     {0.31, NC*(-0.0011185598144939973*CF^2 + CA*CF*(-0.1596400093288342 + 
          0.05851552253977278*lm) + 
        CF*((0.028527991489811777 - 0.010639185916322324*lm)*NM + 
          (0.030886882082924994 - 0.010639185916322324*lm)*NL + 
          (0.026471518541771256 - 0.010639185916322324*lm)*NH))}, 
     {0.315, NC*(-0.0012003064129693076*CF^2 + 
        CA*CF*(-0.157464415937039 + 0.056815430854910254*lm) + 
        CF*((0.0280166553501211 - 0.01033007833725641*lm)*NM + 
          (0.03038177657422744 - 0.01033007833725641*lm)*NL + 
          (0.02594231122320803 - 0.01033007833725641*lm)*NH))}, 
     {0.32, NC*(-0.0012671544550744156*CF^2 + CA*CF*(-0.15527031513719733 + 
          0.05516428526005485*lm) + 
        CF*((0.02750849279402699 - 0.0100298700472827*lm)*NM + 
          (0.02987821310901683 - 0.0100298700472827*lm)*NL + 
          (0.025421414448093375 - 0.0100298700472827*lm)*NH))}, 
     {0.325, NC*(-0.0013204568311360112*CF^2 + 
        CA*CF*(-0.15306036970689677 + 0.05356060915696524*lm) + 
        CF*((0.027003762122786282 - 0.00973829257399368*lm)*NM + 
          (0.029376488855745175 - 0.00973829257399368*lm)*NL + 
          (0.02490871816218311 - 0.00973829257399368*lm)*NH))}, 
     {0.33, NC*(-0.0013614687590733868*CF^2 + CA*CF*(-0.1508371051746222 + 
          0.052002971802007844*lm) + 
        CF*((0.026502702323506867 - 0.009455085782183245*lm)*NM + 
          (0.028876882462794306 - 0.009455085782183245*lm)*NL + 
          (0.02440411334756549 - 0.009455085782183245*lm)*NH))}, 
     {0.335, NC*(-0.0013913541766203653*CF^2 + 
        CA*CF*(-0.1486029159833992 + 0.05048998694259166*lm) + 
        CF*((0.026005534120031388 - 0.009179997625925756*lm)*NM + 
          (0.028379654978383257 - 0.009179997625925756*lm)*NL + 
          (0.023907492052845612 - 0.009179997625925756*lm)*NH))}, 
     {0.34, NC*(-0.0014111917290036949*CF^2 + CA*CF*(-0.14636007138792537 + 
          0.0490203114855167*lm) + 
        CF*((0.025512460971172705 - 0.008912783906457581*lm)*NM + 
          (0.027885050726823596 - 0.008912783906457581*lm)*NL + 
          (0.023418747419858128 - 0.008912783906457581*lm)*NH))}, 
     {0.345, NC*(-0.0014219803777179752*CF^2 + 
        CA*CF*(-0.14411072109618284 + 0.047592644197473596*lm) + 
        CF*((0.025023670018825807 - 0.00865320803590429*lm)*NM + 
          (0.027393298143159214 - 0.00865320803590429*lm)*NL + 
          (0.02293777370715413 - 0.00865320803590429*lm)*NH))}, 
     {0.35, NC*(-0.0014246446543767488*CF^2 + CA*CF*(-0.14185690066615148 + 
          0.046205724437793555*lm) + 
        CF*((0.024539332988367475 - 0.008401040806871556*lm)*NM + 
          (0.02690461056813742 - 0.008401040806871556*lm)*NL + 
          (0.022464466310490636 - 0.008401040806871556*lm)*NH))}, 
     {0.355, NC*(-0.0014200395820755005*CF^2 + 
        CA*CF*(-0.13960053666786718 + 0.044858330923427905*lm) + 
        CF*((0.024059607043644404 - 0.008156060167895983*lm)*NM + 
          (0.026419187005371433 - 0.008156060167895983*lm)*NL + 
          (0.02199872178053656 - 0.008156060167895983*lm)*NH))}, 
     {0.36, NC*(-0.0014089552852606527*CF^2 + CA*CF*(-0.1373434516206963 + 
          0.043549280526032505*lm) + 
        CF*((0.023584635598753567 - 0.007918051004733183*lm)*NM + 
          (0.025937212842470782 - 0.007918051004733183*lm)*NL + 
          (0.02154043783799394 - 0.007918051004733183*lm)*NH))}, 
     {0.365, NC*(-0.001392121307756688*CF^2 + CA*CF*(-0.13508736871532753 + 
          0.042277427100942205*lm) + 
        CF*((0.02311454908872641 - 0.007686804927444038*lm)*NM + 
          (0.025458860537835613 - 0.007686804927444038*lm)*NL + 
          (0.02108951338632067 - 0.007686804927444038*lm)*NH))}, 
     {0.37, NC*(-0.0013702106573152473*CF^2 + CA*CF*(-0.13283391632963573 + 
          0.041041660347743675*lm) + 
        CF*((0.022649465701093312 - 0.007462120063226123*lm)*NM + 
          (0.024984290274733183 - 0.007462120063226123*lm)*NL + 
          (0.020645848522227776 - 0.007462120063226123*lm)*NH))}, 
     {0.375, NC*(-0.0013438435939235934*CF^2 + 
        CA*CF*(-0.13058463234719364 + 0.03984090470208835*lm) + 
        CF*((0.022189492070282875 - 0.007243800854925155*lm)*NM + 
          (0.0245136505842007 - 0.007243800854925155*lm)*NL + 
          (0.020209344544113484 - 0.007243800854925155*lm)*NH))}, 
     {0.38, NC*(-0.001313591177951602*CF^2 + CA*CF*(-0.1283409682868916 + 
          0.03867411825833129*lm) + 
        CF*((0.021734723936639305 - 0.007031657865151143*lm)*NM + 
          (0.024047078938246917 - 0.007031657865151143*lm)*NL + 
          (0.019779903958585175 - 0.007031657865151143*lm)*NH))}, 
     {0.385, NC*(-0.0012799785932328122*CF^2 + 
        CA*CF*(-0.1261042932517672 + 0.03754029172253403*lm) + 
        CF*((0.021285246771818214 - 0.006825507585915278*lm)*NM + 
          (0.023584702314756716 - 0.006825507585915278*lm)*NL + 
          (0.019357430485210363 - 0.006825507585915278*lm)*NH))}, 
     {0.39, NC*(-0.0012434882591923048*CF^2 + CA*CF*(-0.12387589770483114 + 
          0.03643844739532982*lm) + 
        CF*((0.02084113637220757 - 0.006625172253696331*lm)*NM + 
          (0.02312663773543719 - 0.006625172253696331*lm)*NL + 
          (0.018941829059628806 - 0.006625172253696331*lm)*NH))}, 
     {0.395, NC*(-0.0012045627452442849*CF^2 + 
        CA*CF*(-0.12165699707935441 + 0.03536763818411638*lm) + 
        CF*((0.02040245942195374 - 0.006430479669839341*lm)*NM + 
          (0.022672992778081023 - 0.006430479669839341*lm)*NL + 
          (0.018533005835148678 - 0.006430479669839341*lm)*NH))}, 
     {0.4, NC*(-0.00116360749983861*CF^2 + CA*CF*(-0.11944873523077773 + 
          0.03432694664401465*lm) + 
        CF*((0.019969274027089957 - 0.006241263026184482*lm)*NM + 
          (0.022223866064363124 - 0.006241263026184482*lm)*NL + 
          (0.01813086818294213 - 0.006241263026184482*lm)*NH))}, 
     {0.405, NC*(-0.0011209934057544466*CF^2 + 
        CA*CF*(-0.11725218773710458 + 0.03331548404701018*lm) + 
        CF*((0.019541630222199517 - 0.006057360735820033*lm)*NM + 
          (0.02177934772432893 - 0.006057360735820033*lm)*NL + 
          (0.017735324690947962 - 0.006057360735820033*lm)*NH))}, 
     {0.41, NC*(-0.0010770591725030518*CF^2 + CA*CF*(-0.11506836505435461 + 
          0.03233238947867688*lm) + 
        CF*((0.019119570450971655 - 0.005878616268850341*lm)*NM + 
          (0.02133951983867828 - 0.005878616268850341*lm)*NL + 
          (0.017346285161581175 - 0.005878616268850341*lm)*NH))}, 
     {0.415, NC*(-0.0010321135760158744*CF^2 + 
        CA*CF*(-0.11289821553337685 + 0.0313768289618701*lm) + 
        CF*((0.018703130021944483 - 0.005704877993067291*lm)*NM + 
          (0.0209044568598963 - 0.005704877993067291*lm)*NL + 
          (0.016963660608344432 - 0.005704877993067291*lm)*NH))}, 
     {0.42, NC*(-0.0009864375551556187*CF^2 + CA*CF*(-0.1107426283040543 + 
          0.030447994606766882*lm) + 
        CF*((0.018292337540670556 - 0.005535999019412161*lm)*NM + 
          (0.02047422601323305 - 0.005535999019412161*lm)*NL + 
          (0.016587363251428094 - 0.005535999019412161*lm)*NH))}, 
     {0.425, NC*(-0.0009402861739785083*CF^2 + 
        CA*CF*(-0.10860243603267944 + 0.02954510378662509*lm) + 
        CF*((0.017887215319464352 - 0.005371837052113653*lm)*NM + 
          (0.020048887678485987 - 0.005371837052113653*lm)*NL + 
          (0.016217306512381492 - 0.005371837052113653*lm)*NH))}, 
     {0.43, NC*(-0.0008938904581291354*CF^2 + CA*CF*(-0.10647841755802605 + 
          0.028667398338630235*lm) + 
        CF*((0.017487779765867264 - 0.005212254243387315*lm)*NM + 
          (0.01962849575349391 - 0.005212254243387315*lm)*NL + 
          (0.015853405007931816 - 0.005212254243387315*lm)*NH))}, 
     {0.435, NC*(-0.0008474591132090817*CF^2 + 
        CA*CF*(-0.10437130041141264 + 0.027814143789197866*lm) + 
        CF*((0.01709404175086639 - 0.00505711705258143*lm)*NM + 
          (0.019213098000208033 - 0.00505711705258143*lm)*NL + 
          (0.015495574543022616 - 0.00505711705258143*lm)*NH))}, 
     {0.44, NC*(-0.0008011801324776872*CF^2 + CA*CF*(-0.10228176322582061 + 
          0.026984628603100986*lm) + 
        CF*((0.0167060069578926 - 0.004906296109654725*lm)*NM + 
          (0.018802736374164297 - 0.004906296109654725*lm)*NL + 
          (0.015143732103137308 - 0.004906296109654725*lm)*NH))}, 
     {0.445, NC*(-0.0007552223007797253*CF^2 + 
        CA*CF*(-0.10021043803891314 + 0.026178163455795125*lm) + 
        CF*((0.016323676213547002 - 0.004759666082871841*lm)*NM + 
          (0.018397447338142033 - 0.004759666082871841*lm)*NL + 
          (0.014797795845972933 - 0.004759666082871841*lm)*NH))}, 
     {0.45, NC*(-0.0007097366011655067*CF^2 + CA*CF*(-0.09815791249458984 + 
          0.025394080528318718*lm) + 
        CF*((0.015947045800975074 - 0.004617105550603403*lm)*NM + 
          (0.01799726216075651 - 0.004617105550603403*lm)*NL + 
          (0.014457685092519547 - 0.004617105550603403*lm)*NH))}, 
     {0.455, NC*(-0.0006648575302650706*CF^2 + 
        CA*CF*(-0.0961247319475115 + 0.024631732824152607*lm) + 
        CF*((0.015576107756740731 - 0.004478496877118656*lm)*NM + 
          (0.017602207200697363 - 0.004478496877118656*lm)*NL + 
          (0.014123320317601717 - 0.004478496877118656*lm)*NH))}, 
     {0.46, NC*(-0.0006207043280990361*CF^2 + CA*CF*(-0.09411140147483657 + 
          0.023890493507430065*lm) + 
        CF*((0.015210850152046644 - 0.004343726092260011*lm)*NM + 
          (0.017212304177290933 - 0.004343726092260011*lm)*NL + 
          (0.01379462313993225 - 0.004343726092260011*lm)*NH))}, 
     {0.465, NC*(-0.0005773821276575932*CF^2 + 
        CA*CF*(-0.09211838779922493 + 0.02316975526189711*lm) + 
        CF*((0.014851257359061943 - 0.004212682774890383*lm)*NM + 
          (0.016827570428032165 - 0.004212682774890383*lm)*NL + 
          (0.013471516311725901 - 0.004212682774890383*lm)*NH))}, 
     {0.47, NC*(-0.0005349830292469106*CF^2 + CA*CF*(-0.09014612112698789 + 
          0.022468929670032344*lm) + 
        CF*((0.014497310303115216 - 0.004085259940005881*lm)*NM + 
          (0.01644801915370108 - 0.004085259940005881*lm)*NL + 
          (0.01315392370791681 - 0.004085259940005881*lm)*NH))}, 
     {0.475, NC*(-0.0004935871042903893*CF^2 + 
        CA*CF*(-0.08819499690509423 + 0.021787446611745545*lm) + 
        CF*((0.014148986701456982 - 0.003961353929408281*lm)*NM + 
          (0.01607365965164941 - 0.003961353929408281*lm)*NL + 
          (0.012841770315022965 - 0.003961353929408281*lm)*NH))}, 
     {0.48, NC*(-0.00045326333298495637*CF^2 + 
        CA*CF*(-0.08626537750057804 + 0.021124753682084864*lm) + 
        CF*((0.013806261289264304 - 0.0038408643058336113*lm)*NM + 
          (0.015704497537815193 - 0.0038408643058336113*lm)*NL + 
          (0.012534982219692984 - 0.0038408643058336113*lm)*NH))}, 
     {0.485, NC*(-0.00041407047993636165*CF^2 + 
        CA*CF*(-0.08435759380574061 + 0.020480315627393744*lm) + 
        CF*((0.01346910603352743 - 0.0037236937504352263*lm)*NM + 
          (0.015340534957996518 - 0.0037236937504352263*lm)*NL + 
          (0.012233486596974779 - 0.0037236937504352263*lm)*NH))}, 
     {0.49, NC*(-0.00037605791164587555*CF^2 + 
        CA*CF*(-0.08247194677238776 + 0.0198536137993701*lm) + 
        CF*((0.013137490335427214 - 0.0036097479635218365*lm)*NM + 
          (0.014981770788890358 - 0.0036097479635218365*lm)*NL + 
          (0.01193721169833702 - 0.0036097479635218365*lm)*NH))}, 
     {0.495, NC*(-0.0003392663594789569*CF^2 + 
        CA*CF*(-0.08060870887820326 + 0.019244145626492157*lm) + 
        CF*((0.012811381221780674 - 0.003498935568453119*lm)*NM + 
          (0.014628200829378404 - 0.003498935568453119*lm)*NL + 
          (0.011646086839476261 - 0.003498935568453119*lm)*NH))}, 
     {0.5, CF*NC*(-0.000303728787589343*CF + CA*(-0.07876812542388131 + 
          0.018651424171499346*lm) + 0.012490743510599974*NM - 
        0.003391168031181699*lm*NM + 0.01427981797351787*NL - 
        0.003391168031181699*lm*NL + 0.011360042390170737*NH - 
        0.003391168031181699*lm*NH)}, 
     {0.505, CF*NC*(-0.00026947039857941406*CF + 
        CA*(-0.07695041631301688 + 0.01807497734389701*lm) + 
        0.012175540047758617*NM - 0.0032863595170721837*lm*NM + 
        0.013936612421687356*NL - 0.0032863595170721837*lm*NL + 
        0.01107900975232211*NH - 0.0032863595170721837*lm*NH)}, 
     {0.51, CF*NC*(-0.0002365102981816969*CF + 
        CA*(-0.07515577663176991 + 0.017514347884666243*lm) + 
        0.011865731764719821*NM - 0.003184426888121135*lm*NM + 
        0.013598571784820443*NL - 0.003184426888121135*lm*NL + 
        0.010802921362256183*NH - 0.003184426888121135*lm*NH)}, 
     {0.515, CF*NC*(-0.00020486133002153734*CF + 
        CA*(-0.0733843783698614 + 0.01696909257225755*lm) + 
        0.01156127790548773*NM - 0.0030852895585922815*lm*NM + 
        0.013265681284041767*NL - 0.0030852895585922815*lm*NL + 
        0.01053171066730966*NH - 0.0030852895585922815*lm*NH)}, 
     {0.52, CF*NC*(-0.0001745308121324456*CF + 
        CA*(-0.07163637145587583 + 0.01643878186177249*lm) + 
        0.011262136151227054*NM - 0.0029888694294131803*lm*NM + 
        0.012937923888100068*NL - 0.0029888694294131803*lm*NL + 
        0.010265312115814957*NH - 0.0029888694294131803*lm*NH)}, 
     {0.525, CF*NC*(-0.00014552103740722686*CF + 
        CA*(-0.06991188487436473 + 0.015922999449999604*lm) + 
        0.01096826275675561*NM - 0.002895090809090837*lm*NM + 
        0.012615280455051659*NL - 0.002895090809090837*lm*NL + 
        0.010003661144162857*NH - 0.002895090809090837*lm*NH)}, 
     {0.53, CF*NC*(-0.00011782973941190451*CF + 
        CA*(-0.06821102773328076 + 0.01542134185441572*lm) + 
        0.010679612679423404*NM - 0.0028038803371664947*lm*NM + 
        0.012297729866980635*NL - 0.0028038803371664947*lm*NL + 
        0.009746694163816369*NH - 0.0028038803371664947*lm*NH)}, 
     {0.535, CF*NC*(-0.00009145052574519487*CF + 
        CA*(-0.06653389028390655 + 0.014933418005714297*lm) + 
        0.010396139700763595*NM - 0.0027151669101298723*lm*NM + 
        0.011985249158082774*NL - 0.0027151669101298723*lm*NL + 
        0.00949434854829321*NH - 0.0027151669101298723*lm*NH)}, 
     {0.54, CF*NC*(-0.00006637328099247718*CF + 
        CA*(-0.0648805448953483 + 0.014458848853434646*lm) + 
        0.010117796541281473*NM - 0.00262888160971539*lm*NM + 
        0.011677813636424663*NL - 0.00262888160971539*lm*NL + 
        0.009246562620133106*NH - 0.00262888160971539*lm*NH)}, 
     {0.545, CF*NC*(-0.00004258454119761992*CF + 
        CA*(-0.0632510469855725 + 0.013997266984277877*lm) + 
        0.009844534968729493*NM - 0.0025449576335050688*lm*NM + 
        0.011375396999674858*NL - 0.0025449576335050688*lm*NL + 
        0.009003275637864848*NH - 0.0025449576335050688*lm*NH)}, 
     {0.55, CF*NC*(-0.000020067841658156174*CF + 
        CA*(-0.06164543591087771 + 0.01354831625270726*lm) + 
        0.009576305900199124*NM - 0.0024633302277649563*lm*NM + 
        0.011077971445089927*NL - 0.0024633302277649563*lm*NL + 
        0.008764427782986963*NH - 0.0024633302277649563*lm*NH)}, 
     {0.555, CF*NC*(1.1959602613338655*^-6*CF + 
        CA*(-0.060063735815609254 + 0.013111651423442292*lm) + 
        0.009313059498343896*NM - 0.002383936622444053*lm*NM + 
        0.010785507774024875*NL - 0.002383936622444053*lm*NL + 
        0.008529960146974817*NH - 0.002383936622444053*lm*NH)}, 
     {0.56, CF*NC*(0.000021228385706627567*CF + 
        CA*(-0.05850595644384644 + 0.012686937825467186*lm) + 
        0.009054745262032454*NM - 0.002306715968266761*lm*NM + 
        0.010497975491224793*NL - 0.002306715968266761*lm*NL + 
        0.00829981471832591*NH - 0.002306715968266761*lm*NH)}, 
     {0.565, CF*NC*(0.000040053056808539905*CF + 
        CA*(-0.05697209391471509 + 0.012273851017185674*lm) + 
        0.008801312111715606*NM - 0.0022316092758519405*lm*NM + 
        0.010215342899142511*NL - 0.0022316092758519405*lm*NL + 
        0.008073934369654322*NH - 0.0022316092758519405*lm*NH)}, 
     {0.57, CF*NC*(0.00005769543965289706*CF + 
        CA*(-0.055462131462906294 + 0.011872076462364956*lm) + 
        0.008552708469777306*NM - 0.0021585593567936285*lm*NM + 
        0.009937577187515546*NL - 0.0021585593567936285*lm*NL + 
        0.007852262844844278*NH - 0.0021585593567936285*lm*NH)}, 
     {0.575, CF*NC*(0.00007418260642975913*CF + 
        CA*(-0.05397604014591264 + 0.011481309216522396*lm) + 
        0.008308882336126163*NM - 0.0020875107666404355*lm*NM + 
        0.00966464451842466*NL - 0.0020875107666404355*lm*NL + 
        0.007634744746272077*NH - 0.0020875107666404355*lm*NH)}, 
     {0.58, CF*NC*(0.000089543015526539*CF + CA*(-0.05251377951942728 + 
          0.011101253623418962*lm) + 0.008069781359271274*NM - 
        0.0020184097497125387*lm*NM + 0.009396510107046015*NL - 
        0.0020184097497125387*lm*NL + 0.007421325522104831*NH - 
        0.0020184097497125387*lm*NH)}, 
     {0.585, CF*NC*(0.0001038063084054352*CF + 
        CA*(-0.05107529828228786 + 0.01073162302133374*lm) + 
        0.007835352903114228*NM - 0.0019512041856970437*lm*NM + 
        0.009133138298298878*NL - 0.0019512041856970437*lm*NL + 
        0.007211951453683757*NH - 0.0019512041856970437*lm*NH)}, 
     {0.59, CF*NC*(0.0001170031221767503*CF + CA*(-0.04966053489228687 + 
          0.01037213945880377*lm) + 0.007605544109677558*NM - 
        0.0018858435379643216*lm*NM + 0.008874492639581523*NL - 
        0.0018858435379643216*lm*NL + 0.0070065696429990965*NH - 
        0.0018858435379643216*lm*NH)}, 
     {0.595, CF*NC*(0.00012916491684649025*CF + 
        CA*(-0.048269418154112426 + 0.010022533419523236*lm) + 
        0.007380301957979045*NM - 0.0018222788035496791*lm*NM + 
        0.008620535949778853*NL - 0.0018222788035496791*lm*NL + 
        0.0068051280002631226*NH - 0.0018222788035496791*lm*NH)}, 
     {0.6, CF*NC*(0.00014032381627939776*CF + CA*(-0.04690186778062811 + 
          0.009682543556105535*lm) + 0.007159573319250885*NM - 
        0.0017604624647464607*lm*NM + 0.008371230384716802*NL - 
        0.0017604624647464607*lm*NL + 0.006607575231587089*NH - 
        0.0017604624647464607*lm*NH)}, 
     {0.605, CF*NC*(0.0001505124619775183*CF + 
        CA*(-0.04555779492864804 + 0.009351916432421002*lm) + 
        0.006943305008692942*NM - 0.001700348442258364*lm*NM + 
        0.008126537499230353*NL - 0.001700348442258364*lm*NL + 
        0.006413860826767459*NH - 0.001700348442258364*lm*NH)}, 
     {0.61, CF*NC*(0.0001597638788297632*CF + CA*(-0.0442371027103128 + 
          0.009030406274232081*lm) + 0.006731443833939832*NM - 
        0.0016418920498603785*lm*NM + 0.007886418306004289*NL - 
        0.0016418920498603785*lm*NL + 0.006223935047186199*NH - 
        0.0016418920498603785*lm*NH)}, 
     {0.615, CF*NC*(0.00016811135203993873*CF + 
        CA*(-0.042939686681123745 + 0.008717774727856502*lm) + 
        0.006523936640412792*NM - 0.001585049950519364*lm*NM + 
        0.007650833331338353*NL - 0.001585049950519364*lm*NL + 
        0.006037748913829502*NH - 0.001585049950519364*lm*NH)}, 
     {0.62, CF*NC*(0.00017558831448956467*CF + 
        CA*(-0.04166543530564738 + 0.008413790626597556*lm) + 
        0.006320730353718724*NM - 0.0015297801139268284*lm*NM + 
        0.007419742667981467*NL - 0.0015297801139268284*lm*NL + 
        0.00585525419542878*NH - 0.0015297801139268284*lm*NH)}, 
     {0.625, CF*NC*(0.00018222824383769528*CF + 
        CA*(-0.0404142304018573 + 0.008118229764688855*lm) + 
        0.006121772019250838*NM - 0.0014760417753979735*lm*NM + 
        0.007193106025172937*NL - 0.0014760417753979735*lm*NL + 
        0.0056764033967274235*NH - 0.0014760417753979735*lm*NH)}, 
     {0.63, CF*NC*(0.00018806456870306968*CF + 
        CA*(-0.03918594756503934 + 0.007830874678508997*lm) + 
        0.00592700883913761*NM - 0.0014237953960925449*lm*NM + 
        0.006970882776022163*NL - 0.0014237953960925449*lm*NL + 
        0.005501149746876393*NH - 0.0014237953960925449*lm*NH)}, 
     {0.635, CF*NC*(0.00019313058331442017*CF + 
        CA*(-0.03798045657214547 + 0.00755151443482944*lm) + 
        0.005736388206679515*NM - 0.0013730026245144438*lm*NM + 
        0.006753032002352292*NL - 0.0013730026245144438*lm*NL + 
        0.005329447187961329*NH - 0.0013730026245144438*lm*NH)}, 
     {0.64, CF*NC*(0.00019745937005281885*CF + 
        CA*(-0.03679762176744338 + 0.007279944425866415*lm) + 
        0.005549857738406099*NM - 0.0013236262592484392*lm*NM + 
        0.006539512537127428*NL - 0.0013236262592484392*lm*NL + 
        0.005161250363663579*NH - 0.0013236262592484392*lm*NH)}, 
     {0.645, CF*NC*(0.0002010837293456938*CF + 
        CA*(-0.03563730243027222 + 0.007015966170915154*lm) + 
        0.005367365303879347*NM - 0.0012756302128936643*lm*NM + 
        0.006330283004577484*NL - 0.0012756302128936643*lm*NL + 
        0.0049965146080571616*NH - 0.0012756302128936643*lm*NH)}, 
     {0.65, CF*NC*(0.00020403611640573336*CF + 
        CA*(-0.03449935312567992 + 0.006759387124351832*lm) + 
        0.005188859053363073*NM - 0.0012289794771548786*lm*NM + 
        0.006125301858129471*NL - 0.0012289794771548786*lm*NL + 
        0.004835195934543435*NH - 0.0012289794771548786*lm*NH)}, 
     {0.655, CF*NC*(0.00020634858433945722*CF + 
        CA*(-0.033383624038683724 + 0.006510020489795587*lm) + 
        0.0050142874434721185*NM - 0.001183640089053743*lm*NM + 
        0.005924527416249013*NL - 0.001183640089053743*lm*NL + 
        0.004677251024924942*NH - 0.001183640089053743*lm*NH)}, 
     {0.66, CF*NC*(0.00020805273317988285*CF + 
        CA*(-0.032289961292863906 + 0.006267685040229688*lm) + 
        0.004843599260909466*NM - 0.0011395790982235796*lm*NM + 
        0.005727917896291069*NL - 0.0011395790982235796*lm*NL + 
        0.004522637218619636*NH - 0.0011395790982235796*lm*NH)}, 
     {0.665, CF*NC*(0.00020917966442557593*CF + 
        CA*(-0.031218207253969687 + 0.006032204943887502*lm) + 
        0.004676743644394043*NM - 0.0010967645352522731*lm*NM + 
        0.0055354314464542646*NL - 0.0010967645352522731*lm*NL + 
        0.004371312502016482*NH - 0.0010967645352522731*lm*NH)}, 
     {0.67, CF*NC*(0.0002097599406945501*CF + CA*(-0.030168200819187255 + 
          0.005803409595715204*lm) + 0.0045136701048768355*NM - 
        0.001055165381039128*lm*NM + 0.005347026175928899*NL - 
        0.001055165381039128*lm*NL + 0.004223235497973174*NH - 
        0.001055165381039128*lm*NH)}, 
     {0.675, CF*NC*(0.00020982355012607557*CF + 
        CA*(-0.029139777692691802 + 0.005581133454229315*lm) + 
        0.004354328544138118*NM - 0.0010147515371326027*lm*NM + 
        0.005162660183324541*NL - 0.0010147515371326027*lm*NL + 
        0.004078365455456513*NH - 0.0010147515371326027*lm*NH)}, 
     {0.68, CF*NC*(0.00020939987518656567*CF + 
        CA*(-0.02813277064807857 + 0.005365215883593115*lm) + 
        0.004198669271853937*NM - 0.00097549379701693*lm*NM + 
        0.0049822915834591445*NL - 0.00097549379701693*lm*NL + 
        0.0039366622393258105*NH - 0.00097549379701693*lm*NH)}, 
     {0.685, CF*NC*(0.00020851766555742183*CF + 
        CA*(-0.027147009778242474 + 0.005155501000741729*lm) + 
        0.004046643021215642*NM - 0.0009373638183166781*lm*NM + 
        0.0048058785325878735*NL - 0.0009373638183166781*lm*NL + 
        0.0037980863202594743*NH - 0.0009373638183166781*lm*NH)}, 
     {0.69, CF*NC*(0.00020720501480311898*CF + 
        CA*(-0.02618232273325128 + 0.0049518375273912545*lm) + 
        0.0038982009631820243*NM - 0.0009003340958893191*lm*NM + 
        0.004633379252146198*NL - 0.0009003340958893191*lm*NL + 
        0.003662598764824797*NH - 0.0009003340958893191*lm*NH)}, 
     {0.695, CF*NC*(0.00020548934053697825*CF + 
        CA*(-0.02523853494673395 + 0.004754078646772711*lm) + 
        0.0037532947194397056*NM - 0.0008643779357768567*lm*NM + 
        0.004464752051078411*NL - 0.0008643779357768567*lm*NL + 
        0.0035301612256907946*NH - 0.0008643779357768567*lm*NH)}, 
     {0.7, CF*NC*(0.00020339736782008284*CF + CA*(-0.024315469851283356 + 
          0.004562081864936824*lm) + 0.003611876374143597*NM - 
        0.0008294694299885134*lm*NM + 0.004299955346819444*NL - 
        0.0008294694299885134*lm*NL + 0.0034007359319838102*NH - 
        0.0008294694299885134*lm*NH)}, 
     {0.705, CF*NC*(0.00020095511554570997*CF + 
        CA*(-0.023412949083351176 + 0.004375708876480706*lm) + 
        0.0034738984845056682*NM - 0.000795583432087401*lm*NM + 
        0.004138947684994712*NL - 0.000795583432087401*lm*NL + 
        0.0032742856797854563*NH - 0.000795583432087401*lm*NH)}, 
     {0.71, CF*NC*(0.0001981878855775456*CF + CA*(-0.022530792678092316 + 
          0.004194825434552414*lm) + 0.0033393140902968563*NM - 
        0.0007626955335549843*lm*NM + 0.003981687757899778*NL - 
        0.0007626955335549843*lm*NL + 0.0031507738227723623*NH - 
        0.0007626955335549843*lm*NH)}, 
     {0.715, CF*NC*(0.00019512025442487967*CF + 
        CA*(-0.021668819254596548 + 0.004019301224994103*lm) + 
        0.0032080767223236794*NM - 0.0007307820409080186*lm*NM + 
        0.0038281344218187756*NL - 0.0007307820409080186*lm*NL + 
        0.0030301642629970704*NH - 0.0007307820409080186*lm*NH)}, 
     {0.72, CF*NC*(0.00019177606725200483*CF + 
        CA*(-0.020826846191926415 + 0.003849009744489063*lm) + 
        0.0030801404099380387*NM - 0.0006998199535434659*lm*NM + 
        0.0036782467132377952*NL - 0.0006998199535434659*lm*NL + 
        0.0029124214418093193*NH - 0.0006998199535434659*lm*NH)}, 
     {0.725, CF*NC*(0.00018817843403221715*CF + 
        CA*(-0.020004689796362482 + 0.0036838281825824137*lm) + 
        0.002955459687635737*NM - 0.0006697869422877116*lm*NM + 
        0.0035319838640069027*NL - 0.0006697869422877116*lm*NL + 
        0.0027975103309168716*NH - 0.0006697869422877116*lm*NH)}, 
     {0.73, CF*NC*(0.00018434972766919098*CF + 
        CA*(-0.01920216546023984 + 0.0035236373074494795*lm) + 
        0.0028339896007964637*NM - 0.0006406613286271781*lm*NM + 
        0.0033893053155019596*NL - 0.0006406613286271781*lm*NL + 
        0.002685396423584946*NH - 0.0006406613286271781*lm*NH)}, 
     {0.735, CF*NC*(0.00018031158392012374*CF + 
        CA*(-0.018419087812743415 + 0.0033683213552900544*lm) + 
        0.0027156857106153142*NM - 0.0006124220645981916*lm*NM + 
        0.0032501707318350727*NL - 0.0006124220645981916*lm*NL + 
        0.0025760457259732324*NH - 0.0006124220645981916*lm*NH)}, 
     {0.74, CF*NC*(0.00017608490296596073*CF + 
        CA*(-0.017655270863013956 + 0.0032177679232307807*lm) + 
        0.0026005040982734037*NM - 0.0005850487133146874*lm*NM + 
        0.0031145400121602726*NL - 0.0005850487133146874*lm*NL + 
        0.0024694247486094062*NH - 0.0005850487133146874*lm*NH)}, 
     {0.745, CF*NC*(0.0001716898524842608*CF + 
        CA*(-0.016910528135901486 + 0.0030718678656217516*lm) + 
        0.0024884013683927025*NM - 0.0005585214301130457*lm*NM + 
        0.002982373302118856*NL - 0.0005585214301130457*lm*NL + 
        0.002365500497997984*NH - 0.0005585214301130457*lm*NH)}, 
     {0.75, CF*NC*(0.00016714587208988842*CF + 
        CA*(-0.01618467280068871 + 0.0029305151936172076*lm) + 
        0.002379334651817954*NM - 0.0005328209442940378*lm*NM + 
        0.0028536310044668103*NL - 0.0005328209442940378*lm*NL + 
        0.002264240468363305*NH - 0.0005328209442940378*lm*NH)}, 
     {0.755, CF*NC*(0.00016247167901775462*CF + 
        CA*(-0.015477517793093119 + 0.002793606977933838*lm) + 
        0.002273261607766345*NM - 0.0005079285414425161*lm*NM + 
        0.0027282737889247734*NL - 0.0005079285414425161*lm*NL + 
        0.0021656126335253723*NH - 0.0005079285414425161*lm*NH)}, 
     {0.76, CF*NC*(0.00015768527493031286*CF + 
        CA*(-0.014788875930843283 + 0.002661043254683723*lm) + 
        0.002170140425383524*NM - 0.0004838260463061315*lm*NM + 
        0.0026062626012891316*NL - 0.0004838260463061315*lm*NL + 
        0.0020695854389072305*NH - 0.0004838260463061315*lm*NH)}, 
     {0.765, CF*NC*(0.00015280395374048047*CF + 
        CA*(-0.01411856002311243 + 0.0025327269341823304*lm) + 
        0.0020699298247426126*NM - 0.00046049580621496914*lm*NM + 
        0.002487558671841083*NL - 0.00046049580621496914*lm*NL + 
        0.001976127793672523*NH - 0.00046049580621496914*lm*NH)}, 
     {0.77, CF*NC*(0.00014784431034813044*CF + 
        CA*(-0.01346638297408014 + 0.0024085637126353026*lm) + 
        0.0019725890573209486*NM - 0.0004379206750246005*lm*NM + 
        0.0023721235230887983*NL - 0.0004379206750246005*lm*NL + 
        0.0018852090629918217*NH - 0.0004379206750246005*lm*NH)}, 
     {0.775, CF*NC*(0.0001428222501953142*CF + 
        CA*(-0.012832157880881616 + 0.0022884619866109196*lm) + 
        0.0018780779059875516*NM - 0.0004160839975656217*lm*NM + 
        0.0022599189768762015*NL - 0.0004160839975656217*lm*NL + 
        0.001796799060436302*NH - 0.0004160839975656217*lm*NH)}, 
     {0.78, CF*NC*(0.00013775299955195782*CF + 
        CA*(-0.01221569812619289 + 0.0021723327702082135*lm) + 
        0.0017863566845325802*NM - 0.0003949695945833115*lm*NM + 
        0.002150907160890347*NL - 0.0003949695945833115*lm*NL + 
        0.0017108680404972867*NH - 0.0003949695945833115*lm*NH)}, 
     {0.785, CF*NC*(0.0001326511164499513*CF + 
        CA*(-0.011616817465689775 + 0.0020600896148336833*lm) + 
        0.001697386236768449*NM - 0.0003745617481515788*lm*NM + 
        0.002045050514597893*NL - 0.0003745617481515788*lm*NL + 
        0.001627386691230171*NH - 0.0003745617481515788*lm*NH)}, 
     {0.79, CF*NC*(0.00012753050218934284*CF + 
        CA*(-0.011035330110608267 + 0.0019516485315024229*lm) + 
        0.001611127935230738*NM - 0.00035484518754589506*lm*NM + 
        0.0019423117946397823*NL - 0.00035484518754589506*lm*NL + 
        0.0015463261270212115*NH - 0.00035484518754589506*lm*NH)}, 
     {0.795, CF*NC*(0.00012240441334578482*CF + 
        CA*(-0.010471050805624414 + 0.0018469279155822569*lm) + 
        0.001527543679505569*NM - 0.0003358050755604103*lm*NM + 
        0.00184265407971188*NL - 0.0003358050755604103*lm*NL + 
        0.0014676578814756384*NH - 0.0003358050755604103*lm*NH)}, 
     {0.8, CF*NC*(0.00011728547421347379*CF + CA*(-0.00992379490226242 + 
          0.0017458484739021711*lm) + 0.0014465958942087292*NM - 
        0.0003174269952549402*lm*NM + 0.0017460407749580588*NL - 
        0.0003174269952549402*lm*NL + 0.0013913539004255435*NH - 
        0.0003174269952549402*lm*NH)}, 
     {0.805, CF*NC*(0.00011218568962260419*CF + 
        CA*(-0.00939337842803089 + 0.001648333154148908*lm) + 
        0.0013682475266405144*NM - 0.00029969693711798327*lm*NM + 
        0.0016524356159009817*NL - 0.00029969693711798327*lm*NL + 
        0.0013173865350559683*NH - 0.00029969693711798327*lm*NH)}, 
     {0.81, CF*NC*(0.00010711645807483448*CF + 
        CA*(-0.008879618151478563 + 0.0015543070764781116*lm) + 
        0.0012924620441389968*NM - 0.0002826012866323839*lm*NM + 
        0.0015618026719346812*NL - 0.0002826012866323839*lm*NL + 
        0.0012457285351476206*NH - 0.0002826012866323839*lm*NH)}, 
     {0.815, CF*NC*(0.0001020885851444616*CF + 
        CA*(-0.008382331643352902 + 0.0014636974672688377*lm) + 
        0.0012192034311532362*NM - 0.0002661268122306978*lm*NM + 
        0.0014741063494019102*NL - 0.0002661268122306978*lm*NL + 
        0.0011763530424346274*NH - 0.0002661268122306978*lm*NH)}, 
     {0.82, CF*NC*(0.00009711229709693286*CF + 
        CA*(-0.007901337334036938 + 0.0013764335949525773*lm) + 
        0.0011484361860568152*NM - 0.0002502606536277413*lm*NM + 
        0.0013893113942781837*NL - 0.0002502606536277413*lm*NL + 
        0.0011092335840757299*NH - 0.0002502606536277413*lm*NH)}, 
     {0.825, CF*NC*(0.0000921972546800084*CF + 
        CA*(-0.007436454567432454 + 0.0012924467078502151*lm) + 
        0.0010801253177210007*NM - 0.00023499031051822094*lm*NM + 
        0.0013073828944834102*NL - 0.00023499031051822094*lm*NL + 
        0.0010443440662373255*NH - 0.00023499031051822094*lm*NH)}, 
     {0.83, CF*NC*(0.00008735256704633823*CF + 
        CA*(-0.006987503651450418 + 0.0012116699739525359*lm) + 
        0.0010142363418658045*NM - 0.0002203036316277338*lm*NM + 
        0.0012282862818410473*NL - 0.0002203036316277338*lm*NL + 
        0.0009816587677867533*NH - 0.0002203036316277338*lm*NH)}, 
     {0.835, CF*NC*(0.00008258680576944845*CF + 
        CA*(-0.006554305905262711 + 0.0011340384225819987*lm) + 
        0.0009507352772062446*NM - 0.00020618880410581793*lm*NM + 
        0.001151987333703787*NL - 0.00020618880410581793*lm*NL + 
        0.0009211523340942208*NH - 0.00020618880410581793*lm*NH)}, 
     {0.84, CF*NC*(0.0000779080189181555*CF + CA*(-0.006136683703462695 + 
          0.0010594888878755595*lm) + 0.0008895886414101723*NM - 
        0.00019263434325010172*lm*NM + 0.0010784521742638973*NL - 
        0.00019263434325010172*lm*NL + 0.0008627997709417779*NH - 
        0.00019263434325010172*lm*NH)}, 
     {0.845, CF*NC*(0.00007332374515725697*CF + 
        CA*(-0.0057344605172758726 + 0.0009879599540302852*lm) + 
        0.000830763446883157*NM - 0.00017962908255096096*lm*NM + 
        0.0010076472755654986*NL - 0.00017962908255096096*lm*NL + 
        0.0008065764385377355*NH - 0.00017962908255096096*lm*NH)}, 
     {0.85, CF*NC*(0.000068841027844995*CF + CA*(-0.005347460952955908 + 
          0.0009193919022554251*lm) + 0.0007742271963950724*NM - 
        0.00016716216404644092*lm*NM + 0.0009395394582352508*NL - 
        0.00016716216404644092*lm*NL + 0.0007524580456349407*NH - 
        0.00016716216404644092*lm*NH)}, 
     {0.855, CF*NC*(0.0000644664291002635*CF + 
        CA*(-0.0049755107874955105 + 0.0008537266593764448*lm) + 
        0.0007199478785622363*NM - 0.00015522302897753542*lm*NM + 
        0.0008740958919471585*NL - 0.00015522302897753542*lm*NL + 
        0.0007004206437513212*NH - 0.00015522302897753542*lm*NH)}, 
     {0.86, CF*NC*(0.000060206043814845374*CF + 
        CA*(-0.004618437001776204 + 0.0007909077480383212*lm) + 
        0.000667893963198193*NM - 0.0001438014087342402*lm*NM + 
        0.0008112840956364654*NL - 0.0001438014087342402*lm*NL + 
        0.0006504406214911207*NH - 0.0001438014087342402*lm*NH)}, 
     {0.865, CF*NC*(0.000056065513588127484*CF + 
        CA*(-0.004276067811275698 + 0.0007308802384571139*lm) + 
        0.0006180343965455086*NM - 0.00013288731608311163*lm*NM + 
        0.00075107193747691*NL - 0.00013288731608311163*lm*NL + 
        0.0006024946989652532*NH - 0.00013288731608311163*lm*NH)}, 
     {0.87, CF*NC*(0.00005205004056376251*CF + 
        CA*(-0.003948232694446571 + 0.0006735907016705058*lm) + 
        0.0005703385964002622*NM - 0.0001224710366673647*lm*NM + 
        0.0006934276346349419*NL - 0.0001224710366673647*lm*NL + 
        0.0005565599223092187*NH - 0.0001224710366673647*lm*NH)}, 
     {0.875, CF*NC*(0.000048164401149632014*CF + 
        CA*(-0.0036347624188750893 + 0.0006189871642396092*lm) + 
        0.0005247764471402659*NM - 0.00011254312077083804*lm*NM + 
        0.0006383197528138635*NL - 0.00011254312077083804*lm*NL + 
        0.0005126136582970258*NH - 0.00011254312077083804*lm*NH)}, 
     {0.88, CF*NC*(0.00004441295960422606*CF + 
        CA*(-0.0033354890653243966 + 0.0005670190643559*lm) + 
        0.0004813182946674254*NM - 0.00010309437533743637*lm*NM + 
        0.0005857172056002465*NL - 0.00010309437533743637*lm*NL + 
        0.00047063358904958464*NH - 0.00010309437533743637*lm*NH)}, 
     {0.885, CF*NC*(0.00004079968147419693*CF + 
        CA*(-0.0030502460497618383 + 0.0005176372093086434*lm) + 
        0.00043993494127406467*NM - 0.00009411585623793516*lm*NM + 
        0.0005355892536243918*NL - 0.00009411585623793516*lm*NL + 
        0.0004305977068360424*NH - 0.00009411585623793516*lm*NH)}, 
     {0.89, CF*NC*(0.00003732814686937562*CF + 
        CA*(-0.0027788681434659517 + 0.0004707937342696323*lm) + 
        0.0004005976404424794*NM - 0.00008559886077629677*lm*NM + 
        0.0004879055035460452*NL - 0.00008559886077629677*lm*NL + 
        0.0003924843089665473*NH - 0.00008559886077629677*lm*NH)}, 
     {0.895, CF*NC*(0.000034001563562966776*CF + 
        CA*(-0.0025211914913045694 + 0.00042644206235346866*lm) + 
        0.00036327809158645156*NM - 0.00007753492042790339*lm*NM + 
        0.000442635906876047*NL - 0.00007753492042790339*lm*NL + 
        0.0003562719927749408*NH - 0.00007753492042790339*lm*NH)}, 
     {0.9, CF*NC*(0.00003082277990596703*CF + CA*(-0.0022770536282715813 + 
          0.00038453686591297494*lm) + 0.00032794843474295154*NM - 
        0.00006991579380235907*lm*NM + 0.00039975075864408965*NL - 
        0.00006991579380235907*lm*NL + 0.0003219396506898913*NH - 
        0.00006991579380235907*lm*NH)}, 
     {0.905, CF*NC*(0.000027794297546088596*CF + 
        CA*(-0.0020462934943661745 + 0.00034503402903064104*lm) + 
        0.00029458124522177656*NM - 0.00006273345982375291*lm*NM + 
        0.0003592206959222678*NL - 0.00006273345982375291*lm*NL + 
        0.0002894664653929991*NH - 0.00006273345982375291*lm*NH)}, 
     {0.91, CF*NC*(0.000024918283942620942*CF + 
        CA*(-0.001828751447894765 + 0.00030789061116828114*lm) + 
        0.00026314952822041544*NM - 0.00005598011112150566*lm*NM + 
        0.0003210166962136465*NL - 0.00005598011112150566*lm*NL + 
        0.00025883190506241537*NH - 0.00005598011112150566*lm*NH)}, 
     {0.915, CF*NC*(0.000022196584669733098*CF + 
        CA*(-0.0016242692772724314 + 0.000273064811938305*lm) + 
        0.0002336267134109985*NM - 0.00004964814762514636*lm*NM + 
        0.0002851100757146282*NL - 0.00004964814762514636*lm*NL + 
        0.00023001571870053563*NH - 0.00004964814762514636*lm*NH)}, 
     {0.92, CF*NC*(0.000019630735501713025*CF + 
        CA*(-0.001432690211397343 + 0.00024051593696119438*lm) + 
        0.00020598664950577915*NM - 0.000043730170356580794*lm*NM + 
        0.00025147248745947755*NL - 0.000043730170356580794*lm*NL + 
        0.00020299793154434333*NH - 0.000043730170356580794*lm*NH)}, 
     {0.925, CF*NC*(0.00001722197427456281*CF + 
        CA*(-0.0012538589286685505 + 0.00021020436477492562*lm) + 
        0.00018020359880720386*NM - 0.00003821897541362284*lm*NM + 
        0.00022007591935496065*NL - 0.00003821897541362284*lm*NL + 
        0.00017775884055699592*NH - 0.00003821897541362284*lm*NH)}, 
     {0.93, CF*NC*(0.000014971252519223969*CF + 
        CA*(-0.001087621564714473 + 0.00018209151476318707*lm) + 
        0.00015625223174825506*NM - 0.00003310754813876128*lm*NM + 
        0.00019089269211266814*NL - 0.00003310754813876128*lm*NL + 
        0.000154279009999263*NH - 0.00003310754813876128*lm*NH)}, 
     {0.935, CF*NC*(0.000012879246862499851*CF + 
        CA*(-0.0009338257188965238 + 0.00015613981607031534*lm) + 
        0.00013410762142840072*NM - 0.00002838905746733006*lm*NM + 
        0.00016389545708622608*NL - 0.00002838905746733006*lm*NL + 
        0.00013253926707944253*NH - 0.00002838905746733006*lm*NH)}, 
     {0.94, CF*NC*(0.000010946370192475981*CF + 
        CA*(-0.0007923204596495524 + 0.00013231267747191002*lm) + 
        0.00011374523815014887*NM - 0.000024056850449438186*lm*NM + 
        0.0001390571940202456*NL - 0.000024056850449438186*lm*NL + 
        0.00011252069768039904*NH - 0.000024056850449438186*lm*NH)}, 
     {0.945, CF*NC*(9.17278258591779*^-6*CF + CA*(-0.0006629563287181195 + 
          0.00011057445817109042*lm) + 0.00009514094396088877*NM - 
        0.000020104446940198256*lm*NM + 0.00011635120871752746*NL - 
        0.000020104446940198256*lm*NL + 0.00009420464216238518*NH - 
        0.000020104446940198256*lm*NH)}, 
     {0.95, CF*NC*(7.558401995752098*^-6*CF + CA*(-0.0005455853443450755 + 
          0.00009089043949132727*lm) + 0.00007827098720439887*NM - 
        0.000016525534452968598*lm*NM + 0.00009575113063071748*NL - 
        0.000016525534452968598*lm*NL + 0.00007757269124032546*NH - 
        0.000016525534452968598*lm*NH)}, 
     {0.955, CF*NC*(6.102914697317133*^-6*CF + 
        CA*(-0.0004400610034664777 + 0.00007322679743771969*lm) + 
        0.00006311199708611617*NM - 0.00001331396317049449*lm*NM + 
        0.00007723091038430312*NL - 0.00001331396317049449*lm*NL + 
        0.00006260668193425902*NH - 0.00001331396317049449*lm*NH)}, 
     {0.96, CF*NC*(4.805785492598831*^-6*CF + CA*(-0.0003462382829645432 + 
          0.00005755057609949416*lm) + 0.00004964097825599045*NM - 
        0.000010463741108998939*lm*NM + 0.00006076481723254877*NL - 
        0.000010463741108998939*lm*NL + 0.00004928869359165633*NH - 
        0.000010463741108998939*lm*NH)}, 
     {0.965, CF*NC*(3.666267672161687*^-6*CF + 
        CA*(-0.00026397364002809213 + 0.00004382966186737882*lm) + 
        0.00003783530541248965*NM - 7.969029430432513*^-6*lm*NM + 
        0.000046327436458689244*NL - 7.969029430432513*^-6*lm*NL + 
        0.00003760104398034253*NH - 7.969029430432513*^-6*lm*NH)}, 
     {0.97, CF*NC*(2.6834127349330024*^-6*CF + 
        CA*(-0.0001931250116677948 + 0.000032032758440353416*lm) + 
        0.00002767271793107892*NM - 5.824137898246076*^-6*lm*NM + 
        0.00003389366672043445*NL - 5.824137898246076*^-6*lm*NL + 
        0.000027526285450778307*NH - 5.824137898246076*^-6*lm*NH)}, 
     {0.975, CF*NC*(1.8560798664127642*^-6*CF + 
        CA*(-0.0001335518134314741 + 0.000022129362597094807*lm) + 
        0.00001913131452026452*NM - 4.0235204721990555*^-6*lm*NM + 
        0.000023438717346583808*NL - 4.0235204721990555*^-6*lm*NL + 
        0.000019047201166467367*NH - 4.0235204721990555*^-6*lm*NH)}, 
     {0.98, CF*NC*(1.1829451762598694*^-6*CF + 
        CA*(-0.00008511493736274805 + 0.000014089740708230095*lm) + 
        0.000012189547908074747*NM - 2.561771037860017*^-6*lm*NM + 
        0.000014938105589306731*NL - 2.561771037860017*^-6*lm*NL + 
        0.000012146801401277525*NH - 2.561771037860017*^-6*lm*NH)}, 
     {0.985, CF*NC*(6.625106965512673*^-7*CF + 
        CA*(-0.000047676749244404944 + 7.884905966275555*^-6*lm) + 
        6.826219561642152*^-6*NM - 1.4336192665955556*^-6*lm*NM + 
        8.36765383641352*^-6*NL - 1.4336192665955556*^-6*lm*NL + 
        6.80831990248073*^-6*NH - 1.4336192665955556*^-6*lm*NH)}, 
     {0.99, CF*NC*(2.9311314232595477*^-7*CF + 
        CA*(-0.00002110108516609584 + 3.4865963108803253*^-6*lm) + 
        3.0204744423545065*^-6*NM - 6.33926601978241*^-7*lm*NM + 
        3.7034867877198965*^-6*NL - 6.33926601978241*^-7*lm*NL + 
        3.015210318335255*^-6*NH - 6.33926601978241*^-7*lm*NH)}, 
     {0.995, CF*NC*(7.293243631262553*^-8*CF + 
        CA*(-5.2532474541928825*^-6 + 8.67253027710246*^-7*lm) + 
        7.517957988555689*^-7*NM - 1.5768236867459018*^-7*lm*NM + 
        9.220285993973721*^-7*NL - 1.5768236867459018*^-7*lm*NL + 
        7.511426890514037*^-7*NH - 1.5768236867459018*^-7*lm*NH)}, {1., 0.}}
 
CbarLTable["v", 2, 1] = {{0., -1.6075102880658437*^-7*CF*NC*
       (15.*CA*(-29093.002395114298 + 3898.992508165458*lm + 15840.*lm^2) + 
        2.*(CF*(-609746.3369659903 + 167166.91012706028*lm - 194400.*lm^2) + 
          60.*((-625.7551981765639 + 369.5683520871487*lm - 360.*lm^2)*NM + 
            (-625.7551981765639 + 369.5683520871487*lm - 360.*lm^2)*NL + 
            (-294.90179009708874 + 369.5683520871487*lm - 360.*lm^2)*NH)))}, 
     {0.005, CF*NC*(CA*(0.06043681315118497 - 0.011109369768263721*lm - 
          0.037428640405674986*lm^2) + CF*(0.18511499818912794 - 
          0.04956377714650086*lm + 0.06124686611837725*lm^2) + 
        0.01304693661203929*NM - 0.0066412875740256005*lm*NM + 
        0.006805207346486361*lm^2*NM + 0.013047333471654649*NL - 
        0.0066412875740256005*lm*NL + 0.006805207346486361*lm^2*NL + 
        0.005564154375382823*NH - 0.0066412875740256005*lm*NH + 
        0.006805207346486361*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(0.05108245599546837 - 0.012757103948629077*lm - 
          0.036661549228092796*lm^2) + CF*(0.1748210398321127 - 
          0.045479113215898884*lm + 0.05999162600960639*lm^2) + 
        0.013958346001345495*NM - 0.006164190838981476*lm*NM + 
        0.006665736223289599*lm^2*NM + 0.013962708619373754*NL - 
        0.006164190838981476*lm*NL + 0.006665736223289599*lm^2*NL + 
        0.005439865737583196*NH - 0.006164190838981476*lm*NH + 
        0.006665736223289599*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(0.042203780544840905 - 0.014320705437167205*lm - 
          0.035895939378504764*lm^2) + CF*(0.16523389420008538 - 
          0.04153480204407799*lm + 0.0587388098920987*lm^2) + 
        0.014788327395725677*NM - 0.005702733743640122*lm*NM + 
        0.006526534432455411*lm^2*NM + 0.014802328028634749*NL - 
        0.005702733743640122*lm*NL + 0.006526534432455411*lm^2*NL + 
        0.005316326119469507*NH - 0.005702733743640122*lm*NH + 
        0.006526534432455411*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(0.033842712672510655 - 0.015789092224432855*lm - 
          0.03513385565736569*lm^2) + CF*(0.15634651449583456 - 
          0.03775267874814365*lm + 0.05749176380296204*lm^2) + 
        0.01553219581312582*NM - 0.005259404375774517*lm*NM + 
        0.006387973755884671*lm^2*NM + 0.01556234659053429*NL - 
        0.005259404375774517*lm*NL + 0.006387973755884671*lm^2*NL + 
        0.005193896341996743*NH - 0.005259404375774517*lm*NH + 
        0.006387973755884671*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(0.026011369186908752 - 0.017157118358720677*lm - 
          0.03437690850245639*lm^2) + CF*(0.14812556332850438 - 
          0.0341440787356302*lm + 0.05625312300401954*lm^2) + 
        0.01618999089650543*NM - 0.004835511026255569*lm*NM + 
        0.006250347000446616*lm^2*NM + 0.016243014513419262*NL - 
        0.004835511026255569*lm*NL + 0.006250347000446616*lm^2*NL + 
        0.005072853542317665*NH - 0.004835511026255569*lm*NH + 
        0.006250347000446616*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(0.018706371766798766 - 0.018423044821293085*lm - 
          0.033626400877113806*lm^2) + CF*(0.14052822412591376 - 
          0.030714205929519775*lm + 0.055025019617095314*lm^2) + 
        0.016764102734760814*NM - 0.004431671392485444*lm*NM + 
        0.0061138910685661465*lm^2*NM + 0.016846570953056975*NL - 
        0.004431671392485444*lm*NL + 0.0061138910685661465*lm^2*NL + 
        0.004953415576810484*NH - 0.004431671392485444*lm*NH + 
        0.0061138910685661465*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(0.01191552868236841 - 0.019587266119118745*lm - 
          0.03288340177398511*lm^2) + CF*(0.13350891027872616 - 
          0.027464349561299405*lm + 0.053809202902884726*lm^2) + 
        0.017258174675666146*NM - 0.004048061116123725*lm*NM + 
        0.005978800322542747*lm^2*NM + 0.017376292508636197*NL - 
        0.004048061116123725*lm*NL + 0.005978800322542747*lm^2*NL + 
        0.004835755214049201*NH - 0.004048061116123725*lm*NH + 
        0.005978800322542747*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(0.005621470673483174 - 0.020651570688691497*lm - 
          0.03214879453267207*lm^2) + CF*(0.1270223375993681 - 
          0.02439318187020054*lm + 0.05260711832619065*lm^2) + 
        0.017676514560622754*NM - 0.00368455943606285*lm*NM + 
        0.005845235369576739*lm^2*NM + 0.017835992571250937*NL - 
        0.00368455943606285*lm*NL + 0.005845235369576739*lm^2*NL + 
        0.004720009517010192*NH - 0.00368455943606285*lm*NH + 
        0.005845235369576739*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.00019618875997943594 - 0.021618673941775406*lm - 
          0.03142331110448429*lm^2) + CF*(0.12102500486775802 - 
          0.021497584226533306*lm + 0.05141996362551975*lm^2) + 
        0.01802375151535242*NM - 0.003340842018235548*lm*NM + 
        0.005713329291724417*lm^2*NM + 0.018229734555266004*NL - 
        0.003340842018235548*lm*NL + 0.005713329291724417*lm^2*NL + 
        0.004606286538838792*NH - 0.003340842018235548*lm*NH + 
        0.005713329291724417*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.005559496487878154 - 0.022491906996165552*lm - 
          0.03070755762008745*lm^2) + CF*(0.11547589557448942 - 
          0.018773202756680766*lm + 0.0502487306510522*lm^2) + 
        0.018304625841130653*NM - 0.003016443466502533*lm*NM + 
        0.005583192294561355*lm^2*NM + 0.01856165914302865*NL - 
        0.003016443466502533*lm*NL + 0.005583192294561355*lm^2*NL + 
        0.004494670351551617*NH - 0.003016443466502533*lm*NH + 
        0.005583192294561355*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.010491276201282275 - 0.023275001315740732*lm - 
          0.030002034175753436*lm^2) + CF*(0.11033677199853165 - 
          0.01621483656176312*lm + 0.049094237742141986*lm^2) + 
        0.018523856817971425*NM - 0.002710801057642976*lm*NM + 
        0.005454915304682443*lm^2*NM + 0.01883587723380523*NL - 
        0.002710801057642976*lm*NL + 0.005454915304682443*lm^2*NL + 
        0.004385224961810277*NH - 0.002710801057642976*lm*NH + 
        0.005454915304682443*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.01501453994444592 - 0.0239719357742656*lm - 
          0.029307150568990064*lm^2) + CF*(0.10557224744900887 - 
          0.013816716457059796*lm + 0.0479571554765292*lm^2) + 
        0.018686058653162103*NM - 0.002423286189238666*lm*NM + 
        0.005328572830725466*lm^2*NM + 0.019056402903488662*NL - 
        0.002423286189238666*lm*NL + 0.005328572830725466*lm^2*NL + 
        0.004277997442585528*NH - 0.002423286189238666*lm*NH + 
        0.005328572830725466*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.01915209151828461 - 0.024586826067555807*lm - 
          0.028623239079418827*lm^2) + CF*(0.10114973599535257 - 
          0.0115727090662535*lm + 0.04683802758450354*lm^2) + 
        0.018795687370730348*NM - 0.0021532274441115654*lm*NM + 
        0.00520422528716706*lm^2*NM + 0.019227111725354497*NL - 
        0.0021532274441115654*lm*NL + 0.00520422528716706*lm^2*NL + 
        0.004173020489074963*NH - 0.0021532274441115654*lm*NH + 
        0.00520422528716706*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.02292625870027754 - 0.025123843791415315*lm - 
          0.027950565024485913*lm^2) + CF*(0.09703933531574657 - 
          0.009476468344315564*lm + 0.045737288221886045*lm^2) + 
        0.01885700816047662*NM - 0.0018999277460699895*lm*NM + 
        0.005081920913542893*lm^2*NM + 0.019351715643505445*NL - 
        0.0018999277460699895*lm*NL + 0.005081920913542893*lm^2*NL + 
        0.004070314537867045*NH - 0.0018999277460699895*lm*NH + 
        0.005081920913542893*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.02635871409079483 - 0.025587156832895547*lm - 
          0.02728933559569129*lm^2) + CF*(0.09321367485946203 - 
          0.007521549111926231*lm + 0.044655276429313016*lm^2) + 
        0.018874076532925613*NM - 0.001662677242608711*lm*NM + 
        0.004961697381034779*lm^2*NM + 0.01943374887789994*NL - 
        0.001662677242608711*lm*NL + 0.004961697381034779*lm^2*NL + 
        0.00396988954598866*NH - 0.001662677242608711*lm*NH + 
        0.004961697381034779*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.029470358080215284 - 0.025980885385310962*lm - 
          0.02663970733760854*lm^2) + CF*(0.08964774835126658 - 
          0.005701492567311571*lm + 0.04359224837063216*lm^2) + 
        0.01885072891616956*NM - 0.0014407630328611405*lm*NM + 
        0.004843583152292462*lm^2*NM + 0.019476561283710808*NL - 
        0.0014407630328611405*lm*NL + 0.004843583152292462*lm^2*NL + 
        0.0038717464993572575*NH - 0.0014407630328611405*lm*NH + 
        0.004843583152292462*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.03228124596175949 - 0.02630906960194366*lm - 
          0.026001792536494397*lm^2) + CF*(0.08631874199308408 - 
          0.0040098907794002365*lm + 0.042548387786990834*lm^2) + 
        0.01879057975640224*NM - 0.0012334765270998564*lm*NM + 
        0.004727598642998981*lm^2*NM + 0.019483316784632113*NL - 
        0.0012334765270998564*lm*NL + 0.004727598642998981*lm^2*NL + 
        0.003775878702102072*NH - 0.0012334765270998564*lm*NH + 
        0.004727598642998981*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.034810546716407556 - 0.026575646031581253*lm - 
          0.02537566471962743*lm^2) + CF*(0.0832058651185043 - 
          0.0024404352012009863*lm + 0.04152381499575398*lm^2) + 
        0.018697023101925034*NM - 0.0010401190037585167*lm*NM + 
        0.004613757221750442*lm^2*NM + 0.019456995261809988*NL - 
        0.0010401190037585167*lm*NL + 0.004613757221750442*lm^2*NL + 
        0.003682272885788535*NH - 0.0010401190037585167*lm*NH + 
        0.004613757221750442*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.03707652464735547 - 0.0267844307473195*lm - 
          0.024761363420089784*lm^2) + CF*(0.08029018723898958 - 
          0.0009869529010777007*lm + 0.04051859468741965*lm^2) + 
        0.01857323725812924*NM - 0.0008600057795164046*lm*NM + 
        0.00450206607637996*lm^2*NM + 0.019400396779114017*NL - 
        0.0008600057795164046*lm*NL + 0.00450206607637996*lm^2*NL + 
        0.0035909101687746385*NH - 0.0008600057795164046*lm*NH + 
        0.00450206607637996*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.03909653752447067 - 0.02693910761614941*lm - 
          0.024158898328082035*lm^2) + CF*(0.07755448366953979 + 
          0.0003565667284927048*lm + 0.039532742718679695*lm^2) + 
        0.01842219151285195*NM - 0.0006924693027356198*lm*NM + 
        0.004392526968742189*lm^2*NM + 0.01931614736012756*NL - 
        0.0006924693027356198*lm*NL + 0.004392526968742189*lm^2*NL + 
        0.00350176688953404*NH - 0.0006924693027356198*lm*NH + 
        0.004392526968742189*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.04088704662365301 - 0.027043220538882192*lm - 
          0.023568252924994336*lm^2) + CF*(0.07498309082343402 + 
          0.0015959526952472277*lm + 0.03856623205908164*lm^2) + 
        0.018246654216284276*NM - 0.000536861405325894*lm*NM + 
        0.004285136895453516*lm^2*NM + 0.01920670576124225*NL - 
        0.000536861405325894*lm*NL + 0.004285136895453516*lm^2*NL + 
        0.0034148153330354194*NH - 0.000536861405325894*lm*NH + 
        0.004285136895453516*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.042463635265549256 - 0.027100168767259566*lm - 
          0.022989387677723176*lm^2) + CF*(0.07256177157574484 + 
          0.002736838962777011*lm + 0.037618998018092466*lm^2) + 
        0.018049201699864747*NM - 0.0003925548933598223*lm*NM + 
        0.004179888668676941*lm^2*NM + 0.019074370844667322*NL - 
        0.0003925548933598223*lm*NL + 0.004179888668676941*lm^2*NL + 
        0.003330024365677595*NH - 0.0003925548933598223*lm*NH + 
        0.004179888668676941*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.04384103333420833 - 0.02711320460963263*lm - 
          0.02242224285637723*lm^2) + CF*(0.07027759066476326 + 
          0.0037846555963689877*lm + 0.036690942855890016*lm^2) + 
        0.01783222766143766*NM - 0.00025894461625326087*lm*NM + 
        0.004076771428432224*lm^2*NM + 0.018921289267784223*NL - 
        0.00025894461625326087*lm*NL + 0.004076771428432224*lm^2*NL + 
        0.003247359991516908*NH - 0.00025894461625326087*lm*NH + 
        0.004076771428432224*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.045033145894353206 - 0.02708543298961307*lm - 
          0.02186674102736799*lm^2) + CF*(0.06811879983672996 + 
          0.004744623528510735*lm + 0.0357819398629658*lm^2) + 
        0.01759795274709057*NM - 0.00013544812392409986*lm*NM + 
        0.003975771095885089*lm^2*NM + 0.018749463285820864*NL - 
        0.00013544812392409986*lm*NL + 0.003975771095885089*lm^2*NL + 
        0.0031667858403641217*NH - 0.00013544812392409986*lm*NH + 
        0.003975771095885089*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.04605308449620854 - 0.027019812438022324*lm - 
          0.02132278926510393*lm^2) + CF*(0.06607473228372303 + 
          0.005621752179096358*lm + 0.03489183697926098*lm^2) + 
        0.017348434135298775*NM - 0.000021505998234867222*lm*NM + 
        0.003876870775473442*lm^2*NM + 0.018560758523020592*NL - 
        0.000021505998234867222*lm*NL + 0.003876870775473442*lm^2*NL + 
        0.0030882635966171987*NH - 0.000021505998234867222*lm*NH + 
        0.003876870775473442*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.04691320010697889 - 0.02691915718726116*lm - 
          0.020790281118514577*lm^2) + CF*(0.06413570583947863 + 
          0.006420839323330722*lm + 0.03402046001211476*lm^2) + 
        0.017085574984308242*NM + 0.00008341807273832542*lm*NM + 
        0.0037800511124571954*lm^2*NM + 0.018356911609891537*NL + 
        0.00008341807273832542*lm*NL + 0.0037800511124571954*lm^2*NL + 
        0.00301175337632384*NH + 0.00008341807273832542*lm*NH + 
        0.0037800511124571954*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.04762511687111244 - 0.026786140105912567*lm - 
          0.02026909836299969*lm^2) + CF*(0.06229293435872699 + 
          0.007146472722923608*lm + 0.0331676155030904*lm^2) + 
        0.01681113364461459*NM + 0.00017983742286020838*lm*NM + 
        0.0036852906114544885*lm^2*NM + 0.018139537615231984*NL + 
        0.00017983742286020838*lm*NL + 0.0036852906114544885*lm^2*NL + 
        0.0029372140588542046*NH + 0.00017983742286020838*lm*NH + 
        0.0036852906114544885*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.048199766100578675 - 0.02662329626499354*lm - 
          0.01975911256382006*lm^2) + CF*(0.06053844669610469 + 
          0.007803033132166345*lm + 0.03233309328625101*lm^2) + 
        0.01652673256882604*NM + 0.00026824269456939004*lm*NM + 
        0.003592565920694556*lm^2*NM + 0.017910137224558233*NL + 
        0.00026824269456939004*lm*NL + 0.003592565920694556*lm^2*NL + 
        0.0028646035786517266*NH + 0.00026824269456939004*lm*NH + 
        0.003592565920694556*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.048647420048035246 - 0.02643302696942522*lm - 
          0.019260186473189708*lm^2) + CF*(0.05886501271009113 + 
          0.008394698366261548*lm + 0.03151666877431043*lm^2) + 
        0.01623386687389234*NM + 0.0003491022485788678*lm*NM + 
        0.0035018520860344926*lm^2*NM + 0.01767010363351452*NL + 
        0.0003491022485788678*lm*NL + 0.0035018520860344926*lm^2*NL + 
        0.002793879181775171*NH + 0.0003491022485788678*lm*NH + 
        0.0035018520860344926*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.0489777251318644 - 0.026217604121668882*lm - 
          0.01877217528022218*lm^2) + CF*(0.05726607573852462 + 
          0.00892544817951885*lm + 0.030718105003999935*lm^2) + 
        0.015933912527625545*NM + 0.00042286266802061417*lm*NM + 
        0.0034131227782222147*lm^2*NM + 0.01742072913739148*NL + 
        0.00042286266802061417*lm*NL + 0.0034131227782222147*lm^2*NL + 
        0.002724997651315563*NH + 0.00042286266802061417*lm*NH + 
        0.0034131227782222147*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.04919973437131056 - 0.025979174811064504*lm - 
          0.018294927730294556*lm^2) + CF*(0.05573569102026904 + 
          0.009399069749225325*lm + 0.029937154467754724*lm^2) + 
        0.015628134144078456*NM + 0.000489949333844393*lm*NM + 
        0.0033263504964171917*lm^2*NM + 0.01716321140715476*NL + 
        0.000489949333844393*lm*NL + 0.0033263504964171917*lm^2*NL + 
        0.0026579155052425525*NH + 0.000489949333844393*lm*NH + 
        0.0033263504964171917*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.04932193885875697 - 0.02571976604370256*lm - 
          0.01782828712822043*lm^2) + CF*(0.054268469569307476 + 
          0.009819163599775476*lm + 0.029173560755269796*lm^2) + 
        0.015317692381744725*NM + 0.000550767052655242*lm*NM + 
        0.003241506750585533*lm^2*NM + 0.016898659449216057*NL + 
        0.000550767052655242*lm*NL + 0.003241506750585533*lm^2*NL + 
        0.0025925891697870344*NH + 0.000550767052655242*lm*NH + 
        0.003241506750585533*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.049352298149314244 - 0.025441289544791225*lm - 
          0.017372092237789145*lm^2) + CF*(0.05285952704079475 + 
          0.010189149832998672*lm + 0.02842706002547315*lm^2) + 
        0.015003650945490263*NM + 0.0006057007217133126*lm*NM + 
        0.0031585622250525722*lm^2*NM + 0.016628099251173777*NL + 
        0.0006057007217133126*lm*NL + 0.0031585622250525722*lm^2*NL + 
        0.002528975131085537*NH + 0.0006057007217133126*lm*NH + 
        0.0031585622250525722*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.049298269488944654 - 0.02514554657931879*lm - 
          0.01692617808867084*lm^2) + CF*(0.05150443716199721 + 
          0.010512274556084347*lm + 0.02769738232691592*lm^2) + 
        0.014686983198207755*NM + 0.0006551160186961142*lm*NM + 
        0.00307748692521288*lm^2*NM + 0.016352479119361597*NL + 
        0.0006551160186961142*lm*NL + 0.00307748692521288*lm^2*NL + 
        0.0024670300674852915*NH + 0.0006551160186961142*lm*NH + 
        0.00307748692521288*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.04916683583403003 - 0.02483423274802537*lm - 
          0.01649037670035719*lm^2) + CF*(0.050199189333678874 + 
          0.010791616419262792*lm + 0.026984252782402678*lm^2) + 
        0.014368578391850658*NM + 0.0006993601061698902*lm*NM + 
        0.002998250309155853*lm^2*NM + 0.016072674716607758*NL + 
        0.0006993601061698902*lm*NL + 0.002998250309155853*lm^2*NL + 
        0.0024067109646276593*NH + 0.0006993601061698902*lm*NH + 
        0.002998250309155853*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.04896453263968208 - 0.024508942724810925*lm - 
          0.016064517731666523*lm^2) + CF*(0.04894015003879057 + 
          0.011030093192376817*lm + 0.026287392651817947*lm^2) + 
        0.014049247530088599*NM + 0.0007387623426378325*lm*NM + 
        0.0029208214057575496*lm^2*NM + 0.015789493810380084*NL + 
        0.0007387623426378325*lm*NL + 0.0029208214057575496*lm^2*NL + 
        0.0023479752151842974*NH + 0.0007387623426378325*lm*NH + 
        0.0029208214057575496*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.048697473412785124 - 0.024171174909128207*lm - 
          0.01564842906335837*lm^2) + CF*(0.047724027724949915 + 
          0.011230468323404153*lm + 0.025606520285495513*lm^2) + 
        0.013729728876594632*NM + 0.0007736349936098037*lm*NM + 
        0.0028451689206106124*lm^2*NM + 0.01550368074266358*NL + 
        0.0007736349936098037*lm*NL + 0.0028451689206106124*lm^2*NL + 
        0.0022907807049089967*NH + 0.0007736349936098037*lm*NH + 
        0.0028451689206106124*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.048371374039982803 - 0.02382233597296212*lm - 
          0.015241937320550989*lm^2) + CF*(0.04654784085498962 + 
          0.011395357433436639*lm + 0.024941351979083436*lm^2) + 
        0.013410693124133764*NM + 0.0008042739374358592*lm*NM + 
        0.0027712613310092705*lm^2*NM + 0.015215920633634998*NL + 
        0.0008042739374358592*lm*NL + 0.0027712613310092705*lm^2*NL + 
        0.002235085886483684*NH + 0.0008042739374358592*lm*NH + 
        0.0027712613310092705*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.04799157591152839 - 0.02346374528693886*lm - 
          0.014844868340895186*lm^2) + CF*(0.04540888884572826 + 
          0.011527234712048336*lm + 0.02429160273964667*lm^2) + 
        0.013092748240342395*NM + 0.0008309593617156176*lm*NM + 
        0.002699066971071852*lm^2*NM + 0.01492684333157379*NL + 
        0.0008309593617156176*lm*NL + 0.002699066971071852*lm^2*NL + 
        0.0021808498424755393*NH + 0.0008309593617156176*lm*NH + 
        0.002699066971071852*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.04756306786985046 - 0.023096639214143514*lm - 
          0.014457047593812097*lm^2) + CF^2*(0.044304725639066816 + 
          0.01162843918475675*lm + 0.023656986971692523*lm^2) + 
        CF*((0.012776443983885027 + 0.0008539564469786662*lm + 
            0.002628554107965836*lm^2)*NM + (0.014637027121566537 + 
            0.0008539564469786662*lm + 0.002628554107965836*lm^2)*NL + 
          (0.002128032338580283 + 0.0008539564469786662*lm + 
            0.002628554107965836*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.047090507017989405 - 0.022722175263518926*lm - 
          0.014078300555537325*lm^2) + CF^2*(0.043233135672706646 + 
          0.01170118083069482*lm + 0.02303721909087926*lm^2) + 
        CF*((0.01246227621423312 + 0.0008735160350609196*lm + 
            0.0025596910100976955*lm^2)*NM + (0.014347002205488206 + 
            0.0008735160350609196*lm + 0.0025596910100976955*lm^2)*NL + 
          (0.002076593868201621 + 0.0008735160350609196*lm + 
            0.0025596910100976955*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.04657823842513008 - 0.02234143609740451*lm - 
          0.013708453044217406*lm^2) + CF^2*(0.042192112034165154 + 
          0.011747546533904803*lm + 0.022432014072355757*lm^2) + 
        CF*((0.012150690783868524 + 0.0008898752802050568*lm + 
            0.0024924460080395284*lm^2)*NM + (0.014057253965528958 + 
            0.0008898752802050568*lm + 0.0024924460080395284*lm^2)*NL + 
          (0.0020264956893063374 + 0.0008898752802050568*lm + 
            0.0024924460080395284*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.046030313772740555 - 0.021955433389959148*lm - 
          0.013347331518867283*lm^2) + CF^2*(0.04117983660759677 + 
          0.011769505856032862*lm + 0.021841087939964643*lm^2) + 
        CF*((0.011842087292164748 + 0.0009032582814117136*lm + 
            0.00242678754888496*lm^2)*NM + (0.013768226023218552 + 
            0.0009032582814117136*lm + 0.00242678754888496*lm^2)*NL + 
          (0.0019776998543965863 + 0.0009032582814117136*lm + 
            0.00242678754888496*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.04545050898286273 - 0.0215651115349852*lm - 
          0.012994763345611164*lm^2) + CF^2*(0.04019466203280789 + 
          0.011768916621803509*lm + 0.02126415820190918*lm^2) + 
        CF*((0.011536822540096149 + 0.0009138766949798495*lm + 
            0.0023626842446565753*lm^2)*NM + (0.013480323105511944 + 
            0.0009138766949798495*lm + 0.0023626842446565753*lm^2)*NL + 
          (0.0019301692343539868 + 0.0009138766949798495*lm + 
            0.0023626842446565753*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.04484234087307513 - 0.02117135120310312*lm - 
          0.012650577034287102*lm^2) + CF^2*(0.03923509531580796 + 
          0.011747530311616053*lm + 0.02070094423792435*lm^2) + 
        CF*((0.01123521376358726 + 0.0009219303265142957*lm + 
            0.0023001049153249277*lm^2)*NM + (0.013193913729062394 + 
            0.0009219303265142957*lm + 0.0023001049153249277*lm^2)*NL + 
          (0.001883867536832908 + 0.0009219303265142957*lm + 
            0.0023001049153249277*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.04420908288213962 - 0.020774972749376498*lm - 
          0.012314602448191743*lm^2) + CF^2*(0.038299782943161595 + 
          0.01170699725803764*lm + 0.020151167642495582*lm^2) + 
        CF*((0.010937541649731475 + 0.0009276077019579678*lm + 
            0.0022390186269439535*lm^2)*NM + (0.012909332713340261 + 
            0.0009276077019579678*lm + 0.0022390186269439535*lm^2)*NL + 
          (0.001838759319810678 + 0.0009276077019579678*lm + 
            0.0022390186269439535*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.04355377991016036 - 0.020376739473404765*lm - 
          0.01198667098947152*lm^2) + CF^2*(0.03738749736572791 + 
          0.011648871644957688*lm + 0.019614552528226123*lm^2) + 
        CF*((0.010644053149117823 + 0.0009310866174355556*lm + 
            0.002179394725358458*lm^2)*NM + (0.012626883532770115 + 
            0.0009310866174355556*lm + 0.002179394725358458*lm^2)*NL + 
          (0.0017948100008421855 + 0.0009310866174355556*lm + 
            0.002179394725358458*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.042879262316319104 - 0.01997736073462476*lm - 
          0.011666615762425371*lm^2) + CF^2*(0.036497124729147894 + 
          0.011574616309789641*lm + 0.019090825793059697*lm^2) + 
        CF*((0.010354964096854179 + 0.0009325346678829287*lm + 
            0.002121202865895522*lm^2)*NM + (0.012346840517566418 + 
            0.0009325346678829287*lm + 0.002121202865895522*lm^2)*NL + 
          (0.0017519858625094438 + 0.0009325346678829287*lm + 
            0.002121202865895522*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.042188159116372075 - 0.019577494926126236*lm - 
          0.011354271716768704*lm^2) + CF^2*(0.03562765373950552 + 
          0.01148560735041858*lm + 0.018579717354712425*lm^2) + 
        CF*((0.010070461654264416 + 0.0009321097545888714*lm + 
            0.0020644130394124917*lm^2)*NM + (0.012069450912456477 + 
            0.0009321097545888714*lm + 0.0020644130394124917*lm^2)*NL + 
          (0.0017102540545086838 + 0.0009321097545888714*lm + 
            0.0020644130394124917*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.04148291042082446 - 0.019177752310717597*lm - 
          0.011049475772715393*lm^2) + CF^2*(0.03477816556233775 + 
          0.011383138539648039*lm + 0.018080960355352463*lm^2) + 
        CF*((0.009790706582586657 + 0.0009299605718988106*lm + 
            0.0020089955950391624*lm^2)*NM + (0.011794936801994662 + 
            0.0009299605718988106*lm + 0.0020089955950391624*lm^2)*NL + 
          (0.0016695825927725118 + 0.0009299605718988106*lm + 
            0.0020089955950391624*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.04076577915339239 - 0.018778697723299705*lm - 
          0.01075206692956156*lm^2) + CF^2*(0.033947824662264356 + 
          0.011268425550738514*lm + 0.017594291339282555*lm^2) + 
        CF*((0.009515835359391028 + 0.0009262270734286765*lm + 
            0.0019549212599202837*lm^2)*NM + (0.01152349691069827 + 
            0.0009262270734286765*lm + 0.0019549212599202837*lm^2)*NL + 
          (0.0016299403559850417 + 0.0009262270734286765*lm + 
            0.0019549212599202837*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.04003886208789754 - 0.018380853143836126*lm - 
          0.010461886359299493*lm^2) + CF^2*(0.03313587049869692 + 
          0.011142609998288956*lm + 0.017119450406126443*lm^2) + 
        CF*((0.009245962147830886 + 0.00092104091821495*lm + 
            0.0019021611562362716*lm^2)*NM + (0.011255308285776006 + 
            0.00092104091821495*lm + 0.0019021611562362716*lm^2)*NL + 
          (0.0015912970798120075 + 0.00092104091821495*lm + 
            0.0019021611562362716*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.03930410024020799 - 0.017984700145363984*lm - 
          0.010178777486650099*lm^2) + CF^2*(0.032341610000539346 + 
          0.01100676329922064*lm + 0.01665618134179107*lm^2) + 
        CF*((0.00898118062825638 + 0.000914525897287644*lm + 
            0.0018506868157545633*lm^2)*NM + (0.010990527869777084 + 
            0.000914525897287644*lm + 0.0018506868157545633*lm^2)*NL + 
          (0.001553623349135715 + 0.000914525897287644*lm + 
            0.0018506868157545633*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.03856328865025774 - 0.01759068222158386*lm - 
          0.009902586056776241*lm^2) + CF^2*(0.031564410749552886 + 
          0.01086189035900502*lm + 0.016204231729270213*lm^2) + 
        CF*((0.008721565701166464 + 0.0009067983411992574*lm + 
            0.0018004701921411346*lm^2)*NM + (0.010729293970063721 + 
            0.0009067983411992574*lm + 0.0018004701921411346*lm^2)*NL + 
          (0.0015168905885555395 + 0.0009067983411992574*lm + 
            0.0018004701921411346*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.03781808558757216 - 0.01719920699861051*lm - 
          0.009633160191825531*lm^2) + CF^2*(0.03080369480818881 + 
          0.010708933088554456*lm + 0.01576335304116905*lm^2) + 
        CF*((0.008467175069927217 + 0.0008979675090769942*lm + 
            0.0017514836712410058*lm^2)*NM + (0.010471727631603396 + 
            0.0008979675090769942*lm + 0.0017514836712410058*lm^2)*NL + 
          (0.001481071051388505 + 0.0008979675090769942*lm + 
            0.0017514836712410058*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.03707002121209458 - 0.0168106483354688*lm - 
          0.009370350437348282*lm^2) + CF^2*(0.030058933133203552 + 
          0.0105487737573847*lm + 0.015333300715660825*lm^2) + 
        CF*((0.008218050711185917 + 0.0008881359597897662*lm + 
            0.0017037000795178693*lm^2)*NM + (0.0102179339191898 + 
            0.0008881359597897662*lm + 0.0017037000795178693*lm^2)*NL + 
          (0.0014461378073808318 + 0.0008881359597897662*lm + 
            0.0017037000795178693*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.03632050572049126 - 0.01642534831788788*lm - 
          0.009114009799543302*lm^2) + CF^2*(0.02932964052136722 + 
          0.010382238188775341*lm + 0.014913834217434495*lm^2) + 
        CF*((0.007974220240410888 + 0.0008773999058373621*lm + 
            0.001657092690826055*lm^2)*NM + (0.009968003114833347 + 
            0.0008773999058373621*lm + 0.001657092690826055*lm^2)*NL + 
          (0.0014120647293200323 + 0.0008773999058373621*lm + 
            0.001657092690826055*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.03557083700651073 - 0.016043619149888645*lm - 
          0.008863993774199956*lm^2) + CF^2*(0.02861537103808509 + 
          0.010210098802712076*lm + 0.014504717085054474*lm^2) + 
        CF*((0.007735698179536076 + 0.0008658495505781108*lm + 
            0.0016116352316727194*lm^2)*NM + (0.009722011835712994 + 
            0.0008658495505781108*lm + 0.0016116352316727194*lm^2)*NL + 
          (0.0013788264787176 + 0.0008658495505781108*lm + 
            0.0016116352316727194*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.03482220786245862 - 0.015665744947579937*lm - 
          0.008620160368128387*lm^2) + CF^2*(0.027915713883938098 + 
          0.010033077512402566*lm + 0.01410571696602827*lm^2) + 
        CF*((0.007502487133239162 + 0.0008535694094145764*lm + 
            0.0015673018851142524*lm^2)*NM + (0.009480024077750702 + 
            0.0008535694094145764*lm + 0.0015673018851142524*lm^2)*NL + 
          (0.0013463984907153947 + 0.0008535694094145764*lm + 
            0.0015673018851142524*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.03407567908086231 - 0.01529198343948226*lm - 
          0.008382370113800509*lm^2) + CF^2*(0.02723022232491994 + 
          0.009851848480125424*lm + 0.013716605640764469*lm^2) + 
        CF*((0.007274578879987231 + 0.0008406386155553347*lm + 
            0.0015240672934182743*lm^2)*NM + (0.009242092189557719 + 
            0.0008406386155553347*lm + 0.0015240672934182743*lm^2)*NL + 
          (0.0013147569583523827 + 0.0008406386155553347*lm + 
            0.0015240672934182743*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.03333232595195049 - 0.014922567577588312*lm - 
          0.008150486077861216*lm^2) + CF^2*(0.02655869059155102 + 
          0.009667040738106442*lm + 0.01333715903650017*lm^2) + 
        CF*((0.007051955383566593 + 0.0008271312109655274*lm + 
            0.00148190655961113*lm^2)*NM + (0.0090082577812073 + 
            0.0008271312109655274*lm + 0.00148190655961113*lm^2)*NL + 
          (0.0012838788163147307 + 0.0008271312109655274*lm + 
            0.00148190655961113*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.03259302557090108 - 0.014557707063249898*lm - 
          0.00792437386411198*lm^2) + CF^2*(0.02590071349458728 + 
          0.009479240680024432*lm + 0.012967157232183241*lm^2) + 
        CF*((0.006834589730482004 + 0.0008131164231104324*lm + 
            0.00144079524802036*lm^2)*NM + (0.008778552572010767 + 
            0.0008131164231104324*lm + 0.00144079524802036*lm^2)*NL + 
          (0.0012537417242789396 + 0.0008131164231104324*lm + 
            0.00144079524802036*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.03185861431630164 - 0.014197589791854093*lm - 
          0.007703901611516718*lm^2) + CF^2*(0.025255987405510674 + 
          0.009288994428635943*lm + 0.012606384455209174*lm^2) + 
        CF*((0.006622446998220857 + 0.0007986589280853053*lm + 
            0.0014007093839121306*lm^2)*NM + (0.008552999181212469 + 
            0.0007986589280853053*lm + 0.0014007093839121306*lm^2)*NL + 
          (0.0012243240499461429 + 0.0007986589280853053*lm + 
            0.0014007093839121306*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.031129853515603274 - 0.013842383220119546*lm - 
          0.007488939987732276*lm^2) + CF^2*(0.02462422856377792 + 
          0.009096810084878525*lm + 0.012254629070834635*lm^2) + 
        CF*((0.0064154850590956766 + 0.0007838191007117874*lm + 
            0.0013616254523149593*lm^2)*NM + (0.008331611865273262 + 
            0.0007838191007117874*lm + 0.0013616254523149593*lm^2)*NL + 
          (0.0011956048518552453 + 0.0007838191007117874*lm + 
            0.0013616254523149593*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.03040743441252398 - 0.013492235659708904*lm - 
          0.007279362178622504*lm^2) + CF^2*(0.02400517087592298 + 
          0.008903159863669708*lm + 0.011911683565018644*lm^2) + 
        CF*((0.0062136553240435 + 0.0007686532521666593*lm + 
            0.0013235203961131825*lm^2)*NM + (0.008114397205180975 + 
            0.0007686532521666593*lm + 0.0013235203961131825*lm^2)*NL + 
          (0.0011675638620526954 + 0.0007686532521666593*lm + 
            0.0013235203961131825*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.02969198283305061 - 0.01314727750071651*lm - 
          0.00707504387417527*lm^2) + CF^2*(0.02339856393943925 + 
          0.008708482121466818*lm + 0.011577344521377715*lm^2) + 
        CF*((0.006016903430486662 + 0.000753213855693022*lm + 
            0.0012863716134864128*lm^2)*NM + (0.007901354747009148 + 
            0.000753213855693022*lm + 0.0012863716134864128*lm^2)*NL + 
          (0.0011401814686883799 + 0.000753213855693022*lm + 
            0.0012863716134864128*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.02898406356769498 - 0.012807622368453484*lm - 
          0.006875863251205672*lm^2) + CF^2*(0.022804171270519515 + 
          0.008513183280493783*lm + 0.01125141259288201*lm^2) + 
        CF*((0.0058251698780842276 + 0.0007375497609274201*lm + 
            0.0012501569547646676*lm^2)*NM + (0.007692477598741458 + 
            0.0007375497609274201*lm + 0.0012501569547646676*lm^2)*NL + 
          (0.0011134386985991087 + 0.0007375497609274201*lm + 
            0.0012501569547646676*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.028284184486664175 - 0.012473368216815777*lm - 
          0.006681700953195646*lm^2) + CF^2*(0.02222176871659596 + 
          0.008317639654377498*lm + 0.010933692468865603*lm^2) + 
        CF*((0.0056383906159471805 + 0.000721706397359248*lm + 
            0.0012148547187628448*lm^2)*NM + (0.007487752986187918 + 
            0.000721706397359248*lm + 0.0012148547187628448*lm^2)*NL + 
          (0.0010873171999333815 + 0.000721706397359248*lm + 
            0.0012148547187628448*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.027592800403650954 - 0.012144598361385744*lm - 
          0.006492440067590009*lm^2) + CF^2*(0.02165114303630454 + 
          0.008122199179769961*lm + 0.010623992837874558*lm^2) + 
        CF*((0.005456497584685738 + 0.0007057259674212076*lm + 
            0.0011804436486527287*lm^2)*NM + (0.00728716277063941 + 
            0.0007057259674212076*lm + 0.0011804436486527287*lm^2)*NL + 
          (0.0010617992248668751 + 0.0007057259674212076*lm + 
            0.0011804436486527287*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.026910316703065394 - 0.011821382455284869*lm - 
          0.006307966100841338*lm^2) + CF^2*(0.021092090631070863 + 
          0.007927183058364887*lm + 0.01032212634683128*lm^2) + 
        CF*((0.005279419216397056 + 0.0006896476296918156*lm + 
            0.0011469029274256976*lm^2)*NM + (0.007090683930738823 + 
            0.0006896476296918156*lm + 0.0011469029274256976*lm^2)*NL + 
          (0.0010368676124488474 + 0.0006896476296918156*lm + 
            0.0011469029274256976*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.026237092744672588 - 0.011503777410665064*lm - 
          0.0061281669514708596*lm^2) + CF^2*(0.020544416413913604 + 
          0.007732887313550119*lm + 0.010027909556952316*lm^2) + 
        CF*((0.005107080895492074 + 0.0006735076726731185*lm + 
            0.0011142121729947017*lm^2)*NM + (0.0068982890108892966 + 
            0.0006735076726731185*lm + 0.0011142121729947017*lm^2)*NL + 
          (0.00101250577161808 + 0.0006735076726731185*lm + 
            0.0011142121729947017*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.02557344505880014 - 0.011191828268598733*lm - 
          0.005952932881389331*lm^2) + CF^2*(0.02000793280235621 + 
          0.0075395842657709575*lm + 0.009741162896818903*lm^2) + 
        CF*((0.004939405383095638 + 0.0006573396795890155*lm + 
            0.0010823514329798781*lm^2)*NM + (0.006709946538372132 + 
            0.0006573396795890155*lm + 0.0010823514329798781*lm^2)*NL + 
          (0.000988697664418839 + 0.0006573396795890155*lm + 
            0.0010823514329798781*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.0249196503445056 - 0.01088556902000416*lm - 
          0.005782156485700752*lm^2) + CF^2*(0.019482458823486686 + 
          0.007347523930515363*lm + 0.009461710612964866*lm^2) + 
        CF*((0.0047763132076158055 + 0.0006411746846319872*lm + 
            0.0010513011792183185*lm^2)*NM + (0.006525621411208447 + 
            0.0006411746846319872*lm + 0.0010513011792183185*lm^2)*NL + 
          (0.0009654277894464404 + 0.0006411746846319872*lm + 
            0.0010513011792183185*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.02427594828241638 - 0.010585023380122583*lm - 
          0.005615732661192315*lm^2) + CF^2*(0.018967819320359635 + 
          0.007156935342670698*lm + 0.009189380718314698*lm^2) + 
        CF*((0.004617723023696867 + 0.0006250413210686943*lm + 
            0.0010210423020349665*lm^2)*NM + (0.006345275258668766 + 
            0.0006250413210686943*lm + 0.0010210423020349665*lm^2)*NL + 
          (0.000942681165544498 + 0.0006250413210686943*lm + 
            0.0010210423020349665*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.023642544173205222 - 0.010290205518947167*lm - 
          0.005453558573696173*lm^2) + CF^2*(0.018463844249772175 + 
          0.006968027810843611*lm + 0.008924004938775557*lm^2) + 
        CF*((0.004463551941999042 + 0.0006089659615978909*lm + 
            0.0009915561043083952*lm^2)*NM + (0.006168866776213186 + 
            0.0006089659615978909*lm + 0.0009915561043083952*lm^2)*NL + 
          (0.0009204433157756869 + 0.0006089659615978909*lm + 
            0.0009915561043083952*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.023019611412104516 - 0.010001120749891675*lm - 
          0.005295533624492323*lm^2) + CF^2*(0.017970368062500047 + 
          0.006780992105080439*lm + 0.008665418658260165*lm^2) + 
        CF*((0.004313715831654365 + 0.0005929728513374531*lm + 
            0.0009628242953622405*lm^2)*NM + (0.005996352036530862 + 
            0.0005929728513374531*lm + 0.0009628242953622405*lm^2)*NL + 
          (0.0008987002516828447 + 0.0005929728513374531*lm + 
            0.0009628242953622405*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.02240729380919621 - 0.00971776617887849*lm - 
          0.0051415594159069*lm^2) + CF^2*(0.017487229157771417 + 
          0.006596001581275455*lm + 0.00841346086239311*lm^2) + 
        CF*((0.004168129597449407 + 0.0005770842338011041*lm + 
            0.0009348289847103455*lm^2)*NM + (0.005827684778240915 + 
            0.0005770842338011041*lm + 0.0009348289847103455*lm^2)*NL + 
          (0.0008774384578544921 + 0.0005770842338011041*lm + 
            0.0009348289847103455*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.021805707764674578 - 0.009440131315921233*lm - 
          0.004991539716246456*lm^2) + CF^2*(0.017014269404560863 + 
          0.006413213245408514*lm + 0.008167974081130564*lm^2) + 
        CF*((0.004026707433486437 + 0.0005613204702096393*lm + 
            0.0009075526756811738*lm^2)*NM + (0.005662816673716994 + 
            0.0005613204702096393*lm + 0.0009075526756811738*lm^2)*NL + 
          (0.0008566448768074761 + 0.0005613204702096393*lm + 
            0.0009075526756811738*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.021214944307729407 - 0.009168198651177201*lm - 
          0.004845380424196178*lm^2) + CF^2*(0.01655133372294092 + 
          0.006232768760612586*lm + 0.007928804330502838*lm^2) + 
        CF*((0.003889363055017464 + 0.0005457001524661607*lm + 
            0.0008809782589447597*lm^2)*NM + (0.005501697577404225 + 
            0.0005457001524661607*lm + 0.0008809782589447597*lm^2)*NL + 
          (0.0008363068941953835 + 0.0005457001524661607*lm + 
            0.0008809782589447597*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.020635071007196516 - 0.008901944197348547*lm - 
          0.00470298953279844*lm^2) + CF^2*(0.01609826971936001 + 
          0.006054795399935157*lm + 0.0076958010536701755*lm^2) + 
        CF*((0.0037560099099951086 + 0.0005302402101100142*lm + 
            0.0008550890059633528*lm^2)*NM + (0.005344275755909743 + 
            0.0005302402101100142*lm + 0.0008550890059633528*lm^2)*NL + 
          (0.0008164123243507602 + 0.0005302402101100142*lm + 
            0.0008550890059633528*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.020066133761638558 - 0.008641338000218966*lm - 
          0.004564277093117454*lm^2) + CF^2*(0.015654927370268176 + 
          0.0058794069475258896*lm + 0.007468817061464925*lm^2) + 
        CF*((0.0036265613718145886 + 0.0005149560115498225*lm + 
            0.0008298685623849918*lm^2)*NM + (0.0051904981010660245 + 
            0.0005149560115498225*lm + 0.0008298685623849918*lm^2)*NL + 
          (0.000796949396167931 + 0.0005149560115498225*lm + 
            0.0008298685623849918*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.019508158476072453 - 0.008386344619024322*lm - 
          0.004429155177686034*lm^2) + CF^2*(0.015221158749034186 + 
          0.005706704550855986*lm + 0.007247708472577147*lm^2) + 
        CF*((0.0035009309145952656 + 0.0004998614598621994*lm + 
            0.0008053009413974607*lm^2)*NM + (0.005040310327089516 + 
            0.0004998614598621994*lm + 0.0008053009413974607*lm^2)*NL + 
          (0.0007779067393270114 + 0.0004998614598621994*lm + 
            0.0008053009413974607*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.0189611526321347 - 0.008136923578271161*lm - 
          0.004297537843821527*lm^2) + CF^2*(0.01479681779156588 + 
          0.00553677752645269*lm + 0.0070323346535261354*lm^2) + 
        CF*((0.003379032272268677 + 0.00048496908342944453*lm + 
            0.0007813705170584595*lm^2)*NM + (0.004893657152885221 + 
            0.00048496908342944453*lm + 0.0007813705170584595*lm^2)*NL + 
          (0.0007592733708668235 + 0.00048496908342944453*lm + 
            0.0007813705170584595*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.018425106758070752 - 0.007893029792536222*lm - 
          0.004169341096889749*lm^2) + CF^2*(0.014381760096462822 + 
          0.005369704121515017*lm + 0.006822558158546861*lm^2) + 
        CF*((0.0032607795826753044 + 0.0004702901216767267*lm + 
            0.0007580620176163179*lm^2)*NM + (0.004750482470480631 + 
            0.0004702901216767267*lm + 0.0007580620176163179*lm^2)*NL + 
          (0.0007410386821029806 + 0.0004702901216767267*lm + 
            0.0007580620176163179*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.01789999580457335 - 0.007654613965702924*lm - 
          0.004044482853588195*lm^2) + CF^2*(0.01397584275595117 + 
          0.0052055522336641675*lm + 0.006618244669507956*lm^2) + 
        CF*((0.0031460875177074577 + 0.00045583460615698237*lm + 
            0.0007353605188342173*lm^2)*NM + (0.004610729500509467 + 
            0.00045583460615698237*lm + 0.0007353605188342173*lm^2)*NL + 
          (0.0007231924258942859 + 0.00045583460615698237*lm + 
            0.0007353605188342173*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.017385780432114112 - 0.0074216229660171214*lm - 
          0.0039228829053128845*lm^2) + CF^2*(0.01357892421415432 + 
          0.005044380090974118*lm + 0.006419262935966538*lm^2) + 
        CF*((0.0030348714006334424 + 0.00044161143721996613*lm + 
            0.0007132514373296154*lm^2)*NM + (0.004474340935606705 + 
            0.00044161143721996613*lm + 0.0007132514373296154*lm^2)*NL + 
          (0.00070572470425539 + 0.00044161143721996613*lm + 
            0.0007132514373296154*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.016882408215107062 - 0.007194000178274122*lm - 
          0.0038044628816667897*lm^2) + CF^2*(0.01319086414963384 + 
          0.004886236894324374*lm + 0.0062254847154547465*lm^2) + 
        CF*((0.002927047311436502 + 0.00042762845649058323*lm + 
            0.0006917205239394163*lm^2)*NM + (0.004341259072521232 + 
            0.00042762845649058323*lm + 0.0006917205239394163*lm^2)*NL + 
          (0.0006886259563159113 + 0.00042762845649058323*lm + 
            0.0006917205239394163*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.016389814767908135 - 0.006971685834381993*lm - 
          0.0036891462141620045*lm^2) + CF^2*(0.012811523379389796 + 
          0.004731163424017816*lm + 0.00603678471408328*lm^2) + 
        CF*((0.0028225321811496534 + 0.0004138925153708076*lm + 
            0.0006707538571203644*lm^2)*NM + (0.004211425933700767 + 
            0.0004138925153708076*lm + 0.0006707538571203644*lm^2)*NL + 
          (0.0006718869466159289 + 0.0004138925153708076*lm + 
            0.0006707538571203644*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.015907924797369327 - 0.006754617323482286*lm - 
          0.0035768581001623854*lm^2) + CF^2*(0.012440763781800144 + 
          0.004579192612511821*lm + 0.005853040527538448*lm^2) + 
        CF*((0.0027212438759666637 + 0.0004004095397691199*lm + 
            0.000650337836393161*lm^2)*NM + (0.004084783379055356 + 
            0.0004004095397691199*lm + 0.000650337836393161*lm^2)*NL + 
          (0.0006554987537481163 + 0.0004004095397691199*lm + 
            0.000650337836393161*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.015436653086381149 - 0.006542729482748539*lm - 
          0.003467525467108507*lm^2) + CF^2*(0.012078448236211186 + 
          0.004430350085020229*lm + 0.005674132582541193*lm^2) + 
        CF*((0.002623101271943723 + 0.0003871845912514848*lm + 
            0.0006304591758379104*lm^2)*NM + (0.0039612732085604445 + 
            0.0003871845912514848*lm + 0.0006304591758379104*lm^2)*NL + 
          (0.0006394527593278584 + 0.0003871845912514848*lm + 
            0.0006304591758379104*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.014975905412580768 - 0.006335954869924999*lm - 
          0.003361076937062236*lm^2) + CF^2*(0.011724440577126035 + 
          0.0042846546696571905*lm + 0.005499944078829114*lm^2) + 
        CF*((0.0025280243209329827 + 0.00037422192479840793*lm + 
            0.0006111048976476793*lm^2)*NM + (0.0038408372563181357 + 
            0.00037422192479840793*lm + 0.0006111048976476793*lm^2)*NL + 
          (0.0006237406372964449 + 0.00037422192479840793*lm + 
            0.0006111048976476793*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.014525579406150452 - 0.0061342240186129235*lm - 
          0.00325744279160407*lm^2) + CF^2*(0.011378605561129802 + 
          0.004142118878711302*lm + 0.005330360931715751*lm^2) + 
        CF*((0.0024359341085403215 + 0.0003615250433435567*lm + 
            0.0005922623257461945*lm^2)*NM + (0.003723417476655565 + 
            0.0003615250433435567*lm + 0.0005922623257461945*lm^2)*NL + 
          (0.0006083543435486268 + 0.0003615250433435567*lm + 
            0.0005922623257461945*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.014085565350404578 - 0.005937465677259426*lm - 
          0.0031565549371126017*lm^2) + CF^2*(0.0110408088448867 + 
          0.004002749362559559*lm + 0.005165271715275166*lm^2) + 
        CF*((0.002346752904609727 + 0.00034909674926078126*lm + 
            0.0005739190794750185*lm^2)*NM + (0.0036089560228021312 + 
            0.00034909674926078126*lm + 0.0005739190794750185*lm^2)*NL + 
          (0.0005932861058802829 + 0.00034909674926078126*lm + 
            0.0005739190794750185*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.013655746928638671 - 0.005745607032753972*lm - 
          0.003058346870451954*lm^2) + CF^2*(0.010710916972700518 + 
          0.0038665473376554424*lm + 0.005004567606194107*lm^2) + 
        CF*((0.0022604042068869574 + 0.00033693919295812124*lm + 
            0.0005560630673549007*lm^2)*NM + (0.0034973953186525327 + 
            0.00033693919295812124*lm + 0.0005560630673549007*lm^2)*NL + 
          (0.0005785284142471213 + 0.00033693919295812124*lm + 
            0.0005560630673549007*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.013236001920514332 - 0.005558573919490302*lm - 
          0.0029627536450898533*lm^2) + CF^2*(0.010388797372295195 + 
          0.003733508989953736*lm + 0.004848142328328851*lm^2) + 
        CF*((0.0021768127783826706 + 0.00032505391872951044*lm + 
            0.0005386824809254279*lm^2)*NM + (0.003388678124089978 + 
            0.00032505391872951044*lm + 0.0005386824809254279*lm^2)*NL + 
          (0.0005640740113388739 + 0.00032505391872951044*lm + 
            0.0005386824809254279*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.012826202851054186 - 0.005376291014706511*lm - 
          0.0028697118376660546*lm^2) + CF^2*(0.01007431835759909 + 
          0.0036036258550663077*lm + 0.004695892097998999*lm^2) + 
        CF*((0.0020959046789360077 + 0.00031344190800738605*lm + 
            0.0005217657886665554*lm^2)*NM + (0.0032827475943134053 + 
            0.00031344190800738605*lm + 0.0005217657886665554*lm^2)*NL + 
          (0.0005499158834447352 + 0.00031344190800738605*lm + 
            0.0005217657886665554*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.012426217595144897 - 0.005198682020873254*lm - 
          0.002779159515028172*lm^2) + CF^2*(0.009767349137455524 + 
          0.003476885176377972*lm + 0.0045477155700461*lm^2) + 
        CF*((0.002017607291447323 + 0.00030210362015225433*lm + 
            0.0005053017300051221*lm^2)*NM + (0.0031795473335839903 + 
            0.00030210362015225433*lm + 0.0005053017300051221*lm^2)*NL + 
          (0.0005360472516228669 + 0.00030210362015225433*lm + 
            0.0005053017300051221*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.01203590994026898 - 0.005025669835859443*lm - 
          0.0026910362017494843*lm^2) + CF^2*(0.00946775982928508 + 
          0.0033532702422895263*lm + 0.004403513784680974*lm^2) + 
        CF*((0.0019418493432189277 + 0.00029103903090844783*lm + 
            0.0004892793094089971*lm^2)*NM + (0.003079021443779446 + 
            0.00029103903090844783*lm + 0.0004892793094089971*lm^2)*NL + 
          (0.0005224615631529992 + 0.00029103903090844783*lm + 
            0.0004892793094089971*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.011655140110029206 - 0.004857176711566211*lm - 
          0.002605282848141067*lm^2) + CF^2*(0.009175421476838586 + 
          0.003232760703696001*lm + 0.004263190115139927*lm^2) + 
        CF*((0.0018685609228049867 + 0.0002802476686488163*lm + 
            0.00047368779057110303*lm^2)*NM + (0.002981114568119569 + 
            0.0002802476686488163*lm + 0.00047368779057110303*lm^2)*NL + 
          (0.0005091524832740409 + 0.0002802476686488163*lm + 
            0.00047368779057110303*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.011283765647473446 - 0.004693124300836943*lm - 
          0.0025218418346823917*lm^2) + CF*(0.00889020345845381 + 
          0.003115332642729512*lm + 0.004126650274934822*lm^2) + 
        0.0017976736696549587*NM + 0.0002697286218785602*lm*NM + 
        0.00045851669721498026*lm^2*NM + 0.002885772053320018*NL + 
        0.0002697286218785602*lm*NL + 0.00045851669721498026*lm^2*NL + 
        0.0004961138971590564*NH + 0.0002697286218785602*lm*NH + 
        0.00045851669721498026*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.010921640201844062 - 0.004533434219314991*lm - 
          0.0024406567900764156*lm^2) + CF*(0.008611984493697367 + 
          0.003000959821468043*lm + 0.003993802020125043*lm^2) + 
        0.0017291200397612702*NM + 0.0002594806834941336*lm*NM + 
        0.00044375578001389375*lm^2*NM + 0.0027929394681886514*NL + 
        0.0002594806834941336*lm*NL + 0.00044375578001389375*lm^2*NL + 
        0.00048333986031820725*NH + 0.0002594806834941336*lm*NH + 
        0.00044375578001389375*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.01056861658029642 - 0.004378027501044215*lm - 
          0.002361672799681337*lm^2) + CF*(0.008340635292647747 + 
          0.0028896124138557164*lm + 0.0038645554903876432*lm^2) + 
        0.0016628344866379814*NM + 0.0002495022035693825*lm*NM + 
        0.0004293950544875159*lm^2*NM + 0.0027025634515543935*NL + 
        0.0002495022035693825*lm*NL + 0.0004293950544875159*lm^2*NL + 
        0.00047082465739280404*NH + 0.0002495022035693825*lm*NH + 
        0.0004293950544875159*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.010224545280619567 - 0.004226825192761207*lm - 
          0.0022848362068146055*lm^2) + CF*(0.008076030858322647 + 
          0.0027812583378042997*lm + 0.003738822883878446*lm^2) + 
        0.0015987526338394312*NM + 0.00023979124338791396*lm*NM + 
        0.0004154247648753829*lm^2*NM + 0.0026145911632274254*NL + 
        0.00023979124338791396*lm*NL + 0.0004154247648753829*lm^2*NL + 
        0.0004585627481514143*NH + 0.00023979124338791396*lm*NH + 
        0.0004154247648753829*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.009889275346246288 - 0.004079748336989138*lm - 
          0.0022100946283545903*lm^2) + CF*(0.007818047242439329 + 
          0.00267586319929086*lm + 0.003616518482762057*lm^2) + 
        0.001536811495561694*NM + 0.00023034556875894634*lm*NM + 
        0.0004018353869735619*lm^2*NM + 0.002528970461878333*NL + 
        0.00023034556875894634*lm*NL + 0.0004018353869735619*lm^2*NL + 
        0.0004465487730102611*NH + 0.00023034556875894634*lm*NH + 
        0.0004018353869735619*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.00956265470034371 - 0.003936718074090622*lm - 
          0.0021373969258655055*lm^2) + CF*(0.0075665615749046355 + 
          0.002573390511614855*lm + 0.0034975586059617365*lm^2) + 
        0.0014769494735343476*NM + 0.00022116267525421098*lm*NM + 
        0.0003886176228846374*lm^2*NM + 0.002445649926180168*NL + 
        0.00022116267525421098*lm*NL + 0.0003886176228846374*lm^2*NL + 
        0.0004347775463161627*NH + 0.00022116267525421098*lm*NH + 
        0.0003886176228846374*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.009244530454857337 - 0.003797655736692226*lm - 
          0.0020666931772560316*lm^2) + CF*(0.007321452093439829 + 
          0.0024738019012065272*lm + 0.0033818615627825973*lm^2) + 
        0.0014191063515605863*NM + 0.00021223981193438087*lm*NM + 
        0.00037576239586473305*lm^2*NM + 0.002364578873090504*NL + 
        0.00021223981193438087*lm*NL + 0.00037576239586473305*lm^2*NL + 
        0.0004232440498641558*NH + 0.00021223981193438087*lm*NH + 
        0.00037576239586473305*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.008934749196076713 - 0.003662482936926688*lm - 
          0.001997934648971569*lm^2) + CF*(0.007082598173041654 + 
          0.0023770573007166167*lm + 0.0032693476074080225*lm^2) + 
        0.0013632232879281123*NM + 0.00020357400364614216*lm*NM + 
        0.00036326084526755806*lm^2*NM + 0.002285707373485238*NL + 
        0.00020357400364614216*lm*NL + 0.00036326084526755806*lm^2*NL + 
        0.00041194342664304805*NH + 0.00020357400364614216*lm*NH + 
        0.00036326084526755806*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.008633157248197932 - 0.0035311216469147465*lm - 
          0.0019310737687191373*lm^2) + CF*(0.006849880355020592 + 
          0.0022831151300795756*lm + 0.0031599388942676796*lm^2) + 
        0.0013092428058970838*NM + 0.00019516207196684768*lm*NM + 
        0.0003511043215852977*lm^2*NM + 0.0022089862653420964*NL + 
        0.00019516207196684768*lm*NL + 0.0003511043215852977*lm^2*NL + 
        0.0004008709748022252*NH + 0.00019516207196684768*lm*NH + 
        0.0003511043215852977*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.008339600916270347 - 0.0034034942728855947*lm - 
          0.0018660640987230833*lm^2) + CF*(0.006623180375393153 + 
          0.00219193246620655*lm + 0.003053559434274136*lm^2) + 
        0.0012571087824563255*NM + 0.00018700065486972525*lm*NM + 
        0.00033928438158601515*lm^2*NM + 0.0021343671646588806*NL + 
        0.00018700065486972525*lm*NL + 0.00033928438158601515*lm^2*NL + 
        0.00039002214183313835*NH + 0.00018700065486972525*lm*NH + 
        0.00033928438158601515*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.00805392670983244 - 0.0032795237233133124*lm - 
          0.0018028603095090103*lm^2) + CF*(0.006402381192437339 + 
          0.002103465201930269*lm + 0.002950135051923835*lm^2) + 
        0.0012067664355249338*NM + 0.00017908622517884778*lm*NM + 
        0.0003277927835470928*lm^2*NM + 0.002061802474279374*NL + 
        0.00017908622517884778*lm*NL + 0.0003277927835470928*lm^2*NL + 
        0.00037939251895899735*NH + 0.00017908622517884778*lm*NH + 
        0.0003277927835470928*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.007775981548464001 - 0.0031591334714260668*lm - 
          0.0017414181542126548*lm^2) + CF*(0.006187367013249555 + 
          0.002017668194791652*lm + 0.0028495933432570713*lm^2) + 
        0.0011581623097633043*NM + 0.00017141510787949701*lm*NM + 
        0.00031662148258411904*lm^2*NM + 0.0019912453907884827*NL + 
        0.00017141510787949701*lm*NL + 0.00031662148258411904*lm^2*NL + 
        0.00036897783572630775*NH + 0.00017141510787949701*lm*NH + 
        0.00031662148258411904*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.007505612950408705 - 0.0030422476124254447*lm - 
          0.0016816944434098102*lm^2) + CF*(0.005978023319167446 + 
          0.0019344954062271871*lm + 0.0027518636346705984*lm^2) + 
        0.0011112442611453637*NM + 0.00016398349634615784*lm*NM + 
        0.0003057626260745109*lm^2*NM + 0.00192264990962754*NL + 
        0.00016398349634615784*lm*NL + 0.0003057626260745109*lm^2*NL + 
        0.00035877395479200214*NH + 0.00016398349634615784*lm*NH + 
        0.0003057626260745109*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.007242669205352255 - 0.002928790915734824*lm - 
          0.0016236470204628623*lm^2) + CF*(0.005774236889946645 + 
          0.0018539000316870108*lm + 0.002656876942575593*lm^2) + 
        0.0010659614404323911*NM + 0.0001567874675471569*lm*NM + 
        0.00029520854917506587*lm^2*NM + 0.001855970828570741*NL + 
        0.0001567874675471569*lm*NL + 0.00029520854917506587*lm^2*NL + 
        0.00034877686690004017*NH + 0.0001567874675471569*lm*NH + 
        0.00029520854917506587*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.0069869995323765055 - 0.0028186888725782572*lm - 
          0.0015672347373789912*lm^2) + CF*(0.005575895826600496 + 
          0.001775834622185916*lm + 0.002564565933892895*lm^2) + 
        0.0010222642756781745*NM + 0.00014982299628190003*lm*NM + 
        0.00028495177043254386*lm^2*NM + 0.0017911637496943217*NL + 
        0.00014982299628190003*lm*NL + 0.00028495177043254386*lm^2*NL + 
        0.0003389826860414738*NH + 0.00014982299628190003*lm*NH + 
        0.00028495177043254386*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.006738454224048912 - 0.002711867739174792*lm - 
          0.0015124174311746622*lm^2) + CF*(0.0053828895728306805 + 
          0.0017002511977632871*lm + 0.00247486488737672*lm^2) + 
        0.0009801044538853415*NM + 0.0001430859685037593*lm*NM + 
        0.00027498498748630224*lm^2*NM + 0.001728185079961351*NL + 
        0.0001430859685037593*lm*NL + 0.00027498498748630224*lm^2*NL + 
        0.0003293876447921033*NH + 0.0001430859685037593*lm*NH + 
        0.00027498498748630224*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.006496884777549251 - 0.0026082545758174982*lm - 
          0.001459155900740638*lm^2) + CF*(0.005195108934993464 + 
          0.0016271013533030157*lm + 0.0023877096557574076*lm^2) + 
        0.0009394349019234666*NM + 0.00013657219377890162*lm*NM + 
        0.00026530107286193416*lm^2*NM + 0.0016669920305368018*NL + 
        0.00013657219377890162*lm*NL + 0.00026530107286193416*lm^2*NL + 
        0.00031998808982197885*NH + 0.00013657219377890162*lm*NH + 
        0.00026530107286193416*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.0062621440136814924 - 0.0025077772820916466*lm - 
          0.0014074118842013989*lm^2) + CF*(0.0050124461005612575 + 
          0.001556336357140824*lm + 0.002303037628693198*lm^2) + 
        0.0009002097668109532*NM + 0.00013027741692873604*lm*NM + 
        0.00025589306985479977*lm^2*NM + 0.0016075426149398746*NL + 
        0.00013027741692873604*lm*NL + 0.00025589306985479977*lm^2*NL + 
        0.0003107804775711371*NH + 0.00013027741692873604*lm*NH + 
        0.00025589306985479977*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.006034086184567766 - 0.0024103646284724272*lm - 
          0.0013571480367625564*lm^2) + CF*(0.004834794655052463 + 
          0.001487907242863973*lm + 0.0022207876965205466*lm^2) + 
        0.0008623843954546723*NM + 0.00012419732890117205*lm*NM + 
        0.00024675418850228297*lm^2*NM + 0.0015497956461333609*NL + 
        0.00012419732890117205*lm*NL + 0.00024675418850228297*lm^2*NL + 
        0.0003017613700860922*NH + 0.00012419732890117205*lm*NH + 
        0.00024675418850228297*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.005812567070773509 - 0.0023159462845293056*lm - 
          0.0013083279090395864*lm^2) + CF*(0.004662049597414283 + 
          0.0014217648946870502*lm + 0.0021409002147920503*lm^2) + 
        0.0008259153139338829*NM + 0.00011832757691352317*lm*NM + 
        0.00023787780164356116*lm^2*NM + 0.001493710732643073*NL + 
        0.00011832757691352317*lm*NL + 0.00023787780164356116*lm^2*NL + 
        0.00029292743101173873*NH + 0.00011832757691352317*lm*NH + 
        0.00023787780164356116*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.005597444068567752 - 0.0022244528439515215*lm - 
          0.0012609159258609758*lm^2) + CF*(0.00449410735385357 + 
          0.0013578601267673354*lm + 0.0020633169695906876*lm^2) + 
        0.0007907602064080023*NM + 0.00011266377390765415*lm*NM + 
        0.00022925744106563195*lm^2*NM + 0.001439248273794067*NL + 
        0.00011266377390765415*lm*NL + 0.00022925744106563195*lm^2*NL + 
        0.0002842754217334578*NH + 0.00011266377390765415*lm*NH + 
        0.00022925744106563195*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.005388576267980024 - 0.002135815846597299*lm - 
          0.001214877365538689*lm^2) + CF*(0.004330865790119815 + 
          0.0012961437568040682*lm + 0.001987981143608764*lm^2) + 
        0.0007568778937213325*NM + 0.00010720150735584529*lm*NM + 
        0.0002208867937343071*lm^2*NM + 0.0013863694541444542*NL + 
        0.00010720150735584529*lm*NL + 0.0002208867937343071*lm^2*NL + 
        0.0002758021976643509*NH + 0.00010720150735584529*lm*NH + 
        0.0002208867937343071*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.005185824522275445 - 0.002049967797758059*lm - 
          0.0011701783395986947*lm^2) + CF*(0.004172224222252346 + 
          0.0012365666742477812*lm + 0.0019148372829796824*lm^2) + 
        0.0007242283117718307*NM + 0.00010193634745383344*lm*NM + 
        0.00021275969810885358*lm^2*NM + 0.0013350362371920604*NL + 
        0.00010193634745383344*lm*NL + 0.00021275969810885358*lm^2*NL + 
        0.00026750470467266316*NH + 0.00010193634745383344*lm*NH + 
        0.00021275969810885358*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.004989051509431898 - 0.0019668421848182314*lm - 
          0.0011267857729641566*lm^2) + CF*(0.004018083425810688 + 
          0.0011790799034285912*lm + 0.001843831264850438*lm^2) + 
        0.0006927724897054109*NM + 0.0000968638547355761*lm*NM + 
        0.00020487014053893757*lm^2*NM + 0.0012852113584240058*NL + 
        0.0000968638547355761*lm*NL + 0.00020487014053893757*lm^2*NL + 
        0.0002593799756445904*NH + 0.0000968638547355761*lm*NH + 
        0.00020487014053893757*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.00479812178616781 - 0.0018863734914811388*lm - 
          0.001084667384583786*lm^2) + CF*(0.003868345643612981 + 
          0.001123634661896003*lm + 0.0017749102656825588*lm^2) + 
        0.0006624725279920598*NM + 0.00009197958714247146*lm*NM + 
        0.00019721225174250653*lm^2*NM + 0.0012368583177744096*NL + 
        0.00009197958714247146*lm*NL + 0.00019721225174250653*lm^2*NL + 
        0.0002514251271777965*NH + 0.00009197958714247146*lm*NH + 
        0.00019721225174250653*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.0046129018350356855 - 0.0018084972097218524*lm - 
          0.0010437916684977629*lm^2) + CF*(0.003722914592012468 + 
          0.0010701824142472453*lm + 0.0017080227302690666*lm^2) + 
        0.0006332915764352084*NM + 0.00008727910657804454*lm*NM + 
        0.00018978030336322963*lm^2*NM + 0.001189941371550883*NL + 
        0.00008727910657804454*lm*NL + 0.00018978030336322963*lm^2*NL + 
        0.00024363735640110082*NH + 0.00008727910657804454*lm*NH + 
        0.00018978030336322963*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.004433260105065202 - 0.0017331498496188488*lm - 
          0.0010041278753335715*lm^2) + CF*(0.003581695465746406 + 
          0.0010186749217064451*lm + 0.0016431183414549353*lm^2) + 
        0.0006051938121613029*NM + 0.00008275798497747658*lm*NM + 
        0.00018256870460610394*lm^2*NM + 0.0011444255238862045*NL + 
        0.00008275798497747658*lm*NL + 0.00018256870460610394*lm^2*NL + 
        0.00023601393791592416*NH + 0.00008275798497747658*lm*NH + 
        0.00018256870460610394*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.0042590670464101215 - 0.0016602689472077104*lm - 
          0.0009656459942240455*lm^2) + CF*(0.0034445949413953792 + 
          0.0009690642877029809*lm + 0.0015801479905484383*lm^2) + 
        0.0005781444176323392*NM + 0.00007841180991980457*lm*NM + 
        0.00017557199894982647*lm^2*NM + 0.0011002765177675932*NL + 
        0.00007841180991980457*lm*NL + 0.00017557199894982647*lm^2*NL + 
        0.0002285522208552111*NH + 0.00007841180991980457*lm*NH + 
        0.00017557199894982647*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.00409019513942547 - 0.001589793070491992*lm - 
          0.0009283167351398945*lm^2) + CF*(0.003311521179494054 + 
          0.0009213029996841117*lm + 0.0015190637484107363*lm^2) + 
        0.0005521095587202437*NM + 0.00007423618980914693*lm*NM + 
        0.00016878486093452625*lm^2*NM + 0.0010574608256922534*NL + 
        0.00007423618980914693*lm*NL + 0.00016878486093452625*lm^2*NL + 
        0.00022124962605567274*NH + 0.00007423618980914693*lm*NH + 
        0.00016878486093452625*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.003926518918575269 - 0.0015216618237386848*lm - 
          0.0008921115116289697*lm^2) + CF*(0.0031823838253368596 + 
          0.0008753439673844234*lm + 0.0014598188372110413*lm^2) + 
        0.0005270563628783799*NM + 0.00007022675864991665*lm*NM + 
        0.00016220209302344904*lm^2*NM + 0.0010159456399943794*NL + 
        0.00007022675864991665*lm*NL + 0.00016220209302344904*lm^2*NL + 
        0.00021410364333931852*NH + 0.00007022675864991665*lm*NH + 
        0.00016220209302344904*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.00376791499154649 - 0.001455815850178436*lm - 
          0.0008570024239545297*lm^2) + CF*(0.003057094008524066 + 
          0.0008311405577627134*lm + 0.001402367602834685*lm^2) + 
        0.0005029528974421169*NM + 0.00006637918043965917*lm*NM + 
        0.00015581862253718722*lm^2*NM + 0.000975698862885534*NL + 
        0.00006637918043965917*lm*NL + 0.00015581862253718722*lm^2*NL + 
        0.00020711182890036862*NH + 0.00006637918043965917*lm*NH + 
        0.00015581862253718722*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.0036142620539217005 - 0.0013921968332237889*lm - 
          0.0008229622426247814*lm^2) + CF*(0.0029355643412952545 + 
          0.0007886466268056453*lm + 0.0013466654879314604*lm^2) + 
        0.00047976814808729356*NM + 0.00006268915320189652*lm*NM + 
        0.00014962949865905117*lm^2*NM + 0.0009366890962472568*NL + 
        0.00006268915320189652*lm*NL + 0.00014962949865905117*lm^2*NL + 
        0.000200271802793758*NH + 0.00006268915320189652*lm*NH + 
        0.00014962949865905117*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.0034654408997410635 - 0.0013307474963122055*lm - 
          0.0007899643923060042*lm^2) + CF*(0.002817708915698306 + 
          0.0007478165483867913*lm + 0.0012926690055916432*lm^2) + 
        0.0004574719974725394*NM + 0.0000591524126801686*lm*NM + 
        0.0001436298895101826*lm^2*NM + 0.0008988856312119015*NL + 
        0.0000591524126801686*lm*NL + 0.0001436298895101826*lm^2*NL + 
        0.00019358124652156205*NH + 0.0000591524126801686*lm*NH + 
        0.0001436298895101826*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.003321334428263824 - 0.0012714116014744543*lm - 
          0.0007579829361116003*lm^2) + CF*(0.0027034432996428017 + 
          0.0007086052403595164*lm + 0.001240335713637164*lm^2) + 
        0.0004360352040887445*NM + 0.000055764735713332124*lm*NM + 
        0.00013781507929301823*lm^2*NM + 0.0008622584375650201*NL + 
        0.000055764735713332124*lm*NL + 0.00013781507929301823*lm^2*NL + 
        0.00018703790071378817*NH + 0.000055764735713332124*lm*NH + 
        0.00013781507929301823*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.0031818276472200795 - 0.0012141339467231283*lm - 
          0.0007269925602594641*lm^2) + CF*(0.0025926845318872023 + 
          0.0006709681880525351*lm + 0.0011896241895154869*lm^2) + 
        0.00041542938133650706*NM + 0.00005252194331110599*lm*NM + 
        0.00013218046550172075*lm^2*NM + 0.00082677815300011*NL + 
        0.00005252194331110599*lm*NL + 0.00013218046550172075*lm^2*NL + 
        0.00018063956290009184*NH + 0.00005252194331110599*lm*NH + 
        0.00013218046550172075*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.003046807672825462 - 0.001158860362350527*lm - 
          0.0006969685590901242*lm^2) + CF*(0.0024853511160093595 + 
          0.0006348614653278277*lm + 0.0011404940057838395*lm^2) + 
        0.0003956269768501018*NM + 0.00004941990344783568*lm*NM + 
        0.00012672155619820438*lm^2*NM + 0.000792416072254204*NL + 
        0.00004941990344783568*lm*NL + 0.00012672155619820438*lm^2*NL + 
        0.00017438408536908534*NH + 0.00004941990344783568*lm*NH + 
        0.00012672155619820438*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.0029161637268142345 - 0.0011055377062199302*lm - 
          0.000667886820438172*lm^2) + CF*(0.002381363013409831 + 
          0.0006002417533519544*lm + 0.001092905706171554*lm^2) + 
        0.00037660125208439736*NM + 0.00004645453359148468*lm*NM + 
        0.00012143396735239491*lm^2*NM + 0.0007591441361505905*NL + 
        0.00004645453359148468*lm*NL + 0.00012143396735239491*lm^2*NL + 
        0.00016826937311201554*NH + 0.00004645453359148468*lm*NH + 
        0.00012143396735239491*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.0027897871307302124 - 0.0010541138581293427*lm - 
          0.0006397238113495709*lm^2) + CF*(0.0022806416353972347 + 
          0.0005670663572235855*lm + 0.0010468207822083887*lm^2) + 
        0.0003583262621792014*NM + 0.00004362180298394675*lm*NM + 
        0.00011631342024537653*lm^2*NM + 0.0007269349205729091*NL + 
        0.00004362180298394675*lm*NL + 0.00011631342024537653*lm^2*NL + 
        0.00016229338184769318*NH + 0.00004362180298394675*lm*NH + 
        0.00011631342024537653*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0026675712976997586 - 0.0010045377133221314*lm - 
          0.0006124565641375115*lm^2) + CF*(0.0021831098344043745 + 
          0.0005352932205922892*lm + 0.001002201650406837*lm^2) + 
        0.0003407768361137024*NM + 0.00004091773468790552*lm*NM + 
        0.00011135573893409301*lm^2*NM + 0.0006957616253929579*NL + 
        0.00004091773468790552*lm*NL + 0.00011135573893409301*lm^2*NL + 
        0.0001564541161256578*NH + 0.00004091773468790552*lm*NH + 
        0.00011135573893409301*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.002549411721896867 - 0.0009567591752145483*lm - 
          0.0005860626627695701*lm^2) + CF*(0.0020886918943832846 + 
          0.0005048809383962373*lm + 0.0009590116299865693*lm^2) + 
        0.00032392855716201674*NM + 0.00003833840741464546*lm*NM + 
        0.00010655684777628548*lm^2*NM + 0.0006655980633727605*NL + 
        0.00003833840741464546*lm*NL + 0.00010655684777628548*lm^2*NL + 
        0.0001507496275046637*NH + 0.00003833840741464546*lm*NH + 
        0.00010655684777628548*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.0024352059658969065 - 0.0009107291474059722*lm - 
          0.000560520229579012*lm^2) + CF*(0.0019973135204265505 + 
          0.00047578876783949483*lm + 0.0009172149211292924*lm^2) + 
        0.00030775774365930685*NM + 0.000035879957146438455*lm*NM + 
        0.00010191276901436581*lm^2*NM + 0.0006364186490597757*NL + 
        0.000035879957146438455*lm*NL + 0.00010191276901436581*lm^2*NL + 
        0.00014517801280366949*NH + 0.000035879957146438455*lm*NH + 
        0.00010191276901436581*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.0023248536461030183 - 0.0008663995250337399*lm - 
          0.0005358079122931795*lm^2) + CF*(0.001908901827661389 + 
          0.0004479766377229273*lm + 0.0008767765837524755*lm^2) + 
        0.000292241430086525*NM + 0.000033538578566390526*lm*NM + 
        0.00009741962041694172*lm^2*NM + 0.0006081983876925779*NL + 
        0.000033538578566390526*lm*NL + 0.00009741962041694172*lm^2*NL + 
        0.00013973741242260867*NH + 0.000033538578566390526*lm*NH + 
        0.00009741962041694172*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.002218256416417261 - 0.0008237231855307158*lm - 
          0.000511904871371999*lm^2) + CF*(0.0018233853294619916 + 
          0.0004214051562364792*lm + 0.0008376625167905437*lm^2) + 
        0.0002773573484805293*NM + 0.00003131052630793206*lm*NM + 
        0.00009307361297672707*lm^2*NM + 0.0005809128641328796*NL + 
        0.00003131052630793206*lm*NL + 0.00009307361297672707*lm^2*NL + 
        0.00013442600873031185*NH + 0.00003131052630793206*lm*NH + 
        0.00009307361297672707*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.00211531795031745 - 0.0007826539788402144*lm - 
          0.000488790767649744*lm^2) + CF*(0.0017406939250245459 + 
          0.0003960356173146158*lm + 0.0007998394379723085*lm^2) + 
        0.00026308391017512066*NM + 0.00002919211603547012*lm*NM + 
        0.00008887104866358982*lm^2*NM + 0.0005545382318384148*NL + 
        0.00002919211603547012*lm*NL + 0.00008887104866358982*lm^2*NL + 
        0.00012924202451704034*NH + 0.00002919211603547012*lm*NH + 
        0.00008887104866358982*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.0020159439214901434 - 0.000743146717139558*lm - 
          0.0004664457502732965*lm^2) + CF*(0.0016607588863482292 + 
          0.0003718300056510789*lm + 0.000763274864083576*lm^2) + 
        0.0002494001878774455*NM + 0.00002717972536709069*lm*NM + 
        0.00008480831823150845*lm^2*NM + 0.0005290512018899359*NL + 
        0.00002717972536709069*lm*NL + 0.00008480831823150845*lm^2*NL + 
        0.00012418372150917867*NH + 0.00002717972536709069*lm*NH + 
        0.00008480831823150845*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.0019200419831603367 - 0.0007051571641203988*lm - 
          0.0004448504449302496*lm^2) + CF*(0.00158351284466425 + 
          0.0003487510004637544*lm + 0.0007279370917040449*lm^2) + 
        0.00023628589808319804*NM + 0.000025269794649601514*lm*NM + 
        0.0000808818990782272*lm^2*NM + 0.0005044290320843956*NL + 
        0.000025269794649601514*lm*NL + 0.0000808818990782272*lm^2*NL + 
        0.00011924939894371885*NH + 0.000025269794649601514*lm*NH + 
        0.0000808818990782272*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.0018275217462491616 - 0.0006686420238709563*lm - 
          0.00042398594236031087*lm^2) + CF*(0.0015088897763537758 + 
          0.0003267619780953824*lm + 0.0006937951784077814*lm^2) + 
        0.00022372138383312674*NM + 0.000023458827595639132*lm*NM + 
        0.00007708835315642015*lm^2*NM + 0.0004806495161052897*NL + 
        0.000023458827595639132*lm*NL + 0.00007708835315642015*lm^2*NL + 
        0.00011443739220025066*NH + 0.000023458827595639132*lm*NH + 
        0.00007708835315642015*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.0017382947564821458 - 0.000633558929402506*lm - 
          0.00040383378714356683*lm^2) + CF*(0.0014368249883943045 + 
          0.00030582701353103355*lm + 0.0006608189244167457*lm^2) + 
        0.00021168759781250136*NM + 0.000021743391792026958*lm*NM + 
        0.00007342432493519397*lm^2*NM + 0.0004576909727801055*NL + 
        0.000021743391792026958*lm*NL + 0.00007342432493519397*lm^2*NL + 
        0.00010974607148825338*NH + 0.000021743391792026958*lm*NH + 
        0.00007342432493519397*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.0016522744705623842 - 0.0005998664308597962*lm - 
          0.0003843759667592865*lm^2) + CF*(0.0013672551033727233 + 
          0.00028591088090872645*lm + 0.0006289788546970143*lm^2) + 
        0.0002001660857944191*NM + 0.000020120119088061932*lm*NM + 
        0.00006988653941077936*lm^2*NM + 0.0004355322354338735*NL + 
        0.000020120119088061932*lm*NL + 0.00006988653941077936*lm^2*NL + 
        0.00010517384058756129*NH + 0.000020120119088061932*lm*NH + 
        0.00006988653941077936*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0015693762315152596 - 0.0005675239834525578*lm - 
          0.0003655949009090491*lm^2) + CF*(0.00130011804410198 + 
          0.0002669790530952454*lm + 0.0005982462014875349*lm^2) + 
        0.0001891389704271197*NM + 0.00001858570587192477*lm*NM + 
        0.00006647180016528164*lm^2*NM + 0.0004141526413469231*NL + 
        0.00001858570587192477*lm*NL + 0.00006647180016528164*lm^2*NL + 
        0.00010071913563995072*NH + 0.00001858570587192477*lm*NH + 
        0.00006647180016528164*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0014895172433041 - 0.0005364919351429009*lm - 
          0.00034747343109809624*lm^2) + CF*(0.0012353530178769534 + 
          0.00024899770039513467*lm + 0.0005685928872514301*lm^2) + 
        0.00017858893536483442*NM + 0.000017136913242951442*lm*NM + 
        0.00006317698747238113*lm^2*NM + 0.00039353202132412236*NL + 
        0.000017136913242951442*lm*NL + 0.00006317698747238113*lm^2*NL + 
        0.00009638042398986973*NH + 0.000017136913242951442*lm*NH + 
        0.00006317698747238113*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.0014126165448093422 - 0.0005067315141211484*lm - 
          0.000329994810468921*lm^2) + CF*(0.0011729005004037694 + 
          0.00023193368845697253*lm + 0.0005399915080400526*lm^2) + 
        0.00016849920974110444*NM + 0.000015770567087070048*lm*NM + 
        0.00005999905644889473*lm^2*NM + 0.00037365068938210745*NL + 
        0.000015770567087070048*lm*NL + 0.00005999905644889473*lm^2*NL + 
        0.00009215620307240155*NH + 0.000015770567087070048*lm*NH + 
        0.00005999905644889473*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0013385949832573694 - 0.00047820481610054395*lm - 
          0.00031314269388121787*lm^2) + CF*(0.0011127022194354773 + 
          0.0002157545754373635*lm + 0.0005124153172601747*lm^2) + 
        0.0001588535529829726*NM + 0.000014483558062296413*lm*NM + 
        0.00005693503525113052*lm^2*NM + 0.0003544894325602954*NL + 
        0.000014483558062296413*lm*NL + 0.00005693503525113052*lm^2*NL + 
        0.00008804499934662227*NH + 0.000014483558062296413*lm*NH + 
        0.00005693503525113052*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.0012673751871791808 - 0.0004508747914592726*lm - 
          0.000296901128232432*lm^2) + CF*(0.0010547011381456667 + 
          0.00020042860847961457*lm + 0.00048583820983488877*lm^2) + 
        0.00014963623996396935*NM + 0.000013272841500792567*lm*NM + 
        0.00005398202331498764*lm^2*NM + 0.0003360295008608048*NL + 
        0.000013272841500792567*lm*NL + 0.00005398202331498764*lm^2*NL + 
        0.000084045367272579*NH + 0.000013272841500792567*lm*NH + 
        0.00005398202331498764*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.0011988815389733845 - 0.0004247052322563481*lm - 
          0.0002812545430132586*lm^2) + CF*(0.000998841438270293 + 
          0.00018592471956077107*lm + 0.00046023470674896855*lm^2) + 
        0.00014083204649337712*NM + 0.000012135437233623291*lm*NM + 
        0.000051137189638774283*lm^2*NM + 0.00031825259732179596*NL + 
        0.000012135437233623291*lm*NL + 0.000051137189638774283*lm^2*NL + 
        0.00008015588833017893*NH + 0.000012135437233623291*lm*NH + 
        0.000051137189638774283*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.0011330401471427182 - 0.00039966075914614084*lm - 
          0.00026618774109255405*lm^2) + CF*(0.0009450685030466732 + 
          0.00017221252075757477*lm + 0.00043557993996963393*lm^2) + 
        0.00013242623513886576*NM + 0.000011068429343996566*lm*NM + 
        0.0000483977711077371*lm^2*NM + 0.0003011408682281645*NL + 
        0.000011068429343996566*lm*NL + 0.0000483977711077371*lm^2*NL + 
        0.00007637517007834262*NH + 0.000011068429343996566*lm*NH + 
        0.0000483977711077371*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0010697788182682994 - 0.00037570680821464165*lm - 
          0.00025168588972623434*lm^2) + CF*(0.000893328899977337 + 
          0.0001592622989789564*lm + 0.000411849637733838*lm^2) + 
        0.00012440454137923904*NM + 0.0000100689658544426*lm*NM + 
        0.000045761070859315334*lm^2*NM + 0.00028467689346299346*NL + 
        0.0000100689658544426*lm*NL + 0.000045761070859315334*lm^2*NL + 
        0.00007270184525283393*NH + 0.0000100689658544426*lm*NH + 
        0.000045761070859315334*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.0010090270287811392 - 0.00035280961775897287*lm - 
          0.00023773451178484394*lm^2) + CF*(0.0008435703634451535 + 
          0.0001470450102098827*lm + 0.000389020110193381*lm^2) + 
        0.00011675316008371686*NM + 9.134258353072504*^-6*lm*NM + 
        0.000043224456688153445*lm^2*NM + 0.00026884367700267565*NL + 
        9.134258353072504*^-6*lm*NL + 0.000043224456688153445*lm^2*NL + 
        0.000069134570901238*NH + 9.134258353072504*^-6*lm*NH + 
        0.000043224456688153445*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0009507158965860586 - 0.0003309362150301641*lm - 
          0.00022431947719459203*lm^2) + CF*(0.0007957417772049205 + 
          0.00013553227330873415*lm + 0.0003670682354093324*lm^2) + 
        0.000109458732313898*NM + 8.261581563760602*^-6*lm*NM + 
        0.00004078535948992582*lm^2*NM + 0.00025362463755816*NL + 
        8.261581563760602*^-6*lm*NL + 0.00004078535948992582*lm^2*NL + 
        0.00006567202755361474*NH + 8.261581563760602*^-6*lm*NH + 
        0.00004078535948992582*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0008947781525890202 - 0.00031005440295780014*lm - 
          0.00021142699458675846*lm^2) + CF*(0.0007497931567753929 + 
          0.000124696363397887*lm + 0.00034597144568742293*lm^2) + 
        0.0001025083324442994*NM + 7.448272864812946*^-6*lm*NM + 
        0.00003844127174304699*lm^2*NM + 0.0002390035993643555*NL + 
        7.448272864812946*^-6*lm*NL + 0.00003844127174304699*lm^2*NL + 
        0.00006231291842740926*NH + 7.448272864812946*^-6*lm*NH + 
        0.00003844127174304699*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0008411481121750281 - 0.00029013274687382274*lm - 
          0.00019904360315048234*lm^2) + CF*(0.000705675631754548 + 
          0.00011451020488480382*lm + 0.00032570771424624386*lm^2) + 
        0.00009588945559714862*NM + 6.691731760418132*^-6*lm*NM + 
        0.00003618974602736043*lm^2*NM + 0.00022496478311933443*NL + 
        6.691731760418132*^-6*lm*NL + 0.00003618974602736043*lm^2*NL + 
        0.000059055968665254036*NH + 6.691731760418132*^-6*lm*NH + 
        0.00003618974602736043*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0007897616466801136 - 0.00027114056125151186*lm - 
          0.00018715616468405132*lm^2) + CF*(0.0006633414280797311 + 
          0.00010494736414869507*lm + 0.0003062555422102658*lm^2) + 
        0.00008959000538691555*NM + 5.989419308924159*^-6*lm*NM + 
        0.000034028393578918426*lm^2*NM + 0.00021149279707461595*NL + 
        5.989419308924159*^-6*lm*NL + 0.000034028393578918426*lm^2*NL + 
        0.000055899924604347595*NH + 5.989419308924159*^-6*lm*NH + 
        0.000034028393578918426*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0007405561548975277 - 0.0002530478964744965*lm - 
          0.00017575185583991584*lm^2) + CF*(0.0006227438502532086 + 
          0.000095982041925692*lm + 0.0002875939459198623*lm^2) + 
        0.00008359828196990158*NM + 5.338857511746105*^-6*lm*NM + 
        0.000031954882879984696*lm^2*NM + 0.00019857262827747906*NL + 
        5.338857511746105*^-6*lm*NL + 0.000031954882879984696*lm^2*NL + 
        0.00005284355307614412*NH + 5.338857511746105*^-6*lm*NH + 
        0.000031954882879984696*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.0006934705346550682 - 0.00023582552564952946*lm - 
          0.00016481816055875667*lm^2) + CF*(0.0005838372635525624 + 
          0.00008758906542346382*lm + 0.0002697024445506928*lm^2) + 
        0.00007790297039406277*NM + 4.737628666483151*^-6*lm*NM + 
        0.000029966938283410306*lm^2*NM + 0.00018618963396594632*NL + 
        4.737628666483151*^-6*lm*NL + 0.000029966938283410306*lm^2*NL + 
        0.000049885640735135516*NH + 4.737628666483151*^-6*lm*NH + 
        0.000029966938283410306*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.0006484451544974806 - 0.0002194449314757166*lm - 
          0.00015434286268803702*lm^2) + CF*(0.000546577076244308 + 
          0.00007974388019431224*lm + 0.00025256104803496966*lm^2) + 
        0.00007249312924412054*NM + 4.183374687609329*^-6*lm*NM + 
        0.000028062338670552187*lm^2*NM + 0.00017432953311679786*NL + 
        4.183374687609329*^-6*lm*NL + 0.000028062338670552187*lm^2*NL + 
        0.000047024993415553394*NH + 4.183374687609329*^-6*lm*NH + 
        0.000028062338670552187*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.000605421825505071 - 0.0002038782931819021*lm - 
          0.0001443140387805711*lm^2) + CF*(0.0005109197218180907 + 
          0.0000724225417939797*lm + 0.00023615024527729817*lm^2) + 
        0.00006735817957691268*NM + 3.67379639789963*^-6*lm*NM + 
        0.000026238916141922018*lm^2*NM + 0.00016297839814671523*NL + 
        3.67379639789963*^-6*lm*NL + 0.000026238916141922018*lm^2*NL + 
        0.000044260435514862516*NH + 3.67379639789963*^-6*lm*NH + 
        0.000026238916141922018*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.0005643437732770453 - 0.00018909847354298598*lm - 
          0.00013472005106874224*lm^2) + CF*(0.00047682264125782896 + 
          0.00006560170725170806*lm + 0.00022045099265794184*lm^2) + 
        0.00006248789414185272*NM + 3.2066527935612312*^-6*lm*NM + 
        0.000024494554739771314*lm^2*NM + 0.0001521226467664168*NL + 
        3.2066527935612312*^-6*lm*NL + 0.000024494554739771314*lm^2*NL + 
        0.00004159080940296*NH + 3.2066527935612312*^-6*lm*NH + 
        0.000024494554739771314*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.00052515561010563 - 0.0001750790059850744*lm - 
          0.00012554954061010058*lm^2) + CF*(0.00044424426536521016 + 
          0.00005925862637547692*lm + 0.00020544470281652825*lm^2) + 
        0.000057872386881299706*NM + 2.7797602858580235*^-6*lm*NM + 
        0.00002282718920183647*lm^2*NM + 0.0001417490339874271*NL + 
        2.7797602858580235*^-6*lm*NL + 0.00002282718920183647*lm^2*NL + 
        0.00003901497485603566*NH + 2.7797602858580235*^-6*lm*NH + 
        0.00002282718920183647*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.00048780330736473136 - 0.00016179408178854278*lm - 
          0.00011679142060016849*lm^2) + CF*(0.00041314399715002806 + 
          0.00005337113291483117*lm + 0.0001911132337093666*lm^2) + 
        0.000053502102705588*NM + 2.3909919218448216*^-6*lm*NM + 
        0.00002123480374548518*lm^2*NM + 0.0001318446442809234*NL + 
        2.3909919218448216*^-6*lm*NL + 0.00002123480374548518*lm^2*NL + 
        0.00003653180851408874*NH + 2.3909919218448216*^-6*lm*NH + 
        0.00002123480374548518*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.00045223416813473783 - 0.00014921853739731773*lm - 
          0.0001084348698483756*lm^2) + CF*(0.00038348219430095286 + 
          0.000047917635602269874*lm + 0.00017743887793370556*lm^2) + 
        0.000049367807537429704*NM + 2.0382765866650687*^-6*lm*NM + 
        0.000019715430881522838*lm^2*NM + 0.00012239688388791966*NL + 
        2.0382765866650687*^-6*lm*NL + 0.000019715430881522838*lm^2*NL + 
        0.00003414020336113442*NH + 2.0382765866650687*^-6*lm*NH + 
        0.000019715430881522838*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0004183968000830553 - 0.0001373278418419593*lm - 
          0.00010046932641314076*lm^2) + CF*(0.00035522015174947123 + 
          0.00004287710909281091*lm + 0.00016440435231241215*lm^2) + 
        0.00004546057862037754*NM + 1.7195981897120986*^-6*lm*NM + 
        0.00001826715025693468*lm^2*NM + 0.00011339347327988164*NL + 
        1.7195981897120986*^-6*lm*NL + 0.00001826715025693468*lm^2*NL + 
        0.000031839068227170696*NH + 1.7195981897120986*^-6*lm*NH + 
        0.00001826715025693468*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0003862410886180844 - 0.0001260980842834395*lm - 
          0.0000928844813922082*lm^2) + CF*(0.00032832008433890706 + 
          0.00003822908482006136*lm + 0.00015199278773270433*lm^2) + 
        0.000041771795086023255*NM + 1.4329948368085897*^-6*lm*NM + 
        0.000016888087525856037*lm^2*NM + 0.00010482243976871585*NL + 
        1.4329948368085897*^-6*lm*NL + 0.000016888087525856037*lm^2*NL + 
        0.000029627327311011762*NH + 1.4329948368085897*^-6*lm*NH + 
        0.000016888087525856037*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.0003557181703325892 - 0.00011550596168387401*lm - 
          0.00008567027286443756*lm^2) + CF*(0.0003027451096096379 + 
          0.000033953641785910974*lm + 0.000140187719232716*lm^2) + 
        0.000038293128774604594*NM + 1.1765579904212934*^-6*lm*NM + 
        0.000015576413248079556*lm^2*NM + 0.00009667211026493707*NL + 
        1.1765579904212934*^-6*lm*NL + 0.000015576413248079556*lm^2*NL + 
        0.000027503919723128342*NH + 1.1765579904212934*^-6*lm*NH + 
        0.000015576413248079556*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.0003267804067507634 - 0.00010552876660986052*lm - 
          0.00007881687997933427*lm^2) + CF*(0.0002784592307108635 + 
          0.000030031397299819638*lm + 0.00012897307632981972*lm^2) + 
        0.00003501653530370159*NM + 9.48431619798113*^-7*lm*NM + 
        0.000014330341814424414*lm^2*NM + 0.00008893110418269563*NL + 
        9.48431619798113*^-7*lm*NL + 0.000014330341814424414*lm^2*NL + 
        0.000025467799047668813*NH + 9.48431619798113*^-7*lm*NH + 
        0.000014330341814424414*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.00029938135839176634 - 0.00009614437517351168*lm - 
          0.00007231471719069526*lm^2) + CF*(0.0002554273194485477 + 
          0.0000264434976825872*lm + 0.00011833317358477406*lm^2) + 
        0.00003193424537971998*NM + 7.468113427916509*^-7*lm*NM + 
        0.000013148130398308228*lm^2*NM + 0.00008158832649023313*NL + 
        7.468113427916509*^-7*lm*NL + 0.000013148130398308228*lm^2*NL + 
        0.00002351793292286674*NH + 7.468113427916509*^-7*lm*NH + 
        0.000013148130398308228*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.0002734757591610685 - 0.00008733123511574103*lm - 
          0.00006615442863082947*lm^2) + CF*(0.00023361509947845746 + 
          0.00002317160894847164*lm + 0.00010825270139590278*lm^2) + 
        0.000029038756346883966*NM + 5.699435610171678*^-7*lm*NM + 
        0.000012028077932878086*lm^2*NM + 0.00007463296090423475*NL + 
        5.699435610171678*^-7*lm*NL + 0.000012028077932878086*lm^2*NL + 
        0.00002165330263907132*NH + 5.699435610171678*^-7*lm*NH + 
        0.000012028077932878086*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0002490194910796131 - 0.00007906835403586228*lm - 
          0.00006032688262189704*lm^2) + CF*(0.00021298912965254946 + 
          0.00002019790747855603*lm + 0.0000987167170176497*lm^2) + 
        0.00002632282396849336*NM + 4.1612458988308253*^-7*lm*NM + 
        0.000010968524113072189*lm^2*NM + 0.00006805446322645632*NL + 
        4.1612458988308253*^-7*lm*NL + 0.000010968524113072189*lm^2*NL + 
        0.00001987290275366693*NH + 4.1612458988308253*^-7*lm*NH + 
        0.000010968524113072189*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.0002259695593595529 - 0.00007133528777109651*lm - 
          0.00005482316632099238*lm^2) + CF*(0.00019351678752631304 + 
          0.000017505070697353536*lm + 0.00008971063579798752*lm^2) + 
        0.00002377945443523836*NM + 2.836997849284017*^-7*lm*NM + 
        9.967848421998614*^-6*lm^2*NM + 0.000061842554820924*NL + 
        2.836997849284017*^-7*lm*NL + 9.967848421998614*^-6*lm^2*NL + 
        0.000018175740722176668*NH + 2.836997849284017*^-7*lm*NH + 
        9.967848421998614*^-6*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.00020428406783416474 - 0.00006411212892914503*lm - 
          0.00004963458049567757*lm^2) + CF*(0.00017516625303406534 + 
          0.000015076267763779573*lm + 0.00008122022262929057*lm^2) + 
        0.000021401896595410695*NM + 1.7106266580346046*^-7*lm*NM + 
        9.024469181032286*^-6*lm^2*NM + 0.00005598721622993301*NL + 
        1.7106266580346046*^-7*lm*NL + 9.024469181032286*^-6*lm^2*NL + 
        0.00001656083654487219*NH + 1.7106266580346046*^-7*lm*NH + 
        9.024469181032286*^-6*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.00018392219474846404 - 0.00005737949557657722*lm - 
          0.00004475263442675089*lm^2) + CF*(0.0001579064923386065 + 
          0.000012895150286808634*lm + 0.00007323158360741054*lm^2) + 
        0.000019183634401899698*NM + 7.665403913780103*^-8*lm*NM + 
        8.136842623045616*^-6*lm^2*NM + 0.00005047868092701019*NL + 
        7.665403913780103*^-8*lm*NL + 8.136842623045616*^-6*lm^2*NL + 
        0.000015027222428238902*NH + 7.665403913780103*^-8*lm*NH + 
        8.136842623045616*^-6*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.00016484416891603736 - 0.000051118520085399735*lm - 
          0.000040169040935112445*lm^2) + CF*(0.00014170724186108504 + 
          0.000010945843075367949*lm + 0.00006573115789382036*lm^2) + 
        0.000017118379570917043*NM - 1.0388785483829105*^-9*lm*NM + 
        7.303461988202262*^-6*lm^2*NM + 0.000045307429204949114*NL - 
        1.0388785483829105*^-9*lm*NL + 7.303461988202262*^-6*lm^2*NL + 
        0.000013573942460671042*NH - 1.0388785483829105*^-9*lm*NH + 
        7.303461988202262*^-6*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.00014701124624667957 - 0.00004531083813981645*lm - 
          0.0000358757115296648*lm^2) + CF*(0.00012653899249638866 + 
          9.212934931298063*^-6*lm + 0.00005870570977581513*lm^2) + 
        0.000015200064447453323*NM - 6.348333681531018*^-8*lm*NM + 
        6.522856641757237*^-6*lm^2*NM + 0.0000404641821969804*NL - 
        6.348333681531018*^-8*lm*NL + 6.522856641757237*^-6*lm^2*NL + 
        0.000012200052301795851*NH - 6.348333681531018*^-8*lm*NH + 
        6.522856641757237*^-6*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.00013038568664855424 - 0.00003993857790485395*lm - 
          0.000031864751673260106*lm^2) + CF*(0.00011237297401886831 + 
          7.681469493529902*^-6*lm + 0.00005214232091988018*lm^2) + 
        0.000013422835072532575*NM - 1.1210192516112523*^-7*lm*NM + 
        5.79359121332002*^-6*lm^2*NM + 0.000035939896029098516*NL - 
        1.1210192516112523*^-7*lm*NL + 5.79359121332002*^-6*lm^2*NL + 
        0.000010904618884849822*NH - 1.1210192516112523*^-7*lm*NH + 
        5.79359121332002*^-6*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.00011493073130779302 - 0.000034984349358215726*
           lm - 0.00002812845616377792*lm^2) + 
        CF*(0.00009918113968271935 + 6.33693614098636*^-6*lm + 
          0.00004602838281345478*lm^2) + 0.00001178104444739753*NM - 
        1.482734438432707*^-7*lm*NM + 5.114264757050531*^-6*lm^2*NM + 
        0.00003172575610153239*NL - 1.482734438432707*^-7*lm*NL + 
        5.114264757050531*^-6*lm^2*NL + 9.68672013155284*^-6*NH - 
        1.482734438432707*^-7*lm*NH + 5.114264757050531*^-6*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.00010061058034770423 - 0.000030431233786437177*lm - 
          0.00002465930462748858*lm^2) + CF*(0.00008693615102088363 + 
          5.165260961112079*^-6*lm + 0.000040351589390435864*lm^2) + 
        0.000010269245989827665*NM - 1.7333377081043313*^-7*lm*NM + 
        4.483509932270651*^-6*lm^2*NM + 0.00002781317149731861*NL - 
        1.7333377081043313*^-7*lm*NL + 4.483509932270651*^-6*lm^2*NL + 
        8.545444678948044*^-6*NH - 1.7333377081043313*^-7*lm*NH + 
        4.483509932270651*^-6*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.00008739037086907062 - 0.000026262773446142145*
           lm - 0.000021449957121926437*lm^2) + 
        CF*(0.00007561136284589919 + 4.152797790365746*^-6*lm + 
          0.00003509992983587962*lm^2) + 8.882187177864141*^-6*NM - 
        1.885767239571323*^-7*lm*NM + 3.8999922039866245*^-6*lm^2*NM + 
        0.000024193769515913064*NL - 1.885767239571323*^-7*lm*NL + 
        3.8999922039866245*^-6*lm^2*NL + 7.47989161769642*^-6*NH - 
        1.885767239571323*^-7*lm*NH + 3.8999922039866245*^-6*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.00007523615537237809 - 0.000022462961390949322*lm - 
          0.000018493249845564868*lm^2) + CF*(0.00006518080845570914 + 
          3.286319332473221*^-6*lm + 0.000030261681565469783*lm^2) + 
        7.614803376289886*^-6*NM - 1.9525491797463812*^-7*lm*NM + 
        3.362409062829976*^-6*lm^2*NM + 0.00002085939032975865*NL - 
        1.9525491797463812*^-7*lm*NL + 3.362409062829976*^-6*lm^2*NL + 
        6.4891702413355695*^-6*NH - 1.9525491797463812*^-7*lm*NH + 
        3.362409062829976*^-6*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.00006411488056222766 - 0.00001901623146434157*lm - 
          0.000015782190951651456*lm^2) + CF*(0.00005561918504704806 + 
          2.55300835973522*^-6*lm + 0.000025825403375429658*lm^2) + 
        6.462211841289096*^-6*NM - 1.9458061512996923*^-7*lm*NM + 
        2.8694892639366286*^-6*lm^2*NM + 0.00001780208176171341*NL - 
        1.9458061512996923*^-7*lm*NL + 2.8694892639366286*^-6*lm^2*NL + 
        5.572399806031703*^-6*NH - 1.9458061512996923*^-7*lm*NH + 
        2.8694892639366286*^-6*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.00005399436653363823 - 0.000015907448458592942*lm - 
          0.000013309956463626317*lm^2) + CF*(0.00004690183933865071 + 
          1.9404490022085897*^-6*lm + 0.000021779928758661246*lm^2) + 
        5.41970589878801*^-6*NM - 1.8772656935943904*^-7*lm*NM + 
        2.419992084295694*^-6*lm^2*NM + 0.000015014094181234076*NL - 
        1.8772656935943904*^-7*lm*NL + 2.419992084295694*^-6*lm^2*NL + 
        4.728709300372807*^-6*NH - 1.8772656935943904*^-7*lm*NH + 
        2.419992084295694*^-6*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.0000448432863394467 - 0.00001312189843964531*lm - 
          0.000011069886289610028*lm^2) + CF*(0.0000390047534061751 + 
          1.4366181291336831*^-6*lm + 0.000018114359382998227*lm^2) + 
        4.48274929205774*^-6*NM - 1.758268631147431*^-7*lm*NM + 
        2.012706598110914*^-6*lm^2*NM + 0.000012487875517204771*NL - 
        1.758268631147431*^-7*lm*NL + 2.012706598110914*^-6*lm^2*NL + 
        3.957237224769124*^-6*NH - 1.758268631147431*^-7*lm*NH + 
        2.012706598110914*^-6*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.000036631145937550526 - 0.000010645279237638387*
           lm - 9.055480333509445*^-6*lm^2) + CF*(0.00003190453073039768 + 
          1.0298768265605957*^-6*lm + 0.00001481805872756091*lm^2) + 
        3.6469706942398134*^-6*NM - 1.5997773644809883*^-7*lm*NM + 
        1.6464509697289902*^-6*lm^2*NM + 0.000010216066385298983*NL - 
        1.5997773644809883*^-7*lm*NL + 1.6464509697289902*^-6*lm^2*NL + 
        3.2571313800446022*^-6*NH - 1.5997773644809883*^-7*lm*NH + 
        1.6464509697289902*^-6*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.000029328264516314157 - 8.463691102622858*^-6*lm - 
          7.260394700350157*^-6*lm^2) + CF*(0.000025578382459922895 + 
          7.089619747325744*^-7*lm + 0.000011880645873300258*lm^2) + 
        2.908158381535835*^-6*NM - 1.412384078686076*^-7*lm*NM + 
        1.3200717637000285*^-6*lm^2*NM + 8.191495327764363*^-6*NL - 
        1.412384078686076*^-7*lm*NL + 1.3200717637000285*^-6*lm^2*NL + 
        2.6275486648197582*^-6*NH - 1.412384078686076*^-7*lm*NH + 
        1.3200717637000285*^-6*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.000022905755196072105 - 6.563627524825207*^-6*lm - 
          5.678437993503416*^-6*lm^2) + CF*(0.000020004113889351258 + 
          4.6297792841440445*^-7*lm + 9.29198944391468*^-6*lm^2) + 
        2.262255062883955*^-6*NM - 1.2063188654496766*^-7*lm*NM + 
        1.0324432715460756*^-6*lm^2*NM + 6.407174163524693*^-6*NL - 
        1.2063188654496766*^-7*lm*NL + 1.0324432715460756*^-6*lm^2*NL + 
        2.067654881302647*^-6*NH - 1.2063188654496766*^-7*lm*NH + 
        1.0324432715460756*^-6*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.000017335506104306256 - 4.931966218684073*^-6*lm - 
          4.303567701533111*^-6*lm^2) + CF*(0.000015160111153569195 + 
          2.8138830300574446*^-7*lm + 7.042201693417818*^-6*lm^2) + 
        1.7053528620265288*^-6*NM - 9.914577547006204*^-8*lm*NM + 
        7.82466854824202*^-7*lm^2*NM + 4.856293446500647*^-6*NL - 
        9.914577547006204*^-8*lm*NL + 7.82466854824202*^-7*lm^2*NL + 
        1.5766245491201765*^-6*NH - 9.914577547006204*^-8*lm*NH + 
        7.82466854824202*^-7*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.000012590161821750183 - 3.555960269740917*^-6*lm - 
          3.129886672444691*^-6*lm^2) + CF*(0.000011025328138559168 + 
          1.5400786895301065*^-7*lm + 5.121632736727676*^-6*lm^2) + 
        1.2336884479552383*^-6*NM - 7.773306524091875*^-8*lm*NM + 
        5.690703040808529*^-7*lm^2*NM + 3.532218030061018*^-6*NL - 
        7.773306524091875*^-8*lm*NL + 5.690703040808529*^-7*lm^2*NL + 
        1.1536407268370125*^-6*NH - 7.773306524091875*^-8*lm*NH + 
        5.690703040808529*^-7*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-8.643105196377896*^-6 - 2.4232294433415695*^-6*lm - 
          2.1516396731729913*^-6*lm^2) + CF*(7.579273608879573*^-6 + 
          7.099455666731929*^-8*lm + 3.520864919737622*^-6*lm^2) + 
        8.436383098018782*^-7*NM - 5.7312918143216786*^-8*lm*NM + 
        3.9120721330418025*^-7*lm^2*NM + 2.428482735528222*^-6*NL - 
        5.7312918143216786*^-8*lm*NL + 3.9120721330418025*^-7*lm^2*NL + 
        7.978948408237094*^-7*NH - 5.7312918143216786*^-8*lm*NH + 
        3.9120721330418025*^-7*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-5.4684395219658544*^-6 - 1.5217516539893532*^-6*lm - 
          1.3632100321996727*^-6*lm^2) + CF*(4.801998551729804*^-6 + 
          2.2841573869120655*^-8*lm + 2.2307073254176464*^-6*lm^2) + 
        5.31714172324835*^-7*NM - 3.877144226301708*^-8*lm*NM + 
        2.4785636949084957*^-7*lm^2*NM + 1.5387881226763644*^-6*NL - 
        3.877144226301708*^-8*lm*NL + 2.4785636949084957*^-7*lm^2*NL + 
        5.085865211495895*^-7*NH - 3.877144226301708*^-8*lm*NH + 
        2.4785636949084957*^-7*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-3.040971077673981*^-6 - 8.398545940843346*^-7*lm - 
          7.591163632434457*^-7*lm^2) + CF*(2.674083737296214*^-6 + 
          3.696370114351201*^-10*lm + 1.2421904125801838*^-6*lm^2) + 
        2.94558548222855*^-7*NM - 2.2962455379843945*^-8*lm*NM + 
        1.3802115695335374*^-7*lm^2*NM + 8.569963601763404*^-7*NL - 
        2.2962455379843945*^-8*lm*NL + 1.3802115695335374*^-7*lm^2*NL + 
        2.849234441892004*^-7*NH - 2.2962455379843945*^-8*lm*NH + 
        1.3802115695335374*^-7*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-1.3361920248721001*^-6 - 3.6620752068614735*^-7*lm - 
          3.3400936801747815*^-7*lm^2) + CF*(1.176627494868745*^-6 - 
          5.28068181793835*^-9*lm + 5.465607840286006*^-7*lm^2) + 
        1.2894042358889972*^-7*NM - 1.0708238424745013*^-8*lm*NM + 
        6.072897600317785*^-8*lm^2*NM + 3.771271939604819*^-7*NL - 
        1.0708238424745013*^-8*lm*NL + 6.072897600317785*^-8*lm^2*NL + 
        1.2612118164400427*^-7*NH - 1.0708238424745013*^-8*lm*NH + 
        6.072897600317785*^-8*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-3.3026365724088926*^-7 - 8.981319884937163*^-8*lm - 
          8.26687160983859*^-8*lm^2) + CF*(2.912337040252124*^-7 - 
          2.65649135017295*^-9*lm + 1.3527608088826783*^-7*lm^2) + 
        3.175107289760696*^-8*NM - 2.800278314616769*^-9*lm*NM + 
        1.503067565425198*^-8*lm^2*NM + 9.33540114988208*^-8*NL - 
        2.800278314616769*^-9*lm*NL + 1.503067565425198*^-8*lm^2*NL + 
        3.1403055693272374*^-8*NH - 2.800278314616769*^-9*lm*NH + 
        1.503067565425198*^-8*lm^2*NH)}, {1., 0.}}
 
CbarLTable["v", 2, 2] = {{0., -1.286008230452675*^-7*CF*NC*
       (CF*(-769577.7091909414 - 97666.17974587942*lm - 777600.*lm^2) + 
        4.*CA*(-6575.71205023619 + 127610.61095281024*lm + 59400.*lm^2) + 
        20.*((-5945.359133912704 - 1891.294943738554*lm - 2160.*lm^2)*NM + 
          (-5945.359133912704 - 1891.294943738554*lm - 2160.*lm^2)*NL + 
          (987.1190910339575 - 1891.294943738554*lm - 2160.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.002166536793161061 - 0.06514608160454964*lm - 
          0.02978732519421019*lm^2) + CF*(0.09341629674260475 + 
          0.016018188717680144*lm + 0.0974857915446879*lm^2) + 
        0.015709657274405268*NM + 0.004951807354233114*lm*NM + 
        0.005415877308038216*lm^2*NM + 0.01571120003486984*NL + 
        0.004951807354233114*lm*NL + 0.005415877308038216*lm^2*NL - 
        0.0024896551010208435*NH + 0.004951807354233114*lm*NH + 
        0.005415877308038216*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.007399369379959829 - 0.0645921119552623*lm - 
          0.029015006199910678*lm^2) + CF*(0.0883210023772664 + 
          0.019317821224424946*lm + 0.09495820210879857*lm^2) + 
        0.016067156883731212*NM + 0.005029804044779105*lm*NM + 
        0.005275455672711032*lm^2*NM + 0.016075514130267136*NL + 
        0.005029804044779105*lm*NL + 0.005275455672711032*lm^2*NL - 
        0.0024400209404646833*NH + 0.005029804044779105*lm*NH + 
        0.005275455672711032*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.01222655068335226 - 0.06397195047676554*lm - 
          0.028243442253251056*lm^2) + CF*(0.08371168429816458 + 
          0.022395827635909558*lm + 0.09243308373791255*lm^2) + 
        0.016353045586355152*NM + 0.00509559113551911*lm*NM + 
        0.0051351713187729195*lm^2*NM + 0.016374803943258055*NL + 
        0.00509559113551911*lm*NL + 0.0051351713187729195*lm^2*NL - 
        0.002390129778244101*NH + 0.00509559113551911*lm*NH + 
        0.0051351713187729195*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.016624872450530827 - 0.06328490202408023*lm - 
          0.027476080630836404*lm^2) + CF*(0.07955810447076227 + 
          0.025227112530874462*lm + 0.08992171842819187*lm^2) + 
        0.016566704985837392*NM + 0.0051482445195565755*lm*NM + 
        0.004995651023788437*lm^2*NM + 0.016608629432290883*NL + 
        0.0051482445195565755*lm*NL + 0.004995651023788437*lm^2*NL - 
        0.0023401008725265162*NH + 0.0051482445195565755*lm*NH + 
        0.004995651023788437*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.020596098140964067 - 0.06253369430847884*lm - 
          0.02671554510335068*lm^2) + CF*(0.07581710884622542 + 
          0.02780323403614649*lm + 0.08743269306551131*lm^2) + 
        0.016711168871012302*NM + 0.005187652990848887*lm*NM + 
        0.0048573718369728505*lm^2*NM + 0.016779692001469827*NL + 
        0.005187652990848887*lm*NL + 0.0048573718369728505*lm^2*NL - 
        0.002290036987516076*NH + 0.005187652990848887*lm*NH + 
        0.0048573718369728505*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.024153998277212638 - 0.061722677632778424*lm - 
          0.02596388626364501*lm^2) + CF*(0.0724438278244953 + 
          0.030124854920666137*lm + 0.08497271868102003*lm^2) + 
        0.01679104433209015*NM + 0.00521413299619062*lm*NM + 
        0.004720706593390002*lm^2*NM + 0.016892011387045443*NL + 
        0.00521413299619062*lm*NL + 0.004720706593390002*lm^2*NL - 
        0.0022400287216326853*NH + 0.00521413299619062*lm*NH + 
        0.004720706593390002*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.027318477561100327 - 0.06085697842108518*lm - 
          0.025222725984952513*lm^2) + CF*(0.06939551480891377 + 
          0.0321980160396923*lm + 0.08254710322348095*lm^2) + 
        0.016811594218703207*NM + 0.005228241303183501*lm*NM + 
        0.004585950179082275*lm^2*NM + 0.016950141101729807*NL + 
        0.005228241303183501*lm*NL + 0.004585950179082275*lm^2*NL - 
        0.0021901569688558033*NH + 0.005228241303183501*lm*NH + 
        0.004585950179082275*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.030112488683274645 - 0.059942043554188106*lm - 
          0.024493351950236796*lm^2) + CF*(0.06663292350520429 + 
          0.0340320193001555*lm + 0.0801600609280477*lm^2) + 
        0.016778272118260787*NM + 0.005230670277566182*lm*NM + 
        0.004453336718224872*lm^2*NM + 0.016958779295419734*NL + 
        0.005230670277566182*lm*NL + 0.004453336718224872*lm^2*NL - 
        0.002140494506061633*NH + 0.005230670277566182*lm*NH + 
        0.004453336718224872*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.032560274150481704 - 0.058983377108916504*lm - 
          0.023776784322796132*lm^2) + CF*(0.06412070058967238 + 
          0.03563812473199366*lm + 0.07781493051096916*lm^2) + 
        0.016696470641518933*NM + 0.005222184589734474*lm*NM + 
        0.004323051695053842*lm^2*NM + 0.016922562163356546*NL + 
        0.005222184589734474*lm*NL + 0.004323051695053842*lm^2*NL - 
        0.0020911071019894634*NH + 0.005222184589734474*lm*NH + 
        0.004323051695053842*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.034686317938323545 - 0.057986382751481824*lm - 
          0.023073825174344576*lm^2) + CF*(0.06182735117014527 + 
          0.037028707478816494*lm + 0.07551433693421862*lm^2) + 
        0.016571382041142012*NM + 0.005203581121082247*lm*NM + 
        0.004195240940789924*lm^2*NM + 0.016845951670625293*NL + 
        0.005203581121082247*lm*NL + 0.004195240940789924*lm^2*NL - 
        0.0020420543383515622*NH + 0.005203581121082247*lm*NH + 
        0.004195240940789924*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.03651470650039515 - 0.056956268472250736*lm - 
          0.02238509645243336*lm^2) + CF*(0.05972501658952546 + 
          0.03821669468274522*lm + 0.07326031566250917*lm^2) + 
        0.01640792232722429*NM + 0.005175662857201505*lm*NM + 
        0.004070017536806065*lm^2*NM + 0.016733175657955887*NL + 
        0.005175662857201505*lm*NL + 0.004070017536806065*lm^2*NL - 
        0.0019933902460901455*NH + 0.005175662857201505*lm*NH + 
        0.004070017536806065*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.03806873869012171 - 0.05589798997140591*lm - 
          0.021711069922016782*lm^2) + CF*(0.057789176014418395 + 
          0.03921518199290329*lm + 0.0710544106538731*lm^2) + 
        0.016210692972830516*NM + 0.00513922166573934*lm*NM + 
        0.003947467258548505*lm^2*NM + 0.01658819845164724*NL + 
        0.00513922166573934*lm*NL + 0.003947467258548505*lm^2*NL - 
        0.0019451638170388545*NH + 0.00513922166573934*lm*NH + 
        0.003947467258548505*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.0393706928324267 - 0.05481621884509069*lm - 
          0.02105209125819597*lm^2) + CF*(0.05599832603181017 + 
          0.04003716995736316*lm + 0.06889775320864136*lm^2) + 
        0.01598396552199639*NM + 0.005095026936880232*lm*NM + 
        0.0038276529560356313*lm^2*NM + 0.0164147097714422*NL + 
        0.005095026936880232*lm*NL + 0.0038276529560356313*lm^2*NL - 
        0.0018974194283095313*NH + 0.005095026936880232*lm*NH + 
        0.0038276529560356313*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.040441695658497444 - 0.05371532705576053*lm - 
          0.02040839974121104*lm^2) + CF*(0.05433366501194619 + 
          0.04069538282124895*lm + 0.0667911264257816*lm^2) + 
        0.015731680353084698*NM + 0.005043818202254731*lm*NM + 
        0.003710618134765644*lm^2*NM + 0.016216124777112508*NL + 
        0.005043818202254731*lm*NL + 0.003710618134765644*lm^2*NL - 
        0.0018501972035367454*NH + 0.005043818202254731*lm*NH + 
        0.003710618134765644*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.041301658420127195 - 0.052599382241931676*lm - 
          0.01978014456064123*lm^2) + CF*(0.052778795133278544 + 
          0.04120214524571337*lm + 0.06473501856209857*lm^2) + 
        0.01545745419235137*NM + 0.004986300509293739*lm*NM + 
        0.0035963899201165873*lm^2*NM + 0.015995590893719606*NL + 
        0.004986300509293739*lm*NL + 0.0035963899201165873*lm^2*NL - 
        0.0018035333271179932*NH + 0.004986300509293739*lm*NH + 
        0.0035963899201165873*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.04196925772291845 - 0.051472150278347076*lm - 
          0.019167398451013392*lm^2) + CF*(0.05131944773572053 + 
          0.04156930042118773*lm + 0.06272966765786202*lm^2) + 
        0.015164592944669009*NM + 0.004923141731365791*lm*NM + 
        0.0034849815365478897*lm^2*NM + 0.01575599868456135*NL + 
        0.004923141731365791*lm*NL + 0.0034849815365478897*lm^2*NL - 
        0.0017574603225363487*NH + 0.004923141731365791*lm*NH + 
        0.0034849815365478897*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.042461946163754094 - 0.05033710266367129*lm - 
          0.01857016919120487*lm^2) + CF*(0.04994323383605979 + 
          0.041808158121146535*lm + 0.060775099171215936*lm^2) + 
        0.014856107617451375*NM + 0.004854971249975471*lm*NM + 
        0.003376394398400885*lm^2*NM + 0.015499995026193819*NL + 
        0.004854971249975471*lm*NL + 0.003376394398400885*lm^2*NL - 
        0.0017120073025535577*NH + 0.004854971249975471*lm*NH + 
        0.003376394398400885*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.04279598267243009 - 0.04919742706956262*lm - 
          0.017988409369298405*lm^2) + CF*(0.04863941961291736 + 
          0.041929464584617986*lm + 0.05887115793588569*lm^2) + 
        0.014534731878367547*NM + 0.00478237961314068*lm*NM + 
        0.003270619885326983*lm^2*NM + 0.015229997454898706*NL + 
        0.00478237961314068*lm*NL + 0.003270619885326983*lm^2*NL - 
        0.0016672001968486754*NH + 0.00478237961314068*lm*NH + 
        0.003270619885326983*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.04298647561419293 - 0.04805603988941718*lm - 
          0.017422024721967067*lm^2) + CF*(0.04739872562822734 + 
          0.04194338837945108*lm + 0.05701753545371041*lm^2) + 
        0.014202940283099489*NM + 0.0047059188872074385*lm*NM + 
        0.003167640858539467*lm^2*NM + 0.014948208947648709*NL + 
        0.0047059188872074385*lm*NL + 0.003167640858539467*lm^2*NL - 
        0.00162306196115999*NH + 0.0047059188872074385*lm*NH + 
        0.003167640858539467*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.043047433827783026 - 0.04691559996897993*lm - 
          0.016870881290306516*lm^2) + CF*(0.04621314805936448 + 
          0.04185951796843415*lm + 0.05521379331373042*lm^2) + 
        0.013862966537250308*NM + 0.004626103497429554*lm*NM + 
        0.0030674329618739123*lm^2*NM + 0.014656632657847217*NL + 
        0.004626103497429554*lm*NL + 0.0030674329618739123*lm^2*NL - 
        0.0015796127709285326*NH + 0.004626103497429554*lm*NH + 
        0.0030674329618739123*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.042991822221920835 - 0.04577852293991098*lm - 
          0.01633481158427905*lm^2) + CF*(0.045075800029172004 + 
          0.04168686781154732*lm + 0.05345938336673144*lm^2) + 
        0.013516821376818117*NM + 0.004543411407588661*lm*NM + 
        0.0029699657425961913*lm^2*NM + 0.014357086296919534*NL + 
        0.004543411407588661*lm*NL + 0.0029699657425961913*lm^2*NL - 
        0.0015368702016905814*NH + 0.004543411407588661*lm*NH + 
        0.0029699657425961913*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.04283161955964014 - 0.044646995745960386*lm - 
          0.015813619910391416*lm^2) + CF*(0.04398077110403008 + 
          0.04143389063782468*lm + 0.051753665161281*lm^2) + 
        0.013166309801468481*NM + 0.0044582855282658575*lm*NM + 
        0.0028752036200711665*lm^2*NM + 0.014051215967641863*NL + 
        0.0044582855282658575*lm*NL + 0.0028752036200711665*lm^2*NL - 
        0.0014948493979276385*NH + 0.0044582855282658575*lm*NH + 
        0.0028752036200711665*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.042577876768619155 - 0.04352299107189058*lm - 
          0.0153070869884344*lm^2) + CF*(0.04292300310468079 + 
          0.04110849410522906*lm + 0.05009592105305803*lm^2) + 
        0.0128130474975677*NM + 0.004371135271945699*lm*NM + 
        0.0027831067251698908*lm^2*NM + 0.013740509332919752*NL + 
        0.004371135271945699*lm*NL + 0.0027831067251698908*lm^2*NL - 
        0.0014535632316914687*NH + 0.004371135271945699*lm*NH + 
        0.0027831067251698908*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.042240774620162826 - 0.04240828147230743*lm - 
          0.014814973960706164*lm^2) + CF*(0.04189818049558957 + 
          0.04071806050006698*lm + 0.04848536932594745*lm^2) + 
        0.01245847635870224*NM + 0.00428233819414042*lm*NM + 
        0.0026936316292193027*lm^2*NM + 0.013426308056722703*NL + 
        0.00428233819414042*lm*NL + 0.0026936316292193027*lm^2*NL - 
        0.0014130224520357564*NH + 0.00428233819414042*lm*NH + 
        0.0026936316292193027*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.041829679981664425 - 0.04130445306092731*lm - 
          0.014337025879478719*lm^2) + CF*(0.04090263375995076 + 
          0.04026946845177488*lm + 0.04692117560556672*lm^2) + 
        0.012103879060179672*NM + 0.00419224167533055*lm*NM + 
        0.0026067319780870395*lm^2*NM + 0.013109819489976237*NL + 
        0.00419224167533055*lm*NL + 0.0026067319780870395*lm^2*NL - 
        0.0013732358260749899*NH + 0.00419224167533055*lm*NH + 
        0.0026067319780870395*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.04135320010900483 - 0.04021291866722157*lm - 
          0.013872974744381069*lm^2) + CF*(0.039933254313939064 + 
          0.03976911588405377*lm + 0.045402462799792584*lm^2) + 
        0.011750392677477963*NM + 0.0041011646102165665*lm*NM + 
        0.0025223590444329214*lm^2*NM + 0.012792127598674602*NL + 
        0.0041011646102165665*lm*NL + 0.0025223590444329214*lm^2*NL - 
        0.001334210272334625*NH + 0.0041011646102165665*lm*NH + 
        0.0025223590444329214*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.04081923463510801 - 0.039134930401502455*lm - 
          0.01342254215002126*lm^2) + CF*(0.03898741965696681 + 
          0.0392229436101483*lm + 0.04392831976370594*lm^2) + 
        0.011399021361346654*NM + 0.004009399079607097*lm*NM + 
        0.0024404622090947745*lm^2*NM + 0.012474203147860834*NL + 
        0.004009399079607097*lm*NL + 0.0024404622090947745*lm^2*NL - 
        0.001295950986939639*NH + 0.004009399079607097*lm*NH + 
        0.0024404622090947745*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.04023502504873205 - 0.03807159159463383*lm - 
          0.012985441594934833*lm^2) + CF*(0.03806292758996666 + 
          0.03863645912340657*lm + 0.04249780885615036*lm^2) + 
        0.011050648097418885*NM + 0.003917211986973297*lm*NM + 
        0.002360989380897242*lm^2*NM + 0.012156913165857694*NL + 
        0.003917211986973297*lm*NL + 0.002360989380897242*lm^2*NL - 
        0.0012584615631007743*NH + 0.003917211986973297*lm*NH + 
        0.002360989380897242*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.03960720155763375 - 0.037023868097017375*lm - 
          0.012561380495370119*lm^2) + CF*(0.037157938458867557 + 
          0.03801476024485467*lm + 0.041109972530302206*lm^2) + 
        0.01070604558797238*NM + 0.0038248466468100736*lm*NM + 
        0.002283887362794567*lm^2*NM + 0.011841029719906247*NL + 
        0.0038248466468100736*lm*NL + 0.002283887362794567*lm^2*NL - 
        0.0012217441042914389*NH + 0.0038248466468100736*lm*NH + 
        0.002283887362794567*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.038941827302569794 - 0.035992598935022053*lm - 
          0.012150061941155236*lm^2) + CF*(0.03627092449465114 + 
          0.03736255837523461*lm + 0.03976383908014441*lm^2) + 
        0.010365886299438016*NM + 0.0037325243158523843*lm*NM + 
        0.0022091021711191337*lm^2*NM + 0.011527238038355866*NL + 
        0.0037325243158523843*lm*NL + 0.0022091021711191337*lm^2*NL - 
        0.0011857993314578323*NH + 0.0037325243158523843*lm*NH + 
        0.0022091021711191337*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.03824443994045811 - 0.03497850633283532*lm - 
          0.01175118622567379*lm^2) + CF*(0.03540062542466102 + 
          0.03668420116560398*lm + 0.03845842764765968*lm^2) + 
        0.010030751722506774*NM + 0.003640445661186041*lm*NM + 
        0.002136579313758871*lm^2*NM + 0.01121614401658075*NL + 
        0.003640445661186041*lm*NL + 0.002136579313758871*lm^2*NL - 
        0.0011506266845662933*NH + 0.003640445661186041*lm*NH + 
        0.002136579313758871*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.03752009065171576 - 0.03398220511473932*lm - 
          0.011364452177602884*lm^2) + CF*(0.034546009622639415 + 
          0.035983694472536035*lm + 0.037192752581245804*lm^2) + 
        0.009701140893028691*NM + 0.003548792161581688*lm*NM + 
        0.0020662640322914334*lm^2*NM + 0.010908281144463888*NL + 
        0.003548792161581688*lm*NL + 0.0020662640322914334*lm^2*NL - 
        0.001116224418762109*NH + 0.003548792161581688*lm*NH + 
        0.0020662640322914334*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.036773380652206936 - 0.03300421150773689*lm - 
          0.010989558318379786*lm^2) + CF*(0.03370624014797692 + 
          0.03526472350447605*lm + 0.03596582722378839*lm^2) + 
        0.009377478221912131*NM + 0.003457727440128741*lm*NM + 
        0.0019981015124326883*lm^2*NM + 0.010604116893011462*NL + 
        0.003457727440128741*lm*NL + 0.0019981015124326883*lm^2*NL - 
        0.001082589695390835*NH + 0.003457727440128741*lm*NH + 
        0.0019981015124326883*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.036008495307258505 - 0.03204495136778603*lm - 
          0.010626203866237941*lm^2) + CF*(0.032880645098678545 + 
          0.03453067309741057*lm + 0.0347766671985969*lm^2) + 
        0.009060120681350871*NM + 0.003367398527575458*lm*NM + 
        0.0019320370665887165*lm^2*NM + 0.010304058596741557*NL + 
        0.003367398527575458*lm*NL + 0.0019320370665887165*lm^2*NL - 
        0.0010497186681148673*NH + 0.003367398527575458*lm*NH + 
        0.0019320370665887165*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.03522923595597567 - 0.031104767855033508*lm - 
          0.010274089604990393*lm^2) + CF*(0.032068691768400104 + 
          0.03378464708261127*lm + 0.03362429325269583*lm^2) + 
        0.008749364393267275*NM + 0.003277937056785175*lm*NM + 
        0.0018680162918164349*lm^2*NM + 0.010008458867148275*NL + 
        0.003277937056785175*lm*NL + 0.0018680162918164349*lm^2*NL - 
        0.0010176065643433352*NH + 0.003277937056785175*lm*NH + 
        0.0018680162918164349*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.03443904956022465 - 0.030183928584665128*lm - 
          0.009932918633460122*lm^2) + CF*(0.03126996415639717 + 
          0.03302948672831267*lm + 0.032507733709505854*lm^2) + 
        0.008445450664153807*NM + 0.0031894603894690034*lm*NM + 
        0.0018059852060836586*lm^2*NM + 0.009717620570932619*NL + 
        0.0031894603894690034*lm*NL + 0.0018059852060836586*lm^2*NL - 
        0.0009862477621814117*NH + 0.0031894603894690034*lm*NH + 
        0.0018059852060836586*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.03364105629534302 - 0.029282632280535046*lm - 
          0.009602397009498762*lm^2) + CF*(0.030484143431107055 + 
          0.03226778825192867*lm + 0.0314260265765414*lm^2) + 
        0.008148571508822816*NM + 0.003102072676907485*lm*NM + 
        0.0017458903653634113*lm^2*NM + 0.00943180140492699*NL + 
        0.003102072676907485*lm*NL + 0.0017458903653634113*lm^2*NL - 
        0.0009556358630951522*NH + 0.003102072676907485*lm*NH + 
        0.0017458903653634113*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.03283807519978938 - 0.028401014958772397*lm - 
          0.009282234300846084*lm^2) + CF*(0.029710990994023537 + 
          0.03150191941071203*lm + 0.030378221348223548*lm^2) + 
        0.007858874704315729*NM + 0.003015865856771094*lm*NM + 
        0.0016876789637901971*lm^2*NM + 0.009151218097801525*NL + 
        0.003015865856771094*lm*NL + 0.0016876789637901971*lm^2*NL - 
        0.0009257637604794572*NH + 0.003015865856771094*lm*NH + 
        0.0016876789637901971*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.03203264799919487 - 0.027539155668223108*lm - 
          0.008972144053620455*lm^2) + CF*(0.028950333831081008 + 
          0.03073403518732534*lm + 0.02936338053912149*lm^2) + 
        0.007576468414936056*NM + 0.0029309205884259144*lm*NM + 
        0.0016312989188400826*lm^2*NM + 0.008876050266784489*NL + 
        0.0029309205884259144*lm*NL + 0.0016312989188400826*lm^2*NL - 
        0.0008966237043093156*NH + 0.0029309205884259144*lm*NH + 
        0.0016312989188400826*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.031227061196839 - 0.026697081813969*lm - 
          0.008671844187960482*lm^2) + CF^2*(0.028202051833887864 + 
          0.029966092593184945*lm + 0.02838058097877976*lm^2) + 
        CF*((0.007301424799102229 + 0.0028473071292927647*lm + 
            0.0015766989432655424*lm^2)*NM + (0.0086064439557957 + 
            0.0028473071292927647*lm + 0.0015766989432655424*lm^2)*NL + 
          (-0.0008682073620478226 + 0.0028473071292927647*lm + 
            0.0015766989432655424*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.03042336665027639 - 0.025874774089354822*lm - 
          0.008381057329231771*lm^2) + CF^2*(0.027466067068245288 + 
          0.029199864617106285*lm + 0.027428914895667615*lm^2) + 
        CF*((0.007033785642362475 + 0.0027650861549364998*lm + 
            0.0015238286053148675*lm^2)*NM + (0.008342514879608668 + 
            0.0027650861549364998*lm + 0.0015238286053148675*lm^2)*NL + 
          (-0.0008405058759783778 + 0.0027650861549364998*lm + 
            0.0015238286053148675*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.029623400489527676 - 0.02507217104100634*lm - 
          0.008099511082246264*lm^2) + CF^2*(0.026742334275995372 + 
          0.028436953350076483*lm + 0.026507490814624134*lm^2) + 
        CF*((0.006773563653997421 + 0.002684309525613588*lm + 
            0.0014726383785902296*lm^2)*NM + (0.008084351396942175 + 
            0.002684309525613588*lm + 0.0014726383785902296*lm^2)*NL + 
          (-0.0008135099171227782 + 0.002684309525613588*lm + 
            0.0014726383785902296*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.02882880077691418 - 0.024289173290286455*lm - 
          0.007826938255095213*lm^2) + CF^2*(0.026030833020322615 + 
          0.02767880231919149*lm + 0.025615434289402515*lm^2) + 
        CF*((0.0065207468977468335 + 0.002605021002013521*lm + 
            0.001423079682744584*lm^2)*NM + (0.007832017233746852 + 
            0.002605021002013521*lm + 0.001423079682744584*lm^2)*NL + 
          (-0.0007872097359015237 + 0.002605021002013521*lm + 
            0.001423079682744584*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.02804102379707713 - 0.02352564743354657*lm - 
          0.0075630770384537945*lm^2) + CF^2*(0.02533156089384153 + 
          0.026926708065148366*lm + 0.024751888489485147*lm^2) + 
        CF*((0.006275301415194625 + 0.002527256912903457*lm + 
            0.001375104916082508*lm^2)*NM + (0.007585553976403479 + 
            0.002527256912903457*lm + 0.001375104916082508*lm^2)*NL + 
          (-0.0007615952096875577 + 0.002527256912903457*lm + 
            0.001375104916082508*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.02726135914232792 - 0.022781429642415172*lm - 
          0.007307671145561523*lm^2) + CF^2*(0.024644527791913562 + 
          0.02618183099836056*lm + 0.023916014658201347*lm^2) + 
        CF*((0.00603717385786833 + 0.0024510467773339764*lm + 
            0.001328667481011186*lm^2)*NM + (0.00734498335309054 + 
            0.0024510467773339764*lm + 0.001328667481011186*lm^2)*NL + 
          (-0.0007366558873991169 + 0.0024510467773339764*lm + 
            0.001328667481011186*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.026490943665870122 - 0.02205632898424499*lm - 
          0.007060469917506302*lm^2) + CF^2*(0.023969751096037866 + 
          0.025445205568912964*lm + 0.02310699245729335*lm^2) + 
        CF*((0.005806293877620949 + 0.0023764138839934986*lm + 
            0.001283721803182964*lm^2)*NM + (0.007110309320209248 + 
            0.0023764138839934986*lm + 0.001283721803182964*lm^2)*NL + 
          (-0.0007123810312742292 + 0.0023764138839934986*lm + 
            0.001283721803182964*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.02573077438216237 - 0.02135013048173035*lm - 
          0.006821228397930784*lm^2) + CF^2*(0.023307251651062393 + 
          0.024717749785311237*lm + 0.02232402021140984*lm^2) + 
        CF*((0.0055825762954575635 + 0.002303375830214923*lm + 
            0.0012402233450783244*lm^2)*NM + (0.0068815199694739 + 
            0.002303375830214923*lm + 0.0012402233450783244*lm^2)*NL + 
          (-0.0006887596559609493 + 0.002303375830214923*lm + 
            0.0012402233450783244*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.024981720388719927 - 0.02066259792961852*lm - 
          0.006589707380829254*lm^2) + CF^2*(0.022657050433426227 + 
          0.024000274116402494*lm + 0.0215663150645321*lm^2) + 
        CF*((0.005365923067500046 + 0.002231945023044532*lm + 
            0.0011981286146962279*lm^2)*NM + (0.0066585892700812 + 
            0.002231945023044532*lm + 0.0011981286146962279*lm^2)*NL + 
          (-0.0006657805650572784 + 0.002231945023044532*lm + 
            0.0011981286146962279*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.024244533879073785 - 0.019993476485381998*lm - 
          0.006365673434703961*lm^2) + CF^2*(0.022019165819985476 + 
          0.02329348981002809*lm + 0.020833113059031145*lm^2) + 
        CF*((0.005156225065171231 + 0.0021621291446834137*lm + 
            0.0011573951699461746*lm^2)*NM + (0.006441478659261119 + 
            0.0021621291446834137*lm + 0.0011573951699461746*lm^2)*NL + 
          (-0.0006434323852263335 + 0.0021621291446834137*lm + 
            0.0011573951699461746*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.023519860311992057 - 0.019342495049698153*lm - 
          0.006148898905995541*lm^2) + CF^2*(0.021393611377472237 + 
          0.02259801666097554*lm + 0.020123669146894497*lm^2) + 
        CF*((0.004953363685426531 + 0.002093931584508134*lm + 
            0.0011179816192719164*lm^2)*NM + (0.006230138493479672 + 
            0.002093931584508134*lm + 0.0011179816192719164*lm^2)*NL + 
          (-0.0006217035980095199 + 0.002093931584508134*lm + 
            0.0011179816192719164*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.02280824779780807 - 0.018709368451603182*lm - 
          0.005939161904387127*lm^2) + CF^2*(0.020780394102194635 + 
          0.021914390259675797*lm + 0.0194372571416306*lm^2) + 
        CF*((0.0047572123055372555 + 0.0020273518397721526*lm + 
            0.0010798476189794776*lm^2)*NM + (0.00602450937160692 + 
            0.0020273518397721526*lm + 0.0010798476189794776*lm^2)*NL + 
          (-0.0006005825694553704 + 0.0020273518397721526*lm + 
            0.0010798476189794776*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.022110155758585662 - 0.018093799452250953*lm - 
          0.005736246272301547*lm^2) + CF^2*(0.020179513047915956 + 
          0.021243068751882956*lm + 0.01877316961844143*lm^2) + 
        CF*((0.004567637595773797 + 0.0019623858869841125*lm + 
            0.0010429538676911905*lm^2)*NM + (0.005824523340476948 + 
            0.0019623858869841125*lm + 0.0010429538676911905*lm^2)*NL + 
          (-0.0005800575776774297 + 0.0019623858869841125*lm + 
            0.0010429538676911905*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.021425962914947624 - 0.017495480580315657*lm - 
          0.0055399415406612125*lm^2) + CF^2*(0.019590958287196408 + 
          0.02058443913830883*lm + 0.018130717769436696*lm^2) + 
        CF*((0.004384500702242338 + 0.0018990265258547973*lm + 
            0.0010072620983020387*lm^2)*NM + (0.005630104992446255 + 
            0.0018990265258547973*lm + 0.0010072620983020387*lm^2)*NL + 
          (-0.0005601168384498768 + 0.0018990265258547973*lm + 
            0.0010072620983020387*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.020755974648680123 - 0.016914095811230993*lm - 
          0.00535004287275764*lm^2) + CF^2*(0.019014710157918117 + 
          0.01993882314188929*lm + 0.017509231219934092*lm^2) + 
        CF*((0.004207658311156311 + 0.0018372636976022145*lm + 
            0.0009727350677741163*lm^2)*NM + (0.005441172463798747 + 
            0.0018372636976022145*lm + 0.0009727350677741163*lm^2)*NL + 
          (-0.0005407485289454603 + 0.0018372636976022145*lm + 
            0.0009727350677741163*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.020100429786697238 - 0.016349322101657123*lm - 
          0.005166350997878644*lm^2) + CF^2*(0.018450738752332583 + 
          0.01930648266905311*lm + 0.0169080578112392*lm^2) + 
        CF*((0.004036963604850836 + 0.001777084779304584*lm + 
            0.0009393365450688445*lm^2)*NM + (0.005257638342144997 + 
            0.001777084779304584*lm + 0.0009393365450688445*lm^2)*NL + 
          (-0.0005219408097159823 + 0.001777084779304584*lm + 
            0.0009393365450688445*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.019459506848558537 - 0.01580083078980985*lm - 
          0.004988672136163602*lm^2) + CF^2*(0.017899003610775115 + 
          0.01868762489006328*lm + 0.01632656335471724*lm^2) + 
        CF*((0.003872267119054578 + 0.0017184748558945117*lm + 
            0.0009070312974842911*lm^2)*NM + (0.005079410490316777 + 
            0.0017184748558945117*lm + 0.0009070312974842911*lm^2)*NL + 
          (-0.0005036818450113617 + 0.0017184748558945117*lm + 
            0.0009070312974842911*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.018833329796508924 - 0.015268288871572857*lm - 
          0.004816817915998226*lm^2) + CF^2*(0.017359453586331883 + 
          0.018082406962217124*lm + 0.01576413136144874*lm^2) + 
        CF*((0.0037134175100980017 + 0.0016614169712946489*lm + 
            0.0008757850756360411*lm^2)*NM + (0.004906392793661183 + 
            0.0016614169712946489*lm + 0.0008757850756360411*lm^2)*NL + 
          (-0.000485959821529091 + 0.0016614169712946489*lm + 
            0.0008757850756360411*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.01822197332392575 - 0.014751360161642113*lm - 
          0.004650605285118148*lm^2) + CF^2*(0.016832026850251765 + 
          0.01749094041843504*lm + 0.015220162751295757*lm^2) + 
        CF*((0.0035602622400596733 + 0.0016058923601059364*lm + 
            0.0008455645972942087*lm^2)*NM + (0.004738485837088284 + 
            0.0016058923601059364*lm + 0.0008455645972942087*lm^2)*NL + 
          (-0.0004687629656825906 + 0.0016058923601059364*lm + 
            0.0008455645972942087*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.017625467715217943 - 0.014249706348320536*lm - 
          0.004489856416463171*lm^2) + CF^2*(0.016316651011052154 + 
          0.016913295242544896*lm + 0.01469407554478856*lm^2) + 
        CF*((0.0034126481871361684 + 0.0015518806611742398*lm + 
            0.000816337530266031*lm^2)*NM + (0.004575587517718914 + 
            0.0015518806611742398*lm + 0.000816337530266031*lm^2)*NL + 
          (-0.00045207955947161593 + 0.0015518806611742398*lm + 
            0.000816337530266031*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.01704373829499504 - 0.013762987949988347*lm - 
          0.0043343986097100036*lm^2) + CF^2*(0.015813113297886837 + 
          0.016349503651385724*lm + 0.014185304540869102*lm^2) + 
        CF*((0.0032704221879874553 + 0.001499360114279864*lm + 
            0.0007880724744927279*lm^2)*NM + (0.004417593598511483 + 
            0.001499360114279864*lm + 0.0007880724744927279*lm^2)*NL + 
          (-0.0004358979550360452 + 0.001499360114279864*lm + 
            0.0007880724744927279*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.0164768792164965 - 0.013290865180719213*lm - 
          0.004184064189308937*lm^2) + CF^2*(0.01532160023046187 + 
          0.015799563602713635*lm + 0.013693300983192883*lm^2) + 
        CF*((0.0031334315181388477 + 0.0014483077411171278*lm + 
            0.0007607389435107158*lm^2)*NM + (0.004264398207815805 + 
            0.0014483077411171278*lm + 0.0007607389435107158*lm^2)*NL + 
          (-0.0004202065879689056 + 0.0014483077411171278*lm + 
            0.0007607389435107158*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.015924738040410728 - 0.012832998731992033*lm - 
          0.004038690399758186*lm^2) + CF^2*(0.014841859606796784 + 
          0.015263442046797833*lm + 0.013217532217390427*lm^2) + 
        CF*((0.0030015243161420377 + 0.0013986995116578142*lm + 
            0.0007343073454105793*lm^2)*NM + (0.004115894289404942 + 
            0.0013986995116578142*lm + 0.0007343073454105793*lm^2)*NL + 
          (-0.00040499398946209324 + 0.0013986995116578142*lm + 
            0.0007343073454105793*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.015387209019655367 - 0.0123890504769613*lm - 
          0.00389811929876728*lm^2) + CF^2*(0.014373780575162132 + 
          0.01474107793854615*lm + 0.012757481341420188*lm^2) + 
        CF*((0.0028745499565624674 + 0.0013505104969228495*lm + 
            0.0007087489634122326*lm^2)*NM + (0.003971974007170365 + 
            0.0013505104969228495*lm + 0.0007087489634122326*lm^2)*NL + 
          (-0.0003902487973544499 + 0.0013505104969228495*lm + 
            0.0007087489634122326*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.014864161047222012 - 0.011958684103293822*lm - 
          0.0037621976488869968*lm^2) + CF^2*(0.013917243645203432 + 
          0.014232385025998918*lm + 0.012312646850902898*lm^2) + 
        CF*((0.0027523593765873097 + 0.001303715009120894*lm + 
            0.0006840359361612721*lm^2)*NM + (0.0038325291083290145 + 
            0.001303715009120894*lm + 0.0006840359361612721*lm^2)*NL + 
          (-0.00037595976614808484 + 0.001303715009120894*lm + 
            0.0006840359361612721*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.014355440574443212 - 0.011541565680154147*lm - 
          0.003630776808117028*lm^2) + CF^2*(0.01347212119889971 + 
          0.013737254430076883*lm + 0.011882542281110275*lm^2) + 
        CF*((0.0026348053605256363 + 0.0012582867300505326*lm + 
            0.0006601412378394597*lm^2)*NM + (0.003697451248680703 + 
            0.0012582867300505326*lm + 0.0006601412378394597*lm^2)*NL + 
          (-0.0003621157760565595 + 0.0012582867300505326*lm + 
            0.0006601412378394597*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.013860874284280929 - 0.011137364164523909*lm - 
          0.0035037126199429767*lm^2) + CF^2*(0.013038278021171355 + 
          0.01325555702956317*lm + 0.011466695847086105*lm^2) + 
        CF*((0.0025217427860598635 + 0.0012141988286043194*lm + 
            0.0006370386581714503*lm^2)*NM + (0.0035666322831687768 + 
            0.0012141988286043194*lm + 0.0006370386581714503*lm^2)*NL + 
          (-0.00034870584114431586 + 0.0012141988286043194*lm + 
            0.0006370386581714503*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.013380271537994854 - 0.010745751851669502*lm - 
          0.003380865303200852*lm^2) + CF^2*(0.0126155718417484 + 
          0.012787145664440003*lm + 0.011064650083202789*lm^2) + 
        CF*((0.002413028836641953 + 0.0011714240681578942*lm + 
            0.0006147027824001549*lm^2)*NM + (0.0034399645247341075 + 
            0.0011714240681578942*lm + 0.0006147027824001549*lm^2)*NL + 
          (-0.0003357191166142516 + 0.0011714240681578942*lm + 
            0.0006147027824001549*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.012913426613675985 - 0.01036640477422677*lm - 
          0.003262099342119198*lm^2) + CF^2*(0.012203853884071528 + 
          0.01233185716988697*lm + 0.010675961483299194*lm^2) + 
        CF*((0.002308523180876576 + 0.0011299349045756314*lm + 
            0.0005931089712943997*lm^2)*NM + (0.00331734097421044 + 
            0.0011299349045756314*lm + 0.0005931089712943997*lm^2)*NL + 
          (-0.00032314490529961845 + 0.0011299349045756314*lm + 
            0.0005931089712943997*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.012460120750696897 - 0.009999003054048947*lm - 
          0.0031472833768458916*lm^2) + CF^2*(0.011802969411699019 + 
          0.011889514252477884*lm + 0.010300200142404736*lm^2) + 
        CF*((0.0022080881262505534 + 0.0010897035755156354*lm + 
            0.0005722333412447075*lm^2)*NM + (0.0031986555237863783 + 
            0.0010897035755156354*lm + 0.0005722333412447075*lm^2)*NL + 
          (-0.00031097266340675446 + 0.0010897035755156354*lm + 
            0.0005722333412447075*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.012020124017247141 - 0.009643231210663595*lm - 
          0.003036290094727943*lm^2) + CF^2*(0.01141275827218676 + 
          0.011459927219385957*lm + 0.009936949400927814*lm^2) + 
        CF*((0.0021115887451908766 + 0.001050702181671212*lm + 
            0.0005520527444959896*lm^2)*NM + (0.003083803136354214 + 
            0.001050702181671212*lm + 0.0005520527444959896*lm^2)*NL + 
          (-0.0002991920055633855 + 0.001050702181671212*lm + 
            0.0005520527444959896*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.011593197012939337 - 0.009298778429904404*lm - 
          0.0029289961225779176*lm^2) + CF^2*(0.011033055431020745 + 
          0.011042895570720928*lm + 0.009585805492073185*lm^2) + 
        CF*((0.0020188929794839124 + 0.001012902760543101*lm + 
            0.0005325447495596213*lm^2)*NM + (0.002972680002877049 + 
            0.001012902760543101*lm + 0.0005325447495596213*lm^2)*NL + 
          (-0.0002877927092129303 + 0.001012902760543101*lm + 
            0.0005325447495596213*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.011179092420283287 - 0.008965338796023011*lm - 
          0.002825281920129412*lm^2) + CF^2*(0.010663691494525538 + 
          0.010638209464474824*lm + 0.009246377193150803*lm^2) + 
        CF*((0.0019298717234531846 + 0.0009762773532965514*lm + 
            0.0005136876218417112*lm^2)*NM + (0.0028651836797319455 + 
            0.0009762773532965514*lm + 0.0005136876218417112*lm^2)*NL + 
          (-0.000276764718403745 + 0.0009762773532965514*lm + 
            0.0005136876218417112*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.010777556416360893 - 0.008642611490343276*lm - 
          0.00272503167485609*lm^2) + CF^2*(0.010304493218228544 + 
          0.010245651062943874*lm + 0.008918285481347205*lm^2) + 
        CF*((0.0018443988889795153 + 0.000940798065219682*lm + 
            0.0004954603045192891*lm^2)*NM + (0.002761213207826912 + 
            0.000940798065219682*lm + 0.0004954603045192891*lm^2)*NL + 
          (-0.0002660981470087593 + 0.000940798065219682*lm + 
            0.0004954603045192891*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.010388329955838495 - 0.008330300959294677*lm - 
          0.002628133198303718*lm^2) + CF^2*(0.009955283999038899 + 
          0.009864995768920777*lm + 0.008601163194448532*lm^2) + 
        CF*((0.001762351453509006 + 0.0009064371202642875*lm + 
            0.0004778423996915851*lm^2)*NM + (0.0026606692151424035 + 
            0.0009064371202642875*lm + 0.0004778423996915851*lm^2)*NL + 
          (-0.00025578328142075637 + 0.0009064371202642875*lm + 
            0.0004778423996915851*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.010011149935303885 - 0.008028117054451308*lm - 
          0.002534477824062193*lm^2) + CF^2*(0.009615884349375738 + 
          0.00949601335941241*lm + 0.008294654696930812*lm^2) + 
        CF*((0.0016836094936367833 + 0.0008731669101172511*lm + 
            0.00046081414982948956*lm^2)*NM + (0.0025634540042125354 + 
            0.0008731669101172511*lm + 0.00046081414982948956*lm^2)*NL + 
          (-0.000245810582755577 + 0.0008731669101172511*lm + 
            0.00046081414982948956*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.009645750248393616 - 0.007735775147007495*lm - 
          0.002443960307484465*lm^2) + CF^2*(0.00928611235223401 + 
          0.0091384690241315*lm + 0.00799841555176734*lm^2) + 
        CF*((0.0016080562051022167 + 0.0008409600382198336*lm + 
            0.00044435641954263*lm^2)*NM + (0.00246947162593661 + 
            0.0008409600382198336*lm + 0.00044435641954263*lm^2)*NL + 
          (-0.0002361706885996701 + 0.0008409600382198336*lm + 
            0.00044435641954263*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.009291862740311586 - 0.007452996218939367*lm - 
          0.0023564787272412763*lm^2) + CF^2*(0.008965784096179192 + 
          0.008792124315534933*lm + 0.007712112198244177*lm^2) + 
        CF*((0.0015355779110853202 + 0.0008097893591232259*lm + 
            0.00042845067768023206*lm^2)*NM + (0.002378627940996807 + 
            0.0008097893591232259*lm + 0.00042845067768023206*lm^2)*NL + 
          (-0.00022685441433622006 + 0.0008097893591232259*lm + 
            0.00042845067768023206*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.008949218069773451 - 0.007179506932932714*lm - 
          0.0022719343887845616*lm^2) + CF^2*(0.008654714089713347 + 
          0.008456738016734883*lm + 0.007435421636022201*lm^2) + 
        CF*((0.0014660640599657602 + 0.0007796280135417519*lm + 
            0.0004130789797790112*lm^2)*NM + (0.002290830670052373 + 
            0.0007796280135417519*lm + 0.0004130789797790112*lm^2)*NL + 
          (-0.00021785275407809818 + 0.0007796280135417519*lm + 
            0.0004130789797790112*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.00861754648577922 - 0.006915039683000449*lm - 
          0.002190231729778026*lm^2) + CF^2*(0.008352715654637813 + 
          0.00813206693318991*lm + 0.007168031115637176*lm^2) + 
        CF*((0.0013994072138142598 + 0.0007504494594398773*lm + 
            0.000398223950868732*lm^2)*NM + (0.002205989433783496 + 
            0.0007504494594398773*lm + 0.000398223950868732*lm^2)*NL + 
          (-0.00020915688124030504 + 0.0007504494594398773*lm + 
            0.000398223950868732*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.008296578526077122 - 0.006659332627567094*lm - 
          0.002111278227540617*lm^2) + CF^2*(0.008059601298282237 + 
          0.007817866613690374*lm + 0.006909637835587473*lm^2) + 
        CF*((0.0013355030286395849 + 0.00072222749946561*lm + 
            0.00038386876864374847*lm^2)*NM + (0.0021240157837686736 + 
            0.00072222749946561*lm + 0.00038386876864374847*lm^2)*NL + 
          (-0.00020075814877783493 + 0.00072222749946561*lm + 
            0.00038386876864374847*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.007986045643649433 - 0.006412129706662132*lm - 
          0.002034984308537211*lm^2) + CF^2*(0.007775183064614042 + 
          0.007513892005784285*lm + 0.006659948646121782*lm^2) + 
        CF*((0.0012742502274468907 + 0.0006949363050208679*lm + 
            0.00036999714700676565*lm^2)*NM + (0.0020448232250971877 + 
            0.0006949363050208679*lm + 0.00036999714700676565*lm^2)*NL + 
          (-0.00019264808911077588 + 0.0006949363050208679*lm + 
            0.00036999714700676565*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.007685680767083962 - 0.006173180644738206*lm - 
          0.001961263259940734*lm^2) + CF^2*(0.007499272864413733 + 
          0.0072198980504446396*lm + 0.0064186797598060384*lm^2) + 
        CF*((0.0012155505669704835 + 0.0006685504372388427*lm + 
            0.0003565933199892244*lm^2)*NM + (0.0019683272315425943 + 
            0.0006685504372388427*lm + 0.0003565933199892244*lm^2)*NL + 
          (-0.0001848184137740489 + 0.0006685504372388427*lm + 
            0.0003565933199892244*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.0073952188002495 - 0.005942240940513203*lm - 
          0.0018900311432809163*lm^2) + CF^2*(0.0072316827848209675 + 
          0.006935640220456317*lm + 0.006185556468919363*lm^2) + 
        CF*((0.0011593087988983487 + 0.0006430448651192133*lm + 
            0.0003436420260510757*lm^2)*NM + (0.0018944452540535803 + 
            0.0006430448651192133*lm + 0.0003436420260510757*lm^2)*NL + 
          (-0.00017726101279555006 + 0.0006430448651192133*lm + 
            0.0003436420260510757*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.007114397066269128 - 0.005719071845126784*lm - 
          0.0018212067101869634*lm^2) + CF^2*(0.006972225378631086 + 
          0.006660875006697924*lm + 0.0059603128697027895*lm^2) + 
        CF*((0.001105432626415191 + 0.0006183949810541676*lm + 
            0.00033112849276126607*lm^2)*NM + (0.0018230967232544931 + 
            0.0006183949810541676*lm + 0.00033112849276126607*lm^2)*NL + 
          (-0.00016996795384309412 + 0.0006183949810541676*lm + 
            0.00033112849276126607*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.006842955700448535 - 0.0055034403298011274*lm - 
          0.0017547113202243695*lm^2) + CF^2*(0.006720713933892586 + 
          0.006395360356210962*lm + 0.005742691593461573*lm^2) + 
        CF*((0.0010538326564823234 + 0.0005945766139615078*lm + 
            0.00031903842185897625*lm^2)*NM + (0.0017542030465889581 + 
            0.0005945766139615078*lm + 0.00031903842185897625*lm^2)*NL + 
          (-0.00016293148114902817 + 0.0005945766139615078*lm + 
            0.00031903842185897625*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.006580637996388081 - 0.005295119044102228*lm - 
          0.00169046886081992*lm^2) + CF^2*(0.00647696272427097 + 
          0.006138856065683689*lm + 0.005532443544501556*lm^2) + 
        CF*((0.0010044223489004333 + 0.0005715660402255476*lm + 
            0.00030735797469453094*lm^2)*NM + (0.0016876876006858392 + 
            0.0005715660402255476*lm + 0.00030735797469453094*lm^2)*NL + 
          (-0.0001561440142357852 + 0.0005715660402255476*lm + 
            0.00030735797469453094*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.00632719070926774 - 0.0050938862658113536*lm - 
          0.0016284056692634906*lm^2) + CF^2*(0.006240787240870722 + 
          0.005891124133729256*lm + 0.005329327644862333*lm^2) + 
        CF*((0.0009571179622115257 + 0.0005493399926320003*lm + 
            0.0002960737580479074*lm^2)*NM + (0.0016234757194769816 + 
            0.0005493399926320003*lm + 0.0002960737580479074*lm^2)*NL + 
          (-0.00014959814645181273 + 0.0005493399926320003*lm + 
            0.0002960737580479074*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.006082364319926976 - 0.004899525843335805*lm - 
          0.0015684504567704878*lm^2) + CF^2*(0.006012004406118016 + 
          0.005651929075105935*lm + 0.005133110585794323*lm^2) + 
        CF*((0.000911838497301357 + 0.0005278756674695377*lm + 
            0.0002851728103219069*lm^2)*NM + (0.0015614946785503729 + 
            0.0005278756674695377*lm + 0.0002851728103219069*lm^2)*NL + 
          (-0.0001432866433651548 + 0.0005278756674695377*lm + 
            0.0002851728103219069*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.005845913263117409 - 0.004711827131513575*lm - 
          0.0015105342345846334*lm^2) + CF^2*(0.005790432770407866 + 
          0.005421038199810616*lm + 0.0049435665859133456*lm^2) + 
        CF*((0.00086850563894646 + 0.0005071507299580903*lm + 
            0.00027464258810629697*lm^2)*NM + (0.0015016736761802442 + 
            0.0005071507299580903*lm + 0.00027464258810629697*lm^2)*NL + 
          (-0.00013720244097447265 + 0.0005071507299580903*lm + 
            0.00027464258810629697*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.005617596123026157 - 0.004530584921597298*lm - 
          0.0014545902420971919*lm^2) + CF^2*(0.005575892692198489 + 
          0.005198221859774211*lm + 0.0047604771559544455*lm^2) + 
        CF*((0.0008270436958860557 + 0.0004871433181522248*lm + 
            0.00026447095310858033*lm^2)*NM + (0.0014439438114369175 + 
            0.0004871433181522248*lm + 0.00026447095310858033*lm^2)*NL + 
          (-0.00013133864381239293 + 0.0004871433181522248*lm + 
            0.00026447095310858033*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.005397175798949143 - 0.004355599366138819*lm - 
          0.0014005538769556439*lm^2) + CF^2*(0.005368206502291089 + 
          0.00498325366569836*lm + 0.004583630870036653*lm^2) + 
        CF*((0.0007873795394368714 + 0.00046783204545699163*lm + 
            0.0002546461594464807*lm^2)*NM + (0.0013882380597436243 + 
            0.00046783204545699163*lm + 0.0002546461594464807*lm^2)*NL + 
          (-0.00012568852291545678 + 0.00046783204545699163*lm + 
            0.0002546461594464807*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.0051844196437456575 - 0.004186675899436299*lm - 
          0.0013483626271321508*lm^2) + CF^2*(0.005167198652987486 + 
          0.004775910676396047*lm + 0.004412823143341584*lm^2) + 
        CF*((0.000749442541510357 + 0.00044919600188345754*lm + 
            0.00024515684129675466*lm^2)*NM + (0.0013344912462148182 + 
            0.00044919600188345754*lm + 0.00024515684129675466*lm^2)*NL + 
          (-0.0001202455136888684 + 0.00044919600188345754*lm + 
            0.00024515684129675466*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.004979099577529104 - 0.004023625154150754*lm - 
          0.0012979560049198955*lm^2) + CF^2*(0.004972695852876931 + 
          0.004575973562833571*lm + 0.004247856016101476*lm^2) + 
        CF*((0.0007131645117893379 + 0.0004312147541616488*lm + 
            0.00023599200089452645*lm^2)*NM + (0.0012826400170804512 + 
            0.0004312147541616488*lm + 0.00023599200089452645*lm^2)*NL + 
          (-0.00011500321367322031 + 0.0004312147541616488*lm + 
            0.00023599200089452645*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.00478099217883122 - 0.003866262874647944*lm - 
          0.0012492754828234952*lm^2) + CF^2*(0.004784527187944244 + 
          0.004383226748917076*lm + 0.004088537943785984*lm^2) + 
        CF*((0.0006784796346377333 + 0.00041386834481980917*lm + 
            0.0002271409968769991*lm^2)*NM + (0.0012326228094730945 + 
            0.00041386834481980917*lm + 0.0002271409968769991*lm^2)*NL + 
          (-0.00010995538023976018 + 0.00041386834481980917*lm + 
            0.0002271409968769991*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.004589878755322871 - 0.003714409827574381*lm - 
          0.0012022644313080977*lm^2) + CF^2*(0.004602524229726746 + 
          0.004197458530922882*lm + 0.003934683593371956*lm^2) + 
        CF*((0.0006453244058867895 + 0.0003971372903306583*lm + 
            0.00021859353296510865*lm^2)*NM + (0.0011843798198294185 + 
            0.0003971372903306583*lm + 0.00021859353296510865*lm^2)*NL + 
          (-0.00010509592817684302 + 0.0003971372903306583*lm + 
            0.00021859353296510865*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.004405545395994132 - 0.0035678917101325002*lm - 
          0.0011568680583704963*lm^2) + CF^2*(0.004426521131200762 + 
          0.004018461177336386*lm + 0.003786113645576169*lm^2) + 
        CF*((0.0006136375696931751 + 0.00038100257841769517*lm + 
            0.00021033964697645386*lm^2)*NM + (0.001137852971134282 + 
            0.00038100257841769517*lm + 0.00021033964697645386*lm^2)*NL + 
          (-0.00010041892725967848 + 0.00038100257841769517*lm + 
            0.00021033964697645386*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.0042277830065619105 - 0.0034265390564796657*lm - 
          0.0011130333508945608*lm^2) + CF^2*(0.004256354711096528 + 
          0.0038460310107388783*lm + 0.003642654602927654*lm^2) + 
        CF*((0.000583360055654276 + 0.0003654456646074788*lm + 
            0.00020236970016264744*lm^2)*NM + (0.0010929858792143071 + 
            0.0003654456646074788*lm + 0.00020236970016264744*lm^2)*NL + 
          (-0.00009591859972424664 + 0.0003654456646074788*lm + 
            0.00020236970016264744*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.004056387329717786 - 0.003290187142638269*lm - 
          0.0010707090177524935*lm^2) + CF^2*(0.004091864527291304 + 
          0.0036799684732645227*lm + 0.003504138603553615*lm^2) + 
        CF*((0.0005544349163593049 + 0.00035044846810720746*lm + 
            0.0001946743668640897*lm^2)*NM + (0.0010497238182682076 + 
            0.00035044846810720746*lm + 0.0001946743668640897*lm^2)*NL + 
          (-0.00009158931772038794 + 0.00035044846810720746*lm + 
            0.0001946743668640897*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.00389115895171244 - 0.0031586758902696238*lm - 
          0.001029845434612818*lm^2) + CF^2*(0.003932892939937311 + 
          0.0035200781770405275*lm + 0.0033704032405510406*lm^2) + 
        CF*((0.0005268072655016644 + 0.0003359933670807671*lm + 
            0.0001872446244750578*lm^2)*NM + (0.0010080136858031468 + 
            0.0003359933670807671*lm + 0.0001872446244750578*lm^2)*NL + 
          (-0.00008742560071167011 + 0.0003359933670807671*lm + 
            0.0001872446244750578*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.0037319139606631145 - 0.0030318522409105196*lm - 
          0.0009903950258358248*lm^2) + CF*(0.0037792727073586783 + 
          0.0033661741463311572*lm + 0.003241292811826336*lm^2) + 
        0.0005004269541866476*NM + 0.0003220635419556061*lm*NM + 
        0.0001800718228792409*lm^2*NM + 0.0009678059361987668*NL + 
        0.0003220635419556061*lm*NL + 0.0001800718228792409*lm^2*NL - 
        0.0000834221096178207*NH + 0.0003220635419556061*lm*NH + 
        0.0001800718228792409*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.0035784392827455467 - 0.002909559713154513*lm - 
          0.0009523103890643748*lm^2) + CF*(0.0036308792212279275 + 
          0.0032180580559390314*lm + 0.0031166521823924992*lm^2) + 
        0.0004752370478156421*NM + 0.00030864151070741143*lm*NM + 
        0.00017314734346624998*lm^2*NM + 0.0009290463001487367*NL + 
        0.00030864151070741143*lm*NL + 0.00017314734346624998*lm^2*NL - 
        0.00007957365772569858*NH + 0.00030864151070741143*lm*NH + 
        0.00017314734346624998*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.003430562970199318 - 0.0027916545952856673*lm - 
          0.0009155471177365079*lm^2) + CF*(0.0034875482848217777 + 
          0.003075553540712243*lm + 0.0029963360216831167*lm^2) + 
        0.0004511918219139219*NM + 0.00029571141983192117*lm*NM + 
        0.0001664631123157287*lm^2*NM + 0.0008916887348548436*NL + 
        0.00029571141983192117*lm*NL + 0.0001664631123157287*lm^2*NL - 
        0.00007587518657924798*NH + 0.00029571141983192117*lm*NH + 
        0.0001664631123157287*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.0032881047601982898 - 0.0026779944030120716*lm - 
          0.0008800617329589227*lm^2) + CF*(0.0033491339905442814 + 
          0.002938482111509779*lm + 0.0028802020351382926*lm^2) + 
        0.00042824401492090884*NM + 0.0002832574243257499*lm*NM + 
        0.00016001122417434957*lm^2*NM + 0.0008556862621098023*NL + 
        0.0002832574243257499*lm*NL + 0.00016001122417434957*lm^2*NL - 
        0.00007232177842795858*NH + 0.0002832574243257499*lm*NH + 
        0.00016001122417434957*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.0031508891159068883 - 0.002568440812070192*lm - 
          0.0008458121713172718*lm^2) + CF*(0.0032154934030541016 + 
          0.0028066695235922415*lm + 0.0027681125606747077*lm^2) + 
        0.00040634813179888724*NM + 0.00027126410800545957*lm*NM + 
        0.00015378403114859487*lm^2*NM + 0.0008209933495310156*NL + 
        0.00027126410800545957*lm*NL + 0.00015378403114859487*lm^2*NL - 
        0.00006890864950540332*NH + 0.00027126410800545957*lm*NH + 
        0.00015378403114859487*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.0030187451746924044 - 0.002462859560594398*lm - 
          0.0008127577390226922*lm^2) + CF*(0.0030864865752400312 + 
          0.0026799457606463246*lm + 0.00265993441861972*lm^2) + 
        0.000385460387177154*NM + 0.0002597164763672841*lm*NM + 
        0.00014777413436776224*lm^2*NM + 0.0007875658743532281*NL + 
        0.0002597164763672841*lm*NL + 0.00014777413436776224*lm^2*NL - 
        0.0000656311473362621*NH + 0.0002597164763672841*lm*NH + 
        0.00014777413436776224*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.002891506690465897 - 0.0023611203521032237*lm - 
          0.0007808590674984387*lm^2) + CF*(0.0029619765575247562 + 
          0.0025581450112944397*lm + 0.0025555387663585265*lm^2) + 
        0.00036553864969726544*NM + 0.0002485999492257408*lm*NM + 
        0.00014197437590880702*lm^2*NM + 0.0007553610874653442*NL + 
        0.0002485999492257408*lm*NL + 0.00014197437590880702*lm^2*NL - 
        0.00006248474804525785*NH + 0.0002485999492257408*lm*NH + 
        0.00014197437590880702*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.0027690119708703386 - 0.002263096759250728*lm - 
          0.0007500780703663891*lm^2) + CF*(0.002841829401013276 + 
          0.002441105638841409*lm + 0.002454800957562728*lm^2) + 
        0.0003465423875887627*NM + 0.00023790035316741416*lm*NM + 
        0.0001363778309757071*lm^2*NM + 0.0007243375777550583*NL + 
        0.00023790035316741416*lm*NL + 0.0001363778309757071*lm^2*NL - 
        0.00005946505367220529*NH + 0.00023790035316741416*lm*NH + 
        0.0001363778309757071*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.0026511038099755507 - 0.0021686661284756035*lm - 
          0.0007203779017938732*lm^2) + CF*(0.002725914154973163 + 
          0.002328670144954104*lm + 0.002357600405870858*lm^2) + 
        0.00032843261549815497*NM + 0.0002276039138531804*lm*NM + 
        0.00013097780032615876*lm^2*NM + 0.0006944552368177086*NL + 
        0.0002276039138531804*lm*NL + 0.00013097780032615876*lm^2*NL - 
        0.00005656778949702385*NH + 0.0002276039138531804*lm*NH + 
        0.00013097780032615876*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.002537629417084638 - 0.0020777094856661163*lm - 
          0.0006917229161619775*lm^2) + CF*(0.002614102859105918 + 
          0.0022206851279176704*lm + 0.0022638204528937444*lm^2) + 
        0.00031117184258796805*NM + 0.00021769724819933217*lm*NM + 
        0.00012576780293854136*lm^2*NM + 0.0006656752240791116*NL + 
        0.00021769724819933217*lm*NL + 0.00012576780293854136*lm^2*NL - 
        0.00005378880137823959*NH + 0.00021769724819933217*lm*NH + 
        0.00012576780293854136*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.002428440342205811 - 0.0019901114429455575*lm - 
          0.0006640786290172196*lm^2) + CF*(0.002506270531042036 + 
          0.002117001236063205*lm + 0.0021733482404199915*lm^2) + 
        0.00029472402191727963*NM + 0.00020816735646545548*lm*NM + 
        0.00012074156891222175*lm^2*NM + 0.0006379599323760399*NL + 
        0.00020816735646545548*lm*NL + 0.00012074156891222175*lm^2*NL - 
        0.00005112405310819513*NH + 0.00020816735646545548*lm*NH + 
        0.00012074156891222175*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.0023233923986963312 - 0.0019057601066705227*lm - 
          0.0006374116792692309*lm^2) + CF*(0.002402295149466965 + 
          0.0020174731169163066*lm + 0.002086074586699301*lm^2) + 
        0.00027905450111031426*NM + 0.0001990016142744879*lm*NM + 
        0.0001158930325944056*lm^2*NM + 0.0006112729540324143*NL + 
        0.0001990016142744879*lm*NL + 0.0001158930325944056*lm^2*NL - 
        0.00004856962378789949*NH + 0.0001990016142744879*lm*NH + 
        0.0001158930325944056*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.0022223455835416726 - 0.0018245469867229412*lm - 
          0.0006116897925978581*lm^2) + CF*(0.0023020576332609213 + 
          0.0019219593625735571*lm + 0.0020018938666838994*lm^2) + 
        0.00026412997431531733*NM + 0.00019018776458813787*lm*NM + 
        0.00011121632592688329*lm^2*NM + 0.0005855790474641627*NL + 
        0.00019018776458813787*lm*NL + 0.00011121632592688329*lm^2*NL - 
        0.000046121705224181984*NH + 0.00019018776458813787*lm*NH + 
        0.00011121632592688329*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.0021251639956925356 - 0.0017463669071662818*lm - 
          0.0005868817460338767*lm^2) + CF*(0.002205441817012429 + 
          0.001830322451774482*lm + 0.0019207038961108693*lm^2) + 
        0.000249918435452031*NM + 0.00018171390965875746*lm*NM + 
        0.00010670577200615941*lm^2*NM + 0.0005608441043410203*NL + 
        0.00018171390965875746*lm*NL + 0.00010670577200615941*lm^2*NL - 
        0.00004377659935156281*NH + 0.00018171390965875746*lm*NH + 
        0.00010670577200615941*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.002031715752844935 - 0.0016711179183267358*lm - 
          0.0005629573336782953*lm^2) + CF*(0.0021123344232434975 + 
          0.0017424286890997756*lm + 0.0018424058193107847*lm^2) + 
        0.0002363891327426165*NM + 0.00017356850297682577*lm*NM + 
        0.00010235587885059914*lm^2*NM + 0.0005370351173292691*NL + 
        0.00017356850297682577*lm*NL + 0.00010235587885059914*lm^2*NL - 
        0.00004153071568101858*NH + 0.00017356850297682577*lm*NH + 
        0.00010235587885059914*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.001941872907013926 - 0.0015987012103513161*lm - 
          0.0005398873335260316*lm^2) + CF*(0.0020226250316634354 + 
          0.0016581481416923127*lm + 0.0017669040006306489*lm^2) + 
        0.00022351252451777357*NM + 0.00016574034123140554*lm*NM + 
        0.00009816133336836939*lm^2*NM + 0.0005141201484355179*NL + 
        0.00016574034123140554*lm*NL + 0.00009816133336836939*lm^2*NL - 
        0.00003938056877760174*NH + 0.00016574034123140554*lm*NH + 
        0.00009816133336836939*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.001855511359219526 - 0.001529021028286686*lm - 
          0.0005176434753605396*lm^2) + CF*(0.0019362060457484406 + 
          0.0015773545738655822*lm + 0.001694105919361766*lm^2) + 
        0.00021126023628706867*NM + 0.00015821855629927258*lm*NM + 
        0.00009411699552009811*lm^2*NM + 0.0004920682979680696*NL + 
        0.00015821855629927258*lm*NL + 0.00009411699552009811*lm^2*NL - 
        0.0000373227757686678*NH + 0.00015821855629927258*lm*NH + 
        0.00009411699552009811*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.0017725107735737738 - 0.0014619845887150916*lm - 
          0.0004961984096867683*lm^2) + CF*(0.0018529726569252278 + 
          0.0014999253799345027*lm + 0.0016239220680657872*lm^2) + 
        0.00019960501906006475*NM + 0.00015099260727688017*lm*NM + 
        0.00009021789267032151*lm^2*NM + 0.00047084967412919254*NL + 
        0.00015099260727688017*lm*NL + 0.00009021789267032151*lm^2*NL - 
        0.00003535405388427376*NH + 0.00015099260727688017*lm*NH + 
        0.00009021789267032151*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.0016927544910305234 - 0.0013975019979769545*lm - 
          0.0004755256776706372*lm^2) + CF*(0.00177282280661904 + 
          0.0014257415155759805*lm + 0.0015562658541948128*lm^2) + 
        0.0001885207089027271*NM + 0.00014405227256789388*lm*NM + 
        0.00008645921412193404*lm^2*NM + 0.00045043536324867783*NL + 
        0.00014405227256789388*lm*NL + 0.00008645921412193404*lm^2*NL - 
        0.00003347121803113209*NH + 0.00014405227256789388*lm*NH + 
        0.00008645921412193404*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.0016161294430343206 - 0.0013354861720034576*lm - 
          0.000455599682054009*lm^2) + CF*(0.0016956571464093843 + 
          0.0013546874280008928*lm + 0.0014910535049040294*lm^2) + 
        0.00017798218771172795*NM + 0.0001373876420377175*lm*NM + 
        0.00008283630582800163*lm^2*NM + 0.0004307974006664048*NL + 
        0.0001373876420377175*lm*NL + 0.00008283630582800163*lm^2*NL - 
        0.00003167117840133952*NH + 0.0001373876420377175*lm*NH + 
        0.00008283630582800163*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.0015425260652814155 - 0.0012758527577767663*lm - 
          0.0004363956590149366*lm^2) + CF*(0.0016213789965207172 + 
          0.0012866509851953327*lm + 0.0014282039749579744*lm^2) + 
        0.00016796534518767218*NM + 0.00013098910924521186*lm*NM + 
        0.00007934466527544302*lm^2*NM + 0.00041190874226922785*NL + 
        0.00013098910924521186*lm*NL + 0.00007934466527544302*lm^2*NL - 
        0.00002995093811694457*NH + 0.00013098910924521186*lm*NH + 
        0.00007934466527544302*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.0014718382117844746 - 0.001218520056430361*lm - 
          0.00041788965094374987*lm^2) + CF*(0.0015498943028600363 + 
          0.0012215234044667712*lm + 0.0013676388576340905*lm^2) + 
        0.00015844704198688837*NM + 0.0001248473637606855*lm*NM + 
        0.00007597993653522726*lm^2*NM + 0.0003937432366853242*NL + 
        0.0001248473637606855*lm*NL + 0.00007597993653522726*lm^2*NL - 
        0.000028307590911274232*NH + 0.0001248473637606855*lm*NH + 
        0.00007597993653522726*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.0014039630694127636 - 0.0011634089479972294*lm - 
          0.000400058480106326*lm^2) + CF*(0.0014811115927988638 + 
          0.0011591991805102121*lm + 0.0013092822985297941*lm^2) + 
        0.00014940507403025968*NM + 0.00011895338357819766*lm*NM + 
        0.00007273790547387746*lm^2*NM + 0.0003762755981371828*NL + 
        0.00011895338357819766*lm*NL + 0.00007273790547387746*lm^2*NL - 
        0.000026738318847806475*NH + 0.00011895338357819766*lm*NH + 
        0.00007273790547387746*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.0013388010730613319 - 0.0011104428178094036*lm - 
          0.00038287972316666347*lm^2) + CF*(0.001414941929883433 + 
          0.0010995760131903007*lm + 0.0012530609121818078*lm^2) + 
        0.0001408181379465849*NM + 0.00011329842762925869*lm*NM + 
        0.00006961449512121154*lm^2*NM + 0.0003594813799526515*NL + 
        0.00011329842762925869*lm*NL + 0.00006961449512121154*lm^2*NL - 
        0.000025240390077251054*NH + 0.00011329842762925869*lm*NH + 
        0.00006961449512121154*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.0012762558215859514 - 0.001059547484548444*lm - 
          0.0003663316865416392*lm^2) + CF*(0.0013512988676439438 + 
          0.00104255473521761*lm + 0.001198903701409001*lm^2) + 
        0.0001326657976271466*NM + 0.00010787402840413116*lm*NM + 
        0.00006660576118938895*lm^2*NM + 0.0003433369487318838*NL + 
        0.00010787402840413116*lm*NL + 0.00006660576118938895*lm^2*NL - 
        0.000023811156633385935*NH + 0.00010787402840413116*lm*NH + 
        0.00006660576118938895*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.001216233994625134 - 0.0010106511299429659*lm - 
          0.0003503933825615819*lm^2) + CF*(0.0012900984026615256 + 
          0.0009880392398808875*lm + 0.0011467419792924498*lm^2) + 
        0.00012492845186750333*NM + 0.00010267198468612361*lm*NM + 
        0.00006370788773846944*lm^2*NM + 0.00032781945916661014*NL + 
        0.00010267198468612361*lm*NL + 0.00006370788773846944*lm^2*NL - 
        0.000022448052268089812*NH + 0.00010267198468612361*lm*NH + 
        0.00006370788773846944*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.0011586452704163632 - 0.0009636842301061507*lm - 
          0.00033504450641103507*lm^2) + CF*(0.0012312589270399947 + 
          0.0009359364089817902*lm + 0.001096509293708842*lm^2) + 
        0.0001175873030720035*NM + 0.00009768435440352342*lm*NM + 
        0.00006091718298382456*lm^2*NM + 0.0003129068295069062*NL + 
        0.00009768435440352342*lm*NL + 0.00006091718298382456*lm^2*NL - 
        0.000021148590325912456*NH + 0.00009768435440352342*lm*NH + 
        0.00006091718298382456*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.0011034022447006639 - 0.0009185794885033342*lm - 
          0.00032026541382481087*lm^2) + CF*(0.0011747011804185985 + 
          0.0008861560411045191*lm + 0.0010481413543357448*lm^2) + 
        0.00011062432699612437*NM + 0.00009290344760312931*lm*NM + 
        0.000058230075240874705*lm^2*NM + 0.00029857771766951026*NL + 
        0.00009290344760312931*lm*NL + 0.000058230075240874705*lm^2*NL - 
        0.00001991036165843319*NH + 0.00009290344760312931*lm*NH + 
        0.000058230075240874705*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.0010504203507976882 - 0.0008752717705372187*lm - 
          0.00030603709951515295*lm^2) + CF*(0.0011203482016516524 + 
          0.0008386107803396786*lm + 0.0010015759620495915*lm^2) + 
        0.0001040222435014595*NM + 0.00008832181954871512*lm*NM + 
        0.00005564310900275508*lm^2*NM + 0.0002848114979807586*NL + 
        0.00008832181954871512*lm*NL + 0.00005564310900275508*lm^2*NL - 
        0.000018731032578573324*NH + 0.00008832181954871512*lm*NH + 
        0.00005564310900275508*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.000999617780922547 - 0.000833698039735978*lm - 
          0.0002923411763065265*lm^2) + CF*(0.0010681252802712947 + 
          0.0007932160455695828*lm + 0.0009567529406395413*lm^2) + 
        0.00009776448829800096*NM + 0.00008393226394717993*lm*NM + 
        0.000053152941146641186*lm^2*NM + 0.0002715882385463396*NL + 
        0.00008393226394717993*lm*NL + 0.000053152941146641186*lm^2*NL - 
        0.0000176083428549507*NH + 0.00008393226394717993*lm*NH + 
        0.000053152941146641186*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.0009509154088055996 - 0.0007937972955274937*lm - 
          0.00027915985495524556*lm^2) + CF*(0.0010179599078404518 + 
          0.0007498899604110401*lm + 0.0009136140707626218*lm^2) + 
        0.00009183518564827569*NM + 0.00007972780630461146*lm*NM + 
        0.000050756337264590096*lm^2*NM + 0.0002588886792393076*NL + 
        0.00007972780630461146*lm*NL + 0.000050756337264590096*lm^2*NL - 
        0.000016540103746292662*NH + 0.00007972780630461146*lm*NH + 
        0.000050756337264590096*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.0009042367136672467 - 0.000755510512581168*lm - 
          0.00026647592463181806*lm^2) + CF*(0.0009697817292945245 + 
          0.0007085532839012913*lm + 0.0008721030260677682*lm^2) + 
        0.000086219122007893*NM + 0.00007570169741400652*lm*NM + 
        0.000048450168114876016*lm^2*NM + 0.00024669421029714184*NL + 
        0.00007570169741400652*lm*NL + 0.000048450168114876016*lm^2*NL - 
        0.00001552419607585797*NH + 0.00007570169741400652*lm*NH + 
        0.000048450168114876016*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.0008595077055913966 - 0.0007187805816971678*lm - 
          0.00025427273404455376*lm^2) + CF*(0.000923522494362222 + 
          0.0006691293420032302*lm + 0.0008321653114185397*lm^2) + 
        0.00008090172057712912*NM + 0.00007184740697595194*lm*NM + 
        0.00004623140618991887*lm^2*NM + 0.00023498685151806628*NL + 
        0.00007184740697595194*lm*NL + 0.00004623140618991887*lm^2*NL - 
        0.000014558568345757659*NH + 0.00007184740697595194*lm*NH + 
        0.00004623140618991887*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.000816656852333639 - 0.0006835522522215728*lm - 
          0.0002425341731836216*lm^2) + CF*(0.0008791160091483878 + 
          0.0006315439599972057*lm + 0.000793748203146398*lm^2) + 
        0.00007586901673831027*NM + 0.0000681586173531669*lm*NM + 
        0.00004409712239702211*lm^2*NM + 0.0002237492320463616*NL + 
        0.0000681586173531669*lm*NL + 0.00004409712239702211*lm^2*NL - 
        0.000013641234891009463*NH + 0.0000681586173531669*lm*NH + 
        0.00004409712239702211*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.0007756150075931924 - 0.0006497720759646835*lm - 
          0.00023124465566537748*lm^2) + CF*(0.0008364980879545212 + 
          0.0005957253958185725*lm + 0.0007568006912685081*lm^2) + 
        0.00007110763435394842*NM + 0.00006462921745944187*lm*NM + 
        0.00004204448284825045*lm^2*NM + 0.00021296457073599409*NL + 
        0.00006462921745944187*lm*NL + 0.00004204448284825045*lm^2*NL - 
        0.00001277027407310975*NH + 0.00006462921745944187*lm*NH + 
        0.00004204448284825045*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.0007363153407713624 - 0.0006173883525987056*lm - 
          0.00022038910165739732*lm^2) + CF*(0.0007956065054060183 + 
          0.0005616042743926626*lm + 0.0007212734236060277*lm^2) + 
        0.00006660476290082823*NM + 0.00006125329678317686*lm*NM + 
        0.000040070745755890426*lm^2*NM + 0.00020261665708154515*NL + 
        0.00006125329678317686*lm*NL + 0.000040070745755890426*lm^2*NL - 
        0.000011943826512860765*NH + 0.00006125329678317686*lm*NH + 
        0.000040070745755890426*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.0006986932682334893 - 0.0005863510765101318*lm - 
          0.00020995292136525255*lm^2) + CF*(0.0007563809489488744 + 
          0.0005291135230119414*lm + 0.0006871186517408265*lm^2) + 
        0.00006234813541553188*NM + 0.00005802513954542007*lm*NM + 
        0.00003817325843004592*lm^2*NM + 0.0001926898327051488*NL + 
        0.00005802513954542007*lm*NL + 0.00003817325843004592*lm^2*NL - 
        0.000011160093362148914*NH + 0.00005802513954542007*lm*NH + 
        0.00003817325843004592*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.00066268638608614 - 0.0005566118850813886*lm - 
          0.00019992199906265152*lm^2) + CF*(0.000718762971772717 + 
          0.0004981883077937688*lm + 0.0006542901787504959*lm^2) + 
        0.00005832600722721707*NM + 0.000054939218992035596*lm*NM + 
        0.00003634945437502755*lm^2*NM + 0.00018316897338792519*NL + 
        0.000054939218992035596*lm*NL + 0.00003634945437502755*lm^2*NL - 
        0.000010417334614331728*NH + 0.000054939218992035596*lm*NH + 
        0.00003634945437502755*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0006282344044765787 - 0.000528124008375691*lm - 
          0.0001902826776471422*lm^2) + CF*(0.0006826959462115324 + 
          0.0004687659712513449*lm + 0.0006227433086633745*lm^2) + 
        0.00005452713545382499*NM + 0.00005199019181938199*lm*NM + 
        0.000034596850481298585*lm^2*NM + 0.00017403947163423036*NL + 
        0.00005199019181938199*lm*NL + 0.000034596850481298585*lm^2*NL - 
        9.71386745285666*^-6*NH + 0.00005199019181938199*lm*NH + 
        0.000034596850481298585*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.0005952790834172732 - 0.0005008422201985335*lm - 
          0.00018102174370412773*lm^2) + CF*(0.0006481250176683012 + 
          0.0004407859710050659*lm + 0.0005924347975771453*lm^2) + 
        0.00005094075923828623*NM + 0.00004917289273266249*lm*NM + 
        0.0000329130443098414*lm^2*NM + 0.00016528721975692052*NL + 
        0.00004917289273266249*lm*NL + 0.0000329130443098414*lm^2*NL - 
        9.048064637703749*^-6*NH + 0.00004917289273266249*lm*NH + 
        0.0000329130443098414*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.0005637641701343464 - 0.00047472279050884633*lm - 
          0.0001721264130624897*lm^2) + CF*(0.0006149970591049479 + 
          0.00041418981965660244*lm + 0.0005633228063863299*lm^2) + 
        0.00004755658070170876*NM + 0.00004648232913590833*lm*NM + 
        0.000031295711465907216*lm^2*NM + 0.00015689859347175068*NL + 
        0.00004648232913590833*lm*NL + 0.000031295711465907216*lm^2*NL - 
        8.418352929216381*^-6*NH + 0.00004648232913590833*lm*NH + 
        0.000031295711465907216*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.0005336353379354196 - 0.00044972343915253537*lm - 
          0.00016358431682564142*lm^2) + CF*(0.0005832606261345159 + 
          0.0003889210258435143*lm + 0.0005353668550657356*lm^2) + 
        0.00004436474659096904*NM + 0.00004391367595237866*lm*NM + 
        0.00002974260305920753*lm^2*NM + 0.00014886043598898638*NL + 
        0.00004391367595237866*lm*NL + 0.00002974260305920753*lm^2*NL - 
        7.823211548859327*^-6*NH + 0.00004391367595237866*lm*NH + 
        0.00002974260305920753*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.0005048401265891829 - 0.0004258032908909074*lm - 
          0.00015538348786234637*lm^2) + CF*(0.0005528659127482888 + 
          0.0003649250364880982*lm + 0.0005085277784585881*lm^2) + 
        0.000041355830598582*NM + 0.000041462270574002186*lm*NM + 
        0.000028251543247699342*lm^2*NM + 0.00014116004259030044*NL + 
        0.000041462270574002186*lm*NL + 0.000028251543247699342*lm^2*NL - 
        7.261170676421163*^-6*NH + 0.000041462270574002186*lm*NH + 
        0.000028251543247699342*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.0004773278842062557 - 0.00040292283169634293*lm - 
          0.00014751234774213764*lm^2) + CF*(0.0005237647077066697 + 
          0.00034214918025040963*lm + 0.0004827676835197232*lm^2) + 
        0.00003852081633319428*NM + 0.000039123607938344554*lm*NM + 
        0.00002682042686220684*lm^2*NM + 0.00013378514567905045*NL + 
        0.000039123607938344554*lm*NL + 0.00002682042686220684*lm^2*NL - 
        6.730809983158564*^-6*NH + 0.000039123607938344554*lm*NH + 
        0.00002682042686220684*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.00045104971060841816 - 0.00038104386628751293*lm - 
          0.0001399596941006578*lm^2) + CF*(0.0004959103516189984 + 
          0.0003205426121919688*lm + 0.0004580499079657891*lm^2) + 
        0.0000358510809195253*NM + 0.0000368933357314617*lm*NM + 
        0.000025447217109210508*lm^2*NM + 0.0001267239002920845*NL + 
        0.0000368933357314617*lm*NL + 0.000025447217109210508*lm^2*NL - 
        6.230757200362726*^-6*NH + 0.0000368933357314617*lm*NH + 
        0.000025447217109210508*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.00042595840217110083 - 0.00036012947687643704*lm - 
          0.0001327146884207121*lm^2) + CF*(0.0004692576947340962 + 
          0.00030005625965354274*lm + 0.00043433898028596686*lm^2) + 
        0.00003333837920706972*NM + 0.00003476724971488988*lm*NM + 
        0.00002412994334922038*lm^2*NM + 0.0001199648700612977*NL + 
        0.00003476724971488988*lm*NL + 0.00002412994334922038*lm^2*NL - 
        5.7596867228132905*^-6*NH + 0.00003476724971488988*lm*NH + 
        0.00002412994334922038*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.00040200839812207174 - 0.00034014398309973974*lm - 
          0.00012576684421528424*lm^2) + CF*(0.00044376305546019136 + 
          0.000280642769347556*lm + 0.0004116005810682029*lm^2) + 
        0.00003097482856736985*NM + 0.00003274128917492823*lm*NM + 
        0.000022866698948233496*lm^2*NM + 0.00011349701361326054*NL + 
        0.00003274128917492823*lm*NL + 0.000022866698948233496*lm^2*NL - 
        5.316318246572201*^-6*NH + 0.00003274128917492823*lm*NH + 
        0.000022866698948233496*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.00037915572827755404 - 0.0003210529031065755*lm - 
          0.00011910601559920976*lm^2) + CF*(0.00041938417962995617 + 
          0.0002622564556631147*lm + 0.0003898015055974137*lm^2) + 
        0.00002875289426016617*NM + 0.0000308115324922875*lm*NM + 
        0.00002165563919985632*lm^2*NM + 0.00010730967139535617*NL + 
        0.0000308115324922875*lm*NL + 0.00002165563919985632*lm^2*NL - 
        4.899415440559002*^-6*NH + 0.0000308115324922875*lm*NH + 
        0.00002165563919985632*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.00035735796219551146 - 0.0003028229157758543*lm - 
          0.00011272238623663352*lm^2) + CF*(0.00039608020052368705 + 
          0.00024485325017929623*lm + 0.0003689096276835279*lm^2) + 
        0.00002666537534923592*NM + 0.000028974192830107897*lm*NM + 
        0.00002049497931575155*lm^2*NM + 0.00010139255291699754*NL + 
        0.000028974192830107897*lm*NL + 0.00002049497931575155*lm^2*NL - 
        4.507784651339899*^-6*NH + 0.000028974192830107897*lm*NH + 
        0.00002049497931575155*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.00033657415972453966 - 0.00028542182403560684*lm - 
          0.0001066064586517965*lm^2) + CF*(0.0003738115996611524 + 
          0.00022839065238025876*lm + 0.00034889386467860673*lm^2) + 
        0.00002470539114923203*NM + 0.000027225613938289656*lm*NM + 
        0.00001938299248214482*lm^2*NM + 0.00009573572439464438*NL + 
        0.000027225613938289656*lm*NL + 0.00001938299248214482*lm^2*NL - 
        4.1402736405554165*^-6*NH + 0.000027225613938289656*lm*NH + 
        0.00001938299248214482*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0003167648229256869 - 0.0002688185192575699*lm - 
          0.00010074904389110366*lm^2) + CF*(0.0003525401683703217 + 
          0.0002128276815638319*lm + 0.00032972414364361197*lm^2) + 
        0.00002286636818533615*NM + 0.000025562266072030047*lm*NM + 
        0.000018318007980200664*lm^2*NM + 0.00009032959678950058*NL + 
        0.000025562266072030047*lm*NL + 0.000018318007980200664*lm^2*NL - 
        3.795770354405502*^-6*NH + 0.000025562266072030047*lm*NH + 
        0.000018318007980200664*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.00029789184934356976 - 0.0002529829467003526*lm - 
          0.00009514125152481876*lm^2) + CF*(0.00033222897013905335 + 
          0.00019812482993355213*lm + 0.0003113713686266796*lm^2) + 
        0.000021142027648038903*NM + 0.0000239807420224201*lm*NM + 
        0.000017298409368148866*lm^2*NM + 0.00008516491422694613*NL + 
        0.0000239807420224201*lm*NL + 0.000017298409368148866*lm^2*NL - 
        3.473201724606366*^-6*NH + 0.0000239807420224201*lm*NH + 
        0.000017298409368148866*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0002799184866023524 - 0.0002378860719748526*lm - 
          0.00008977447997711419*lm^2) + CF*(0.0003128423037538477 + 
          0.00018424401686258817*lm + 0.0002938073890160101*lm^2) + 
        0.000019526373325856115*NM + 0.000022477753256921984*lm*NM + 
        0.00001632263272311167*lm^2*NM + 0.00008023274278693905*NL + 
        0.000022477753256921984*lm*NL + 0.00001632263272311167*lm^2*NL - 
        3.17153250023013*^-6*NH + 0.000022477753256921984*lm*NH + 
        0.00001632263272311167*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.00026280928830148747 - 0.0002234998485059274*lm - 
          0.00008464040717357409*lm^2) + CF*(0.0002943456672279634 + 
          0.000171148544316648*lm + 0.00027700496893169705*lm^2) + 
        0.00001801367999928114*NM + 0.000021050126167523376*lm*NM + 
        0.000015389164940649834*lm^2*NM + 0.00007552445965481396*NL + 
        0.000021050126167523376*lm*NL + 0.000015389164940649834*lm^2*NL - 
        2.8897641098363095*^-6*NH + 0.000021050126167523376*lm*NH + 
        0.000015389164940649834*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.0002465300711855794 - 0.00020979718596468496*lm - 
          0.00007973098149560834*lm^2) + CF*(0.00027670572251952926 + 
          0.00015880305342176008*lm + 0.0002609377576219909*lm^2) + 
        0.000016598482279759178*NM + 0.000019694798424347404*lm*NM + 
        0.000014496542090110606*lm^2*NM + 0.00007103174262210027*NL + 
        0.000019694798424347404*lm*NL + 0.000014496542090110606*lm^2*NL - 
        2.626933553303239*^-6*NH + 0.000019694798424347404*lm*NH + 
        0.000014496542090110606*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.00023104787356230454 - 0.0001967519196461381*lm - 
          0.00007503841303158252*lm^2) + CF*(0.00025989026103875797 + 
          0.0001471734821617611*lm + 0.0002455802608306337*lm^2) + 
        0.00001527556387794908*NM + 0.000018408815432485353*lm*NM + 
        0.000013643347823924095*lm^2*NM + 0.000066746559927186*NL + 
        0.000018408815432485353*lm*NL + 0.000013643347823924095*lm^2*NL - 
        2.382112322767684*^-6*NH + 0.000018408815432485353*lm*NH + 
        0.000013643347823924095*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.00021633091494199794 - 0.00018433878076736537*lm - 
          0.00007055516511480637*lm^2) + CF*(0.0002438681699419747 + 
          0.00013622702418939495*lm + 0.00023090781310300263*lm^2) + 
        0.000014039947286010708*NM + 0.000017189326889813718*lm*NM + 
        0.000012828211839055701*lm^2*NM + 0.00006266116042586067*NL + 
        0.000017189326889813718*lm*NL + 0.000012828211839055701*lm^2*NL - 
        2.1544053520819094*^-6*NH + 0.000017189326889813718*lm*NH + 
        0.000012828211839055701*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.000202348556872289 - 0.00017253336766173281*lm - 
          0.00006627394613884898*lm^2) + CF*(0.00022860939920889674 + 
          0.000125932088734117*lm + 0.0002168965509998694*lm^2) + 
        0.00001288688385912105*NM + 0.000016033583443556614*lm*NM + 
        0.000012049808388881633*lm^2*NM + 0.00005876806408198066*NL + 
        0.000016033583443556614*lm*NL + 0.000012049808388881633*lm^2*NL - 
        1.9429499941994186*^-6*NH + 0.000016033583443556614*lm*NH + 
        0.000012049808388881633*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0001890712649410238 - 0.00016131211784515832*lm - 
          0.00006218770164096587*lm^2) + CF*(0.00021408492949844237 + 
          0.00011625826158900023*lm + 0.00020352338718861558*lm^2) + 
        0.00001181184428187909*NM + 0.000014938933443358995*lm*NM + 
        0.000011306854843811978*lm^2*NM + 0.00005506005276871457*NL + 
        0.000014938933443358995*lm*NL + 0.000011306854843811978*lm^2*NL - 
        1.74691502590327*^-6*NH + 0.000014938933443358995*lm*NH + 
        0.000011306854843811978*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0001764705719206449 - 0.00015065228093083527*lm - 
          0.000058289606644728155*lm^2) + CF*(0.0002002667407772929 + 
          0.00010717626715854142*lm + 0.0001907659853827467*lm^2) + 
        0.000010810509405708086*NM + 0.000013902819788644524*lm*NM + 
        0.000010598110299041482*lm^2*NM + 0.000051530161371040414*NL + 
        0.000013902819788644524*lm*NL + 0.000010598110299041482*lm^2*NL - 
        1.5654996792943222*^-6*NH + 0.000013902819788644524*lm*NH + 
        0.000010598110299041482*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0001645190420272014 - 0.0001405318923692782*lm - 
          0.000054573058253241106*lm^2) + CF*(0.00018712778171447807 + 
          0.00009865793154866148*lm + 0.00017860273610151634*lm^2) + 
        9.878761443803254*^-6*NM + 0.000012922776868044374*lm*NM + 
        9.92237422786202*^-6*lm^2*NM + 0.00004817166918038315*NL + 
        0.000012922776868044374*lm*NL + 9.92237422786202*^-6*lm^2*NL - 
        1.3979326994608384*^-6*NH + 0.000012922776868044374*lm*NH + 
        9.92237422786202*^-6*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0001531902362672268 - 0.000130929747991005*lm - 
          0.00005103166848462566*lm^2) + CF*(0.00017464193983439446 + 
          0.00009067614667977543*lm + 0.00016701273322241125*lm^2) + 
        9.012675510603376*^-6*NM + 0.000011996427588699104*lm*NM + 
        9.278485179022848*^-6*lm^2*NM + 0.000044978091572497315*NL + 
        0.000011996427588699104*lm*NL + 9.278485179022848*^-6*lm^2*NL - 
        1.2434714277555793*^-6*NH + 0.000011996427588699104*lm*NH + 
        9.278485179022848*^-6*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0001424586788458433 - 0.00012182537932962719*lm - 
          0.000047659257341713964*lm^2) + CF*(0.00016278401241989318 + 
          0.00008320483540346682*lm + 0.00015597575130015478*lm^2) + 
        8.208511493185697*^-6*NM + 0.000011121480493254606*lm*NM + 
        8.665319516675265*^-6*lm^2*NM + 0.00004194317195991595*NL + 
        0.000011121480493254606*lm*NL + 8.665319516675265*^-6*lm^2*NL - 
        1.1014009101117307*^-6*NH + 0.000011121480493254606*lm*NH + 
        8.665319516675265*^-6*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.00013229982460962096 - 0.00011319902970358113*lm - 
          0.000044449846108178754*lm^2) + CF*(0.0001515296781563805 + 
          0.00007621891760303261*lm + 0.00014547222362676682*lm^2) + 
        7.462706242394871*^-6*NM + 0.000010295726962394874*lm*NM + 
        8.081790201487046*^-6*lm^2*NM + 0.00003906087401050263*NL + 
        0.000010295726962394874*lm*NL + 8.081790201487046*^-6*lm^2*NL - 
        9.710330298347422*^-7*NH + 0.000010295726962394874*lm*NH + 
        8.081790201487046*^-6*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.00012269002749793671 - 0.00010503163103519642*lm - 
          0.000041397650863576024*lm^2) + CF*(0.0001408554695072574 + 
          0.0000696942772579619*lm + 0.00013548322100806698*lm^2) + 
        6.7718660719182114*^-6*NM + 9.517038500778451*^-6*lm*NM + 
        7.5268456115592764*^-6*lm^2*NM + 0.000036325374123857906*NL + 
        9.517038500778451*^-6*lm*NL + 7.5268456115592764*^-6*lm^2*NL - 
        8.517056643133007*^-7*NH + 9.517038500778451*^-6*lm*NH + 
        7.5268456115592764*^-6*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.0001136065099768329 - 0.00009730478138626234*lm - 
          0.0000384970762100318*lm^2) + CF*(0.00013073874581047916 + 
          0.00006360773045226786*lm + 0.00012599043123283135*lm^2) + 
        6.132759553911361*^-6*NM + 8.783364104271744*^-6*lm*NM + 
        6.999468401823964*^-6*lm^2*NM + 0.0000337310541575443*NL + 
        8.783364104271744*^-6*lm*NL + 6.999468401823964*^-6*lm^2*NL - 
        7.427818650992193*^-7*NH + 8.783364104271744*^-6*lm*NH + 
        6.999468401823964*^-6*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.00010502733342966567 - 0.00009000072318971775*lm - 
          0.00003574270920354701*lm^2) + CF*(0.00012115766708553318 + 
          0.00005793699430650479*lm + 0.00011697613921160839*lm^2) + 
        5.542310600160202*^-6*NM + 8.092727706400616*^-6*lm*NM + 
        6.49867440064491*^-6*lm^2*NM + 0.00003127249439530488*NL + 
        8.092727706400616*^-6*lm*NL + 6.49867440064491*^-6*lm^2*NL - 
        6.436490608129275*^-7*NH + 8.092727706400616*^-6*lm*NH + 
        6.49867440064491*^-6*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.00009693136947915492 - 0.00008310232215755404*lm - 
          0.000033129313483129484*lm^2) + CF*(0.00011209116853971464 + 
          0.00005266065681326186*lm + 0.00010842320776296921*lm^2) + 
        4.99759181813686*^-6*NM + 7.4432257019715986*^-6*lm*NM + 
        6.0235115423871785*^-6*lm^2*NM + 0.0000289444667496591*NL + 
        7.4432257019715986*^-6*lm*NL + 6.0235115423871785*^-6*lm^2*NL - 
        5.5371828233846*^-7*NH + 7.4432257019715986*^-6*lm*NH + 
        6.0235115423871785*^-6*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.00008929827221579642 - 0.00007659304684548194*lm - 
          0.00003065182359118972*lm^2) + CF*(0.00010351893576221525 + 
          0.000047758147555932885*lm + 0.00010031505902571183*lm^2) + 
        4.495818131669609*^-6*NM + 6.833024545845375*^-6*lm*NM + 
        5.573058834761768*^-6*lm^2*NM + 0.00002674192819146545*NL + 
        6.833024545845375*^-6*lm*NL + 5.573058834761768*^-6*lm^2*NL - 
        4.7242340977933063*^-7*NH + 6.833024545845375*^-6*lm*NH + 
        5.573058834761768*^-6*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.00008210845130796862 - 0.00007045694885537305*lm - 
          0.00002830533947885675*lm^2) + CF*(0.00009542138059422945 + 
          0.000043209709290607204*lm + 0.00009263565647625844*lm^2) + 
        4.034340656298651*^-6*NM + 6.2603584248778355*^-6*lm*NM + 
        5.146425359792136*^-6*lm^2*NM + 0.00002466001439924384*NL + 
        6.2603584248778355*^-6*lm*NL + 5.146425359792136*^-6*lm^2*NL - 
        3.992204406544156*^-7*NH + 6.2603584248778355*^-6*lm*NH + 
        5.146425359792136*^-6*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.00007534304596945975 - 0.00006467864365694212*lm - 
          0.000026085121190083178*lm^2) + CF*(0.00008777961766301951 + 
          0.00003899637037101205*lm + 0.00008536948753118131*lm^2) + 
        3.6106408197320933*^-6*NM + 5.723527001077668*^-6*lm*NM + 
        4.74274930728785*^-6*lm^2*NM + 0.000022694033621250637*NL + 
        5.723527001077668*^-6*lm*NL + 4.74274930728785*^-6*lm^2*NL - 
        3.335867788208989*^-7*NH + 5.723527001077668*^-6*lm*NH + 
        4.74274930728785*^-6*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.00006898389976055056 - 0.00005924329201058829*lm - 
          0.000023986583718614233*lm^2) + CF*(0.0000805754415676642 + 
          0.00003509991799655341*lm + 0.00007850154671546476*lm^2) + 
        3.2223247181490724*^-6*NM + 5.220893224063999*^-6*lm*NM + 
        4.3611970397480426*^-6*lm^2*NM + 0.000020839460743496197*NL + 
        5.220893224063999*^-6*lm*NL + 4.3611970397480426*^-6*lm^2*NL - 
        2.750205436194582*^-7*NH + 5.220893224063999*^-6*lm*NH + 
        4.3611970397480426*^-6*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.00006301353619921352 - 0.000054136581973760366*lm - 
          0.00002200529203209409*lm^2) + CF*(0.00007379130470403866 + 
          0.000031502872263650724*lm + 0.00007201731937776248*lm^2) + 
        2.867117699419957*^-6*NM + 4.750881210942921*^-6*lm*NM + 
        4.000962187653471*^-6*lm^2*NM + 0.00001909193155708821*NL + 
        4.750881210942921*^-6*lm*NL + 4.000962187653471*^-6*lm^2*NL - 
        2.2303989874513368*^-7*NH + 4.750881210942921*^-6*lm*NH + 
        4.000962187653471*^-6*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.00005741513515942579 - 0.000049344711473653654*
           lm - 0.00002013695625777523*lm^2) + 
        CF*(0.00006741029571643641 + 0.000028188461000734604*lm + 
          0.00006590276593453712*lm^2) + 2.5428591646271054*^-6*NM + 
        4.311974191757636*^-6*lm*NM + 3.6612647741409513*^-6*lm^2*NM + 
        0.000017447237218474218*NL + 4.311974191757636*^-6*lm*NL + 
        3.6612647741409513*^-6*lm^2*NL - 1.7718240035571675*^-7*NH + 
        4.311974191757636*^-6*lm*NH + 3.6612647741409513*^-6*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.000052172510034041444 - 0.00004485437142948174*lm - 
          0.000018377427024482134*lm^2) + CF*(0.00006141611856314132 + 
          0.00002514059536747589*lm + 0.000060144306625577887*lm^2) + 
        2.247497579573786*^-6*NM + 3.902712518703295*^-6*lm*NM + 
        3.3413503680876606*^-6*lm^2*NM + 0.00001590131889634286*NL + 
        3.902712518703295*^-6*lm*NL + 3.3413503680876606*^-6*lm^2*NL - 
        1.370043639379918*^-7*NH + 3.902712518703295*^-6*lm*NH + 
        3.3413503680876606*^-6*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.00004727008564012284 - 0.00004065272940799742*lm - 
          0.000016722690955660255*lm^2) + CF*(0.000055793072183188184 + 
          0.00002234384619903401*lm + 0.00005472880676397901*lm^2) + 
        1.9790856882637974*^-6*NM + 3.521691737334348*^-6*lm*NM + 
        3.0404892646655006*^-6*lm^2*NM + 0.0000144502625991261*NL + 
        3.521691737334348*^-6*lm*NL + 3.0404892646655006*^-6*lm^2*NL - 
        1.0208024946073869*^-7*NH + 3.521691737334348*^-6*lm*NH + 
        3.0404892646655006*^-6*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.00004269287684509323 - 0.000036727413796360765*lm - 
          0.000015168866308514741*lm^2) + CF*(0.00005052603075151073 + 
          0.000019783421076351704*lm + 0.000049643562464230064*lm^2) + 
        1.7357759206202175*^-6*NM + 3.167560718029125*^-6*lm*NM + 
        2.757975692457226*^-6*lm^2*NM + 0.000013090294177223448*NL + 
        3.167560718029125*^-6*lm*NL + 2.757975692457226*^-6*lm^2*NL - 
        7.200206435203768*^-8*NH + 3.167560718029125*^-6*lm*NH + 
        2.757975692457226*^-6*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.00003842646789253825 - 0.000033066498476869995*
           lm - 0.000013712198754411069*lm^2) + 
        CF*(0.00004560042450966295 + 0.000017445142103778956*lm + 
          0.00004487628683261804*lm^2) + 1.5158159869886847*^-6*NM + 
        2.8390198460134717*^-6*lm*NM + 2.4931270462565578*^-6*lm^2*NM + 
        0.000011817774494244058*NL + 2.8390198460134717*^-6*lm*NL + 
        2.4931270462565578*^-6*lm^2*NL - 4.637878384709582*^-8*NH + 
        2.8390198460134717*^-6*lm*NH + 2.4931270462565578*^-6*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.000034456992406952924 - 0.000029658487988480936*
           lm - 0.000012349057295871865*lm^2) + 
        CF*(0.00004100222115931312 + 0.000015315424375579228*lm + 
          0.00004041509660467156*lm^2) + 1.317544652238886*^-6*NM + 
        2.5348192682823833*^-6*lm*NM + 2.2452831447039756*^-6*lm^2*NM + 
        0.000010629194761733726*NL + 2.5348192682823833*^-6*lm*NL + 
        2.2452831447039756*^-6*lm^2*NL - 2.483578826151025*^-8*NH + 
        2.5348192682823833*^-6*lm*NH + 2.2452831447039756*^-6*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.0000307711140572012 - 0.00002649230316044457*lm - 
          0.000011075930315660913*lm^2) + CF*(0.00003671790780574509 + 
          0.000013381255113154197*lm + 0.00003624849921489026*lm^2) + 
        1.1393876825376597*^-6*NM + 2.2537571957956606*^-6*lm*NM + 
        2.0138055119383476*^-6*lm^2*NM + 9.52117203202082*^-6*NL + 
        2.2537571957956606*^-6*lm*NL + 2.0138055119383476*^-6*lm^2*NL - 
        7.014316753592514*^-9*NH + 2.2537571957956606*^-6*lm*NH + 
        2.0138055119383476*^-6*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.00002735600785892594 - 0.00002355726720378803*lm - 
          9.889421753596576*^-6*lm^2) + CF*(0.000032734473438658207 + 
          0.000011630173455117373*lm + 0.00003236538028449789*lm^2) + 
        9.798539581184993*^-7*NM + 1.9946782593605995*^-6*lm*NM + 
        1.7980766824721047*^-6*lm^2*NM + 8.490444843978426*^-6*NL + 
        1.9946782593605995*^-6*lm*NL + 1.7980766824721047*^-6*lm^2*NL + 
        7.429062851923823*^-9*NH + 1.9946782593605995*^-6*lm*NH + 
        1.7980766824721047*^-6*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.00002419934209661719 - 0.000020843092246753063*
           lm - 8.786247406883317*^-6*lm^2) + CF*(0.000029039391937633025 + 
          0.000010050250882650211*lm + 0.000028754991513436313*lm^2) + 
        8.37531745615462*^-7*NM + 1.7564719176515247*^-6*lm*NM + 
        1.5974995285242396*^-6*lm^2*NM + 7.533869016659213*^-6*NL + 
        1.7564719176515247*^-6*lm*NL + 1.5974995285242396*^-6*lm^2*NL + 
        1.8822968597790256*^-8*NH + 1.7564719176515247*^-6*lm*NH + 
        1.5974995285242396*^-6*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.000021289260846514465 - 0.00001833986630068699*lm - 
          7.763231349891227*^-6*lm^2) + CF*(0.00002562060558972258 + 
          8.630072262885751*^-6*lm + 0.000025406938963280375*lm^2) + 
        7.110851237647276*^-7*NM + 1.5380709158525575*^-6*lm*NM + 
        1.411496609071132*^-6*lm^2*NM + 6.648413585914821*^-6*NL + 
        1.5380709158525575*^-6*lm*NL + 1.411496609071132*^-6*lm^2*NL + 
        2.748170369611675*^-8*NH + 1.5380709158525575*^-6*lm*NH + 
        1.411496609071132*^-6*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.000018614367081984528 - 0.0000160380406432546*lm - 
          6.8173024694501035*^-6*lm^2) + CF*(0.000022466509106737993 + 
          7.358717493382544*^-6*lm + 0.00002231117171820034*lm^2) + 
        5.992505565045259*^-7*NM + 1.3384497934462666*^-6*lm*NM + 
        1.2395095399000188*^-6*lm^2*NM + 5.831156879263027*^-6*NL + 
        1.3384497934462666*^-6*lm*NL + 1.2395095399000188*^-6*lm^2*NL + 
        3.370574099996058*^-8*NH + 1.3384497934462666*^-6*lm*NH + 
        1.2395095399000188*^-6*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.00001616370634347782 - 0.000013928417606205021*lm - 
          5.94549111185663*^-6*lm^2) + CF*(0.000019565934129919402 + 
          6.225743731074607*^-6*lm + 0.00001945797091153079*lm^2) + 
        5.008336077240327*^-7*NM + 1.1566234397068167*^-6*lm*NM + 
        1.0809983839739327*^-6*lm^2*NM + 5.079282724413439*^-6*NL + 
        1.1566234397068167*^-6*lm*NL + 1.0809983839739327*^-6*lm^2*NL + 
        3.7782193037831104*^-8*NH + 1.1566234397068167*^-6*lm*NH + 
        1.0809983839739327*^-6*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.000013926750955624216 - 0.00001200213875528553*
           lm - 5.1449258379206216*^-6*lm^2) + 
        CF*(0.000016908134209818685 + 5.221168189410351*^-6*lm + 
          0.000016837939105922033*lm^2) + 4.1470579212433493*^-7*NM + 
        9.916456954917708*^-7*lm*NM + 9.35441061440113*^-7*lm^2*NM + 
        4.3900767870061625*^-6*NL + 9.916456954917708*^-7*lm*NL + 
        9.35441061440113*^-7*lm^2*NL + 3.9985267995826096*^-8*NH + 
        9.916456954917708*^-7*lm*NH + 9.35441061440113*^-7*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.000011893384774481731 - 0.000010250673450244237*
           lm - 4.4128302824995934*^-6*lm^2) + 
        CF*(0.000014482770249366992 + 4.335451487723496*^-6*lm + 
          0.000014441990015453216*lm^2) + 3.398015568598701*^-7*NM + 
        8.42607999961856*^-7*lm*NM + 8.023327786362898*^-7*lm^2*NM + 
        3.760923033257749*^-6*NL + 8.42607999961856*^-7*lm*NL + 
        8.023327786362898*^-7*lm^2*NL + 4.057671202370177*^-8*NH + 
        8.42607999961856*^-7*lm*NH + 8.023327786362898*^-7*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.000010053888448398765 - 8.665807773206032*^-6*lm - 
          3.7465201150899065*^-6*lm^2) + CF*(0.000012279896398256658 + 
          3.5594815372113527*^-6*lm + 0.000012261338558476057*lm^2) + 
        2.751153888270601*^-7*NM + 7.086380808926886*^-7*lm*NM + 
        6.811854754708921*^-7*lm^2*NM + 3.1893003133448486*^-6*NL + 
        7.086380808926886*^-7*lm*NL + 6.811854754708921*^-7*lm^2*NL + 
        3.980623823284532*^-8*NH + 7.086380808926886*^-7*lm*NH + 
        6.811854754708921*^-7*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-8.398925176392025*^-6 - 7.239633814040568*^-6*lm - 
          3.143400098157709*^-6*lm^2) + CF*(0.000010289946386932616 + 
          2.8845579482292556*^-6*lm + 0.00001028749123033432*lm^2) + 
        2.1969904265836147*^-7*NM + 5.888986872766665*^-7*lm*NM + 
        5.715272905741289*^-7*lm^2*NM + 2.6727790614883617*^-6*NL + 
        5.888986872766665*^-7*lm*NL + 5.715272905741289*^-7*lm^2*NL + 
        3.791194274587124*^-8*NH + 5.888986872766665*^-7*lm*NH + 
        5.715272905741289*^-7*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-6.919526948376946*^-6 - 5.964539301667852*^-6*lm - 
          2.6009612400040655*^-6*lm^2) + CF*(8.503720288661767*^-6 + 
          2.302376943943907*^-6*lm + 8.512236785467851*^-6*lm^2) + 
        1.7265888466485534*^-7*NM + 4.825863629469331*^-7*lm*NM + 
        4.729020436371028*^-7*lm^2*NM + 2.2090181088296328*^-6*NL + 
        4.825863629469331*^-7*lm*NL + 4.729020436371028*^-7*lm^2*NL + 
        3.512070814940812*^-8*NH + 4.825863629469331*^-7*lm*NH + 
        4.729020436371028*^-7*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-5.607081252015725*^-6 - 4.833197570566106*^-6*lm - 
          2.1167780390659384*^-6*lm^2) + CF*(6.912371698328927*^-6 + 
          1.805016765721997*^-6*lm + 6.927637218761253*^-6*lm^2) + 
        1.3315334814897384*^-7*NM + 3.8893025998849646*^-7*lm*NM + 
        3.848687343756251*^-7*lm^2*NM + 1.7957616053153304*^-6*NL + 
        3.8893025998849646*^-7*lm*NL + 3.848687343756251*^-7*lm^2*NL + 
        3.164859469358614*^-8*NH + 3.8893025998849646*^-7*lm*NH + 
        3.848687343756251*^-7*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-4.453318231369044*^-6 - 3.8385578520579345*^-6*lm - 
          1.688505816658428*^-6*lm^2) + CF*(5.5073953167940124*^-6 + 
          1.3849235559631509*^-6*lm + 5.526019036336674*^-6*lm^2) + 
        1.003904956812031*^-7*NM + 3.071909907342031*^-7*lm*NM + 
        3.0700105757425965*^-7*lm^2*NM + 1.4308360469292523*^-6*NL + 
        3.071909907342031*^-7*lm*NL + 3.0700105757425965*^-7*lm^2*NL + 
        2.7701219573781754*^-8*NH + 3.071909907342031*^-7*lm*NH + 
        3.0700105757425965*^-7*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-3.4502982829512952*^-6 - 2.9738358802546778*^-6*lm - 
          1.313878135263851*^-6*lm^2) + CF*(4.280614929836224*^-6 + 
          1.0348977044174182*^-6*lm + 4.299964806318058*^-6*lm^2) + 
        7.362568410079787*^-8*NM + 2.366595171753312*^-7*lm*NM + 
        2.3888693368433654*^-7*lm^2*NM + 1.1121474047273859*^-6*NL + 
        2.366595171753312*^-7*lm*NL + 2.3888693368433654*^-7*lm^2*NL + 
        2.3474124622330385*^-8*NH + 2.366595171753312*^-7*lm*NH + 
        2.3888693368433654*^-7*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-2.590400075195235*^-6 - 2.2325048028351686*^-6*lm - 
          9.907042995700112*^-7*lm^2) + CF*(3.2241717709063476*^-6 + 
          7.480806443565936*^-7*lm + 3.2423049804109454*^-6*lm^2) + 
        5.215932816087192*^-8*NM + 1.7665607664804458*^-7*lm*NM + 
        1.8012805446727475*^-7*lm^2*NM + 8.376783522472354*^-7*NL + 
        1.7665607664804458*^-7*lm*NL + 1.8012805446727475*^-7*lm^2*NL + 
        1.9153132730182593*^-8*NH + 1.7665607664804458*^-7*lm*NH + 
        1.8012805446727475*^-7*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-1.8663089777303053*^-6 - 1.6082863871239948*^-6*lm - 
          7.168669375535344*^-7*lm^2) + CF*(2.330513257107137*^-6 + 
          5.179420852952138*^-7*lm + 2.346109977447931*^-6*lm^2) + 
        3.533475889287165*^-8*NM + 1.2652914268784234*^-7*lm*NM + 
        1.3033944319155172*^-7*lm^2*NM + 6.054855879737693*^-7*NL + 
        1.2652914268784234*^-7*lm*NL + 1.3033944319155172*^-7*lm^2*NL + 
        1.4914693310859463*^-8*NH + 1.2652914268784234*^-7*lm*NH + 
        1.3033944319155172*^-7*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-1.2710058872693061*^-6 - 1.0951425122159673*^-6*lm - 
          4.903196589944646*^-7*lm^2) + CF*(1.5923820880234372*^-6 + 
          3.3826766928063577*^-7*lm + 1.6046825203455206*^-6*lm^2) + 
        2.2536172914573018*^-8*NM + 8.565441997443201*^-8*lm*NM + 
        8.914902890808447*^-8*lm^2*NM + 4.13697249652386*^-7*NL + 
        8.565441997443201*^-8*lm*NL + 8.914902890808447*^-8*lm^2*NL + 
        1.0926217111559721*^-8*NH + 8.565441997443201*^-8*lm*NH + 
        8.914902890808447*^-8*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-7.97756437280449*^-7 - 6.872669381678439*^-7*lm - 
          3.090847888955752*^-7*lm^2) + CF*(1.0028056972276064*^-6 + 
          2.031470380918219*^-7*lm + 1.0115502182037006*^-6*lm^2) + 
        1.3186669049537125*^-8*NM + 5.34338723191443*^-8*lm*NM + 
        5.6197234344650035*^-8*lm^2*NM + 2.6051041734415253*^-7*NL + 
        5.34338723191443*^-8*lm*NL + 5.6197234344650035*^-8*lm^2*NL + 
        7.34640066888854*^-9*NH + 5.34338723191443*^-8*lm*NH + 
        5.6197234344650035*^-8*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-4.401005789960687*^-7 - 3.790773435455998*^-7*lm - 
          1.7125117336416746*^-7*lm^2) + CF*(5.550860464913497*^-7 + 
          1.0696229900297*^-7*lm + 5.604583855554572*^-7*lm^2) + 
        6.7463687645863695*^-9*NM + 2.9294782676086828*^-8*lm*NM + 
        3.1136576975303176*^-8*lm^2*NM + 1.4418870222026774*^-7*NL + 
        2.9294782676086828*^-8*lm*NL + 3.1136576975303176*^-8*lm^2*NL + 
        4.325540699416917*^-9*NH + 2.9294782676086828*^-8*lm*NH + 
        3.1136576975303176*^-8*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-1.9184252167531363*^-7 - 1.652076228757612*^-7*lm - 
          7.497205559555982*^-8*lm^2) + CF*(2.4278975294171505*^-7 + 
          4.437687708064476*^-8*lm + 2.4536309104001395*^-7*lm^2) + 
        2.7106170654867072*^-9*NM + 1.2688844186703069*^-8*lm*NM + 
        1.363128283555633*^-8*lm^2*NM + 6.30599181913475*^-8*NL + 
        1.2688844186703069*^-8*lm*NL + 1.363128283555633*^-8*lm^2*NL + 
        2.0058387081433935*^-9*NH + 1.2688844186703069*^-8*lm*NH + 
        1.363128283555633*^-8*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-4.7041020395950426*^-8 - 4.050043580265602*^-8*lm - 
          1.8463019676157306*^-8*lm^2) + CF*(5.973853960627835*^-8 + 
          1.0324742291320517*^-8*lm + 6.042442803106028*^-8*lm^2) + 
        6.082606198038183*^-10*NM + 3.091281295256429*^-9*lm*NM + 
        3.3569126683922374*^-9*lm^2*NM + 1.5513833562764987*^-8*NL + 
        3.091281295256429*^-9*lm*NL + 3.3569126683922374*^-9*lm^2*NL + 
        5.21696090917717*^-10*NH + 3.091281295256429*^-9*lm*NH + 
        3.3569126683922374*^-9*lm^2*NH)}, {1., 0.}}
 
CbarLTable["v", 2, 3] = {{0., -9.720394788002078*^-11*CF*NC*
       (CF*(-6.680692866407926*^8 - 7.327430668528489*^8*lm - 
          1.1573604*^9*lm^2) + 35.*CA*(7.177114445052359*^6 + 
          1.9947862188032452*^7*lm + 6.73596*^6*lm^2) + 
        70.*(9.*(-252382.29040926497 - 114897.19381850964*lm - 68040.*lm^2)*
           NM + 9.*(-252382.29040926497 - 114897.19381850964*lm - 
            68040.*lm^2)*NL + (496876.36851328495 - 1.0340747443665867*^6*
             lm - 612360.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.02763105350647356 - 0.0666059485990369*lm - 
          0.022223078802041305*lm^2) + CF*(0.06196790278993544 + 
          0.07297037590582472*lm + 0.10909511411911187*lm^2) + 
        0.015568925279376528*NM + 0.006967641840674836*lm*NM + 
        0.004040559782189328*lm^2*NM + 0.015570875805004313*NL + 
        0.006967641840674836*lm*NL + 0.004040559782189328*lm^2*NL - 
        0.0032911082617025525*NH + 0.006967641840674836*lm*NH + 
        0.004040559782189328*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.030553154564743886 - 0.06528840312882316*lm - 
          0.02152364571787521*lm^2) + CF*(0.059328163490659155 + 
          0.07449677215454162*lm + 0.10566153352411468*lm^2) + 
        0.015624772737728379*NM + 0.006889940402757053*lm*NM + 
        0.0039133901305227654*lm^2*NM + 0.015634330506567342*NL + 
        0.006889940402757053*lm*NL + 0.0039133901305227654*lm^2*NL - 
        0.003200520105603923*NH + 0.006889940402757053*lm*NH + 
        0.0039133901305227654*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.03311781877997333 - 0.06391523290811515*lm - 
          0.02082485062243273*lm^2) + CF*(0.057011923544323655 + 
          0.07574280939335484*lm + 0.10223108487376067*lm^2) + 
        0.015617004583194531*NM + 0.00680197774008609*lm*NM + 
        0.003786336476805951*lm^2*NM + 0.01564058937827277*NL + 
        0.00680197774008609*lm*NL + 0.003786336476805951*lm^2*NL - 
        0.0031097611312675363*NH + 0.00680197774008609*lm*NH + 
        0.003786336476805951*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.03531760719956902 - 0.06249374837495777*lm - 
          0.020131148973314965*lm^2) + CF*(0.054976294573516035 + 
          0.07669345045149023*lm + 0.09882564041445527*lm^2) + 
        0.015548293425636841*NM + 0.006704052008233486*lm*NM + 
        0.003660208904239084*lm^2*NM + 0.015592072908683098*NL + 
        0.006704052008233486*lm*NL + 0.003660208904239084*lm^2*NL - 
        0.0030192920673363676*NH + 0.006704052008233486*lm*NH + 
        0.003660208904239084*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.03716543414360251 - 0.06103236725169298*lm - 
          0.019445820128553247*lm^2) + CF*(0.05317613592707313 + 
          0.07735253644393796*lm + 0.09546129881289775*lm^2) + 
        0.015423940821348354*NM + 0.006596934842460783*lm*NM + 
        0.003535603659736954*lm^2*NM + 0.015493428176293206*NL + 
        0.006596934842460783*lm*NL + 0.003535603659736954*lm^2*NL - 
        0.0029294670943403496*NH + 0.006596934842460783*lm*NH + 
        0.003535603659736954*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.03868295381047197 - 0.05953953045085664*lm - 
          0.01877133814327946*lm^2) + CF*(0.05157033890942097 + 
          0.07773322674093677*lm + 0.09215020543064462*lm^2) + 
        0.015250099312698549*NM + 0.006481588445512571*lm*NM + 
        0.003412970571505356*lm^2*NM + 0.015349991233079632*NL + 
        0.006481588445512571*lm*NL + 0.003412970571505356*lm^2*NL - 
        0.002840566151172768*NH + 0.006481588445512571*lm*NH + 
        0.003412970571505356*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.039895497346365945 - 0.05802327297861429*lm - 
          0.01810958488659606*lm^2) + CF*(0.05012321758007686 + 
          0.07785345662094659*lm + 0.08890159853419884*lm^2) + 
        0.015033037702209682*NM + 0.006359038253758882*lm*NM + 
        0.00329265179756292*lm^2*NM + 0.015167170397525773*NL + 
        0.006359038253758882*lm*NL + 0.00329265179756292*lm^2*NL - 
        0.002752813505766814*NH + 0.006359038253758882*lm*NH + 
        0.00329265179756292*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.04082953595742606 - 0.056491043997475426*lm - 
          0.0174619887944981*lm^2) + CF*(0.048804484577486804 + 
          0.07773346803065725*lm + 0.08572249044571796*lm^2) + 
        0.014778801242247326*NM + 0.006230308113210847*lm*NM + 
        0.0031749070535451096*lm^2*NM + 0.014950168732467298*NL + 
        0.006230308113210847*lm*NL + 0.0031749070535451096*lm^2*NL - 
        0.002666389864593691*NH + 0.006230308113210847*lm*NH + 
        0.0031749070535451096*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.04151132268897271 - 0.05494963964630594*lm - 
          0.016829622122505137*lm^2) + CF*(0.04758877678812558 + 
          0.07739436821885227*lm + 0.08261814496502522*lm^2) + 
        0.014493051593187561*NM + 0.006096385560236255*lm*NM + 
        0.003059931295000934*lm^2*NM + 0.014703857153848112*NL + 
        0.006096385560236255*lm*NL + 0.003059931295000934*lm^2*NL - 
        0.0025814408901894065*NH + 0.006096385560236255*lm*NH + 
        0.003059931295000934*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.041966148675771475 - 0.05340519172834466*lm - 
          0.016213272513446064*lm^2) + CF*(0.04645505943033888 + 
          0.07685725620281673*lm + 0.07959242870237158*lm^2) + 
        0.014180997356393138*NM + 0.0059582032036949815*lm*NM + 
        0.002947867729717466*lm^2*NM + 0.014432721709552124*NL + 
        0.0059582032036949815*lm*NL + 0.002947867729717466*lm^2*NL - 
        0.002498083505128983*NH + 0.0059582032036949815*lm*NH + 
        0.002947867729717466*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.04221794319624398 - 0.05186318526759619*lm - 
          0.01561349750171723*lm^2) + CF*(0.045386030932090975 + 
          0.07614268598410913*lm + 0.07664807864479369*lm^2) + 
        0.013847372934536533*NM + 0.005816629304454824*lm*NM + 
        0.002838817727584951*lm^2*NM + 0.014140849567423936*NL + 
        0.005816629304454824*lm*NL + 0.002838817727584951*lm^2*NL - 
        0.002416410731526404*NH + 0.005816629304454824*lm*NH + 
        0.002838817727584951*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.04228907512046068 - 0.0503284909839342*lm - 
          0.015030667081685276*lm^2) + CF*(0.044367574119260095 + 
          0.07527033942550561*lm + 0.07378691112827317*lm^2) + 
        0.01349644386241583*NM + 0.005672463829416237*lm*NM + 
        0.0027328485603064136*lm^2*NM + 0.013831935733510171*NL + 
        0.005672463829416237*lm*NL + 0.0027328485603064136*lm^2*NL - 
        0.002336495509705139*NH + 0.005672463829416237*lm*NH + 
        0.0027328485603064136*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.04220027568684095 - 0.04880540505526519*lm - 
          0.014464997594421415*lm^2) + CF*(0.043388268164951914 + 
          0.07425883413010499*lm + 0.07100998819079604*lm^2) + 
        0.01313202659192353*NM + 0.005526437839438302*lm*NM + 
        0.0026299995626220757*lm^2*NM + 0.013509300806463318*NL + 
        0.005526437839438302*lm*NL + 0.0026299995626220757*lm^2*NL - 
        0.0022583937761612416*NH + 0.005526437839438302*lm*NH + 
        0.0026299995626220757*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.04197063533229115 - 0.04729769183376817*lm - 
          0.013916579104502249*lm^2) + CF*(0.04243896274761386 + 
          0.07312562022918745*lm + 0.06831775196755649*lm^2) + 
        0.012757515843261886*NM + 0.005379214920800303*lm*NM + 
        0.0025302871099095*lm^2*NM + 0.013175914315516622*NL + 
        0.005379214920800303*lm*NL + 0.0025302871099095*lm^2*NL - 
        0.0021821469867096066*NH + 0.005379214920800303*lm*NH + 
        0.0025302871099095*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.04161764562171796 - 0.045808627006130864*lm - 
          0.013385397775545831*lm^2) + CF*(0.04151241052030678 + 
          0.07188693651290783*lm + 0.06571013453449771*lm^2) + 
        0.01237591546647097*NM + 0.005231393854707402*lm*NM + 
        0.0024337086864628784*lm^2*NM + 0.012834420491140966*NL + 
        0.005231393854707402*lm*NL + 0.0024337086864628784*lm^2*NL - 
        0.0021077842131875767*NH + 0.005231393854707402*lm*NH + 
        0.0024337086864628784*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.04115726805919054 - 0.04434103973952471*lm - 
          0.012871354327348566*lm^2) + CF*(0.04060295204077163 + 
          0.07055780636821993*lm + 0.06318664851607478*lm^2) + 
        0.011989870391918558*NM + 0.00508351200912218*lm*NM + 
        0.002340246241336103*lm^2*NM + 0.012487164623560271*NL + 
        0.00508351200912218*lm*NL + 0.002340246241336103*lm^2*NL - 
        0.0020353239053187*NH + 0.00508351200912218*lm*NH + 
        0.002340246241336103*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.04060401809871511 - 0.042897352982012235*lm - 
          0.012374279373179703*lm^2) + CF*(0.03970624688831103 + 
          0.06915206031576646*lm + 0.060746462377427625*lm^2) + 
        0.011601698224284723*NM + 0.004936049116985434*lm*NM + 
        0.002249868976941764*lm^2*NM + 0.012136218931132054*NL + 
        0.004936049116985434*lm*NL + 0.002249868976941764*lm^2*NL - 
        0.0019647753849149656*NH + 0.004936049116985434*lm*NH + 
        0.002249868976941764*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.03997105677496375 - 0.04147962146865596*lm - 
          0.011893946239639824*lm^2) + CF*(0.03881904494675745 + 
          0.0676823760575187*lm + 0.05838846335823187*lm^2) + 
        0.011213419632102631*NM + 0.004789431219838975*lm*NM + 
        0.002162535679934514*lm^2*NM + 0.011783407322435782*NL + 
        0.004789431219838975*lm*NL + 0.002162535679934514*lm^2*NL - 
        0.0018961401228433374*NH + 0.004789431219838975*lm*NH + 
        0.002162535679934514*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.03927028501357347 - 0.04008956722161385*lm - 
          0.01143008173233708*lm^2) + CF*(0.037938992361972707 + 
          0.06616032970096238*lm + 0.05611131032238203*lm^2) + 
        0.010826787057351966*NM + 0.004644034631157575*lm*NM + 
        0.002078196678606742*lm^2*NM + 0.01143032871904001*NL + 
        0.004644034631157575*lm*NL + 0.002078196678606742*lm^2*NL - 
        0.0018294128373730336*NH + 0.004644034631157575*lm*NH + 
        0.002078196678606742*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.03851243741222981 - 0.03872861248032086*lm - 
          0.01098237520952194*lm^2) + CF*(0.037064467296880364 + 
          0.0645964537069566*lm + 0.05391347830128952*lm^2) + 
        0.010443311504240287*NM + 0.0045001898239706165*lm*NM + 
        0.001996795492640353*lm^2*NM + 0.011078378781278328*NL + 
        0.0045001898239706165*lm*NL + 0.001996795492640353*lm^2*NL - 
        0.0017645824439958845*NH + 0.0045001898239706165*lm*NH + 
        0.001996795492640353*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.037707173437208974 - 0.03739791008974262*lm - 
          0.010550486250804162*lm^2) + CF*(0.036194441217720204 + 
          0.06300029841690052*lm + 0.05179329614031134*lm^2) + 
        0.01006428731462149*NM + 0.00435818518142001*lm*NM + 
        0.0019182702274189386*lm^2*NM + 0.010728769988204039*NL + 
        0.00435818518142001*lm*NL + 0.0019182702274189386*lm^2*NL - 
        0.0017016328805308063*NH + 0.00435818518142001*lm*NH + 
        0.0019182702274189386*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.0368631647569731 - 0.036098371430875964*lm - 
          0.0101340511513974*lm^2) + CF*(0.03532836201254011 + 
          0.061380494938493534*lm + 0.04974897837958723*lm^2) + 
        0.00969081493073671*NM + 0.004218270572232594*lm*NM + 
        0.001842554754799527*lm^2*NM + 0.010382550089914582*NL + 
        0.004218270572232594*lm*NL + 0.001842554754799527*lm^2*NL - 
        0.0016405438266096696*NH + 0.004218270572232594*lm*NH + 
        0.001842554754799527*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.03598817796144878 - 0.034830692010771734*lm - 
          0.009732688428823895*lm^2) + CF*(0.03446605575202219 + 
          0.059744817829214564*lm + 0.04777865228695367*lm^2) + 
        0.009323821703567107*NM + 0.004080660729172802*lm*NM + 
        0.0017695797143316174*lm^2*NM + 0.01004061899080175*NL + 
        0.004080660729172802*lm*NL + 0.0017695797143316174*lm^2*NL - 
        0.0015812913330465878*NH + 0.004080660729172802*lm*NH + 
        0.0017695797143316174*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.035089152274190606 - 0.03359537484739944*lm - 
          0.009346003495130043*lm^2) + CF*(0.033607644350745806 + 
          0.058100246492482785*lm + 0.045880380794274755*lm^2) + 
        0.00896408083941723*NM + 0.003945538419662367*lm*NM + 
        0.0016992733627509168*lm^2*NM + 0.009703744145499361*NL + 
        0.003945538419662367*lm*NL + 0.0016992733627509168*lm^2*NL - 
        0.001523848373810345*NH + 0.003945538419662367*lm*NH + 
        0.0016992733627509168*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.03417227210815152 - 0.03239275179286457*lm - 
          0.008973592620948297*lm^2) + CF*(0.0327534767767536 + 
          0.0564530245470253*lm + 0.044052181957382544*lm^2) + 
        0.008612228596394966*NM + 0.0038130574054253573*lm*NM + 
        0.001631562294717872*lm^2*NM + 0.009372574561432659*NL + 
        0.0038130574054253573*lm*NL + 0.001631562294717872*lm^2*NL - 
        0.0014681853311380973*NH + 0.0038130574054253573*lm*NH + 
        0.001631562294717872*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.033243034479904586 - 0.03122300294025417*lm - 
          0.008615046296439333*lm^2) + CF*(0.03190407179405368 + 
          0.054808716682110584*lm + 0.04229204545524763*lm^2) + 
        0.008268779851464358*NM + 0.003683345193266863*lm*NM + 
        0.0015663720538980604*lm^2*NM + 0.009047653506851678*NL + 
        0.003683345193266863*lm*NL + 0.0015663720538980604*lm^2*NL - 
        0.0014142704225974636*NH + 0.003683345193266863*lm*NH + 
        0.0015663720538980604*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.03230631140605666 - 0.030086174257002773*lm - 
          0.008269952076992836*lm^2) + CF*(0.03106007051246743 + 
          0.053172262695690524*lm + 0.04059794655978302*lm^2) + 
        0.00793414216120432*NM + 0.003556505582630261*lm*NM + 
        0.001503627650362334*lm^2*NM + 0.008729430023627367*NL + 
        0.003556505582630261*lm*NL + 0.001503627650362334*lm^2*NL - 
        0.0013620700775156232*NH + 0.003556505582630261*lm*NH + 
        0.001503627650362334*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.03136640747586665 - 0.028982193582671862*lm - 
          0.007937896987624609*lm^2) + CF*(0.030222197267971027 + 
          0.051548028547291354*lm + 0.03896785793924808*lm^2) + 
        0.007608628437644291*NM + 0.003432621017894975*lm*NM + 
        0.0014432539977499287*lm^2*NM + 0.008418269341605408*NL + 
        0.003432621017894975*lm*NL + 0.0014432539977499287*lm^2*NL - 
        0.0013115492690692135*NH + 0.003432621017894975*lm*NH + 
        0.0014432539977499287*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.0304271128372651 - 0.027910885122455424*lm - 
          0.007618469548587795*lm^2) + CF*(0.0293912275699051 + 
          0.04993985435571571*lm + 0.037399759602158265*lm^2) + 
        0.007292468356143798*NM + 0.003311754754822819*lm*NM + 
        0.0013851762815614173*lm^2*NM + 0.008114462287078331*NL + 
        0.003311754754822819*lm*NL + 0.0013851762815614173*lm^2*NL - 
        0.0012626718074092139*NH + 0.003311754754822819*lm*NH + 
        0.0013851762815614173*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.029491751857661955 - 0.026871982560263352*lm - 
          0.007311261475293248*lm^2) + CF*(0.02856796203409373 + 
          0.04835109934269313*lm + 0.035891647242348675*lm^2) + 
        0.00698581860631116*NM + 0.003193952851384982*lm*NM + 
        0.001329320268235136*lm^2*NM + 0.007818233772704982*NL + 
        0.003193952851384982*lm*NL + 0.001329320268235136*lm^2*NL - 
        0.0012154005984368699*NH + 0.003193952851384982*lm*NH + 
        0.001329320268235136*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.02856322773185117 - 0.025865140907367464*lm - 
          0.007015869097807864*lm^2) + CF*(0.027753205377371467 + 
          0.04678468377444625*lm + 0.03444153920742042*lm^2) + 
        0.006688772090161911*NM + 0.003079245993582347*lm*NM + 
        0.0012756125632377934*lm^2*NM + 0.007529750450478005*NL + 
        0.003079245993582347*lm*NL + 0.0012756125632377934*lm^2*NL - 
        0.001169697872216799*NH + 0.003079245993582347*lm*NH + 
        0.0012756125632377934*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.027644063311050203 - 0.024889947194640185*lm - 
          0.006731894538661444*lm^2) + CF*(0.02694774968304216 + 
          0.04524312798882225*lm + 0.03304748228070164*lm^2) + 
        0.006401366164645678*NM + 0.0029676511669385424*lm*NM + 
        0.0012239808252111717*lm^2*NM + 0.0072491276034456695*NL + 
        0.0029676511669385424*lm*NL + 0.0012239808252111717*lm^2*NL - 
        0.0011255253844862786*NH + 0.0029676511669385424*lm*NH + 
        0.0012239808252111717*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.026736438422569297 - 0.023945930108585152*lm - 
          0.006458946682200676*lm^2) + CF*(0.0261523612616416 + 
          0.04372858861996732*lm + 0.03170755643989423*lm^2) + 
        0.00612359001878181*NM + 0.0028591731841921854*lm*NM + 
        0.0011743539422183046*lm^2*NM + 0.006976435346049562*NL + 
        0.0028591731841921854*lm*NL + 0.0011743539422183046*lm^2*NL - 
        0.0010828445942756455*NH + 0.0028591731841921854*lm*NH + 
        0.0011743539422183046*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.025842223940883865 - 0.023032568663788805*lm - 
          0.006196641964093598*lm^2) + CF*(0.025367770529841068 + 
          0.0422428921483397*lm + 0.030419878732823116*lm^2) + 
        0.005855391269448494*NM + 0.002753806079411016*lm*NM + 
        0.001126662175289745*lm^2*NM + 0.006711704197281049*NL + 
        0.002753806079411016*lm*NL + 0.001126662175289745*lm^2*NL - 
        0.001041616820278289*NH + 0.002753806079411016*lm*NH + 
        0.001126662175289745*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.024963012859483952 - 0.022149299997197794*lm - 
          0.005944605005658353*lm^2) + CF*(0.024594664414785965 + 
          0.040787565913305686*lm + 0.02918260639141373*lm^2) + 
        0.005596681855114272*NM + 0.0026515343783464268*lm*NM + 
        0.0010808372737560641*lm^2*NM + 0.006454930085470933*NL + 
        0.0026515343783464268*lm*NL + 0.0010808372737560641*lm^2*NL - 
        0.0010018033782877972*NH + 0.0026515343783464268*lm*NH + 
        0.0010808372737560641*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.02410014859984421 - 0.021295526362797978*lm - 
          0.005702469114345459*lm^2) + CF*(0.023833680863583694 + 
          0.03936386673026636*lm + 0.02799393928860498*lm^2) + 
        0.005347343304771775*NM + 0.0025523342543791955*lm*NM + 
        0.001036812566244629*lm^2*NM + 0.006206078838454966*NL + 
        0.0025523342543791955*lm*NL + 0.001036812566244629*lm^2*NL - 
        0.0009633657017447352*NH + 0.0025523342543791955*lm*NH + 
        0.001036812566244629*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.02325475077984969 - 0.020470621398860887*lm - 
          0.005469876668845746*lm^2) + CF*(0.02308540509953783 + 
          0.03797280725545206*lm + 0.02685212182887912*lm^2) + 
        0.005107231462337966*NM + 0.0024561745789029635*lm*NM + 
        0.0009945230306992268*lm^2*NM + 0.005965090208125582*NL + 
        0.0024561745789029635*lm*NL + 0.0009945230306992268*lm^2*NL - 
        0.0009262654471985881*NH + 0.0024561745789029635*lm*NH + 
        0.0009945230306992268*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.022427738649242707 - 0.019673935733940533*lm - 
          0.005246479404847439*lm^2) + CF*(0.022350367318887558 + 
          0.03661518024013776*lm + 0.025755444351069245*lm^2) + 
        0.004876180758879574*NM + 0.002363017874470772*lm*NM + 
        0.0009539053463358979*lm^2*NM + 0.00573188147399298*NL + 
        0.002363017874470772*lm*NL + 0.0009539053463358979*lm^2*NL - 
        0.0008904645862853471*NH + 0.002363017874470772*lm*NH + 
        0.0009539053463358979*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.021619852383697794 - 0.018904801992242065*lm - 
          0.005031938615360833*lm^2) + CF*(0.02162904156389463 + 
          0.035291580812791365*lm + 0.02470224411177136*lm^2) + 
        0.004654008153011246*NM + 0.002272821178505968*lm*NM + 
        0.0009148979300656059*lm^2*NM + 0.005506350666331696*NL + 
        0.002272821178505968*lm*NL + 0.0009148979300656059*lm^2*NL - 
        0.0008559254856430131*NH + 0.002272821178505968*lm*NH + 
        0.0009148979300656059*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.02083167189518836 - 0.018162539253832415*lm - 
          0.004825925277714578*lm^2) + CF^2*(0.02092184450708007 + 
          0.03400242692311731*lm + 0.023690905908780657*lm^2) + 
        CF*((0.0044405054682835916 + 0.0021855368248620247*lm + 
            0.0008774409595844687*lm^2)*NM + (0.005288379445769752 + 
            0.0021855368248620247*lm + 0.0008774409595844687*lm^2)*NL + 
          (-0.0008226109760317844 + 0.0021855368248620247*lm + 
            0.0008774409595844687*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.020063636089145995 - 0.01744645702040409*lm - 
          0.0046281201177595455*lm^2) + CF^2*(0.020229139487346143 + 
          0.03274797807651718*lm + 0.022719862396274132*lm^2) + 
        CF*((0.004235475128214648 + 0.002101113150013411*lm + 
            0.0008414763850471902*lm^2)*NM + (0.005077835672770325 + 
            0.002101113150013411*lm + 0.0008414763850471902*lm^2)*NL + 
          (-0.0007904844117895116 + 0.002101113150013411*lm + 
            0.0008414763850471902*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.019316056565373715 - 0.016755858732916608*lm - 
          0.004438213620458317*lm^2) + CF^2*(0.019551233325874145 + 
          0.03152835248147613*lm + 0.021787594136795378*lm^2) + 
        CF*((0.004038692353281482 + 0.0020194951301763017*lm + 
            0.0008069479309924213*lm^2)*NM + (0.004874575697341745 + 
            0.0020194951301763017*lm + 0.0008069479309924213*lm^2)*NL + 
          (-0.0007595097216333038 + 0.0020194951301763017*lm + 
            0.0008069479309924213*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.018589133306294504 - 0.016090044883403848*lm - 
          0.004255905994859758*lm^2) + CF^2*(0.018888380591673373 + 
          0.030343542726040014*lm + 0.020892629429311537*lm^2) + 
        CF*((0.0038499303243709256 + 0.001940624955196789*lm + 
            0.0007738010899745014*lm^2)*NM + (0.004678446396470795 + 
            0.001940624955196789*lm + 0.0007738010899745014*lm^2)*NL + 
          (-0.0007296514517126223 + 0.001940624955196789*lm + 
            0.0007738010899745014*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.017882967427264074 - 0.015448315759527329*lm - 
          0.004080907100433435*lm^2) + CF^2*(0.018240785092723366 + 
          0.02919343009305615*lm + 0.020033543947582316*lm^2) + 
        CF*((0.003668957134421955 + 0.0018644425446071495*lm + 
            0.0007419831091697154*lm^2)*NM + (0.004489286984186681 + 
            0.0018644425446071495*lm + 0.0007419831091697154*lm^2)*NL + 
          (-0.0007008748017260994 + 0.0018644425446071495*lm + 
            0.0007419831091697154*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.017197572966105083 - 0.014829973857052611*lm - 
          0.0039129363408462224*lm^2) + CF^2*(0.017608602212777737 + 
          0.028077797617346488*lm + 0.01920896021869964*lm^2) + 
        CF*((0.003495537507064966 + 0.001790886010838539*lm + 
            0.0007114429710629496*lm^2)*NM + (0.004306930616809048 + 
            0.001790886010838539*lm + 0.0007114429710629496*lm^2)*NL + 
          (-0.0006731456548303773 + 0.001790886010838539*lm + 
            0.0007114429710629496*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.01653288753572773 - 0.014234325992306937*lm - 
          0.0037517225304850316*lm^2) + CF^2*(0.016991941442524115 + 
          0.0269963419815663*lm + 0.01841754696783561*lm^2) + 
        CF*((0.0033294342965504487 + 0.0017198920741915021*lm + 
            0.0006821313691790967*lm^2)*NM + (0.004131205813793955 + 
            0.0017198920741915021*lm + 0.0006821313691790967*lm^2)*NL + 
          (-0.0006464306019997757 + 0.0017198920741915021*lm + 
            0.0006821313691790967*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.015888781940860342 - 0.01366068514381942*lm - 
          0.0035970037383497547*lm^2) + CF^2*(0.016390869039666637 + 
          0.02594868434124814*lm + 0.017658018351898796*lm^2) + 
        CF*((0.0031704097919833083 + 0.0016513964338035877*lm + 
            0.0006540006796999555*lm^2)*NM + (0.003961937712648965 + 
            0.0016513964338035877*lm + 0.0006540006796999555*lm^2)*NL + 
          (-0.0006206969614218095 + 0.0016513964338035877*lm + 
            0.0006540006796999555*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.015265068851305921 - 0.01310837204973071*lm - 
          0.003448527113346069*lm^2) + CF^2*(0.01580541076354934 + 
          0.024934380163491143*lm + 0.0169291331018807*lm^2) + 
        CF*((0.003018226846983165 + 0.001585334098515584*lm + 
            0.0006270049296992852*lm^2)*NM + (0.0037989491746253878 + 
            0.001585334098515584*lm + 0.0006270049296992852*lm^2)*NL + 
          (-0.0005959127934655354 + 0.001585334098515584*lm + 
            0.0006270049296992852*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.014661510616492672 - 0.012576716585167937*lm - 
          0.0033060486944873507*lm^2) + CF^2*(0.015235554639956857 + 
          0.023952928157964865*lm + 0.016229693591119723*lm^2) + 
        CF*((0.0028726498533272497 + 0.0015216396812235437*lm + 
            0.0006010997626340638*lm^2)*NM + (0.003642061756296567 + 
            0.0015216396812235437*lm + 0.0006010997626340638*lm^2)*NL + 
          (-0.0005720469116989625 + 0.0015216396812235437*lm + 
            0.0006010997626340638*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.014077826298710324 - 0.012065058941595068*lm - 
          0.0031693332090590685*lm^2) + CF^2*(0.0146812537196408 + 
          0.023003778373378334*lm + 0.015558544844471792*lm^2) + 
        CF*((0.002733445575656676 + 0.0014602476600118809*lm + 
            0.0005762424016471034*lm^2)*NM + (0.0034910965606812956 + 
            0.0014602476600118809*lm + 0.0005762424016471034*lm^2)*NL + 
          (-0.0005490688903889253 + 0.0014602476600118809*lm + 
            0.0005762424016471034*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.013513697995821623 - 0.011572750628151812*lm - 
          0.0030381538613992658*lm^2) + CF^2*(0.014142428801203097 + 
          0.022086339527330513*lm + 0.014914573501414577*lm^2) + 
        CF*((0.002600383862434499 + 0.001401092609092235*lm + 
            0.0005523916111635029*lm^2)*NM + (0.0033458749802575015 + 
            0.001401092609092235*lm + 0.0005523916111635029*lm^2)*NL + 
          (-0.0005269490688734992 + 0.001401092609092235*lm + 
            0.0005523916111635029*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.012968776518059956 - 0.011099155313170564*lm - 
          0.0029122921145980185*lm^2) + CF^2*(0.01361897109476877 + 
          0.02119998563251451*lm + 0.014296706744390273*lm^2) + 
        CF*((0.002473238246866154 + 0.0013441094023223792*lm + 
            0.0005295076571996397*lm^2)*NM + (0.0032062193430208758 + 
            0.0013441094023223792*lm + 0.0005295076571996397*lm^2)*NL + 
          (-0.0005056585531596009 + 0.0013441094023223792*lm + 
            0.0005295076571996397*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.012442686477811903 - 0.010643649522395982*lm - 
          0.0027915374671108883*lm^2) + CF^2*(0.013110744807706453 + 
          0.02034406197759384*lm + 0.013703911202180724*lm^2) + 
        CF*((0.002351786450083367 + 0.0012892333918479895*lm + 
            0.0005075522667474342*lm^2)*NM + (0.003071953471664838 + 
            0.0012892333918479895*lm + 0.0005075522667474342*lm^2)*NL + 
          (-0.0004851692150637122 + 0.0012892333918479895*lm + 
            0.0005075522667474342*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.011935030845968751 - 0.010205623208912449*lm - 
          0.002675687226011003*lm^2) + CF^2*(0.012617589637566628 + 
          0.019517890516700644*lm + 0.013135191836781286*lm^2) + 
        CF*((0.0022358107977215576 + 0.0012364005641964115*lm + 
            0.00048648858654745506*lm^2)*NM + (0.0029429031649817164 + 
            0.0012364005641964115*lm + 0.00048648858654745506*lm^2)*NL + 
          (-0.0004654536891834002 + 0.0012364005641964115*lm + 
            0.00048648858654745506*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.011445395023469135 - 0.00978448020839862*lm - 
          0.00256454627836691*lm^2) + CF^2*(0.012139323160495142 + 
          0.01872077471741606*lm + 0.012589590821073922*lm^2) + 
        CF*((0.0021250985597508656 + 0.0011855476759545134*lm + 
            0.00046628114152125633*lm^2)*NM + (0.0028188966097008536 + 
            0.0011855476759545134*lm + 0.00046628114152125633*lm^2)*NL + 
          (-0.00044648536795939466 + 0.0011855476759545134*lm + 
            0.00046628114152125633*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.010973350471921458 - 0.009379638592064069*lm - 
          0.002457926862024705*lm^2) + CF^2*(0.011675743105554456 + 
          0.017952003913271817*lm + 0.012066186413575824*lm^2) + 
        CF*((0.0020194422225690784 + 0.0011366123709811386*lm + 
            0.00044689579309540087*lm^2)*NM + (0.002699764730178925 + 
            0.0011366123709811386*lm + 0.00044689579309540087*lm^2)*NL + 
          (-0.0004282383950627972 + 0.0011366123709811386*lm + 
            0.00044689579309540087*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.010518457942714998 - 0.0089905309284705*lm - 
          0.002355648336889617*lm^2) + CF^2*(0.011226629506841437 + 
          0.017210857203249066*lm + 0.011564091835639938*lm^2) + 
        CF*((0.0019186397012960633 + 0.0010895332809375351*lm + 
            0.000428299697616294*lm^2)*NM + (0.002585341482633222 + 
            0.0010895332809375351*lm + 0.000428299697616294*lm^2)*NL + 
          (-0.0004106876573189722 + 0.0010895332809375351*lm + 
            0.000428299697616294*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.0100802703397105 - 0.008616604464389277*lm - 
          0.002257536957641223*lm^2) + CF^2*(0.01079174672597317 + 
          0.016496606937433215*lm + 0.011082454155693276*lm^2) + 
        CF*((0.0018224944995235133 + 0.0010442501107653707*lm + 
            0.0004104612650256769*lm^2)*NM + (0.002475464099952906 + 
            0.0010442501107653707*lm + 0.0004104612650256769*lm^2)*NL + 
          (-0.00039380877536083315 + 0.0010442501107653707*lm + 
            0.0004104612650256769*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.009658335246641078 - 0.008257321233889654*lm - 
          0.002163425648675044*lm^2) + CF^2*(0.01037084533792937 + 
          0.015808521824899734*lm + 0.010620453184404762*lm^2) + 
        CF*((0.0017308158228313251 + 0.0010007037106005878*lm + 
            0.0003933501179409171*lm^2)*NM + (0.0023699732925298147 + 
            0.0010007037106005878*lm + 0.0003933501179409171*lm^2)*NL + 
          (-0.00037757809318191015 + 0.0010007037106005878*lm + 
            0.0003933501179409171*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.009252069050711487 - 0.007912158103979777*lm - 
          0.002073153781939137*lm^2) + CF^2*(0.009963407681412701 + 
          0.015145869697042659*lm + 0.010177300384064853*lm^2) + 
        CF*((0.0016434186520242636 + 0.0009588361354814816*lm + 
            0.00037693705126166124*lm^2)*NM + (0.0022687134100134484 + 
            0.0009588361354814816*lm + 0.00037693705126166124*lm^2)*NL + 
          (-0.00036197266674767076 + 0.0009588361354814816*lm + 
            0.00037693705126166124*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.00886128860806452 - 0.007580606764328031*lm - 
          0.0019865669582253783*lm^2) + CF^2*(0.009569708909921808 + 
          0.01450791995690208*lm + 0.009752237794924585*lm^2) + 
        CF*((0.0015601237809954446 + 0.0009185906940901329*lm + 
            0.00036119399240461427*lm^2)*NM + (0.002171532568408932 + 
            0.0009185906940901329*lm + 0.00036119399240461427*lm^2)*NL + 
          (-0.0003469702518036772 + 0.0009185906940901329*lm + 
            0.00036119399240461427*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.008485392541370965 - 0.007262173667868814*lm - 
          0.0019035167923796505*lm^2) + CF^2*(0.009189177674875492 + 
          0.013893945742586936*lm + 0.00934453698077283*lm^2) + 
        CF*((0.0014807578241257653 + 0.0008799119876568901*lm + 
            0.00034609396225084553*lm^2)*NM + (0.002078282746497249 + 
            0.0008799119876568901*lm + 0.00034609396225084553*lm^2)*NL + 
          (-0.0003325492910082244 + 0.0008799119876568901*lm + 
            0.00034609396225084553*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.008123927765754093 - 0.006956379928438293*lm - 
          0.001823860702811479*lm^2) + CF^2*(0.008821527589374049 + 
          0.013303225830612152*lm + 0.008953497995619989*lm^2) + 
        CF*((0.0014051531969136461 + 0.0008427459400571986*lm + 
            0.0003316110368748144*lm^2)*NM + (0.0019888198551594916 + 
            0.0008427459400571986*lm + 0.0003316110368748144*lm^2)*NL + 
          (-0.0003186889005036514 + 0.0008427459400571986*lm + 
            0.0003316110368748144*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.0077764448050594865 - 0.0066627611809861615*lm - 
          0.0017474617056105024*lm^2) + CF^2*(0.008466466557558321 + 
          0.012735046302863267*lm + 0.00857844837299701*lm^2) + 
        CF*((0.0013331480740362278 + 0.0008070398200380289*lm + 
            0.0003177203101110004*lm^2)*NM + (0.00190300378282731 + 
            0.0008070398200380289*lm + 0.0003177203101110004*lm^2)*NL + 
          (-0.0003053688560278405 + 0.0008070398200380289*lm + 
            0.0003177203101110004*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.007442498952795834 - 0.006380867409364172*lm - 
          0.0016741882135131718*lm^2) + CF^2*(0.008123698043427222 + 
          0.012188701998955383*lm + 0.008218742139064662*lm^2) + 
        CF*((0.0012645863273674704 + 0.0007727422564268013*lm + 
            0.0003043978570023949*lm^2)*NM + (0.0018206984199565773 + 
            0.0007727422564268013*lm + 0.0003043978570023949*lm^2)*NL + 
          (-0.00029256957865959703 + 0.0007727422564268013*lm + 
            0.0003043978570023949*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.007121651384353276 - 0.006110262746196051*lm - 
          0.001603913839907297*lm^2) + CF^2*(0.007792922461355036 + 
          0.01166349777395589*lm + 0.007873758850454004*lm^2) + 
        CF*((0.0011993172124660765 + 0.00073980324709842*lm + 
            0.0002916206981649631*lm^2)*NM + (0.0017417716651272866 + 
            0.00073980324709842*lm + 0.0002916206981649631*lm^2)*NL + 
          (-0.0002802721202790698 + 0.00073980324709842*lm + 
            0.0002916206981649631*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.0068134694595588675 - 0.0058505252488823935*lm - 
          0.0015365172080134325*lm^2) + CF^2*(0.007473837138870754 + 
          0.011158749579781526*lm + 0.007542902657520487*lm^2) + 
        CF*((0.0011371964577724977 + 0.0007081741624052607*lm + 
            0.0002793667650933514*lm^2)*NM + (0.0016660954151069003 + 
            0.0007081741624052607*lm + 0.0002793667650933514*lm^2)*NL + 
          (-0.0002684581488171105 + 0.0007081741624052607*lm + 
            0.0002793667650933514*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.006517528575766715 - 0.005601246655384052*lm - 
          0.0014718817653398802*lm^2) + CF^2*(0.0071661395475904645 + 
          0.010673785387050187*lm + 0.007225601393486685*lm^2) + 
        CF*((0.0010780837751802282 + 0.000677807743710186*lm + 
            0.00026761486642543276*lm^2)*NM + (0.0015935455409741236 + 
            0.000677807743710186*lm + 0.00026761486642543276*lm^2)*NL + 
          (-0.0002571099333659173 + 0.000677807743710186*lm + 
            0.00026761486642543276*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.006233411616661667 - 0.005362032123054984*lm - 
          0.0014098956034714494*lm^2) + CF^2*(0.006869525870885615 + 
          0.010207945962757405*lm + 0.006921305689768933*lm^2) + 
        CF*((0.0010218452059259518 + 0.0006486580976033807*lm + 
            0.0002563446551766272*lm^2)*NM + (0.0015240018521829558 + 
            0.0006486580976033807*lm + 0.0002563446551766272*lm^2)*NL + 
          (-0.0002462103291964657 + 0.0006486580976033807*lm + 
            0.0002563446551766272*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.0059607101222706295 - 0.005132499953457012*lm - 
          0.001350451283220473*lm^2) + CF^2*(0.006583693139939613 + 
          0.009760585517847527*lm + 0.006629488117627777*lm^2) + 
        CF*((0.0009683516332650716 + 0.0006206806863295951*lm + 
            0.0002455365969491769*lm^2)*NM + (0.0014573480502507122 + 
            0.0006206806863295951*lm + 0.0002455365969491769*lm^2)*NL + 
          (-0.00023574276275289944 + 0.0006206806863295951*lm + 
            0.0002455365969491769*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.005699024493809671 - 0.004912281305781686*lm - 
          0.00129344566514131*lm^2) + CF^2*(0.006308339548292974 + 
          0.009331072237552808*lm + 0.006349642356148248*lm^2) + 
        CF*((0.0009174790712529496 + 0.0005938323149028133*lm + 
            0.0002351719391166018*lm^2)*NM + (0.0013934716735765009 + 
            0.0005938323149028133*lm + 0.0002351719391166018*lm^2)*NL + 
          (-0.00022569121665442653 + 0.0005938323149028133*lm + 
            0.0002351719391166018*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.005447964379517317 - 0.004701019901225455*lm - 
          0.0012387797453861584*lm^2) + CF^2*(0.006043165221969098 + 
          0.008918788706271599*lm + 0.006081282386441142*lm^2) + 
        CF*((0.0008691084422805205 + 0.0005680711153400627*lm + 
            0.00022523268097930153*lm^2)*NM + (0.0013322640347366162 + 
            0.0005680711153400627*lm + 0.00022523268097930153*lm^2)*NL + 
          (-0.0002160402147617998 + 0.0005680711153400627*lm + 
            0.00022523268097930153*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.005207148926169397 - 0.004498371720411339*lm - 
          0.0011863584968600327*lm^2) + CF^2*(0.005787872801102003 + 
          0.008523132237743059*lm + 0.005823941711858342*lm^2) + 
        CF*((0.0008231254585093676 + 0.0005433565284046987*lm + 
            0.0002157015448836423*lm^2)*NM + (0.0012736201514588431 + 
            0.0005433565284046987*lm + 0.0002157015448836423*lm^2)*NL + 
          (-0.00020677480732762487 + 0.0005433565284046987*lm + 
            0.0002157015448836423*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.00497620697500919 - 0.004304004695720784*lm - 
          0.0011360907156157739*lm^2) + CF^2*(0.005542167978617214 + 
          0.008143515120343229*lm + 0.005577172603931981*lm^2) + 
        CF*((0.0007794204819930592 + 0.0005196492832116991*lm + 
            0.00020656194829377707*lm^2)*NM + (0.0012174386723472588 + 
            0.0005196492832116991*lm + 0.00020656194829377707*lm^2)*NL + 
          (-0.00019788055628140947 + 0.0005196492832116991*lm + 
            0.00020656194829377707*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.0047547771992006585 - 0.004117598400191466*lm - 
          0.0010878888724156586*lm^2) + CF^2*(0.005305759979651509 + 
          0.007779364786470043*lm + 0.0053405453736768685*lm^2) + 
        CF*((0.0007378883845559964 + 0.0004969113750130067*lm + 
            0.00019779797680284699*lm^2)*NM + (0.0011636217983114914 + 
            0.0004969113750130067*lm + 0.00019779797680284699*lm^2)*NL + 
          (-0.0001893435206636994 + 0.0004969113750130067*lm + 
            0.00019779797680284699*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.004542508189778168 - 0.003938843734448366*lm - 
          0.0010416689693741833*lm^2) + CF^2*(0.0050783619863656575 + 
          0.007430123914196976*lm + 0.005113647667836899*lm^2) + 
        CF*((0.0006984284058463781 + 0.0004751060414494787*lm + 
            0.00018939435806803332*lm^2)*NM + (0.0011120752005482832 + 
            0.0004751060414494787*lm + 0.00018939435806803332*lm^2)*NL + 
          (-0.0001811502422385188 + 0.0004751060414494787*lm + 
            0.00018939435806803332*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.0043390584959072075 - 0.0037674426129649568*lm - 
          0.0009973504015866829*lm^2) + CF^2*(0.004859691511590101 + 
          0.007095250468651254*lm + 0.0048960837896073525*lm^2) + 
        CF*((0.0006609440117229577 + 0.00045419773752728863*lm + 
            0.00018133643665212417*lm^2)*NM + (0.001062707935827553 + 
            0.00045419773752728863*lm + 0.00018133643665212417*lm^2)*NL + 
          (-0.0001732877313097687 + 0.00045419773752728863*lm + 
            0.00018133643665212417*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.004144096624967945 - 0.003603107650797018*lm - 
          0.0009548558236403239*lm^2) + CF^2*(0.004649470725122242 + 
          0.006774217689907941*lm + 0.004687474043325227*lm^2) + 
        CF*((0.0006253427530824607 + 0.00043415210955045723*lm + 
            0.00017361014975278617*lm^2)*NM + (0.0010154323597489701 + 
            0.00043415210955045723*lm + 0.00017361014975278617*lm^2)*NL + 
          (-0.0001657434527510046 + 0.00043415210955045723*lm + 
            0.00017361014975278617*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.003957301007353443 - 0.003445561851792147*lm - 
          0.0009141110208974834*lm^2) + CF^2*(0.004447426736130947 + 
          0.006466514033581122*lm + 0.004487454102587646*lm^2) + 
        CF*((0.0005915361258907685 + 0.00041493596821733634*lm + 
            0.00016620200379954245*lm^2)*NM + (0.0009701640385574121 + 
            0.00041493596821733634*lm + 0.00016620200379954245*lm^2)*NL + 
          (-0.0001585053122752129 + 0.00041493596821733634*lm + 
            0.00016620200379954245*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.0037783599304428055 - 0.0032945382991520097*lm - 
          0.0008750447854363856*lm^2) + CF^2*(0.00425329183504208 + 
          0.0061716430697336564*lm + 0.004295674401233166*lm^2) + 
        CF*((0.000559439432649632 + 0.0003965172610671522*lm + 
            0.00015909905189752466*lm^2)*NM + (0.0009268216600358036 + 
            0.0003965172610671522*lm + 0.00015909905189752466*lm^2)*NL + 
          (-0.00015156164295273024 + 0.0003965172610671522*lm + 
            0.00015909905189752466*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.003606971445733401 - 0.0031497798491106586*lm - 
          0.0008375887965299375*lm^2) + CF^2*(0.004066803698022076 + 
          0.005889123345213451*lm + 0.004111799546601512*lm^2) + 
        CF*((0.0005289716459007308 + 0.0003788650444429441*lm + 
            0.00015228887209635226*lm^2)*NM + (0.0008853269439309668 + 
            0.0003788650444429441*lm + 0.00015228887209635226*lm^2)*NL + 
          (-0.00014490119197387214 + 0.0003788650444429441*lm + 
            0.00015228887209635226*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.003442843252749415 - 0.0030110388283896704*lm - 
          0.0008016775055408455*lm^2) + CF^2*(0.003887705557061699 + 
          0.005618488214053512*lm + 0.003935507754473242*lm^2) + 
        CF*((0.000500055273970695 + 0.0003619494551192486*lm + 
            0.00014575954646197192*lm^2)*NM + (0.000845604552311592 + 
            0.0003619494551192486*lm + 0.00014575954646197192*lm^2)*NL + 
          (-0.0001385131077096371 + 0.0003619494551192486*lm + 
            0.00014575954646197192*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.003285692562977755 - 0.002878076735998451*lm - 
          0.0007672480251091501*lm^2) + CF^2*(0.003715746338479862 + 
          0.00535928564014153*lm + 0.0037664903050812827*lm^2) + 
        CF*((0.0004726162292284278 + 0.00034574168172652657*lm + 
            0.0001394996409289364*lm^2)*NM + (0.0008075820002066591 + 
            0.00034574168172652657*lm + 0.0001394996409289364*lm^2)*NL + 
          (-0.00013238692701189071 + 0.00034574168172652657*lm + 
            0.0001394996409289364*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.0031352459467187677 - 0.00275066394986488*lm - 
          0.000734240022507179*lm^2) + CF^2*(0.0035506807724291524 + 
          0.005111077975969505*lm + 0.003604451019580697*lm^2) + 
        CF*((0.00044658369939322364 + 0.00033021393608947394*lm + 
            0.0001334981859103962*lm^2)*NM + (0.000771189566827055 + 
            0.00033021393608947394*lm + 0.0001334981859103962*lm^2)*NL + 
          (-0.0001265125628232527 + 0.00033021393608947394*lm + 
            0.0001334981859103962*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.0029912391655571666 - 0.0026285794387067157*lm - 
          0.000702595617036474*lm^2) + CF^2*(0.003392269476054614 + 
          0.004873441720911947*lm + 0.0034491057563608724*lm^2) + 
        CF*((0.0004218900211632338 + 0.0003153394245828634*lm + 
            0.00012774465764299527*lm^2)*NM + (0.0007363602076322457 + 
            0.0003153394245828634*lm + 0.00012774465764299527*lm^2)*NL + 
          (-0.00012088029206164553 + 0.0003153394245828634*lm + 
            0.00012774465764299527*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.002853416992683847 - 0.00251161047948703*lm - 
          0.000672259281341403*lm^2) + CF^2*(0.0032402790123927947 + 
          0.004645967262149879*lm + 0.0033001819265850696*lm^2) + 
        CF*((0.0003984705579077921 + 0.0003010923195963254*lm + 
            0.00012222896024389148*lm^2)*NM + (0.0007030294674672149 + 
            0.0003010923195963254*lm + 0.00012222896024389148*lm^2)*NL + 
          (-0.00011548074379699542 + 0.0003010923195963254*lm + 
            0.00012222896024389148*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.002721533023288867 - 0.0023995523807367686*lm - 
          0.0006431777465148379*lm^2) + CF^2*(0.0030944819274184195 + 
          0.004428258601054709*lm + 0.003157418028345568*lm^2) + 
        CF*((0.00037626357974277565 + 0.0002874477311883756*lm + 
            0.00011694140845724325*lm^2)*NM + (0.0006711353949620895 + 
            0.0002874477311883756*lm + 0.00011694140845724325*lm^2)*NL + 
          (-0.00011030488768988992 + 0.0002874477311883756*lm + 
            0.00011694140845724325*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.0025953494768441885 - 0.0022922082119736396*lm - 
          0.0006152999108723887*lm^2) + CF^2*(0.00295465676714457 + 
          0.00421993306756883*lm + 0.0030205631988280903*lm^2) + 
        CF*((0.0003552101474160394 + 0.0002743816789999437*lm + 
            0.00011187271106770704*lm^2)*NM + (0.0006406184583575304 + 
            0.0002743816789999437*lm + 0.00011187271106770704*lm^2)*NL + 
          (-0.0001053440228081822 + 0.0002743816789999437*lm + 
            0.00011187271106770704*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.0024746369929920203 - 0.0021893885393983624*lm - 
          0.0005885767522731705*lm^2) + CF^2*(0.002820588076743644 + 
          0.004020621024866384*lm + 0.0028893767838864735*lm^2) + 
        CF*((0.00033525399931197316 + 0.0002618710644885554*lm + 
            0.00010701395495875827*lm^2)*NM + (0.0006114214628927756 + 
            0.0002618710644885554*lm + 0.00010701395495875827*lm^2)*NL + 
          (-0.000100589766610393 + 0.0002618710644885554*lm + 
            0.00010701395495875827*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.002359174422512535 - 0.002090911168006346*lm - 
          0.0005629612438668759*lm^2) + CF^2*(0.0026920663834079546 + 
          0.003829965566346117*lm + 0.00276362792443739*lm^2) + 
        CF*((0.0003163414423084576 + 0.0002498936435360916*lm + 
            0.00010235658979397742*lm^2)*NM + (0.0005834894698698575 + 
            0.0002498936435360916*lm + 0.00010235658979397742*lm^2)*NL + 
          (-0.00009603404432190674 + 0.0002498936435360916*lm + 
            0.00010235658979397742*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.0022487486147395224 - 0.0019966008902146002*lm - 
          0.0005384082731489915*lm^2) + CF^2*(0.002568888164666086 + 
          0.003647622206796839*lm + 0.002643095159095049*lm^2) + 
        CF*((0.0002984212451383696 + 0.00023842799947561527*lm + 
            0.00009789241329981663*lm^2)*NM + (0.0005567697174867053 + 
            0.00023842799947561527*lm + 0.00009789241329981663*lm^2)*NL + 
          (-0.00009166907855308624 + 0.00023842799947561527*lm + 
            0.00009789241329981663*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.002143154202564671 - 0.0019062892410697*lm - 
          0.0005148745642082781*lm^2) + CF^2*(0.002450855803598328 + 
          0.003473258569383085*lm + 0.0025275660424770013*lm^2) + 
        CF*((0.0002814445363986813 + 0.0002274535165760464*lm + 
            0.00009361355712877783*lm^2)*NM + (0.0005312115435133425 + 
            0.0002274535165760464*lm + 0.00009361355712877783*lm^2)*NL + 
          (-0.00008748737921488147 + 0.0002274535165760464*lm + 
            0.00009361355712877783*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.002042193386123885 - 0.0018198142600724897*lm - 
          0.000492318603053093*lm^2) + CF^2*(0.0023377775324605774 + 
          0.0033065540699225722*lm + 0.0024168367786242748*lm^2) + 
        CF*((0.00026536470506252256 + 0.0002169503540174229*lm + 
            0.00008951247328238054*lm^2)*NM + (0.0005067663098689699 + 
            0.0002169503540174229*lm + 0.00008951247328238054*lm^2)*NL + 
          (-0.0000834817337098031 + 0.0002169503540174229*lm + 
            0.00008951247328238054*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.001945675716052768 - 0.001737020259628623*lm - 
          0.00047070056590573785*lm^2) + CF^2*(0.0022294673659544522 + 
          0.003147199599766666*lm + 0.0023107118689918043*lm^2) + 
        CF*((0.00025013730472444765 + 0.0002068994203840417*lm + 
            0.00008558192107377052*lm^2)*NM + (0.00048338732914318184 + 
            0.0002068994203840417*lm + 0.00008558192107377052*lm^2)*NL + 
          (-0.0000796451974597186 + 0.0002068994203840417*lm + 
            0.00008558192107377052*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.0018534178771519754 - 0.00165775760011057*lm - 
          0.0004499822503567296*lm^2) + CF^2*(0.002125745025411759 + 
          0.002994897208448938*lm + 0.0022090037744784906*lm^2) + 
        CF*((0.00023571996119955892 + 0.0001972823486978852*lm + 
            0.00008181495461031448*lm^2)*NM + (0.00046102979309170955 + 
            0.0001972823486978852*lm + 0.00008181495461031448*lm^2)*NL + 
          (-0.00007597108456428894 + 0.0001972823486978852*lm + 
            0.00008181495461031448*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.0017652434731524375 - 0.0015818824714961593*lm - 
          0.00043012700927369264*lm^2) + CF^2*(0.002026435854967648 + 
          0.0028493597871338985*lm + 0.0021115325909799457*lm^2) + 
        CF*((0.00022207228338616086 + 0.00018808147201034803*lm + 
            0.00007820491077703503*lm^2)*NM + (0.00043965070312575915 + 
            0.00018808147201034803*lm + 0.00007820491077703503*lm^2)*NL + 
          (-0.00007245295893418416 + 0.00018808147201034803*lm + 
            0.00007820491077703503*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.0016809828132264113 - 0.001509256681530742*lm - 
          0.0004110996873624332*lm^2) + CF^2*(0.001931370730802309 + 
          0.002710310753776989*lm + 0.0020181257379610355*lm^2) + 
        CF*((0.00020915577735078505 + 0.00017927979956634872*lm + 
            0.00007474539770226057*lm^2)*NM + (0.0004192088028040558 + 
            0.00017927979956634872*lm + 0.00007474539770226057*lm^2)*NL + 
          (-0.0000690846255203323 + 0.00017927979956634872*lm + 
            0.00007474539770226057*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.0016004727007619443 - 0.0014397474503444136*lm - 
          0.00039286656028065755*lm^2) + CF^2*(0.0018403859643555318 + 
          0.0025774837407969613*lm + 0.0019286176595595915*lm^2) + 
        CF*((0.000196933763656448 + 0.00017086099355139413*lm + 
            0.00007143028368739227*lm^2)*NM + (0.00039966451232798157 + 
            0.00017086099355139413*lm + 0.00007143028368739227*lm^2)*NL + 
          (-0.00006586012191938214 + 0.00017086099355139413*lm + 
            0.00007143028368739227*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.0015235562248821408 - 0.0013732272114422097*lm - 
          0.00037539527620772357*lm^2) + CF^2*(0.00175332320041625 + 
          0.0024506222859619086*lm + 0.0018428495377470066*lm^2) + 
        CF*((0.00018537129780237573 + 0.00016280934642902772*lm + 
            0.00006825368658322247*lm^2)*NM + (0.0003809798650325823 + 
            0.00016280934642902772*lm + 0.00006825368658322247*lm^2)*NL + 
          (-0.00006277371017579465 + 0.00016280934642902772*lm + 
            0.00006825368658322247*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.0014501558098691267 - 0.0013095958382441275*lm - 
          0.0003586567077529482*lm^2) + CF*(0.0016700701897505855 + 
          0.0023295677776420196*lm + 0.001760678383514473*lm^2) + 
        0.00017444832658433312*NM + 0.00015511339358915914*lm*NM + 
        0.00006521031050053604*lm^2*NM + 0.00036312972744222073*NL + 
        0.00015511339358915914*lm*NL + 0.00006521031050053604*lm^2*NL - 
        0.00005982031758916129*NH + 0.00015511339358915914*lm*NH + 
        0.00006521031050053604*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.001379967405870126 - 0.0012486869306386169*lm - 
          0.00034261693420847134*lm^2) + CF*(0.001590390355937982 + 
          0.0022138910478431617*lm + 0.0016819376770234047*lm^2) + 
        0.0001641043948269509*NM + 0.00014775072988605268*lm*NM + 
        0.00006229398803790387*lm^2*NM + 0.0003460546689087934*NL + 
        0.00014775072988605268*lm*NL + 0.00006229398803790387*lm^2*NL - 
        0.00005699365741575977*NH + 0.00014775072988605268*lm*NH + 
        0.00006229398803790387*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.0013129396578749721 - 0.001190414333097236*lm - 
          0.0003272496894204303*lm^2) + CF*(0.0015141894586358636 + 
          0.002103469366870274*lm + 0.0016064984753366579*lm^2) + 
        0.00015432521575310017*NM + 0.0001407117687964227*lm*NM + 
        0.00005949994353098733*lm^2*NM + 0.00032973474826563596*NL + 
        0.0001407117687964227*lm*NL + 0.00005949994353098733*lm^2*NL - 
        0.00005428915642118527*NH + 0.0001407117687964227*lm*NH + 
        0.00005949994353098733*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.0012489384541533323 - 0.0011346693668089242*lm - 
          0.00031252756436739375*lm^2) + CF*(0.0014413292186794056 + 
          0.001998082498879301*lm + 0.0015342262250762964*lm^2) + 
        0.00014508198822020123*NM + 0.00013398309311991164*lm*NM + 
        0.000056823193521344316*lm^2*NM + 0.00031413780477791914*NL + 
        0.00013398309311991164*lm*NL + 0.000056823193521344316*lm^2*NL - 
        0.00005170189568066659*NH + 0.00013398309311991164*lm*NH + 
        0.000056823193521344316*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.0011878350285272395 - 0.0010813476782549894*lm - 
          0.0002984242654242782*lm^2) + CF*(0.0013716761523629771 + 
          0.0018975186925759247*lm + 0.0014649918484464567*lm^2) + 
        0.00013634730140943467*NM + 0.00012755181396471052*lm*NM + 
        0.00005425895734986876*lm^2*NM + 0.00029923301024690563*NL + 
        0.00012755181396471052*lm*NL + 0.00005425895734986876*lm^2*NL - 
        0.000049227143812184805*NH + 0.00012755181396471052*lm*NH + 
        0.00005425895734986876*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.0011295057678218266 - 0.001030349074033956*lm - 
          0.0002849145686031857*lm^2) + CF*(0.0013051014502660607 + 
          0.0018015743933716029*lm + 0.001398671518597457*lm^2) + 
        0.00012809507102865298*NM + 0.00012140555130461015*lm*NM + 
        0.00005180264883694285*lm^2*NM + 0.0002849908159064568*NL + 
        0.00012140555130461015*lm*NL + 0.00005180264883694285*lm^2*NL - 
        0.0000468603501968815*NH + 0.00012140555130461015*lm*NH + 
        0.00005180264883694285*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.0010738320247515576 - 0.0009815773615339776*lm - 
          0.00027197427568288637*lm^2) + CF*(0.001241480855644136 + 
          0.0017100539626590983*lm + 0.0013351464442614422*lm^2) + 
        0.00012030047826366243*NM + 0.00011553241516220406*lm*NM + 
        0.000049449868305979344*lm^2*NM + 0.00027138290127490055*NL + 
        0.00011553241516220406*lm*NL + 0.000049449868305979344*lm^2*NL - 
        0.00004459713842567998*NH + 0.00011553241516220406*lm*NH + 
        0.000049449868305979344*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.0010206999362111242 - 0.0009349401952797054*lm - 
          0.00025958017214937215*lm^2) + CF*(0.001180694542756073 + 
          0.0016227694042443251*lm + 0.001274302663278736*lm^2) + 
        0.00011293991137110048*NM + 0.00010992098740471983*lm*NM + 
        0.000047196394936249475*lm^2*NM + 0.0002583821249028721*NL + 
        0.00010992098740471983*lm*NL + 0.000047196394936249475*lm^2*NL - 
        0.00004243329996577152*NH + 0.00010992098740471983*lm*NH + 
        0.000047196394936249475*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.0009700002469279371 - 0.0008903489287830538*lm - 
          0.00024770998687301645*lm^2) + CF*(0.0011226269954628014 + 
          0.0015395400979483654*lm + 0.0012160308446493534*lm^2) + 
        0.00010599090980947406*NM + 0.0001045603041387002*lm*NM + 
        0.00004503817943145754*lm^2*NM + 0.00024596247695855334*NL + 
        0.0001045603041387002*lm*NL + 0.00004503817943145754*lm^2*NL - 
        0.000040364788040713266*NH + 0.0001045603041387002*lm*NH + 
        0.00004503817943145754*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.000921628138422269 - 0.0008477184717300563*lm - 
          0.00023634235345086838*lm^2) + CF*(0.0010671668863979622 + 
          0.0014601925403727478*lm + 0.0011602260987588085*lm^2) + 
        0.00009943211080821626*NM + 0.00009943983868956136*lm*NM + 
        0.00004297133699106698*lm^2*NM + 0.00023409903359262145*NL + 
        0.00009943983868956136*lm*NL + 0.00004297133699106698*lm^2*NL - 
        0.00003838771171798425*NH + 0.00009943983868956136*lm*NH + 
        0.00004297133699106698*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.0008754830632114657 - 0.000806967152338884*lm - 
          0.00022545677314548588*lm^2) + CF*(0.001014206956979729 + 
          0.0013845600928023977*lm + 0.0011067877954414763*lm^2) + 
        0.0000932431982778627*NM + 0.00009454948515191607*lm*NM + 
        0.00004099214057190653*lm^2*NM + 0.0002227679130261753*NL + 
        0.00009454948515191607*lm*NL + 0.00004099214057190653*lm^2*NL - 
        0.00003649833019795009*NH + 0.00009454948515191607*lm*NH + 
        0.00004099214057190653*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.0008314685841861935 - 0.0007680165847271418*lm - 
          0.00021503357935448195*lm^2) + CF*(0.0009636438985038518 + 
          0.0013124827362039147*lm + 0.0010556193895583659*lm^2) + 
        0.00008740485396763777*NM + 0.0000898795424964597*lm*NM + 
        0.000039097014428087626*lm^2*NM + 0.00021194623330592028*NL + 
        0.0000898795424964597*lm*NL + 0.000039097014428087626*lm^2*NL - 
        0.00003469304729829546*NH + 0.0000898795424964597*lm*NH + 
        0.000039097014428087626*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.0007894922190792713 - 0.0007307915411296964*lm - 
          0.00020505390354761817*lm^2) + CF*(0.0009153782345310642 + 
          0.0012438068332618491*lm + 0.0010066282537792165*lm^2) + 
        0.00008189871077987272*NM + 0.00008542069921917366*lm*NM + 
        0.00003728252791774876*lm^2*NM + 0.0002016120716719585*NL + 
        0.00008542069921917366*lm*NL + 0.00003728252791774876*lm^2*NL - 
        0.000032968406128094696*NH + 0.00008542069921917366*lm*NH + 
        0.00003728252791774876*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.0007494652899412339 - 0.0006952198288115365*lm - 
          0.0001954996426108397*lm^2) + CF*(0.0008693142047571766 + 
          0.0011783848973823256*lm + 0.0009597255182713949*lm^2) + 
        0.00007670730815374952*NM + 0.00008116401851859745*lm*NM + 
        0.000035545389565607216*lm^2*NM + 0.0001917444254846379*NL + 
        0.00008116401851859745*lm*NL + 0.000035545389565607216*lm^2*NL - 
        0.00003132108394580545*NH + 0.00008116401851859745*lm*NH + 
        0.000035545389565607216*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.0007113027775312432 - 0.0006612321715234814*lm - 
          0.00018635342753910432*lm^2) + CF*(0.000825359650531299 + 
          0.0011160753685815425*lm + 0.0009148259170101486*lm^2) + 
        0.00007181404943387365*NM + 0.00007710092398695593*lm*NM + 
        0.000033882441370746245*lm^2*NM + 0.00018232317465805678*NL + 
        0.00007710092398695593*lm*NL + 0.000033882441370746245*lm^2*NL - 
        0.000029747887195586932*NH + 0.00007710092398695593*lm*NH + 
        0.000033882441370746245*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.0006749231805272823 - 0.0006287620953519476*lm - 
          0.00017759859342222434*lm^2) + CF*(0.0007834259021665787 + 
          0.001056742396166286*lm + 0.0008718476404363741*lm^2) + 
        0.0000672031611421243*NM + 0.00007322318580099641*lm*NM + 
        0.00003229065334949534*lm^2*NM + 0.0001733290455489932*NL + 
        0.00007322318580099641*lm*NL + 0.00003229065334949534*lm^2*NL - 
        0.000028245746716462573*NH + 0.00007322318580099641*lm*NH + 
        0.00003229065334949534*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.000640248379455633 - 0.0005977458188174116*lm - 
          0.00016921915067021062*lm^2) + CF*(0.000743427668168488 + 
          0.0010002556281044725*lm + 0.0008307121941992158*lm^2) + 
        0.00006285965407410883*NM + 0.0000695229073984889*lm*NM + 
        0.00003076711830367466*lm^2*NM + 0.00016474357625122278*NL + 
        0.0000695229073984889*lm*NL + 0.00003076711830367466*lm^2*NL - 
        0.00002681171311896722*NH + 0.0000695229073984889*lm*NH + 
        0.00003076711830367466*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.0006072035052364003 - 0.00056812214707968*lm - 
          0.00016119975742679278*lm^2) + CF*(0.0007052829264879157 + 
          0.0009464900069758311*lm + 0.0007913442637315282*lm^2) + 
        0.00005876928614435995*NM + 0.00006599251262646912*lm*NM + 
        0.000029309046804871414*lm^2*NM + 0.00015654908324640326*NL + 
        0.00006599251262646912*lm*NL + 0.000029309046804871414*lm^2*NL - 
        0.00002544295232403945*NH + 0.00006599251262646912*lm*NH + 
        0.000029309046804871414*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.0005757168122392381 - 0.0005398323701115767*lm - 
          0.00015352569312188682*lm^2) + CF*(0.0006689128178900281 + 
          0.0008953255723860088*lm + 0.0007536715844165354*lm^2) + 
        0.00005491852690715689*NM + 0.00006262473334745335*lm*NM + 
        0.000027913762385797605*lm^2*NM + 0.00014872862936392807*NL + 
        0.00006262473334745335*lm*NL + 0.000027913762385797605*lm^2*NL - 
        0.000024136741259041477*NH + 0.00006262473334745335*lm*NH + 
        0.000027913762385797605*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.0005457195557414054 - 0.0005128201647061578*lm - 
          0.00014618283311579712*lm^2) + CF*(0.0006342415415149428 + 
          0.0008466472697215727*lm + 0.0007176248171139132*lm^2) + 
        0.000051294523682525005*NM + 0.00005941259749002605*lm*NM + 
        0.000026578696930144934*lm^2*NM + 0.00014126599300338683*NL + 
        0.00005941259749002605*lm*NL + 0.000026578696930144934*lm^2*NL - 
        0.000022890463705910908*NH + 0.00005941259749002605*lm*NH + 
        0.000026578696930144934*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.0005171458736787729 - 0.00048703150018608577*lm - 
          0.00013915762438987525*lm^2) + CF*(0.0006011962526926264 + 
          0.0008003447651184917*lm + 0.000683137428823024*lm^2) + 
        0.00004788506921957206*NM + 0.000056349417530391573*lm*NM + 
        0.000025301386252704592*lm^2*NM + 0.0001341456385745075*NL + 
        0.000056349417530391573*lm*NL + 0.000025301386252704592*lm^2*NL - 
        0.00002170160629657051*NH + 0.000056349417530391573*lm*NH + 
        0.000025301386252704592*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.000489932672579369 - 0.00046241454768728953*lm - 
          0.00013243706224021768*lm^2) + CF*(0.0005697069630619785 + 
          0.0007563122665126357*lm + 0.0006501455782701595*lm^2) + 
        0.00004467857083185259*NM + 0.000053428779391688216*lm*NM + 
        0.000024079465861857758*lm^2*NM + 0.00012735268811069322*NL + 
        0.000053428779391688216*lm*NL + 0.000024079465861857758*lm^2*NL - 
        0.00002056775465084389*NH + 0.000053428779391688216*lm*NH + 
        0.000024079465861857758*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.0004640195175684558 - 0.00043891959289253456*lm - 
          0.00012600866793276998*lm^2) + CF*(0.0005397064430327352 + 
          0.000714448350637559*lm + 0.0006185880062154163*lm^2) + 
        0.00004166402094191504*NM + 0.000050644531748084304*lm*NM + 
        0.000022910666896867268*lm^2*NM + 0.00012087289401350274*NL + 
        0.000050644531748084304*lm*NL + 0.000022910666896867268*lm^2*NL - 
        0.00001948658965224617*NH + 0.000050644531748084304*lm*NH + 
        0.000022910666896867268*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.0004393485263339054 - 0.0004164989520939924*lm - 
          0.00011986046727991896*lm^2) + CF*(0.0005111301266185193 + 
          0.0006746557958322609*lm + 0.0005884059302832385*lm^2) + 
        0.000038830968974579*NM + 0.00004799077572090994*lm*NM + 
        0.00002179281223271254*lm^2*NM + 0.00011469261288665037*NL + 
        0.00004799077572090994*lm*NL + 0.00002179281223271254*lm^2*NL - 
        0.0000184558838571391*NH + 0.00004799077572090994*lm*NH + 
        0.00002179281223271254*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.00041586426694079114 - 0.0003951068914673386*lm - 
          0.00011398097010030086*lm^2) + CF*(0.0004839160186600154 + 
          0.0006368414205196944*lm + 0.0005595429441287497*lm^2) + 
        0.00003616949454081324*NM + 0.00004546185495432252*lm*NM + 
        0.000020723812745509248*lm^2*NM + 0.00010879878041932243*NL + 
        0.00004546185495432252*lm*NL + 0.000020723812745509248*lm^2*NL - 
        0.000017473498032859755*NH + 0.00004546185495432252*lm*NH + 
        0.000020723812745509248*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.0003935136593845453 - 0.00037469954944331337*lm - 
          0.00010835915052513344*lm^2) + CF*(0.00045800460444879015 + 
          0.0006009159272154431*lm + 0.0005319449207597459*lm^2) + 
        0.00003367018185633841*NM + 0.00004305234605825751*lm*NM + 
        0.000019701663731842443*lm^2*NM + 0.00010317888727981468*NL + 
        0.00004305234605825751*lm*NL + 0.000019701663731842443*lm^2*NL - 
        0.00001653737782055017*NH + 0.00004305234605825751*lm*NH + 
        0.000019701663731842443*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.0003722458807727698 - 0.0003552348620660443*lm - 
          0.00010298442811589654*lm^2) + CF*(0.00043333876175464045 + 
          0.0005667937519251686*lm + 0.0005055599198416739*lm^2) + 
        0.00003132409534126322*NM + 0.00004075704940667662*lm*NM + 
        0.00001872444147561755*lm^2*NM + 0.0000978209559816896*NL + 
        0.00004075704940667662*lm*NL + 0.00001872444147561755*lm^2*NL - 
        0.000015645550518532616*NH + 0.00004075704940667662*lm*NH + 
        0.00001872444147561755*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.0003520122740267559 - 0.0003366724912307479*lm - 
          0.00009784664975964158*lm^2) + CF*(0.00040986367525247335 + 
          0.0005343929187890903*lm + 0.0004803380988200587*lm^2) + 
        0.000029122756349179275*NM + 0.000038570980279392475*lm*NM + 
        0.00001779029995629847*lm^2*NM + 0.00009271351868583078*NL + 
        0.000038570980279392475*lm*NL + 0.00001779029995629847*lm^2*NL - 
        0.000014796121982190689*NH + 0.000038570980279392475*lm*NH + 
        0.00001779029995629847*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.00033276625999496503 - 0.00031897375569670005*lm - 
          0.00009293607230960719*lm^2) + CF*(0.0003875267533385532 + 
          0.0005036348998318437*lm + 0.000456231627701708*lm^2) + 
        0.00002705812097618889*NM + 0.000036489360336019834*lm*NM + 
        0.00001689746769265585*lm^2*NM + 0.00008784559590293377*NL + 
        0.000036489360336019834*lm*NL + 0.00001689746769265585*lm^2*NL - 
        0.000013987273636430723*NH + 0.000036489360336019834*lm*NH + 
        0.00001689746769265585*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.00031446325287211183 - 0.0003021015647745799*lm - 
          0.00008824334594015861*lm^2) + CF*(0.0003662775473204286 + 
          0.00047444447967653794*lm + 0.0004331946073425968*lm^2) + 
        0.000025122558902322888*NM + 0.000034507609410878647*lm*NM + 
        0.000016044244716392476*lm^2*NM + 0.00008320667606211401*NL + 
        0.000034507609410878647*lm*NL + 0.000016044244716392476*lm^2*NL - 
        0.000013217259596910358*NH + 0.000034507609410878647*lm*NH + 
        0.000016044244716392476*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.0002970605788190455 - 0.00028602035459045493*lm - 
          0.0000837594981863552*lm^2) + CF*(0.0003460676729599354 + 
          0.00044674962508265277*lm + 0.00041118299109665283*lm^2) + 
        0.00002330883321972287*NM + 0.000032621337617950935*lm*NM + 
        0.0000152289996702464*lm^2*NM + 0.00007878669591243544*NL + 
        0.000032621337617950935*lm*NL + 0.0000152289996702464*lm^2*NL - 
        0.00001248440389633186*NH + 0.000032621337617950935*lm*NH + 
        0.0000152289996702464*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.0002805173976803316 - 0.0002706960268317766*lm - 
          0.00007947591863968332*lm^2) + CF*(0.00032685073434430444 + 
          0.0004204813591685396*lm + 0.00039015450968571814*lm^2) + 
        0.000021610081203815134*NM + 0.00003082633775527234*lm*NM + 
        0.000014450167025396967*lm^2*NM + 0.00007457602172526357*NL + 
        0.00003082633775527234*lm*NL + 0.000014450167025396967*lm^2*NL - 
        0.000011787097812206516*NH + 0.00003082633775527234*lm*NH + 
        0.000014450167025396967*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.000264794627698267 - 0.0002560958898837972*lm - 
          0.00007538434427267656*lm^2) + CF*(0.0003085822500565534 + 
          0.000395573640180693*lm + 0.0003700685991567758*lm^2) + 
        0.000020019795985493653*NM + 0.000029118577998418138*lm*NM + 
        0.00001370624441321392*lm^2*NM + 0.00007056543126642548*NL + 
        0.000029118577998418138*lm*NL + 0.00001370624441321392*lm^2*NL - 
        0.000011123797292603351*NH + 0.000029118577998418138*lm*NH + 
        0.00001370624441321392*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.0002498548731239996 - 0.00024218860226779613*lm - 
          0.00007147684536627986*lm^2) + CF*(0.000291219581612957 + 
          0.00037196324467360213*lm + 0.0003508863317981011*lm^2) + 
        0.000018531809084057197*NM + 0.00002749419487302214*lm*NM + 
        0.000012995790066596339*lm^2*NM + 0.00006674609650821452*NL + 
        0.00002749419487302214*lm*NL + 0.000012995790066596339*lm^2*NL - 
        0.0000104930204765002*NH + 0.00002749419487302214*lm*NH + 
        0.000012995790066596339*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.00023566235462845362 - 0.00022894411829541835*lm - 
          0.00006774581201490342*lm^2) + CF*(0.0002747218641324421 + 
          0.00034958965496584364*lm + 0.00033257034989134406*lm^2) + 
        0.00001714027376231322*NM + 0.000025949486496544698*lm*NM + 
        0.000012317420366346076*lm^2*NM + 0.00006310956705230903*NL + 
        0.000025949486496544698*lm*NL + 0.000012317420366346076*lm^2*NL - 
        9.893345305458008*^-6*NH + 0.000025949486496544698*lm*NH + 
        0.000012317420366346076*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.00022218284241786772 - 0.00021633363585627286*lm - 
          0.00006418394118515648*lm^2) + CF*(0.00025904993920019843 + 
          0.00032839495074012115*lm + 0.0003150848021816773*lm^2) + 
        0.00001583964916686912*NM + 0.000024480906079781994*lm*NM + 
        0.00001166980748821027*lm^2*NM + 0.00005964775423568152*NL + 
        0.000024480906079781994*lm*NL + 0.00001166980748821027*lm^2*NL - 
        9.323407223439802*^-6*NH + 0.000024480906079781994*lm*NH + 
        0.00001166980748821027*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.00020938359196091873 - 0.00020432954625872063*lm - 
          0.000060784224305252547*lm^2) + CF*(0.00024416628988561186 + 
          0.0003083237046571552*lm + 0.000298395282953058*lm^2) + 
        0.000014624685218181633*NM + 0.0000230850556788825*lm*NM + 
        0.000011051677146409553*lm^2*NM + 0.00005635291589255759*NL + 
        0.0000230850556788825*lm*NL + 0.000011051677146409553*lm^2*NL - 
        8.781896961694393*^-6*NH + 0.0000230850556788825*lm*NH + 
        0.000011051677146409553*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.0001972332822366168 - 0.00019290538604649316*lm - 
          0.000057539935363037715*lm^2) + CF*(0.00023003497787276776 + 
          0.0002893228818556676*lm + 0.00028246877360036695*lm^2) + 
        0.000013490408216428679*NM + 0.000021758680188907386*lm*NM + 
        0.00001046180642964322*lm^2*NM + 0.0000532176417464414*NL + 
        0.000021758680188907386*lm*NL + 0.00001046180642964322*lm^2*NL - 
        8.267558405721096*^-6*NH + 0.000021758680188907386*lm*NH + 
        0.00001046180642964322*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.00018570195641441013 - 0.0001820357907164265*lm - 
          0.00005444461949151481*lm^2) + CF*(0.00021662158266022458 + 
          0.00027134174321316*lm + 0.00026727358659470906*lm^2) + 
        0.000012432107130706557*NM + 0.00002049866157023941*lm*NM + 
        9.899021725729966*^-6*lm^2*NM + 0.00005023483940715663*NL + 
        0.00002049866157023941*lm*NL + 9.899021725729966*^-6*lm^2*NL - 
        7.77918654142598*^-6*NH + 0.00002049866157023941*lm*NH + 
        9.899021725729966*^-6*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.00017476096488021169 - 0.0001716964502651714*lm - 
          0.00005149208202161827*lm^2) + CF*(0.00020389314278548504 + 
          0.0002543317522447417*lm + 0.0002527793117424897*lm^2) + 
        0.000011445320540440026*NM + 0.000019302013299408754*lm*NM + 
        9.362196731203322*^-6*lm^2*NM + 0.000047397720948759514*NL + 
        0.000019302013299408754*lm*NL + 9.362196731203322*^-6*lm^2*NL - 
        7.315625477672037*^-6*NH + 0.000019302013299408754*lm*NH + 
        9.362196731203322*^-6*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.00016438291052435367 - 0.00016186406649524711*lm - 
          0.000048676377982841254*lm^2) + CF*(0.0001918180990285747 + 
          0.0002382464855198952*lm + 0.0002389567646430389*lm^2) + 
        0.000010525824199225482*NM + 0.000018165875036164305*lm*NM + 
        8.850250542334775*^-6*lm^2*NM + 0.00004469979004506204*NL + 
        0.000018165875036164305*lm*NL + 8.850250542334775*^-6*lm^2*NL - 
        6.8757665425153495*^-6*NH + 0.000018165875036164305*lm*NH + 
        8.850250542334775*^-6*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.00015454159620977335 - 0.00015251631201324462*lm - 
          0.000045991802033127385*lm^2) + CF*(0.00018036623954834985 + 
          0.0002230415464797697*lm + 0.00022577793725353442*lm^2) + 
        9.66961919260909*^-6*NM + 0.000017087507498874502*lm*NM + 
        8.36214582420498*^-6*lm^2*NM + 0.000042134829640360114*NL + 
        0.000017087507498874502*lm*NL + 8.36214582420498*^-6*lm^2*NL - 
        6.4585464505068914*^-6*NH + 0.000017087507498874502*lm*NH + 
        8.36214582420498*^-6*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.00014521197434103403 - 0.00014363179085535605*lm - 
          0.0000434328788002171*lm^2) + CF*(0.0001695086469045793 + 
          0.00020867448254034086*lm + 0.00021321595047379304*lm^2) + 
        8.87292066253417*^-6*NM + 0.00001606428754059301*lm*NM + 
        7.896887054584927*^-6*lm^2*NM + 0.0000396968901337931*NL + 
        0.00001606428754059301*lm*NL + 7.896887054584927*^-6*lm^2*NL - 
        6.062945538524786*^-6*NH + 0.00001606428754059301*lm*NH + 
        7.896887054584927*^-6*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.0001363700984570753 - 0.0001351900006777091*lm - 
          0.00004099435361738385*lm^2) + CF*(0.00015921764691845532 + 
          0.00019510470536956477*lm + 0.00020124500866715707*lm^2) + 
        8.132147072376595*^-6*NM + 0.00001509370341837068*lm*NM + 
        7.453518839524336*^-6*lm^2*NM + 0.0000373802780565676*NL + 
        0.00001509370341837068*lm*NL + 7.453518839524336*^-6*lm^2*NL - 
        5.687986067684963*^-6*NH + 0.00001509370341837068*lm*NH + 
        7.453518839524336*^-6*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.00012799307677286462 - 0.0001271712964512219*lm - 
          0.00003867118363720937*lm^2) + CF*(0.0001494667593239738 + 
          0.00018229341422946481*lm + 0.00018984035603720965*lm^2) + 
        7.44390998762504*^-6*NM + 0.000014173350248636522*lm*NM + 
        7.031124297674431*^-6*lm^2*NM + 0.000035179545222060435*NL + 
        0.000014173350248636522*lm*NL + 7.031124297674431*^-6*lm^2*NL - 
        5.332730588959038*^-6*NH + 0.000014173350248636522*lm*NH + 
        7.031124297674431*^-6*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.00012005902759738122 - 0.0001195568556028629*lm - 
          0.000036458529307732006*lm^2) + CF*(0.00014023065016255954 + 
          0.00017020352227691896*lm + 0.00017897823478341167*lm^2) + 
        6.805004348355847*^-6*NM + 0.000013300925641706508*lm*NM + 
        6.628823510496729*^-6*lm^2*NM + 0.000033089478329572946*NL + 
        0.000013300925641706508*lm*NL + 6.628823510496729*^-6*lm^2*NL - 
        4.996280370206876*^-6*NH + 0.000013300925641706508*lm*NH + 
        6.628823510496729*^-6*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.00011254703655759676 - 0.00011232864454730438*lm - 
          0.000034351746195957655*lm^2) + CF*(0.00013148508587339035 + 
          0.00015879958571974676*lm + 0.00016863584496197397*lm^2) + 
        6.212399210701762*^-6*NM + 0.000012474225508709767*lm*NM + 
        6.245772035628665*^-6*lm^2*NM + 0.00003110508900324271*NL + 
        0.000012474225508709767*lm*NL + 6.245772035628665*^-6*lm^2*NL - 
        4.677773882407924*^-6*NH + 0.000012474225508709767*lm*NH + 
        6.245772035628665*^-6*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.00010543711556032433 - 0.00010546938655499812*lm - 
          0.00003234637714435172*lm^2) + CF*(0.00012320688903207452 + 
          0.00014804773572752448*lm + 0.00015879130598136297*lm^2) + 
        5.663228935520896*^-6*NM + 0.000011691140034447195*lm*NM + 
        5.881159480791221*^-6*lm^2*NM + 0.0000292216042483279*NL + 
        0.000011691140034447195*lm*NL + 5.881159480791221*^-6*lm^2*NL - 
        4.376385342949753*^-6*NH + 0.000011691140034447195*lm*NH + 
        5.881159480791221*^-6*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.00009871016342598036 - 0.00009896253090467766*lm - 
          0.000030438144746532413*lm^2) + CF*(0.00011537389569064761 + 
          0.00013791561299937355*lm + 0.00014942361966479548*lm^2) + 
        5.154784803438722*^-6*NM + 0.000010949649809917363*lm*NM + 
        5.534208135733166*^-6*lm^2*NM + 0.00002743445730776635*NL + 
        0.000010949649809917363*lm*NL + 5.534208135733166*^-6*lm^2*NL - 
        4.091323313904584*^-6*NH + 0.000010949649809917363*lm*NH + 
        5.534208135733166*^-6*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0000923479281304434 - 0.00009279222327020507*lm - 
          0.000028622944128963128*lm^2) + CF*(0.00010796491427226639 + 
          0.00012837230489376697*lm + 0.00014051263481490992*lm^2) + 
        4.684507036362736*^-6*NM + 0.00001024782211845904*lm*NM + 
        5.204171659811478*^-6*lm^2*NM + 0.000025739278902574784*NL + 
        0.00001024782211845904*lm*NL + 5.204171659811478*^-6*lm^2*NL - 
        3.821829353294805*^-6*NH + 0.00001024782211845904*lm*NH + 
        5.204171659811478*^-6*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.000086332970593294 - 0.00008694327729353309*lm - 
          0.000026896836025994077*lm^2) + CF*(0.00010095968597447573 + 
          0.00011938828502817229*lm + 0.0001320390132185164*lm^2) + 
        4.249977206458315*^-6*NM + 9.583807369668545*^-6*lm*NM + 
        4.890333822908014*^-6*lm^2*NM + 0.000024131888840294762*NL + 
        9.583807369668545*^-6*lm*NL + 4.890333822908014*^-6*lm^2*NL - 
        3.5671767174166937*^-6*NH + 9.583807369668545*^-6*lm*NH + 
        4.890333822908014*^-6*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.00008064862995277959 - 0.00008140114729734515*lm - 
          0.000025256040136133485*lm^2) + CF*(0.00009433884663549984 + 
          0.00011093535525909427*lm + 0.00012398419703192802*lm^2) + 
        3.848911014426187*^-6*NM + 8.955835675453353*^-6*lm*NM + 
        4.592007297478816*^-6*lm^2*NM + 0.000022608287976311062*NL + 
        8.955835675453353*^-6*lm*NL + 4.592007297478816*^-6*lm^2*NL - 
        3.3266691123577203*^-6*NH + 8.955835675453353*^-6*lm*NH + 
        4.592007297478816*^-6*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.00007527899026986675 - 0.00007615190209266975*lm - 
          0.000023696928747935825*lm^2) + CF*(0.0000880838900186525 + 
          0.00010298658995578997*lm + 0.00011633037748986678*lm^2) + 
        3.4791514197385472*^-6*NM + 8.362213562781252*^-6*lm*NM + 
        4.308532499624695*^-6*lm^2*NM + 0.00002116465051346587*NL + 
        8.362213562781252*^-6*lm*NL + 4.308532499624695*^-6*lm^2*NL - 
        3.099639492907041*^-6*NH + 8.362213562781252*^-6*lm*NH + 
        4.308532499624695*^-6*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.0000702088486057157 - 0.00007118219983844149*lm - 
          0.000022216020624380844*lm^2) + CF*(0.00008217713247066279 + 
          0.00009551628248359951*lm + 0.00010906046488332414*lm^2) + 
        3.138662106272998*^-6*NM + 7.80132081787644*^-6*lm*NM + 
        4.039276477160153*^-6*lm^2*NM + 0.000019797316625968896*NL + 
        7.80132081787644*^-6*lm*NL + 4.039276477160153*^-6*lm^2*NL - 
        2.885448907121054*^-6*NH + 7.80132081787644*^-6*lm*NH + 
        4.039276477160153*^-6*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.00006542368441884078 - 0.0000664792639116006*lm - 
          0.00002080997513508286*lm^2) + CF*(0.00007660167891046564 + 
          0.00008849989381546414*lm + 0.00010215805975404314*lm^2) + 
        2.8255212675328507*^-6*NM + 7.27160745680077*^-6*lm*NM + 
        3.783631842742338*^-6*lm^2*NM + 0.000018502785394159688*NL + 
        7.27160745680077*^-6*lm*NL + 3.783631842742338*^-6*lm^2*NL - 
        2.6834853848662684*^-6*NH + 7.27160745680077*^-6*lm*NH + 
        3.783631842742338*^-6*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.0000609096302301016 - 0.00006203085974788775*lm - 
          0.00001947558662611592*lm^2) + CF*(0.00007134139010580216 + 
          0.00008191400319278518*lm + 0.00009560742525547816*lm^2) + 
        2.5379156963597117*^-6*NM + 6.771590817539544*^-6*lm*NM + 
        3.5410157502028947*^-6*lm^2*NM + 0.000017277708037214722*NL + 
        6.771590817539544*^-6*lm*NL + 3.5410157502028947*^-6*lm^2*NL - 
        2.4931628687202504*^-6*NH + 6.771590817539544*^-6*lm*NH + 
        3.5410157502028947*^-6*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0000566534435055046 - 0.00005782527261500217*lm - 
          0.00001820977901766778*lm^2) + CF*(0.0000663808511958076 + 
          0.00007573626075931196*lm + 0.00008939346063218729*lm^2) + 
        2.2741351647311953*^-6*NM + 6.299852768887189*^-6*lm*NM + 
        3.310868912303233*^-6*lm^2*NM + 0.000016118881431408805*NL + 
        6.299852768887189*^-6*lm*NL + 3.310868912303233*^-6*lm^2*NL - 
        2.3139201856681013*^-6*NH + 6.299852768887189*^-6*lm*NH + 
        3.310868912303233*^-6*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.00005264247970858044 - 0.00005385128628124998*lm - 
          0.000017009600620145086*lm^2) + CF*(0.0000617053414186281 + 
          0.00006994534209423001*lm + 0.00008350167577162133*lm^2) + 
        2.0325670798939644*^-6*NM + 5.855037031598653*^-6*lm*NM + 
        3.0926546582081974*^-6*lm^2*NM + 0.000015023241902038107*NL + 
        5.855037031598653*^-6*lm*NL + 3.0926546582081974*^-6*lm^2*NL - 
        2.145220058086837*^-6*NH + 5.855037031598653*^-6*lm*NH + 
        3.0926546582081974*^-6*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.000048864666475842056 - 0.000050098162544218*lm - 
          0.000015872219159744196*lm^2) + CF*(0.000057300805003995026 + 
          0.0000645209045730518*lm + 0.00007791816678419878*lm^2) + 
        1.8116914037113726*^-6*NM + 5.435846607437673*^-6*lm*NM + 
        2.8858580290443992*^-6*lm^2*NM + 0.00001398785927759194*NL + 
        5.435846607437673*^-6*lm*NL + 2.8858580290443992*^-6*lm^2*NL - 
        1.986548152563203*^-6*NH + 5.435846607437673*^-6*lm*NH + 
        2.8858580290443992*^-6*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.00004530847887051772 - 0.00004655562158536702*lm - 
          0.000014794917004877769*lm^2) + CF*(0.000053153823191593854 + 
          0.0000594435454872897*lm + 0.00007262959256939996*lm^2) + 
        1.610075822706785*^-6*NM + 5.0410413119131965*^-6*lm*NM + 
        2.689984909977776*^-6*lm^2*NM + 0.000013009931195222045*NL + 
        5.0410413119131965*^-6*lm*NL + 2.689984909977776*^-6*lm^2*NL - 
        1.8374121651419347*^-6*NH + 5.0410413119131965*^-6*lm*NH + 
        2.689984909977776*^-6*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.00004196291567139567 - 0.000043213823117749004*lm - 
          0.000013775086585206918*lm^2) + CF*(0.000049251587336987734 + 
          0.000054694761856212735*lm + 0.00006762315232737942*lm^2) + 
        1.4263711568592647*^-6*NM + 4.669435406650285*^-6*lm*NM + 
        2.5045611973103485*^-6*lm^2*NM + 0.00001208677764700269*NL + 
        4.669435406650285*^-6*lm*NL + 2.5045611973103485*^-6*lm^2*NL - 
        1.6973409416512828*^-6*NH + 4.669435406650285*^-6*lm*NH + 
        2.5045611973103485*^-6*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.00003881747665521082 - 0.00004006334829531696*lm - 
          0.00001281022599537344*lm^2) + CF*(0.00004558187306778963 + 
          0.00005025691186625459*lm + 0.0000628865639772878*lm^2) + 
        1.2593069957587516*^-6*NM + 4.319895327491874*^-6*lm*NM + 
        2.3291319991588072*^-6*lm^2*NM + 0.000011215835756902483*NL + 
        4.319895327491874*^-6*lm*NL + 2.3291319991588072*^-6*lm^2*NL - 
        1.5658836318008118*^-6*NH + 4.319895327491874*^-6*lm*NH + 
        2.3291319991588072*^-6*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.00003586214083255024 - 0.00003709518235351434*lm - 
          0.000011897934775856587*lm^2) + CF*(0.00004213301545371863 + 
          0.000046113177875850046*lm + 0.00005840804344511415*lm^2) + 
        1.1076875512541447*^-6*NM + 3.991337504572983*^-6*lm*NM + 
        2.1632608683375613*^-6*lm^2*NM + 0.000010394654778800342*NL + 
        3.991337504572983*^-6*lm*NL + 2.1632608683375613*^-6*lm^2*NL - 
        1.4426088757931105*^-6*NH + 3.991337504572983*^-6*lm*NH + 
        2.1632608683375613*^-6*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.00003308734559875282 - 0.00003430069795200578*lm - 
          0.000011035909863695068*lm^2) + CF*(0.00003889388515512105 + 
          0.0000422475309256294*lm + 0.00005417628478541215*lm^2) + 
        9.703877162307635*^-7*NM + 3.6827262707493003*^-6*lm*NM + 
        2.006529066126376*^-6*lm^2*NM + 9.620891306273575*^-6*NL + 
        3.6827262707493003*^-6*lm*NL + 2.006529066126376*^-6*lm^2*NL - 
        1.3271040222361229*^-6*NH + 3.6827262707493003*^-6*lm*NH + 
        2.006529066126376*^-6*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.000030483966762730697 - 0.00003167163919154249*lm - 
          0.000010221941706117697*lm^2) + CF*(0.00003585386551548286 + 
          0.00003864469669599559*lm + 0.0000501804411027596*lm^2) + 
        8.463493196344657*^-7*NM + 3.3930718548978455*^-6*lm*NM + 
        1.858534855657763*^-6*lm^2*NM + 8.892304685266612*^-6*NL + 
        3.3930718548978455*^-6*lm*NL + 1.858534855657763*^-6*lm^2*NL - 
        1.2189743761864011*^-6*NH + 3.3930718548978455*^-6*lm*NH + 
        1.858534855657763*^-6*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.000028043299418046152 - 0.00002920010627804608*
           lm - 9.453910530416182*^-6*lm^2) + CF*(0.00003300283056440415 + 
          0.00003529012285614706*lm + 0.00004641010624022489*lm^2) + 
        7.345775683191377*^-7*NM + 3.1214284567385185*^-6*lm*NM + 
        1.718892823712033*^-6*lm^2*NM + 8.206752621114476*^-6*NL + 
        3.1214284567385185*^-6*lm*NL + 1.718892823712033*^-6*lm^2*NL - 
        1.1178424761957187*^-6*NH + 3.1214284567385185*^-6*lm*NH + 
        1.718892823712033*^-6*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.000025757039621937757 - 0.00002687854080804511*lm - 
          8.729782763671273*^-6*lm^2) + CF*(0.00003033112389844561 + 
          0.0000321699477505903*lm + 0.000042855297203477156*lm^2) + 
        6.34137666733224*^-7*NM + 2.8668923999520397*^-6*lm*NM + 
        1.5872332297584132*^-6*lm^2*NM + 7.562186971746578*^-6*NL + 
        2.8668923999520397*^-6*lm*NL + 1.5872332297584132*^-6*lm^2*NL - 
        1.0233473992741974*^-6*NH + 2.8668923999520397*^-6*lm*NH + 
        1.5872332297584132*^-6*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.000023617266849305766 - 0.000024699711650609846*
           lm - 8.047607596209576*^-6*lm^2) + CF*(0.00002782953840819021 + 
          0.000029270970371110768*lm + 0.000039506437290483376*lm^2) + 
        5.441516058802594*^-7*NM + 2.6286003604921356*^-6*lm*NM + 
        1.463201381129014*^-6*lm^2*NM + 6.956649719234058*^-6*NL + 
        2.6286003604921356*^-6*lm*NL + 1.463201381129014*^-6*lm^2*NL - 
        9.351440927224495*^-7*NH + 2.6286003604921356*^-6*lm*NH + 
        1.463201381129014*^-6*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.00002161642718993847 - 0.000022656701401904755*lm - 
          7.40551368292315*^-6*lm^2) + CF*(0.00002548929682078746 + 
          0.000026580621564038913*lm + 0.00003635433989798637*lm^2) + 
        4.637951133888535*^-7*NM + 2.405727667107904*^-6*lm*NM + 
        1.3464570332587544*^-6*lm^2*NM + 6.388269112168243*^-6*NL + 
        2.405727667107904*^-6*lm*NL + 1.3464570332587544*^-6*lm^2*NL - 
        8.529027318232491*^-7*NH + 2.405727667107904*^-6*lm*NH + 
        1.3464570332587544*^-6*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0000197473172584903 - 0.000020742893389415776*lm - 
          6.801705976828051*^-6*lm^2) + CF*(0.000023302033028161706 + 
          0.000024086936424460963*lm + 0.000033390192977155886*lm^2) + 
        3.922947569100045*^-7*NM + 2.1974866712062946*^-6*lm*NM + 
        1.2366738139687365*^-6*lm^2*NM + 5.855255971669307*^-6*NL + 
        2.1974866712062946*^-6*lm*NL + 1.2366738139687365*^-6*lm^2*NL - 
        7.763081024199571*^-7*NH + 2.1974866712062946*^-6*lm*NH + 
        1.2366738139687365*^-6*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.000018003068787909386 - 0.000018951959203811654*
           lm - 6.2344626894718235*^-6*lm^2) + 
        CF*(0.00002125977417196833 + 0.000021778527830781738*lm + 
          0.00003060554411195259*lm^2) + 3.289251934247837*^-7*NM + 
        2.0031251832945895*^-6*lm*NM + 1.1335386708130588*^-6*lm^2*NM + 
        5.355900154123368*^-6*NL + 2.0031251832945895*^-6*lm*NL + 
        1.1335386708130588*^-6*lm^2*NL - 7.050590074443838*^-7*NH + 
        2.0031251832945895*^-6*lm*NH + 1.1335386708130588*^-6*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.00001637713387815817 - 0.000017277846737267108*
           lm - 5.702132373023755*^-6*lm^2) + CF*(0.000019354923457270885 + 
          0.000019644561074750497*lm + 0.000027992286194843885*lm^2) + 
        2.7300655739403585*^-7*NM + 1.8219249733488534*^-6*lm*NM + 
        1.0367513405497736*^-6*lm^2*NM + 4.888567164033414*^-6*NL + 
        1.8219249733488534*^-6*lm*NL + 1.0367513405497736*^-6*lm^2*NL - 
        6.388676964910079*^-7*NH + 1.8219249733488534*^-6*lm*NH + 
        1.0367513405497736*^-6*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.000014863270873176304 - 0.000015714768707911025*
           lm - 5.2031311190962425*^-6*lm^2) + 
        CF*(0.000017580243667787097 + 0.00001767472954371111*lm + 
          0.000025542643675563374*lm^2) + 2.239019810145101*^-7*NM + 
        1.6532003325565928*^-6*lm*NM + 9.460238398356805*^-7*lm^2*NM + 
        4.451694910645157*^-6*NL + 1.6532003325565928*^-6*lm*NL + 
        9.460238398356805*^-7*lm^2*NL - 5.774593175675202*^-7*NH + 
        1.6532003325565928*^-6*lm*NH + 9.460238398356805*^-7*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.000013455530840101767 - 0.000014257191650866664*
           lm - 4.735939869551018*^-6*lm^2) + CF*(0.000015928841356411567 + 
          0.000015859231413435864*lm + 0.00002324915935961409*lm^2) + 
        1.810152401634369*^-7*NM + 1.49629669398048*^-6*lm*NM + 
        8.610799762820034*^-7*lm^2*NM + 4.043790602273459*^-6*NL + 
        1.49629669398048*^-6*lm*NL + 8.610799762820034*^-7*lm^2*NL - 
        5.205713901835626*^-7*NH + 1.49629669398048*^-6*lm*NH + 
        8.610799762820034*^-7*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.000012148244625794486 - 0.000012899825357124073*
           lm - 4.299101834740709*^-6*lm^2) + CF*(0.000014394151685566634 + 
          0.000014188747311448753*lm + 0.00002110468173418166*lm^2) + 
        1.4378851991666196*^-7*NM + 1.3505893097850394*^-6*lm*NM + 
        7.816548790437652*^-7*lm^2*NM + 3.6634277725088918*^-6*NL + 
        1.3505893097850394*^-6*lm*NL + 7.816548790437652*^-7*lm^2*NL - 
        4.679532989703286*^-7*NH + 1.3505893097850394*^-6*lm*NH + 
        7.816548790437652*^-7*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.000010936010466698278 - 0.000011637612742228386*
           lm - 3.89122001482471*^-6*lm^2) + CF*(0.000012969923892759852 + 
          0.000012654418912240389*lm + 0.000019102352800048576*lm^2) + 
        1.1170029381465894*^-7*NM + 1.2154819827597736*^-6*lm*NM + 
        7.074945481499473*^-7*lm^2*NM + 3.30924343272756*^-6*NL + 
        1.2154819827597736*^-6*lm*NL + 7.074945481499473*^-7*lm^2*NL - 
        4.193658070533955*^-7*NH + 1.2154819827597736*^-6*lm*NH + 
        7.074945481499473*^-7*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-9.813682129032166*^-6 - 0.000010465720127482838*lm - 
          3.5109548199788593*^-6*lm^2) + CF*(0.000011650207357536217 + 
          0.0000112478284272235*lm + 0.00001723559638898713*lm^2) + 
        8.426331132667831*^-8*NM + 1.0904058499604495*^-6*lm*NM + 
        6.383554218143381*^-7*lm^2*NM + 2.979935345561048*^-6*NL + 
        1.0904058499604495*^-6*lm*NL + 6.383554218143381*^-7*lm^2*NL - 
        3.745805884298337*^-7*NH + 1.0904058499604495*^-6*lm*NH + 
        6.383554218143381*^-7*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-8.7763575572224*^-6 - 9.379527917052783*^-6*lm - 
          3.157021785491298*^-6*lm^2) + CF*(0.000010429338246805119 + 
          9.960978953676762*^-6*lm + 0.00001549810694695728*lm^2) + 
        6.102268822652861*^-8*NM + 9.74818216375247*^-7*lm*NM + 
        5.740039609984177*^-7*lm^2*NM + 2.674259414207469*^-6*NL + 
        9.74818216375247*^-7*lm*NL + 5.740039609984177*^-7*lm^2*NL - 
        3.333797786282905*^-7*NH + 9.74818216375247*^-7*lm*NH + 
        5.740039609984177*^-7*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-7.81936800937287*^-6 - 8.374621655018014*^-6*lm - 
          2.828189377902581*^-6*lm^2) + CF*(9.301926716295693*^-6 + 
          8.786275648276286*^-6*lm + 0.000013883838764249036*lm^2) + 
        4.155409484458693*^-8*NM + 8.682014366043309*^-7*lm*NM + 
        5.14216250527742*^-7*lm^2*NM + 2.391027182679613*^-6*NL + 
        8.682014366043309*^-7*lm*NL + 5.14216250527742*^-7*lm^2*NL - 
        2.955555429574256*^-7*NH + 8.682014366043309*^-7*lm*NH + 
        5.14216250527742*^-7*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-6.93826765942477*^-6 - 7.4467834470560975*^-6*lm - 
          2.5232768885067447*^-6*lm^2) + CF*(8.262844646649525*^-6 + 
          7.716507692119785*^-6*lm + 0.000012386995634487656*lm^2) + 
        2.5462037400132582*^-8*NM + 7.700618426202091*^-7*lm*NM + 
        4.5877761609213544*^-7*lm^2*NM + 2.1291034422923433*^-6*NL + 
        7.700618426202091*^-7*lm*NL + 4.5877761609213544*^-7*lm^2*NL - 
        2.609096616738072*^-7*NH + 7.700618426202091*^-7*lm*NH + 
        4.5877761609213544*^-7*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-6.12882364647776*^-6 - 6.591983732050133*^-6*lm - 
          2.241152410682034*^-6*lm^2) + CF*(7.307213893396291*^-6 + 
          6.744831015409304*^-6*lm + 0.00001100202092516635*lm^2) + 
        1.2378227846506018*^-8*NM + 6.799287157521155*^-7*lm*NM + 
        4.074822564876426*^-7*lm^2*NM + 1.8874039398890906*^-6*NL + 
        6.799287157521155*^-7*lm*NL + 4.074822564876426*^-7*lm^2*NL - 
        2.2925313142518838*^-7*NH + 6.799287157521155*^-7*lm*NH + 
        4.074822564876426*^-7*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-5.3870065525350736*^-6 - 5.806373389501351*^-6*lm - 
          1.980730897665619*^-6*lm^2) + CF*(6.4303950307757994*^-6 + 
          5.864751751175633*^-6*lm + 9.723588043085766*^-6*lm^2) + 
        1.960037879407395*^-9*NM + 5.973533011106809*^-7*lm*NM + 
        3.60132890484658*^-7*lm^2*NM + 1.664893183496822*^-6*NL + 
        5.973533011106809*^-7*lm*NL + 3.60132890484658*^-7*lm^2*NL - 
        2.0040578234901596*^-7*NH + 5.973533011106809*^-7*lm*NH + 
        3.60132890484658*^-7*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-4.708981290695441*^-6 - 5.0862761691910146*^-6*lm - 
          1.740972297526089*^-6*lm^2) + CF*(5.627976570068939*^-6 + 
          5.070110388602327*^-6*lm + 8.546591278764437*^-6*lm^2) - 
        6.110967033662035*^-9*NM + 5.219078627394365*^-7*lm*NM + 
        3.165404177320162*^-7*lm^2*NM + 1.4605823412805725*^-6*NL + 
        5.219078627394365*^-7*lm*NL + 3.165404177320162*^-7*lm^2*NL - 
        1.741959102290905*^-7*NH + 5.219078627394365*^-7*lm*NH + 
        3.165404177320162*^-7*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-4.0910983865458615*^-6 - 4.42818143007812*^-6*lm - 
          1.5208797622211715*^-6*lm^2) + CF*(4.895764633780332*^-6 + 
          4.355066597640687*^-6*lm + 7.466137014540296*^-6*lm^2) - 
        1.2130417546793615*^-8*NM + 4.53184777847321*^-7*lm*NM + 
        2.765235931311221*^-7*lm^2*NM + 1.2735272298428102*^-6*NL + 
        4.53184777847321*^-7*lm*NL + 2.765235931311221*^-7*lm^2*NL - 
        1.5045992313554052*^-7*NH + 4.53184777847321*^-7*lm*NH + 
        2.765235931311221*^-7*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-3.529885636212542*^-6 - 3.828737175940166*^-6*lm - 
          1.3194979277561182*^-6*lm^2) + CF*(4.22977306767697*^-6 + 
          3.714084697700392*^-6*lm + 6.477535281711852*^-6*lm^2) - 
        1.6372458007094377*^-8*NM + 3.907956685414244*^-7*lm*NM + 
        2.39908714137476*^-7*lm^2*NM + 1.1028263880798469*^-6*NL + 
        3.907956685414244*^-7*lm*NL + 2.39908714137476*^-7*lm^2*NL - 
        1.2904200199471386*^-7*NH + 3.907956685414244*^-7*lm*NH + 
        2.39908714137476*^-7*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-3.022040125203337*^-6 - 3.284743375764609*^-6*lm - 
          1.1359112625808738*^-6*lm^2) + CF*(3.6262139733299726*^-6 + 
          3.1419197442547875*^-6*lm + 5.576291652669744*^-6*lm^2) - 
        1.9090995279369575*^-8*NM + 3.343705695417928*^-7*lm*NM + 
        2.065293204692498*^-7*lm^2*NM + 9.476192329675249*^-7*NL + 
        3.343705695417928*^-7*lm*NL + 2.065293204692498*^-7*lm^2*NL - 
        1.0979377455625572*^-7*NH + 3.343705695417928*^-7*lm*NH + 
        2.065293204692498*^-7*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-2.5644205928249056*^-6 - 2.7931455573792704*^-6*lm - 
          9.692424814816424*^-7*lm^2) + CF*(3.0814886444309805*^-6 + 
          2.6336042082163243*^-6*lm + 4.758099454546244*^-6*lm^2) - 
        2.0520882227750895*^-8*NM + 2.8355713042031373*^-7*lm*NM + 
        1.7622590572393498*^-7*lm^2*NM + 8.070842938017486*^-7*NL + 
        2.8355713042031373*^-7*lm*NL + 1.7622590572393498*^-7*lm^2*NL - 
        9.257400224456192*^-8*NH + 2.8355713042031373*^-7*lm*NH + 
        1.7622590572393498*^-7*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-2.1540401275823203*^-6 - 2.3510286632716874*^-6*lm - 
          8.186510223350544*^-7*lm^2) + CF*(2.592178890760701*^-6 + 
          2.1844352239173733*^-6*lm + 4.018832291462994*^-6*lm^2) - 
        2.08790390944516*^-8*NM + 2.380198509636*^-7*lm*NM + 
        1.4884564042455533*^-7*lm^2*NM + 6.804375215663758*^-7*NL + 
        2.380198509636*^-7*lm*NL + 1.4884564042455533*^-7*lm^2*NL - 
        7.724827940099164*^-8*NH + 2.380198509636*^-7*lm*NH + 
        1.4884564042455533*^-7*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-1.788059179568954*^-6 - 1.955611157990881*^-6*lm - 
          6.833315832010191*^-7*lm^2) + CF*(2.1550387342750835*^-6 + 
          1.7899623824758158*^-6*lm + 3.3545368629868212*^-6*lm^2) - 
        2.0365515859998126*^-8*NM + 1.974393483154615*^-7*lm*NM + 
        1.2424210603654894*^-7*lm^2*NM + 5.669306702417845*^-7*NL + 
        1.974393483154615*^-7*lm*NL + 1.2424210603654894*^-7*lm^2*NL - 
        6.368874444172259*^-8*NH + 1.974393483154615*^-7*lm*NH + 
        1.2424210603654894*^-7*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-1.463778876431001*^-6 - 1.6042393769509712*^-6*lm - 
          5.625127173337018*^-7*lm^2) + CF*(1.7669864623446691*^-6 + 
          1.4459760482344407*^-6*lm + 2.7614260669109*^-6*lm^2) - 
        1.916449852077965*^-8*NM + 1.615116546080803*^-7*lm*NM + 
        1.0227503951521851*^-7*lm^2*NM + 4.6584974700234336*^-7*NL + 
        1.615116546080803*^-7*lm*NL + 1.0227503951521851*^-7*lm^2*NL - 
        5.1773802473955076*^-8*NH + 1.615116546080803*^-7*lm*NH + 
        1.0227503951521851*^-7*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-1.1786346300447425*^-6 - 1.2943821068651657*^-6*lm - 
          4.554554837891093*^-7*lm^2) + CF*(1.4250970237351403*^-6 + 
          1.1484961768394236*^-6*lm + 2.2358723749647184*^-6*lm^2) - 
        1.7445262078237938*^-8*NM + 1.2994754384246765*^-7*lm*NM + 
        8.281008796165623*^-8*lm^2*NM + 3.7651352838026386*^-7*NL + 
        1.2994754384246765*^-7*lm*NL + 8.281008796165623*^-8*lm^2*NL - 
        4.138785893034582*^-8*NH + 1.2994754384246765*^-7*lm*NH + 
        8.281008796165623*^-8*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-9.301900215765176*^-7 - 1.0236253884314966*^-6*lm - 
          3.614521514026738*^-7*lm^2) + CF*(1.12659475345229*^-6 + 
          8.937616143670342*^-7*lm + 1.774401470522217*^-6*lm^2) - 
        1.5363072899169698*^-8*NM + 1.0247188682824843*^-7*lm*NM + 
        6.571857298230432*^-8*lm^2*NM + 2.9827213959714374*^-7*NL + 
        1.0247188682824843*^-7*lm*NL + 6.571857298230432*^-8*lm^2*NL - 
        3.24210637980972*^-8*NH + 1.0247188682824843*^-7*lm*NH + 
        6.571857298230432*^-8*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-7.161309531060609*^-7 - 7.896675322689607*^-7*lm - 
          2.798249540011632*^-7*lm^2) + CF*(8.688464130928277*^-7 + 
          6.782198577202807*^-7*lm + 1.3736861378238919*^-6*lm^2) - 
        1.306004297812609*^-8*NM + 7.882303304036831*^-8*lm*NM + 
        5.087726436384785*^-8*lm^2*NM + 2.30505694383133*^-7*NL + 
        7.882303304036831*^-8*lm*NL + 5.087726436384785*^-8*lm^2*NL - 
        2.4769066035066892*^-8*NH + 7.882303304036831*^-8*lm*NH + 
        5.087726436384785*^-8*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-5.342600544842071*^-7 - 5.903143394649619*^-7*lm - 
          2.0992489480039762*^-7*lm^2) + CF*(6.493545338439782*^-7 + 
          4.985172572994831*^-7*lm + 1.0305403926564974*^-6*lm^2) - 
        1.0665938510476816*^-8*NM + 5.8752218296016765*^-8*lm*NM + 
        3.816816269098139*^-8*lm^2*NM + 1.7262299271728806*^-7*NL + 
        5.8752218296016765*^-8*lm*NL + 3.816816269098139*^-8*lm^2*NL - 
        1.8332777780616896*^-8*NH + 5.8752218296016765*^-8*lm*NH + 
        3.816816269098139*^-8*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-3.824913345666857*^-7 - 4.234745184428086*^-7*lm - 
          1.5113059802377024*^-7*lm^2) + CF*(4.657510497600351*^-7 + 
          3.5148964370375246*^-7*lm + 7.419138448439631*^-7*lm^2) - 
        8.298945068078985*^-9*NM + 4.202299719897704*^-8*lm*NM + 
        2.747829054977641*^-8*lm^2*NM + 1.2406027403152593*^-7*NL + 
        4.202299719897704*^-8*lm*NL + 2.747829054977641*^-8*lm^2*NL - 
        1.3018147983710202*^-8*NH + 4.202299719897704*^-8*lm*NH + 
        2.747829054977641*^-8*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-2.588450664175568*^-7 - 2.871552901919797*^-7*lm - 
          1.0284720585660672*^-7*lm^2) + CF*(3.157912094132665*^-7 + 
          2.341533609450317*^-7*lm + 5.048862832960694*^-7*lm^2) - 
        6.0663915583868134*^-9*NM + 2.8410699340814587*^-8*lm*NM + 
        1.8699491973928497*^-8*lm^2*NM + 8.428002352484666*^-8*NL + 
        2.8410699340814587*^-8*lm*NL + 1.8699491973928497*^-8*lm^2*NL - 
        8.735945085007954*^-9*NH + 2.8410699340814587*^-8*lm*NH + 
        1.8699491973928497*^-8*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-1.6144289650948586*^-7 - 1.7945817422453026*^-7*lm - 
          6.450531892810939*^-8*lm^2) + CF*(1.9734775447018345*^-7 + 
          1.436966893536834*^-7*lm + 3.1666247473799154*^-7*lm^2) - 
        4.06543504200118*^-9*NM + 1.7701908288864486*^-8*lm*NM + 
        1.1728239805110798*^-8*lm^2*NM + 5.27698293343493*^-8*NL + 
        1.7701908288864486*^-8*lm*NL + 1.1728239805110798*^-8*lm^2*NL - 
        5.401548403439157*^-9*NH + 1.7701908288864486*^-8*lm*NH + 
        1.1728239805110798*^-8*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-8.850316836419642*^-8 - 9.85749479288414*^-8*lm - 
          3.555997858614986*^-8*lm^2) + CF*(1.0840535418253584*^-7 + 
          7.74716420255086*^-8*lm + 1.7456716760473568*^-7*lm^2) - 
        2.3837083828442416*^-9*NM + 9.693962429936487*^-9*lm*NM + 
        6.465450652027247*^-9*lm^2*NM + 2.9041288405205167*^-8*NL + 
        9.693962429936487*^-9*lm*NL + 6.465450652027247*^-9*lm^2*NL - 
        2.9347478909270473*^-9*NH + 9.693962429936487*^-9*lm*NH + 
        6.465450652027247*^-9*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-3.833645147574171*^-8 - 4.278377228745339*^-8*lm - 
          1.5489689300640175*^-8*lm^2) + CF*(4.7055285205869705*^-8 + 
          3.2986119305470676*^-8*lm + 7.604029293041541*^-8*lm^2) - 
        1.0999326091202984*^-9*NM + 4.194476776083055*^-9*lm*NM + 
        2.816307145570941*^-9*lm^2*NM + 1.2628958993346813*^-8*NL + 
        4.194476776083055*^-9*lm*NL + 2.816307145570941*^-9*lm^2*NL - 
        1.2595519316796371*^-9*NH + 4.194476776083055*^-9*lm*NH + 
        2.816307145570941*^-9*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-9.341266742335117*^-9 - 1.0445477209424497*^-8*lm - 
          3.795479598752816*^-9*lm^2) + CF*(1.1490346567429754*^-8 + 
          7.896406424157076*^-9*lm + 1.8632354393877462*^-8*lm^2) - 
        2.8449577176720115*^-10*NM + 1.020884874729422*^-9*lm*NM + 
        6.900871997732393*^-10*lm^2*NM + 3.0893578223510967*^-9*NL + 
        1.020884874729422*^-9*lm*NL + 6.900871997732393*^-10*lm^2*NL - 
        3.040028747038637*^-10*NH + 1.020884874729422*^-9*lm*NH + 
        6.900871997732393*^-10*lm^2*NH)}, {1., 0.}}
 
CbarLTable["v", 2, 4] = {{0., -1.7357847835717997*^-12*CF*NC*
       (3.*CF*(-1.0799698834635353*^10 - 2.098322000857385*^10*lm - 
          2.19469824*^10*lm^2) + 60.*CA*(3.243221734494542*^8 + 
          5.762396861766058*^8*lm + 1.6765056*^8*lm^2) + 
        280.*(9.*(-3.258726118232396*^6 - 1.570849550548077*^6*lm - 
            725760.*lm^2)*NM + 9.*(-3.258726118232396*^6 - 
            1.570849550548077*^6*lm - 725760.*lm^2)*NL + 
          (6.2874215955206975*^6 - 1.4137645954932693*^7*lm - 
            6.53184*^6*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.03560982181041073 - 0.058476095027134196*lm - 
          0.016841910885815835*lm^2) + CF*(0.05443163942790648 + 
          0.10924555678398483*lm + 0.11023796216170365*lm^2) + 
        0.014195386165274316*NM + 0.0067347155850752795*lm*NM + 
        0.0030621656156028794*lm^2*NM + 0.014197464200314763*NL + 
        0.0067347155850752795*lm*NL + 0.0030621656156028794*lm^2*NL - 
        0.0029576785546773397*NH + 0.0067347155850752795*lm*NH + 
        0.0030621656156028794*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.03716792077466461 - 0.056879286491735896*lm - 
          0.01621675287206964*lm^2) + CF*(0.0528539716660543 + 
          0.10894607857717346*lm + 0.10614601879900128*lm^2) + 
        0.014081549973123986*NM + 0.00658905142479537*lm*NM + 
        0.0029485005221944797*lm^2*NM + 0.014091283236540774*NL + 
        0.00658905142479537*lm*NL + 0.0029485005221944797*lm^2*NL - 
        0.0028584370407626924*NH + 0.00658905142479537*lm*NH + 
        0.0029485005221944797*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.038406078782260704 - 0.05523573374011146*lm - 
          0.015592657338285092*lm^2) + CF*(0.05147326863761029 + 
          0.10832338390444683*lm + 0.10206102985059333*lm^2) + 
        0.013910997025707297*NM + 0.0064346424529790865*lm*NM + 
        0.002835028606960926*lm^2*NM + 0.013934316744346139*NL + 
        0.0064346424529790865*lm*NL + 0.002835028606960926*lm^2*NL - 
        0.0027591244368106956*NH + 0.0064346424529790865*lm*NH + 
        0.002835028606960926*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.03933009440211604 - 0.05355899500981298*lm - 
          0.014974815065455607*lm^2) + CF*(0.05024299091317437 + 
          0.10738192102604638*lm + 0.09801697133752761*lm^2) + 
        0.01368907760168808*NM + 0.0062727526312655255*lm*NM + 
        0.002722693648264656*lm^2*NM + 0.01373136963027047*NL + 
        0.0062727526312655255*lm*NL + 0.002722693648264656*lm^2*NL - 
        0.0026604530811642456*NH + 0.0062727526312655255*lm*NH + 
        0.002722693648264656*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.03996173114967486 - 0.051861598250531285*lm - 
          0.014366919838231258*lm^2) + CF*(0.04912231669353598 + 
          0.1061437052255897*lm + 0.09403802075933188*lm^2) + 
        0.013422801700627335*NM + 0.006104805008605066*lm*NM + 
        0.002612167243314774*lm^2*NM + 0.013488602996490951*NL + 
        0.006104805008605066*lm*NL + 0.002612167243314774*lm^2*NL - 
        0.002562947033714509*NH + 0.006104805008605066*lm*NH + 
        0.002612167243314774*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.040328452430834216 - 0.05015466071903229*lm - 
          0.01377165698529868*lm^2) + CF*(0.04807825322388277 + 
          0.1046378951517493*lm + 0.09014175481286409*lm^2) + 
        0.013119364868449706*NM + 0.005932199506035928*lm*NM + 
        0.002503937633690669*lm^2*NM + 0.01321228228399681*NL + 
        0.005932199506035928*lm*NL + 0.002503937633690669*lm^2*NL - 
        0.0024670017099828593*NH + 0.005932199506035928*lm*NH + 
        0.002503937633690669*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.04045916571933207 - 0.048447867436758586*lm - 
          0.013190982930718034*lm^2) + CF*(0.04708503194254742 + 
          0.10289611199216418*lm + 0.08634097918288168*lm^2) + 
        0.012785597278978895*NM + 0.005756244310318876*lm*NM + 
        0.0023983605328578243*lm^2*NM + 0.012908327939780345*NL + 
        0.005756244310318876*lm*NL + 0.0023983605328578243*lm^2*NL - 
        0.0023729180611638894*NH + 0.005756244310318876*lm*NH + 
        0.0023983605328578243*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.040382230701883154 - 0.04674955814361372*lm - 
          0.012626306159831933*lm^2) + CF*(0.04612299628753682 + 
          0.10095006979894479*lm + 0.08264491304617265*lm^2) + 
        0.012427748703438445*NM + 0.0055781298073075015*lm*NM + 
        0.002295692029060351*lm^2*NM + 0.012582148466849514*NL + 
        0.0055781298073075015*lm*NL + 0.002295692029060351*lm^2*NL - 
        0.002280924771361387*NH + 0.0055781298073075015*lm*NH + 
        0.002295692029060351*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.04012449493981259 - 0.045066847721627334*lm - 
          0.012078613160384078*lm^2) + CF*(0.04517749485717013 + 
          0.0988303184741664*lm + 0.07906001341342306*lm^2) + 
        0.012051418630660591*NM + 0.0053989213337607206*lm*NM + 
        0.002196111483706196*lm^2*NM + 0.012238591727743785*NL + 
        0.0053989213337607206*lm*NL + 0.002196111483706196*lm^2*NL - 
        0.002191193782220396*NH + 0.0053989213337607206*lm*NH + 
        0.002196111483706196*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.039710846939726596 - 0.043405752834996716*lm - 
          0.011548560321025173*lm^2) + CF*(0.04423790801000099 + 
          0.0965655802851482*lm + 0.07559057664671022*lm^2) + 
        0.01166155441063104*NM + 0.0052195609370349*lm*NM + 
        0.0020997382401863954*lm^2*NM + 0.011881949913678407*NL + 
        0.0052195609370349*lm*NL + 0.0020997382401863954*lm^2*NL - 
        0.0021038516977551973*NH + 0.0052195609370349*lm*NH + 
        0.0020997382401863954*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.03916404603923846 - 0.04177131404100138*lm - 
          0.011036543239298428*lm^2) + CF*(0.04329682844279233 + 
          0.09418242359712135*lm + 0.07223919211177153*lm^2) + 
        0.011262481996539035*NM + 0.005040873538856813*lm*NM + 
        0.002006644225326987*lm^2*NM + 0.011515989286982572*NL + 
        0.005040873538856813*lm*NL + 0.002006644225326987*lm^2*NL - 
        0.0020189884589355525*NH + 0.005040873538856813*lm*NH + 
        0.002006644225326987*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.038504705053213746 - 0.040167709174582636*lm - 
          0.010542750259735327*lm^2) + CF*(0.042349384453463396 + 
          0.09170513558586388*lm + 0.06900709260917669*lm^2) + 
        0.010857951666764568*NM + 0.004863575161720899*lm*NM + 
        0.0019168636835882413*lm^2*NM + 0.01114399069899363*NL + 
        0.004863575161720899*lm*NL + 0.0019168636835882413*lm^2*NL - 
        0.0019366641130061754*NH + 0.004863575161720899*lm*NH + 
        0.0019168636835882413*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.03775135762962653 - 0.03859835663288899*lm - 
          0.010067204576198306*lm^2) + CF*(0.04139268642067281 + 
          0.08915571455387115*lm + 0.065894429953298*lm^2) + 
        0.010451189530678338*NM + 0.004688281965206655*lm*NM + 
        0.0018304008320360558*lm^2*NM + 0.010768793771834288*NL + 
        0.004688281965206655*lm*NL + 0.0018304008320360558*lm^2*NL - 
        0.0018569142000036843*NH + 0.004688281965206655*lm*NH + 
        0.0018304008320360558*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.03692057133770821 - 0.037066008456972076*lm - 
          0.009609797793863156*lm^2) + CF*(0.040425376644283036 + 
          0.086553934156866*lm + 0.06290049465074066*lm^2) + 
        0.010044949905896163*NM + 0.004515519403514193*lm*NM + 
        0.0017472359625205736*lm^2*NM + 0.01039284105634023*NL + 
        0.004515519403514193*lm*NL + 0.0017472359625205736*lm^2*NL - 
        0.0017797541043500125*NH + 0.004515519403514193*lm*NH + 
        0.0017472359625205736*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.03602708351169251 - 0.03557283368051699*lm - 
          0.00917031696342678*lm^2) + CF*(0.03944726474929702 + 
          0.08391744993252753*lm + 0.06002389285152075*lm^2) + 
        0.009641565949868992*NM + 0.004345731123929123*lm*NM + 
        0.0016673303569866875*lm^2*NM + 0.010018220271537355*NL + 
        0.004345731123929123*lm*NL + 0.0016673303569866875*lm^2*NL - 
        0.0017051826126104233*NH + 0.004345731123929123*lm*NH + 
        0.0016673303569866875*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.035083946083471276 - 0.03412049265752799*lm - 
          0.008748466532184994*lm^2) + CF*(0.03845903347159373 + 
          0.08126192933073272*lm + 0.05726269002884723*lm^2) + 
        0.009242997204075192*NM + 0.004179287401358976*lm*NM + 
        0.0015906302785790897*lm^2*NM + 0.009646703704444337*NL + 
        0.004179287401358976*lm*NL + 0.0015906302785790897*lm^2*NL - 
        0.0016331848500435767*NH + 0.004179287401358976*lm*NH + 
        0.0015906302785790897*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.03410267112507166 - 0.03271020316139648*lm - 
          0.00834388627672059*lm^2) + CF*(0.03746200215534082 + 
          0.07860119314107483*lm + 0.05461452835671658*lm^2) + 
        0.00885087343429957*NM + 0.004016493006632612*lm*NM + 
        0.0015170702321310162*lm^2*NM + 0.009279784388929246*NL + 
        0.004016493006632612*lm*NL + 0.0015170702321310162*lm^2*NL - 
        0.0015637347229497227*NH + 0.004016493006632612*lm*NH + 
        0.0015170702321310162*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.03309337217816889 - 0.03134279904867863*lm - 
          0.007956166019385594*lm^2) + CF*(0.036457937493820355 + 
          0.07594736048314696*lm + 0.05207672303597844*lm^2) + 
        0.008466534567031081*NM + 0.0038575944671746546*lm*NM + 
        0.00144657563988829*lm^2*NM + 0.008918708984009807*NL + 
        0.0038575944671746546*lm*NL + 0.00144657563988829*lm^2*NL - 
        0.0014967969624162588*NH + 0.0038575944671746546*lm*NH + 
        0.00144657563988829*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.03206489853975936 - 0.030018782243418494*lm - 
          0.007584857744213821*lm^2) + CF*(0.0354489029030191 + 
          0.07331099230915117*lm + 0.04964634159849046*lm^2) + 
        0.00809106676010519*NM + 0.0037027867150183466*lm*NM + 
        0.001379065044402513*lm^2*NM + 0.008564507438697803*NL + 
        0.0037027867150183466*lm*NL + 0.001379065044402513*lm^2*NL - 
        0.0014323288428310756*NH + 0.0037027867150183466*lm*NH + 
        0.001379065044402513*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.031024960992830326 - 0.028738368743234956*lm - 
          0.007229485592178963*lm^2) + CF*(0.034437139457094666 + 
          0.07070123021496218*lm + 0.04732026933062594*lm^2) + 
        0.007725334778351898*NM + 0.0035522191385963476*lm*NM + 
        0.0013144519258507206*lm^2*NM + 0.008218019619140338*NL + 
        0.0035522191385963476*lm*NL + 0.0013144519258507206*lm^2*NL - 
        0.0013702816324209215*NH + 0.0035522191385963476*lm*NH + 
        0.0013144519258507206*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.029980248307708058 - 0.027501529287759844*lm - 
          0.006889554114931488*lm^2) + CF*(0.03342497258089043 + 
          0.068125928595582*lm + 0.045095263297733376*lm^2) + 
        0.007370010914424708*NM + 0.0034060010670465693*lm*NM + 
        0.001252646202714816*lm^2*NM + 0.007879919116728008*NL + 
        0.0034060010670465693*lm*NL + 0.001252646202714816*lm^2*NL - 
        0.001310601821146653*NH + 0.0034060010670465693*lm*NH + 
        0.001252646202714816*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.02893653436891896 - 0.02630802526915219*lm - 
          0.0065645550899692245*lm^2) + CF*(0.032414739732341186 + 
          0.06559177901966122*lm + 0.04296799695252583*lm^2) + 
        0.007025600726258184*NM + 0.003264206722332313*lm*NM + 
        0.0011935554709034952*lm^2*NM + 0.007550734471862015*NL + 
        0.003264206722332313*lm*NL + 0.0011935554709034952*lm^2*NL - 
        0.0012532321622989416*NH + 0.003264206722332313*lm*NH + 
        0.0011935554709034952*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.02789877611260952 - 0.025157440406245554*lm - 
          0.006253973141715853*lm^2) + CF*(0.031408735157501685 + 
          0.06310442626673413*lm + 0.04093509692759467*lm^2) + 
        0.006692465870929888*NM + 0.0031268796774327136*lm*NM + 
        0.0011370860257665187*lm^2*NM + 0.007230868048400197*NL + 
        0.0031268796774327136*lm*NL + 0.0011370860257665187*lm^2*NL - 
        0.0011981125572535516*NH + 0.0031268796774327136*lm*NH + 
        0.0011370860257665187*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.026871202659807965 - 0.02404920864978279*lm - 
          0.005957290367472145*lm^2) + CF*(0.03040916849745489 + 
          0.06066857585574549*lm + 0.03899317331436313*lm^2) + 
        0.006370844309440019*NM + 0.0029940368595537297*lm*NM + 
        0.0010831437031767538*lm^2*NM + 0.0069206127851942825*NL + 
        0.0029940368595537297*lm*NL + 0.0010831437031767538*lm^2*NL - 
        0.0011451808074963712*NH + 0.0029940368595537297*lm*NH + 
        0.0010831437031767538*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.02585739614560686 - 0.02298263873667814*lm - 
          0.00567399013136323*lm^2) + CF*(0.029418134597919303 + 
          0.058288093151407774*lm + 0.037138844496195686*lm^2) + 
        0.006060868143887603*NM + 0.0028656721366012283*lm*NM + 
        0.001031634569338769*lm^2*NM + 0.006620167037702658*NL + 
        0.0028656721366012283*lm*NL + 0.001031634569338769*lm^2*NL - 
        0.001094373253819192*NH + 0.0028656721366012283*lm*NH + 
        0.001031634569338769*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.024860364802889105 - 0.02195693576638419*lm - 
          0.0054035601608774415*lm^2) + CF*(0.028437592342120302 + 
          0.05596609430456285*lm + 0.035368757416652345*lm^2) + 
        0.005762579331355992*NM + 0.0027417595236023454*lm*NM + 
        0.0009824654837958984*lm^2*NM + 0.0063296477069283335*NL + 
        0.0027417595236023454*lm*NL + 0.0009824654837958984*lm^2*NL - 
        0.0010456253192368805*NH + 0.0027417595236023454*lm*NH + 
        0.0009824654837958984*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.023882608880876035 - 0.020971220132052777*lm - 
          0.005145495057672382*lm^2) + CF*(0.027469350714174046 + 
          0.05370502939057494*lm + 0.03367960401385559*lm^2) + 
        0.005475943499803933*NM + 0.0026222560437217718*lm*NM + 
        0.0009355445559404332*lm^2*NM + 0.0060491018364190255*NL + 
        0.0026222560437217718*lm*NL + 0.0009355445559404332*lm^2*NL - 
        0.0009988719694823578*NH + 0.0026222560437217718*lm*NH + 
        0.0009355445559404332*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.02292617997651794 - 0.020024544102968885*lm - 
          0.004899298315755422*lm^2) + CF*(0.02651506061902971 + 
          0.05150675817431366*lm + 0.032068134430399124*lm^2) + 
        0.005200862071821883*NM + 0.0025071042762327576*lm*NM + 
        0.0008907815119555312*lm^2*NM + 0.005778516841691161*NL + 
        0.0025071042762327576*lm*NL + 0.0008907815119555312*lm^2*NL - 
        0.0009540481027490372*NH + 0.0025071042762327576*lm*NH + 
        0.0008907815119555312*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.021992734339324825 - 0.01911590632235922*lm - 
          0.004664483924991245*lm^2) + CF*(0.02557621124821547 + 
          0.04937261896446866*lm + 0.030531167509033598*lm^2) + 
        0.004937182883171332*NM + 0.0023962346214227107*lm*NM + 
        0.0008480879863620444*lm^2*NM + 0.005517829520733582*NL + 
        0.0023962346214227107*lm*NL + 0.0008480879863620444*lm^2*NL - 
        0.0009110888785605952*NH + 0.0023962346214227107*lm*NH + 
        0.0008480879863620444*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.02108358068358161 - 0.018244264455776777*lm - 
          0.004440577625438596*lm^2) + CF*(0.024654129998216007 + 
          0.0473034910329617*lm + 0.02906559900287081*lm^2) + 
        0.004684709465227309*NM + 0.002289567310039739*lm*NM + 
        0.0008073777500797447*lm^2*NM + 0.0052669339795000086*NL + 
        0.002289567310039739*lm*NL + 0.0008073777500797447*lm^2*NL - 
        0.0008699299941719534*NH + 0.002289567310039739*lm*NH + 
        0.0008073777500797447*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.020199723010042494 - 0.017408546199493603*lm - 
          0.004227117867729258*lm^2) + CF*(0.02374998512841809 + 
          0.04529985107364414*lm + 0.0276684078615006*lm^2) + 
        0.004443209144422833*NM + 0.002187014182582149*lm*NM + 
        0.0007685668850416833*lm^2*NM + 0.005025688592650339*NL + 
        0.002187014182582149*lm*NL + 0.0007685668850416833*lm^2*NL - 
        0.000830507915679728*NH + 0.002187014182582149*lm*NH + 
        0.0007685668850416833*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.019341898904907857 - 0.01660765883537187*lm - 
          0.004023656526154403*lm^2) + CF*(0.022864790494885046 + 
          0.04336182416298445*lm + 0.02633666089846518*lm^2) + 
        0.004212420098500431*NM + 0.0020884802615360153*lm*NM + 
        0.000731573913846255*lm^2*NM + 0.004793922107293794*NL + 
        0.0020884802615360153*lm*NL + 0.000731573913846255*lm^2*NL - 
        0.0007927600699962981*NH + 0.0020884802615360153*lm*NH + 
        0.000731573913846255*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.01851061374903435 - 0.015840497498229324*lm - 
          0.0038297594039886965*lm^2) + CF*(0.02199941182028762 + 
          0.041489229667436664*lm + 0.025067516098835105*lm^2) + 
        0.003992057500649808*NM + 0.0019938651375980302*lm*NM + 
        0.0006963198916343085*lm^2*NM + 0.004571438986108439*NL + 
        0.0019938651375980302*lm*NL + 0.0006963198916343085*lm^2*NL - 
        0.0007566250029810643*NH + 0.0019938651375980302*lm*NH + 
        0.0006963198916343085*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.017706171236167814 - 0.01510595230349846*lm - 
          0.0036450065646021577*lm^2) + CF*(0.021154574063663497 + 
          0.03968162252006231*lm + 0.02385822478648685*lm^2) + 
        0.0037818188821936213*NM + 0.001903064188992609*lm*NM + 
        0.0006627284662913014*lm^2*NM + 0.004358024075914252*NL + 
        0.001903064188992609*lm*NL + 0.0006627284662913014*lm^2*NL - 
        0.000722042508295532*NH + 0.001903064188992609*lm*NH + 
        0.0006627284662913014*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.016928700566208682 - 0.014402914466754221*lm - 
          0.003468992516878065*lm^2) + CF*(0.020330869539776388 + 
          0.037938330264495425*lm + 0.022706132837747334*lm^2) + 
        0.0035813888597830907*NM + 0.00181596965120667*lm*NM + 
        0.0006307259121596481*lm^2*NM + 0.004153446678494477*NL + 
        0.00181596965120667*lm*NL + 0.0006307259121596481*lm^2*NL - 
        0.0006889537309319168*NH + 0.00181596965120667*lm*NH + 
        0.0006307259121596481*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.01617818064802042 - 0.013730281532234543*lm - 
          0.003301326279207567*lm^2) + CF*(0.019528766508546735 + 
          0.03625848623873462*lm + 0.021608681100267712*lm^2) + 
        0.003390443418041751*NM + 0.0017324715528210584*lm*NM + 
        0.0006002411416741031*lm^2*NM + 0.003957464092117297*NL + 
        0.0017324715528210584*lm*NL + 0.0006002411416741031*lm^2*NL - 
        0.0006573012488391273*NH + 0.0017324715528210584*lm*NH + 
        0.0006002411416741031*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.015454461614419665 - 0.013086961814605148*lm - 
          0.0031416313427349812*lm^2) + CF*(0.018748618008961472 + 
          0.03464105924539702*lm + 0.020563405152447152*lm^2) + 
        0.0032086540380349754*NM + 0.0016524585316093701*lm*NM + 
        0.0005712056986790875*lm^2*NM + 0.003769824684728443*NL + 
        0.0016524585316093701*lm*NL + 0.0005712056986790875*lm^2*NL - 
        0.0006270291356200189*NH + 0.0016524585316093701*lm*NH + 
        0.0005712056986790875*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.014757283914798698 - 0.012471878146751431*lm - 
          0.0029895455514742995*lm^2) + CF*(0.01799067074094477 + 
          0.033084880029587885*lm + 0.019567934518740872*lm^2) + 
        0.0030356921568354756*NM + 0.00157581854369629*lm*NM + 
        0.0005435537366316909*lm^2*NM + 0.003590270553088153*NL + 
        0.00157581854369629*lm*NL + 0.0005435537366316909*lm^2*NL - 
        0.0005980830068874155*NH + 0.00157581854369629*lm*NH + 
        0.0005435537366316909*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.014086295196741951 - 0.01188397101616039*lm - 
          0.0028447209143189355*lm^2) + CF*(0.0172550737813512 + 
          0.031588664860845626*lm + 0.018619991439178488*lm^2) + 
        0.0028712347956041783*NM + 0.0015024394773107304*lm*NM + 
        0.0005172219844216246*lm^2*NM + 0.0034185398161385256*NL + 
        0.0015024394773107304*lm*NL + 0.0005172219844216246*lm^2*NL - 
        0.0005704100525334835*NH + 0.0015024394773107304*lm*NH + 
        0.0005172219844216246*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.013441058157209963 - 0.011322201163347312*lm - 
          0.0027068233617508416*lm^2) + CF^2*(0.016541872938405783 + 
          0.030151036491988987*lm + 0.0177173892769146*lm^2) + 
        CF*((0.002714824190910281 + 0.0014322096815257627*lm + 
            0.0004921497021365167*lm^2)*NM + (0.0032543685855402214 + 
            0.0014322096815257627*lm + 0.0004921497021365167*lm^2)*NL + 
          (-0.0005439590568793799 + 0.0014322096815257627*lm + 
            0.0004921497021365167*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.01282108733253052 - 0.010785551707662813*lm - 
          0.0025755324581620415*lm^2) + CF^2*(0.015851066196182553 + 
          0.02877054274529368*lm + 0.016858030635242455*lm^2) + 
        CF*((0.0025663008519284025 + 0.0013650184193392124*lm + 
            0.0004682786287567348*lm^2)*NM + (0.0030974926515459997 + 
            0.0013650184193392124*lm + 0.0004682786287567348*lm^2)*NL + 
          (-0.0005186804084228572 + 0.0013650184193392124*lm + 
            0.0004682786287567348*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.012225830303884145 - 0.01027302985857703*lm - 
          0.0024505410790817855*lm^2) + CF^2*(0.015182550776943344 + 
          0.027445672955349585*lm + 0.01603990524489896*lm^2) + 
        CF*((0.0024252736170576987 + 0.0013007562535074766*lm + 
            0.00044555292346941557*lm^2)*NM + (0.0029476489181235305 + 
            0.0013007562535074766*lm + 0.00044555292346941557*lm^2)*NL + 
          (-0.0004945261006850147 + 0.0013007562535074766*lm + 
            0.00044555292346941557*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.011654695778683756 - 0.009783668264083986*lm - 
          0.002331555061214586*lm^2) + CF^2*(0.014536166370301983 + 
          0.026174872478246743*lm + 0.01526108767340456*lm^2) + 
        CF*((0.0022914234906494853 + 0.0012393153726928867*lm + 
            0.00042391910203901556*lm^2)*NM + (0.0028045766174472995 + 
            0.0012393153726928867*lm + 0.00042391910203901556*lm^2)*NL + 
          (-0.0004714497254688823 + 0.0012393153726928867*lm + 
            0.00042391910203901556*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.011107058593242247 - 0.009316526042113017*lm - 
          0.0022182928320038666*lm^2) + CF^2*(0.013911694295273575 + 
          0.02495655545839596*lm + 0.014519734900388943*lm^2) + 
        CF*((0.0021644383598264146 + 0.0011805898647138686*lm + 
            0.00040332596945524845*lm^2)*NM + (0.002668018330500345 + 
            0.0011805898647138686*lm + 0.00040332596945524845*lm^2)*NL + 
          (-0.0004494064596785997 + 0.0011805898647138686*lm + 
            0.00040332596945524845*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.01058226758736583 - 0.008870689535701455*lm - 
          0.002110485024413779*lm^2) + CF^2*(0.013308864212990474 + 
          0.02378911602729319*lm + 0.013814083796162918*lm^2) + 
        CF*((0.0020440137730810804 + 0.0011244759429904644*lm + 
            0.0003837245498934144*lm^2)*NM + (0.0025377208375169337 + 
            0.0011244759429904644*lm + 0.0003837245498934144*lm^2)*NL + 
          (-0.0004283530467018087 + 0.0011244759429904644*lm + 
            0.0003837245498934144*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.010079652484044474 - 0.008445272828104523*lm - 
          0.002007874081743495*lm^2) + CF^2*(0.012727360409057432 + 
          0.022670938092833173*lm + 0.013142448535048331*lm^2) + 
        CF*((0.0019298535521683029 + 0.0010708721316486085*lm + 
            0.0003650680148624537*lm^2)*NM + (0.0024134358193174223 + 
            0.0010708721316486085*lm + 0.0003650680148624537*lm^2)*NL + 
          (-0.0004082477732406858 + 0.0010708721316486085*lm + 
            0.0003650680148624537*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.009598529882411432 - 0.008039418049935243*lm - 
          0.0019102138565333408*lm^2) + CF^2*(0.012166827646145868 + 
          0.021600403863311548*lm + 0.012503217970036413*lm^2) + 
        CF*((0.0018216702593702864 + 0.0010196794141788578*lm + 
            0.00034731161027878925*lm^2)*NM + (0.0022949204282008964 + 
            0.0010196794141788578*lm + 0.00034731161027878925*lm^2)*NL + 
          (-0.0003890504423495555 + 0.0010196794141788578*lm + 
            0.00034731161027878925*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.009138208460902434 - 0.0076522955067853966*lm - 
          0.001817269206972968*lm^2) + CF^2*(0.011626876592631064 + 
          0.02057590123695993*lm + 0.011894852991095791*lm^2) + 
        CF*((0.0017191855405979041 + 0.0009708013500333522*lm + 
            0.0003304125830859942*lm^2)*NM + (0.0021819377449378364 + 
            0.0009708013500333522*lm + 0.0003304125830859942*lm^2)*NL + 
          (-0.0003707223433622961 + 0.0009708013500333522*lm + 
            0.0003304125830859942*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.008697993477864173 - 0.007283103652530572*lm - 
          0.0017288155936634928*lm^2) + CF^2*(0.011107088837947138 + 
          0.019595830175664873*lm + 0.011315883885797406*lm^2) + 
        CF*((0.0016221303610936023 + 0.000924144163083428*lm + 
            0.0003143301079388169*lm^2)*NM + (0.0020742571365155666 + 
            0.000924144163083428*lm + 0.0003143301079388169*lm^2)*NL + 
          (-0.00035322621929022963 + 0.000924144163083428*lm + 
            0.0003143301079388169*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.008277190647631496 - 0.006931068930625843*lm - 
          0.0016446386791054946*lm^2) + CF^2*(0.010607021508080352 + 
          0.018658608170358436*lm + 0.010764907717781418*lm^2) + 
        CF*((0.0015302451494757351 + 0.0008796168054447496*lm + 
            0.0002990252143828172*lm^2)*NM + (0.0019716545276080993 + 
            0.0008796168054447496*lm + 0.0002990252143828172*lm^2)*NL + 
          (-0.00033652623220505116 + 0.0008796168054447496*lm + 
            0.0002990252143828172*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.00787510946205272 - 0.006595445503115864*lm - 
          0.0015645339318721447*lm^2) + CF^2*(0.010126211497094374 + 
          0.017762674895363637*lm + 0.010240585735890402*lm^2) + 
        CF*((0.0014432798634764418 + 0.0008371309998027188*lm + 
            0.0002844607148858445*lm^2)*NM + (0.001873912597246524 + 
            0.0008371309998027188*lm + 0.0002844607148858445*lm^2)*NL + 
          (-0.0003205879270531284 + 0.0008371309998027188*lm + 
            0.0002844607148858445*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.007491066020023725 - 0.006275514884780503*lm - 
          0.0014883062370722334*lm^2) + CF^2*(0.009664179331972528 + 
          0.016906496139662972*lm + 0.0097416408244728*lm^2) + 
        CF*((0.0013609939892093473 + 0.0007966012630342853*lm + 
            0.00027060113401313336*lm^2)*NM + (0.001780820910835989 + 
            0.0007966012630342853*lm + 0.00027060113401313336*lm^2)*NL + 
          (-0.0003053781942905733 + 0.0007966012630342853*lm + 
            0.00027060113401313336*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.007124385420824995 - 0.005970585497784614*lm - 
          0.0014157695144035721*lm^2) + CF^2*(0.00922043268872062 + 
          0.016088567094565253*lm + 0.009266855003368836*lm^2) + 
        CF*((0.0012831564842869063 + 0.0007579449136195166*lm + 
            0.0002574126389824676*lm^2)*NM + (0.001692175996482568 + 
            0.0007579449136195166*lm + 0.0002574126389824676*lm^2)*NL + 
          (-0.0002908652316761984 + 0.0007579449136195166*lm + 
            0.0002574126389824676*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.006774403770795741 - 0.005679992160371477*lm - 
          0.0013467463448363132*lm^2) + CF^2*(0.008794469577560913 + 
          0.015307415069511195*lm + 0.00881506698438314*lm^2) + 
        CF*((0.001209545674027598 + 0.000721082065064097*lm + 
            0.00024486297178842055*lm^2)*NM + (0.0016077813735417368 + 
            0.000721082065064097*lm + 0.00024486297178842055*lm^2)*NL + 
          (-0.0002770185055155714 + 0.000721082065064097*lm + 
            0.00024486297178842055*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.006440469847048636 - 0.005403095521509858*lm - 
          0.001281067606742295*lm^2) + CF^2*(0.008385781214229782 + 
          0.014561601700720643*lm + 0.008385169789585931*lm^2) + 
        CF*((0.0011399491084521259 + 0.0006859356073093604*lm + 
            0.00023292138304405364*lm^2)*NM + (0.001527447540365499 + 
            0.0006859356073093604*lm + 0.00023292138304405364*lm^2)*NL + 
          (-0.0002638087116094363 + 0.0006859356073093604*lm + 
            0.00023292138304405364*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.006121946456231566 - 0.005139281451953451*lm - 
          0.0012185721220955123*lm^2) + CF^2*(0.007993854592470458 + 
          0.013849724710987207*lm + 0.007976108435534262*lm^2) + 
        CF*((0.0010741633872329167 + 0.00065243117788679*lm + 
            0.0002215585676537295*lm^2)*NM + (0.0014509919273946 + 
            0.00065243117788679*lm + 0.0002215585676537295*lm^2)*NL + 
          (-0.000251207736124589 + 0.00065243117788679*lm + 
            0.0002215585676537295*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.005818211520842406 - 0.004887960400879479*lm - 
          0.001159106313205872*lm^2) + CF^2*(0.007618174770084372 + 
          0.013170419273115772*lm + 0.007586877686438435*lm^2) + 
        CF*((0.0010119939584067028 + 0.0006204971243767282*lm + 
            0.00021074660240106766*lm^2)*NM + (0.0013782388210043404 + 
            0.0006204971243767282*lm + 0.00021074660240106766*lm^2)*NL + 
          (-0.00023918861657367012 + 0.0006204971243767282*lm + 
            0.00021074660240106766*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.005528658919977486 - 0.004648566726123595*lm - 
          0.0011025238703097407*lm^2) + CF^2*(0.007258226876875273 + 
          0.012522359024225176*lm + 0.00721651987839103*lm^2) + 
        CF*((0.0009532548964699038 + 0.000590064459554102*lm + 
            0.00020045888551086197*lm^2)*NM + (0.0013090192628571434 + 
            0.000590064459554102*lm + 0.00020045888551086197*lm^2)*NL + 
          (-0.00022772550306721808 + 0.000590064459554102*lm + 
            0.00020045888551086197*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.0052526991062736795 - 0.004420558005005802*lm - 
          0.0010486854302231502*lm^2) + CF^2*(0.0069134978488792865 + 
          0.01190425677335624*lm + 0.006864122816006074*lm^2) + 
        CF*((0.0008977686635945603 + 0.0005610668104452846*lm + 
            0.00019067007822239096*lm^2)*NM + (0.001243170928933174 + 
            0.0005610668104452846*lm + 0.00019067007822239096*lm^2)*NL + 
          (-0.00021679361996854965 + 0.0005610668104452846*lm + 
            0.00019067007822239096*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.004989505783297566 - 0.0042034143318332206*lm - 
          0.0009974582661640954*lm^2) + CF^2*(0.0065829704237548945 + 
          0.011314864940491434*lm + 0.0065288177421649884*lm^2) + 
        CF*((0.0008453658592759897 + 0.000533440362377985*lm + 
            0.0001813560483934719*lm^2)*NM + (0.0011805379918939133 + 
            0.000533440362377985*lm + 0.0001813560483934719*lm^2)*NL + 
          (-0.0002063692280727205 + 0.000533440362377985*lm + 
            0.0001813560483934719*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.004739062207988009 - 0.003996637607358244*lm - 
          0.0009487159887666518*lm^2) + CF^2*(0.006267216497699872 + 
          0.010752975761167429*lm + 0.006209777381018085*lm^2) + 
        CF*((0.0007958849599576473 + 0.0005071237989786374*lm + 
            0.00017249381613939125*lm^2)*NM + (0.0011209709699754997 + 
            0.0005071237989786374*lm + 0.00017249381613939125*lm^2)*NL + 
          (-0.00019642958740130522 + 0.0005071237989786374*lm + 
            0.00017249381613939125*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.004500546766375314 - 0.0037997508247539905*lm - 
          0.0009023382582395556*lm^2) + CF^2*(0.005965169115664764 + 
          0.01021742128730937*lm + 0.005906214053931637*lm^2) + 
        CF*((0.0007491720548777065 + 0.0004820582389576879*lm + 
            0.000164061501498101*lm^2)*NM + (0.0010643265652024415 + 
            0.0004820582389576879*lm + 0.000164061501498101*lm^2)*NL + 
          (-0.00018695292069544558 + 0.0004820582389576879*lm + 
            0.000164061501498101*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.004273440797355459 - 0.003612297356033345*lm - 
          0.0008582105075635705*lm^2) + CF^2*(0.00567633902337048 + 
          0.009707073211702425*lm + 0.005617377867688825*lm^2) + 
        CF*((0.0007050805715839105 + 0.0004581871704211043*lm + 
            0.00015603827410246737*lm^2)*NM + (0.0010104674933523333 + 
            0.0004581871704211043*lm + 0.00015603827410246737*lm^2)*NL + 
          (-0.0001779183776733079 + 0.0004581871704211043*lm + 
            0.00015603827410246737*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.0040572434803685005 - 0.003433840242274672*lm - 
          0.00081622367657381*lm^2) + CF^2*(0.005400245394932183 + 
          0.009220842540611602*lm + 0.005342554973937666*lm^2) + 
        CF*((0.0006634710034569678 + 0.00043545638335517445*lm + 
            0.0001484043048316018*lm^2)*NM + (0.0009592623077833602 + 
            0.00043545638335517445*lm + 0.0001484043048316018*lm^2)*NL + 
          (-0.00016930600010233585 + 0.00043545638335517445*lm + 
            0.0001484043048316018*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.003851471823673448 - 0.0032639614905186428*lm - 
          0.0007762739567337967*lm^2) + CF^2*(0.00513641679431694 + 
          0.008757679136436814*lm + 0.005081065898621215*lm^2) + 
        CF*((0.0006242104545793277 + 0.0004138139008501143*lm + 
            0.00014114071940614487*lm^2)*NM + (0.0009105852189541569 + 
            0.0004138139008501143*lm + 0.00014114071940614487*lm^2)*NL + 
          (-0.0001610966877321715 + 0.0004138139008501143*lm + 
            0.00014114071940614487*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.003655993390660879 - 0.0031022613797597304*lm - 
          0.0007382625463762118*lm^2) + CF^2*(0.004885057632736353 + 
          0.008316571149921076*lm + 0.0048322639399170225*lm^2) + 
        CF*((0.000586469355013924 + 0.00039320990955520773*lm + 
            0.00013422955388658398*lm^2)*NM + (0.0008643159112159634 + 
            0.00039320990955520773*lm + 0.00013422955388658398*lm^2)*NL + 
          (-0.00015327216511660608 + 0.00039320990955520773*lm + 
            0.00013422955388658398*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.0034693602799426133 - 0.0029483577780665296*lm - 
          0.0007020954161599656*lm^2) + CF^2*(0.004643717142730543 + 
          0.007896544359292225*lm + 0.004595533633047047*lm^2) + 
        CF*((0.0005522392950327869 + 0.0003735966897932613*lm + 
            0.00012765371202908465*lm^2)*NM + (0.0008203393582364071 + 
            0.0003735966897932613*lm + 0.00012765371202908465*lm^2)*NL + 
          (-0.00014581494934765842 + 0.0003735966897932613*lm + 
            0.00012765371202908465*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.00329214906922706 - 0.0028018854725215944*lm - 
          0.0006676830844734779*lm^2) + CF^2*(0.004413970280019773 + 
          0.007496661431791064*lm + 0.004370289280190037*lm^2) + 
        CF*((0.0005192806316109044 + 0.0003549285457042785*lm + 
            0.00012139692444972325*lm^2)*NM + (0.000778545638219431 + 
            0.0003549285457042785*lm + 0.00012139692444972325*lm^2)*NL + 
          (-0.00013870831873463173 + 0.0003549285457042785*lm + 
            0.00012139692444972325*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.0031235889431850514 - 0.0026624955133690764*lm - 
          0.0006349404024991156*lm^2) + CF^2*(0.004194674986131788 + 
          0.0071160211213020345*lm + 0.004155973543630575*lm^2) + 
        CF*((0.00048823072486215617 + 0.0003371617357367309*lm + 
            0.00011544370954529375*lm^2)*NM + (0.0007388297499140437 + 
            0.0003371617357367309*lm + 0.00011544370954529375*lm^2)*NL + 
          (-0.00013193628240133935 + 0.0003371617357367309*lm + 
            0.00011544370954529375*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.002963305067581699 - 0.002529854573492553*lm - 
          0.0006037863486428776*lm^2) + CF^2*(0.003985459930282046 + 
          0.006753757414238409*lm + 0.003952056100207926*lm^2) + 
        CF*((0.00045894551948253803 + 0.00032025440375897185*lm + 
            0.00010977933611688684*lm^2)*NM + (0.0007010914302531348 + 
            0.00032025440375897185*lm + 0.00010977933611688684*lm^2)*NL + 
          (-0.00012548355085300646 + 0.00032025440375897185*lm + 
            0.00010977933611688684*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.0028109078284862745 - 0.002403644324112159*lm - 
          0.0005741438320260628*lm^2) + CF^2*(0.0037859039631999193 + 
          0.006409038634426582*lm + 0.0037580323550796832*lm^2) + 
        CF*((0.0004313413790578898 + 0.00030416651102262594*lm + 
            0.00010438978764110232*lm^2)*NM + (0.000665234974330326 + 
            0.00030416651102262594*lm + 0.00010438978764110232*lm^2)*NL + 
          (-0.00011933550746806693 + 0.00030416651102262594*lm + 
            0.00010438978764110232*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.002666030860084222 - 0.0022835608273858703*lm - 
          0.000545939504731267*lm^2) + CF^2*(0.0035956131260001453 + 
          0.006081066516468342*lm + 0.0035734222127864756*lm^2) + 
        CF*((0.0004053259583702393 + 0.00028885976917366663*lm + 
            0.00009926172813295765*lm^2)*NM + (0.0006311690583056871 + 
            0.00028885976917366663*lm + 0.00009926172813295765*lm^2)*NL + 
          (-0.00011347818095346737 + 0.00028885976917366663*lm + 
            0.00009926172813295765*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.0025283229740070156 - 0.002169313946421408*lm - 
          0.0005191035824931779*lm^2) + CF^2*(0.003414205436823454 + 
          0.005769075255922813*lm + 0.00339776890359171*lm^2) + 
        CF*((0.0003808116785773884 + 0.00027429757447489247*lm + 
            0.00009438246954421417*lm^2)*NM + (0.0005988065657283385 + 
            0.00027429757447489247*lm + 0.00009438246954421417*lm^2)*NL + 
          (-0.00010789821870626283 + 0.00027429757447489247*lm + 
            0.00009438246954421417*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.0023974477069290687 - 0.002060626773049814*lm - 
          0.0004935696735248753*lm^2) + CF^2*(0.0032413108863564993 + 
          0.005472330543628701*lm + 0.0032306378630719114*lm^2) + 
        CF*((0.0003577155236581194 + 0.0002604449433752017*lm + 
            0.00008973994064088643*lm^2)*NM + (0.0005680644176738907 + 
            0.0002604449433752017*lm + 0.00008973994064088643*lm^2)*NL + 
          (-0.00010258286112333398 + 0.0002604449433752017*lm + 
            0.00008973994064088643*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.0022730828686133723 - 0.001957235073576838*lm - 
          0.00046927461517236557*lm^2) + CF^2*(0.003076571404818868 + 
          0.005190128590571548*lm + 0.003071615662946393*lm^2) + 
        CF*((0.00033595883054260927 + 0.00024726844953606774*lm + 
            0.00008532265730406648*lm^2)*NM + (0.0005388634070158974 + 
            0.00024726844953606774*lm + 0.00008532265730406648*lm^2)*NL + 
          (-0.00009751991680592092 + 0.00024726844953606774*lm + 
            0.00008532265730406648*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.00215492008753814 - 0.0018588867526114932*lm - 
          0.00044615831809355946*lm^2) + CF^2*(0.002919640793426336 + 
          0.0049217951488798204*lm + 0.0029203089911578437*lm^2) + 
        CF*((0.00031546708014513195 + 0.00023473616240358004*lm + 
            0.00008111969419882899*lm^2)*NM + (0.0005111280370817574 + 
            0.00023473616240358004*lm + 0.00008111969419882899*lm^2)*NL + 
          (-0.0000926977386556841 + 0.00023473616240358004*lm + 
            0.00008111969419882899*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.0020426643531123567 - 0.0017653413349705573*lm - 
          0.00042416361766261834*lm^2) + CF^2*(0.0027701846175305416 + 
          0.004666684533798648*lm + 0.0027763436792462293*lm^2) + 
        CF*((0.00029616969817171753 + 0.00022281758739503262*lm + 
            0.0000771206577568397*lm^2)*NM + (0.00048478636488364415 + 
            0.00022281758739503262*lm + 0.0000771206577568397*lm^2)*NL + 
          (-0.00008810520085781277 + 0.00022281758739503262*lm + 
            0.0000771206577568397*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.0019360335580628 - 0.0016763694655714653*lm - 
          0.0004032361323062895*lm^2) + CF^2*(0.002627880068154647 + 
          0.004424178650832576*lm + 0.002639363775095713*lm^2) + 
        CF*((0.00027799986309152687 + 0.00021148360775203416*lm + 
            0.00007331566041932536*lm^2)*NM + (0.0004597698490630762 + 
            0.00021148360775203416*lm + 0.00007331566041932536*lm^2)*NL + 
          (-0.0000837316767048032 + 0.00021148360775203416*lm + 
            0.00007331566041932536*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.0018347580430339492 - 0.001591752427152461*lm - 
          0.00038332412848535635*lm^2) + CF^2*(0.0024924157958718385 + 
          0.004193686031661354*lm + 0.002509030659176878*lm^2) + 
        CF*((0.00026089432204114794 + 0.0002007064280972245*lm + 
            0.00006969529608824662*lm^2)*NM + (0.00043601320264274516 + 
            0.0002007064280972245*lm + 0.00006969529608824662*lm^2)*NL + 
          (-0.00007956701727392779 + 0.0002007064280972245*lm + 
            0.00006969529608824662*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.0017385801453413295 - 0.001511281675596484*lm - 
          0.00036437839204146586*lm^2) + CF^2*(0.002363491721029169 + 
          0.003974640881908554*lm + 0.0023850222024532314*lm^2) + 
        CF*((0.0002447932138500289 + 0.00019045951971869096*lm + 
            0.00006625061673481198*lm^2)*NM + (0.00041345425064040335 + 
            0.00019045951971869096*lm + 0.00006625061673481198*lm^2)*NL + 
          (-0.0000756015309222027 + 0.00019045951971869096*lm + 
            0.00006625061673481198*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.0016472537534315949 - 0.0014347583925828306*lm - 
          0.0003463521056372223*lm^2) + CF^2*(0.002240818823756888 + 
          0.0037665021433757025*lm + 0.0022670319641709094*lm^2) + 
        CF*((0.00022963989971936833 + 0.00018071756759487642*lm + 
            0.0000629731101158586*lm^2)*NM + (0.00039203379256625695 + 
            0.00018071756759487642*lm + 0.0000629731101158586*lm^2)*NL + 
          (-0.00007182596352895333 + 0.00018071756759487642*lm + 
            0.0000629731101158586*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.0015605438684196885 - 0.001361993055246942*lm - 
          0.0003292007320254346*lm^2) + CF^2*(0.0021241189170107797 + 
          0.0035687525729388345*lm + 0.002154768427802845*lm^2) + 
        CF*((0.0002153808010049626 + 0.00017145641916297978*lm + 
            0.00005985467855007902*lm^2)*NM + (0.00037169546979677604 + 
            0.00017145641916297978*lm + 0.00005985467855007902*lm^2)*NL + 
          (-0.00006823147960735847 + 0.00017145641916297978*lm + 
            0.00005985467855007902*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.0014782261738325684 - 0.001292805022492729*lm - 
          0.0003128819028916619*lm^2) + CF^2*(0.0020131244055530645 + 
          0.0033808978399349227*lm + 0.0020479542734726966*lm^2) + 
        CF*((0.0002019652439038695 + 0.00016265303482540085*lm + 
            0.0000568876187075749*lm^2)*NM + (0.0003523856377935577 + 
            0.00016265303482540085*lm + 0.0000568876187075749*lm^2)*NL + 
          (-0.00006480964404757538 + 0.00016265303482540085*lm + 
            0.0000568876187075749*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.0014000866143989974 - 0.0012270221375726828*lm - 
          0.00029735531302263436*lm^2) + CF^2*(0.0019075780333084585 + 
          0.003202465643537919*lm + 0.001946325685239061*lm^2) + 
        CF*((0.00018934531192679686 + 0.00015428544018153105*lm + 
            0.000054064602367751697*lm^2)*NM + (0.0003340532431153521 + 
            0.00015428544018153105*lm + 0.000054064602367751697*lm^2)*NL + 
          (-0.00006155240467921352 + 0.00015428544018153105*lm + 
            0.000054064602367751697*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.001325920984842983 - 0.0011644803465278443*lm - 
          0.0002825826195616526*lm^2) + CF^2*(0.0018072326218545505 + 
          0.0030330048513339284*lm + 0.0018496316916762716*lm^2) + 
        CF*((0.00017747570281325827 + 0.0001463326799660025*lm + 
            0.00005137865810211865*lm^2)*NM + (0.00031664970515413594 + 
            0.0001463326799660025*lm + 0.00005137865810211865*lm^2)*NL + 
          (-0.00005845207550185769 + 0.0001463326799660025*lm + 
            0.00005137865810211865*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.0012555345289631326 - 0.0011050233320617647*lm - 
          0.0002685273461206305*lm^2) + CF^2*(0.0017118508015203913 + 
          0.0028720846600485857*lm + 0.0017576335382441268*lm^2) + 
        CF*((0.00016631359518525597 + 0.0001387747736692659*lm + 
            0.00004882315384011463*lm^2)*NM + (0.00030012880251180065 + 
            0.0001387747736692659*lm + 0.00004882315384011463*lm^2)*NL + 
          (-0.000055501320608475575 + 0.0001387747736692659*lm + 
            0.00004882315384011463*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.001188741549743632 - 0.0010485021624092132*lm - 
          0.00025515479152697727*lm^2) + CF^2*(0.0016212047375415617 + 
          0.002719293779153607*lm + 0.0016701040899947605*lm^2) + 
        CF*((0.00015581851852136173 + 0.00013159267281196137*lm + 
            0.00004639178027763224*lm^2)*NM + (0.00028444656392224315 + 
            0.00013159267281196137*lm + 0.00004639178027763224*lm^2)*NL + 
          (-0.0000526931386633294 + 0.00013159267281196137*lm + 
            0.00004639178027763224*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.0011253650306703832 - 0.0009947749547510169*lm - 
          0.00024243194299198464*lm^2) + CF^2*(0.0015350758526079889 + 
          0.002574239637880624*lm + 0.0015868272632202631*lm^2) + 
        CF*((0.00014595223089700898 + 0.00012476821984088265*lm + 
            0.00004407853508945175*lm^2)*NM + (0.0002695611636141099 + 
            0.00012476821984088265*lm + 0.00004407853508945175*lm^2)*NL + 
          (-0.000050020848326763626 + 0.00012476821984088265*lm + 
            0.00004407853508945175*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.001065236268572295 - 0.0009437065527205108*lm - 
          0.00023032739349573936*lm^2) + CF^2*(0.001453254547453237 + 
          0.0024365476159960062*lm + 0.0015075974846993849*lm^2) + 
        CF*((0.00013667860162980234 + 0.00011828410861132675*lm + 
            0.00004187770790831625*lm^2)*NM + (0.00025543282100185113 + 
            0.00011828410861132675*lm + 0.00004187770790831625*lm^2)*NL + 
          (-0.00004747807384550441 + 0.00011828410861132675*lm + 
            0.00004187770790831625*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.0010081945180725816 - 0.000895168217544168*lm - 
          0.00021881126319180398*lm^2) + CF^2*(0.001375539920672543 + 
          0.0023058602985379026*lm + 0.0014322191772554442*lm^2) + 
        CF*((0.00012796350119170363 + 0.00011212384641819161*lm + 
            0.00003978386603487345*lm^2)*NM + (0.00024202370458685206 + 
            0.00011212384641819161*lm + 0.00003978386603487345*lm^2)*NL + 
          (-0.00004505873160287238 + 0.00011212384641819161*lm + 
            0.00003978386603487345*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.0009540866478046067 - 0.0008490373323586767*lm - 
          0.00020785512464296105*lm^2) + CF^2*(0.0013017394890961 + 
          0.002181836754583913*lm + 0.0013605062703902905*lm^2) + 
        CF*((0.00011977469300185135 + 0.00010627171753626428*lm + 
            0.000037791840844174735*lm^2)*NM + (0.0002292978399460044 + 
            0.00010627171753626428*lm + 0.000037791840844174735*lm^2)*NL + 
          (-0.000042757017069946304 + 0.00010627171753626428*lm + 
            0.000037791840844174735*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.0009027668082945593 - 0.0008051971192486494*lm - 
          0.00019743193170718672*lm^2) + CF^2*(0.0012316689095320217 + 
          0.002064151840002549*lm + 0.0012922817348106769*lm^2) + 
        CF*((0.00011208173502992814 + 0.00010071274822866991*lm + 
            0.000035896714855852135*lm^2)*NM + (0.00021722102168195433 + 
            0.00010071274822866991*lm + 0.000035896714855852135*lm^2)*NL + 
          (-0.00004056739234519265 + 0.00010071274822866991*lm + 
            0.000035896714855852135*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.0008540961115705431 - 0.0007635363685529661*lm - 
          0.0001875159519006878*lm^2) + CF^2*(0.0011651517029943913 + 
          0.0019524955240421294*lm + 0.0012273771397135929*lm^2) + 
        CF*((0.00010485588289928292 + 0.00009543267318137187*lm + 
            0.00003409380943648869*lm^2)*NM + (0.00020576072920725706 + 
            0.00009543267318137187*lm + 0.00003409380943648869*lm^2)*NL + 
          (-0.00003848457418881436 + 0.00009543267318137187*lm + 
            0.00003409380943648869*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.0008079423222998006 - 0.0007239491799931959*lm - 
          0.00017808270207229066*lm^2) + CF^2*(0.0011020189819974818 + 
          0.001846572239525289*lm + 0.0011656322317459026*lm^2) + 
        CF*((0.00009806999905418493 + 0.00009041790332087745*lm + 
            0.00003237867310405285*lm^2)*NM + (0.00019488604623361347 + 
            0.00009041790332087745*lm + 0.00003237867310405285*lm^2)*NL + 
          (-0.000036503522793927086 + 0.00009041790332087745*lm + 
            0.00003237867310405285*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.0007641795603869232 - 0.0006863347151843328*lm - 
          0.00016910888723070162*lm^2) + CF^2*(0.0010421091817369576 + 
          0.001746100256344321*lm + 0.0011068945346009561*lm^2) + 
        CF*((0.00009169846651764384 + 0.00008565549497186508*lm + 
            0.00003074707040558212*lm^2)*NM + (0.0001845675838371369 + 
            0.00008565549497186508*lm + 0.00003074707040558212*lm^2)*NL + 
          (-0.000034619430455798076 + 0.00008565549497186508*lm + 
            0.00003074707040558212*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.0007226880147899066 - 0.0006505969610960187*lm - 
          0.0001605723423731598*lm^2) + CF^2*(0.000985267795601238 + 
          0.001650811077890808*lm + 0.0010510189682606823*lm^2) + 
        CF*((0.00008571710685783617 + 0.0000811331203112722*lm + 
            0.000029194971340574508*lm^2)*NM + (0.0001747774069710702 + 
            0.0000811331203112722*lm + 0.000029194971340574508*lm^2)*NL + 
          (-0.00003282771152947179 + 0.0000811331203112722*lm + 
            0.000029194971340574508*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.0006833536684162098 - 0.0006166445040412923*lm - 
          0.00015245197717077147*lm^2) + CF^2*(0.0009313471156387448 + 
          0.0015604488600011366*lm + 0.0009978674869359587*lm^2) + 
        CF*((0.00008010310221391014 + 0.00007683903907542833*lm + 
            0.00002771854130377663*lm^2)*NM + (0.00016548896429844325 + 
            0.00007683903907542833*lm + 0.00002771854130377663*lm^2)*NL + 
          (-0.00003112399213786713 + 0.00007683903907542833*lm + 
            0.00002771854130377663*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.0006460680338023079 - 0.0005843903137795374*lm - 
          0.00014472772337234657*lm^2) + CF^2*(0.0008802059782596122 + 
          0.001474769851956467*lm + 0.000947308734800814*lm^2) + 
        CF*((0.00007483492154610677 + 0.00007276207147705882*lm + 
            0.000026314131522244832*lm^2)*NM + (0.00015667702121873419 + 
            0.00007276207147705882*lm + 0.000026314131522244832*lm^2)*NL + 
          (-0.000029504100780313657 + 0.00007276207147705882*lm + 
            0.000026314131522244832*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.0006107278993699676 - 0.0005537515373305429*lm - 
          0.0001373804847948529*lm^2) + CF^2*(0.0008317095155988316 + 
          0.0013935418590405293*lm + 0.0008992177186572189*lm^2) + 
        CF*((0.0000698922506694878 + 0.00006889157228938895*lm + 
            0.000024978269962700527*lm^2)*NM + (0.0001483175959645905 + 
            0.00006889157228938895*lm + 0.000024978269962700527*lm^2)*NL + 
          (-0.000027964059098922457 + 0.00006889157228938895*lm + 
            0.000024978269962700527*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.0005773629705527431 - 0.0005246663071860507*lm - 
          0.00013038197978808776*lm^2) + CF*(0.0007861174954406108 + 
          0.0013168192149401632*lm + 0.0008534093222493016*lm^2) + 
        0.00006524982744634127*NM + 0.00006522283738865007*lm*NM + 
        0.000023705814506925046*lm^2*NM + 0.00014039494301598993*NL + 
        0.00006522283738865007*lm*NL + 0.000023705814506925046*lm^2*NL - 
        0.000026500618480071882*NH + 0.00006522283738865007*lm*NH + 
        0.000023705814506925046*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.0005456034924385495 - 0.0004970225649043122*lm - 
          0.00012373664270503253*lm^2) + CF*(0.000742469115153119 + 
          0.0012437964337919532*lm + 0.0008099125704329401*lm^2) + 
        0.00006090251318767864*NM + 0.00006173446638143766*lm*NM + 
        0.000022497571400915002*lm^2*NM + 0.00013287207297593662*NL + 
        0.00006173446638143766*lm*NL + 0.000022497571400915002*lm^2*NL - 
        0.00002510897702451974*NH + 0.00006173446638143766*lm*NH + 
        0.000022497571400915002*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.0005155123309209134 - 0.0004707693129448461*lm - 
          0.00011741618877230436*lm^2) + CF*(0.0007011052061363614 + 
          0.0011745990488821491*lm + 0.0007685423265096286*lm^2) + 
        0.00005682634534990222*NM + 0.0000584237322244801*lm*NM + 
        0.000021348397958600795*lm^2*NM + 0.0001257369075422505*NL + 
        0.0000584237322244801*lm*NL + 0.000021348397958600795*lm^2*NL - 
        0.00002378633848715374*NH + 0.0000584237322244801*lm*NH + 
        0.000021348397958600795*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.0004870045727489212 - 0.00044583844689931123*lm - 
          0.00011140498543487887*lm^2) + CF*(0.0006619124418479298 + 
          0.0011090351534274174*lm + 0.0007291962683010254*lm^2) + 
        0.00005300525044049021*NM + 0.00005528186974882842*lm*NM + 
        0.000020255451897250704*lm^2*NM + 0.00011896986036450999*NL + 
        0.00005528186974882842*lm*NL + 0.000020255451897250704*lm^2*NL - 
        0.000022529410886868516*NH + 0.00005528186974882842*lm*NH + 
        0.000020255451897250704*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.00045999952680457473 - 0.0004221651531235135*lm - 
          0.00010568815331077573*lm^2) + CF*(0.000624782811857863 + 
          0.0010469221489103173*lm + 0.0006917770034887138*lm^2) + 
        0.000049424072977467846*NM + 0.000052300537818310554*lm*NM + 
        0.000019216027874686497*lm^2*NM + 0.00011255232556890711*NL + 
        0.000052300537818310554*lm*NL + 0.000019216027874686497*lm^2*NL - 
        0.000021335055651875898*NH + 0.000052300537818310554*lm*NH + 
        0.000019216027874686497*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.0004344205189267836 - 0.0003996877512115511*lm - 
          0.00010025152964398217*lm^2) + CF*(0.0005896133893350282 + 
          0.0009880863075134175*lm + 0.0006561918303969743*lm^2) + 
        0.00004606852456873258*NM + 0.00004947179914564152*lm*NM + 
        0.000018227550844360394*lm^2*NM + 0.00010646662904395423*NL + 
        0.00004947179914564152*lm*NL + 0.000018227550844360394*lm^2*NL - 
        0.000020200280583106987*NH + 0.00004947179914564152*lm*NH + 
        0.000018227550844360394*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.00041019469641823657 - 0.0003783475439168189*lm - 
          0.00009508163353800729*lm^2) + CF*(0.0005563061077051094 + 
          0.0009323623543796383*lm + 0.0006223525104305931*lm^2) + 
        0.00004292513573643007*NM + 0.00004678810105046125*lm*NM + 
        0.000017287569734183143*lm^2*NM + 0.00010069598211582674*NL + 
        0.00004678810105046125*lm*NL + 0.000017287569734183143*lm^2*NL - 
        0.000019122233135308914*NH + 0.00004678810105046125*lm*NH + 
        0.000017287569734183143*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.0003872528417967656 - 0.00035808867417542697*lm - 
          0.00009016563288387211*lm^2) + CF*(0.0005247675461785425 + 
          0.0008795930688440449*lm + 0.0005901750516035266*lm^2) + 
        0.00003998121034346776*NM + 0.000044242257116619615*lm*NM + 
        0.000016393751433431294*lm^2*NM + 0.000095224437498851*NL + 
        0.000044242257116619615*lm*NL + 0.000016393751433431294*lm^2*NL - 
        0.00001809819400181208*NH + 0.000044242257116619615*lm*NH + 
        0.000016393751433431294*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.0003655291953715245 - 0.00033885798890294567*lm - 
          0.00008549131290041474*lm^2) + CF*(0.0004949087238530422 + 
          0.0008296289038166776*lm + 0.0005595795026208964*lm^2) + 
        0.00003722478248634729*NM + 0.00004182742970787762*lm*NM + 
        0.000015543875072802682*lm^2*NM + 0.00009003684741192179*NL + 
        0.00004182742970787762*lm*NL + 0.000015543875072802682*lm^2*NL - 
        0.00001712557098954114*NH + 0.00004182742970787762*lm*NH + 
        0.000015543875072802682*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.0003449612862422754 - 0.0003206049092500997*lm - 
          0.00008104704620868012*lm^2) + CF*(0.0004666449021017595 + 
          0.0007823276225291117*lm + 0.0005304897570022699*lm^2) + 
        0.00003464457572526152*NM + 0.00003953711330296818*lm*NM + 
        0.000014735826583396385*lm^2*NM + 0.00008511882375667692*NL + 
        0.00003953711330296818*lm*NL + 0.000014735826583396385*lm^2*NL - 
        0.000016201893171416364*NH + 0.00003953711330296818*lm*NH + 
        0.000014735826583396385*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.00032548977133733676 - 0.0003032813070171238*lm - 
          0.00007682176436587934*lm^2) + CF*(0.0004398953949645913 + 
          0.0007375539518893323*lm + 0.0005028333667584829*lm^2) + 
        0.00003222996452885142*NM + 0.00003736511861266201*lm*NM + 
        0.00001396759352106897*lm^2*NM + 0.00008045670025808206*NL + 
        0.00003736511861266201*lm*NL + 0.00001396759352106897*lm^2*NL - 
        0.00001532480530384235*NH + 0.00003736511861266201*lm*NH + 
        0.00001396759352106897*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.0003070582821223271 - 0.000286841386939985*lm - 
          0.00007280493078794866*lm^2) + CF*(0.0004145833872667087 + 
          0.0006951792517202397*lm + 0.0004765413651574822*lm^2) + 
        0.000029970937817165375*NM + 0.00003530555744311659*lm*NM + 
        0.000013237260143263394*lm^2*NM + 0.00007603749647269315*NL + 
        0.00003530555744311659*lm*NL + 0.000013237260143263394*lm^2*NL - 
        0.000014492062497508816*NH + 0.00003530555744311659*lm*NH + 
        0.000013237260143263394*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.0002896132786277551 - 0.0002712415745745921*lm - 
          0.00006898651499312384*lm^2) + CF*(0.0003906357601949522 + 
          0.0006550811991866826*lm + 0.00045154809813681055*lm^2) + 
        0.000027858064492221374*NM + 0.00003335282827135172*lm*NM + 
        0.000012543002726022516*lm^2*NM + 0.00007184888357427521*NL + 
        0.00003335282827135172*lm*NL + 0.000012543002726022516*lm^2*NL - 
        0.00001370152513023459*NH + 0.00003335282827135172*lm*NH + 
        0.000012543002726022516*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.0002731039104587893 - 0.0002564404095174822*lm - 
          0.00006535696810217423*lm^2) + CF*(0.0003679829240693603 + 
          0.0006171434877444093*lm + 0.00042779106394150407*lm^2) + 
        0.000025882460851153992*NM + 0.00003150160250019611*lm*NM + 
        0.000011883085109486224*lm^2*NM + 0.00006787915183067452*NL + 
        0.00003150160250019611*lm*NL + 0.000011883085109486224*lm^2*NL - 
        0.000012951153991071615*NH + 0.00003150160250019611*lm*NH + 
        0.000011883085109486224*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.00025748188446520935 - 0.00024239844371330726*lm - 
          0.00006190719953402402*lm^2) + CF*(0.00034655865805372437 + 
          0.0005812555399717534*lm + 0.000405210760586339*lm^2) + 
        0.00002403575978224474*NM + 0.000029746811361488327*lm*NM + 
        0.000011255854460731638*lm^2*NM + 0.00006411717968987212*NL + 
        0.000029746811361488327*lm*NL + 0.000011255854460731638*lm^2*NL - 
        0.000012239005645351524*NH + 0.000029746811361488327*lm*NH + 
        0.000011255854460731638*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.00024270133876361756 - 0.00022907814461077324*lm - 
          0.000058628554838426764*lm^2) + CF*(0.0003262999565556862 + 
          0.0005473122336712712*lm + 0.00038375054076061156*lm^2) + 
        0.000022310081649197655*NM + 0.000028083633437694728*lm*NM + 
        0.000010659737243350321*lm^2*NM + 0.00006055240439699943*NL + 
        0.000028083633437694728*lm*NL + 0.000010659737243350321*lm^2*NL - 
        0.000011563228010803947*NH + 0.000028083633437694728*lm*NH + 
        0.000010659737243350321*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.0002287187228174956 - 0.00021644380293952203*lm - 
          0.000055512794610164776*lm^2) + CF*(0.0003071468820735066 + 
          0.0005152136406539476*lm + 0.00036335647381198765*lm^2) + 
        0.000020698006773843202*NM + 0.00002650748277342868*lm*NM + 
        0.000010093235383666324*lm^2*NM + 0.000057174794067778096*NL + 
        0.00002650748277342868*lm*NL + 0.000010093235383666324*lm^2*NL - 
        0.000010922056135303936*NH + 0.00002650748277342868*lm*NH + 
        0.000010093235383666324*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.00021549268329365095 - 0.00020446144489081637*lm - 
          0.000052552074431918265*lm^2) + CF*(0.000289042424253215 + 
          0.0004848647776430345*lm + 0.000343977214463465*lm^2) + 
        0.000019192549432043287*NM + 0.00002501399754962189*lm*NM + 
        9.55492262398514*^-6*lm^2*NM + 0.00005397482114736276*NL + 
        0.00002501399754962189*lm*NL + 9.55492262398514*^-6*lm^2*NL - 
        0.000010313808167216286*NH + 0.00002501399754962189*lm*NH + 
        9.55492262398514*^-6*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.00020298395542602354 - 0.00019309874849480753*lm - 
          0.00004973892579550019*lm^2) + CF*(0.0002719323649263963 + 
          0.00045617536875809667*lm + 0.00032556387793418305*lm^2) + 
        0.000017787133281938415*NM + 0.000023599029294312072*lm*NM + 
        9.043441053727308*^-6*lm^2*NM + 0.00005094343718692487*NL + 
        0.000023599029294312072*lm*NL + 9.043441053727308*^-6*lm^2*NL - 
        9.736881509698064*^-6*NH + 0.000023599029294312072*lm*NH + 
        9.043441053727308*^-6*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.000191155259629744 - 0.00018232496399665194*lm - 
          0.000047066237953583595*lm^2) + CF*(0.00025576514890536447 + 
          0.000429059619062451*lm + 0.000308069921150729*lm^2) + 
        0.000016475568147834904*NM + 0.00002225863260517357*lm*NM + 
        8.557497809742472*^-6*lm^2*NM + 0.0000480720488735238*NL + 
        0.00002225863260517357*lm*NL + 8.557497809742472*^-6*lm^2*NL - 
        9.189749150697666*^-6*NH + 0.00002225863260517357*lm*NH + 
        8.557497809742472*^-6*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.00017997120311976145 - 0.00017211083804281627*lm - 
          0.000044527240656366026*lm^2) + CF*(0.0002404917603189126 + 
          0.00040343599867893594*lm + 0.00029145102975075944*lm^2) + 
        0.000015252028086984875*NM + 0.000020989055360030655*lm*NM + 
        8.095861937521096*^-6*lm^2*NM + 0.00004535249525187489*NL + 
        0.000020989055360030655*lm*NL + 8.095861937521096*^-6*lm^2*NL - 
        8.670956160750021*^-6*NH + 0.000020989055360030655*lm*NH + 
        8.095861937521096*^-6*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.00016939818629931402 - 0.00016242854149758502*lm - 
          0.000042115487729824754*lm^2) + CF*(0.0002260656042781984 + 
          0.0003792270369998488*lm + 0.00027566501059521657*lm^2) + 
        0.000014111030670273398*NM + 0.000019786729392659318*lm*NM + 
        7.657361405422682*^-6*lm^2*NM + 0.000042777026079548644*NL + 
        0.000019786729392659318*lm*NL + 7.657361405422682*^-6*lm^2*NL - 
        8.179116351013828*^-6*NH + 0.000019786729392659318*lm*NH + 
        7.657361405422682*^-6*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.00015940431369401597 - 0.00015325160071807744*lm - 
          0.00003982484145432157*lm^2) + CF*(0.00021244239366862002 + 
          0.0003563591265369871*lm + 0.0002606716895191957*lm^2) + 
        0.000013047417411404714*NM + 0.000018648261612204127*lm*NM + 
        7.240880264422104*^-6*lm^2*NM + 0.0000403382812599272*NL + 
        0.000018648261612204127*lm*NL + 7.240880264422104*^-6*lm^2*NL - 
        7.71290908432828*^-6*NH + 0.000018648261612204127*lm*NH + 
        7.240880264422104*^-6*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.0001499593092173965 - 0.00014455483212400831*lm - 
          0.000037649457704321945*lm^2) + CF*(0.0001995800408697518 + 
          0.00033476233597704106*lm + 0.00024643281406465275*lm^2) + 
        0.000012056335282580888*NM + 0.00001757042554551379*lm*NM + 
        6.845355946240354*^-6*lm^2*NM + 0.00003802927129990863*NL + 
        0.00001757042554551379*lm*NL + 6.845355946240354*^-6*lm^2*NL - 
        7.271076232384511*^-6*NH + 0.00001757042554551379*lm*NH + 
        6.845355946240354*^-6*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.00014103443556336677 - 0.00013631427990600374*lm - 
          0.00003558377181190423*lm^2) + CF*(0.0001874385542115351 + 
          0.00031437023202614164*lm + 0.00023291196095064589*lm^2) + 
        0.000011133219257899783*NM + 0.00001655015328263441*lm*NM + 
        6.4697766930734965*^-6*lm^2*NM + 0.00003584335874189215*NL + 
        0.00001655015328263441*lm*NL + 6.4697766930734965*^-6*lm^2*NL - 
        6.852419272411207*^-6*NH + 0.00001655015328263441*lm*NH + 
        6.4697766930734965*^-6*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.00013260241753032637 - 0.00012850715672352197*lm - 
          0.000033622485118555154*lm^2) + CF*(0.0001759799389809503 + 
          0.00029511970964519443*lm + 0.00022007444804872465*lm^2) + 
        0.000010273775828772514*NM + 0.00001558452780659454*lm*NM + 
        6.113179112464574*^-6*lm^2*NM + 0.000033774240522003334*NL + 
        0.00001558452780659454*lm*NL + 6.113179112464574*^-6*lm^2*NL - 
        6.455796517065225*^-6*NH + 0.00001558452780659454*lm*NH + 
        6.113179112464574*^-6*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.0001246373690904658 - 0.00012111178725034917*lm - 
          0.000031760552181481685*lm^2) + CF*(0.00016516810279932896 + 
          0.0002769508302947523*lm + 0.0002078872506424256*lm^2) + 
        9.473967438580901*^-6*NM + 0.000014670775689472681*lm*NM + 
        5.774645851178489*^-6*lm^2*NM + 0.00003181593120883257*NL + 
        0.000014670775689472681*lm*NL + 5.774645851178489*^-6*lm^2*NL - 
        6.080120471497143*^-6*NH + 0.000014670775689472681*lm*NH + 
        5.774645851178489*^-6*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.00011711472402629166 - 0.00011410755443224612*lm - 
          0.000029993168602320455*lm^2) + CF*(0.00015496876519629333 + 
          0.00025980666782462184*lm + 0.00019631892176064298*lm^2) + 
        8.72999778656993*^-6*NM + 0.000013806260137557372*lm*NM + 
        5.453303382240083*^-6*lm^2*NM + 0.000029962747079167344*NL + 
        0.000013806260137557372*lm*NL + 5.453303382240083*^-6*lm^2*NL - 
        5.724355311828714*^-6*NH + 0.000013806260137557372*lm*NH + 
        5.453303382240083*^-6*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.00011001116996451096 - 0.00010747484832763734*lm - 
          0.000028315759447698348*lm^2) + CF*(0.00014534937121203056 + 
          0.00024363316165918614*lm + 0.00018533951638493464*lm^2) + 
        8.038297953605736*^-6*NM + 0.000012988474369193948*lm*NM + 
        5.1483198995815175*^-6*lm^2*NM + 0.00002820929098930388*NL + 
        0.000012988474369193948*lm*NL + 5.1483198995815175*^-6*lm^2*NL - 
        5.387514479535012*^-6*NH + 0.000012988474369193948*lm*NH + 
        5.1483198995815175*^-6*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.00010330458564517313 - 0.00010119501740826113*lm - 
          0.000026723968232594766*lm^2) + CF*(0.00013627900886521856 + 
          0.00022837897694457938*lm + 0.00017492051934062027*lm^2) + 
        7.395513304932452*^-6*NM + 0.000012215035309661913*lm*NM + 
        4.85890331501723*^-6*lm^2*NM + 0.000026550438002530954*NL + 
        0.000012215035309661913*lm*NL + 4.85890331501723*^-6*lm^2*NL - 
        5.0686583864687886*^-6*NH + 0.000012215035309661913*lm*NH + 
        4.85890331501723*^-6*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.00009697398127139885 - 0.00009525032220245825*lm - 
          0.000025213646438881053*lm^2) + CF*(0.0001277283303294142 + 
          0.00021399537133839393*lm + 0.0001650347766908578*lm^2) + 
        6.798491127437821*^-6*NM + 0.000011483677588143902*lm*NM + 
        4.584299352523828*^-6*lm^2*NM + 0.000024981321735292122*NL + 
        0.000011483677588143902*lm*NL + 4.584299352523828*^-6*lm^2*NL - 
        4.766892225498891*^-6*NH + 0.000011483677588143902*lm*NH + 
        4.584299352523828*^-6*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.00009099944179213356 - 0.0000896238911692737*lm - 
          0.000023780843542769164*lm^2) + CF*(0.00011966947666609373 + 
          0.0002004360681365568*lm + 0.0001556564304617618*lm^2) + 
        6.244268961193575*^-6*NM + 0.000010792247822532934*lm*NM + 
        4.323789735048939*^-6*lm^2*NM + 0.00002349732138635686*NL + 
        0.000010792247822532934*lm*NL + 4.323789735048939*^-6*lm^2*NL - 
        4.481363881958768*^-6*NH + 0.000010792247822532934*lm*NH + 
        4.323789735048939*^-6*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.00008536207297716602 - 0.0000842996786967951*lm - 
          0.000022421797526192467*lm^2) + CF*(0.00011207600596779186 + 
          0.00018765713544540094*lm + 0.00014676085653507796*lm^2) + 
        5.730063587177987*^-6*NM + 0.00001013869917848019*lm*NM + 
        4.076690459307721*^-6*lm^2*NM + 0.000022094049415069498*NL + 
        0.00001013869917848019*lm*NL + 4.076690459307721*^-6*lm^2*NL - 
        4.211261941315648*^-6*NH + 0.00001013869917848019*lm*NH + 
        4.076690459307721*^-6*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.0000800439501501584 - 0.00007926242512316105*lm - 
          0.000021132925848370274*lm^2) + CF*(0.00010492282476992633 + 
          0.00017561687111980137*lm + 0.00013832460555296907*lm^2) + 
        5.2532606351202*^-6*NM + 9.521086189712195*^-6*lm*NM + 
        3.84235015424914*^-6*lm^2*NM + 0.000020767339836401603*NL + 
        9.521086189712195*^-6*lm*NL + 3.84235015424914*^-6*lm^2*NL - 
        3.955813788676216*^-6*NH + 9.521086189712195*^-6*lm*NH + 
        3.84235015424914*^-6*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.00007502806945165747 - 0.00007449761868345568*lm - 
          0.000019910816854976584*lm^2) + CF*(0.00009818612259490847 + 
          0.0001642756932005612*lm + 0.00013032534668711945*lm^2) + 
        4.811404777334039*^-6*NM + 8.937559827245294*^-6*lm*NM + 
        3.6201485190866513*^-6*lm^2*NM + 0.000019513237102112084*NL + 
        8.937559827245294*^-6*lm*NL + 3.6201485190866513*^-6*lm^2*NL - 
        3.7142837959410082*^-6*NH + 8.937559827245294*^-6*lm*NH + 
        3.6201485190866513*^-6*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.00007029830151000685 - 0.00006999145929026828*lm - 
          0.000018752221603445825*lm^2) + CF*(0.00009184330949703458 + 
          0.00015359603559604492*lm + 0.0001227418141316454*lm^2) + 
        4.4021904762381684*^-6*NM + 8.38636280569768*^-6*lm*NM + 
        3.40949483699015*^-6*lm^2*NM + 0.000018327985538823062*NL + 
        8.38636280569768*^-6*lm*NL + 3.40949483699015*^-6*lm^2*NL - 
        3.4859715926075577*^-6*NH + 8.38636280569768*^-6*lm*NH + 
        3.40949483699015*^-6*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.00006583934740376947 - 0.00006573082406005318*lm - 
          0.000017654046084006464*lm^2) + CF*(0.00008587295648142159 + 
          0.0001435422487643754*lm + 0.00011555375618622412*lm^2) + 
        4.02345325499428*^-6*NM + 7.865825115446191*^-6*lm*NM + 
        3.209826560728448*^-6*lm^2*NM + 0.00001720801931525215*NL + 
        7.865825115446191*^-6*lm*NL + 3.209826560728448*^-6*lm^2*NL - 
        3.27021041640199*^-6*NH + 7.865825115446191*^-6*lm*NH + 
        3.209826560728448*^-6*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.00006163669680470728 - 0.00006170323450157896*lm - 
          0.00001661334381703986*lm^2) + CF*(0.00008025473867489607 + 
          0.00013408050516336545*lm + 0.00010874188680244271*lm^2) + 
        3.673161462340226*^-6*NM + 7.374359769897696*^-6*lm*NM + 
        3.02060796673452*^-6*lm^2*NM + 0.000016149952912206137*NL + 
        7.374359769897696*^-6*lm*NL + 3.02060796673452*^-6*lm^2*NL - 
        3.06636554009059*^-6*NH + 7.374359769897696*^-6*lm*NH + 
        3.02060796673452*^-6*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.000057676588195563085 - 0.00005789682528672104*lm - 
          0.00001562730880831912*lm^2) + CF*(0.00007496938113126661 + 
          0.00012517870924575204*lm + 0.00010228783947263423*lm^2) + 
        3.349408504254841*^-6*NM + 6.910458757644029*^-6*lm*NM + 
        2.8413288742398396*^-6*lm^2*NM + 0.000015150572070240299*NL + 
        6.910458757644029*^-6*lm*NL + 2.8413288742398396*^-6*lm^2*NL - 
        2.8738327709871555*^-6*NH + 6.910458757644029*^-6*lm*NH + 
        2.8413288742398396*^-6*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.000053945971061855356 - 0.00005430031452763237*
           lm - 0.000014693268844593185*lm^2) + 
        CF*(0.00006999860715780787 + 0.00011680641178726636*lm + 
          0.00009617412334642813*lm^2) + 3.050405516569954*^-6*NM + 
        6.472689189746306*^-6*lm*NM + 2.67150342628967*^-6*lm^2*NM + 
        0.000014206825191124796*NL + 6.472689189746306*^-6*lm*NL + 
        2.67150342628967*^-6*lm^2*NL - 2.692037019829056*^-6*NH + 
        6.472689189746306*^-6*lm*NH + 2.67150342628967*^-6*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.00005043246996164253 - 0.000050902975487933894*lm - 
          0.000013808679112847313*lm^2) + CF*(0.00006532508905405836 + 
          0.00010893472834461713*lm + 0.00009038408146590968*lm^2) + 
        2.774474454046649*^-6*NM + 6.059689632849759*^-6*lm*NM + 
        2.5106689296086023*^-6*lm^2*NM + 0.000013315815170437344*NL + 
        6.059689632849759*^-6*lm*NL + 2.5106689296086023*^-6*lm^2*NL - 
        2.520430935845121*^-6*NH + 6.059689632849759*^-6*lm*NH + 
        2.5106689296086023*^-6*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.0000471243503817455 - 0.00004769460965900564*lm - 
          0.000012971116127394413*lm^2) + CF*(0.00006093240115818647 + 
          0.00010153626164960698*lm + 0.00008490185101567252*lm^2) + 
        2.520041572761074*^-6*NM + 5.670166619265128*^-6*lm*NM + 
        2.358384750435348*^-6*lm^2*NM + 0.000012474791639722609*NL + 
        5.670166619265128*^-6*lm*NL + 2.358384750435348*^-6*lm^2*NL - 
        2.3584936049820585*^-6*NH + 5.670166619265128*^-6*lm*NH + 
        2.358384750435348*^-6*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.00004401048629324618 - 0.00004466552113573951*lm - 
          0.000012178271949734688*lm^2) + CF*(0.00005680497510020917 + 
          0.00009458502775435561*lm + 0.0000797123254891725*lm^2) + 
        2.2856312839036087*^-6*NM + 5.302891325567751*^-6*lm*NM + 
        2.214231263588125*^-6*lm^2*NM + 0.000011681143597725936*NL + 
        5.302891325567751*^-6*lm*NL + 2.214231263588125*^-6*lm^2*NL - 
        2.2057293083933654*^-6*NH + 5.302891325567751*^-6*lm*NH + 
        2.214231263588125*^-6*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.00004108032932321427 - 0.00004180649222924182*lm - 
          0.000011427948686865287*lm^2) + CF*(0.00005292805716525793 + 
          0.00008805638575098539*lm + 0.0000748011186776637*lm^2) + 
        2.069860358287483*^-6*NM + 4.956696411661917*^-6*lm*NM + 
        2.0778088521573247*^-6*lm^2*NM + 0.000010932392411224625*NL + 
        4.956696411661917*^-6*lm*NL + 2.0778088521573247*^-6*lm^2*NL - 
        2.0616663384258786*^-6*NH + 4.956696411661917*^-6*lm*NH + 
        2.0778088521573247*^-6*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.000038323879463560915 - 0.00003910876025695543*lm - 
          0.000010718053254429381*lm^2) + CF*(0.000049287667673877 + 
          0.00008192697089714849*lm + 0.00007015453039262868*lm^2) + 
        1.8714324619922827*^-6*NM + 4.630473012636338*^-6*lm*NM + 
        1.9487369553507966*^-6*lm^2*NM + 0.000010226185166946483*NL + 
        4.630473012636338*^-6*lm*NL + 1.9487369553507966*^-6*lm^2*NL - 
        1.925855869464495*^-6*NH + 4.630473012636338*^-6*lm*NH + 
        1.9487369553507966*^-6*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.000035731657241686084 - 0.00003656399545351333*
           lm - 0.000010046592391766773*lm^2) + 
        CF*(0.00004587056229001197 + 0.0000761746309864533*lm + 
          0.00006575951383701888*lm^2) + 1.6891330046373723*^-6*NM + 
        4.323167876097716*^-6*lm*NM + 1.826653162139413*^-6*lm^2*NM + 
        9.560288356984896*^-6*NL + 4.323167876097716*^-6*lm*NL + 
        1.826653162139413*^-6*lm^2*NL - 1.7978708811153976*^-6*NH + 
        4.323167876097716*^-6*lm*NH + 1.826653162139413*^-6*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.0000332946772811825 - 0.000034164279948344935*lm - 
          9.411667916567596*^-6*lm^2) + CF*(0.00004266419517090381 + 
          0.00007077836581019722*lm + 0.00006160364454480608*lm^2) + 
        1.5218242827930634*^-6*NM + 4.0337806380140155*^-6*lm*NM + 
        1.7112123484668356*^-6*lm^2*NM + 8.932581880994513*^-6*NL + 
        4.0337806380140155*^-6*lm*NL + 1.7112123484668356*^-6*lm^2*NL - 
        1.6773051313226244*^-6*NH + 4.0337806380140155*^-6*lm*NH + 
        1.7112123484668356*^-6*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.00003100442318429119 - 0.00003190208775863847*lm - 
          8.811472207438552*^-6*lm^2) + CF*(0.00003965668387654542 + 
          0.00006571826956384226*lm + 0.000057675090812325066*lm^2) + 
        1.3684409019963186*^-6*NM + 3.761361230427825*^-6*lm*NM + 
        1.6020858558979184*^-6*lm^2*NM + 8.3410533492839*^-6*NL + 
        3.761361230427825*^-6*lm*NL + 1.6020858558979184*^-6*lm^2*NL - 
        1.563772177122199*^-6*NH + 3.761361230427825*^-6*lm*NH + 
        1.6020858558979184*^-6*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.000028852823671077765 - 0.000029770265748723606*
           lm - 8.244283903268773*^-6*lm^2) + CF*(0.00003683677595968806 + 
          0.00006097547605839635*lm + 0.000053962585548668325*lm^2) + 
        1.2279854617455652*^-6*NM + 3.5050074147139974*^-6*lm*NM + 
        1.4989607096852313*^-6*lm^2*NM + 7.783792671713016*^-6*NL + 
        3.5050074147139974*^-6*lm*NL + 1.4989607096852313*^-6*lm^2*NL - 
        1.4569044408425617*^-6*NH + 3.5050074147139974*^-6*lm*NH + 
        1.4989607096852313*^-6*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0000268322299134232 - 0.000027762015509283686*lm - 
          7.708463808831556*^-6*lm^2) + CF*(0.000034193817160604024 + 
          0.00005653210660329481*lm + 0.00005045539947598837*lm^2) + 
        1.0995244887084396*^-6*NM + 3.2638624343550213*^-6*lm*NM + 
        1.4015388743330104*^-6*lm^2*NM + 7.258986918056248*^-6*NL + 
        3.2638624343550213*^-6*lm*NL + 1.4015388743330104*^-6*lm^2*NL - 
        1.3563523196598727*^-6*NH + 3.2638624343550213*^-6*lm*NH + 
        1.4015388743330104*^-6*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.000024935394004901995 - 0.000025870876112041216*
           lm - 7.2024509965800284*^-6*lm^2) + 
        CF*(0.00003171772113392266 + 0.00005237122043352798*lm + 
          0.00004714331561397837*lm^2) + 9.821846041895026*^-7*NM + 
        3.0371127814931068*^-6*lm*NM + 1.3095365448327324*^-6*lm^2*NM + 
        6.7649154362076805*^-6*NL + 3.0371127814931068*^-6*lm*NL + 
        1.3095365448327324*^-6*lm^2*NL - 1.2617833365121458*^-6*NH + 
        3.0371127814931068*^-6*lm*NH + 1.3095365448327324*^-6*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.00002315544851046307 - 0.00002409070769768926*lm - 
          6.724759095090719*^-6*lm^2) + CF*(0.00002939894063786112 + 
          0.00004847676755964159*lm + 0.00004401660498604834*lm^2) + 
        8.751489126744743*^-7*NM + 2.823986071790278*^-6*lm*NM + 
        1.222683471834676*^-6*lm^2*NM + 6.299945215285983*^-6*NL + 
        2.823986071790278*^-6*lm*NL + 1.222683471834676*^-6*lm^2*NL - 
        1.1728813304672505*^-6*NH + 2.823986071790278*^-6*lm*NH + 
        1.222683471834676*^-6*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.000021485887042538376 - 0.000022415675856869688*
           lm - 6.273972755080343*^-6*lm^2) + CF*(0.000027228440119070997 + 
          0.000044833543924858824*lm + 0.00004106600348779861*lm^2) + 
        7.776535989956307*^-7*NM + 2.623749022387467*^-6*lm*NM + 
        1.140722319105517*^-6*lm^2*NM + 5.862526481343611*^-6*NL + 
        2.623749022387467*^-6*lm*NL + 1.140722319105517*^-6*lm^2*NL - 
        1.0893456847268462*^-6*NH + 2.623749022387467*^-6*lm*NH + 
        1.140722319105517*^-6*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.000019920545812788076 - 0.000020840236765931107*
           lm - 5.848744284368937*^-6*lm^2) + CF*(0.000025197669629120053 + 
          0.00004142714875894609*lm + 0.000038282689861323953*lm^2) + 
        6.889847223518053*^-7*NM + 2.435705528001274*^-6*lm*NM + 
        1.063408051703443*^-6*lm^2*NM + 5.451188514000351*^-6*NL + 
        2.435705528001274*^-6*lm*NL + 1.063408051703443*^-6*lm^2*NL - 
        1.0108905905313926*^-6*NH + 2.435705528001274*^-6*lm*NH + 
        1.063408051703443*^-6*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.000018453586111154288 - 0.000019359123041040012*
           lm - 5.447790443588055*^-6*lm^2) + CF*(0.000023298540011326386 + 
          0.00003824394402357985*lm + 0.000035658264721667265*lm^2) + 
        6.084751960680032*^-7*NM + 2.2591948304331794*^-6*lm*NM + 
        9.905073533796463*^-7*lm^2*NM + 5.064535672906197*^-6*NL + 
        2.2591948304331794*^-6*lm*NL + 9.905073533796463*^-7*lm^2*NL - 
        9.372443453107464*^-7*NH + 2.2591948304331794*^-6*lm*NH + 
        9.905073533796463*^-7*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.000017079477666242938 - 0.000017967330275971356*
           lm - 5.069889394837177*^-6*lm^2) + CF*(0.000021523399299263102 + 
          0.0000352710158488782*lm + 0.000033184730584388796*lm^2) + 
        5.355019425958854*^-7*NM + 2.093589776991148*^-6*lm*NM + 
        9.217980717885776*^-7*lm^2*NM + 4.701243623494613*^-6*NL + 
        2.093589776991148*^-6*lm*NL + 9.217980717885776*^-7*lm^2*NL - 
        8.681486835006163*^-7*NH + 2.093589776991148*^-6*lm*NH + 
        9.217980717885776*^-7*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.000015792982843290905 - 0.000016660104230574526*
           lm - 4.713877795875716*^-6*lm^2) + CF*(0.000019865010270757417 + 
          0.00003249613786544828*lm + 0.000030854472845731956*lm^2) + 
        4.6948321383918847*^-7*NM + 1.9382951635381777*^-6*lm*NM + 
        8.570686901592211*^-7*lm^2*NM + 4.3600557520156925*^-6*NL + 
        1.9382951635381777*^-6*lm*NL + 8.570686901592211*^-7*lm^2*NL - 
        8.033581385175134*^-7*NH + 1.9382951635381777*^-6*lm*NH + 
        8.570686901592211*^-7*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.000014589141638107447 - 0.000015432928638500445*
           lm - 4.378648032803162*^-6*lm^2) + CF*(0.00001831652910362112 + 
          0.000029907736340778*lm + 0.000028660241669257065*lm^2) + 
        4.0987606743924385*^-7*NM + 1.7927461580869523*^-6*lm*NM + 
        7.961178241460296*^-7*lm^2*NM + 4.039779760341029*^-6*NL + 
        1.7927461580869523*^-6*lm*NL + 7.961178241460296*^-7*lm^2*NL - 
        7.426394344539084*^-7*NH + 1.7927461580869523*^-6*lm*NH + 
        7.961178241460296*^-7*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.000013463257427410446 - 0.000014281513604289809*
           lm - 4.063145584526854*^-6*lm^2) + CF*(0.00001687148508167227 + 
          0.00002749485703307654*lm + 0.00002659513473508486*lm^2) + 
        3.5617399017683397*^-7*NM + 1.656406801054743*^-6*lm*NM + 
        7.387537426412461*^-7*lm^2*NM + 3.7392844315094326*^-6*NL + 
        1.656406801054743*^-6*lm*NL + 7.387537426412461*^-7*lm^2*NL - 
        6.857709061212644*^-7*NH + 1.656406801054743*^-6*lm*NH + 
        7.387537426412461*^-7*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.00001241088343791292 - 0.000013201784561364056*
           lm - 3.76636651264651*^-6*lm^2) + CF*(0.000015523761301843035 + 
          0.000025247133679751575*lm + 0.000024652580810049883*lm^2) + 
        3.0790466013924863*^-7*NM + 1.5287685784785698*^-6*lm*NM + 
        6.847939113902746*^-7*lm^2*NM + 3.4574965574361695*^-6*NL + 
        1.5287685784785698*^-6*lm*NL + 6.847939113902746*^-7*lm^2*NL - 
        6.325419461315768*^-7*NH + 1.5287685784785698*^-6*lm*NH + 
        6.847939113902746*^-7*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.00001142780989835865 - 0.000012189871763833579*lm - 
          3.4873550706979413*^-6*lm^2) + CF*(0.00001426757633531833 + 
          0.000023154758041609422*lm + 0.0000228263240991138*lm^2) + 
        2.6462783976709633*^-7*NM + 1.4093490646677388*^-6*lm*NM + 
        6.340645583087166*^-7*lm^2*NM + 3.1933980206394406*^-6*NL + 
        1.4093490646677388*^-6*lm*NL + 6.340645583087166*^-7*lm^2*NL - 
        5.827524777681643*^-7*NH + 1.4093490646677388*^-6*lm*NH + 
        6.340645583087166*^-7*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.000010510051840461175 - 0.000011242100286344684*
           lm - 3.225201426995947*^-6*lm^2) + CF*(0.00001309746679771653 + 
          0.00002120845142758639*lm + 0.000021110409340337108*lm^2) + 
        2.259333923356074*^-7*NM + 1.2976906309396407*^-6*lm*NM + 
        5.864002594538086*^-7*lm^2*NM + 2.946023022247244*^-6*NL + 
        1.2976906309396407*^-6*lm*NL + 5.864002594538086*^-7*lm^2*NL - 
        5.362124524538255*^-7*NH + 1.2976906309396407*^-6*lm*NH + 
        5.864002594538086*^-7*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-9.653837516372144*^-6 - 0.000010354980507431203*lm - 
          2.9790394955992555*^-6*lm^2) + CF*(0.000012008270785309781 + 
          0.000019399437628371697*lm + 0.000019499167607558763*lm^2) + 
        1.9143941484120305*^-7*NM + 1.1933592172455149*^-6*lm*NM + 
        5.4164354465441*^-7*lm^2*NM + 2.7144554489368487*^-6*NL + 
        1.1933592172455149*^-6*lm*NL + 5.4164354465441*^-7*lm^2*NL - 
        4.927413706792487*^-7*NH + 1.1933592172455149*^-6*lm*NH + 
        5.4164354465441*^-7*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-8.85559740189679*^-6 - 9.525199053021376*^-6*lm - 
          2.748044870189069*^-6*lm^2) + CF*(0.000010995112136189336 + 
          0.000017719417190672803*lm + 0.000017987202786692087*lm^2) + 
        1.6079048065728287*^-7*NM + 1.0959431636460855*^-6*lm*NM + 
        4.99644521852558*^-7*lm^2*NM + 2.4978263718286804*^-6*NL + 
        1.0959431636460855*^-6*lm*NL + 4.99644521852558*^-7*lm^2*NL - 
        4.5216782530683335*^-7*NH + 1.0959431636460855*^-6*lm*NH + 
        4.99644521852558*^-7*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-8.111953756189681*^-6 - 8.749610177878368*^-6*lm - 
          2.5314328559081285*^-6*lm^2) + CF*(0.000010053385477113647 + 
          0.000016160542967109053*lm + 0.00001656937869321684*lm^2) + 
        1.3365598569472948*^-7*NM + 1.0050520987429464*^-6*lm*NM + 
        4.6026051925602333*^-7*lm^2*NM + 2.295311670707522*^-6*NL + 
        1.0050520987429464*^-6*lm*NL + 4.6026051925602333*^-7*lm^2*NL - 
        4.143290662149774*^-7*NH + 1.0050520987429464*^-6*lm*NH + 
        4.6026051925602333*^-7*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-7.419710710106541*^-6 - 8.025227563826383*^-6*lm - 
          2.32845659444984*^-6*lm^2) + CF*(9.1787420185357*^-6 + 
          0.000014715396879806277*lm + 0.000015240806800035315*lm^2) + 
        1.0972859215370471*^-7*NM + 9.20315882310619*^-7*lm*NM + 
        4.233557444454254*^-7*lm^2*NM + 2.106129777277446*^-6*NL + 
        9.20315882310619*^-7*lm*NL + 4.233557444454254*^-7*lm^2*NL - 
        3.790705852954976*^-7*NH + 9.20315882310619*^-7*lm*NH + 
        4.233557444454254*^-7*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-6.7758448567610604*^-6 - 7.349216514636228*^-6*lm - 
          2.1384052779175668*^-6*lm^2) + CF*(8.367076061993753*^-6 + 
          0.0000133769678387097*lm + 0.000013996834546369528*lm^2) + 
        8.872276428501684*^-8*NM + 8.41383599506654*^-7*lm*NM + 
        3.8880095962137577*^-7*lm^2*NM + 1.929539531473689*^-6*NL + 
        8.41383599506654*^-7*lm*NL + 3.8880095962137577*^-7*lm^2*NL - 
        3.46245720862296*^-7*NH + 8.41383599506654*^-7*lm*NH + 
        3.8880095962137577*^-7*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-6.177496319142452*^-6 - 6.718886528416908*^-6*lm - 
          1.9606024471932743*^-6*lm^2) + CF*(7.614512185668654*^-6 + 
          0.000012138630758441385*lm + 0.000012833034199810522*lm^2) + 
        7.03733908927217*^-8*NM + 7.679226041633083*^-7*lm*NM + 
        3.5647317221695895*^-7*lm^2*NM + 1.764838145155566*^-6*NL + 
        7.679226041633083*^-7*lm*NL + 3.5647317221695895*^-7*lm^2*NL - 
        3.1571528057275177*^-7*NH + 7.679226041633083*^-7*lm*NH + 
        3.5647317221695895*^-7*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-5.621960270893168*^-6 - 6.131684229285628*^-6*lm - 
          1.7944043707629083*^-6*lm^2) + CF*(6.917393075463252*^-6 + 
          0.000010994126620207463*lm + 0.00001174519224499358*lm^2) + 
        5.4434489605669066*^-8*NM + 6.996176087844826*^-7*lm*NM + 
        3.262553401387106*^-7*lm^2*NM + 1.6113592677903172*^-6*NL + 
        6.996176087844826*^-7*lm*NL + 3.262553401387106*^-7*lm^2*NL - 
        2.8734718200469964*^-7*NH + 6.996176087844826*^-7*lm*NH + 
        3.262553401387106*^-7*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-5.106678887529589*^-6 - 5.585186640969809*^-6*lm - 
          1.6391985001437398*^-6*lm^2) + CF*(6.272267970447598*^-6 + 
          9.937543527815207*^-6*lm + 0.000010729299273668115*lm^2) + 
        4.0677988225362914*^-8*NM + 6.36169818986042*^-7*lm*NM + 
        2.9803609093522543*^-7*lm^2*NM + 1.4684711490091914*^-6*NL + 
        6.36169818986042*^-7*lm*NL + 2.9803609093522543*^-7*lm^2*NL - 
        2.610161100713485*^-7*NH + 6.36169818986042*^-7*lm*NH + 
        2.9803609093522543*^-7*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-4.629233706514386*^-6 - 5.0770947858333585*^-6*lm - 
          1.4944019982469149*^-6*lm^2) + CF*(5.675881692939685*^-6 + 
          8.963298709296136*^-6*lm + 9.781540352161624*^-6*lm^2) + 
        2.889257872165647*^-8*NM + 5.772961102266139*^-7*lm*NM + 
        2.717094542267118*^-7*lm^2*NM + 1.33557489317485*^-6*NL + 
        5.772961102266139*^-7*lm*NL + 2.717094542267118*^-7*lm^2*NL - 
        2.3660319049417423*^-7*NH + 5.772961102266139*^-7*lm*NH + 
        2.717094542267118*^-7*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-4.18733837566045*^-6 - 4.605227593617637*^-6*lm - 
          1.3594603371871414*^-6*lm^2) + CF*(5.125164234857617*^-6 + 
          8.066121417954016*^-6*lm + 8.898285843406743*^-6*lm^2) + 
        1.8882639697298055*^-8*NM + 5.22728244779736*^-7*lm*NM + 
        2.4717460676129843*^-7*lm^2*NM + 1.2121028013439673*^-6*NL + 
        5.22728244779736*^-7*lm*NL + 2.4717460676129843*^-7*lm^2*NL - 
        2.139956785897744*^-7*NH + 5.22728244779736*^-7*lm*NH + 
        2.4717460676129843*^-7*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-3.7788317703651953*^-6 - 4.167516104947161*^-6*lm - 
          1.2338459622212605*^-6*lm^2) + CF*(4.6172208732874485*^-6 + 
          7.241036688870865*^-6*lm + 8.076082661811886*^-6*lm^2) + 
        1.046722337797736*^-8*NM + 4.722121269970434*^-7*lm*NM + 
        2.2433562949477464*^-7*lm^2*NM + 1.0975167962413805*^-6*NL + 
        4.722121269970434*^-7*lm*NL + 2.2433562949477464*^-7*lm^2*NL - 
        1.930866626609815*^-7*NH + 4.722121269970434*^-7*lm*NH + 
        2.2433562949477464*^-7*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-3.4016714611432876*^-6 - 3.7619979553730037*^-6*lm - 
          1.1170570186588447*^-6*lm^2) + CF*(4.1493227894635386*^-6 + 
          6.483349909014788*^-6*lm + 7.311645940312437*^-6*lm^2) + 
        3.479103407053763*^-9*NM + 4.2550709500626804*^-7*lm*NM + 
        2.0310127611978992*^-7*lm^2*NM + 9.913069260829026*^-7*NL + 
        4.2550709500626804*^-7*lm*NL + 2.0310127611978992*^-7*lm^2*NL - 
        1.7377478131526016*^-7*NH + 4.2550709500626804*^-7*lm*NH + 
        2.0310127611978992*^-7*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-3.053927513847642*^-6 - 3.386812126414805*^-6*lm - 
          1.0086161387413705*^-6*lm^2) + CF*(3.7188981665571507*^-6 + 
          5.788632161105224*^-6*lm + 6.601851089943517*^-6*lm^2) - 
        2.2361200657063565*^-9*NM + 3.8238524707741594*^-7*lm*NM + 
        1.83384752498431*^-7*lm^2*NM + 8.929899432935429*^-7*NL + 
        3.8238524707741594*^-7*lm*NL + 1.83384752498431*^-7*lm^2*NL - 
        1.5596395406464574*^-7*NH + 3.8238524707741594*^-7*lm*NH + 
        1.83384752498431*^-7*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-2.733776605845216*^-6 - 3.0401939507169643*^-6*lm - 
          9.080692856323214*^-7*lm^2) + CF*(3.3235237428162297*^-6 + 
          5.1527063033084635*^-6*lm + 5.94372623322974*^-6*lm^2) - 
        6.820861313617259*^-9*NM + 3.4263080097577034*^-7*lm*NM + 
        1.651035064786039*^-7*lm^2*NM + 8.021079543669408*^-7*NL + 
        3.4263080097577034*^-7*lm*NL + 1.651035064786039*^-7*lm^2*NL - 
        1.3956312459127478*^-7*NH + 3.4263080097577034*^-7*lm*NH + 
        1.651035064786039*^-7*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-2.4394964422477933*^-6 - 2.720470359057605*^-6*lm - 
          8.149846517991644*^-7*lm^2) + CF*(2.9609167976966373*^-6 + 
          4.571633748663347*^-6*lm + 5.334444993594531*^-6*lm^2) - 
        1.0406339105646195*^-8*NM + 3.0603948470157604*^-7*lm*NM + 
        1.4817902759984807*^-7*lm^2*NM + 7.182271373008467*^-7*NL + 
        3.0603948470157604*^-7*lm*NL + 1.4817902759984807*^-7*lm^2*NL - 
        1.244860160909848*^-7*NH + 3.0603948470157604*^-7*lm*NH + 
        1.4817902759984807*^-7*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-2.1694604570906585*^-6 - 2.4260553575417073*^-6*lm - 
          7.289516091998958*^-7*lm^2) + CF*(2.6289275496746057*^-6 + 
          4.041701909877993*^-6*lm + 4.7713196238538635*^-6*lm^2) - 
        1.3113318870011749*^-8*NM + 2.724179570935577*^-7*lm*NM + 
        1.3253665621816288*^-7*lm^2*NM + 6.409365232229546*^-7*NL + 
        2.724179570935577*^-7*lm*NL + 1.3253665621816288*^-7*lm^2*NL - 
        1.1065089813457874*^-7*NH + 2.724179570935577*^-7*lm*NH + 
        1.3253665621816288*^-7*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-1.9221327851058004*^-6 - 2.155445723873972*^-6*lm - 
          6.495797088120811*^-7*lm^2) + CF*(2.3255319454335506*^-6 + 
          3.559412276797078*^-6*lm + 4.251794457679076*^-6*lm^2) - 
        1.505280972971159*^-8*NM + 2.4158325684701746*^-7*lm*NM + 
        1.1810540160219656*^-7*lm^2*NM + 5.698468389918229*^-7*NL + 
        2.4158325684701746*^-7*lm*NL + 1.1810540160219656*^-7*lm^2*NL - 
        9.798036451222116*^-8*NH + 2.4158325684701746*^-7*lm*NH + 
        1.1810540160219656*^-7*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-1.6960634904528482*^-6 - 1.907216912143751*^-6*lm - 
          5.764977271613747*^-7*lm^2) + CF*(2.0488248210774585*^-6 + 
          3.1214690954194167*^-6*lm + 3.773439668692635*^-6*lm^2) - 
        1.632671903318101*^-8*NM + 2.1336227856730604*^-7*lm*NM + 
        1.0481776857479542*^-7*lm^2*NM + 5.045894077194309*^-7*NL + 
        2.1336227856730604*^-7*lm*NL + 1.0481776857479542*^-7*lm^2*NL - 
        8.640112155111388*^-8*NH + 2.1336227856730604*^-7*lm*NH + 
        1.0481776857479542*^-7*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-1.4898840394522221*^-6 - 1.6800191560652203*^-6*lm - 
          5.093527576196916*^-7*lm^2) + CF*(1.797013416939603*^-6 + 
          2.7247686188509124*^-6*lm + 3.333945322601618*^-6*lm^2) - 
        1.7028466854402102*^-8*NM + 1.8759127454614447*^-7*lm*NM + 
        9.26095922944894*^-8*lm^2*NM + 4.448151043155698*^-7*NL + 
        1.8759127454614447*^-7*lm*NL + 9.26095922944894*^-8*lm^2*NL - 
        7.584378642014373*^-8*NH + 1.8759127454614447*^-7*lm*NH + 
        9.26095922944894*^-8*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-1.3023030050125554*^-6 - 1.4725737611019956*^-6*lm - 
          4.4780934435081403*^-7*lm^2) + CF*(1.5684112284309754*^-6 + 
          2.3663889020118255*^-6*lm + 2.9311157084780552*^-6*lm^2) - 
        1.7243562796235126*^-8*NM + 1.641153810117447*^-7*lm*NM + 
        8.141988079105709*^-8*lm^2*NM + 3.901933633001468*^-7*NL + 
        1.641153810117447*^-7*lm*NL + 8.141988079105709*^-8*lm^2*NL - 
        6.624269495765525*^-8*NH + 1.641153810117447*^-7*lm*NH + 
        8.141988079105709*^-8*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-1.1321019910600591*^-6 - 1.2836695763679156*^-6*lm - 
          3.9154865688353544*^-7*lm^2) + CF*(1.361432176209219*^-6 + 
          2.043580113282992*^-6*lm + 2.562863935964959*^-6*lm^2) - 
        1.7050147298067586*^-8*NM + 1.4278816766409217*^-7*lm*NM + 
        7.119066488791554*^-8*lm^2*NM + 3.404112362680016*^-7*NL + 
        1.4278816766409217*^-7*lm*NL + 7.119066488791554*^-8*lm^2*NL - 
        5.7535718579927264*^-8*NH + 1.4278816766409217*^-7*lm*NH + 
        7.119066488791554*^-8*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-9.781317658626022*^-7 - 1.1121596376357932*^-6*lm - 
          3.4026770338972785*^-7*lm^2) + CF*(1.1745850797475887*^-6 + 
          1.7537553375763055*^-6*lm + 2.227206785823673*^-6*lm^2) - 
        1.6519499523636715*^-8*NM + 1.2347120936425678*^-7*lm*NM + 
        6.186685516176869*^-8*lm^2*NM + 2.951724965223504*^-7*NL + 
        1.2347120936425678*^-7*lm*NL + 6.186685516176869*^-8*lm^2*NL - 
        4.966408984837084*^-8*NH + 1.2347120936425678*^-7*lm*NH + 
        6.186685516176869*^-8*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-8.393085936974123*^-7 - 9.56957973204693*^-7*lm - 
          2.93678580837227*^-7*lm^2) + CF*(1.006468419146064*^-6 + 
          1.4944818465534349*^-6*lm + 1.9222598018436677*^-6*lm^2) - 
        1.571651378666541*^-8*NM + 1.0603367890132963*^-7*lm*NM + 
        5.339610560676855*^-8*lm^2*NM + 2.5419678851784623*^-7*NL + 
        1.0603367890132963*^-7*lm*NL + 5.339610560676855*^-8*lm^2*NL - 
        4.257223629296262*^-8*NH + 1.0603367890132963*^-7*lm*NH + 
        5.339610560676855*^-8*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-7.146107548398543*^-7 - 8.17036564774758*^-7*lm - 
          2.5150776027540046*^-7*lm^2) + CF*(8.557653707547049*^-7 + 
          1.2634728128962512*^-6*lm + 1.6462326127117122*^-6*lm^2) - 
        1.4700146360370542*^-8*NM + 9.035195981267324*^-8*lm*NM + 
        4.572868368643645*^-8*lm^2*NM + 2.1721881987280995*^-7*NL + 
        9.035195981267324*^-8*lm*NL + 4.572868368643645*^-8*lm^2*NL - 
        3.620762210802552*^-8*NH + 9.035195981267324*^-8*lm*NH + 
        4.572868368643645*^-8*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-6.030752443530377*^-7 - 6.914224558577493*^-7*lm - 
          2.1349540559491794*^-7*lm^2) + CF*(7.212391028740924*^-7 + 
          1.0585794466555676*^-6*lm + 1.3974244729849174*^-6*lm^2) - 
        1.3523834411587288*^-8*NM + 7.630927828275027*^-8*lm*NM + 
        3.881734647180326*^-8*lm^2*NM + 1.8398759382275934*^-7*NL + 
        7.630927828275027*^-8*lm*NL + 3.881734647180326*^-8*lm^2*NL - 
        3.052059735420885*^-8*NH + 7.630927828275027*^-8*lm*NH + 
        3.881734647180326*^-8*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-5.037946406353614*^-7 - 5.791950006122291*^-7*lm - 
          1.7939472418280573*^-7*lm^2) + CF*(6.017283184606228*^-7 + 
          8.777835327741503*^-7*lm + 1.1742200128329102*^-6*lm^2) - 
        1.2235888700855853*^-8*NM + 6.379535319297917*^-8*lm*NM + 
        3.261722257869195*^-8*lm^2*NM + 1.5426568009425207*^-7*NL + 
        6.379535319297917*^-8*lm*NL + 3.261722257869195*^-8*lm^2*NL - 
        2.5464254317441982*^-8*NH + 6.379535319297917*^-8*lm*NH + 
        3.261722257869195*^-8*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-4.1591413513670766*^-7 - 4.79483246335603*^-7*lm - 
          1.4897134796953324*^-7*lm^2) + CF*(4.961430323968757*^-7 + 
          7.19190349898055*^-7*lm + 9.750851867096722*^-7*lm^2) - 
        1.0879861596008297*^-8*NM + 5.270606343996969*^-8*lm*NM + 
        2.708569963082423*^-8*lm^2*NM + 1.2782852227954468*^-7*NL + 
        5.270606343996969*^-8*lm*NL + 2.708569963082423*^-8*lm^2*NL - 
        2.0994290691777187*^-8*NH + 5.270606343996969*^-8*lm*NH + 
        2.708569963082423*^-8*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-3.386287150850279*^-7 - 3.9146344317187477*^-7*lm - 
          1.2200274343685092*^-7*lm^2) + CF*(4.034605714905333*^-7 + 
          5.810219515596096*^-7*lm + 7.985634115866606*^-7*lm^2) - 
        9.494891858262134*^-9*NM + 4.294313168222661*^-8*lm*NM + 
        2.218231698851835*^-8*lm^2*NM + 1.0446377988893079*^-7*NL + 
        4.294313168222661*^-8*lm*NL + 2.218231698851835*^-8*lm^2*NL - 
        1.706887926843391*^-8*NH + 4.294313168222661*^-8*lm*NH + 
        2.218231698851835*^-8*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-2.711804914746278*^-7 - 3.1435667490478304*^-7*lm - 
          9.827764922355482*^-8*lm^2) + CF*(3.2272178594063923*^-7 + 
          4.616107917380408*^-7*lm + 6.432718858269043*^-7*lm^2) - 
        8.116027576280166*^-9*NM + 3.44138237160801*^-8*lm*NM + 
        1.7868663495191787*^-8*lm^2*NM + 8.397070334911692*^-8*NL + 
        3.44138237160801*^-8*lm*NL + 1.7868663495191787*^-8*lm^2*NL - 
        1.3648543828043094*^-8*NH + 3.44138237160801*^-8*lm*NH + 
        1.7868663495191787*^-8*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-2.1285616495660547*^-7 - 2.4742660500173367*^-7*lm - 
          7.759554003147174*^-8*lm^2) + CF*(2.530274615585687*^-7 + 
          3.593936776820751*^-7*lm + 5.078980802059968*^-7*lm^2) - 
        6.7745285448146245*^-9*NM + 2.7030662720305222*^-8*lm*NM + 
        1.4108280005722134*^-8*lm^2*NM + 6.615954030286747*^-8*NL + 
        2.7030662720305222*^-8*lm*NL + 1.4108280005722134*^-8*lm^2*NL - 
        1.069604094709864*^-8*NH + 2.7030662720305222*^-8*lm*NH + 
        1.4108280005722134*^-8*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-1.629846226416341*^-7 - 1.8997733235536774*^-7*lm - 
          5.976611559590367*^-8*lm^2) + CF*(1.935349225540618*^-7 + 
          2.729060337148805*^-7*lm + 3.911963929913695*^-7*lm^2) - 
        5.498149310155939*^-9*NM + 2.0711157645725515*^-8*lm*NM + 
        1.0866566471982484*^-8*lm^2*NM + 5.085097164763821*^-8*NL + 
        2.0711157645725515*^-8*lm*NL + 1.0866566471982484*^-8*lm^2*NL - 
        8.176247442985112*^-9*NH + 2.0711157645725515*^-8*lm*NH + 
        1.0866566471982484*^-8*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-1.2093465917656685*^-7 - 1.4135135143738471*^-7*lm - 
          4.4608813543701875*^-8*lm^2) + CF*(1.4345481519520168*^-7 + 
          2.0077646053747528*^-7*lm + 2.919849613769577*^-7*lm^2) - 
        4.311404034404265*^-9*NM + 1.53775450611472*^-8*lm*NM + 
        8.11069337158216*^-9*lm^2*NM + 3.7875575829242166*^-8*NL + 
        1.53775450611472*^-8*lm*NL + 8.11069337158216*^-9*lm^2*NL - 
        6.056053194695932*^-9*NH + 1.53775450611472*^-8*lm*NH + 
        8.11069337158216*^-9*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-8.611281579008085*^-8 - 1.0092761183405604*^-7*lm - 
          3.195234501820608*^-8*lm^2) + CF*(1.0204806312633911*^-7 + 
          1.41721575304111*^-7*lm + 2.0914262193734888*^-7*lm^2) - 
        3.235814264341023*^-9*NM + 1.0956543800326136*^-8*lm*NM + 
        5.809517276037469*^-9*lm^2*NM + 2.7073319980962256*^-8*NL + 
        1.0956543800326136*^-8*lm*NL + 5.809517276037469*^-9*lm^2*NL - 
        4.304259088513275*^-9*NH + 1.0956543800326136*^-8*lm*NH + 
        5.809517276037469*^-9*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-5.7961331319645434*^-8 - 6.811967237533689*^-8*lm - 
          2.163425200362776*^-8*lm^2) + CF*(6.862298558072416*^-8 + 
          9.454111846395264*^-8*lm + 1.4160601311465443*^-7*lm^2) - 
        2.290140628176947*^-9*NM + 7.379121786411854*^-9*lm*NM + 
        3.933500364295956*^-9*lm^2*NM + 1.8293076569143822*^-8*NL + 
        7.379121786411854*^-9*lm*NL + 3.933500364295956*^-9*lm^2*NL - 
        2.891479849516385*^-9*NH + 7.379121786411854*^-9*lm*NH + 
        3.933500364295956*^-9*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-3.5956199533311434*^-8 - 4.2373945300213866*^-8*lm - 
          1.350048533221119*^-8*lm^2) + CF*(4.253257015598771*^-8 + 
          5.811331404937518*^-8*lm + 8.836681308356415*^-8*lm^2) - 
        1.4905994244833534*^-9*NM + 4.58027444051894*^-9*lm*NM + 
        2.4546336967656706*^-9*lm^2*NM + 1.1392164273356678*^-8*NL + 
        4.58027444051894*^-9*lm*NL + 2.4546336967656706*^-9*lm^2*NL - 
        1.7900515308454593*^-9*NH + 4.58027444051894*^-9*lm*NH + 
        2.4546336967656706*^-9*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-1.960532734596837*^-8 - 2.3168026120487215*^-8*lm - 
          7.40500240580141*^-9*lm^2) + CF*(2.317189223157427*^-8 + 
          3.1390470744017385*^-8*lm + 4.846910665615468*^-8*lm^2) - 
        8.510650119771674*^-10*NM + 2.4988141098204897*^-9*lm*NM + 
        1.3463640737820745*^-9*lm^2*NM + 6.235911892890945*^-9*NL + 
        2.4988141098204897*^-9*lm*NL + 1.3463640737820745*^-9*lm^2*NL - 
        9.739434431977999*^-10*NH + 2.4988141098204897*^-9*lm*NH + 
        1.3463640737820745*^-9*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-8.446788801544136*^-9 - 1.0009105054119044*^-8*lm - 
          3.209383709405354*^-9*lm^2) + CF*(9.975673498676102*^-9 + 
          1.3394811684964978*^-8*lm + 2.1006875188835044*^-8*lm^2) - 
        3.8325885634114923*^-10*NM + 1.0771699779113146*^-9*lm*NM + 
        5.835243108009735*^-10*lm^2*NM + 2.6972441318158646*^-9*NL + 
        1.0771699779113146*^-9*lm*NL + 5.835243108009735*^-10*lm^2*NL - 
        4.186743170955411*^-10*NH + 1.0771699779113146*^-9*lm*NH + 
        5.835243108009735*^-10*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-2.047169950842314*^-9 - 2.432456098101262*^-9*lm - 
          7.82467238067098*^-10*lm^2) + CF*(2.4159724460346*^-9 + 
          3.2145215445814205*^-9*lm + 5.1216037400755504*^-9*lm^2) - 
        9.692604074257297*^-11*NM + 2.611979462177605*^-10*lm*NM + 
        1.4226677055765418*^-10*lm^2*NM + 6.562881722480025*^-10*NL + 
        2.611979462177605*^-10*lm*NL + 1.4226677055765418*^-10*lm^2*NL - 
        1.0123250006218828*^-10*NH + 2.611979462177605*^-10*lm*NH + 
        1.4226677055765418*^-10*lm^2*NH)}, {1., 0.}}

CbarSeries["v", 2, -1, "x0"] = SeriesData[x, 0, 
     {(CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 391*Pi^4 + 
           20*Pi^2*(-73 + 96*Log[2]^2) + 15*(869 + 936*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 144*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             128*Log[2]^4 - 156*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
             2712*Zeta[3]) - 10*lm*(-1233 + 44*Pi^2 + 648*Zeta[3])) + 
         2*(CF*(5670*lm^2 - 3240*lm^3 + 981*Pi^4 + 10*Pi^2*(259 + 576*
                Log[2]^2) + 15*(1025 + 2808*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 432*Im[PolyLog[2, (-1)^(1/3)]]^2 - 384*
                Log[2]^4 - 468*PolyGamma[2, 1] - 9216*PolyLog[4, 1/2] - 10464*
                Zeta[3]) + 135*lm*(95 + 8*Pi^2 - 144*Zeta[3])) - 
           15*(NL*(-219 - 162*lm - 84*lm^2 - 24*lm^3 + 28*Pi^2 + 8*lm*Pi^2 - 
               288*Zeta[3]) + NM*(-219 - 84*lm^2 - 24*lm^3 + 28*Pi^2 + 2*lm*
                (-81 + 4*Pi^2) + 8*PolyGamma[2, 1] - 272*Zeta[3]) - 
             NH*(-837 + 162*lm + 84*lm^2 + 24*lm^3 - 8*lm*Pi^2 - 1296*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 216*PolyGamma[2, 1] + 
               2928*Zeta[3])))))/25920, 
      -(CF*NC*(-3*CA*(18240*lm^2 + 2640*lm^3 + 647*Pi^4 + 
            30*Pi^2*(5 + 128*Log[2]^2) + 30*(2255 + 216*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 216*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              128*Log[2]^4 - 36*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
              1540*Zeta[3]) - 180*lm*(-275 + 72*Zeta[3])) + 
          2*(CF*(1620*lm^2 - 6480*lm^3 + 1941*Pi^4 + 10*Pi^2*(59 + 
                1152*Log[2]^2) + 15*(1207 + 1296*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 1296*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                768*Log[2]^4 - 216*PolyGamma[2, 1] - 18432*PolyLog[4, 1/2] - 
                11784*Zeta[3]) - 270*lm*(-41 + 144*Zeta[3])) - 
            180*(NM*(-82 - 57*lm - 20*lm^2 - 4*lm^3 + 2*Pi^2 - 32*Zeta[3]) + 
              NL*(-82 - 57*lm - 20*lm^2 - 4*lm^3 + 2*Pi^2 - 32*Zeta[3]) - 
              NH*(178 + 57*lm + 20*lm^2 + 4*lm^3 - 216*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 36*PolyGamma[2, 1] + 
                200*Zeta[3])))))/25920, 
      (CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 236*Pi^4 + 
           30*Pi^2*(51 + 64*Log[2]^2) + 15*(1523 + 1224*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 128*Log[2]^4 - 
             300*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 3968*Zeta[3]) + 
           10*lm*(1497 + 44*Pi^2 - 648*Zeta[3])) + 
         10*(CF*(1134*lm^2 - 648*lm^3 + 180*Pi^4 + 8*Pi^2*(-17 + 144*
                Log[2]^2) + 3*(1643 + 3672*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] - 384*Log[2]^4 - 900*PolyGamma[2, 1] - 9216*
                PolyLog[4, 1/2] - 13560*Zeta[3]) - 27*lm*(-47 + 8*Pi^2 + 144*
                Zeta[3])) + 3*(NM*(-1773 + 84*lm^2 + 24*lm^3 + 140*Pi^2 + lm*
                (210 + 8*Pi^2) - 40*PolyGamma[2, 1] + 16*Zeta[3]) + 
             NL*(387 + 210*lm + 84*lm^2 + 24*lm^3 - 4*Pi^2 + 8*lm*Pi^2 + 96*
                Zeta[3]) + NH*(339 + 210*lm + 84*lm^2 + 24*lm^3 + 8*lm*
                Pi^2 - 3888*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 792*
                PolyGamma[2, 1] + 6768*Zeta[3])))))/25920, 
      (CF*NC*(-34875*CF + 82080*NM - 4320*NL - 351200*NH - 4380*CF*Pi^2 - 
         7200*NM*Pi^2 + 1440*NL*Pi^2 + 6300*Sqrt[3]*CF*Pi^3 + 
         8400*Sqrt[3]*NH*Pi^3 + 648*CF*Pi^4 - 64800*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] + 120960*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 51840*CF*Im[PolyLog[2, (-1)^(1/3)]]^
           2 + 233280*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         311040*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         4860*Sqrt[3]*CF*Pi*Log[3]^2 + 6480*Sqrt[3]*NH*Pi*Log[3]^2 - 
         2880*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
           4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         11520*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
         25920*CF*PolyGamma[2, 1] + 1440*NM*PolyGamma[2, 1] - 
         24480*NH*PolyGamma[2, 1] - 34560*CF*Zeta[3] - 83520*NM*Zeta[3] + 
         17280*NL*Zeta[3] - 198720*NH*Zeta[3] - 
         6*CA*(-430*Pi^2 + 525*Sqrt[3]*Pi^3 + 54*Pi^4 + 405*Sqrt[3]*Pi*
            Log[3]^2 - 120*(22 + 45*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             36*Im[PolyLog[2, (-1)^(1/3)]]^2 - 162*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] - 18*PolyGamma[2, 1] + 21*Zeta[3])) - 
         120*Log[x]*(-3*CA*(608*lm + 132*lm^2 + 3*(241 - 9*Pi^2 + 36*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 96*Zeta[3])) + 
           2*(135*NL + 120*lm*NL + 36*lm^2*NL - 889*NH + 120*lm*NH + 
             36*lm^2*NH - 12*NL*Pi^2 + 3*NM*(189 + 40*lm + 12*lm^2 - 4*
                Pi^2) + 432*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
             3*CF*(60 - 18*lm + 108*lm^2 + 29*Pi^2 - 108*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3])))))/25920, 
      -(CF*NC*(-25083*CF - 3888*CF*lm - 21336*NM + 432*lm*NM - 504*NL + 
          432*lm*NL - 72184*NH + 432*lm*NH + 1728*CF*Pi^2 - 
          1632*NM*Pi^2 + 96*NL*Pi^2 + 980*Sqrt[3]*CF*Pi^3 + 
          1680*Sqrt[3]*NH*Pi^3 - 54864*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 65664*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 36288*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 62208*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 756*Sqrt[3]*CF*Pi*
           Log[3]^2 + 1296*Sqrt[3]*NH*Pi*Log[3]^2 - 
          576*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
            4*(2*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          2304*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          15552*CF*PolyGamma[2, 1] - 3456*NM*PolyGamma[2, 1] - 
          16128*NH*PolyGamma[2, 1] + 109152*CF*Zeta[3] - 3456*NM*Zeta[3] + 
          3456*NL*Zeta[3] - 122112*NH*Zeta[3] - 
          2*CA*(1188*lm + 57*Pi^2 + 245*Sqrt[3]*Pi^3 + 189*Sqrt[3]*Pi*
             Log[3]^2 - 36*(381*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              4*(-4 + 63*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                27*PolyGamma[2, 1] + 179*Zeta[3]))) - 
          24*Log[x]*(3*CA*(-687 - 608*lm - 132*lm^2 + 61*Pi^2 - 
              84*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3]) + 
            2*(135*NL + 120*lm*NL + 36*lm^2*NL - 889*NH + 120*lm*NH + 
              36*lm^2*NH - 12*NL*Pi^2 + 3*NM*(-47 + 40*lm + 12*lm^2 + 
                20*Pi^2) + 432*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
              3*CF*(165 - 18*lm + 108*lm^2 + 71*Pi^2 - 84*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3])))))/10368, 
      (CF*NC*(-259200*(15*CA*(53 + 22*lm) + 2*(30*CF*(-2 + 9*lm) - 130*NM - 
             30*lm*NM - 45*NL - 30*lm*NL - 8*NH - 30*lm*NH))*Log[x]^2 + 
         5184000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 - 
         1080*Log[x]*(8*(25*NL*(3 + 40*lm + 12*lm^2 - 8*Pi^2) + 
             25*NM*(217 + 40*lm + 12*lm^2 + 16*Pi^2) + 
             NH*(-14923 + 1000*lm + 300*lm^2 + 8000*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) - 50*CF*(1317 - 72*lm + 
             432*lm^2 + 98*Pi^2 - 792*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             1152*Zeta[3]) + 25*CA*(-1851 - 2432*lm - 528*lm^2 + 106*Pi^2 - 
             792*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1152*Zeta[3])) - 
         225*CA*(-560*Pi^2 + 7700*Sqrt[3]*Pi^3 + 432*Pi^4 + 
           5940*Sqrt[3]*Pi*Log[3]^2 + 15*(-10411 - 4560*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 19008*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             2304*PolyGamma[2, 1] + 1216*Zeta[3])) + 
         2*(16*(2*NH*(87500*Sqrt[3]*Pi^3 + 67500*Sqrt[3]*Pi*Log[3]^2 + 9*
                (-324269 + 72000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                 360000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                 18750*PolyGamma[2, 1] - 175500*Zeta[3])) + 
             4500*NM*(-82 + 12*Pi^2 - 21*PolyGamma[2, 1] - 402*Zeta[3]) + 
             3375*NL*(-75 + 4*Pi^2 + 96*Zeta[3])) + 
           225*CF*(72*Pi^2 + 7700*Sqrt[3]*Pi^3 + 432*Pi^4 + 
             5940*Sqrt[3]*Pi*Log[3]^2 + 15*(-10821 - 4560*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^
                 2 + 19008*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               2304*PolyGamma[2, 1] + 1408*Zeta[3])))))/7776000, 
      -(CF*NC*(-86400*(120*CA*(26 + 11*lm) + 5*CF*(-133 + 432*lm) - 
            2*(502*NM + 120*lm*NM + 195*NL + 120*lm*NL + 36*NH + 
              120*lm*NH))*Log[x]^2 + 3456000*(40*CA + 49*CF - 11*NM - 
            4*NL)*Log[x]^3 - 125*CA*(7920*lm + 78948*Pi^2 + 
            17920*Sqrt[3]*Pi^3 + 13824*Sqrt[3]*Pi*Log[3]^2 - 
            9*(207425 + 68224*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              73728*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              25920*PolyGamma[2, 1] - 220416*Zeta[3])) + 
          360*Log[x]*(-2*(2*(75*NL*(35 + 112*lm + 36*lm^2 - 20*Pi^2) + 
                NM*(12521 + 8400*lm + 2700*lm^2 + 12300*Pi^2) + 
                NH*(-134107 + 8400*lm + 2700*lm^2 + 73200*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 75*CF*(-8011 + 252*lm - 
                648*lm^2 + 112*Pi^2 + 1024*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 1728*Zeta[3])) + 75*CA*(-3227 + 3472*lm + 
              792*lm^2 + 172*Pi^2 + 1024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              1728*Zeta[3])) + 8*(125*CF*(-511485 - 1620*lm + 21600*Pi^2 + 
              4480*Sqrt[3]*Pi^3 - 153504*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              165888*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              3456*Sqrt[3]*Pi*Log[3]^2 + 58320*PolyGamma[2, 1] + 
              525096*Zeta[3]) + 2*(NH*(11250*lm + 533750*Sqrt[3]*Pi^3 + 
                411750*Sqrt[3]*Pi*Log[3]^2 + 9*(-2131739 + 1238000*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]] + 2196000*Sqrt[3]*
                   Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 354000*PolyGamma[
                    2, 1] - 2592000*Zeta[3])) + 3*NM*(-1964849 + 3750*lm + 
                46500*Pi^2 - 468000*PolyGamma[2, 1] - 1746000*Zeta[3]) + 
              1125*NL*(-553 + 10*lm + 20*Pi^2 + 720*Zeta[3])))))/23328000, 
      (CF*NC*(-90542867625*CF - 64412699904*NM - 11113200000*NL - 
         213683340384*NH + 178737300*CF*Pi^2 + 5000940000*NM*Pi^2 + 
         333396000*NL*Pi^2 + 3727552500*Sqrt[3]*CF*Pi^3 + 
         7034930000*Sqrt[3]*NH*Pi^3 + 150028200*CF*Pi^4 - 
         33784128000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         32154192000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         12002256000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 138025944000*Sqrt[3]*
          CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 260493408000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2875540500*Sqrt[3]*CF*Pi*
          Log[3]^2 + 5426946000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         9525600*(35*CA*(637 + 264*lm) + 2*(35*CF*(-43 + 216*lm) - 
             2*(2583*NM + 420*lm*NM + 595*NL + 420*lm*NL + 153*NH + 420*
                lm*NH)))*Log[x]^2 + 3556224000*(22*CA + 86*CF - 
           3*(7*NM + NL))*Log[x]^3 + 18003384000*CF*PolyGamma[2, 1] - 
         5000940000*NM*PolyGamma[2, 1] - 11002068000*NH*PolyGamma[2, 1] + 
         21337344000*CF*Zeta[3] - 46008648000*NM*Zeta[3] + 
         12002256000*NL*Zeta[3] - 110020680000*NH*Zeta[3] - 
         7560*Log[x]*(-600642*NM + 882000*lm*NM + 264600*lm^2*NM - 
           815850*NL + 882000*lm*NL + 264600*lm^2*NL - 20925882*NH + 
           882000*lm*NH + 264600*lm^2*NH + 2381400*NM*Pi^2 - 
           264600*NL*Pi^2 + 11485600*Sqrt[3]*NH*
            Im[PolyLog[2, (-1)^(1/3)]] + 3675*CA*(-500 - 1824*lm - 396*lm^2 + 
             43*Pi^2 - 828*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             864*Zeta[3]) - 2450*CF*(5651 - 162*lm + 972*lm^2 + 123*Pi^2 - 
             2484*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 2592*Zeta[3])) - 
         77175*CA*(1692*Pi^2 + 24150*Sqrt[3]*Pi^3 + 972*Pi^4 + 
           18630*Sqrt[3]*Pi*Log[3]^2 + 5*(-116717 - 43776*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 15552*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 178848*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             23328*PolyGamma[2, 1] + 27216*Zeta[3]))))/6001128000, 
      (2188945*CF^2*NC)/62208 + (7*CF^2*lm*NC)/288 + (136898029*CF*NM*NC)/
        16669800 - (7*CF*lm*NM*NC)/2592 + (3757*CF*NC*NL)/5184 - 
       (7*CF*lm*NC*NL)/2592 + (4452593609*CF*NC*NH)/222264000 - 
       (7*CF*lm*NC*NH)/2592 - (5273*CF^2*NC*Pi^2)/17280 - 
       (131*CF*NM*NC*Pi^2)/324 - (11*CF*NC*NL*Pi^2)/648 - 
       (123445*CF^2*NC*Pi^3)/(139968*Sqrt[3]) - (10535*CF*NC*NH*Pi^3)/
        (5832*Sqrt[3]) + (61829*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2592*Sqrt[3]) - (694*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27*Sqrt[3]) - (3527*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (108*Sqrt[3]) - (602*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9*Sqrt[3]) - (3527*CF^2*NC*Pi*Log[3]^2)/(5184*Sqrt[3]) - 
       (301*CF*NC*NH*Pi*Log[3]^2)/(216*Sqrt[3]) + 
       (CF*NC*(70*CA*(809 + 660*lm) + 35*CF*(2279 + 2160*lm) - 
          4*(5*(2861 + 420*lm)*NM + 12*(35*(8 + 5*lm)*NL + 
              (66 + 175*lm)*NH)))*Log[x]^2)/7560 - 
       (CF*NC*(345*CA + 4*(7*CF - 46*NM - 5*NL))*Log[x]^3)/27 - 
       (7*CF^2*NC*PolyGamma[2, 1])/2 + (43*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (76*CF*NC*NH*PolyGamma[2, 1])/27 + 
       (CA*CF*NC*(124740*lm + 1131003*Pi^2 + 1234450*Sqrt[3]*Pi^3 + 
          952290*Sqrt[3]*Pi*Log[3]^2 - 135*(1038271 + 247316*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 338592*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 108864*PolyGamma[2, 1] - 
            1107216*Zeta[3])))/8398080 + 
       (CF*NC*Log[x]*(2*(24*(3675*NL*(-26 + 55*lm + 18*lm^2 - 14*Pi^2) + 
              5*NM*(-154442 + 40425*lm + 13230*lm^2 + 177870*Pi^2) + 
              NH*(-5299507 + 202125*lm + 66150*lm^2 + 2949800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 1225*CF*(-362181 + 5184*lm - 
              11664*lm^2 + 23742*Pi^2 + 28216*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 31104*Zeta[3])) - 
          1225*CA*(-276525 + 61704*lm + 14256*lm^2 + 25758*Pi^2 + 
            28216*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 31104*Zeta[3])))/
        19051200 - (2675*CF^2*NC*Zeta[3])/72 + (131*CF*NM*NC*Zeta[3])/27 - 
       (7*CF*NC*NL*Zeta[3])/9 + (182*CF*NC*NH*Zeta[3])/9, 
      (CF*NC*(-7144200*(315*CA*(4057 + 1760*lm) + 
           2*(315*CF*(-101 + 1440*lm) - 8*(3*(-611 + 2100*lm)*NM + 210*
                (41 + 30*lm)*NL + 5*(527 + 1260*lm)*NH)))*Log[x]^2 + 
         4000752000*(1025*CA + 4010*CF - 24*(92*NM + 5*NL))*Log[x]^3 + 
         1890*Log[x]*(-2*(8*(27*NM*(-7993673 + 294000*lm + 88200*lm^2 + 
                 2704800*Pi^2) - 5*(26460*NL*(115 - 60*lm - 18*lm^2 + 
                   24*Pi^2) - NH*(-52968051 + 1587600*lm + 476280*lm^2 + 
                   29384320*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
             3675*CF*(-445737 + 7776*lm - 46656*lm^2 + 11484*Pi^2 + 150512*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 124416*Zeta[3])) + 
           3675*CA*(-106869 + 262656*lm + 57024*lm^2 + 11484*Pi^2 + 
             150512*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 124416*Zeta[3])) - 
         25725*CA*(-883791*Pi^2 + 3292450*Sqrt[3]*Pi^3 + 104976*Pi^4 + 
           2539890*Sqrt[3]*Pi*Log[3]^2 - 45*(685324*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 186624*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             3*(-599701 + 903072*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                    Sqrt[3])]] + 124416*PolyGamma[2, 1] + 230832*Zeta[3]))) + 
         2*(3675*CF*(-6583113*Pi^2 + 23047150*Sqrt[3]*Pi^3 + 734832*Pi^4 + 
             17779230*Sqrt[3]*Pi*Log[3]^2 - 1260*(448266 + 171331*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 46656*Im[PolyLog[2, (-1)^(1/3)]]^
                 2 - 677304*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
               93312*PolyGamma[2, 1] - 173124*Zeta[3])) - 
           2*(243*NM*(3415153639 + 144060000*Pi^2 + 284004000*PolyGamma[2, 
                 1] - 321048000*Zeta[3]) - 5*(NH*(17997896000*Sqrt[3]*Pi^3 + 
                 13884091200*Sqrt[3]*Pi*Log[3]^2 + 9*(-57474588853 + 
                   5860086400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                   74048486400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[
                         3])]] - 2733847200*PolyGamma[2, 1] - 28405339200*
                    Zeta[3])) + 4167450*NL*(-6883 + 144*Pi^2 + 
                 6912*Zeta[3]))))))/216040608000, 
      (10864813831*CF^2*NC)/349920000 + (9*CF^2*lm*NC)/800 + 
       (21007793549*CF*NM*NC)/2000376000 - (CF*lm*NM*NC)/800 + 
       (43361*CF*NC*NL)/43200 - (CF*lm*NC*NL)/800 + (81967377167*CF*NC*NH)/
        3000564000 - (CF*lm*NC*NH)/800 + (280619*CF^2*NC*Pi^2)/60480 + 
       (47*CF*NM*NC*Pi^2)/180 - (19*CF*NC*NL*Pi^2)/1080 - 
       (31409*CF^2*NC*Pi^3)/(26244*Sqrt[3]) - (135905*CF*NC*NH*Pi^3)/
        (52488*Sqrt[3]) + (3073733*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (109350*Sqrt[3]) - (20102*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (729*Sqrt[3]) - (17948*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (405*Sqrt[3]) - (7766*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) - 
       (4487*CF^2*NC*Pi*Log[3]^2)/(4860*Sqrt[3]) - 
       (3883*CF*NC*NH*Pi*Log[3]^2)/(1944*Sqrt[3]) + 
       (CF*NC*(21*CA*(-161837 + 52800*lm) + 2*(21*CF*(270319 + 43200*lm) - 
            40*(18*(-31 + 140*lm)*NM + 5*(798*NL + 504*lm*NL + 205*NH + 
                504*lm*NH))))*Log[x]^2)/151200 + 
       (CF*NC*(-2889*CA + 2650*CF + 1920*NM + 80*NL)*Log[x]^3)/90 - 
       (9*CF^2*NC*PolyGamma[2, 1])/2 + (20*CF*NM*NC*PolyGamma[2, 1])/9 + 
       (31*CF*NC*NH*PolyGamma[2, 1])/9 + 
       (CF*NC*Log[x]*(80*(13230*NL*(-337 + 273*lm + 90*lm^2 - 90*Pi^2) + 
            9*NM*(-13448069 + 401310*lm + 132300*lm^2 + 4806900*Pi^2) + 
            NH*(-135717597 + 3611790*lm + 1190700*lm^2 + 76106800*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) + 98*CF*(-566753889 + 4082400*lm - 
            8748000*lm^2 + 70696800*Pi^2 + 28716800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3]) - 
          49*CA*(-501267117 + 46040400*lm + 10692000*lm^2 + 72640800*Pi^2 + 
            28716800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3])))/
        571536000 - (11579*CF^2*NC*Zeta[3])/180 + (13*CF*NM*NC*Zeta[3])/9 - 
       CF*NC*NL*Zeta[3] + (220*CF*NC*NH*Zeta[3])/9 + 
       (CA*CF*NC*(433026*lm - 147363705*Pi^2 + 12563600*Sqrt[3]*Pi^3 + 
          9691920*Sqrt[3]*Pi*Log[3]^2 + 12*(-75789849 - 24589864*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 38767680*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 11809800*
             PolyGamma[2, 1] + 163573020*Zeta[3])))/62985600, 
      (CF*NC*(-149057820133459083*CF + 171180111915149040*NM - 
         29827593233499600*NL - 523552088145198960*NH - 
         17467524420192000*CF*Pi^2 - 110866518987840000*NM*Pi^2 + 
         479250082080000*NL*Pi^2 + 8104245986760000*Sqrt[3]*CF*Pi^3 + 
         18920005812400000*Sqrt[3]*NH*Pi^3 + 215662536936000*CF*Pi^4 - 
         78248778123700800*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         34498993562880000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         17253002954880000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         300088651395456000*Sqrt[3]*CF*Im[PolyLog[3, 
            -((-1)^(5/6)/Sqrt[3])]] + 700580786653440000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6251846904072000*Sqrt[3]*CF*
          Pi*Log[3]^2 + 14595433055280000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         62240270400*(77*CA*(71629 + 39600*lm) + 16*(231*CF*(719 + 1350*lm) - 
             5*(11*(-23153 + 630*lm)*NM + 10*(231*(4 + 3*lm)*NL + 
                 (314 + 693*lm)*NH))))*Log[x]^2 + 63900010944000*
          (4049*CA + 8*(1579*CF - 45*(50*NM + NL)))*Log[x]^3 + 
         43132507387200000*CF*PolyGamma[2, 1] - 14856752544480000*NM*
          PolyGamma[2, 1] - 23483254021920000*NH*PolyGamma[2, 1] + 
         166320*Log[x]*(-20*(2401245*NL*(-3487 + 1200*lm + 360*lm^2 - 600*
                Pi^2) + 16335*NM*(-18167027 + 176400*lm + 52920*lm^2 + 
               5309640*Pi^2) + NH*(-125789175753 + 2881494000*lm + 864448200*
                lm^2 + 70204103200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
           17787*CF*(-146505813 + 1458000*lm - 8748000*lm^2 + 12873600*Pi^2 + 
             33812800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             23328000*Zeta[3]) + 71148*CA*(-10412301 + 6156000*lm + 
             1336500*lm^2 + 1609200*Pi^2 + 4226600*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 2916000*Zeta[3])) + 141346824208128000*CF*
          Zeta[3] + 367105562873280000*NM*Zeta[3] + 28755004924800000*NL*
          Zeta[3] - 250168542845760000*NH*Zeta[3] - 
         1565256*CA*(-5561996625*Pi^2 + 2588792500*Sqrt[3]*Pi^3 + 
           68890500*Pi^4 + 1997068500*Sqrt[3]*Pi*Log[3]^2 - 
           126*(198377150*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             43740000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 9*(-42122011 + 84532000*
                Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 12150000*
                PolyGamma[2, 1] + 39816000*Zeta[3])))))/8626501477440000, 
      (-16299117387979*CF^2*NC)/288054144000 + (11*CF^2*lm*NC)/1800 - 
       (58127084691343*CF*NM*NC)/11981252052000 - (11*CF*lm*NM*NC)/16200 + 
       (496307*CF*NC*NL)/388800 - (11*CF*lm*NC*NL)/16200 + 
       (627562212403691*CF*NC*NH)/17971878078000 - (11*CF*lm*NC*NH)/16200 + 
       (9219307*CF^2*NC*Pi^2)/302400 + (1537*CF*NM*NC*Pi^2)/270 - 
       (29*CF*NC*NL*Pi^2)/1620 - (956165*CF^2*NC*Pi^3)/(629856*Sqrt[3]) - 
       (1621585*CF*NC*NH*Pi^3)/(472392*Sqrt[3]) + 
       (1703699*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(52488*Sqrt[3]) - 
       (564802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) - 
       (27319*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(486*Sqrt[3]) - 
       (92662*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (729*Sqrt[3]) - (27319*CF^2*NC*Pi*Log[3]^2)/(23328*Sqrt[3]) - 
       (46331*CF*NC*NH*Pi*Log[3]^2)/(17496*Sqrt[3]) + 
       (CF*NC*(165*CA*(-2686829 + 129360*lm) + 
          4*(33*CF*(7376777 + 264600*lm) - 10*((-4076683 + 97020*lm)*NM + 
              13860*(11 + 7*lm)*NL + (40757 + 97020*lm)*NH)))*Log[x]^2)/
        2494800 + (CF*NC*(-28461*CA + 8*(5637*CF + 2230*NM + 35*NL))*
         Log[x]^3)/270 - (11*CF^2*NC*PolyGamma[2, 1])/2 + 
       (77*CF*NM*NC*PolyGamma[2, 1])/27 + (110*CF*NC*NH*PolyGamma[2, 1])/
        27 + (CF*NC*Log[x]*(5*(4*(7203735*NL*(-2159 + 1088*lm + 360*lm^2 - 
                440*Pi^2) + 45*NM*(-21561451811 + 174170304*lm + 
                57629880*lm^2 + 6025524120*Pi^2) + NH*(-390384828501 + 
                7837663680*lm + 2593344600*lm^2 + 219757199200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 363*CF*(-36001150329 + 
              122880240*lm - 257191200*lm^2 + 8261394120*Pi^2 + 
              1070904800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              685843200*Zeta[3])) - 363*CA*(-84964986417 + 3375237600*lm + 
            785862000*lm^2 + 20828121300*Pi^2 + 2677262000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1714608000*Zeta[3])))/
        311201352000 - (78547*CF^2*NC*Zeta[3])/540 - (461*CF*NM*NC*Zeta[3])/
        27 - (11*CF*NC*NL*Zeta[3])/9 + (86*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(21329012024471/720135360000 + (121*lm)/32400 - 
         (865423*Pi^2)/56700 + (956165*Pi^3)/(1259712*Sqrt[3]) - 
         (1703699*Im[PolyLog[2, (-1)^(1/3)]])/(104976*Sqrt[3]) + 
         (27319*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(972*Sqrt[3]) + 
         (27319*Pi*Log[3]^2)/(46656*Sqrt[3]) + (11*PolyGamma[2, 1])/4 + 
         (77227*Zeta[3])/1080), 
      (CF*NC*(-63111634185600*(1001*CA*(-64709 + 277200*lm) + 
           2*(1001*CF*(686599 + 226800*lm) - 40*(26*(-4919443 + 24255*lm)*
                NM + 7*(2145*(55 + 42*lm)*NL + 2*(21514 + 45045*lm)*NH))))*
          Log[x]^2 + 30323877993497088000*(1371*CA + 1783*CF - 11380*NM - 
           70*NL)*Log[x]^3 + 2162160*Log[x]*
          (-2*(80*(13689*NM*(-49882031113 + 160083000*lm + 48024900*lm^2 + 
                 18249462000*Pi^2) - 7*(626107482*NL*(1947 - 500*lm - 
                   150*lm^2 + 300*Pi^2) - NH*(-17056099700859 + 313053741000*
                    lm + 93916122300*lm^2 + 9555768622400*Sqrt[3]*
                    Im[PolyLog[2, (-1)^(1/3)]]))) + 9018009*CF*
              (-1786358067 + 8748000*lm - 52488000*lm^2 + 315981000*Pi^2 + 
               235314400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 139968000*
                Zeta[3])) + 9018009*CA*(-1407506217 + 295488000*lm + 
             64152000*lm^2 + 315981000*Pi^2 + 235314400*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 139968000*Zeta[3])) - 
         1289575287*CA*(-2921846288400*Pi^2 + 288260140000*Sqrt[3]*Pi^3 + 
           6613488000*Pi^4 + 222372108000*Sqrt[3]*Pi*Log[3]^2 - 
           21*(136031507200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             25194240000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             3*(58450855853 + 169426368000*Sqrt[3]*Im[PolyLog[3, 
                  -((-1)^(5/6)/Sqrt[3])]] + 25194240000*PolyGamma[2, 1] + 
               190084320000*Zeta[3]))) + 
         2*(-320*(533871*NM*(-538266941649491 + 158773777192800*Pi^2 + 
               4326563241000*PolyGamma[2, 1] - 446634451494000*Zeta[3]) - 
             7*(5*NH*(-2251539187836033519 + 83696588421446000*Sqrt[3]*
                  Pi^3 + 84439876691089920*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]] + 3099165102691257600*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 64565939639401200*
                  Sqrt[3]*Pi*Log[3]^2 - 96454299421279800*PolyGamma[2, 1] - 
                 1045767667409665200*Zeta[3]) + 22562409221352*NL*
                (-28751 + 375*Pi^2 + 27000*Zeta[3]))) + 1289575287*CF*
            (-2922889244400*Pi^2 + 288260140000*Sqrt[3]*Pi^3 + 
             6613488000*Pi^4 + 222372108000*Sqrt[3]*Pi*Log[3]^2 - 
             21*(136031507200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               25194240000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3*(58607564483 + 
                 169426368000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                 25194240000*PolyGamma[2, 1] + 190084320000*Zeta[3]))))))/
       682287254853684480000, (-797195647130731*CF^2*NC)/1361055830400 + 
       (13*CF^2*lm*NC)/3528 - (1459954832124653173*CF*NM*NC)/
        13161405379122000 - (13*CF*lm*NM*NC)/31752 + 
       (21047903*CF*NC*NL)/13608000 - (13*CF*lm*NC*NL)/31752 + 
       (921366545631722017*CF*NC*NH)/21536845165836000 - 
       (13*CF*lm*NC*NH)/31752 + (320382179*CF^2*NC*Pi^2)/1905120 + 
       (4253*CF*NM*NC*Pi^2)/126 - (41*CF*NC*NL*Pi^2)/2268 - 
       (980020*CF^2*NC*Pi^3)/(531441*Sqrt[3]) - (6132245*CF*NC*NH*Pi^3)/
        (1417176*Sqrt[3]) + (1600466429*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (43401015*Sqrt[3]) - (8613718*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (295245*Sqrt[3]) - (3136064*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(45927*Sqrt[3]) - 
       (350414*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2187*Sqrt[3]) - (196004*CF^2*NC*Pi*Log[3]^2)/(137781*Sqrt[3]) - 
       (175207*CF*NC*NH*Pi*Log[3]^2)/(52488*Sqrt[3]) + 
       (CF*NC*(143*CA*(-159372823 + 1552320*lm) + 
          143*CF*(325055279 + 2540160*lm) - 
          28*((-325941659 + 1441440*lm)*NM + 385*(234*(25 + 16*lm)*NL + 
              (1597 + 3744*lm)*NH)))*Log[x]^2)/22702680 + 
       (CF*NC*(-169321*CA + 318332*CF + 88256*NM + 448*NL)*Log[x]^3)/378 - 
       (13*CF^2*NC*PolyGamma[2, 1])/2 + (94*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (127*CF*NC*NH*PolyGamma[2, 1])/27 - (6941*CF^2*NC*Zeta[3])/14 - 
       (2617*CF*NM*NC*Zeta[3])/27 - (13*CF*NC*NL*Zeta[3])/9 + 
       (296*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (32059870513395661/108884466432000 + (143*lm)/63504 - 
         (213637439*Pi^2)/2540160 + (490010*Pi^3)/(531441*Sqrt[3]) - 
         (1600466429*Im[PolyLog[2, (-1)^(1/3)]])/(86802030*Sqrt[3]) + 
         (1568032*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(45927*Sqrt[3]) + 
         (98002*Pi*Log[3]^2)/(137781*Sqrt[3]) + (13*PolyGamma[2, 1])/4 + 
         (62105*Zeta[3])/252) + CF*Log[x]*((-56782313976329*NM*NC)/
          292183491600 + (95*lm*NM*NC)/189 + (lm^2*NM*NC)/6 - 
         (14809*NC*NL)/10800 + (95*lm*NC*NL)/189 + (lm^2*NC*NL)/6 - 
         (7543006819409*NC*NH)/239059220400 + (95*lm*NC*NH)/189 + 
         (lm^2*NC*NH)/6 + (3211*NM*NC*Pi^2)/54 - (13*NC*NL*Pi^2)/54 + 
         (350414*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
         CF*NC*(-336265978891/675126900 + (61*lm)/84 - (3*lm^2)/2 + 
           (27575*Pi^2)/126 + (3136064*Im[PolyLog[2, (-1)^(1/3)]])/
            (137781*Sqrt[3]) - 4*Zeta[3]) + CA*NC*(749520229441/3086294400 - 
           (743*lm)/189 - (11*lm^2)/12 - (82907*Pi^2)/756 - 
           (1568032*Im[PolyLog[2, (-1)^(1/3)]])/(137781*Sqrt[3]) + 
           2*Zeta[3])), (25976928869179973*CF^2*NC)/136105583040000 + 
       (987721958435857643*CF*NM*NC)/584951350183200 - 
       (26782633*CF*NC*NL)/5292000 - (20730024426972390631*CF*NC*NH)/
        236905296824196000 - (88876727*CF^2*NC*Pi^2)/1587600 - 
       (19993*CF*NM*NC*Pi^2)/45 + (CF*NC*NL*Pi^2)/18 + 
       (7883069*CF^2*NC*Pi^3)/(2125764*Sqrt[3]) + (21209965*CF*NC*NH*Pi^3)/
        (2125764*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (65228707633*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1736040600*Sqrt[3]) + (221164*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (59049*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (31532276*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (229635*Sqrt[3]) + (2423996*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) + 
       (7883069*CF^2*NC*Pi*Log[3]^2)/(2755620*Sqrt[3]) + 
       (605999*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) - 
       (CF*NC*(143*CA*(-70707943 + 7761600*lm) + 
          4*(143*CF*(44058419 + 3175200*lm) - 140*(630*(-570937 + 572*lm)*
               NM + 15015*(31 + 24*lm)*NL + (178679 + 360360*lm)*NH)))*
         Log[x]^2)/37837800 - 
       (CF*NC*(-57649*CA + 8*(4376*CF + 90545*NM + 140*NL))*Log[x]^3)/315 + 
       7*CF^2*NC*PolyGamma[2, 1] - (47*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (65*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-12986649161482279/136105583040000 + (19749431*Pi^2)/
          705600 - (7883069*Pi^3)/(4251528*Sqrt[3]) - Pi^4/80 + 
         (65228707633*Im[PolyLog[2, (-1)^(1/3)]])/(3472081200*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (15766138*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(229635*Sqrt[3]) - 
         (7883069*Pi*Log[3]^2)/(5511240*Sqrt[3]) - (7*PolyGamma[2, 1])/2 - 
         (1157*Zeta[3])/14) + (1157*CF^2*NC*Zeta[3])/7 + 
       (10039*CF*NM*NC*Zeta[3])/9 + (14*CF*NC*NL*Zeta[3])/3 - 
       (119*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((15894510038087*NM*NC)/
          16232416200 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (205031*NC*NL)/37800 - (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + 
         (288255311502329*NC*NH)/3944477136600 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (5177*NM*NC*Pi^2)/9 + (7*NC*NL*Pi^2)/9 - 
         (2423996*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CA*NC*(-3080502264331/27005076000 + (76*lm)/9 + (11*lm^2)/6 + 
           (1391*Pi^2)/36 + (15766138*Im[PolyLog[2, (-1)^(1/3)]])/
            (688905*Sqrt[3]) - 4*Zeta[3]) + 
         CF*NC*(6745576831067/27005076000 - lm/2 + 3*lm^2 - (1391*Pi^2)/18 - 
           (31532276*Im[PolyLog[2, (-1)^(1/3)]])/(688905*Sqrt[3]) + 
           8*Zeta[3])), (-9431281586988054657931*CF^2*NC)/
        2608654046777856000 + (15*CF^2*lm*NC)/6272 - 
       (95639596186170803321*CF*NM*NC)/140388324043968000 - 
       (5*CF*lm*NM*NC)/18816 + (7687021*CF*NC*NL)/4233600 - 
       (5*CF*lm*NC*NL)/18816 + (18074599182648023711*CF*NC*NH)/
        355357945236294000 - (5*CF*lm*NC*NH)/18816 + 
       (1380301583*CF^2*NC*Pi^2)/1451520 + (1338251*CF*NM*NC*Pi^2)/7560 - 
       (55*CF*NC*NL*Pi^2)/3024 - (1330809445*CF^2*NC*Pi^3)/
        (612220032*Sqrt[3]) - (22385825*CF*NC*NH*Pi^3)/(4251528*Sqrt[3]) + 
       (42186871637*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1020366720*Sqrt[3]) - (25772162*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) - 
       (38023127*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (472392*Sqrt[3]) - (1279190*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (38023127*CF^2*NC*Pi*Log[3]^2)/(22674816*Sqrt[3]) - 
       (639595*CF*NC*NH*Pi*Log[3]^2)/(157464*Sqrt[3]) + 
       (CF*NC*(13*CA*(-26546935249 + 51226560*lm) + 
          2*(13*CF*(26650826509 + 41912640*lm) - 
            56*(5*(-229302977 + 216216*lm)*NM + 12*(10010*(14 + 9*lm)*NL + 
                (38713 + 90090*lm)*NH))))*Log[x]^2)/60540480 + 
       (CF*NC*(-572213*CA + 16*(70510*CF + 15386*NM + 21*NL))*Log[x]^3)/
        252 - (15*CF^2*NC*PolyGamma[2, 1])/2 + (37*CF*NM*NC*PolyGamma[2, 1])/
        9 + (16*CF*NC*NH*PolyGamma[2, 1])/3 - (2344933*CF^2*NC*Zeta[3])/
        1008 - (4183*CF*NM*NC*Zeta[3])/9 - (5*CF*NC*NL*Zeta[3])/3 + 
       (334*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*(9440878302360171545341/
          5217308093555712000 + (55*lm)/37632 - (51124349*Pi^2)/107520 + 
         (1330809445*Pi^3)/(1224440064*Sqrt[3]) - 
         (42186871637*Im[PolyLog[2, (-1)^(1/3)]])/(2040733440*Sqrt[3]) + 
         (38023127*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(944784*Sqrt[3]) + 
         (38023127*Pi*Log[3]^2)/(45349632*Sqrt[3]) + (15*PolyGamma[2, 1])/4 + 
         (2341573*Zeta[3])/2016) + CF*Log[x]*((-29108658290821*NM*NC)/
          48697248600 + (253*lm*NM*NC)/504 + (lm^2*NM*NC)/6 - 
         (26321*NC*NL)/15120 + (253*lm*NC*NL)/504 + (lm^2*NC*NL)/6 - 
         (60486399210323*NC*NH)/1577790854640 + (253*lm*NC*NH)/504 + 
         (lm^2*NC*NH)/6 + (491*NM*NC*Pi^2)/2 - (5*NC*NL*Pi^2)/18 + 
         (1279190*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CF*NC*(-11195734117734871/9410728884480 + (41*lm)/56 - (3*lm^2)/2 + 
           (2277323*Pi^2)/2016 + (38023127*Im[PolyLog[2, (-1)^(1/3)]])/
            (1417176*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(173017545026353/294085277640 - (3959*lm)/1008 - 
           (11*lm^2)/12 - (759481*Pi^2)/1344 - 
           (38023127*Im[PolyLog[2, (-1)^(1/3)]])/(2834352*Sqrt[3]) + 
           2*Zeta[3])), (1237087645615681639*CF^2*NC)/1088844664320000 + 
       (1381201167664216321127*CF*NM*NC)/140388324043968000 - 
       (868673371*CF*NC*NL)/148176000 - (152943961647297193529488559*CF*NC*
         NH)/1508434777393268332608000 - (163558708009*CF^2*NC*Pi^2)/
        558835200 - (268246*CF*NM*NC*Pi^2)/105 + (CF*NC*NL*Pi^2)/18 + 
       (93852211*CF^2*NC*Pi^3)/(22674816*Sqrt[3]) + 
       (168930020*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (1187181918493*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (27776649600*Sqrt[3]) - (269356144*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) + 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (93852211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (612360*Sqrt[3]) + (77225152*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) + 
       (93852211*CF^2*NC*Pi*Log[3]^2)/(29393280*Sqrt[3]) + 
       (4826572*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) + 
       CF*((-7421698933*CF*NC)/2116800 + CA*(7108378093/4233600 - 33*lm)*NC - 
         54*CF*lm*NC - (3313318565*NM*NC)/108108 + 6*lm*NM*NC + 
         (23*NC*NL)/3 + 6*lm*NC*NL + (208261*NC*NH)/68068 + 6*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-482913*CA + 767446*CF + 840*(9028*NM + 3*NL))*
         Log[x]^3)/630 + 8*CF^2*NC*PolyGamma[2, 1] - 
       (55*CF*NM*NC*PolyGamma[2, 1])/18 - (73*CF*NC*NH*PolyGamma[2, 1])/
        18 + CA*CF*NC*(-1237065858603656539/2177689328640000 + 
         (4956290953*Pi^2)/33868800 - (93852211*Pi^3)/(45349632*Sqrt[3]) - 
         Pi^4/80 + (1187181918493*Im[PolyLog[2, (-1)^(1/3)]])/
          (55553299200*Sqrt[3]) - Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (93852211*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1224720*Sqrt[3]) - 
         (93852211*Pi*Log[3]^2)/(58786560*Sqrt[3]) - 4*PolyGamma[2, 1] - 
         (752711*Zeta[3])/2016) + (752711*CF^2*NC*Zeta[3])/1008 + 
       (53813*CF*NM*NC*Zeta[3])/9 + (16*CF*NC*NL*Zeta[3])/3 - 
       45*CF*NC*NH*Zeta[3] + CF*Log[x]*((467658725140813*NM*NC)/
          194788994400 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (1725523*NC*NL)/264600 - (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + 
         (2119146828289999919*NC*NH)/24623004077511840 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (27088*NM*NC*Pi^2)/9 + (8*NC*NL*Pi^2)/9 - 
         (77225152*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CA*NC*(-99259606070099/288054144000 + (76*lm)/9 + (11*lm^2)/6 + 
           (246769*Pi^2)/1344 + (93852211*Im[PolyLog[2, (-1)^(1/3)]])/
            (3674160*Sqrt[3]) - 4*Zeta[3]) + 
         CF*NC*(102376997267579/144027072000 - lm/2 + 3*lm^2 - 
           (246769*Pi^2)/672 - (93852211*Im[PolyLog[2, (-1)^(1/3)]])/
            (1837080*Sqrt[3]) + 8*Zeta[3])), 
      (-13271154288958771534191059*CF^2*NC)/614058529368316032000 + 
       (17*CF^2*lm*NC)/10368 - (298488495896649420669199*CF*NM*NC)/
        79583981080155552000 - (17*CF*lm*NM*NC)/93312 + 
       (8337740303*CF*NC*NL)/4000752000 - (17*CF*lm*NC*NL)/93312 + 
       (267609898454451710118586171*CF*NC*NH)/4525304332179804997824000 - 
       (17*CF*lm*NC*NH)/93312 + (407432416177*CF^2*NC*Pi^2)/71850240 + 
       (64494629*CF*NM*NC*Pi^2)/68040 - (71*CF*NC*NL*Pi^2)/3888 - 
       (323663900*CF^2*NC*Pi^3)/(129140163*Sqrt[3]) - 
       (6448947085*CF*NC*NH*Pi^3)/(1033121304*Sqrt[3]) + 
       (1096578581*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) - 
       (14325583078*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (502211745*Sqrt[3]) - (147960640*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (368511262*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) - (9247540*CF^2*NC*Pi*Log[3]^2)/(4782969*Sqrt[3]) - 
       (184255631*CF*NC*NH*Pi*Log[3]^2)/(38263752*Sqrt[3]) + 
       (CF*NC*(51*CA*(-1765274666509 + 634233600*lm) + 
          34*CF*(5299678078327 + 1556755200*lm) - 
          96*(104*(-3014261947 + 589050*lm)*NM + 
            45*(68068*(31 + 20*lm)*NL + (586983 + 1361360*lm)*NH)))*
         Log[x]^2)/2646483840 + (CF*NC*(-4155323*CA + 8285940*CF + 
          1523904*NM + 480*NL)*Log[x]^3)/324 - (17*CF^2*NC*PolyGamma[2, 1])/
        2 + (128*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (161*CF*NC*NH*PolyGamma[2, 1])/27 - (8351741*CF^2*NC*Zeta[3])/648 - 
       (62753*CF*NM*NC*Zeta[3])/27 - (17*CF*NC*NL*Zeta[3])/9 + 
       (124*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*(26547470654962169600071063/
          2456234117473264128000 + (187*lm)/186624 - (7407912007*Pi^2)/
          2612736 + (161831950*Pi^3)/(129140163*Sqrt[3]) - 
         (1096578581*Im[PolyLog[2, (-1)^(1/3)]])/(47829690*Sqrt[3]) + 
         (73980320*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
         (4623770*Pi*Log[3]^2)/(4782969*Sqrt[3]) + (17*PolyGamma[2, 1])/4 + 
         (8349293*Zeta[3])/1296) + CF*Log[x]*((-24237898398323971*NM*NC)/
          12990927549600 + (325*lm*NM*NC)/648 + (lm^2*NM*NC)/6 - 
         (3348547*NC*NL)/1587600 + (325*lm*NC*NL)/648 + (lm^2*NC*NL)/6 - 
         (50304016191669287587*NC*NH)/1108035183488032800 + 
         (325*lm*NC*NH)/648 + (lm^2*NC*NH)/6 + (63575*NM*NC*Pi^2)/54 - 
         (17*NC*NL*Pi^2)/54 + (368511262*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CF*NC*(-103334087302961851123/
            61344508428403200 + (53*lm)/72 - (3*lm^2)/2 + 
           (1383743*Pi^2)/216 + (147960640*Im[PolyLog[2, (-1)^(1/3)]])/
            (4782969*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(102492934161788597929/122689016856806400 - (5087*lm)/1296 - 
           (11*lm^2)/12 - (461293*Pi^2)/144 - 
           (73980320*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
           2*Zeta[3])), (11691438699770394343*CF^2*NC)/1837425371040000 + 
       (20266695258426189258461219*CF*NM*NC)/344863918014007392000 - 
       (17773683199*CF*NC*NL)/2667168000 - (5379812629449540599603099357017*
         CF*NC*NH)/46558593621631923720112224000 - 
       (676938452893*CF^2*NC*Pi^2)/419126400 - (2162163*CF*NM*NC*Pi^2)/140 + 
       (CF*NC*NL*Pi^2)/18 + (6285375307*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) + 
       (260630405*CF*NC*NH*Pi^3)/(19131876*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (8980049695609*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (187492384800*Sqrt[3]) - (11544469999*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1506635235*Sqrt[3]) + 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (6285375307*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (37200870*Sqrt[3]) + (29786332*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) + 
       (6285375307*CF^2*NC*Pi*Log[3]^2)/(1785641760*Sqrt[3]) + 
       (7446583*CF*NC*NH*Pi*Log[3]^2)/(708588*Sqrt[3]) + 
       CF*((-30759873601*CF*NC)/1587600 + CA*(30498792151/3175200 - 
           (110*lm)/3)*NC - 60*CF*lm*NC - (425733296543*NM*NC)/2297295 + 
         (20*lm*NM*NC)/3 + (76*NC*NL)/9 + (20*lm*NC*NL)/3 + 
         (30331346*NC*NH)/8729721 + (20*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-10958861*CA + 8*(2604659*CF + 1575*(15586*NM + NL)))*
         Log[x]^3)/2835 + 9*CF^2*NC*PolyGamma[2, 1] - 
       (7*CF*NM*NC*PolyGamma[2, 1])/2 - (9*CF*NC*NH*PolyGamma[2, 1])/2 + 
       CA*CF*NC*(-46765640330382369187/14699402968320000 + 
         (676937815753*Pi^2)/838252800 - (6285375307*Pi^3)/
          (2754990144*Sqrt[3]) - Pi^4/80 + 
         (8980049695609*Im[PolyLog[2, (-1)^(1/3)]])/(374984769600*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (6285375307*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74401740*Sqrt[3]) - (6285375307*Pi*Log[3]^2)/
          (3571283520*Sqrt[3]) - (9*PolyGamma[2, 1])/2 - 
         (322871*Zeta[3])/168) + (322871*CF^2*NC*Zeta[3])/84 + 
       34591*CF*NM*NC*Zeta[3] + 6*CF*NC*NL*Zeta[3] - 
       (151*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((6847913712539657*NM*NC)/
          3752934625440 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (8063141*NC*NL)/1058400 - (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + 
         (1473224840628345757741*NC*NH)/14814840786636290400 - 
         (10*lm*NC*NH)/9 - (lm^2*NC*NH)/3 - (51955*NM*NC*Pi^2)/3 + 
         NC*NL*Pi^2 - (29786332*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (177147*Sqrt[3]) + CA*NC*(-18413160290415713/17499289248000 + 
           (76*lm)/9 + (11*lm^2)/6 + (8686045*Pi^2)/9072 + 
           (6285375307*Im[PolyLog[2, (-1)^(1/3)]])/(223205220*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(18602536652193953/8749644624000 - lm/2 + 
           3*lm^2 - (8686045*Pi^2)/4536 - 
           (6285375307*Im[PolyLog[2, (-1)^(1/3)]])/(111602610*Sqrt[3]) + 
           8*Zeta[3])), (-1105113378050190113979711101*CF^2*NC)/
        8289790146472266432000 + (19*CF^2*lm*NC)/16200 - 
       (18612536241450591605263911781*CF*NM*NC)/887033105121778763148000 - 
       (19*CF*lm*NM*NC)/145800 + (12546276727*CF*NC*NL)/5334336000 - 
       (19*CF*lm*NC*NL)/145800 + (314635151822295437157920006509*CF*NC*NH)/
        4655859362163192372011222400 - (19*CF*lm*NC*NH)/145800 + 
       (39852315673*CF^2*NC*Pi^2)/1122660 + (362878219*CF*NM*NC*Pi^2)/
        68040 - (89*CF*NC*NL*Pi^2)/4860 - (11741221807*CF^2*NC*Pi^3)/
        (4132485216*Sqrt[3]) - (7493666215*CF*NC*NH*Pi^3)/
        (1033121304*Sqrt[3]) + (1138890086981*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22599528525*Sqrt[3]) - 
       (82894255321*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3013270470*Sqrt[3]) - (1677317401*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(15943230*Sqrt[3]) - 
       (428209498*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) - (1677317401*CF^2*NC*Pi*Log[3]^2)/
        (765275040*Sqrt[3]) - (214104749*CF*NC*NH*Pi*Log[3]^2)/
        (38263752*Sqrt[3]) + 
       (CF*NC*(323*CA*(-41445408955207 + 2616213600*lm) + 
          4*(323*CF*(20725352206759 + 1070269200*lm) - 
            30*((-33520210102381 + 1280359080*lm)*NM + 
              9*(12932920*(17 + 11*lm)*NL + (61415051 + 142262120*lm)*
                 NH))))*Log[x]^2)/62853991200 + 
       (CF*NC*(-62918603*CA + 40*(3144131*CF + 506424*NM + 33*NL))*
         Log[x]^3)/810 - (19*CF^2*NC*PolyGamma[2, 1])/2 + 
       (145*CF*NM*NC*PolyGamma[2, 1])/27 + (178*CF*NC*NH*PolyGamma[2, 1])/
        27 - (4664909*CF^2*NC*Zeta[3])/60 - (336769*CF*NM*NC*Zeta[3])/27 - 
       (19*CF*NC*NL*Zeta[3])/9 + (410*CF*NC*NH*Zeta[3])/9 + 
       CA*CF*NC*(22103051936572918287449725537/331591605858890657280000 + 
         (209*lm)/291600 - (637637733067*Pi^2)/35925120 + 
         (11741221807*Pi^3)/(8264970432*Sqrt[3]) - 
         (1138890086981*Im[PolyLog[2, (-1)^(1/3)]])/(45199057050*Sqrt[3]) + 
         (1677317401*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (31886460*Sqrt[3]) + (1677317401*Pi*Log[3]^2)/
          (1530550080*Sqrt[3]) + (19*PolyGamma[2, 1])/4 + 
         (13993967*Zeta[3])/360) + CF*Log[x]*((-135334072439665202657*NM*NC)/
          24386569196109120 + (203*lm*NM*NC)/405 + (lm^2*NM*NC)/6 - 
         (1048577*NC*NL)/423360 + (203*lm*NC*NL)/405 + (lm^2*NC*NL)/6 - 
         (8433896558829508446637*NC*NH)/160000280495671936320 + 
         (203*lm*NC*NH)/405 + (lm^2*NC*NH)/6 + (337705*NM*NC*Pi^2)/54 - 
         (19*NC*NL*Pi^2)/54 + (428209498*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CF*NC*(453603886594730245709/
            38340317767752000 + (133*lm)/180 - (3*lm^2)/2 + 
           (125814793*Pi^2)/3240 + (1677317401*Im[PolyLog[2, (-1)^(1/3)]])/
            (47829690*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-64879476896879392469/10954376505072000 - (1589*lm)/405 - 
           (11*lm^2)/12 - (125817073*Pi^2)/6480 - 
           (1677317401*Im[PolyLog[2, (-1)^(1/3)]])/(95659380*Sqrt[3]) + 
           2*Zeta[3])), (8712529907884594412407*CF^2*NC)/238130328086784000 + 
       (432300689267173203540730968661*CF*NM*NC)/1182710806829038350864000 - 
       (716802637*CF*NC*NL)/96018048 - (1485007036190725135275677291183*CF*
         NC*NH)/11428018434400563094936636800 - (1136068605167*CF^2*NC*Pi^2)/
        121080960 - (277064201*CF*NM*NC*Pi^2)/2835 + (CF*NC*NL*Pi^2)/18 + 
       (7719229835*CF^2*NC*Pi^3)/(1549681956*Sqrt[3]) + 
       (18039985355*CF*NC*NH*Pi^3)/(1162261467*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (805494956957113*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15186883168800*Sqrt[3]) - 
       (583615586572*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (40679151345*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (6175383868*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (33480783*Sqrt[3]) + (8246850448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) + 
       (1543845967*CF^2*NC*Pi*Log[3]^2)/(401769396*Sqrt[3]) + 
       (515428153*CF*NC*NH*Pi*Log[3]^2)/(43046721*Sqrt[3]) + 
       CF*((-22342692101*CF*NC)/198450 + CA*(89227180169/1587600 - 
           (121*lm)/3)*NC - 66*CF*lm*NC - (51188868194333*NM*NC)/43648605 + 
         (22*lm*NM*NC)/3 + (83*NC*NL)/9 + (22*lm*NC*NL)/3 + 
         (2204663*NC*NH)/566865 + (22*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-60885269*CA + 4*(30121177*CF + 315*(956438*NM + 11*NL)))*
         Log[x]^3)/2835 + 10*CF^2*NC*PolyGamma[2, 1] - 
       (71*CF*NM*NC*PolyGamma[2, 1])/18 - (89*CF*NC*NH*PolyGamma[2, 1])/
        18 + CA*CF*NC*(-8712526937497682750881/476260656173568000 + 
         (262169644397*Pi^2)/55883520 - (7719229835*Pi^3)/
          (3099363912*Sqrt[3]) - Pi^4/80 + (805494956957113*
           Im[PolyLog[2, (-1)^(1/3)]])/(30373766337600*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (3087691934*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33480783*Sqrt[3]) - (1543845967*Pi*Log[3]^2)/(803538792*Sqrt[3]) - 
         5*PolyGamma[2, 1] - (60817447*Zeta[3])/5670) + 
       (60817447*CF^2*NC*Zeta[3])/2835 + (1912429*CF*NM*NC*Zeta[3])/9 + 
       (20*CF*NC*NL*Zeta[3])/3 - (167*CF*NC*NH*Zeta[3])/3 + 
       CF*Log[x]*((-114087406467310200917*NM*NC)/2540267624594700 - 
         (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + (8301673*NC*NL)/952560 - 
         (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + (462986820091944640069*NC*NH)/
          4090916262673430190 - (10*lm*NC*NH)/9 - (lm^2*NC*NH)/3 - 
         (956444*NM*NC*Pi^2)/9 + (10*NC*NL*Pi^2)/9 - 
         (8246850448*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CA*NC*(-429914282754869669/157493603232000 + (76*lm)/9 + 
           (11*lm^2)/6 + (30386831*Pi^2)/5670 + 
           (3087691934*Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(431618677417980389/78746801616000 - lm/2 + 
           3*lm^2 - (30386831*Pi^2)/2835 - 
           (6175383868*Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) + 
           8*Zeta[3])), (-18772678005881945710169942797515463*CF^2*NC)/
        21992979054393852289424640000 + (21*CF^2*lm*NC)/24200 - 
       (288893496044904970861055127877*CF*NM*NC)/2365421613658076701728000 - 
       (7*CF*lm*NM*NC)/72600 + (2174001437191*CF*NC*NL)/829870272000 - 
       (7*CF*lm*NC*NL)/72600 + (95753622254599831985650248980183*CF*NC*NH)/
        1257082027784061940443030048000 - (7*CF*lm*NC*NH)/72600 + 
       (65984593299283*CF^2*NC*Pi^2)/285405120 + (7856440621*CF*NM*NC*Pi^2)/
        249480 - (109*CF*NC*NL*Pi^2)/5940 - (121892695295*CF^2*NC*Pi^3)/
        (38354628411*Sqrt[3]) - (77133964985*CF*NC*NH*Pi^3)/
        (9298091736*Sqrt[3]) + (811597559346683*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(14766531938235*Sqrt[3]) - 
       (303262542683*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (11622614670*Sqrt[3]) - (55722374992*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(473513931*Sqrt[3]) - 
       (4407655142*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) - (3482648437*CF^2*NC*Pi*Log[3]^2)/
        (1420541793*Sqrt[3]) - (2203827571*CF*NC*NH*Pi*Log[3]^2)/
        (344373768*Sqrt[3]) + 
       (CF*NC*(10944*CA*(-4868636775242 + 51476425*lm) + 
          19*CF*(5608789542587981 + 48518870400*lm) - 
          220*((-65977786931443 + 465585120*lm)*NM + 
            385*(50388*(37 + 24*lm)*NL + (522073 + 1209312*lm)*NH)))*
         Log[x]^2)/38410772400 + (CF*NC*(-489368405*CA + 
          176*(5560429*CF + 801745*NM + 10*NL))*Log[x]^3)/990 - 
       (21*CF^2*NC*PolyGamma[2, 1])/2 + 6*CF*NM*NC*PolyGamma[2, 1] + 
       (65*CF*NC*NH*PolyGamma[2, 1])/9 - (97889317*CF^2*NC*Zeta[3])/198 - 
       71231*CF*NM*NC*Zeta[3] - (7*CF*NC*NL*Zeta[3])/3 + 
       (448*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (103250365373019977674613455970369773/
          241922769598332375183671040000 + (7*lm)/13200 - 
         (126893469413*Pi^2)/1097712 + (121892695295*Pi^3)/
          (76709256822*Sqrt[3]) - (811597559346683*
           Im[PolyLog[2, (-1)^(1/3)]])/(29533063876470*Sqrt[3]) + 
         (27861187496*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (473513931*Sqrt[3]) + (3482648437*Pi*Log[3]^2)/
          (2841083586*Sqrt[3]) + (21*PolyGamma[2, 1])/4 + 
         (97888393*Zeta[3])/396) + CF*Log[x]*((-486819467538865729013*NM*NC)/
          40644281993515200 + (248*lm*NM*NC)/495 + (lm^2*NM*NC)/6 - 
         (3405575*NC*NL)/1197504 + (248*lm*NC*NL)/495 + (lm^2*NC*NL)/6 - 
         (61970516842134034517029*NC*NH)/1028573231757891019200 + 
         (248*lm*NC*NH)/495 + (lm^2*NC*NH)/6 + (641429*NM*NC*Pi^2)/18 - 
         (7*NC*NL*Pi^2)/18 + (4407655142*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(604254058361228332395829763/
            3290864494959457416000 + (163*lm)/220 - (3*lm^2)/2 + 
           (8155892*Pi^2)/33 + (55722374992*Im[PolyLog[2, (-1)^(1/3)]])/
            (1420541793*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-604303801072088090300814941/6581728989918914832000 - 
           (353*lm)/90 - (11*lm^2)/12 - (24467753*Pi^2)/198 - 
           (27861187496*Im[PolyLog[2, (-1)^(1/3)]])/(1420541793*Sqrt[3]) + 
           2*Zeta[3])), (571641291421723119318810223*CF^2*NC)/
        2614849600138953408000 + (5583620407674685374750118660001*CF*NM*NC)/
        2365421613658076701728000 - (24010979218757*CF*NC*NL)/
        2904545952000 - (19898499025168750678933605234429374317*CF*NC*NH)/
        137654253288438134664333119346144000 - (379067607962611*CF^2*NC*Pi^2)/
        6659452800 - (7280849551*CF*NM*NC*Pi^2)/11340 + 
       (CF*NC*NL*Pi^2)/18 + (2207095956887*CF^2*NC*Pi^3)/
        (409116036384*Sqrt[3]) + (730732792195*CF*NC*NH*Pi^3)/
        (41841412812*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (320685066962980003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5512838590274400*Sqrt[3]) - (7910294803553*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) + 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (2207095956887*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (11048658390*Sqrt[3]) + (83512319108*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) + 
       (2207095956887*CF^2*NC*Pi*Log[3]^2)/(530335602720*Sqrt[3]) + 
       (20878079777*CF*NC*NH*Pi*Log[3]^2)/(1549681956*Sqrt[3]) + 
       CF*((-131214382678789*CF*NC)/192099600 + 
         CA*(131176476495859/384199200 - 44*lm)*NC - 72*CF*lm*NC - 
         (336294736512809*NM*NC)/43648605 + 8*lm*NM*NC + 10*NC*NL + 
         8*lm*NC*NL + (1440235306*NC*NH)/334639305 + 8*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-3949524763*CA + 8*(985306522*CF + 
            10395*(1024665*NM + 2*NL)))*Log[x]^3)/31185 + 
       11*CF^2*NC*PolyGamma[2, 1] - (79*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (97*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-1143282529402482809767511123/10459398400555813632000 + 
         (1137202804254373*Pi^2)/39956716800 - (2207095956887*Pi^3)/
          (818232072768*Sqrt[3]) - Pi^4/80 + (320685066962980003*
           Im[PolyLog[2, (-1)^(1/3)]])/(11025677180548800*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (2207095956887*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22097316780*Sqrt[3]) - 
         (2207095956887*Pi*Log[3]^2)/(1060671205440*Sqrt[3]) - 
         (11*PolyGamma[2, 1])/2 - (15794857151*Zeta[3])/249480) + 
       (15794857151*CF^2*NC*Zeta[3])/124740 + (12295487*CF*NM*NC*Zeta[3])/
        9 + (22*CF*NC*NL*Zeta[3])/3 - 61*CF*NC*NH*Zeta[3] + 
       CF*Log[x]*((-11633615997360355138781*NM*NC)/20322140996757600 - 
         (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + (205622009*NC*NL)/20956320 - 
         (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + (436122968371073459021224807*NC*
           NH)/3427926009479523399687840 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (6147997*NM*NC*Pi^2)/9 + (11*NC*NL*Pi^2)/9 - 
         (83512319108*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CA*NC*(-810579220173261169249/
            628871957705376000 + (76*lm)/9 + (11*lm^2)/6 + 
           (15792735311*Pi^2)/498960 + (2207095956887*
             Im[PolyLog[2, (-1)^(1/3)]])/(66291950340*Sqrt[3]) - 4*Zeta[3]) + 
         CF*NC*(817384986196954618369/314435978852688000 - lm/2 + 3*lm^2 - 
           (15792735311*Pi^2)/249480 - (2207095956887*
             Im[PolyLog[2, (-1)^(1/3)]])/(33145975170*Sqrt[3]) + 8*Zeta[3])), 
      (-8435319185976749796369746822905411923997*CF^2*NC)/
        1493413449007465585246319697024000 + (23*CF^2*lm*NC)/34848 - 
       (4256479554517097769148782289674731*CF*NM*NC)/
        5756016954675563845984915200 - (23*CF*lm*NM*NC)/313632 + 
       (50316679953851*CF*NC*NL)/17427275712000 - (23*CF*lm*NC*NL)/313632 + 
       (922657079935349238011889552479478917*CF*NC*NH)/
        10867441049087221157710509422064000 - (23*CF*lm*NC*NH)/313632 + 
       (2662268459038477*CF^2*NC*Pi^2)/1712430720 + 
       (144978652039*CF*NM*NC*Pi^2)/748440 - (131*CF*NC*NL*Pi^2)/7128 - 
       (7062533480555*CF^2*NC*Pi^3)/(2008387814976*Sqrt[3]) - 
       (2351369083385*CF*NC*NH*Pi^3)/(251048476872*Sqrt[3]) + 
       (299007745816817*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5020969537440*Sqrt[3]) - (53395521054971*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2196674172630*Sqrt[3]) - 
       (201786670873*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1549681956*Sqrt[3]) - (134363947622*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (201786670873*CF^2*NC*Pi*Log[3]^2)/(74384733888*Sqrt[3]) - 
       (67181973811*CF*NC*NH*Pi*Log[3]^2)/(9298091736*Sqrt[3]) + 
       (CF*NC*(161*CA*(-61422302388488201 + 104623627680*lm) + 
          2*(483*CF*(20474171336258273 + 28533716640*lm) - 
            220*((-5600632782891093 + 6960497544*lm)*NM + 
              19*(28180152*(20 + 13*lm)*NL + (158047699 + 366341976*lm)*
                 NH))))*Log[x]^2)/1060137318240 + 
       (4*CF*NC*(-242497472*CA + 484986279*CF + 63477535*NM + 143*NL)*
         Log[x]^3)/297 - (23*CF^2*NC*PolyGamma[2, 1])/2 + 
       (179*CF*NM*NC*PolyGamma[2, 1])/27 + (212*CF*NC*NH*PolyGamma[2, 1])/
        27 - (7760125201*CF^2*NC*Zeta[3])/2376 - (11540315*CF*NM*NC*Zeta[3])/
        27 - (23*CF*NC*NL*Zeta[3])/9 + 54*CF*NC*NH*Zeta[3] + 
       CA*CF*NC*(1687065567070391514597142712549425215233/
          597365379602986234098527878809600 + (23*lm)/57024 - 
         (42258230533331*Pi^2)/54362880 + (7062533480555*Pi^3)/
          (4016775629952*Sqrt[3]) - (299007745816817*
           Im[PolyLog[2, (-1)^(1/3)]])/(10041939074880*Sqrt[3]) + 
         (201786670873*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3099363912*Sqrt[3]) + (201786670873*Pi*Log[3]^2)/
          (148769467776*Sqrt[3]) + (23*PolyGamma[2, 1])/4 + 
         (7760113057*Zeta[3])/4752) + CF*Log[x]*
        ((1481129253096210031697161*NM*NC)/64502475523708622400 + 
         (595*lm*NM*NC)/1188 + (lm^2*NM*NC)/6 - (403698833*NC*NL)/
          125737920 + (595*lm*NC*NL)/1188 + (lm^2*NC*NL)/6 - 
         (73600383153641163093542273*NC*NH)/1082502950361954757796160 + 
         (595*lm*NC*NH)/1188 + (lm^2*NC*NH)/6 + (11541479*NM*NC*Pi^2)/54 - 
         (23*NC*NL*Pi^2)/54 + (134363947622*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CF*NC*(1913721593089873659204941652991/1069201874412327714458400 + 
           (49*lm)/66 - (3*lm^2)/2 + (7759880527*Pi^2)/4752 + 
           (201786670873*Im[PolyLog[2, (-1)^(1/3)]])/(4649045868*Sqrt[3]) - 
           4*Zeta[3]) + CA*NC*(-478434629021524093398149297101/
            534600937206163857229200 - (847*lm)/216 - (11*lm^2)/12 - 
           (7759884575*Pi^2)/9504 - (201786670873*Im[PolyLog[2, (-1)^(1/3)]])/
            (9298091736*Sqrt[3]) + 2*Zeta[3])), 
      (14158418842049395348636897249*CF^2*NC)/10459398400555813632000 + 
       (45290666473631572392138206008860841*CF*NM*NC)/
        2878008477337781922992457600 - (3017970807529*CF*NC*NL)/
        332812557000 - (949174648718464354081315421873069691349*CF*NC*NH)/
        5956193651903573134514413817862000000 - 
       (595893116393269*CF^2*NC*Pi^2)/1664863200 - 
       (4304761859*CF*NM*NC*Pi^2)/990 + (CF*NC*NL*Pi^2)/18 + 
       (527712448861*CF^2*NC*Pi^3)/(90914674752*Sqrt[3]) + 
       (1830872948485*CF*NC*NH*Pi^3)/(94143178827*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (174457410482445239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2756419295137200*Sqrt[3]) - 
       (1065379495087414*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (36245123848395*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (527712448861*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2455257420*Sqrt[3]) + (836970490736*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) + 
       (527712448861*CF^2*NC*Pi*Log[3]^2)/(117852356160*Sqrt[3]) + 
       (52310655671*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) + 
       CF*((-206270348453821*CF*NC)/48024900 + CA*(8594170099709/4002075 - 
           (143*lm)/3)*NC - 78*CF*lm*NC - (104766708178475723*NM*NC)/
          2007835830 + (26*lm*NM*NC)/3 + (97*NC*NL)/9 + (26*lm*NC*NL)/3 + 
         (3643755277*NC*NH)/772244550 + (26*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-97276299457*CA + 194475620474*CF + 
          55440*(40949092*NM + 13*NL))*Log[x]^3)/124740 + 
       12*CF^2*NC*PolyGamma[2, 1] - (29*CF*NM*NC*PolyGamma[2, 1])/6 - 
       (35*CF*NC*NH*PolyGamma[2, 1])/6 + 
       CA*CF*NC*(-14158418752869337216927976257/20918796801111627264000 + 
         (5363038035302581*Pi^2)/29967537600 - (527712448861*Pi^3)/
          (181829349504*Sqrt[3]) - Pi^4/80 + (174457410482445239*
           Im[PolyLog[2, (-1)^(1/3)]])/(5512838590274400*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (527712448861*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4910514840*Sqrt[3]) - (527712448861*Pi*Log[3]^2)/
          (235704712320*Sqrt[3]) - 6*PolyGamma[2, 1] - (194545599667*Zeta[3])/
          498960) + (194545599667*CF^2*NC*Zeta[3])/249480 + 
       (27299215*CF*NM*NC*Zeta[3])/3 + 8*CF*NC*NL*Zeta[3] - 
       (199*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-4789620735231557345821963*NM*NC)/895867715607064200 - 
         (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + (209555729*NC*NL)/19209960 - 
         (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + (10499217928058273286712770533*
           NC*NH)/74161860782008919704785000 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - 4549900*NM*NC*Pi^2 + (4*NC*NL*Pi^2)/3 - 
         (836970490736*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CA*NC*(9389001089689243348393/
            139749323934528000 + (76*lm)/9 + (11*lm^2)/6 + 
           (194540965807*Pi^2)/997920 + (527712448861*
             Im[PolyLog[2, (-1)^(1/3)]])/(14731544520*Sqrt[3]) - 4*Zeta[3]) + 
         CF*NC*(-9387488663552795654233/69874661967264000 - lm/2 + 3*lm^2 - 
           (194540965807*Pi^2)/498960 - (527712448861*
             Im[PolyLog[2, (-1)^(1/3)]])/(7365772260*Sqrt[3]) + 8*Zeta[3])), 
      (-1220760884761173518330677488530628843511427*CF^2*NC)/
        31768977006158813358876255373056000 + (25*CF^2*lm*NC)/48672 - 
       (1389347069639619810983966314847314393*CF*NM*NC)/
        299792549722685616978381000000 - (25*CF*lm*NM*NC)/438048 + 
       (817625476519723*CF*NC*NL)/259178444388864 - (25*CF*lm*NC*NL)/
        438048 + (2074154813083318630385863387703007392291*CF*NC*NH)/
        22123004992784700213910679894916000000 - (25*CF*lm*NC*NH)/438048 + 
       (10859238672343433*CF^2*NC*Pi^2)/1011890880 + 
       (11992630968821*CF*NM*NC*Pi^2)/9729720 - (155*CF*NC*NL*Pi^2)/8424 - 
       (56636164104625*CF^2*NC*Pi^3)/(14686335897012*Sqrt[3]) - 
       (7879910502485*CF*NC*NH*Pi^3)/(753145430616*Sqrt[3]) + 
       (2358065489381246003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (36752555582272530*Sqrt[3]) - (1608093181426357*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(72490247696790*Sqrt[3]) - 
       (6472704469100*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (45328197213*Sqrt[3]) - (450280600142*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) - 
       (1618176117275*CF^2*NC*Pi*Log[3]^2)/(543938366556*Sqrt[3]) - 
       (225140300071*CF*NC*NH*Pi*Log[3]^2)/(27894275208*Sqrt[3]) + 
       (CF*NC*(230*CA*(-438441725754534083 + 116512676280*lm) + 
          115*CF*(1753767845559363617 + 381314213280*lm) - 
          338*(9*(-7614806288726687 + 1601692400*lm)*NM + 
            514829700*(43 + 28*lm)*NL + (6212452331 + 14415231600*lm)*NH))*
         Log[x]^2)/1566111947400 + (CF*NC*(-31212796587*CA + 62425407902*CF + 
          7490845648*NM + 2912*NL)*Log[x]^3)/1404 - 
       (25*CF^2*NC*PolyGamma[2, 1])/2 + (196*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (229*CF*NC*NH*PolyGamma[2, 1])/27 - (200082880*CF^2*NC*Zeta[3])/9 - 
       (72026203*CF*NM*NC*Zeta[3])/27 - (25*CF*NC*NL*Zeta[3])/9 + 
       (524*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (110978280513888543787655306994660167562937/
          5776177637483420610704773704192000 + (275*lm)/876096 - 
         (10859238710394953*Pi^2)/2023781760 + (56636164104625*Pi^3)/
          (29372671794024*Sqrt[3]) - (2358065489381246003*
           Im[PolyLog[2, (-1)^(1/3)]])/(73505111164545060*Sqrt[3]) + 
         (3236352234550*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (45328197213*Sqrt[3]) + (1618176117275*Pi*Log[3]^2)/
          (1087876733112*Sqrt[3]) + (25*PolyGamma[2, 1])/4 + 
         (100041415*Zeta[3])/9) + CF*Log[x]*
        ((11191934907169751210237537*NM*NC)/17720460308711160000 + 
         (703*lm*NM*NC)/1404 + (lm^2*NM*NC)/6 - (64318606241*NC*NL)/
          17980522560 + (703*lm*NC*NL)/1404 + (lm^2*NC*NL)/6 - 
         (585564026791961955267276552391*NC*NH)/
          7712833521328927649297640000 + (703*lm*NC*NH)/1404 + 
         (lm^2*NC*NH)/6 + (72027481*NM*NC*Pi^2)/54 - (25*NC*NL*Pi^2)/54 + 
         (450280600142*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*(1404014238663981623071664146859849/
            90979359495448976430278400 + (29*lm)/39 - (3*lm^2)/2 + 
           (31212772105*Pi^2)/2808 + (6472704469100*Im[PolyLog[2, (-1)^
                (1/3)]])/(135984591639*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-127637794895084006147588729717539/
            16541701726445268441868800 - (11009*lm)/2808 - (11*lm^2)/12 - 
           (10404258235*Pi^2)/1872 - (3236352234550*Im[PolyLog[2, (-1)^
                (1/3)]])/(135984591639*Sqrt[3]) + 2*Zeta[3])), 
      (1254930976475510748175080322068467629*CF^2*NC)/
        145183206571081452267766272000 + 
       (387580682114654268834585224108344419557*CF*NM*NC)/
        3597510596672227403740572000000 - (53290677158054729*CF*NC*NL)/
        5399550924768000 - (242991055738358681272651231692006543579367*CF*NC*
         NH)/1393749314545436113476372833379708000000 - 
       (1806718791167570677*CF^2*NC*Pi^2)/779155977600 - 
       (753269498897*CF*NM*NC*Pi^2)/24948 + (CF*NC*NL*Pi^2)/18 + 
       (8026811781667363*CF^2*NC*Pi^3)/(1292397558937056*Sqrt[3]) + 
       (72760055686325*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (15485856622421048596781*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(226395742386798784800*Sqrt[3]) - 
       (12288050751590843*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (326206114635555*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (8026811781667363*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (34902711854010*Sqrt[3]) + (8315434935580*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) + 
       (8026811781667363*CF^2*NC*Pi*Log[3]^2)/(1675330168992480*Sqrt[3]) + 
       (2078858733895*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) + 
       CF*((-301119717551975657*CF*NC)/10821610800 + 
         CA*(301117226352845237/21643221600 - (154*lm)/3)*NC - 84*CF*lm*NC - 
         (1818712657025974019*NM*NC)/5019589575 + (28*lm*NM*NC)/3 + 
         (104*NC*NL)/9 + (28*lm*NC*NL)/3 + (11042158514*NC*NH)/
          2151252675 + (28*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-2014326031639*CA + 8*(503545618306*CF + 
            45045*(140295457*NM + 7*NL)))*Log[x]^3)/405405 + 
       13*CF^2*NC*PolyGamma[2, 1] - (95*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (113*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-313732743856712893339903271691071683/
          72591603285540726133883136000 + (1806718790630003647*Pi^2)/
          1558311955200 - (8026811781667363*Pi^3)/(2584795117874112*
           Sqrt[3]) - Pi^4/80 + (15485856622421048596781*
           Im[PolyLog[2, (-1)^(1/3)]])/(452791484773597569600*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (8026811781667363*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(69805423708020*Sqrt[3]) - 
         (8026811781667363*Pi*Log[3]^2)/(3350660337984960*Sqrt[3]) - 
         (13*PolyGamma[2, 1])/2 - (8057255281373*Zeta[3])/3243240) + 
       (8057255281373*CF^2*NC*Zeta[3])/1621620 + 
       (561181243*CF*NM*NC*Zeta[3])/9 + (26*CF*NC*NL*Zeta[3])/3 - 
       (215*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-12191955673125727028156455639*NM*NC)/268760314682119260000 - 
         (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + (35977343141*NC*NL)/
          2996753760 - (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + 
         (37908374415382889884351317071*NC*NH)/242711544377483737215660000 - 
         (10*lm*NC*NH)/9 - (lm^2*NC*NH)/3 - (280590923*NM*NC*Pi^2)/9 + 
         (13*NC*NL*Pi^2)/9 - (8315434935580*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CA*NC*(278958730030655431062773001571/335736500932126790496000 + 
           (76*lm)/9 + (11*lm^2)/6 + (8057222627213*Pi^2)/6486480 + 
           (8026811781667363*Im[PolyLog[2, (-1)^(1/3)]])/(209416271124060*
             Sqrt[3]) - 4*Zeta[3]) + CF*NC*(-2179336691119395143888980397/
            1311470706766120275375 - lm/2 + 3*lm^2 - (8057222627213*Pi^2)/
            3243240 - (8026811781667363*Im[PolyLog[2, (-1)^(1/3)]])/
            (104708135562030*Sqrt[3]) + 8*Zeta[3])), 
      (-965322761237629689476217031464099105371003587417*CF^2*NC)/
        3607642670183386633282842391823741952000 + (27*CF^2*lm*NC)/66248 - 
       (193674677209700578027020970465375954811*CF*NM*NC)/
        6475519074010009326733029600000 - (3*CF*lm*NM*NC)/66248 + 
       (4106121836154133*CF*NC*NL)/1199900205504000 - 
       (3*CF*lm*NC*NL)/66248 + (143172799918095402427880481500001233028509*
         CF*NC*NH)/1393749314545436113476372833379708000000 - 
       (3*CF*lm*NC*NH)/66248 + (357525010881681491*CF^2*NC*Pi^2)/
        4722157440 + (26165851753259*CF*NM*NC*Pi^2)/3243240 - 
       (181*CF*NC*NL*Pi^2)/9828 - (37935493821445*CF^2*NC*Pi^3)/
        (9037745167392*Sqrt[3]) - (78514052459885*CF*NC*NH*Pi^3)/
        (6778308875544*Sqrt[3]) + (34904048196398681*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(507431733877530*Sqrt[3]) - 
       (12882253197050653*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (652412229271110*Sqrt[3]) - (7587098764289*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(48814981614*Sqrt[3]) - 
       (4486517283422*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) - (7587098764289*CF^2*NC*Pi*Log[3]^2)/
        (2343119117472*Sqrt[3]) - (2243258641711*CF*NC*NH*Pi*Log[3]^2)/
        (251048476872*Sqrt[3]) + CF*((13551293325220121831*CF*NC)/
          14915351880 + 30*CF*lm*NC + CA*(-83001664842879085993/
            182713060530 + (55*lm)/3)*NC + (35342928216366209*NM*NC)/
          365061060 - (10*lm*NM*NC)/3 - (46*NC*NL)/9 - (10*lm*NC*NL)/3 - 
         (86420704759*NC*NH)/60235074900 - (10*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-253991771913*CA + 56*(9071130379*CF + 1005660747*NM + 
            65*NL))*Log[x]^3)/1638 - (27*CF^2*NC*PolyGamma[2, 1])/2 + 
       (71*CF*NM*NC*PolyGamma[2, 1])/9 + (82*CF*NC*NH*PolyGamma[2, 1])/9 - 
       (507983878891*CF^2*NC*Zeta[3])/3276 - (154716617*CF*NM*NC*Zeta[3])/
        9 - 3*CF*NC*NL*Zeta[3] + (562*CF*NC*NH*Zeta[3])/9 + 
       CA*CF*NC*(120665348246421629937668014192924740624779225369/
          901910667545846658320710597955935488000 + (33*lm)/132496 - 
         (44690626382361031*Pi^2)/1180539360 + (37935493821445*Pi^3)/
          (18075490334784*Sqrt[3]) - (34904048196398681*
           Im[PolyLog[2, (-1)^(1/3)]])/(1014863467755060*Sqrt[3]) + 
         (7587098764289*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (97629963228*Sqrt[3]) + (7587098764289*Pi*Log[3]^2)/
          (4686238234944*Sqrt[3]) + (27*PolyGamma[2, 1])/4 + 
         (507983859235*Zeta[3])/6552) + CF*Log[x]*
        ((197091684878248082480481023*NM*NC)/29319307056231192000 + 
         (410*lm*NM*NC)/819 + (lm^2*NM*NC)/6 - (1125475189*NC*NL)/
          285405120 + (410*lm*NC*NL)/819 + (lm^2*NC*NL)/6 - 
         (5832581951332213508873437273987*NC*NH)/
          69415501691960348843678760000 + (410*lm*NC*NH)/819 + 
         (lm^2*NC*NH)/6 + (154717081*NM*NC*Pi^2)/18 - (NC*NL*Pi^2)/2 + 
         (4486517283422*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (42701307919075849317640868790938680033/
            336896568211647559721320915200 + (271*lm)/364 - (3*lm^2)/2 + 
           (507983482765*Pi^2)/6552 + (7587098764289*Im[PolyLog[2, (-1)^
                (1/3)]])/(146444944842*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-3050093838227336307514918844804485691/
            48128081173092508531617273600 - (6421*lm)/1638 - (11*lm^2)/12 - 
           (507983489317*Pi^2)/13104 - (7587098764289*
             Im[PolyLog[2, (-1)^(1/3)]])/(292889889684*Sqrt[3]) + 
           2*Zeta[3])), (49363391623612831068304440491477057113*CF^2*NC)/
        871099239426488713606597632000 + 
       (12210274978883505862517340298376923965283*CF*NM*NC)/
        16188797685025023316832574000000 - (53502220916122679*CF*NC*NL)/
        5013868715856000 - (1932382509869290246063073287418898528229419269*CF*
         NC*NH)/10197645609734592411472577109989309523600000 - 
       (25507959100648121953*CF^2*NC*Pi^2)/1655706452400 - 
       (86792316146951*CF*NM*NC*Pi^2)/405405 + (CF*NC*NL*Pi^2)/18 + 
       (12822202237069477*CF^2*NC*Pi^3)/(1938596338405584*Sqrt[3]) + 
       (59794539973805*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (49921924769551111019623*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(679187227160396354400*Sqrt[3]) - 
       (590296417557925244*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12722038470786645*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 + (1831743176724211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7479152540145*Sqrt[3]) + (27334646845168*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) + 
       (1831743176724211*CF^2*NC*Pi*Log[3]^2)/(358999321926960*Sqrt[3]) + 
       (1708415427823*CF*NC*NH*Pi*Log[3]^2)/(94143178827*Sqrt[3]) + 
       CF*((-31755939033980999*CF*NC)/171771600 + 
         CA*(95267690001011897/1030629600 - 55*lm)*NC - 90*CF*lm*NC - 
         (12895602278186476183*NM*NC)/5019589575 + 10*lm*NM*NC + 
         (37*NC*NL)/3 + 10*lm*NC*NL + (161503790213*NC*NH)/29113619535 + 
         10*lm*NC*NH)*Log[x]^2 - (CF*NC*(-26401703696243*CA + 
          52802754239986*CF + 1081080*(655987222*NM + 5*NL))*Log[x]^3)/
        810810 + 14*CF^2*NC*PolyGamma[2, 1] - (103*CF*NM*NC*PolyGamma[2, 1])/
        18 - (121*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-49363391618214058590109637233635179527/
          1742198478852977427213195264000 + (6001872729334065491*Pi^2)/
          779155977600 - (12822202237069477*Pi^3)/(3877192676811168*
           Sqrt[3]) - Pi^4/80 + (49921924769551111019623*
           Im[PolyLog[2, (-1)^(1/3)]])/(1358374454320792708800*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (1831743176724211*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14958305080290*Sqrt[3]) - 
         (1831743176724211*Pi*Log[3]^2)/(717998643853920*Sqrt[3]) - 
         7*PolyGamma[2, 1] - (26401677598819*Zeta[3])/1621620) + 
       (26401677598819*CF^2*NC*Zeta[3])/810810 + 
       (3935922701*CF*NM*NC*Zeta[3])/9 + (28*CF*NC*NL*Zeta[3])/3 - 
       77*CF*NC*NH*Zeta[3] + CF*Log[x]*((-5326591271797365964638558649*NM*
           NC)/14397874000827817500 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (36459356321*NC*NL)/2782699920 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (187233555601190184965935206834653*NC*NH)/
          1094595692305099750828759446750 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (1967961676*NM*NC*Pi^2)/9 + (14*NC*NL*Pi^2)/9 - 
         (27334646845168*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CA*NC*(15518257070666107676535389238121/
            2014419005592760742976000 + (76*lm)/9 + (11*lm^2)/6 + 
           (26401660005529*Pi^2)/3243240 + (1831743176724211*
             Im[PolyLog[2, (-1)^(1/3)]])/(44874915240870*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-15518235268760835733170668055091/
            1007209502796380371488000 - lm/2 + 3*lm^2 - (26401660005529*Pi^2)/
            1621620 - (1831743176724211*Im[PolyLog[2, (-1)^(1/3)]])/
            (22437457620435*Sqrt[3]) + 8*Zeta[3])), 
      (-202272062190318611587321577108138887966834663158317*CF^2*NC)/
        106431765838015121392741198185359520000000 + (29*CF^2*lm*NC)/88200 - 
       (175826788861413233056953054675764445058745971*CF*NM*NC)/
        888364320165169410767016706393500000 - (29*CF*lm*NM*NC)/793800 + 
       (1553833941721187149*CF*NC*NL)/421164972131904000 - 
       (29*CF*lm*NC*NL)/793800 + 
       (1005973490063742315894303338157670985459736829*CF*NC*NH)/
        8997922596824640363064038626461155462000000 - 
       (29*CF*lm*NC*NH)/793800 + (279994266547818689*CF^2*NC*Pi^2)/
        514594080 + (47839981884509*CF*NM*NC*Pi^2)/884520 - 
       (209*CF*NC*NL*Pi^2)/11340 - (11538960484093*CF^2*NC*Pi^3)/
        (2541865828329*Sqrt[3]) - (776341008915395*CF*NC*NH*Pi^3)/
        (61004779879896*Sqrt[3]) + (4670580095401235789*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(63610192353933225*Sqrt[3]) - 
       (259754910922719635*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15266446164943974*Sqrt[3]) - (26374766820784*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(156905298045*Sqrt[3]) - 
       (44362343366594*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) - (1648422926299*CF^2*NC*Pi*Log[3]^2)/
        (470715894135*Sqrt[3]) - (22181171683297*CF*NC*NH*Pi*Log[3]^2)/
        (2259436291848*Sqrt[3]) + CF*((9176812182289817897647*CF*NC)/
          1405485081000 + 32*CF*lm*NC + CA*(-2294203017781615387123/
            702742540500 + (176*lm)/9)*NC + (261631449787988498147*NM*NC)/
          403111655100 - (32*lm*NM*NC)/9 - (49*NC*NL)/9 - 
         (32*lm*NC*NL)/9 - (471107126561*NC*NH)/308261853900 - 
         (32*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-1043083623234*CA + 5*(417233418081*CF + 43003883132*NM + 
            448*NL))*Log[x]^3)/945 - (29*CF^2*NC*PolyGamma[2, 1])/2 + 
       (230*CF*NM*NC*PolyGamma[2, 1])/27 + (263*CF*NC*NH*PolyGamma[2, 1])/
        27 - (1043083727227*CF^2*NC*Zeta[3])/945 - 
       (3071704571*CF*NM*NC*Zeta[3])/27 - (29*CF*NC*NL*Zeta[3])/9 + 
       (200*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*
        (8899970770975544351873867845339631317547482193650573/
          9365995393745330682561225440311637760000000 + (319*lm)/1587600 - 
         (197643011694421597*Pi^2)/726485760 + (11538960484093*Pi^3)/
          (5083731656658*Sqrt[3]) - (4670580095401235789*
           Im[PolyLog[2, (-1)^(1/3)]])/(127220384707866450*Sqrt[3]) + 
         (13187383410392*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (156905298045*Sqrt[3]) + (1648422926299*Pi*Log[3]^2)/
          (941431788270*Sqrt[3]) + (29*PolyGamma[2, 1])/4 + 
         (1043083721137*Zeta[3])/1890) + CF*Log[x]*
        ((726531015511186262450757328681331*NM*NC)/
          12205480930973764073640000 + (473*lm*NM*NC)/945 + 
         (lm^2*NM*NC)/6 - (719538439547*NC*NL)/166961995200 + 
         (473*lm*NC*NL)/945 + (lm^2*NC*NL)/6 - 
         (407472540272413203786584693065823*NC*NH)/
          4415175901734856137796676760000 + (473*lm*NC*NH)/945 + 
         (lm^2*NC*NH)/6 + (3071706077*NM*NC*Pi^2)/54 - 
         (29*NC*NL*Pi^2)/54 + (44362343366594*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(2121342685929056528063721300232099122197/
            2082465050758810465310362800000 + (313*lm)/420 - (3*lm^2)/2 + 
           (2086167208969*Pi^2)/3780 + (26374766820784*
             Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) - 
           4*Zeta[3]) + CA*NC*(-29698798127367637331192848128939527765983/
            58309021421246693028690158400000 - (3704*lm)/945 - (11*lm^2)/12 - 
           (2086167213029*Pi^2)/7560 - (13187383410392*
             Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) + 
           2*Zeta[3])), (2482854373020446051451701702439653655799*CF^2*NC)/
        6533244295698665352049482240000 + 
       (12749288292170970463415877766656343074774910691*CF*NM*NC)/
        2368971520440451762045377883716000000 - (2147421885961769*CF*NC*NL)/
        187184432058624 - 
       (5599501284799585910329505318598424319236102271938079*CF*NC*NH)/
        27341825432364291827716159021532236801581084000000 - 
       (277073062013661987413*CF^2*NC*Pi^2)/2649130323840 - 
       (167044862773043*CF*NM*NC*Pi^2)/108108 + (CF*NC*NL*Pi^2)/18 + 
       (81595161787869383*CF^2*NC*Pi^3)/(11631578030433504*Sqrt[3]) + 
       (2343639723637835*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (32028096941882667260849*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(407512336296237812640*Sqrt[3]) - 
       (6360811121607106481*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (114498346237079805*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 + (81595161787869383*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(314124406686090*Sqrt[3]) + 
       (267844539844324*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) + (81595161787869383*CF^2*NC*Pi*Log[3]^2)/
        (15077971520932320*Sqrt[3]) + (66961134961081*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) + CF*((-40746038270091120619*CF*NC)/
          32464832400 + CA*(40746029728955097199/64929664800 - (176*lm)/3)*
          NC - 96*CF*lm*NC - (8097370258195025898173*NM*NC)/436704293025 + 
         (32*lm*NM*NC)/3 + (118*NC*NL)/9 + (32*lm*NC*NL)/3 + 
         (11529979440794*NC*NH)/1933976154825 + (32*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-88592316314797*CA + 4*(44296066017851*CF + 
            180180*(3518653717*NM + 4*NL)))*Log[x]^3)/405405 + 
       15*CF^2*NC*PolyGamma[2, 1] - (37*CF*NM*NC*PolyGamma[2, 1])/6 - 
       (43*CF*NC*NH*PolyGamma[2, 1])/6 + 
       CA*CF*NC*(-1241427186492660825249888890337844876367/
          6533244295698665352049482240000 + (30785895779145084727*Pi^2)/
          588695627520 - (81595161787869383*Pi^3)/(23263156060867008*
           Sqrt[3]) - Pi^4/80 + (32028096941882667260849*
           Im[PolyLog[2, (-1)^(1/3)]])/(815024672592475625280*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (81595161787869383*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(628248813372180*Sqrt[3]) - 
         (81595161787869383*Pi*Log[3]^2)/(30155943041864640*Sqrt[3]) - 
         (15*PolyGamma[2, 1])/2 - (354369209715137*Zeta[3])/3243240) + 
       (354369209715137*CF^2*NC*Zeta[3])/1621620 + 
       (9383076353*CF*NM*NC*Zeta[3])/3 + 10*CF*NC*NL*Zeta[3] - 
       (247*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-6028964005475087711215614027073411*NM*NC)/
          2034246821828960678940000 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (184385278873*NC*NL)/12985932960 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (140986422502032928765714381282051581439*NC*NH)/
          757372651419744619593435236395260000 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (4691538293*NM*NC*Pi^2)/3 + (5*NC*NL*Pi^2)/3 - 
         (267844539844324*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CA*NC*(195898134582917398631368881523709/
            3021628508389141114464000 + (76*lm)/9 + (11*lm^2)/6 + 
           (354369171997457*Pi^2)/6486480 + (81595161787869383*
             Im[PolyLog[2, (-1)^(1/3)]])/(1884746440116540*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-97949050939674658761071776239847/
            755407127097285278616000 - lm/2 + 3*lm^2 - (354369171997457*Pi^2)/
            3243240 - (81595161787869383*Im[PolyLog[2, (-1)^(1/3)]])/
            (942373220058270*Sqrt[3]) + 8*Zeta[3])), 
      (-180363732955748973799375944518012619700506178059432419*CF^2*NC)/
        13136720812006437840475485033164375040000000 + 
       (31*CF^2*lm*NC)/115200 - 
       (49821436788017855144607885870649195357159040974771*CF*NM*NC)/
        37225862276276834343609944193643968000000 - (31*CF*lm*NM*NC)/
        1036800 + (6665611044172040369*CF*NC*NL)/1684659888527616000 - 
       (31*CF*lm*NC*NL)/1036800 + 
       (26461497442643781855486404756374167200669423848358317*CF*NC*NH)/
        218734603458914334621729272172257894412648672000000 - 
       (31*CF*lm*NC*NH)/1036800 + (168216693614401429211*CF^2*NC*Pi^2)/
        42343741440 + (7201915572916327*CF*NM*NC*Pi^2)/19459440 - 
       (239*CF*NC*NL*Pi^2)/12960 - (85784143008121985*CF^2*NC*Pi^3)/
        (17569376605410048*Sqrt[3]) - (2541981074845975*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) + (13731330070163355212323*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(175869459820154580480*Sqrt[3]) - 
       (41664813905506237*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2973983019144930*Sqrt[3]) - (2450975514517771*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13556617751088*Sqrt[3]) - 
       (145256061419770*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) - (2450975514517771*CF^2*NC*Pi*Log[3]^2)/
        (650717652052224*Sqrt[3]) - (72628030709885*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((1378325535421622638400299*CF*NC)/
          28912835952000 + 34*CF*lm*NC + CA*(-1378325532991854972594709/
            57825671904000 + (187*lm)/9)*NC + (1442976739166667536970179*NM*
           NC)/324907994010600 - (34*lm*NM*NC)/9 - (52*NC*NL)/9 - 
         (34*lm*NC*NL)/9 - (18815557559749*NC*NH)/11603856928950 - 
         (34*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-8633752445387*CA + 32*(539609521658*CF + 51978637790*NM + 
            85*NL))*Log[x]^3)/1080 - (31*CF^2*NC*PolyGamma[2, 1])/2 + 
       (247*CF*NM*NC*PolyGamma[2, 1])/27 + (280*CF*NC*NH*PolyGamma[2, 1])/
        27 - (11511670096831*CF^2*NC*Zeta[3])/1440 - 
       (20791453645*CF*NM*NC*Zeta[3])/27 - (31*CF*NC*NL*Zeta[3])/9 + 
       (638*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (1984001063657981641841250723203081425733354069173669609/
          289007857864141632490460670729616250880000000 + (341*lm)/2073600 - 
         (168216693615985590427*Pi^2)/84687482880 + (85784143008121985*Pi^3)/
          (35138753210820096*Sqrt[3]) - (13731330070163355212323*
           Im[PolyLog[2, (-1)^(1/3)]])/(351738919640309160960*Sqrt[3]) + 
         (2450975514517771*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27113235502176*Sqrt[3]) + (2450975514517771*Pi*Log[3]^2)/
          (1301435304104448*Sqrt[3]) + (31*PolyGamma[2, 1])/4 + 
         (11511670086911*Zeta[3])/2880) + CF*Log[x]*
        ((443222372027841777676249270736826919*NM*NC)/
          902266705743522098059080000 + (1081*lm*NM*NC)/2160 + 
         (lm^2*NM*NC)/6 - (2732296003763*NC*NL)/584366983200 + 
         (1081*lm*NC*NL)/2160 + (lm^2*NC*NL)/6 - 
         (10895863787820184436094854144320758487*NC*NH)/
          108196093059963517084776462342180000 + (1081*lm*NC*NH)/2160 + 
         (lm^2*NC*NH)/6 + (20791455265*NM*NC*Pi^2)/54 - 
         (31*NC*NL*Pi^2)/54 + (145256061419770*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(7294173216204447044634541230200242213209889/
            899624901927806121014076729600000 + (179*lm)/240 - (3*lm^2)/2 + 
           (11511669896881*Pi^2)/2880 + (2450975514517771*
             Im[PolyLog[2, (-1)^(1/3)]])/(40669853253264*Sqrt[3]) - 
           4*Zeta[3]) + CA*NC*(-47364761253477940389608200246759920229141/
            11683440284776702870312684800000 - (16931*lm)/4320 - 
           (11*lm^2)/12 - (34535009700563*Pi^2)/17280 - 
           (2450975514517771*Im[PolyLog[2, (-1)^(1/3)]])/(81339706506528*
             Sqrt[3]) + 2*Zeta[3])), 
      (7336332198765315243294141903029893248427577*CF^2*NC)/
        2822361535741823432085376327680000 + 
       (2938529970976154162370844894641576596526018094510069*CF*NM*NC)/
        75278965936470931672633442702702246400000 - 
       (1723070395140088261*CF*NC*NL)/140388324043968000 - 
       (1889204285218561831365520608780241713705859044586243*CF*NC*NH)/
        8577827586624091553793304791068937035790144000000 - 
       (971027397075194181058097*CF^2*NC*Pi^2)/1342226030745600 - 
       (9181301259003317*CF*NM*NC*Pi^2)/810810 + (CF*NC*NL*Pi^2)/18 + 
       (18625805765066051675*CF^2*NC*Pi^3)/(2512420854573636864*Sqrt[3]) + 
       (634360742598380*CF*NC*NH*Pi^3)/(22876792454961*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (73655172889849360475987099*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(880226646399873675302400*Sqrt[3]) - 
       (2484848721959335334*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (38166115412359935*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 + (3725161153013210335*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13570174368839088*Sqrt[3]) + 
       (289993482330688*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) + (3725161153013210335*CF^2*NC*Pi*Log[3]^2)/
        (651368369704276224*Sqrt[3]) + (18124592645668*CF*NC*NH*Pi*Log[3]^2)/
        (847288609443*Sqrt[3]) + CF*((-4509415152368004764323*CF*NC)/
          519437318400 + CA*(4509415007169188521843/1038874636800 - 
           (187*lm)/3)*NC - 102*CF*lm*NC - (327034082429104577596921*NM*NC)/
          2406725881560 + (34*lm*NM*NC)/3 + (125*NC*NL)/9 + 
         (34*lm*NC*NL)/3 + (5803036854457*NC*NH)/910106425800 + 
         (34*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-1213579268549237*CA + 2427157710973174*CF + 
          360360*(102347157092*NM + 17*NL))*Log[x]^3)/810810 + 
       16*CF^2*NC*PolyGamma[2, 1] - (119*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (137*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-7336332198752027642204351173838739614417537/
          5644723071483646864170752655360000 + (51106705109189099969323*Pi^2)/
          141286950604800 - (18625805765066051675*Pi^3)/(5024841709147273728*
           Sqrt[3]) - Pi^4/80 + (73655172889849360475987099*
           Im[PolyLog[2, (-1)^(1/3)]])/(1760453292799747350604800*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (3725161153013210335*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27140348737678176*
           Sqrt[3]) - (3725161153013210335*Pi*Log[3]^2)/(1302736739408552448*
           Sqrt[3]) - 8*PolyGamma[2, 1] - (19417267825645621*Zeta[3])/
          25945920) + (19417267825645621*CF^2*NC*Zeta[3])/12972960 + 
       (204694313461*CF*NM*NC*Zeta[3])/9 + (32*CF*NC*NL*Zeta[3])/3 - 
       (263*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-12281110678034333530729325072566948721*NM*NC)/
          521309652207368323323024000 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (1489700423573*NC*NL)/97394497200 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (5129003127239481491393258988296000963*NC*NH)/
          25457904249403180490535638198160000 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (102347157104*NM*NC*Pi^2)/9 + 
         (16*NC*NL*Pi^2)/9 - (289993482330688*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(1364864864723937517630805329852335167/
            2610687031248217922896896000 + (76*lm)/9 + (11*lm^2)/6 + 
           (19417267503663961*Pi^2)/51891840 + (3725161153013210335*
             Im[PolyLog[2, (-1)^(1/3)]])/(81421046213034528*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-1364864836467485222856402378413028047/
            1305343515624108961448448000 - lm/2 + 3*lm^2 - 
           (19417267503663961*Pi^2)/25945920 - (3725161153013210335*
             Im[PolyLog[2, (-1)^(1/3)]])/(40710523106517264*Sqrt[3]) + 
           8*Zeta[3])), 
      (-1085577100111210297942500734065837144621000432356988189882123*CF^2*
         NC)/10784377347536281920459063306589654436349849600000 + 
       (33*CF^2*lm*NC)/147968 - 
       (1301624352503339365451321873892475402121476421960261*CF*NM*NC)/
        141148061130882996886187705067566712000000 - (11*CF*lm*NM*NC)/
        443904 + (62317482191187116063*CF*NC*NL)/14753536599529728000 - 
       (11*CF*lm*NC*NL)/443904 + 
       (34186304585340486670855152268773705447087248791966007*CF*NC*NH)/
        262481524150697201546075126606709473295178406400000 - 
       (11*CF*lm*NC*NH)/443904 + (13406375285032982206111*CF^2*NC*Pi^2)/
        455900949504 + (18951637912864141*CF*NM*NC*Pi^2)/7351344 - 
       (271*CF*NC*NL*Pi^2)/14688 - (54879966525810335*CF^2*NC*Pi^3)/
        (10500447736827099*Sqrt[3]) - (8275555744911035*CF*NC*NH*Pi^3)/
        (549043018919064*Sqrt[3]) + (147844329201929736598601*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1786861191375867436830*Sqrt[3]) - 
       (7383083447552713669*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (686990077422478830*Sqrt[3]) - (25087984697513296*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129635157244779*Sqrt[3]) - 
       (472888899709202*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (847288609443*Sqrt[3]) - (1567999043594581*CF^2*NC*Pi*Log[3]^2)/
        (388905471734337*Sqrt[3]) - (236444449854601*CF*NC*NH*Pi*Log[3]^2)/
        (20334926626632*Sqrt[3]) + CF*((134130784756446630098513321*CF*NC)/
          380107416648960 + 36*CF*lm*NC + 
         CA*(-26826156944524550116277353/152042966659584 + 22*lm)*NC + 
         (418803599497334153287774*NM*NC)/13537833083775 - 4*lm*NM*NC - 
         (55*NC*NL)/9 - 4*lm*NC*NL - (3852670911*NC*NH)/2247176360 - 
         4*lm*NC*NH)*Log[x]^2 + (CF*NC*(-71929189664327*CA + 
          136*(1057782199129*CF + 95654837120*NM + 24*NL))*Log[x]^3)/1224 - 
       (33*CF^2*NC*PolyGamma[2, 1])/2 + (88*CF*NM*NC*PolyGamma[2, 1])/9 + 
       11*CF*NC*NH*PolyGamma[2, 1] - (143858379636065*CF^2*NC*Zeta[3])/
        2448 - (47827418035*CF*NM*NC*Zeta[3])/9 - (11*CF*NC*NL*Zeta[3])/3 + 
       (676*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (155082442886056381911008262137665569267361249656017169809989/
          3081250670724651977274018087597044124671385600000 + 
         (121*lm)/887808 - (3527993496065794411321*Pi^2)/239947868160 + 
         (54879966525810335*Pi^3)/(21000895473654198*Sqrt[3]) - 
         (147844329201929736598601*Im[PolyLog[2, (-1)^(1/3)]])/
          (3573722382751734873660*Sqrt[3]) + 
         (12543992348756648*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (129635157244779*Sqrt[3]) + (1567999043594581*Pi*Log[3]^2)/
          (777810943468674*Sqrt[3]) + (33*PolyGamma[2, 1])/4 + 
         (143858379618113*Zeta[3])/4896) + CF*Log[x]*
        ((30687992944697810980531934497640108477*NM*NC)/
          7819644783110524849845360000 + (1225*lm*NM*NC)/2448 + 
         (lm^2*NM*NC)/6 - (137974369751*NC*NL)/27367048800 + 
         (1225*lm*NC*NL)/2448 + (lm^2*NC*NL)/6 - 
         (198604896185110630219810415777306069173*NC*NH)/
          1817694363407387087024244567348624000 + (1225*lm*NC*NH)/2448 + 
         (lm^2*NC*NH)/6 + (15942472871*NM*NC*Pi^2)/6 - 
         (11*NC*NL*Pi^2)/18 + (472888899709202*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(595449807632971120231690621271687567994471730253/
            9260594800460527760739543602225664000 + (203*lm)/272 - 
           (3*lm^2)/2 + (71929189637099*Pi^2)/2448 + 
           (25087984697513296*Im[PolyLog[2, (-1)^(1/3)]])/(388905471734337*
             Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-85064258258991492088460055061518212367661101149/
            2645884228703007931639869600635904000 - (19187*lm)/4896 - 
           (11*lm^2)/12 - (23976396546697*Pi^2)/1632 - 
           (12543992348756648*Im[PolyLog[2, (-1)^(1/3)]])/(388905471734337*
             Sqrt[3]) + 2*Zeta[3])), 
      (1066004772882894108784584801913392329332035055223*CF^2*NC)/
        58931614456673208717800679066040320000 + 
       (162147110527926322206438103538001321813469362033633887*CF*NM*NC)/
        564592244523531987544750820270266848000000 - 
       (2121923770858544264477*CF*NC*NL)/162288902594827008000 - 
       (4178208282550277395287526735483292529813522948506138891*CF*NC*NH)/
        17717502880172061104360071045952889447424542432000000 - 
       (29015796168754861965454691*CF^2*NC*Pi^2)/5704460630668800 - 
       (272731976519776483*CF*NM*NC*Pi^2)/3243240 + (CF*NC*NL*Pi^2)/18 + 
       (83393261348425731475*CF^2*NC*Pi^3)/(10677788631937956672*Sqrt[3]) + 
       (221441698813151845*CF*NC*NH*Pi^3)/(7412080755407364*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (5644369598415380314977127109*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(63596375202390873040598400*Sqrt[3]) - 
       (126525377540213926429*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1686248371855175310*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 + (16678652269685146295*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(57673241067566124*Sqrt[3]) + 
       (25307622721503068*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (22876792454961*Sqrt[3]) + (16678652269685146295*CF^2*NC*Pi*Log[3]^2)/
        (2768315571243173952*Sqrt[3]) + (6326905680375767*CF*NC*NH*Pi*
         Log[3]^2)/(274521509459532*Sqrt[3]) + 
       CF*((-2290720749841587080987083*CF*NC)/37529346254400 + 
         CA*(2290720738733899707784663/75058692508800 - 66*lm)*NC - 
         108*CF*lm*NC - (27322307134999755624127799*NM*NC)/27075666167550 + 
         12*lm*NM*NC + (44*NC*NL)/3 + 12*lm*NC*NL + 
         (10214475243391*NC*NH)/1504203675975 + 12*lm*NC*NH)*Log[x]^2 - 
       (2*CF*NC*(-35956479371803996*CA + 71912954832846137*CF + 
          9189180*(125832373414*NM + 3*NL))*Log[x]^3)/6891885 + 
       17*CF^2*NC*PolyGamma[2, 1] - (127*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (145*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-1066004772882649135173651308377572378311798163773/
          117863228913346417435601358132080640000 + 
         (29015796168752606564266651*Pi^2)/11408921261337600 - 
         (83393261348425731475*Pi^3)/(21355577263875913344*Sqrt[3]) - 
         Pi^4/80 + (5644369598415380314977127109*Im[PolyLog[2, (-1)^(1/3)]])/
          (127192750404781746081196800*Sqrt[3]) - Im[PolyLog[2, (-1)^(1/3)]]^
          2 - (16678652269685146295*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (115346482135132248*Sqrt[3]) - (16678652269685146295*Pi*Log[3]^2)/
          (5536631142486347904*Sqrt[3]) - (17*PolyGamma[2, 1])/2 - 
         (575303667832669733*Zeta[3])/110270160) + 
       (575303667832669733*CF^2*NC*Zeta[3])/55135080 + 
       (1509988480199*CF*NM*NC*Zeta[3])/9 + (34*CF*NC*NL*Zeta[3])/3 - 
       93*CF*NC*NH*Zeta[3] + CF*Log[x]*
        ((-1460418057650392152568241353484832270521*NM*NC)/
          7819644783110524849845360000 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (217125395491261*NC*NL)/13245651619200 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (53247787217487685977028400858389755301403*NC*NH)/
          245388739059997256748273016592064240000 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (754994240497*NM*NC*Pi^2)/9 + 
         (17*NC*NL*Pi^2)/9 - (25307622721503068*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CA*NC*(13241661327714305432786954602982508612799/
            3206576346130623663798112512000 + (76*lm)/9 + (11*lm^2)/6 + 
           (575303666378256773*Pi^2)/220540320 + (16678652269685146295*
             Im[PolyLog[2, (-1)^(1/3)]])/(346039446405396744*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-13241661293007674861282576131375933659799/
            1603288173065311831899056256000 - lm/2 + 3*lm^2 - 
           (575303666378256773*Pi^2)/110270160 - (16678652269685146295*
             Im[PolyLog[2, (-1)^(1/3)]])/(173019723202698372*Sqrt[3]) + 
           8*Zeta[3])), 
      (-810647391694885791522040871621001552205945578621961352659359655183*
         CF^2*NC)/1084311176266530139586836348012316834182381996838400000 + 
       (35*CF^2*lm*NC)/187272 - 
       (4973319297638452068214136262080577962536752774501193*CF*NM*NC)/
        76989851525936180119738748218672752000000 - (35*CF*lm*NM*NC)/
        1685448 + (124947504048043781197*CF*NC*NL)/27820954730541772800 - 
       (35*CF*lm*NC*NL)/1685448 + 
       (77023540614868705180640678627137609046046673444315783*CF*NC*NH)/
        551756145057261418474881105237287214625677792000000 - 
       (35*CF*lm*NC*NH)/1685448 + (141240779455107417169853*CF^2*NC*Pi^2)/
        641110710240 + (223475669130450697*CF*NM*NC*Pi^2)/12252240 - 
       (305*CF*NC*NL*Pi^2)/16524 - (2973081702881764705*CF^2*NC*Pi^3)/
        (533669814389330208*Sqrt[3]) - (2171273899360646605*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) + (116740005016122999651521*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1335508710509298845520*Sqrt[3]) - 
       (2417607846178170142489*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (333877177627324711380*Sqrt[3]) - (84945191510907563*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(411782264189298*Sqrt[3]) - 
       (124072794249179806*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (205891132094649*Sqrt[3]) - (84945191510907563*CF^2*NC*Pi*Log[3]^2)/
        (19765548681086304*Sqrt[3]) - (62036397124589903*CF*NC*NH*Pi*
         Log[3]^2)/(4941387170271576*Sqrt[3]) + 
       CF*((1347893352408410226843954979*CF*NC)/509855621370480 + 
         38*CF*lm*NC + CA*(-2695786704721034637163504643/2039422485481920 + 
           (209*lm)/9)*NC + (71114210657960773974159703*NM*NC)/
          324907994010600 - (38*lm*NM*NC)/9 - (58*NC*NL)/9 - 
         (38*lm*NC*NL)/9 - (4106084174191*NC*NH)/2272083874200 - 
         (38*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-1205190939312391*CA + 24*(100432578250605*CF + 
            8559381724540*NM + 323*NL))*Log[x]^3)/2754 - 
       (35*CF^2*NC*PolyGamma[2, 1])/2 + (281*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (314*CF*NC*NH*PolyGamma[2, 1])/27 - (2410381879359223*CF^2*NC*
         Zeta[3])/5508 - (1006986083561*CF*NM*NC*Zeta[3])/27 - 
       (35*CF*NC*NL*Zeta[3])/9 + (238*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*
        (3242589566818529549466165569825049388376070512403985209371092542607/
          8674489410132241116694690784098534673459055974707200000 + 
         (385*lm)/3370896 - (564963117820525406917007*Pi^2)/5128885681920 + 
         (2973081702881764705*Pi^3)/(1067339628778660416*Sqrt[3]) - 
         (116740005016122999651521*Im[PolyLog[2, (-1)^(1/3)]])/
          (2671017421018597691040*Sqrt[3]) + 
         (84945191510907563*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (823564528378596*Sqrt[3]) + (84945191510907563*Pi*Log[3]^2)/
          (39531097362172608*Sqrt[3]) + (35*PolyGamma[2, 1])/4 + 
         (2410381879316383*Zeta[3])/11016) + 
       CF*Log[x]*((1447922526181478749894049130474926020211*NM*NC)/
          46917868698663149099072160000 + (689*lm*NM*NC)/1377 + 
         (lm^2*NM*NC)/6 - (1364309895989*NC*NL)/252298126080 + 
         (689*lm*NC*NL)/1377 + (lm^2*NC*NL)/6 - 
         (520995793108570012029176323592063365444217*NC*NH)/
          4416997303079950621468914298657156320000 + (689*lm*NC*NH)/1377 + 
         (lm^2*NC*NH)/6 + (1006986085409*NM*NC*Pi^2)/54 - 
         (35*NC*NL*Pi^2)/54 + (124072794249179806*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(15308923735416538461026229088022848520174705038422233/
            30035581660943664225988617230868662976000 + (457*lm)/612 - 
           (3*lm^2)/2 + (267820208721737*Pi^2)/1224 + 
           (84945191510907563*Im[PolyLog[2, (-1)^(1/3)]])/(1235346792567894*
             Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-15308923736022046926888610593316510629939234527561483/
            60071163321887328451977234461737325952000 - (5396*lm)/1377 - 
           (11*lm^2)/12 - (803460626169971*Pi^2)/7344 - 
           (84945191510907563*Im[PolyLog[2, (-1)^(1/3)]])/(2470693585135788*
             Sqrt[3]) + 2*Zeta[3])), 
      (152529203173020134716714428468030653929903242668197*CF^2*NC)/
        1193365192747632476535463751087316480000 + 
       (603984392014789018308837408449378770310627232235645847*CF*NM*NC)/
        282296122261765993772375410135133424000000 - 
       (2126868122200011021697*CF*NC*NL)/153272852450669952000 - 
       (4112589570600883291072108538968375997734537846738790463149*CF*NC*NH)/
        16350206600210928542656591312177865147011251275856000000 - 
       (1862750963579932404485888999*CF^2*NC*Pi^2)/51340145676019200 - 
       (2902907432631322559*CF*NM*NC*Pi^2)/4594590 + (CF*NC*NL*Pi^2)/18 + 
       (7096193645302230083165*CF^2*NC*Pi^3)/(864900879186974490432*
         Sqrt[3]) + (534486167793774665*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (483301720230438059355260926669*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5151306391393660716288470400*Sqrt[3]) - 
       (121061101205397890224462*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1418978004916130023365*Sqrt[3]) + 2*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 + (1419238729060446016633*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) + (244336533848582704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (1419238729060446016633*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) + (15271033365536419*CF*NC*NH*Pi*Log[3]^2)/
        (617673396283947*Sqrt[3]) + CF*((-49019762198470414929615379*CF*NC)/
          112588038763200 + CA*(49019762163296105673509359/225176077526400 - 
           (209*lm)/3)*NC - 114*CF*lm*NC - (205280086086709926669460273*NM*
           NC)/27075666167550 + (38*lm*NM*NC)/3 + (139*NC*NL)/9 + 
         (38*lm*NC*NL)/3 + (379893465977227*NC*NH)/52726297273650 + 
         (38*lm*NC*NH)/3)*Log[x]^2 - (2*CF*NC*(-84860664494744807*CA + 
          169721327545512079*CF + 510510*(5639540532910*NM + 19*NL))*
         Log[x]^3)/2297295 + 18*CF^2*NC*PolyGamma[2, 1] - 
       (15*CF*NM*NC*PolyGamma[2, 1])/2 - (17*CF*NC*NH*PolyGamma[2, 1])/2 + 
       CA*CF*NC*(-305058406346031445343452890591967797625562930531639/
          4773460770990529906141855004349265920000 + 
         (1862750963579914353781417199*Pi^2)/102680291352038400 - 
         (7096193645302230083165*Pi^3)/(1729801758373948980864*Sqrt[3]) - 
         Pi^4/80 + (483301720230438059355260926669*
           Im[PolyLog[2, (-1)^(1/3)]])/(10302612782787321432576940800*
           Sqrt[3]) - Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (1419238729060446016633*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) - (1419238729060446016633*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) - 9*PolyGamma[2, 1] - 
         (4073311893517732823*Zeta[3])/110270160) + 
       (4073311893517732823*CF^2*NC*Zeta[3])/55135080 + 
       1253231229445*CF*NM*NC*Zeta[3] + 12*CF*NC*NL*Zeta[3] - 
       (295*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-723696361736592192880151284727217884647*NM*NC)/
          488727798944407803115335000 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (24309100393829*NC*NL)/1389975787200 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (578608122123089282212167432246349698260419*NC*
           NH)/2486377182531436020062065655781927221250 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (1879846844308*NM*NC*Pi^2)/3 + 2*NC*NL*Pi^2 - 
         (244336533848582704*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CA*NC*(8387699000439286404445138374742501273093649/
            259732684036580516767647113472000 + (76*lm)/9 + (11*lm^2)/6 + 
           (4073311891977353983*Pi^2)/220540320 + (1419238729060446016633*
             Im[PolyLog[2, (-1)^(1/3)]])/(28029195158837136264*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-8387698997628001673683313576506347218798009/
            129866342018290258383823556736000 - lm/2 + 3*lm^2 - 
           (4073311891977353983*Pi^2)/110270160 - (1419238729060446016633*
             Im[PolyLog[2, (-1)^(1/3)]])/(14014597579418568132*Sqrt[3]) + 
           8*Zeta[3])), (-742486893662815728035163542442782283456494380919694\
3675724677906763*CF^2*NC)/
        1322047851276838886768976937683466514404187675289600000 + 
       (37*CF^2*lm*NC)/233928 - 
       (271671483787898720742680163120857679126838282477967609579*CF*NM*NC)/
        591688778521044119278019240672065379001600000 - 
       (37*CF*lm*NM*NC)/2105352 + (28434896312523988059615449*CF*NC*NL)/
        5975801971346720088576000 - (37*CF*lm*NC*NL)/2105352 + 
       (37616988673159748625722823855811743112385355109551735905461*CF*NC*
         NH)/252406314390756209377261128381745793206986191571027000000 - 
       (37*CF*lm*NC*NH)/2105352 + (281240294095621743627229*CF^2*NC*Pi^2)/
        168596588160 + (274124184277650184837*CF*NM*NC*Pi^2)/2095133040 - 
       (341*CF*NC*NL*Pi^2)/18468 - (5623972674062722070*CF^2*NC*Pi^3)/
        (950599356880994433*Sqrt[3]) - (2333910961446246875*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) + (141525642188735787559329619*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1536753179324168815304295*Sqrt[3]) - 
       (361688661632908811401*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (103198400357536728972*Sqrt[3]) - (2570958936714387232*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11735794529394993*Sqrt[3]) - 
       (133366340654071250*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (205891132094649*Sqrt[3]) - (160684933544649202*CF^2*NC*Pi*Log[3]^2)/
        (35207383588184979*Sqrt[3]) - (66683170327035625*CF*NC*NH*Pi*
         Log[3]^2)/(4941387170271576*Sqrt[3]) + 
       CF*((296575483613074274983617813217*CF*NC)/14815804526883360 + 
         40*CF*lm*NC + CA*(-74143870902902303619129724873/7407902263441680 + 
           (220*lm)/9)*NC + (11833641990669891029852989*NM*NC)/
          7537050644760 - (40*lm*NM*NC)/9 - (61*NC*NL)/9 - 
         (40*lm*NC*NL)/9 - (1201997514602383*NC*NH)/632715567283800 - 
         (40*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-10145314200697205*CA + 152*(133490976320059*CF + 
            10758766704078*NM + 60*NL))*Log[x]^3)/3078 - 
       (37*CF^2*NC*PolyGamma[2, 1])/2 + (298*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (331*CF*NC*NH*PolyGamma[2, 1])/27 - (3381771400377175*CF^2*NC*
         Zeta[3])/1026 - (7172511134269*CF*NM*NC*Zeta[3])/27 - 
       (37*CF*NC*NL*Zeta[3])/9 + (752*CF*NC*NH*Zeta[3])/9 + 
       CA*CF*NC*
        (20418389575762052420317862108885349242099154230900473801262918389067/
          7271263182022613877229373157259065829223032214092800000 + 
         (407*lm)/4210704 - (478108499962567655577863*Pi^2)/573228399744 + 
         (2811986337031361035*Pi^3)/(950599356880994433*Sqrt[3]) - 
         (141525642188735787559329619*Im[PolyLog[2, (-1)^(1/3)]])/
          (3073506358648337630608590*Sqrt[3]) + 
         (1285479468357193616*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (11735794529394993*Sqrt[3]) + (80342466772324601*Pi*Log[3]^2)/
          (35207383588184979*Sqrt[3]) + (37*PolyGamma[2, 1])/4 + 
         (3381771400368739*Zeta[3])/2052) + CF*Log[x]*
        ((106701616798934650141640257406848999767937*NM*NC)/
          442969394817033455976757152000 + (770*lm*NM*NC)/1539 + 
         (lm^2*NM*NC)/6 - (1829669133913763*NC*NL)/316914479481600 + 
         (770*lm*NC*NL)/1539 + (lm^2*NC*NL)/6 - 
         (766555278599716023346691540723841892404525811*NC*NH)/
          6046869307916452400790943674861647002080000 + 
         (770*lm*NC*NH)/1539 + (lm^2*NC*NH)/6 + (7172511136231*NM*NC*Pi^2)/
          54 - (37*NC*NL*Pi^2)/54 + (133366340654071250*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(15670596911166415697046631248886428541033042235398127/
            3873366865777802852672740231130121696000 + (511*lm)/684 - 
           (3*lm^2)/2 + (2536328550155333*Pi^2)/1539 + 
           (2570958936714387232*Im[PolyLog[2, (-1)^(1/3)]])/
            (35207383588184979*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-3637817140110984102474700029865836530562025964171371/
            1798348901968265610169486535881842216000 - (12061*lm)/3078 - 
           (11*lm^2)/12 - (1268164275078721*Pi^2)/1539 - 
           (1285479468357193616*Im[PolyLog[2, (-1)^(1/3)]])/
            (35207383588184979*Sqrt[3]) + 2*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["v", 2, -1, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(10*(2*NL*(27 - 65*lm + 12*lm^3 + 96*Zeta[3]) + 
           NM*(36 - 130*lm + 24*lm^3 + 147*Zeta[3]) + 
           NH*(36 - 130*lm + 24*lm^3 + 147*Zeta[3])) + 
         3*CF*(3780*lm^2 - 720*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           90*lm*(-31 + 48*Zeta[3]) - 5*(331 + 192*Log[2]^4 + 
             4608*PolyLog[4, 1/2] + 1272*Zeta[3])) - 
         2*CA*(1260*lm^2 + 660*lm^3 - 5*lm*(961 + 648*Zeta[3]) + 
           6*(22*Pi^4 + 120*Pi^2*Log[2]^2 - 5*(21 + 24*Log[2]^4 + 576*
                PolyLog[4, 1/2] + 55*Zeta[3])))))/8640, 
      (CF*NC*(782*NM - 144*lm^2*NM + 260*NL - 144*lm^2*NL - 262*NH - 
         144*lm^2*NH + 2*CA*(-961 + 504*lm + 396*lm^2 - 648*Zeta[3]) - 
         567*NM*Zeta[3] + 567*NH*Zeta[3] + 54*CF*(-31 - 84*lm + 24*lm^2 + 
           48*Zeta[3])))/1728, 
      -(CF*NC*(100246*NM - 75264*lm*NM - 10368*lm^2*NM + 31968*NL - 
          75264*lm*NL - 10368*lm^2*NL - 87674*NH - 75264*lm*NH - 
          10368*lm^2*NH + 12*CA*(28966 + 40544*lm + 4752*lm^2 - 
            27729*Zeta[3]) + 72*CF*(136 + 4872*lm + 1296*lm^2 - 
            11877*Zeta[3]) - 61425*NM*Zeta[3] + 142695*NH*Zeta[3]))/622080, 
      (CF*NC*(13006*NM - 44160*lm*NM - 1728*lm^2*NM - 24336*NL - 
         44160*lm*NL - 1728*lm^2*NL - 113042*NH - 44160*lm*NH - 
         1728*lm^2*NH + 12*CA*(48160 + 21248*lm + 792*lm^2 - 
           21249*Zeta[3]) + 72*CF*(13423 + 4764*lm + 216*lm^2 - 
           14037*Zeta[3]) - 27405*NM*Zeta[3] + 108675*NH*Zeta[3]))/622080, 
      (CF*NC*(80*CF*(-109586362 - 7544016*lm + 116640*lm^2 + 
           89307765*Zeta[3]) + 8*CA*(-240504682 - 42700320*lm + 712800*lm^2 + 
           123182775*Zeta[3]) - 3*(128*(-230723 - 165180*lm + 2700*lm^2)*
            NL + 5*NM*(232690 - 4228608*lm + 69120*lm^2 - 
             4531275*Zeta[3]) + 5*NH*(-17521550 - 4228608*lm + 69120*lm^2 + 
             14519925*Zeta[3]))))/1741824000, 
      -(CF*NC*(-54613270*NM + 60334080*lm*NM - 4147200*lm^2*NM + 
          145427968*NL + 60334080*lm*NL - 4147200*lm^2*NL + 
          386381350*NH + 60334080*lm*NH - 4147200*lm^2*NH + 
          158594625*NM*Zeta[3] - 302801625*NH*Zeta[3] + 
          96*CA*(-43913414 - 3154240*lm + 237600*lm^2 + 27093825*Zeta[3]) + 
          320*CF*(-88115530 - 2105136*lm + 116640*lm^2 + 71076825*Zeta[3])))/
       3483648000, (CF*NC*(-48174873222*NM + 10112040960*lm*NM - 
         1445068800*lm^2*NM + 40594341888*NL + 10112040960*lm*NL - 
         1445068800*lm^2*NL + 104770414378*NH + 10112040960*lm*NH - 
         1445068800*lm^2*NH + 73181579625*NM*Zeta[3] - 
         80263929375*NH*Zeta[3] + 3*CA*(-631580589114 - 15166914560*lm + 
           2649292800*lm^2 + 446854440375*Zeta[3]) + 
         14*CF*(-1269988956574 - 9752002560*lm + 928972800*lm^2 + 
           1036283338125*Zeta[3])))/1365590016000, 
      -(CF*NC*(CA*(-2254668687626 - 11133480960*lm + 5960908800*lm^2 + 
            1728192200175*Zeta[3]) + 
          2*(7*CF*(-1942828185562 - 4626616320*lm + 696729600*lm^2 + 
              1599448839975*Zeta[3]) - 3*(21*NM*(586911658 - 27013120*lm + 
                8601600*lm^2 - 668721375*Zeta[3]) + 2*(1024*(-2190743 - 
                  276990*lm + 88200*lm^2)*NL + 21*NH*(-278945898 - 
                  13506560*lm + 4300800*lm^2 + 211845375*Zeta[3]))))))/
       1365590016000, (CF*NC*(144*CF*(-1659869686130066 - 1095226675200*lm + 
           283481856000*lm^2 + 1373484289030875*Zeta[3]) + 
         8*CA*(-2023800553317086 + 2835304012800*lm + 3118300416000*lm^2 + 
           1618015693762125*Zeta[3]) - 
         35*(16384*(-176604602 - 2875005*lm + 7909650*lm^2)*NL + 
           63*NM*(264108043066 - 747683840*lm + 2057011200*lm^2 - 
             259383576375*Zeta[3]) + 63*NH*(-124845649886 - 747683840*lm + 
             2057011200*lm^2 + 94581766125*Zeta[3]))))/8111604695040000, 
      -(CF*NC*(72*CF*(-2383771850674514 - 299987251200*lm + 
            195084288000*lm^2 + 1977747392950875*Zeta[3]) + 
          4*CA*(-2447732969882654 + 6942065356800*lm + 2145927168000*lm^2 + 
            1998597515410125*Zeta[3]) - 
          35*(8192*(-107842871 + 10681020*lm + 5443200*lm^2)*NL + 
            9*NM*(1151371090734 + 9722101760*lm + 4954521600*lm^2 - 
              1043248177125*Zeta[3]) + 63*NH*(-40848900154 + 1388871680*lm + 
              707788800*lm^2 + 30959688375*Zeta[3]))))/4055802347520000, 
      (CF*NC*(1089*CA*(-30188216956358946 + 80272860774400*lm + 
           15100968960000*lm^2 + 24902423975401875*Zeta[3]) + 
         22*CF*(-30507892869502623706 + 664204404326400*lm + 
           1223178485760000*lm^2 + 25345567110203022375*Zeta[3]) - 
         15*(1310720*(-2591632231 + 614857089*lm + 152078850*lm^2)*NL + 
           11*NM*(7469878183769606 + 73264134881280*lm + 18121162752000*
              lm^2 - 6479700381779625*Zeta[3]) + 11*NH*(-998228051202778 + 
             73264134881280*lm + 18121162752000*lm^2 + 757722164574375*
              Zeta[3]))))/11341825942487040000, 
      -(CF*NC*(-893314935137229682*NM - 7357011774013440*lm*NM - 
          1236912419635200*lm^2*NM + 17254473142763520*NL - 
          7357011774013440*lm*NL - 1236912419635200*lm^2*NL + 
          64971201231639582*NH - 7357011774013440*lm*NH - 
          1236912419635200*lm^2*NH + 757364354516644875*NM*Zeta[3] - 
          49402682093890125*NH*Zeta[3] + 1815*CA*(-12915766765378954 + 
            27064436195328*lm + 3748219453440*lm^2 + 10706306820742575*
             Zeta[3]) + 330*CF*(-1666472444917054226 + 82576862871552*lm + 
            33733975080960*lm^2 + 1385413121095940475*Zeta[3])))/
       6805095565492224000, CA*CF*NC*(-978118943416755807069157/
          241512841619319029760000 + (221717003*lm)/35416180800 + 
         (61*lm^2)/87360 + (508571642209*Zeta[3])/151145938944) + 
       (CF*NC*(832*CF*(-2007465143879390028248462 + 89003501398219161600*lm + 
            21227258326450176000*lm^2 + 1669454472612462373963125*Zeta[3]) - 
          1155*(143*NM*(14889968399299287554 + 91399973366661120*lm + 
              11881101341491200*lm^2 - 12480132927006619875*Zeta[3]) + 
            3*(6291456*(-951230950983 + 692483912120*lm + 90016126200*lm^2)*
               NL + 143*NH*(-197849129963473066 + 30466657788887040*lm + 
                3960367113830400*lm^2 + 150648414679137375*Zeta[3])))))/
        15456821863636417904640000, 
      -(CF*NC*(128*CA*(-379402331172894700320158 + 421192835921726668800*lm + 
            39932678839173120000*lm^2 + 315534216868134877738125*Zeta[3]) + 
          3328*CF*(-439082034928320400791914 + 14513604580255334400*lm + 
            2513245521346560000*lm^2 + 365212110941965821909375*Zeta[3]) - 
          3465*(8388608*(-223093924849 + 296544087840*lm + 31972941000*lm^2)*
             NL + 39*NM*(14822207355357704002 + 63784413015572480*lm + 
              6877140221952000*lm^2 - 12357002465164231875*Zeta[3]) + 
            143*NH*(-88935252822345826 + 17395749004247040*lm + 
              1875583696896000*lm^2 + 67769486355445875*Zeta[3]))))/
       10304547909090945269760000, CA*CF*NC*((149198321*lm)/34735100400 + 
         (5*lm^2)/13923 + (-45685655523905049064997911622 + 
           38011216327708573473570671625*Zeta[3])/
          8408511093818211340124160000) + 
       (CF*NC*(CF*(-769507231955946195963451016122 + 
            17758864260947330570649600*lm + 2470620877304522342400000*lm^2 + 
            640101836281215019475140752375*Zeta[3]) - 
          5005*(268435456*(-671537517757 + 2183819617980*lm + 
              204324120000*lm^2)*NL + 13*NM*(15496597228989439437026 + 
              45093431921092853760*lm + 4219064486461440000*lm^2 - 
              12890181087125985517875*Zeta[3]) + 143*NH*
             (-17253815738453661194 + 4099402901917532160*lm + 
              383551316951040000*lm^2 + 13147668268186827375*Zeta[3]))))/
        4204255546909105670062080000, 
      -(CF*NC*(CA*(-7462192979254692143368344646 + 4205766355506453440102400*
             lm + 318500940082141200384000*lm^2 + 
            6209616334357209807648239625*Zeta[3]) + 
          18*CF*(-15532759016348006655096334442 + 244149839307922105958400*
             lm + 28954630916558290944000*lm^2 + 
            12921227276224330873664229375*Zeta[3]) - 
          2860*(117440512*(68957783593 + 2057229886140*lm + 172410638400*lm^
                2)*NL + 2*NM*(62789075647917684542618 + 
              120801065564991651840*lm + 10123996823971430400*lm^2 - 
              52188358959411125826375*Zeta[3]) + 715*NH*
             (-1210389074684878370 + 337905078503473152*lm + 
              28318872234885120*lm^2 + 921653679454182675*Zeta[3]))))/
       1201215870545458762874880000, 
      CA*CF*NC*((34126039243*lm)/11967399924480 + (3379*lm^2)/16930368 + 
         (-558129958203430224191705775338438 + 
           464458455144066901566686740727625*Zeta[3])/
          79150516141981368803351592960000) + 
       (CF*NC*(34*CF*(-679947609853991953129535681454746 + 
            7234140616471312336945152000*lm + 760285044937519697756160000*
             lm^2 + 565640209748094809578452365538375*Zeta[3]) - 
          6435*(134217728*(13282698547414861 + 43281254557440900*lm + 
              3325480620462000*lm^2)*NL + 51*NM*
             (90824661456808589950563346 + 113904150033124766515200*lm + 
              8751734380126273536000*lm^2 - 75481888608548473531354875*Zeta[
                3]) + 21879*NH*(-831291790876518606582 + 
              265510839238053068800*lm + 20400313240387584000*lm^2 + 
              632111934224646500625*Zeta[3]))))/
        79150516141981368803351592960000, 
      CA*CF*NC*((-1742271521*lm)/747962495280 - (1619*lm^2)/10581480 + 
         (78696349129951586543760861227114 - 65487344290314455885891393253375*
            Zeta[3])/9893814517747671100418949120000) - 
       (CF*NC*(544*CF*(-105387513401456676283653529785398 + 
            761454920337970333483008000*lm + 72855962577913251889152000*
             lm^2 + 87671610329112768672865134608625*Zeta[3]) - 
          2145*(51*NM*(693073303247924346556449502 + 
              561623504438251487232000*lm + 40255388111771113881600*lm^2 - 
              576068487922920337674454125*Zeta[3]) + 
            11*(1073741824*(1292245247023357 + 2425062277638000*lm + 
                173820757874400*lm^2)*NL + 663*NH*(
                -10989563966699135228674 + 3927437093973786624000*lm + 
                281506210571825971200*lm^2 + 8340805961837822347875*
                 Zeta[3])))))/158301032283962737606703185920000, 
      (CF*NC*(12*CA*(-793315420042793814736321192207078582 + 
           170032517240807526078118625280000*lm + 
           10604839744453727779653943296000*lm^2 + 
           660134361345473114600832998649608625*Zeta[3]) + 
         152*CF*(-3117638891939545905998303905954946666 + 
           15427271545348706445211729920000*lm + 
           1370003220575361961964863488000*lm^2 + 
           2593571583259124386704269743297413375*Zeta[3]) - 
         7735*(17179869184*(1860567339509044021 + 2570106309439769100*lm + 
             174117529309323600*lm^2)*NL + 969*NM*
            (87479698176902035131517596658 + 45566656537820699138457600*lm + 
             3087013804102647388569600*lm^2 - 72725262317327955671153692875*
              Zeta[3]) + 37791*NH*(-2977137472657098561710546 + 
             1168375808662069208678400*lm + 79154200105196086886400*lm^2 + 
             2254673369718233812222875*Zeta[3]))))/
       1066737889550863567819037202186240000, 
      CA*CF*NC*(1329117376523832253433406572983947913/
          133342236193857945977379650273280000 - (800922151*lm)/
          506641262400 - (1999*lm^2)/21162960 - (4738658020310358967*Zeta[3])/
          571335103972638720) - 
       (CF*NC*(8360*CF*(-13770138351235518689647960534969790 + 
            47190004716988272882185404416*lm + 3944551606592143306480680960*
             lm^2 + 11455448219696577685786123959277245*Zeta[3]) - 
          13923*(665*NM*(18327660240779583233493264434 + 
              6119419060986614762176512*lm + 395737259439512113643520*lm^2 - 
              15239237795111945282750757675*Zeta[3]) + 
            13*(17179869184*(16185988092656777 + 18220850103338190*lm + 
                1178325787577400*lm^2)*NL + 323*NH*(
                -2284440361596217801608578 + 969138765314622247403520*lm + 
                62673321630691963699200*lm^2 + 1726111027351012823395875*
                 Zeta[3])))))/213347577910172713563807440437248000, 
      CA*CF*NC*(-997923053018498895743413209560681094739/
          89961562018789494219405470717706240000 + (3631486711*lm)/
          2759861613600 + (73823*lm^2)/973496160 + 
         (754669766159401543067*Zeta[3])/81764401546306519040) + 
       (CF*NC*(324*CF*(-2164268027682785430463031770643593307054 + 
            5200827624633836347623279794585600*lm + 
            413457134647376575588800135168000*lm^2 + 
            1800468496516926701092315141057904425125*Zeta[3]) - 
          1616615*(42949672960*(3556644928182385001 + 3446849460151921824*
               lm + 214371242886921120*lm^2)*NL + 
            57*NM*(12149500160396288940289375009034 + 
              2597211527296098144847134720*lm + 161529382000385760795033600*
               lm^2 - 10103641031404143814063052955375*Zeta[3]) + 
            37791*NH*(-8653986887925397219805754 + 3917362786268624652861440*
               lm + 243634060332406879027200*lm^2 + 6524066401104072502056375*
               Zeta[3]))))/1079538744225473930632865648612474880000, 
      -(CF*NC*(168*CA*(-158211205800938225242384581729562376362 + 
            14177795298426377500701952573440000*lm + 
            792171807774257151979145920512000*lm^2 + 
            131636347408337434975035006153232737375*Zeta[3]) + 
          16*CF*(-104658148985024182669019458833340138904078 + 
            178638939361887373830134578544640000*lm + 
            13610951969939509247641688997888000*lm^2 + 
            87065858737106889656680841670741398275125*Zeta[3]) - 
          1616615*(240518168576*(1198825103986121231 + 1034579607054364800*
               lm + 62231673833128800*lm^2)*NL + 
            15*NM*(121225552440529421255865667999946 + 
              16589012822319570117533368320*lm + 997856547850874720794705920*
               lm^2 - 100823362686594670881058820895375*Zeta[3]) + 
            37791*NH*(-13777672245410772108885722 + 
              6584509336476768324812800*lm + 396069122747826752716800*lm^2 + 
              10364389818023649039006375*Zeta[3]))))/
       2159077488450947861265731297224949760000, 
      (CF*NC*(CA*(-124599936281975310383303778459148307635827334 + 
           8511696825464287427249745602352355737600*lm + 
           462901538489444240507774030742080716800*lm^2 + 
           103667982434523743942943762948052802957810025*Zeta[3]) + 
         46*CF*(-182567495159623781199284320599672072560115862 + 
           224195834992706450469925111429123276800*lm + 
           16466853147845842547707376587662950400*lm^2 + 
           151879258765731563968208793549838143622077825*Zeta[3]) - 
         373065*(1099511627776*(4467638232891988060463 + 
             3511704256028227579320*lm + 205183106867161463040*lm^2)*NL + 
           207*NM*(18652945230983109016146422005760*lm + 
             1089860926684297893853758750720*lm^2 + 
             23*(9253412869797207829418077033389146 - 
               7696674188427697946639993185734375*Zeta[3])) + 
           156009*NH*(-49470267321762145058297425814 + 
             24749595618288070344289812480*lm + 1446078186666472216524226560*
              lm^2 + 37141175204074853073852314625*Zeta[3]))))/
       9137215931124411348876574849855987384320000, 
      -(CF*NC*(459*CA*(-27311882519447199671009399367244839026834 + 
            1433336403703512486156464175238348800*lm + 
            76103589279769940668601611793203200*lm^2 + 
            22723162359683376838881100465024692140475*Zeta[3]) + 
          2*(299*CF*(-1502520192519513098172795376641921459588526 + 
              1344069303647641050777557216211763200*lm + 
              95586478356561150775917682674892800*lm^2 + 
              1249957960856384369891062675796694862575525*Zeta[3]) - 
            11305*(7559142440960*(897092301467676908623 + 
                652587105206893507560*lm + 37160542414576316736*lm^2)*NL + 
              161*NM*(545372628369071416247873944158445606 + 
                30639744617345697605937109401600*lm + 
                1744731883820608889291758632960*lm^2 - 
                453647366459905295816299316996465625*Zeta[3]) + 
              14858*NH*(-638242379515282027016411841322 + 
                332009616596625206256284467200*lm + 
                18905763446972542144028344320*lm^2 + 
                478331468040732024026390457375*Zeta[3])))))/
       830655993738582849897870440895998853120000}, 2, 26, 1]
 
CbarSeries["v", 2, 0, "x0"] = SeriesData[x, 0, 
     {(CF*NC*(-3*(CF*(-29160*lm + 3424*Pi^4 + 20*Pi^2*(367 + 1152*Log[2]^2) + 
             45*(747 + 1056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1536*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 512*Log[2]^4 - 176*
                PolyGamma[2, 1] - 12288*PolyLog[4, 1/2] - 5760*Zeta[3])) - 
           80*(NH*(574 + 27*lm^2 + 4*lm*(3 + Pi^2) + 864*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 144*PolyGamma[2, 1] - 2064*
                Zeta[3]) + NL*(-164 + 27*lm^2 + 30*Pi^2 + 4*lm*(3 + Pi^2) - 
               48*Zeta[3]) + NM*(-164 + 27*lm^2 + 30*Pi^2 + 4*lm*
                (3 + Pi^2) + 4*PolyGamma[2, 1] - 40*Zeta[3]))) + 
         4*CA*(-8910*lm^2 + 1476*Pi^4 - 60*lm*(417 + 22*Pi^2) + 
           Pi^2*(-5605 + 8640*Log[2]^2) + 90*(482 + 198*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 288*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             96*Log[2]^4 - 33*PolyGamma[2, 1] - 2304*PolyLog[4, 1/2] - 
             738*Zeta[3]))))/233280, 
      (CF*NC*(-12*CA*(-7505*Pi^2 + 351*Pi^4 - 1980*lm*(7 + Pi^2) - 
           60*(754 + 675*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             468*Im[PolyLog[2, (-1)^(1/3)]]^2 - 120*PolyGamma[2, 1] - 
             1018*Zeta[3])) - 240*(NL*(351 + 29*Pi^2 + 18*lm*(7 + Pi^2) - 
             216*Zeta[3]) + NM*(351 + 29*Pi^2 + 18*lm*(7 + Pi^2) + 
             18*PolyGamma[2, 1] - 180*Zeta[3]) + 
           3*NH*(1421 + 6*lm*(7 + Pi^2) - 1116*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 186*PolyGamma[2, 1] + 772*Zeta[3])) + 
         CF*(35260*Pi^2 + 1512*Pi^4 + 15*(10217 - 64800*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 44928*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 11520*PolyGamma[2, 1] + 61920*Zeta[3]))))/233280, 
      (CF*NC*(CF*(-12700*Pi^2 + 1424*Pi^4 + 15*(-8747 + 19392*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 11520*Im[PolyLog[2, (-1)^(1/3)]]^
               2 - 3008*PolyGamma[2, 1] - 31584*Zeta[3])) - 
         40*CA*(3645 + 469*Pi^2 + 5*Pi^4 + 44*lm*(33 + 2*Pi^2) + 
           3636*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
           2160*Im[PolyLog[2, (-1)^(1/3)]]^2 - 564*PolyGamma[2, 1] - 
           7752*Zeta[3]) + 80*(NL*(303 + 132*lm + 16*Pi^2 + 8*lm*Pi^2 - 
             96*Zeta[3]) + NM*(1887 - 176*Pi^2 + 4*lm*(33 + 2*Pi^2) + 
             32*PolyGamma[2, 1] - 32*Zeta[3]) + NH*(4671 + 132*lm + 
             8*lm*Pi^2 - 5472*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             816*PolyGamma[2, 1] + 5664*Zeta[3]))))/77760, 
      (CF*NC*(1038015*CF - 2032560*NM - 194400*lm*NM - 632880*NL - 
         194400*lm*NL - 29455920*NH - 194400*lm*NH - 46692*CF*Pi^2 - 
         46800*NM*Pi^2 - 12960*lm*NM*Pi^2 + 82800*NL*Pi^2 - 
         12960*lm*NL*Pi^2 - 12960*lm*NH*Pi^2 + 266000*Sqrt[3]*CF*Pi^3 + 
         800800*Sqrt[3]*NH*Pi^3 + 31104*CF*Pi^4 - 10484640*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] + 8527680*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 7464960*CF*Im[PolyLog[2, (-1)^(1/3)]]^
           2 + 9849600*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         29652480*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         205200*Sqrt[3]*CF*Pi*Log[3]^2 + 617760*Sqrt[3]*NH*Pi*Log[3]^2 + 
         77760*(159*CF - 2*CA*(76 + 33*lm) + 4*(5*NM + 3*lm*NM + 5*NL + 
             3*lm*NL + 3*lm*NH))*Log[x]^2 + 311040*(11*CA + 36*CF - 
           2*(NM + NL))*Log[x]^3 + 2612160*CF*PolyGamma[2, 1] - 
         12960*NM*PolyGamma[2, 1] - 1277280*NH*PolyGamma[2, 1] + 
         10343520*CF*Zeta[3] - 1736640*NM*Zeta[3] + 1088640*NL*Zeta[3] - 
         15134400*NH*Zeta[3] + 2160*Log[x]*
          (8*(NM*(-125 + 15*lm + 9*Pi^2) + NL*(37 + 15*lm + 9*Pi^2) + 
             NH*(1033 + 15*lm - 572*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
           2*CA*(1225 + 330*lm + 42*Pi^2 - 380*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 648*Zeta[3]) + CF*(4335 + 88*Pi^2 - 
             1520*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 2592*Zeta[3])) - 
         20*CA*(-22941*Pi^2 + 6650*Sqrt[3]*Pi^3 + 1296*Pi^4 - 
           3564*lm*(15 + Pi^2) + 5130*Sqrt[3]*Pi*Log[3]^2 + 
           18*(-11823 - 14562*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             10368*Im[PolyLog[2, (-1)^(1/3)]]^2 + 13680*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3628*PolyGamma[2, 1] + 
             19964*Zeta[3]))))/699840, 
      -(CF*NC*(-7531245*CF - 475200*NM - 185760*lm*NM - 602640*NL - 
          185760*lm*NL - 29365200*NH - 185760*lm*NH + 648612*CF*Pi^2 - 
          249120*NM*Pi^2 - 5760*lm*NM*Pi^2 + 92160*NL*Pi^2 - 
          5760*lm*NL*Pi^2 - 5760*lm*NH*Pi^2 + 296800*Sqrt[3]*CF*Pi^3 + 
          739200*Sqrt[3]*NH*Pi^3 + 9360*CF*Pi^4 - 10128960*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 15546240*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 5909760*CF*Im[PolyLog[2, (-1)^(1/3)]]^
            2 + 10990080*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          27371520*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          228960*Sqrt[3]*CF*Pi*Log[3]^2 + 570240*Sqrt[3]*NH*Pi*Log[3]^2 + 
          77760*(165*CF - 2*CA*(76 + 33*lm) + 2*(7*NM + 6*lm*NM + 10*NL + 
              6*lm*NL + 6*lm*NH))*Log[x]^2 + 311040*(11*CA + 36*CF - 
            2*(NM + NL))*Log[x]^3 + 2334720*CF*PolyGamma[2, 1] + 
          313920*NM*PolyGamma[2, 1] - 2614080*NH*PolyGamma[2, 1] - 
          4*CA*(6930*Pi^2 + 37100*Sqrt[3]*Pi^3 + 2322*Pi^4 - 
            1980*lm*(129 + 4*Pi^2) + 28620*Sqrt[3]*Pi*Log[3]^2 - 
            15*(126099 + 84408*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              49248*Im[PolyLog[2, (-1)^(1/3)]]^2 - 91584*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 19456*PolyGamma[2, 1] - 
              149792*Zeta[3])) + 15594720*CF*Zeta[3] - 1480320*NM*Zeta[3] + 
          1002240*NL*Zeta[3] - 26275200*NH*Zeta[3] + 
          2160*Log[x]*(4*(NL*(73 + 33*lm + 18*Pi^2) + NM*(-356 + 33*lm + 
                24*Pi^2) + NH*(1909 + 33*lm - 1056*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) - 2*CA*(1811 + 363*lm + 50*Pi^2 - 
              424*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 648*Zeta[3]) + 
            CF*(6711 + 216*Pi^2 - 1696*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              2592*Zeta[3]))))/699840, 
      (CF*NC*(-1320944625*CF - 537192000*NM - 26730000*lm*NM - 
         202581000*NL - 26730000*lm*NL - 8159365872*NH - 26730000*lm*NH - 
         40549500*CF*Pi^2 + 5238000*NM*Pi^2 - 972000*lm*NM*Pi^2 + 
         24678000*NL*Pi^2 - 972000*lm*NL*Pi^2 - 972000*lm*NH*Pi^2 + 
         89390000*Sqrt[3]*CF*Pi^3 + 270970000*Sqrt[3]*NH*Pi^3 + 
         8116200*CF*Pi^4 - 1908864000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         1321992000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         1271376000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 3309984000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10033632000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 68958000*Sqrt[3]*CF*Pi*
          Log[3]^2 + 209034000*Sqrt[3]*NH*Pi*Log[3]^2 + 
         1166400*(3430*CF - 5*CA*(674 + 297*lm) + 3*(330*NM + 90*lm*NM + 
             135*NL + 90*lm*NL + 8*NH + 90*lm*NH))*Log[x]^2 + 
         104976000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 + 
         596904000*CF*PolyGamma[2, 1] - 972000*NM*PolyGamma[2, 1] - 
         196404000*NH*PolyGamma[2, 1] - 50*CA*(-1047708*Pi^2 + 
           893900*Sqrt[3]*Pi^3 + 96714*Pi^4 - 53460*lm*(55 + 2*Pi^2) + 
           689580*Sqrt[3]*Pi*Log[3]^2 - 15*(1744767 + 1272576*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 847584*Im[PolyLog[2, (-1)^(1/3)]]^
               2 - 2206656*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
             397936*PolyGamma[2, 1] - 1680176*Zeta[3])) + 
         1999596000*CF*Zeta[3] - 1121688000*NM*Zeta[3] + 
         326592000*NL*Zeta[3] - 3917928000*NH*Zeta[3] - 
         2160*Log[x]*(2*(450*NM*(235 - 39*lm + 11*Pi^2) - 
             225*NL*(343 + 78*lm + 54*Pi^2) - 2*NH*(696849 + 8775*lm - 
               387100*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
           50*CA*(19335 + 3861*lm + 312*Pi^2 - 5108*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 5832*Zeta[3]) - 25*CF*(64245 + 204*Pi^2 - 
             20432*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 23328*Zeta[3]))))/
       52488000, -(CF*NC*(-31857937875*CF - 5231104848*NM - 
          196992000*lm*NM - 1701486000*NL - 196992000*lm*NL - 
          67236928848*NH - 196992000*lm*NH + 739586700*CF*Pi^2 - 
          177552000*NM*Pi^2 - 3888000*lm*NM*Pi^2 + 185328000*NL*Pi^2 - 
          3888000*lm*NL*Pi^2 - 3888000*lm*NH*Pi^2 + 771610000*Sqrt[3]*CF*
           Pi^3 + 2052680000*Sqrt[3]*NH*Pi^3 + 39657600*CF*Pi^4 - 
          16637184000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
          23283072000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          8398080000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 28571616000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 76007808000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 595242000*Sqrt[3]*CF*Pi*
           Log[3]^2 + 1583496000*Sqrt[3]*NH*Pi*Log[3]^2 - 
          388800*(15*CA*(4981 + 2332*lm) - 4*(17345*CF + 2*(2881 + 795*lm)*
               NM + 3*(815*NL + 530*lm*NL + 54*NH + 530*lm*NH)))*
           Log[x]^2 + 15552000*(835*CA + 2038*CF - 248*NM - 106*NL)*
           Log[x]^3 + 4195944000*CF*PolyGamma[2, 1] + 443232000*NM*
           PolyGamma[2, 1] - 4408704000*NH*PolyGamma[2, 1] - 
          200*CA*(754920*Pi^2 + 1929025*Sqrt[3]*Pi^3 + 114696*Pi^4 - 
            35640*lm*(152 + 3*Pi^2) + 1488105*Sqrt[3]*Pi*Log[3]^2 - 
            180*(551793 + 231072*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              116640*Im[PolyLog[2, (-1)^(1/3)]]^2 - 396828*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 58277*PolyGamma[2, 1] - 
              479380*Zeta[3])) + 4320*Log[x]*
           (4*(6*NM*(-43307 + 5325*lm - 5325*Pi^2) + 225*NL*(657 + 142*lm + 
                106*Pi^2) + 2*NH*(1319154 + 15975*lm - 733100*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) - 25*CF*(-431103 + 5058*Pi^2 + 
              88184*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 93312*Zeta[3]) + 
            25*CA*(-230568 - 28116*lm + 2259*Pi^2 + 44092*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 46656*Zeta[3])) + 
          32733684000*CF*Zeta[3] - 8164800000*NM*Zeta[3] + 
          2519424000*NL*Zeta[3] - 50465664000*NH*Zeta[3]))/472392000, 
      (CF*NC*(-3021403796775*CF - 1744250079600*NM - 24504606000*lm*NM - 
         381277222200*NL - 24504606000*lm*NL - 12701110937184*NH - 
         24504606000*lm*NH - 96174505980*CF*Pi^2 + 12168954000*NM*Pi^2 - 
         600112800*lm*NM*Pi^2 + 32839506000*NL*Pi^2 - 
         600112800*lm*NL*Pi^2 - 600112800*lm*NH*Pi^2 + 
         145978399000*Sqrt[3]*CF*Pi^3 + 455349650000*Sqrt[3]*NH*Pi^3 + 
         10922052960*CF*Pi^4 - 2357067736800*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] + 1243043524800*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 1411465305600*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 5405371574400*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 16860947040000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 112611907800*Sqrt[3]*CF*Pi*
          Log[3]^2 + 351269730000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         28576800*(21*CA*(10679 + 4818*lm) - 2*(109543*CF + 33236*NM + 
             9198*lm*NM + 13055*NL + 9198*lm*NL + 1458*NH + 9198*lm*NH))*
          Log[x]^2 + 1600300800*(1614*CA + 6329*CF - 1360*NM - 219*NL)*
          Log[x]^3 + 906754800000*CF*PolyGamma[2, 1] - 173432599200*NM*
          PolyGamma[2, 1] - 204975976800*NH*PolyGamma[2, 1] - 
         3430*CA*(-18593874*Pi^2 + 21279650*Sqrt[3]*Pi^3 + 1732104*Pi^4 - 
           160380*lm*(245 + 6*Pi^2) + 16415730*Sqrt[3]*Pi*Log[3]^2 - 
           15*(42179067 + 22906392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             13716864*Im[PolyLog[2, (-1)^(1/3)]]^2 - 52530336*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
             8812000*PolyGamma[2, 1] - 32937536*Zeta[3])) + 
         15120*Log[x]*(36400140*NM + 6747300*lm*NM + 42569730*NL + 
           6747300*lm*NL + 667207236*NH + 6747300*lm*NH - 
           29820420*NM*Pi^2 + 5794740*NL*Pi^2 - 371714000*Sqrt[3]*NH*
            Im[PolyLog[2, (-1)^(1/3)]] - 245*CF*(-1608423 + 17946*Pi^2 + 
             486392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 419904*Zeta[3]) + 
           245*CA*(-968970 - 151470*lm + 45*Pi^2 + 243196*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 209952*Zeta[3])) + 
         2814564429600*CF*Zeta[3] - 1940764795200*NM*Zeta[3] + 
         532900166400*NL*Zeta[3] - 5775760536000*NH*Zeta[3]))/32406091200, 
      -(CF*NC*(-13522934265876*CF - 4505691010977*NM - 46439284500*lm*NM - 
          807283685250*NL - 46439284500*lm*NL - 27469369346337*NH - 
          46439284500*lm*NH - 347370849000*CF*Pi^2 + 31950450000*NM*Pi^2 - 
          666792000*lm*NM*Pi^2 + 61733826000*NL*Pi^2 - 
          666792000*lm*NL*Pi^2 - 666792000*lm*NH*Pi^2 + 
          321421870000*Sqrt[3]*CF*Pi^3 + 907890130000*Sqrt[3]*NH*Pi^3 + 
          15669612000*CF*Pi^4 - 5649965286000*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 6931286376000*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 2448460224000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 11901792672000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 33617874528000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 247954014000*Sqrt[3]*CF*Pi*
           Log[3]^2 + 700372386000*Sqrt[3]*NH*Pi*Log[3]^2 - 
          4762800*(7*CA*(265759 + 173580*lm) - 2*(412748*CF + 
              2*(239093 + 55230*lm)*NM + 3*(54215*NL + 36820*lm*NL + 
                6282*NH + 36820*lm*NH)))*Log[x]^2 + 
          1333584000*(5675*CA + 10497*CF - 3620*NM - 526*NL)*Log[x]^3 + 
          292773824000*CF*PolyGamma[2, 1] + 375737292000*NM*
           PolyGamma[2, 1] - 1493127020000*NH*PolyGamma[2, 1] + 
          3780*Log[x]*(303195342*NM + 48510000*lm*NM + 332646300*NL + 
            48510000*lm*NL + 5313981402*NH + 48510000*lm*NH - 
            308876400*NM*Pi^2 + 46393200*NL*Pi^2 - 2964539200*Sqrt[3]*NH*
             Im[PolyLog[2, (-1)^(1/3)]] - 49*CF*(-121823229 + 6249600*Pi^2 + 
              21419200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 17496000*Zeta[
                3]) + 49*CA*(-64332027 - 5445000*lm + 3147300*Pi^2 + 
              10709600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 8748000*Zeta[
                3])) + 11820326056000*CF*Zeta[3] - 2529142056000*NM*
           Zeta[3] + 1060199280000*NL*Zeta[3] - 18427823176000*NH*Zeta[3] - 
          686*CA*(-309122325*Pi^2 + 234272500*Sqrt[3]*Pi^3 + 12198600*Pi^4 - 
            111375*lm*(3343 + 48*Pi^2) + 180724500*Sqrt[3]*Pi*Log[3]^2 + 
            4*(-2815576677 - 1029512625*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              446148000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 2168694000*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 53348000*PolyGamma[2, 
                1] + 2222011000*Zeta[3]))))/81015228000, 
      -(CF*NC*(2332433761683795*CF + 1163179282601448*NM + 
          11765211444000*lm*NM + 317820238974000*NL + 11765211444000*lm*
           NL + 9356818486565160*NH + 11765211444000*lm*NH + 
          147843960868800*CF*Pi^2 + 246874403664000*NM*Pi^2 + 
          216040608000*lm*NM*Pi^2 - 20355826176000*NL*Pi^2 + 
          216040608000*lm*NL*Pi^2 + 216040608000*lm*NH*Pi^2 - 
          108130811740000*Sqrt[3]*CF*Pi^3 - 349936338080000*Sqrt[3]*NH*
           Pi^3 - 6902497425600*CF*Pi^4 + 1504492165848000*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] - 530119660224000*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] - 801078574464000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 - 4003929486144000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 12957642690048000*Sqrt[3]*
           NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 83415197628000*Sqrt[3]*
           CF*Pi*Log[3]^2 - 269950889376000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          514382400*(35*CA*(244327 + 121968*lm) - 
            4*(1833930*CF + 7*(-121483 + 27720*lm)*NM + 5*(53284*NL + 
                38808*lm*NL + 8247*NH + 38808*lm*NH)))*Log[x]^2 - 
          48009024000*(48233*CA + 187524*CF - 87960*NM - 5544*NL)*
           Log[x]^3 - 799677685632000*CF*PolyGamma[2, 1] + 
          746852381856000*NM*PolyGamma[2, 1] + 111706494816000*NH*
           PolyGamma[2, 1] + 490*CA*(-159412135860*Pi^2 + 
            110337563000*Sqrt[3]*Pi^3 + 7396084080*Pi^4 - 
            101039400*lm*(1307 + 24*Pi^2) + 85117548600*Sqrt[3]*Pi*Log[3]^2 - 
            21*(147663588399 + 73104575600*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 38925100800*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              194554396800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              38857030400*PolyGamma[2, 1] - 138309707200*Zeta[3])) - 
          15120*Log[x]*(4*(3969*NM*(8904427 + 265500*lm - 4216800*Pi^2) + 
              5*(39690*NL*(43783 + 5310*lm + 5544*Pi^2) + NH*(25570201317 + 
                  210753900*lm - 14283115840*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]]))) - 245*CF*(-1299215559 + 55180440*Pi^2 + 
              360285920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 251942400*Zeta[
                3]) + 245*CA*(-767362677 - 94624200*lm + 21767940*Pi^2 + 
              180142960*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 125971200*Zeta[
                3])) - 2505933775968000*CF*Zeta[3] + 1608638367168000*NM*
           Zeta[3] - 401835530880000*NL*Zeta[3] + 4073544678336000*NH*
           Zeta[3]))/11666192832000, 
      -(CF*NC*(-11017775166020847*CF - 6711716499210720*NM - 
          42650416771200*lm*NM - 1252203369984000*NL - 42650416771200*lm*
           NL - 38917220514838560*NH - 42650416771200*lm*NH - 
          3356131762746000*CF*Pi^2 - 630230461056000*NM*Pi^2 - 
          480090240000*lm*NM*Pi^2 + 72317593152000*NL*Pi^2 - 
          480090240000*lm*NL*Pi^2 - 480090240000*lm*NH*Pi^2 + 
          452451835080000*Sqrt[3]*CF*Pi^3 + 1347080089600000*Sqrt[3]*NH*
           Pi^3 + 19935747216000*CF*Pi^4 - 7108685129750400*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 7486844628480000*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 2670261914880000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 16753645093248000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 49880451317760000*Sqrt[3]*
           NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 349034272776000*
           Sqrt[3]*CF*Pi*Log[3]^2 + 1039176069120000*Sqrt[3]*NH*Pi*
           Log[3]^2 - 342921600*(83316331*CF + 21*CA*(-583109 + 1152800*lm) - 
            40*((-166357 + 110040*lm)*NM + 3*(70*(751 + 524*lm)*NL + 
                (8091 + 36680*lm)*NH)))*Log[x]^2 + 192036096000*
           (93614*CA + 63895*CF - 85600*NM - 5240*NL)*Log[x]^3 - 
          8987311793600000*CF*PolyGamma[2, 1] + 2726912563200000*NM*
           PolyGamma[2, 1] - 1856443321600000*NH*PolyGamma[2, 1] + 
          15120*Log[x]*(80*(27*NM*(324645547 + 6582660*lm - 128007600*
                 Pi^2) + 79380*NL*(20240 + 2239*lm + 2620*Pi^2) + 
              NH*(24566883681 + 177731820*lm - 13745715200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) - 63*CF*(-36913648833 + 
              5424501600*Pi^2 + 5862673600*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 3919104000*Zeta[3]) + 
            252*CA*(-4818137343 - 310325400*lm + 680409450*Pi^2 + 
              732834200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 489888000*Zeta[
                3])) + 4590481855232000*CF*Zeta[3] + 4595423777280000*NM*
           Zeta[3] + 1515164797440000*NL*Zeta[3] - 24103279316480000*NH*
           Zeta[3] - 700*CA*(-9116991455589 - 2442063205260*Pi^2 + 
            323179882200*Sqrt[3]*Pi^3 + 14788494000*Pi^4 - 
            6286896*lm*(53303 + 600*Pi^2) - 5077632235536*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 1907329939200*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 11966889352320*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 249310194840*Sqrt[3]*Pi*
             Log[3]^2 - 6419508424000*PolyGamma[2, 1] + 3463578892480*
             Zeta[3])))/58330964160000, 
      (CF*NC*(-51269520729845400741*CF + 89343835414355027880*NM - 
         294242776644247200*lm*NM - 12330944462515971600*NL - 
         294242776644247200*lm*NL - 335065654823861947320*NH - 
         294242776644247200*lm*NH - 15586389741675337200*CF*Pi^2 - 
         52820883271504656000*NM*Pi^2 - 4313250738720000*lm*NM*Pi^2 + 
         620341306244352000*NL*Pi^2 - 4313250738720000*lm*NL*Pi^2 - 
         4313250738720000*lm*NH*Pi^2 + 3832349760266720000*Sqrt[3]*CF*Pi^3 + 
         12885657803603200000*Sqrt[3]*NH*Pi^3 + 213937236640512000*CF*Pi^4 - 
         48920871742880121600*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         8956006836342720000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         23188035971358720000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         141906436837304832000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 477137500384849920000*
          Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         2956384100777184000*Sqrt[3]*CF*Pi*Log[3]^2 + 9940364591351040000*
          Sqrt[3]*NH*Pi*Log[3]^2 + 373441622400*(30708579*CF - 
           11*CA*(23812193 + 19404000*lm) + 10*(11*(-14457727 + 352800*lm)*
              NM + 7700*(677 + 504*lm)*NL + 3*(329741 + 1293600*lm)*NH))*
          Log[x]^2 + 191700032832000*(595041*CA + 
           4*(443713*CF - 600*(880*NM + 21*NL)))*Log[x]^3 + 
         56844578597773120000*CF*PolyGamma[2, 1] - 141616961504393760000*NM*
          PolyGamma[2, 1] - 3142472736763360000*NH*PolyGamma[2, 1] + 
         166320*Log[x]*(-20*(-29403*NM*(1592694247 + 19959660*lm - 
               1026354000*Pi^2) - 28814940*NL*(207826 + 20367*lm + 25200*
                Pi^2) + NH*(-85407958363767 - 586873882980*lm + 
               47813201497600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
           121*CF*(-9820984460937 + 1091748067200*Pi^2 + 2350449875200*
              Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1388832480000*Zeta[3]) + 
           1210*CA*(-563346833673 - 53352171180*lm + 50985535860*Pi^2 + 
             117522493760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             69441624000*Zeta[3])) + 172729700107276928000*CF*Zeta[3] - 
         165861743906738880000*NM*Zeta[3] + 14544281490963840000*NL*
          Zeta[3] - 140743348501891520000*NH*Zeta[3] - 
         2662*CA*(-13363586029449081 - 2943870979429800*Pi^2 + 
           719825274280000*Sqrt[3]*Pi^3 + 41479796736000*Pi^4 - 
           14852791800*lm*(40931 + 600*Pi^2) - 9188743753358400*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 4355378657280000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 26654101584768000*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 555293783016000*Sqrt[3]*
            Pi*Log[3]^2 + 10677043312880000*PolyGamma[2, 1] + 
           34427928045952000*Zeta[3])))/232915539890880000, 
      -(CF*NC*(1705349355215660079453*CF + 198196611685430752800*NM - 
          1865653474525948800*lm*NM - 83102369198991357600*NL - 
          1865653474525948800*lm*NL - 2438214872118423233760*NH - 
          1865653474525948800*lm*NH - 913766402658824946000*CF*Pi^2 - 
          238072174924044384000*NM*Pi^2 - 17253002954880000*lm*NM*Pi^2 + 
          3826140955293888000*NL*Pi^2 - 17253002954880000*lm*NL*Pi^2 - 
          17253002954880000*lm*NH*Pi^2 + 27933087655688600000*Sqrt[3]*CF*
           Pi^3 + 87103616224609600000*Sqrt[3]*NH*Pi^3 + 
          1108936764924912000*CF*Pi^4 - 409773445019485008000*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 364520348121874560000*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 135091013136710400000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 1034322331479212160000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3225322475059829760000*
           Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          21548381905816920000*Sqrt[3]*CF*Pi*Log[3]^2 + 67194218230413120000*
           Sqrt[3]*NH*Pi*Log[3]^2 - 373441622400*(27405891183*CF + 
            165*CA*(-72611839 + 8454600*lm) - 40*(14*(-12244669 + 452925*lm)*
               NM + 17325*(515 + 366*lm)*NL + (1640659 + 6340950*lm)*NH))*
           Log[x]^2 + 6901201181952000*(387482*CA - 278093*CF - 352770*NM - 
            9150*NL)*Log[x]^3 - 3684744059422863360000*CF*PolyGamma[2, 1] + 
          944299984227969600000*NM*PolyGamma[2, 1] - 105479805478850880000*
           NH*PolyGamma[2, 1] + 166320*Log[x]*
           (-40*(-1134*NM*(234022733191 + 1509582690*lm - 82012807800*
                 Pi^2) - 5*(12966723*NL*(295933 + 26404*lm + 36600*Pi^2) + 
                2*NH*(28816666006629 + 171186677046*lm - 16160225644640*
                   Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) - 
            121*CF*(-84521914828989 + 54423972640800*Pi^2 + 17131871176000*
               Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 9721827360000*Zeta[3]) + 
            242*CA*(-22136687901519 - 1556242518600*lm + 13622764169700*Pi^
                2 + 4282967794000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              2430456840000*Zeta[3])) - 5324*CA*(153212789812306437 - 
            86050232313601500*Pi^2 + 2623317773825000*Sqrt[3]*Pi^3 + 
            106737562890000*Pi^4 - 89116750800*lm*(21627 + 200*Pi^2) - 
            38483606782446000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            12686984704800000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            97137709567920000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
            2023702282665000*Sqrt[3]*Pi*Log[3]^2 - 346050343672320000*
             PolyGamma[2, 1] - 415333386872376000*Zeta[3]) - 
          4429690285153676928000*CF*Zeta[3] + 2497389430721834880000*NM*
           Zeta[3] + 94926022257749760000*NL*Zeta[3] - 
          1420981720195255680000*NH*Zeta[3]))/2096239859017920000, 
      (1437203417285683*CF^2*NC)/2160406080000 + (40118865069119*CF*NM*NC)/
        7715736000 - (49231*CF*lm*NM*NC)/32400 - (133440827*CF*NC*NL)/
        1458000 - (49231*CF*lm*NC*NL)/32400 - 
       (1116344145913337213879*CF*NC*NH)/473810593648392000 - 
       (49231*CF*lm*NC*NH)/32400 - (1162751087*CF^2*NC*Pi^2)/3061800 - 
       (1657429*CF*NM*NC*Pi^2)/972 - (CF*lm*NM*NC*Pi^2)/54 + 
       (9157*CF*NC*NL*Pi^2)/2430 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (2028172321*CF^2*NC*Pi^3)/
        (25509168*Sqrt[3]) + (1769251085*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) + 
       (1423*CF^2*NC*Pi^4)/1080 - (1263618227*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1312200*Sqrt[3]) + 
       (7074311*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) + 
       (1226*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (289738903*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (98415*Sqrt[3]) + (202200124*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) + 
       (289738903*CF^2*NC*Pi*Log[3]^2)/(4723920*Sqrt[3]) + 
       (50550031*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) + 
       (CF*NC*(3861*CA*(11705377 - 7099400*lm) + 
          20*(-7714718440*CF + 1001*(-49095943 + 248940*lm)*NM + 
            329579250*NL + 249188940*lm*NL + 71979253*NH + 
            249188940*lm*NH))*Log[x]^2)/48648600 + 
       (CF*NC*(1784733*CA + 1944868*CF - 10967880*NM - 82980*NL)*Log[x]^3)/
        1215 + (21946635265*CF^2*NC*PolyGamma[2, 1])/14348907 - 
       (298369*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (518719631*CF*NC*NH*PolyGamma[2, 1])/28697814 + 
       (591575492231*CF^2*NC*Zeta[3])/143489070 - (193285*CF*NM*NC*Zeta[3])/
        27 + (308*CF*NC*NL*Zeta[3])/3 - (13779235463*CF*NC*NH*Zeta[3])/
        14348907 - (CA*CF*NC*(10800178503621021 - 7474405946870835*Pi^2 + 
          521747329577250*Sqrt[3]*Pi^3 + 26522360266500*Pi^4 - 
          6683756310*lm*(49231 + 600*Pi^2) - 6319278936133380*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 2681766077256000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 19319558260917600*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 402490797102450*Sqrt[3]*Pi*
           Log[3]^2 + 30110783583580000*PolyGamma[2, 1] + 
          82493131334205200*Zeta[3]))/39373400808000 + 
       CF*Log[x]*((1236564641*NM*NC)/1530900 + (119*lm*NM*NC)/10 + 
         (2348089*NC*NL)/16200 + (119*lm*NC*NL)/10 + 
         (2408325362255269*NC*NH)/1183343140980 + (119*lm*NC*NH)/10 - 
         (182647*NM*NC*Pi^2)/81 + (461*NC*NL*Pi^2)/27 - 
         (202200124*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(59049*Sqrt[3]) + 
         CA*NC*(-11016108144371/11573604000 - (1309*lm)/20 + 
           (2307809*Pi^2)/9720 + (289738903*Im[PolyLog[2, (-1)^(1/3)]])/
            (590490*Sqrt[3]) - 84*Zeta[3]) + 
         CF*NC*(19834128852169/11573604000 - (2355179*Pi^2)/4860 - 
           (289738903*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) + 
           168*Zeta[3])), (-46798481297260189253191*CF^2*NC)/
        4891226337708480000 - (269921069086340710823*CF*NM*NC)/
        118452648412098000 + (3748219*CF*lm*NM*NC)/3572100 + 
       (7076227577*CF*NC*NL)/107163000 + (3748219*CF*lm*NC*NL)/3572100 + 
       (17889784115108038251103*CF*NC*NH)/9594664521379938000 + 
       (3748219*CF*lm*NC*NH)/3572100 + (89148353527*CF^2*NC*Pi^2)/28576800 + 
       (18706174*CF*NM*NC*Pi^2)/25515 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (7139*CF*NC*NL*Pi^2)/2835 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (903690824*CF^2*NC*Pi^3)/
        (14348907*Sqrt[3]) - (2935892155*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) - 
       (367*CF^2*NC*Pi^4)/486 + (5176122769199*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5859137025*Sqrt[3]) - 
       (15601294504*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (23914845*Sqrt[3]) - (776*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (14459053184*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6200145*Sqrt[3]) - (1342122128*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (903690824*CF^2*NC*Pi*Log[3]^2)/(18600435*Sqrt[3]) - 
       (83882633*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) + 
       (CF*NC*(18840288042017*CF + 1768*CA*(-5184775669 + 114726150*lm) - 
          280*((-15676918927 + 131711580*lm)*NM + 180180*(1015 + 731*lm)*
             NL + (38053931 + 131711580*lm)*NH))*Log[x]^2)/510810300 + 
       (4*CF*NC*(-15005786*CA + 35*(680065*CF + 297928*NM + 2924*NL))*
         Log[x]^3)/8505 + (708942044887*CF^2*NC*PolyGamma[2, 1])/43046721 - 
       (334612*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (3215856056*CF*NC*NH*PolyGamma[2, 1])/43046721 + 
       (CF*NC*Log[x]*(560*(-972*NM*(258822046569509 + 616657896855*lm - 
              101646037543050*Pi^2) - 7*(134165889*NL*(8534541 + 638220*lm + 
                1023400*Pi^2) + 10*NH*(1709836049895351 + 8562735367758*lm - 
                960576938841520*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
          169*CF*(715722090916607553 + 884939337738363600*Pi^2 + 
            68582181062348800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            33878623984128000*Zeta[3]) - 2366*CA*(25073540164921827 - 
            780272927002800*lm + 31615771144696200*Pi^2 + 2449363609369600*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1209950856576000*Zeta[3])))/
        44730370729044000 + CA*CF*NC*(5825534331168888616751/
          1222806584427120000 - (66889335329*Pi^2)/42865200 + 
         (451845412*Pi^3)/(14348907*Sqrt[3]) + (1867*Pi^4)/4860 - 
         (11*lm*(3748219 + 29400*Pi^2))/7144200 - 
         (5176122769199*Im[PolyLog[2, (-1)^(1/3)]])/(11718274050*Sqrt[3]) + 
         (388*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (7229526592*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6200145*Sqrt[3]) + (451845412*Pi*Log[3]^2)/(18600435*Sqrt[3]) - 
         (708942044887*PolyGamma[2, 1])/86093442 - (19350352773524*Zeta[3])/
          1506635235) + (38702956199683*CF^2*NC*Zeta[3])/1506635235 - 
       (828536*CF*NM*NC*Zeta[3])/81 - (1952*CF*NC*NL*Zeta[3])/27 + 
       (44562249568*CF*NC*NH*Zeta[3])/43046721, 
      (326187458188583248376809*CF^2*NC)/44021037039376320000 + 
       (583670639631198401*CF*NM*NC)/14377502462400 - 
       (2820319*CF*lm*NM*NC)/1587600 - (5202867223*CF*NC*NL)/35721000 - 
       (2820319*CF*lm*NC*NL)/1587600 - (1247158185958866050456221*CF*NC*NH)/
        345407922769677768000 - (2820319*CF*lm*NC*NH)/1587600 - 
       (700259312801*CF^2*NC*Pi^2)/314344800 - (410004143*CF*NM*NC*Pi^2)/
        34020 - (CF*lm*NM*NC*Pi^2)/54 + (86059*CF*NC*NL*Pi^2)/17010 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (123498173299*CF^2*NC*Pi^3)/(1033121304*Sqrt[3]) + 
       (223146037135*CF*NC*NH*Pi^3)/(516560652*Sqrt[3]) + 
       (161*CF^2*NC*Pi^4)/90 - (73857966185033*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(52732233225*Sqrt[3]) - 
       (36527185937*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (215233605*Sqrt[3]) + (536*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (246996346598*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (55801305*Sqrt[3]) + (25502404244*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (123498173299*CF^2*NC*Pi*Log[3]^2)/(1339231320*Sqrt[3]) + 
       (6375601061*CF*NC*NH*Pi*Log[3]^2)/(19131876*Sqrt[3]) - 
       (CF*NC*(130*CA*(-14800675697 + 1131786810*lm) + 
          7*(599118368953*CF - 10*(13*(-26992040909 + 29397060*lm)*NM + 
              210210*(2377 + 1818*lm)*NL + (120986911 + 382161780*lm)*NH)))*
         Log[x]^2)/170270100 - (CF*NC*(-17100009*CA + 
          4*(3049673*CF + 38171560*NM + 74235*NL))*Log[x]^3)/2835 + 
       (1636962707776*CF^2*NC*PolyGamma[2, 1])/129140163 - 
       (2689633*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (6024448391*CF*NC*NH*PolyGamma[2, 1])/258280326 + 
       CA*CF*NC*(-19958265939350109636667/5502629629922040000 + 
         (95461477759*Pi^2)/85730400 - (123498173299*Pi^3)/
          (2066242608*Sqrt[3]) - (491*Pi^4)/540 + 
         (11*lm*(2820319 + 29400*Pi^2))/3175200 + 
         (73857966185033*Im[PolyLog[2, (-1)^(1/3)]])/(105464466450*Sqrt[3]) - 
         (268*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (123498173299*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55801305*Sqrt[3]) - (123498173299*Pi*Log[3]^2)/
          (2678462640*Sqrt[3]) - (818481353888*PolyGamma[2, 1])/129140163 - 
         (27881627368907*Zeta[3])/1807962282) + 
       (27794197884233*CF^2*NC*Zeta[3])/903981141 - 
       (1988893*CF*NM*NC*Zeta[3])/27 + (472*CF*NC*NL*Zeta[3])/3 - 
       (185194467131*CF*NC*NH*Zeta[3])/129140163 + 
       CF*Log[x]*((-14318358982489*NM*NC)/1296672300 + 
         (30271*lm*NM*NC)/1890 + (25735601*NC*NL)/113400 + 
         (30271*lm*NC*NL)/1890 + (1516453380658006573*NC*NH)/
          479253972096900 + (30271*lm*NC*NH)/1890 - (1090777*NM*NC*Pi^2)/
          81 + (707*NC*NL*Pi^2)/27 - (25502404244*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CA*NC*(-92659472642891521/49626890601750 - (332981*lm)/3780 + 
           (4450231*Pi^2)/3402 + (123498173299*Im[PolyLog[2, (-1)^(1/3)]])/
            (167403915*Sqrt[3]) - 112*Zeta[3]) + 
         CF*NC*(2749442464410112841/794030249628000 - (110489*Pi^2)/42 - 
           (246996346598*Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) + 
           224*Zeta[3])), 
      -(CF*NC*(-1704014123011200*(3*CA*(-92695972958359 + 405301696800*lm) + 
            4*(139810968848349*CF - 70*((-358560192187 + 789548760*lm)*NM + 
                49*(12870*(1721 + 1252*lm)*NL + (5050391 + 16113240*lm)*
                   NH))))*Log[x]^2 + 409372352912210688000*
           (400630505*CA - 2*(380067391*CF + 95870320*NM + 306740*NL))*
           Log[x]^3 + 8*(-35*(7*(NH*(62161739691480*lm*(34546727 + 
                    235200*Pi^2) - 7*(-713096864051882973404463 + 
                    26576909005218331760000*Sqrt[3]*Pi^3 + 
                    64332119841031000358400*Sqrt[3]*Im[PolyLog[2, (-1)^
                        (1/3)]] + 984104973450370227456000*Sqrt[3]*
                     Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                    20502186946882713072000*Sqrt[3]*Pi*Log[3]^2 - 
                    26845520505507800096000*PolyGamma[2, 1] - 
                    380399419517310601408000*Zeta[3])) + 4144115979432*NL*
                 (43797339659 - 1422451800*Pi^2 + 15*lm*(34546727 + 
                    235200*Pi^2) - 46421424000*Zeta[3])) + 6561*NM*(
                -29957244327208779988643 + 7804732962477221971200*Pi^2 + 
                66321014760*lm*(34546727 + 235200*Pi^2) - 
                70752369396436824096000*PolyGamma[2, 1] - 
                161443811680190335296000*Zeta[3])) + 
            CF*(32765318458622974639588831191 - 9956384897913115841192013000*
               Pi^2 + 13524983156317254321700000*Sqrt[3]*Pi^3 + 
              443989902505349504304000*Pi^4 - 183995236279438073453964000*
               Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              48357109187754887520000000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              500810804873918902883520000*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 10433558434873310476740000*Sqrt[
                3]*Pi*Log[3]^2 - 64960782043112489854960640000*PolyGamma[2, 
                1] - 109299279879957891757729696000*Zeta[3])) + 
          2162160*Log[x]*(2*(-140*(-2187*NM*(31139718149377867 + 
                  26028911268360*lm - 14873589818287200*Pi^2) - 
                7*(4829972004*NL*(26159751 + 1683690*lm + 3067400*Pi^2) + 
                  NH*(1887702473612695371 + 8132175563414760*lm - 
                    1062014345862870400*Sqrt[3]*Im[PolyLog[2, (-1)^
                        (1/3)]]))) - CF*(35605647545102881287351 + 
                18739105507269656308800*Pi^2 + 308833638505888496000*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 135264641084629056000*
                 Zeta[3])) + 7*CA*(5079011992340114380821 - 
              12523550367658730400*lm + 2677225234208931806400*Pi^2 + 
              44119091215126928000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              19323520154947008000*Zeta[3])) + 
          CA*(-130986419179106883892844025387 + 39828040115258251602669924000*
             Pi^2 - 54099932625269017286800000*Sqrt[3]*Pi^3 - 
            1798884461784481815744000*Pi^4 + 670103553874154400*lm*
             (34546727 + 235200*Pi^2) + 735980945117752293815856000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 193428436751019550080000000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 2003243219495675611534080000*
             Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
            41734233739493241906960000*Sqrt[3]*Pi*Log[3]^2 + 
            259843128172449959419842560000*PolyGamma[2, 1] + 
            437199870502043137086742144000*Zeta[3])))/
       3481711861518351901440000, (19464537138228495146754020671*CF^2*NC)/
        386856873502039100160000 + (371660972971835556283481*CF*NM*NC)/
        1263494916395712000 - (12916651*CF*lm*NM*NC)/6350400 - 
       (218039556151*CF*NC*NL)/1000188000 - (12916651*CF*lm*NC*NL)/
        6350400 - (3400203583988983307102272553*CF*NC*NH)/
        646472047454257856832000 - (12916651*CF*lm*NC*NH)/6350400 - 
       (50606751021923*CF^2*NC*Pi^2)/3772137600 - (147477079*CF*NM*NC*Pi^2)/
        1701 - (CF*lm*NM*NC*Pi^2)/54 + (444721*CF*NC*NL*Pi^2)/68040 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (78390759931*CF^2*NC*Pi^3)/(459165024*Sqrt[3]) + 
       (82326756575*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) + 
       (2519*CF^2*NC*Pi^4)/1080 - (3304330176311389*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1687431463200*Sqrt[3]) - 
       (50288308493*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (100442349*Sqrt[3]) + (2042*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (78390759931*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (12400290*Sqrt[3]) + (37635088720*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (78390759931*CF^2*NC*Pi*Log[3]^2)/(595213920*Sqrt[3]) + 
       (2352193045*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) - 
       (CF*NC*(3657931098042266*CF + 765*CA*(-2345843230853 + 
            38032874880*lm) - 280*(17*(-5059015957189 + 1111350240*lm)*NM + 
            4084080*(5995 + 4626*lm)*NL + (6416759551 + 18892954080*lm)*
             NH))*Log[x]^2)/23156733600 - 
       (CF*NC*(-535499025*CA + 28*(30687113*CF + 218648940*NM + 92520*NL))*
         Log[x]^3)/17010 + (130659260597032*CF^2*NC*PolyGamma[2, 1])/
        1162261467 - (24212737*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (67973462879*CF*NC*NH*PolyGamma[2, 1])/2324522934 + 
       CA*CF*NC*(-3877136152263122711928695501/154742749400815640064000 + 
         (50601721094503*Pi^2)/7544275200 - (78390759931*Pi^3)/
          (918330048*Sqrt[3]) - (2551*Pi^4)/2160 + 
         lm*(142083161/12700800 + (11*Pi^2)/108) + 
         (3304330176311389*Im[PolyLog[2, (-1)^(1/3)]])/(3374862926400*
           Sqrt[3]) - (1021*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (78390759931*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (24800580*Sqrt[3]) - (78390759931*Pi*Log[3]^2)/
          (1190427840*Sqrt[3]) - (65329630298516*PolyGamma[2, 1])/
          1162261467 - (41575737340032691*Zeta[3])/325433210760) + 
       (41553921261829891*CF^2*NC*Zeta[3])/162716605380 - 
       (19392823*CF*NM*NC*Zeta[3])/27 + (686*CF*NC*NL*Zeta[3])/3 - 
       (2373728026523*CF*NC*NH*Zeta[3])/1162261467 + 
       CF*Log[x]*((-7534344673366717*NM*NC)/50088598560 + 
         (26119*lm*NM*NC)/1260 + (133032269*NC*NL)/396900 + 
         (26119*lm*NC*NL)/1260 + (738218436214614121411*NC*NH)/
          158290740498290400 + (26119*lm*NC*NH)/1260 - (7288990*NM*NC*Pi^2)/
          81 + (1028*NC*NL*Pi^2)/27 - (37635088720*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CA*NC*(-393779531752692818891/119280988610784000 - 
           (287309*lm)/2520 + (1031360959*Pi^2)/136080 + 
           (78390759931*Im[PolyLog[2, (-1)^(1/3)]])/(74401740*Sqrt[3]) - 
           144*Zeta[3]) + CF*NC*(185805844186878933811/29820247152696000 - 
           (1032756059*Pi^2)/68040 - (78390759931*Im[PolyLog[2, (-1)^(1/3)]])/
            (37200870*Sqrt[3]) + 288*Zeta[3])), 
      -(CF*NC*(-1477380244650710400*(51*CA*(-2122266244502057 + 
              1735897363200*lm) + 16*(13543516585238126*CF - 
              105*((-16364013615623 + 9581251680*lm)*NM + 
                65*(94248*(2133 + 1564*lm)*NL + (49198063 + 147403872*lm)*
                   NH))))*Log[x]^2 + 12067478219146146660864000*
           (4392928501*CA - 15*(579295351*CF + 94624432*NM + 87584*NL))*
           Log[x]^3 + 16*(-35*(13*(-5*NH*(-17082467768056671215046772491 + 
                  646558045390946907137920000*Sqrt[3]*Pi^3 - 
                  32889298303533672*lm*(176010259 + 1058400*Pi^2) + 
                  1166443279320648432068725760*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]] + 23941120766476205475735552000*Sqrt[3]*
                   Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                  498773349301587614077824000*Sqrt[3]*Pi*Log[3]^2 - 
                  610558874072629414745612800*PolyGamma[2, 1] - 
                  8809983493144142890765184000*Zeta[3]) + 2349235593109548*
                 NL*(1346761247147 - 38040718800*Pi^2 + 70*lm*(176010259 + 
                    1058400*Pi^2) - 1391372640000*Zeta[3])) + 
              1240029*NM*(-20275999675755693543535819 + 
                4880903811538333916937600*Pi^2 + 1723995478920*lm*
                 (176010259 + 1058400*Pi^2) - 74545441478666638736256000*
                 PolyGamma[2, 1] - 161179709895213624590976000*Zeta[3])) + 
            9826*CF*(558221481567431404434887594007 - 
              169788291251487063156675949275*Pi^2 + 
              42977351632018520819602500*Sqrt[3]*Pi^3 + 
              1296574990096677921630000*Pi^4 - 572150376220684506563017700*
               Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              136221976581905518143840000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              1591389934717028656634424000*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 33153956973271430346550500*Sqrt[
                3]*Pi*Log[3]^2 - 1316985160174284612329678360000*PolyGamma[2, 
                1] - 2296399982992627585354949668000*Zeta[3])) + 
          73513440*Log[x]*(-280*(-19683*NM*(20009865651662319967 + 
                4793495320734120*lm - 10581461725338504000*Pi^2) - 
              13*(322121979036*NL*(398876729 + 22530970*lm + 45981600*
                   Pi^2) + NH*(1927327279336444202709 + 7257720646000744920*
                   lm - 1085566610517124736000*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]]))) - 867*CF*(1024943747885789800603611 + 
              414904879391918340625200*Pi^2 + 1308477477022589473600*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] - 515293870798586880000*Zeta[
                3]) + 12138*CA*(36598291142577494506383 - 
              11970634975526026800*lm + 14818266596303496225900*Pi^2 + 
              46731338465092481200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              18403352528520960000*Zeta[3])) - 4913*CA*
           (8930839650730028802873562081179 - 2716637301497690251753480808400*
             Pi^2 + 687637626112296333113640000*Sqrt[3]*Pi^3 + 
            20951523507414600932832000*Pi^4 - 1340207107748308800*lm*
             (176010259 + 1058400*Pi^2) - 9154406019530952105008283200*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            2179551625310488290301440000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            25462238955472458506150784000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                 Sqrt[3])]] + 530463311572342885544808000*Sqrt[3]*Pi*
             Log[3]^2 - 21071762562788553797274853760000*PolyGamma[2, 1] - 
            36742492766960118606082783168000*Zeta[3])))/
       153950853380756966025972480000, 
      (474001900682390619334067590223*CF^2*NC)/1492162226365007957760000 + 
       (108957147466675287265399*CF*NM*NC)/50539796655828480 - 
       (130989059*CF*lm*NM*NC)/57153600 - (11206357838813*CF*NC*NL)/
        36006768000 - (130989059*CF*lm*NC*NL)/57153600 - 
       (3701518171785598710332592470486923*CF*NC*NH)/
        502832811113624776177212019200 - (130989059*CF*lm*NC*NH)/57153600 - 
       (2018074489732853*CF^2*NC*Pi^2)/24518894400 - 
       (10961232419*CF*NM*NC*Pi^2)/17010 - (CF*lm*NM*NC*Pi^2)/54 + 
       (185947*CF*NC*NL*Pi^2)/22680 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (121037561357*CF^2*NC*Pi^3)/
        (516560652*Sqrt[3]) + (698953043285*CF*NC*NH*Pi^3)/
        (774840978*Sqrt[3]) + (398*CF^2*NC*Pi^4)/135 - 
       (3774217718792746*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1423770297075*Sqrt[3]) - (5850418182649*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5811307335*Sqrt[3]) + 
       (2528*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (484150245428*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (55801305*Sqrt[3]) + (159760695608*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) + 
       (121037561357*CF^2*NC*Pi*Log[3]^2)/(669615660*Sqrt[3]) + 
       (19970086951*CF*NC*NH*Pi*Log[3]^2)/(28697814*Sqrt[3]) + 
       ((-200951680368821*CF^2*NC)/204324120 + 
         CA*CF*(333500683420493/681080400 - (5258*lm)/3)*NC + 
         CF*NC*((-37615818255791/4864860 + (956*lm)/3)*NM + 
           (4*(2768 + 2151*lm)*NL)/27 + (59937338609*NH)/523783260 + 
           (956*lm*NH)/3))*Log[x]^2 - 
       (CF*NC*(-9390793855*CA + 4*(4453105283*CF + 3780*(8724808*NM + 
              717*NL)))*Log[x]^3)/51030 + (10558129202565295*CF^2*NC*
         PolyGamma[2, 1])/10460353203 - (217922689*CF*NM*NC*PolyGamma[2, 1])/
        54 - (749489149751*CF*NC*NH*PolyGamma[2, 1])/20920706406 + 
       CA*CF*NC*(-3315274027329299283880172610119/
          20890271169110111408640000 + (155232536688811*Pi^2)/3772137600 - 
         (121037561357*Pi^3)/(1033121304*Sqrt[3]) - (67*Pi^4)/45 + 
         lm*(1440879649/114307200 + (11*Pi^2)/108) + 
         (1887108859396373*Im[PolyLog[2, (-1)^(1/3)]])/(1423770297075*
           Sqrt[3]) - (1264*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (242075122714*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55801305*Sqrt[3]) - (121037561357*Pi*Log[3]^2)/
          (1339231320*Sqrt[3]) - (10558129202565295*PolyGamma[2, 1])/
          20920706406 - (1612045166280646079*Zeta[3])/1464449448420) + 
       (1611912877680472139*CF^2*NC*Zeta[3])/732224724210 - 
       (183078503*CF*NM*NC*Zeta[3])/27 + (2870*CF*NC*NL*Zeta[3])/9 - 
       (29309094477527*CF*NC*NH*Zeta[3])/10460353203 + 
       CF*Log[x]*((-2528254436181176371*NM*NC)/1753100949600 + 
         (295271*lm*NM*NC)/11340 + (6762602587*NC*NL)/14288400 + 
         (295271*lm*NC*NL)/11340 + (7910585092780607258829719*NC*NH)/
          1200002103717539522400 + (295271*lm*NC*NH)/11340 - 
         (5816704*NM*NC*Pi^2)/9 + (478*NC*NL*Pi^2)/9 - 
         (159760695608*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CA*NC*(-35148791066649365939/
            15336127107100800 - (3247981*lm)/22680 + (9307710227*Pi^2)/
            204120 + (242075122714*Im[PolyLog[2, (-1)^(1/3)]])/
            (167403915*Sqrt[3]) - 180*Zeta[3]) + 
         CF*NC*(2196375342929060423309/536764448748528000 - 
           (9310578197*Pi^2)/102060 - (484150245428*Im[PolyLog[2, (-1)^
                (1/3)]])/(167403915*Sqrt[3]) + 360*Zeta[3])), 
      (-337255346000040808604143119133733887*CF^2*NC)/
        76975426690378483012986240000 - (722579899257995172484905912403*CF*
         NM*NC)/1451508717472001612424000 + (196578107*CF*lm*NM*NC)/
        128595600 + (7557354154157*CF*NC*NL)/36006768000 + 
       (196578107*CF*lm*NC*NL)/128595600 + 
       (658970398969670259434539952779297*CF*NC*NH)/
        117851440104755806916534067000 + (196578107*CF*lm*NC*NH)/128595600 + 
       (99292523714656171*CF^2*NC*Pi^2)/73556683200 + 
       (17211061439*CF*NM*NC*Pi^2)/153090 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (160459*CF*NC*NL*Pi^2)/30618 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (9998601989267*CF^2*NC*Pi^3)/
        (55788550416*Sqrt[3]) - (2242922187520*CF*NC*NH*Pi^3)/
        (3486784401*Sqrt[3]) - (8101*CF^2*NC*Pi^4)/4860 + 
       (160523025417564923*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (68340974259600*Sqrt[3]) - (101569197370174*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(122037454035*Sqrt[3]) - 
       (1532*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (9998601989267*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1506635235*Sqrt[3]) - (1025335857152*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(43046721*Sqrt[3]) - 
       (9998601989267*CF^2*NC*Pi*Log[3]^2)/(72318491280*Sqrt[3]) - 
       (64083491072*CF*NC*NH*Pi*Log[3]^2)/(129140163*Sqrt[3]) + 
       (CF*NC*(19*CA*(-843748512217979297 + 121673197245600*lm) + 
          40*(801708967258963289*CF - 84*(33*(-24081260241707 + 3790815210*
                 lm)*NM + 5*(17459442*(1942 + 1433*lm)*NL + 
                (8779762469 + 25019380386*lm)*NH))))*Log[x]^2)/
        1979900722800 + (2*CF*NC*(-33606761233*CA + 67069520131*CF + 
          1260*(5688041*NM + 1433*NL))*Log[x]^3)/25515 + 
       (379914452492534080*CF^2*NC*PolyGamma[2, 1])/31381059609 - 
       (735473893*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (6000777141179*CF*NC*NH*PolyGamma[2, 1])/31381059609 + 
       CA*CF*NC*(84312964537019400711315385927671319/
          38487713345189241506493120000 - (7637896170638317*Pi^2)/
          11316412800 + (9998601989267*Pi^3)/(111577100832*Sqrt[3]) + 
         (1633*Pi^4)/1944 + lm*(-2162359177/257191200 - (11*Pi^2)/243) - 
         (160523025417564923*Im[PolyLog[2, (-1)^(1/3)]])/
          (136681948519200*Sqrt[3]) + (766*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (9998601989267*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3013270470*Sqrt[3]) + (9998601989267*Pi*Log[3]^2)/
          (144636982560*Sqrt[3]) - (189957226246267040*PolyGamma[2, 1])/
          31381059609 - (47400250799086773587*Zeta[3])/4393348345260) + 
       (47400225008504820857*CF^2*NC*Zeta[3])/2196674172630 - 
       (1538829422*CF*NM*NC*Zeta[3])/243 - (17204*CF*NC*NL*Zeta[3])/81 + 
       (87900327441370*CF*NC*NH*Zeta[3])/31381059609 + 
       CF*Log[x]*((-636872063863878095677*NM*NC)/2078400783759300 - 
         (79882*lm*NM*NC)/5103 - (4444725727*NC*NL)/14288400 - 
         (79882*lm*NC*NL)/5103 - (6337237921657781374205899*NC*NH)/
          1350002366682231962700 - (79882*lm*NC*NH)/5103 + 
         (1264456*NM*NC*Pi^2)/9 - (2866*NC*NL*Pi^2)/81 + 
         (1025335857152*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (129140163*Sqrt[3]) + CF*NC*(388787273926008182582689681/
            104709324839619099600 + (134371070423*Pi^2)/102060 + 
           (9998601989267*Im[PolyLog[2, (-1)^(1/3)]])/(4519905705*Sqrt[3]) - 
           264*Zeta[3]) + CA*NC*(-1110792830364137864751982211/
            598338999083537712000 + (439351*lm)/5103 - (134371465013*Pi^2)/
            204120 - (9998601989267*Im[PolyLog[2, (-1)^(1/3)]])/
            (9039811410*Sqrt[3]) + 132*Zeta[3])), 
      (1180736709631998967794461591266146871*CF^2*NC)/
        593810434468634011814465280000 + (1106771287793894172242925191*CF*NM*
         NC)/68214840925847616000 - (29148631*CF*lm*NM*NC)/11430720 - 
       (30822837543397*CF*NC*NL)/72013536000 - (29148631*CF*lm*NC*NL)/
        11430720 - (2031407707376475330377765953871874641*CF*NC*NH)/
        203647288501018034351770867776000 - (29148631*CF*lm*NC*NH)/
        11430720 - (91389923976247*CF^2*NC*Pi^2)/179625600 - 
       (167712144043*CF*NM*NC*Pi^2)/34020 - (CF*lm*NM*NC*Pi^2)/54 + 
       (227863*CF*NC*NL*Pi^2)/22680 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (938545665489299*CF^2*NC*Pi^3)/
        (3012581722464*Sqrt[3]) + (464670546715655*CF*NC*NH*Pi^3)/
        (376572715308*Sqrt[3]) + (1309*CF^2*NC*Pi^4)/360 - 
       (1841907185701550873*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (527201801431200*Sqrt[3]) - (5694512247016018*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3295011258945*Sqrt[3]) + 
       (1022*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (134077952212757*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (11622614670*Sqrt[3]) + (53105205338932*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) + 
       (134077952212757*CF^2*NC*Pi*Log[3]^2)/(557885504160*Sqrt[3]) + 
       (13276301334733*CF*NC*NH*Pi*Log[3]^2)/(13947137604*Sqrt[3]) + 
       ((-1121033901515123*CF^2*NC)/183783600 + 
         CA*CF*(211679237836399007/69470200800 - 2365*lm)*NC + 
         CF*NC*((-376340843516719/6361740 + 430*lm)*NM + (14855/27 + 430*lm)*
            NL + (84625734073*NH)/523783260 + 430*lm*NH))*Log[x]^2 - 
       (CF*NC*(-19077105185*CA + 37680936356*CF + 330170213520*NM + 
          4876200*NL)*Log[x]^3)/17010 + (854891456413424395*CF^2*NC*
         PolyGamma[2, 1])/94143178827 - (1961314561*CF*NM*NC*
         PolyGamma[2, 1])/54 - (8110478440751*CF*NC*NH*PolyGamma[2, 1])/
        188286357654 + CA*CF*NC*(-1652755178735567383769075496466612007/
          1662669216512175233080502784000 + (3564186270188693*Pi^2)/
          14010796800 - (938545665489299*Pi^3)/(6025163444928*Sqrt[3]) - 
         (3959*Pi^4)/2160 + lm*(320634941/22861440 + (11*Pi^2)/108) + 
         (1841907185701550873*Im[PolyLog[2, (-1)^(1/3)]])/
          (1054403602862400*Sqrt[3]) - (511*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (134077952212757*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (23245229340*Sqrt[3]) - (134077952212757*Pi*Log[3]^2)/
          (1115771008320*Sqrt[3]) - (854891456413424395*PolyGamma[2, 1])/
          188286357654 - (36304376949464915437*Zeta[3])/3765727153080) + 
       (36303929618271496477*CF^2*NC*Zeta[3])/1882863576540 - 
       (1699349753*CF*NM*NC*Zeta[3])/27 + (3872*CF*NC*NL*Zeta[3])/9 - 
       (351117082581791*CF*NC*NH*Zeta[3])/94143178827 + 
       CF*Log[x]*((-15419953234674569699*NM*NC)/1217899457775 + 
         (362219*lm*NM*NC)/11340 + (18430374479*NC*NL)/28576800 + 
         (362219*lm*NC*NL)/11340 + (1313580670873048244913998159*NC*NH)/
          145800255601681051971600 + (362219*lm*NC*NH)/11340 - 
         (43673597*NM*NC*Pi^2)/9 + (215*NC*NL*Pi^2)/3 - 
         (53105205338932*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CA*NC*(3574887885532893834108041909/
            226172141653577255136000 - (3984409*lm)/22680 + 
           (1813303651*Pi^2)/6480 + (134077952212757*Im[PolyLog[2, (-1)^
                (1/3)]])/(69735688020*Sqrt[3]) - 220*Zeta[3]) + 
         CF*NC*(-260470293578938227021062923/8077576487627759112000 - 
           (5440274653*Pi^2)/9720 - (134077952212757*Im[PolyLog[2, (-1)^
                (1/3)]])/(34867844010*Sqrt[3]) + 440*Zeta[3])), 
      (-244914610878804807371021431801079082725747*CF^2*NC)/
        7127655097535631202311980372160000 - 
       (81637656649346320719207471430213*CF*NM*NC)/
        31933191784384035473328000 + (5255245711*CF*lm*NM*NC)/3112013520 + 
       (619849824302833*CF*NC*NL)/2178409464000 + (5255245711*CF*lm*NC*NL)/
        3112013520 + (9801891992644491026835741024223081*CF*NC*NH)/
        1305431336544987399690838896000 + (5255245711*CF*lm*NC*NH)/
        3112013520 + (135561834169063444*CF^2*NC*Pi^2)/12642554925 + 
       (435414964562*CF*NM*NC*Pi^2)/841995 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (10714489*CF*NC*NL*Pi^2)/1683990 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (245252440080460*CF^2*NC*Pi^3)/
        (1035574967097*Sqrt[3]) - (27415663019605*CF*NC*NH*Pi^3)/
        (31381059609*Sqrt[3]) - (2489*CF^2*NC*Pi^4)/1215 + 
       (8562694906440676831*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2790874536326415*Sqrt[3]) - (826857678530428*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1098337086315*Sqrt[3]) - 
       (1840*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (784807808257472*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (89494132959*Sqrt[3]) - (12532874523248*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (49050488016092*CF^2*NC*Pi*Log[3]^2)/(268482398877*Sqrt[3]) - 
       (783304657703*CF*NC*NH*Pi*Log[3]^2)/(1162261467*Sqrt[3]) + 
       (CF*NC*(280228876799850650051*CF + 216*CA*(-648657775075365589 + 
            15691867491300*lm) - 1848*((-7312528266111951 + 333475342200*lm)*
             NM + 65*(13430340*(515 + 382*lm)*NL + (1875657367 + 
                5130389880*lm)*NH)))*Log[x]^2)/2177890795080 + 
       (2*CF*NC*(-2905234552533*CA + 11*(528017236703*CF + 
            12600*(2752736*NM + 191*NL)))*Log[x]^3)/280665 + 
       (30773939978725510003*CF^2*NC*PolyGamma[2, 1])/282429536481 - 
       (6619414612*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (69809319099968*CF*NC*NH*PolyGamma[2, 1])/282429536481 + 
       CA*CF*NC*(1077622910461527426067593666146485741524577/
          62723364858313554580345427275008000 - (4337979453238971233*Pi^2)/
          809123515200 + (122626220040230*Pi^3)/(1035574967097*Sqrt[3]) + 
         (167*Pi^4)/162 + lm*(-5255245711/565820640 - (11*Pi^2)/243) - 
         (8562694906440676831*Im[PolyLog[2, (-1)^(1/3)]])/
          (5581749072652830*Sqrt[3]) + (920*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (392403904128736*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (89494132959*Sqrt[3]) + (24525244008046*Pi*Log[3]^2)/
          (268482398877*Sqrt[3]) - (30773939978725510003*PolyGamma[2, 1])/
          564859072962 - (4288953166001396605267*Zeta[3])/43494148618074) + 
       (4288952749585195947040*CF^2*NC*Zeta[3])/21747074309037 - 
       (13568649848*CF*NM*NC*Zeta[3])/243 - (22928*CF*NC*NL*Zeta[3])/81 + 
       (1035638546431312*CF*NC*NH*Zeta[3])/282429536481 + 
       CF*Log[x]*((-25934649459818327516779*NM*NC)/11431204310676150 - 
         (5336809*lm*NM*NC)/280665 - (32937870631*NC*NL)/78586200 - 
         (5336809*lm*NC*NL)/280665 - (212634312660322399203106*NC*NH)/
          33379179395989251825 - (5336809*lm*NC*NH)/280665 + 
         (18353500*NM*NC*Pi^2)/27 - (3820*NC*NL*Pi^2)/81 + 
         (12532874523248*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(711727091713664996261903252660533/
            22453239362658882003626400 + (581005834891*Pi^2)/56133 + 
           (784807808257472*Im[PolyLog[2, (-1)^(1/3)]])/(268482398877*
             Sqrt[3]) - 320*Zeta[3]) + 
         CA*NC*(-1016749545478717031620512564755653/
            64152112464739662867504000 + (5336809*lm)/51030 - 
           (1162012261835*Pi^2)/224532 - (392403904128736*
             Im[PolyLog[2, (-1)^(1/3)]])/(268482398877*Sqrt[3]) + 
           160*Zeta[3])), (11687979888062414508925750133439186639927587*CF^2*
         NC)/940850472874703318705181409125120000 + 
       (5327142774161298097859288149500173*CF*NM*NC)/
        42577589045845380631104000 - (3884300191*CF*lm*NM*NC)/1383117120 - 
       (710814497039137*CF*NC*NL)/1244805408000 - (3884300191*CF*lm*NC*NL)/
        1383117120 - (97831720901470671098094390947738275622491*CF*NC*NH)/
        7433329677575659271873988444691776000 - (3884300191*CF*lm*NC*NH)/
        1383117120 - (843405448553435777*CF^2*NC*Pi^2)/269707838400 - 
       (962255942849*CF*NM*NC*Pi^2)/24948 - (CF*lm*NM*NC*Pi^2)/54 + 
       (3013853*CF*NC*NL*Pi^2)/249480 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (5015849609581619*CF^2*NC*Pi^3)/
        (12426899605164*Sqrt[3]) + (1854561533860595*CF*NC*NH*Pi^3)/
        (1129718145924*Sqrt[3]) + (1187*CF^2*NC*Pi^4)/270 - 
       (1507731147445777534937*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (334904944359169800*Sqrt[3]) - (26766217386718744*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9885033776835*Sqrt[3]) + 
       (3656*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (20063398438326476*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1342411994385*Sqrt[3]) + (211949889584068*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3486784401*Sqrt[3]) + 
       (5015849609581619*CF^2*NC*Pi*Log[3]^2)/(16108943932620*Sqrt[3]) + 
       (52987472396017*CF*NC*NH*Pi*Log[3]^2)/(41841412812*Sqrt[3]) - 
       (CF*NC*(6264436392944238071014*CF + 69*CA*(-45385458193993946533 + 
            7515336495466800*lm) - 4620*(23*(-727290685741797787 + 
              887288842440*lm)*NM + 3*(4908043140*(1765 + 1386*lm)*NL + 
              (2653884273377 + 6802547792040*lm)*NH)))*Log[x]^2)/
        166971627622800 - (CF*NC*(-3871463193317*CA + 7720797756172*CF + 
          83160*(1012826396*NM + 2541*NL))*Log[x]^3)/561330 + 
       (69242358895547518642*CF^2*NC*PolyGamma[2, 1])/847288609443 - 
       (17651844001*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (86409708949607*CF*NC*NH*PolyGamma[2, 1])/1694577218886 + 
       CA*CF*NC*(-1062508119241409128915712829204225076901623/
          171063722340855148855487528931840000 + (64877260828917899*Pi^2)/
          41493513600 - (5015849609581619*Pi^3)/(24853799210328*Sqrt[3]) - 
         (239*Pi^4)/108 + lm*(3884300191/251475840 + (11*Pi^2)/108) + 
         (1507731147445777534937*Im[PolyLog[2, (-1)^(1/3)]])/
          (669809888718339600*Sqrt[3]) - (1828*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          9 - (10031699219163238*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1342411994385*Sqrt[3]) - (5015849609581619*Pi*Log[3]^2)/
          (32217887865240*Sqrt[3]) - (34621179447773759321*PolyGamma[2, 1])/
          847288609443 - (10102866070922357825783*Zeta[3])/118620405322020) + 
       (10102847927858141350403*CF^2*NC*Zeta[3])/59310202661010 - 
       (15626290577*CF*NM*NC*Zeta[3])/27 + (5084*CF*NC*NL*Zeta[3])/9 - 
       (4102725083360675*CF*NC*NH*Zeta[3])/847288609443 + 
       CF*Log[x]*((-493941820049004344802067*NM*NC)/4572481724270460 + 
         (4795009*lm*NM*NC)/124740 + (38340050257*NC*NL)/44906400 + 
         (4795009*lm*NC*NL)/124740 + (2771247694268792864893990808051*NC*
           NH)/231385005639867829478929200 + (4795009*lm*NC*NH)/124740 - 
         (1012827749*NM*NC*Pi^2)/27 + (847*NC*NL*Pi^2)/9 - 
         (211949889584068*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (10460353203*Sqrt[3]) + CA*NC*(-72460308340473735625307523389479/
            1347194361759532920217584000 - (4795009*lm)/22680 + 
           (351803663159*Pi^2)/204120 + (10031699219163238*
             Im[PolyLog[2, (-1)^(1/3)]])/(4027235983155*Sqrt[3]) - 
           264*Zeta[3]) + CF*NC*(20549038146974292856202336648687/
            192456337394218988602512000 - (351808626929*Pi^2)/102060 - 
           (20063398438326476*Im[PolyLog[2, (-1)^(1/3)]])/(4027235983155*
             Sqrt[3]) + 528*Zeta[3])), 
      (-44640157597104055834314497506399884794922721*CF^2*NC)/
        162839504920621728237435243887040000 - 
       (81782373913258822133682238213621439*CF*NM*NC)/
        7064202626192737447345123200 + (5753536021*CF*lm*NM*NC)/3112013520 + 
       (14709005500788223*CF*NC*NL)/39211370352000 + 
       (5753536021*CF*lm*NC*NL)/3112013520 + 
       (12648464163607231410443056392862356325469*CF*NC*NH)/
        1286537828811171797055113384658192000 + (5753536021*CF*lm*NC*NH)/
        3112013520 + (1166203874327617423*CF^2*NC*Pi^2)/13485391920 + 
       (53361819289*CF*NM*NC*Pi^2)/31185 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (6392072*CF*NC*NL*Pi^2)/841995 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (8539190564761534*CF^2*NC*Pi^3)/
        (27960524111619*Sqrt[3]) - (5873543017292615*CF*NC*NH*Pi^3)/
        (5083731656658*Sqrt[3]) - (200*CF^2*NC*Pi^4)/81 + 
       (5911352245974314037749*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1507072249616264100*Sqrt[3]) - (10054022047537388*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(17793060798303*Sqrt[3]) - 
       (2176*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (136627049036184544*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (12081707949465*Sqrt[3]) - (1342524118238312*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (8539190564761534*CF^2*NC*Pi*Log[3]^2)/(36245123848395*Sqrt[3]) - 
       (167815514779789*CF*NC*NH*Pi*Log[3]^2)/(188286357654*Sqrt[3]) + 
       (CF*NC*(299*CA*(-434631896687397670117 + 1694266669141200*lm) + 
          6*(43318530490603860820861*CF - 1540*(6*(-92760137215200043 + 
                1661372602890*lm)*NM + 13*(283156335*(3635 + 2708*lm)*NL + 
                2*(145040896813 + 383393677590*lm)*NH))))*Log[x]^2)/
        250457441434200 + (2*CF*NC*(-23255127666629*CA + 
          20*(2325353712130*CF + 231*(337860236*NM + 7447*NL)))*Log[x]^3)/
        280665 + (2492699586365205179728*CF^2*NC*PolyGamma[2, 1])/
        2541865828329 - (19858314293*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (795635793934133*CF*NC*NH*PolyGamma[2, 1])/2541865828329 + 
       CA*CF*NC*(44640150991770430225184302757170803105493513/
          325679009841243456474870487774080000 - (1166203901948324537*Pi^2)/
          26970783840 + (4269595282380767*Pi^3)/(27960524111619*Sqrt[3]) + 
         (1508*Pi^4)/1215 + lm*(-5753536021/565820640 - (11*Pi^2)/243) - 
         (5911352245974314037749*Im[PolyLog[2, (-1)^(1/3)]])/
          (3014144499232528200*Sqrt[3]) + (1088*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          9 + (68313524518092272*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (12081707949465*Sqrt[3]) + (4269595282380767*Pi*Log[3]^2)/
          (36245123848395*Sqrt[3]) - (1246349793182602589864*PolyGamma[2, 1])/
          2541865828329 - (878603302193719736370334*Zeta[3])/
          978618343906665) + (1757206576672001436667958*CF^2*NC*Zeta[3])/
        978618343906665 - (40166886034*CF*NM*NC*Zeta[3])/81 - 
       (9932*CF*NC*NL*Zeta[3])/27 + (11932251240115630*CF*NC*NH*Zeta[3])/
        2541865828329 + CF*Log[x]*((-2799652590480118881554529811*NM*NC)/
          145130569928344400400 - (6370429*lm*NM*NC)/280665 - 
         (777457277813*NC*NL)/1414551600 - (6370429*lm*NC*NL)/280665 - 
         (1348594657256192242518375480451*NC*NH)/
          160189619289139266562335600 - (6370429*lm*NC*NH)/280665 + 
         (675744386*NM*NC*Pi^2)/243 - (14894*NC*NL*Pi^2)/243 + 
         (1342524118238312*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CF*NC*(5695898810470759437845572906943617/
            21197114083629014478948000 + (23254860558596*Pi^2)/280665 + 
           (136627049036184544*Im[PolyLog[2, (-1)^(1/3)]])/
            (36245123848395*Sqrt[3]) - (1144*Zeta[3])/3) + 
         CA*NC*(-8950694109437507157799055845490267/
            66619501405691188362408000 + (6370429*lm)/51030 - 
           (23254862516321*Pi^2)/561330 - (68313524518092272*
             Im[PolyLog[2, (-1)^(1/3)]])/(36245123848395*Sqrt[3]) + 
           (572*Zeta[3])/3)), (13694031097291190045954144906942587695329369*
         CF^2*NC)/178266405386785891965192266992128000 + 
       (26632033942398714569857603020251*CF*NM*NC)/27067761631179517248000 - 
       (4241818891*CF*lm*NM*NC)/1383117120 - (2543208704573857*CF*NC*NL)/
        3423214872000 - (4241818891*CF*lm*NC*NL)/1383117120 - 
       (142000165812943391556980223062415497025149621*CF*NC*NH)/
        8362495887272616680858237000278248000000 - (4241818891*CF*lm*NC*NH)/
        1383117120 - (10131504093764964271*CF^2*NC*Pi^2)/539415676800 - 
       (86169567931501*CF*NM*NC*Pi^2)/280665 - (CF*lm*NM*NC*Pi^2)/54 + 
       (44043*CF*NC*NL*Pi^2)/3080 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (457911527872978669*CF^2*NC*Pi^3)/
        (894736771571808*Sqrt[3]) + (10847056386106885*CF*NC*NH*Pi^3)/
        (5083731656658*Sqrt[3]) + (5647*CF^2*NC*Pi^4)/1080 - 
       (9801385426079527582103*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1722368285275730400*Sqrt[3]) - (354972373143599023*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(88965303991515*Sqrt[3]) + 
       (4298*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (65415932553282667*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3451916556990*Sqrt[3]) + (2479327173967288*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) + 
       (65415932553282667*CF^2*NC*Pi*Log[3]^2)/(165691994735520*Sqrt[3]) + 
       (309915896745911*CF*NC*NH*Pi*Log[3]^2)/(188286357654*Sqrt[3]) - 
       (CF*NC*(75263821999545595283314*CF + 3933*CA*(-9567838721674919899 + 
            338518854273600*lm) - 1848*(7475*(-89064835298323565 + 
              17523907632*lm)*NM + 4461857400*(37237 + 29358*lm)*NL + 
            (52751205391733 + 130991209549200*lm)*NH))*Log[x]^2)/
        333943255245600 - (CF*NC*(-23533279423955*CA + 
          8*(5879508968801*CF + 6930*(11989297382*NM + 4893*NL)))*Log[x]^3)/
        561330 + (5608585573977085183066*CF^2*NC*PolyGamma[2, 1])/
        7625597484987 - (158866611841*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (908593470705407*CF*NC*NH*PolyGamma[2, 1])/15251194969974 + 
       CA*CF*NC*(-34234849482603469808043063697633795518997541/
          891332026933929459825961334960640000 + (10131501410911396261*Pi^2)/
          1078831353600 - (457911527872978669*Pi^3)/(1789473543143616*
           Sqrt[3]) - (631*Pi^4)/240 + lm*(4241818891/251475840 + 
           (11*Pi^2)/108) + (9801385426079527582103*
           Im[PolyLog[2, (-1)^(1/3)]])/(3444736570551460800*Sqrt[3]) - 
         (2149*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (65415932553282667*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6903833113980*Sqrt[3]) - (65415932553282667*Pi*Log[3]^2)/
          (331383989471040*Sqrt[3]) - (2804292786988542591533*
           PolyGamma[2, 1])/7625597484987 - (17766744772177136243326607*
           Zeta[3])/23486840253759960) + (17766740230808098534826687*CF^2*NC*
         Zeta[3])/11743420126879980 - (142881010439*CF*NM*NC*Zeta[3])/27 + 
       (6526*CF*NC*NL*Zeta[3])/9 - (46946490780684947*CF*NC*NH*Zeta[3])/
        7625597484987 + CF*Log[x]*((-12845309573117550299124503*NM*NC)/
          14069174536216800 + (5679739*lm*NM*NC)/124740 + 
         (30281808589*NC*NL)/27442800 + (5679739*lm*NC*NL)/124740 + 
         (231398245915641235600995621546451*NC*NH)/
          14874750362562931895074020000 + (5679739*lm*NC*NH)/124740 - 
         (23978600690*NM*NC*Pi^2)/81 + (3262*NC*NL*Pi^2)/27 - 
         (2479327173967288*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CA*NC*(-58118783497103327498999976552613/
            16575186952612161697824000 - (5679739*lm)/22680 + 
           (47062389404249*Pi^2)/4490640 + (65415932553282667*
             Im[PolyLog[2, (-1)^(1/3)]])/(20711499341940*Sqrt[3]) - 
           312*Zeta[3]) + CF*NC*(4474514073105074993212906395607817/
            638144697675568225366224000 - (47062528470869*Pi^2)/2245320 - 
           (65415932553282667*Im[PolyLog[2, (-1)^(1/3)]])/(10355749670970*
             Sqrt[3]) + 624*Zeta[3])), 
      (-104188562354691370352805722045659647242318736214283*CF^2*NC)/
        46994292677388852196710710104019796480000 - 
       (129609466554086337851253692008698330187*CF*NM*NC)/
        3735876388851928457730594000000 + (1056589131859*CF*lm*NM*NC)/
        525930284880 + (8804962347281750941*CF*NC*NL)/18223484371092000 + 
       (1056589131859*CF*lm*NC*NL)/525930284880 + 
       (1549769526415609081087780418519102514860647*CF*NC*NH)/
        122977880695185539424385838239386000000 + 
       (1056589131859*CF*lm*NC*NH)/525930284880 + 
       (927924654578901396163*CF^2*NC*Pi^2)/1314825712200 - 
       (28623090768647*CF*NM*NC*Pi^2)/10945935 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (195444247*CF*NC*NL*Pi^2)/21891870 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (748035965192813965*CF^2*NC*Pi^3)/
        (1938596338405584*Sqrt[3]) - (3797979736279400*CF*NC*NH*Pi^3)/
        (2541865828329*Sqrt[3]) - (14233*CF^2*NC*Pi^4)/4860 + 
       (66880536300427297661065*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (13583744543207927088*Sqrt[3]) - (3095244011160872*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) - 
       (2540*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (149607193038562793*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10470813556203*Sqrt[3]) - (1736219308013440*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (149607193038562793*CF^2*NC*Pi*Log[3]^2)/(502599050697744*Sqrt[3]) - 
       (108513706750840*CF*NC*NH*Pi*Log[3]^2)/(94143178827*Sqrt[3]) + 
       (CF*NC*(55148395905916316871023270*CF + 1045*CA*
           (-26386771504999098885929 + 16038129328341120*lm) - 
          144144*(3*(472548728444015519 + 7046760120400*lm)*NM + 
            17*(3018315300*(551 + 412*lm)*NL + (484269713971 + 1243545903600*
                 lm)*NH)))*Log[x]^2)/6511893477289200 + 
       (2*CF*NC*(-2453123132584343*CA + 104*(47174904131263*CF + 
            2310*(153921703*NM + 2369*NL)))*Log[x]^3)/3648645 + 
       (201908788912545985723813*CF^2*NC*PolyGamma[2, 1])/22876792454961 - 
       (536174773808*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (8911332207541292*CF*NC*NH*PolyGamma[2, 1])/22876792454961 + 
       CA*CF*NC*(26047140176956274257670316582854007472050576155423/
          23497146338694426098355355052009898240000 - 
         (7423397260090155623249*Pi^2)/21037211395200 + 
         (748035965192813965*Pi^3)/(3877192676811168*Sqrt[3]) + 
         (14297*Pi^4)/9720 + lm*(-1056589131859/95623688160 - 
           (11*Pi^2)/243) - (66880536300427297661065*
           Im[PolyLog[2, (-1)^(1/3)]])/(27167489086415854176*Sqrt[3]) + 
         (1270*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (149607193038562793*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (20941627112406*Sqrt[3]) + (149607193038562793*Pi*Log[3]^2)/
          (1005198101395488*Sqrt[3]) - (201908788912545985723813*
           PolyGamma[2, 1])/45753584909922 - (67896132586281786968855551*
           Zeta[3])/8327152453605804) + (67896132422154640151797945*CF^2*NC*
         Zeta[3])/4163576226802902 - (1074811434616*CF*NM*NC*Zeta[3])/243 - 
       (37912*CF*NC*NL*Zeta[3])/81 + (134905146767784712*CF*NC*NH*Zeta[3])/
        22876792454961 + CF*Log[x]*((-315373252407283933122626983369*NM*NC)/
          1814132124104305005000 - (97426327*lm*NM*NC)/3648645 - 
         (35633475663431*NC*NL)/50570219700 - (97426327*lm*NC*NL)/3648645 - 
         (16661476393412018606990331343049*NC*NH)/
          1531224302028537106845855000 - (97426327*lm*NC*NH)/3648645 + 
         (1231405552*NM*NC*Pi^2)/243 - (18952*NC*NL*Pi^2)/243 + 
         (1736219308013440*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CF*NC*
          (133129724472327594348288536835742889981/
            58513614478865102477913632640 + (178408633597195*Pi^2)/265356 + 
           (149607193038562793*Im[PolyLog[2, (-1)^(1/3)]])/
            (31412440668609*Sqrt[3]) - 448*Zeta[3]) + 
         CA*NC*(-10805983495950782716009571789186229553/
            9498963389426152999661304000 + (97426327*lm)/663390 - 
           (178408635984853*Pi^2)/530712 - (149607193038562793*
             Im[PolyLog[2, (-1)^(1/3)]])/(62824881337218*Sqrt[3]) + 
           224*Zeta[3])), 
      (11154499739091092954405144838917933077052828289957091*CF^2*NC)/
        24108072143500481176912594283362155594240000 + 
       (214253429215249098519345851842884872101*CF*NM*NC)/
        27265343469515828744139072000 - (777314733379*CF*lm*NM*NC)/
        233746793280 - (7665211206593329421*CF*NC*NL)/8099326387152000 - 
       (777314733379*CF*lm*NC*NL)/233746793280 - 
       (323552212731065163816346985251554709251611459*CF*NC*NH)/
        15052492597090710025544826600500846400000 - 
       (777314733379*CF*lm*NC*NH)/233746793280 - 
       (19022158773691026901*CF^2*NC*Pi^2)/177397119900 - 
       (18075839609055143*CF*NM*NC*Pi^2)/7297290 - (CF*lm*NM*NC*Pi^2)/54 + 
       (18058613*CF*NC*NL*Pi^2)/1081080 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (160349996509063237*CF^2*NC*Pi^3)/
        (251644717004571*Sqrt[3]) + (62199857593727875*CF*NC*NH*Pi^3)/
        (22876792454961*Sqrt[3]) + (92*CF^2*NC*Pi^4)/15 - 
       (623746321272598501211413*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (88163726602551449850*Sqrt[3]) - (1414647427950529745*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(251644717004571*Sqrt[3]) + 
       (1664*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (2565599944145011792*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (108735371545185*Sqrt[3]) + (28434220614275600*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (160349996509063237*CF^2*NC*Pi*Log[3]^2)/(326206114635555*Sqrt[3]) + 
       (1777138788392225*CF*NC*NH*Pi*Log[3]^2)/(847288609443*Sqrt[3]) - 
       (CF*NC*(465506031193637514534969*CF + 
          13*CA*(-17903909576590550907689 + 139724331648501600*lm) - 
          10010*(8645*(-124266425148891661 + 3816397728*lm)*NM + 
            11600829240*(3595 + 2844*lm)*NL + (13652152242271 + 
              32992758358560*lm)*NH))*Log[x]^2)/361771859849400 - 
       (CF*NC*(-598825327968399*CA + 4*(299368232704579*CF + 
            60060*(96097537811*NM + 6162*NL)))*Log[x]^3)/2432430 + 
       (454294905670022522235385*CF^2*NC*PolyGamma[2, 1])/68630377364883 - 
       (1429799525569*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (9447003217598999*CF*NC*NH*PolyGamma[2, 1])/137260754729766 + 
       CA*CF*NC*(-429018641496350908057478401324782474853471540416653/
          1854467087961575475147122637181704276480000 + 
         (17903207236010497553*Pi^2)/333923990400 - (160349996509063237*Pi^3)/
          (503289434009142*Sqrt[3]) - (416*Pi^4)/135 + 
         lm*(777314733379/42499416960 + (11*Pi^2)/108) + 
         (623746321272598501211413*Im[PolyLog[2, (-1)^(1/3)]])/
          (176327453205102899700*Sqrt[3]) - 
         (832*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (1282799972072505896*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (108735371545185*Sqrt[3]) - (160349996509063237*Pi*Log[3]^2)/
          (652412229271110*Sqrt[3]) - (454294905670022522235385*
           PolyGamma[2, 1])/137260754729766 - (842191602537670068947769683*
           Zeta[3])/124907286804087060) + (842191572490528298853493583*CF^2*
         NC*Zeta[3])/62453643402043530 - (1301669637839*CF*NM*NC*Zeta[3])/
        27 + (8218*CF*NC*NL*Zeta[3])/9 - (527709721532817695*CF*NC*NH*
         Zeta[3])/68630377364883 + CF*Log[x]*
        ((-39205870288109177569975480337*NM*NC)/5092300699240154400 + 
         (86301367*lm*NM*NC)/1621620 + (1745134892057*NC*NL)/1248647400 + 
         (86301367*lm*NC*NL)/1621620 + (3713169677713181386469293958617453*
           NC*NH)/187421854568292941877932652000 + (86301367*lm*NC*NH)/
          1621620 - (192195083864*NM*NC*Pi^2)/81 + (4108*NC*NL*Pi^2)/27 - 
         (28434220614275600*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CA*NC*
          (-5622563577685441091154950754060253092949/
            93804638211430617409905292326000 - (86301367*lm)/294840 + 
           (54437631458933*Pi^2)/884520 + (1282799972072505896*
             Im[PolyLog[2, (-1)^(1/3)]])/(326206114635555*Sqrt[3]) - 
           364*Zeta[3]) + CF*NC*(44980054989423315639432423151201314738233/
            375218552845722469639621169304000 - (54437665734083*Pi^2)/
            442260 - (2565599944145011792*Im[PolyLog[2, (-1)^(1/3)]])/
            (326206114635555*Sqrt[3]) + 728*Zeta[3])), 
      (-214208679945487968617454921887366405464336780522409809*CF^2*NC)/
        11817682423284549596525781511452037056000000 + 
       (53927612478539509197751761299718185473*CF*NM*NC)/
        449688824584028425467571500000 + (1140854601499*CF*lm*NM*NC)/
        525930284880 + (50835797322391049*CF*NC*NL)/83307357124992 + 
       (1140854601499*CF*lm*NC*NL)/525930284880 + 
       (149234496936046368371907555544392067541501753*CF*NC*NH)/
        9407807873181693765965516625313029000000 + 
       (1140854601499*CF*lm*NC*NH)/525930284880 + 
       (51981335549020812430819*CF^2*NC*Pi^2)/8940814842960 - 
       (596668716397703*CF*NM*NC*Pi^2)/4378374 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (227039107*CF*NC*NL*Pi^2)/21891870 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (8359581077503128107*CF^2*NC*Pi^3)/
        (17447367045650256*Sqrt[3]) - (43372210177226245*CF*NC*NH*Pi^3)/
        (22876792454961*Sqrt[3]) - (3331*CF^2*NC*Pi^4)/972 + 
       (18592960816554565576291999*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (3056342522221783594800*Sqrt[3]) + (2100275150321947534*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(8807565095159985*Sqrt[3]) - 
       (2932*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (8359581077503128107*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (471186610029135*Sqrt[3]) - (19827296081017712*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (8359581077503128107*CF^2*NC*Pi*Log[3]^2)/(22616957281398480*
         Sqrt[3]) - (1239206005063607*CF*NC*NH*Pi*Log[3]^2)/
        (847288609443*Sqrt[3]) + 
       (CF*NC*(51*CA*(-4454086183092961156676299 + 410711159025367200*lm) + 
          2*(227158422584010175204958159*CF - 144144*
             (6*(6156464929115056726 + 2201740716175*lm)*NM + 
              7250518275*(2429 + 1822*lm)*NL + 2*(2637056836823 + 
                6605222148525*lm)*NH)))*Log[x]^2)/6511893477289200 + 
       (4*CF*NC*(-10059128464912386*CA + 5*(4023643906132135*CF - 
            78078*(724648667*NM - 911*NL)))*Log[x]^3)/3648645 + 
       (16354613305973007102289408*CF^2*NC*PolyGamma[2, 1])/205891132094649 - 
       (4825573344977*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (98321839291729175*CF*NC*NH*PolyGamma[2, 1])/205891132094649 + 
       CA*CF*NC*(3825154993293919935258853097081265843550826482887089/
          422060086545876771304492196837572752000000 - 
         (12230902487222997314813*Pi^2)/4207442279040 + 
         (8359581077503128107*Pi^3)/(34894734091300512*Sqrt[3]) + 
         (5573*Pi^4)/3240 + lm*(-1140854601499/95623688160 - (11*Pi^2)/243) - 
         (18592960816554565576291999*Im[PolyLog[2, (-1)^(1/3)]])/
          (6112685044443567189600*Sqrt[3]) + 
         (1466*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (8359581077503128107*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (942373220058270*Sqrt[3]) + (8359581077503128107*Pi*Log[3]^2)/
          (45233914562796960*Sqrt[3]) - (8177306652986503551144704*
           PolyGamma[2, 1])/205891132094649 - (304691395692335852766059903341*
           Zeta[3])/4121940464534872980) + (304691395583918640918016114651*
         CF^2*NC*Zeta[3])/2060970232267436490 - 
       (9613463873950*CF*NM*NC*Zeta[3])/243 - (47380*CF*NC*NL*Zeta[3])/81 + 
       (1500719133994930738*CF*NC*NH*Zeta[3])/205891132094649 + 
       CF*Log[x]*((-2894944988043896075423383499359*NM*NC)/
          1814132124104305005000 - (113210392*lm*NM*NC)/3648645 - 
         (179281649017199*NC*NL)/202280878800 - (113210392*lm*NC*NL)/
          3648645 - (3232961324177042344538795154202727*NC*NH)/
          234277318210366177347415815000 - (113210392*lm*NC*NH)/3648645 - 
         (18840823820*NM*NC*Pi^2)/243 - (23686*NC*NL*Pi^2)/243 + 
         (19827296081017712*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CF*NC*
          (28954931272931937044007542374286521768741/
            1501474801303411243055706960000 + (80473005612774869*Pi^2)/
            14594580 + (8359581077503128107*Im[PolyLog[2, (-1)^(1/3)]])/
            (1413559830087405*Sqrt[3]) - 520*Zeta[3]) + 
         CA*NC*(-709395810856552995175529156512182051634997/
            73572265263867150909729641040000 + (56605196*lm)/331695 - 
           (80473005778690619*Pi^2)/29189160 - (8359581077503128107*
             Im[PolyLog[2, (-1)^(1/3)]])/(2827119660174810*Sqrt[3]) + 
           260*Zeta[3])), 
      (954536080361005699492464912129422109161021946465305227*CF^2*NC)/
        361621082152507217653688914250432333913600000 + 
       (587823961941912040485211528249470367596539*CF*NM*NC)/
        9250741534300013323904328000000 - (837783244339*CF*lm*NM*NC)/
        233746793280 - (49870517574882075179*CF*NC*NL)/42116497213190400 - 
       (837783244339*CF*lm*NC*NL)/233746793280 - 
       (1734071931734180661538266318967453261464479713831*CF*NC*NH)/
        64785042697137410614061078110520319326400000 - 
       (837783244339*CF*lm*NC*NH)/233746793280 - 
       (9351825557262485652221*CF^2*NC*Pi^2)/17030123510400 - 
       (58969801157831279*CF*NM*NC*Pi^2)/2918916 - (CF*lm*NM*NC*Pi^2)/54 + 
       (772539*CF*NC*NL*Pi^2)/40040 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (245304599271964937059*CF^2*NC*Pi^3)/
        (314052606821704608*Sqrt[3]) + (935073207022949855*CF*NC*NH*Pi^3)/
        (274521509459532*Sqrt[3]) + (7679*CF^2*NC*Pi^4)/1080 - 
       (476956174672487463045325523*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (55014165399992104706400*Sqrt[3]) - (40431659384393732734*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5284539057095991*Sqrt[3]) + 
       (5738*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (245304599271964937059*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (8481358980524430*Sqrt[3]) + (106865509374051412*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) + 
       (245304599271964937059*CF^2*NC*Pi*Log[3]^2)/(407105231065172640*
         Sqrt[3]) + (26716377343512853*CF*NC*NH*Pi*Log[3]^2)/
        (10167463313316*Sqrt[3]) - 
       (CF*NC*(87*CA*(-4767851056333168259248957 + 9000723085559805600*lm) + 
          22*(37709453539884828281764999*CF - 
            1092*(203*(-6258380708235698317711 + 29193932968200*lm)*NM + 
              85*(5327982660*(16493 + 13086*lm)*NL + (29536772791147 + 
                  69721981088760*lm)*NH))))*Log[x]^2)/125896607227591200 - 
       (CF*NC*(-9796494480879227*CA + 8*(2449035783454556*CF + 
            45045*(1559388977578*NM + 15267*NL)))*Log[x]^3)/7297290 + 
       (36797881397001118329056197*CF^2*NC*PolyGamma[2, 1])/617673396283947 - 
       (12868195752577*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (97273551318022607*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 + 
       CA*CF*NC*(-477267903853110151791623899983627602432384369037330341/
          361621082152507217653688914250432333913600000 + 
         (9351825431979366443831*Pi^2)/34060247020800 - 
         (245304599271964937059*Pi^3)/(628105213643409216*Sqrt[3]) - 
         (7711*Pi^4)/2160 + lm*(837783244339/42499416960 + (11*Pi^2)/108) + 
         (476956174672487463045325523*Im[PolyLog[2, (-1)^(1/3)]])/
          (110028330799984209412800*Sqrt[3]) - 
         (2869*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (245304599271964937059*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (16962717961048860*Sqrt[3]) - (245304599271964937059*Pi*Log[3]^2)/
          (814210462130345280*Sqrt[3]) - (36797881397001118329056197*
           PolyGamma[2, 1])/1235346792567894 - 
         (114614464231972580282736224327*Zeta[3])/1902434060554556760) + 
       (114614463670590124537365660407*CF^2*NC*Zeta[3])/951217030277278380 - 
       (11828603303381*CF*NM*NC*Zeta[3])/27 + (10180*CF*NC*NL*Zeta[3])/9 - 
       (5841422620029150071*CF*NC*NH*Zeta[3])/617673396283947 + 
       CF*Log[x]*((-11224303480346844583254464583157*NM*NC)/
          172774488009933810000 + (99729067*lm*NM*NC)/1621620 + 
         (112973475737449*NC*NL)/64929664800 + (99729067*lm*NC*NL)/
          1621620 + (345015022726416710961011430541509389*NC*NH)/
          13907804090464796834059531794000 + (99729067*lm*NC*NH)/1621620 - 
         (1559388988631*NM*NC*Pi^2)/81 + (5089*NC*NL*Pi^2)/27 - 
         (106865509374051412*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (2541865828329*Sqrt[3]) + 
         CA*NC*(-3485011887109493989196047214797496142801749/
            4502622634148669635675454031648000 - (99729067*lm)/294840 + 
           (1507146487273529*Pi^2)/4490640 + (245304599271964937059*
             Im[PolyLog[2, (-1)^(1/3)]])/(50888153883146580*Sqrt[3]) - 
           420*Zeta[3]) + CF*NC*(697001721798728398191969767255483598490333/
            450262263414866963567545403164800 - (1507146701720069*Pi^2)/
            2245320 - (245304599271964937059*Im[PolyLog[2, (-1)^(1/3)]])/
            (25444076941573290*Sqrt[3]) + 840*Zeta[3])), 
      (-12164936161988662310010437269905649840915808892523585405159*CF^2*NC)/
        81364743484314123972080005706347275130560000000 + 
       (697112789168027551161766020240685786305119101*CF*NM*NC)/
        182749231576834850214929151029520000 + (6125695978607*CF*lm*NM*NC)/
        2629651424400 + (119688722489832637741*CF*NC*NL)/
        157936864549464000 + (6125695978607*CF*lm*NC*NL)/2629651424400 + 
       (36596470063902718869293562638744805705259301719*CF*NC*NH)/
        1861779025669050305024670351410520070800000 + 
       (6125695978607*CF*lm*NC*NH)/2629651424400 + 
       (2876918739149937870867187*CF^2*NC*Pi^2)/59605432286400 - 
       (21267944517401182*CF*NM*NC*Pi^2)/10945935 + (2*CF*lm*NM*NC*Pi^2)/
        243 - (52195631*CF*NC*NL*Pi^2)/4378374 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (414158369511628466035*CF^2*NC*Pi^3)/
        (706618365348835368*Sqrt[3]) - (1461722255819234885*CF*NC*NH*Pi^3)/
        (617673396283947*Sqrt[3]) - (3211*CF^2*NC*Pi^4)/810 + 
       (917682596342780018683346231*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (123781872149982235589400*Sqrt[3]) + 
       (2809997129553259688708*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3091455348401154735*Sqrt[3]) - 
       (3352*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (165663347804651386414*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7633223082471987*Sqrt[3]) - (668215888374507376*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (82831673902325693207*CF^2*NC*Pi*Log[3]^2)/(183197353979327688*
         Sqrt[3]) - (41763493023406711*CF*NC*NH*Pi*Log[3]^2)/
        (22876792454961*Sqrt[3]) + 
       (CF*NC*(136721965708503382929205407003*CF + 
          29*CA*(-2357275228806287102268081251 + 32220607744387062000*lm) - 
          700700*(7*(1122119382531926876551 + 34636889069640*lm)*NM + 
            232908956280*(1384 + 1041*lm)*NL + (98914096197463 + 
              242458223487480*lm)*NH))*Log[x]^2)/236056138551733500 + 
       (4*CF*NC*(-83204027073850411*CA + 166408005346200637*CF - 
          180180*(29835036974*NM - 2429*NL))*Log[x]^3)/3648645 + 
       (1324723693598185609116929455*CF^2*NC*PolyGamma[2, 1])/
        1853020188851841 - (43430160596140*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (1070733794134224200*CF*NC*NH*PolyGamma[2, 1])/1853020188851841 + 
       CA*CF*NC*(276475821832439261565382469354779414401039111875127623711/
          3698397431105187453276363895743057960480000000 - 
         (719229684826692012249203*Pi^2)/29802716143200 + 
         (414158369511628466035*Pi^3)/(1413236730697670736*Sqrt[3]) + 
         (1933*Pi^4)/972 + lm*(-6125695978607/478118440800 - (11*Pi^2)/243) - 
         (917682596342780018683346231*Im[PolyLog[2, (-1)^(1/3)]])/
          (247563744299964471178800*Sqrt[3]) + 
         (1676*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (82831673902325693207*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (7633223082471987*Sqrt[3]) + (82831673902325693207*Pi*Log[3]^2)/
          (366394707958655376*Sqrt[3]) - (1324723693598185609116929455*
           PolyGamma[2, 1])/3706040377703682 - 
         (1241451026485637416958967454580*Zeta[3])/1854873209040692841) + 
       (2482902052845074756695425548089*CF^2*NC*Zeta[3])/
        1854873209040692841 - (86144278958408*CF*NM*NC*Zeta[3])/243 - 
       (58304*CF*NC*NL*Zeta[3])/81 + (16461607607715475648*CF*NC*NH*
         Zeta[3])/1853020188851841 + CF*Log[x]*
        ((-20572090088674608019169250522413*NM*NC)/1401139392586273937025 - 
         (26033495*lm*NM*NC)/729729 - (53407538905417*NC*NL)/48697248600 - 
         (26033495*lm*NC*NL)/729729 - (54196371162031359286183866876954649*
           NC*NH)/3147772227575612301199864444500 - (26033495*lm*NC*NH)/
          729729 - (13260014476*NM*NC*Pi^2)/9 - (9716*NC*NL*Pi^2)/81 + 
         (668215888374507376*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (22876792454961*Sqrt[3]) + 
         CF*NC*(82957292742705866860553521023881903214371525839/
            506545046341725334013488578560400000 + (66563218938086357*Pi^2)/
            1459458 + (165663347804651386414*Im[PolyLog[2, (-1)^(1/3)]])/
            (22899669247415961*Sqrt[3]) - (1792*Zeta[3])/3) + 
         CA*NC*(-41478646332063447437041800652658767877227999307/
            506545046341725334013488578560400000 + (26033495*lm)/132678 - 
           (33281609479341967*Pi^2)/1459458 - (82831673902325693207*
             Im[PolyLog[2, (-1)^(1/3)]])/(22899669247415961*Sqrt[3]) + 
           (896*Zeta[3])/3)), 
      (7137872084057581276870242214033500831583269230915473991*CF^2*NC)/
        531795709047804731843660168015341667520000000 + 
       (36301177475683860837522517273649765043562261*CF*NM*NC)/
        69935605999308100728716719680000 - (4491344171519*CF*lm*NM*NC)/
        1168733966400 - (846230725432851487*CF*NC*NL)/580117041504000 - 
       (4491344171519*CF*lm*NC*NL)/1168733966400 - 
       (5390451515576657931273534635780997833181996303015932107*CF*NC*NH)/
        164050952594185750966296954129193420809486504000000 - 
       (4491344171519*CF*lm*NC*NH)/1168733966400 - 
       (118953754185585140102909*CF^2*NC*Pi^2)/56625160672080 - 
       (2426178079213501133*CF*NM*NC*Pi^2)/14594580 - 
       (CF*lm*NM*NC*Pi^2)/54 + (71576651*CF*NC*NL*Pi^2)/3243240 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (6180471544352604445*CF^2*NC*Pi^3)/(6542762642118846*Sqrt[3]) + 
       (384747837669725215*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) + 
       (2203*CF^2*NC*Pi^4)/270 - (144277444763889883868238767*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(13753541349998026176600*Sqrt[3]) - 
       (3478933047671618904992*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (343495038711239415*Sqrt[3]) + 
       (6536*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (9888754470964167112*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282711966017481*Sqrt[3]) + (43971181447968596*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (1236094308870520889*CF^2*NC*Pi*Log[3]^2)/(1696271796104886*Sqrt[3]) + 
       (10992795361992149*CF*NC*NH*Pi*Log[3]^2)/(3389154437772*Sqrt[3]) + 
       ((-8046865995952633652882503*CF^2*NC)/319210464573000 + 
         CA*CF*(149015928101821355819077/11822609799000 - (68365*lm)/9)*NC + 
         CF*NC*((-216288923178107989712653/108423134820 + (12430*lm)/9)*NM + 
           (55*(2557 + 2034*lm)*NL)/81 + (291074899979683829*NH)/
            487361991015900 + (12430*lm*NH)/9))*Log[x]^2 - 
       (CF*NC*(-44990478778363805*CA + 28*(3213573137265187*CF + 
            12870*(12777334503872*NM + 18645*NL)))*Log[x]^3)/7297290 + 
       (2980628326650694717256121652*CF^2*NC*PolyGamma[2, 1])/
        5559060566555523 - (115813761799393*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (993128743854295367*CF*NC*NH*PolyGamma[2, 1])/11118121133111046 + 
       CA*CF*NC*(-3568935802366205416498979950017885169148308056960717433/
          531795709047804731843660168015341667520000000 + 
         (25042895514458932096487*Pi^2)/23842172914560 - 
         (6180471544352604445*Pi^3)/(13085525284237692*Sqrt[3]) - 
         (737*Pi^4)/180 + lm*(4491344171519/212497084800 + (11*Pi^2)/108) + 
         (144277444763889883868238767*Im[PolyLog[2, (-1)^(1/3)]])/
          (27507082699996052353200*Sqrt[3]) - 
         (3268*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (4944377235482083556*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (282711966017481*Sqrt[3]) - (1236094308870520889*Pi*Log[3]^2)/
          (3392543592209772*Sqrt[3]) - (1490314163325347358628060826*
           PolyGamma[2, 1])/5559060566555523 - 
         (60015258091837416165029978185501*Zeta[3])/111292392542441570460) + 
       (60015258052051072821184539224881*CF^2*NC*Zeta[3])/
        55646196271220785230 - (107295539045189*CF*NM*NC*Zeta[3])/27 + 
       (4144*CF*NC*NL*Zeta[3])/3 - (63802277500647919307*CF*NC*NH*Zeta[3])/
        5559060566555523 + CF*Log[x]*((-21738552923454392791389262103831*NM*
           NC)/39581064525912109200 + (114119443*lm*NM*NC)/1621620 + 
         (113370067813397*NC*NL)/53124271200 + (114119443*lm*NC*NL)/
          1621620 + (11590880182501936773956167966661127091651*NC*NH)/
          378686325709872309796717618197630000 + (114119443*lm*NC*NH)/
          1621620 - (12777334518277*NM*NC*Pi^2)/81 + (6215*NC*NL*Pi^2)/27 - 
         (43971181447968596*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CA*NC*
          (-4857058295606974732811048908222643298820297/
            551791989479003631822972307800000 - (114119443*lm)/294840 + 
           (44990427090696733*Pi^2)/29189160 + (4944377235482083556*
             Im[PolyLog[2, (-1)^(1/3)]])/(848135898052443*Sqrt[3]) - 
           480*Zeta[3]) + CF*NC*(4857057817237472602335867654572118923514247/
            275895994739501815911486153900000 - (44990428785740083*Pi^2)/
            14594580 - (9888754470964167112*Im[PolyLog[2, (-1)^(1/3)]])/
            (848135898052443*Sqrt[3]) + 960*Zeta[3])), 
      (-29582428942370491180825056840902227001906522767063728412840193489*
         CF^2*NC)/23812856746067246034660711110065244317910734080000000 + 
       (790533689240121845298087205577178782723978375810809913*CF*NM*NC)/
        15243990602135363663708272147297204896000000 + 
       (52377572736127*CF*lm*NM*NC)/21037211395200 + 
       (502254769581035189729*CF*NC*NL)/541497821312448000 + 
       (52377572736127*CF*lm*NC*NL)/21037211395200 + 
       (425697990778795895368522370562469118437708949004755231941*CF*NC*NH)/
        17717502880172061104360071045952889447424542432000000 + 
       (52377572736127*CF*lm*NC*NH)/21037211395200 + 
       (2740267896799584895017594821*CF^2*NC*Pi^2)/6795019280649600 - 
       (15347378049368707*CF*NM*NC*Pi^2)/694980 + (2*CF*lm*NM*NC*Pi^2)/
        243 - (1189044607*CF*NC*NL*Pi^2)/87567480 + (2*CF*lm*NC*NL*Pi^2)/
        243 + (2*CF*lm*NC*NH*Pi^2)/243 - (3000523635829423573895*CF^2*NC*
         Pi^3)/(4239710192093012208*Sqrt[3]) - 
       (10791878621866449415*CF*NC*NH*Pi^3)/(3706040377703682*Sqrt[3]) - 
       (11033*CF^2*NC*Pi^4)/2430 + (2651791944769018844902768357*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(297076493159957365414560*Sqrt[3]) + 
       (2380994199596893199444*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1324909435029066315*Sqrt[3]) - 
       (3800*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (600104727165884714779*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (22899669247415961*Sqrt[3]) - (2466715113569474152*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (600104727165884714779*CF^2*NC*Pi*Log[3]^2)/(1099184123875966128*
         Sqrt[3]) - (308339389196184269*CF*NC*NH*Pi*Log[3]^2)/
        (137260754729766*Sqrt[3]) + 
       (CF*NC*(31*CA*(-9138793400289540640909456373983 + 
            18151959343566288240000*lm) + 
          26*(21792507395755549313001256152861*CF - 
            3080*((387450337419260409994957567 + 1277610434226126000*lm)*
               NM + 90252220558500*(18775 + 14156*lm)*NL + 
              (531199019434676317 + 1277610434226126000*lm)*NH)))*Log[x]^2)/
        117083844721659816000 + (CF*NC*(-5544697106593221179*CA + 
          11089393712188371284*CF - 240240*(2212323219784*NM - 17695*NL))*
         Log[x]^3)/7297290 + (107302619356816791223012725952*CF^2*NC*
         PolyGamma[2, 1])/16677181699666569 - 
       (130290481995545*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (11527280966240253041*CF*NC*NH*PolyGamma[2, 1])/16677181699666569 + 
       CA*CF*NC*
        (29582428942286015876855772712818376084579785776934137379358195739/
          47625713492134492069321422220130488635821468160000000 - 
         (144224626148365937784247559*Pi^2)/715265187436800 + 
         (3000523635829423573895*Pi^3)/(8479420384186024416*Sqrt[3]) + 
         (2213*Pi^4)/972 + lm*(-52377572736127/3824947526400 - 
           (11*Pi^2)/243) - (2651791944769018844902768357*
           Im[PolyLog[2, (-1)^(1/3)]])/(594152986319914730829120*Sqrt[3]) + 
         (1900*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (600104727165884714779*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (45799338494831922*Sqrt[3]) + (600104727165884714779*Pi*Log[3]^2)/
          (2198368247751932256*Sqrt[3]) - (53651309678408395611506362976*
           PolyGamma[2, 1])/16677181699666569 - 
         (404270710851679971186487586800313*Zeta[3])/66775435525464942276) + 
       (404270710848812749399357129155425*CF^2*NC*Zeta[3])/
        33387717762732471138 - (257631199149226*CF*NM*NC*Zeta[3])/81 - 
       (23596*CF*NC*NL*Zeta[3])/27 + (178364282344682356486*CF*NC*NH*
         Zeta[3])/16677181699666569 + CF*Log[x]*
        ((-14212444660223182724759094840905590210327*NM*NC)/
          105565204571992085472912360000 - (593189347*lm*NM*NC)/14594580 - 
         (439816248985793*NC*NL)/328706428050 - (593189347*lm*NC*NL)/
          14594580 - (371197169948359773769047419714280227410427*NC*NH)/
          17527767075714089767733786899433160000 - (593189347*lm*NC*NH)/
          14594580 - (4424646373558*NM*NC*Pi^2)/243 - (35390*NC*NL*Pi^2)/
          243 + (2466715113569474152*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (68630377364883*Sqrt[3]) + 
         CF*NC*(111346151756647183999414898615712108609391872521299/
            79875821995010813607251980231743075000 + 
           (277234853677613708*Pi^2)/729729 + (600104727165884714779*
             Im[PolyLog[2, (-1)^(1/3)]])/(68699007742247883*Sqrt[3]) - 
           680*Zeta[3]) + CA*NC*
          (-7126153711588309430089589156909918728370246583697411/
            10224105215361384141728253469663113600000 + (593189347*lm)/
            2653560 - (138617426845104145*Pi^2)/729729 - 
           (600104727165884714779*Im[PolyLog[2, (-1)^(1/3)]])/
            (137398015484495766*Sqrt[3]) + 340*Zeta[3])), 
      (3049168887947731391068437346255262933782420663290879240091869973*CF^2*
         NC)/61233060204172918374841828568739199674627601920000000 + 
       (529451107761385523773521260869742736468654077761*CF*NM*NC)/
        123822830832459184658633181580800000 - (19175368043651*CF*lm*NM*NC)/
        4674935865600 - (165931306866454623359*CF*NC*NL)/93592216029312000 - 
       (19175368043651*CF*lm*NC*NL)/4674935865600 - 
       (2540730850235250292641482610463936663863648252898167548071*CF*NC*NH)/
        63783010368619419975696255765430402010728352755200000 - 
       (19175368043651*CF*lm*NC*NH)/4674935865600 + 
       (2241641030152567284264083*CF^2*NC*Pi^2)/3020008569177600 - 
       (8044890580655300633*CF*NM*NC*Pi^2)/5837832 - 
       (CF*lm*NM*NC*Pi^2)/54 + (162357487*CF*NC*NL*Pi^2)/6486480 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (172316750127000761787305*CF^2*NC*Pi^3)/(152629566915348439488*
         Sqrt[3]) + (85439975832993917450*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) + (3341*CF^2*NC*Pi^4)/360 - 
       (671171778400369835080506877931*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (53473768768792325774620800*Sqrt[3]) - 
       (218765385334910869158241*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (16693858881366235569*Sqrt[3]) + 
       (2462*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (34463350025400152357461*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(824388092906974596*
         Sqrt[3]) + (39058274666511505120*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (34463350025400152357461*CF^2*NC*Pi*Log[3]^2)/(39570628459534780608*
         Sqrt[3]) + (2441142166656969070*CF*NC*NH*Pi*Log[3]^2)/
        (617673396283947*Sqrt[3]) + 
       (CF*NC*(-31*CA*(11213863868181314714293058239 + 
            23068734767907244416000*lm) + 2*(347628911282415483726331933279*
             CF + 200200*(85405*(-37746626598851768433877 + 3802291549056*lm)*
               NM + 19253807052480*(21155 + 16866*lm)*NL + 
              (142999239755163947 + 324734709747127680*lm)*NH)))*Log[x]^2)/
        78055896481106544000 - (CF*NC*(-72161422841227771*CA + 
          8*(18040259094498247*CF + 60060*(52774351454989*NM + 11244*NL)))*
         Log[x]^3)/4864860 + (241430893727345223049742672380*CF^2*NC*
         PolyGamma[2, 1])/50031545098999707 - 
       (1042323856224769*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (10063868459416151711*CF*NC*NH*PolyGamma[2, 1])/100063090197999414 + 
       CA*CF*NC*
        (-21344181757830454608932202029153811072069996248263477538134437811/
          857262842858420857247785599962348795444786426880000000 - 
         (6724923182053013713204609*Pi^2)/18120051415065600 - 
         (172316750127000761787305*Pi^3)/(305259133830696878976*Sqrt[3]) - 
         (2011*Pi^4)/432 + lm*(19175368043651/849988339200 + (11*Pi^2)/108) + 
         (671171778400369835080506877931*Im[PolyLog[2, (-1)^(1/3)]])/
          (106947537537584651549241600*Sqrt[3]) - 
         (1231*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (34463350025400152357461*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1648776185813949192*Sqrt[3]) - (34463350025400152357461*Pi*
           Log[3]^2)/(79141256919069561216*Sqrt[3]) - 
         (120715446863672611524871336190*PolyGamma[2, 1])/50031545098999707 - 
         (19363500751162171120355990977531561*Zeta[3])/
          4006526131527896536560) + (19363500749446091890637116379514121*CF^2*
         NC*Zeta[3])/2003263065763948268280 - 
       (971958054585455*CF*NM*NC*Zeta[3])/27 + 1666*CF*NC*NL*Zeta[3] - 
       (688736218666780621643*CF*NC*NH*Zeta[3])/50031545098999707 + 
       CF*Log[x]*((-11246990236626031737070397637875419*NM*NC)/
          2416528150003055088000 + (258944561*lm*NM*NC)/3243240 + 
         (1509787089025213*NC*NL)/584366983200 + (258944561*lm*NC*NL)/
          3243240 + (16466769932205561197268850923786680245539359*NC*NH)/
          441699730307995062146891429865715632000 + (258944561*lm*NC*NH)/
          3243240 - (105548702928322*NM*NC*Pi^2)/81 + (7496*NC*NL*Pi^2)/
          27 - (39058274666511505120*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CA*NC*(-17151581821363197503003115579771303837004158405487411/
            184033893876504914551108562453936044800000 - (258944561*lm)/
            589680 + (144322762548198089*Pi^2)/38918880 + 
           (34463350025400152357461*Im[PolyLog[2, (-1)^(1/3)]])/
            (4946328557441847576*Sqrt[3]) - 544*Zeta[3]) + 
         CF*NC*(133996731509926589352289024021807693468470286344287/
            718882397955097322465267822085687675000 - 
           (144322765264391569*Pi^2)/19459440 - (34463350025400152357461*
             Im[PolyLog[2, (-1)^(1/3)]])/(2473164278720923788*Sqrt[3]) + 
           1088*Zeta[3])), (-112729132520133897285797711394927554580936811951\
1479716417972874580062009*CF^2*NC)/
        108539548744279666972642318436032915101656437883523840000000 + 
       (17892835736690987336781705847419068019740288317367407*CF*NM*NC)/
        30858280571124217942729295844731184000000 + 
       (8055887845000739*CF*lm*NM*NC)/3039877046606400 + 
       (613928563585093504674649*CF*NC*NL)/547725046257541152000 + 
       (8055887845000739*CF*lm*NC*NL)/3039877046606400 + 
       (2313512330929967368969656359664397661677597985143030891537*CF*NC*NH)/
        79728762960774274969620319706788002513410440944000000 + 
       (8055887845000739*CF*lm*NC*NH)/3039877046606400 + 
       (782700535249684847449967124829*CF^2*NC*Pi^2)/231030655542086400 - 
       (449611611465865627*CF*NM*NC*Pi^2)/1969110 + (2*CF*lm*NM*NC*Pi^2)/
        243 - (11420188657*CF*NC*NL*Pi^2)/744323580 + 
       (2*CF*lm*NC*NL*Pi^2)/243 + (2*CF*lm*NC*NH*Pi^2)/243 - 
       (1096073817061074307871225*CF^2*NC*Pi^3)/(1297351318780461735648*
         Sqrt[3]) - (59011011222623661040*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) - (5011*CF^2*NC*Pi^4)/972 + 
       (82160484490833587266175937559267*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (7726959587090491074432705600*Sqrt[3]) + 
       (244827501466312360817176*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (83469294406831177845*Sqrt[3]) - 
       (4276*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (219214763412214861574245*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7007298789709284066*
         Sqrt[3]) - (26976462273199387904*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (219214763412214861574245*CF^2*NC*Pi*Log[3]^2)/(336350341906045635168*
         Sqrt[3]) - (1686028892074961744*CF*NC*NH*Pi*Log[3]^2)/
        (617673396283947*Sqrt[3]) + 
       (CF*NC*(80919494821936243309439028903993794*CF + 
          3*CA*(-13486582465308430883383173166186769 + 
            3826072623385700303616000*lm) - 2722720*
           (19*(105423662816180388961891619 + 40341792566275200*lm)*NM + 
            144403552893600*(7025 + 5308*lm)*NL + (324082841722718831 + 
              766494058759228800*lm)*NH))*Log[x]^2)/1990425360268216872000 + 
       (CF*NC*(-394919577758505758817*CA + 170*(4646112647836340669*CF - 
            48048*(5943272915509*NM - 5308*NL)))*Log[x]^3)/62026965 + 
       (8691512169820522402325259845377*CF^2*NC*PolyGamma[2, 1])/
        150094635296999121 - (1172614338217352*CF*NM*NC*PolyGamma[2, 1])/
        81 + (122844723596420005796*CF*NC*NH*PolyGamma[2, 1])/
        150094635296999121 + CA*CF*NC*(11272913252027044942015557439277797370\
62154325619160217668072442685626259/
          217079097488559333945284636872065830203312875767047680000000 - 
         (782700535250396911069278709369*Pi^2)/462061311084172800 + 
         (1096073817061074307871225*Pi^3)/(2594702637560923471296*Sqrt[3]) + 
         (2791*Pi^4)/1080 + lm*(-8055887845000739/552704917564800 - 
           (11*Pi^2)/243) - (82160484490833587266175937559267*
           Im[PolyLog[2, (-1)^(1/3)]])/(15453919174180982148865411200*
           Sqrt[3]) + (2138*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (219214763412214861574245*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (14014597579418568132*Sqrt[3]) + (219214763412214861574245*Pi*
           Log[3]^2)/(672700683812091270336*Sqrt[3]) - 
         (8691512169820522402325259845377*PolyGamma[2, 1])/
          300189270593998242 - (29897843571272349559197257517624691*Zeta[3])/
          546344472481076800440) + (29897843571243315734730655109137111*CF^2*
         NC*Zeta[3])/273172236240538400220 - 
       (2313531220222696*CF*NM*NC*Zeta[3])/81 - (28312*CF*NC*NL*Zeta[3])/
        27 + (1911757193844626205208*CF*NC*NH*Zeta[3])/150094635296999121 + 
       CF*Log[x]*((-310231867029039716007342558632776366399*NM*NC)/
          252548336296631783428020000 - (5698392577*lm*NM*NC)/124053930 - 
         (36038152509581851*NC*NL)/22352037107400 - (5698392577*lm*NC*NL)/
          124053930 - (2029038104056070243697316024587092676253439*NC*NH)/
          78874951840713403954802041047449220000 - (5698392577*lm*NC*NH)/
          124053930 - (47546183242888*NM*NC*Pi^2)/243 - 
         (42464*NC*NL*Pi^2)/243 + (26976462273199387904*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(2234898403159153059115013812598990895891927660485464797809/
            187910107766278799313841286550622072743600000 + 
           (143607119062363619737*Pi^2)/45110520 + 
           (219214763412214861574245*Im[PolyLog[2, (-1)^(1/3)]])/
            (21021896369127852198*Sqrt[3]) - 768*Zeta[3]) + 
         CA*NC*(-34920287548861152900972367805884627670421131735793221531/
            5872190867696212478557540204706939773237500 + 
           (5698392577*lm)/22555260 - (143607119063303422237*Pi^2)/90221040 - 
           (219214763412214861574245*Im[PolyLog[2, (-1)^(1/3)]])/
            (42043792738255704396*Sqrt[3]) + 384*Zeta[3])), 
      (-279439706914771427353016896170575259117398990698851104979552350119301*
         CF^2*NC)/
        6202259928244552398436703910630452291523225021915648000000 + 
       (360505994125069875671601765049183893674422016788370707123*CF*NM*NC)/
        10162660401423575775805514764864803264000000 - 
       (5891435825671139*CF*lm*NM*NC)/1351056465158400 - 
       (12341844461978755698671*CF*NC*NL)/5796032235529536000 - 
       (5891435825671139*CF*lm*NC*NL)/1351056465158400 - 
       (5076840745272328881642735426074379651160026107617017832699*CF*NC*NH)/
        106305017281032366626160426275717336684547254592000000 - 
       (5891435825671139*CF*lm*NC*NH)/1351056465158400 + 
       (1582673901392181754364179487*CF^2*NC*Pi^2)/11001459787718400 - 
       (814895572136186027957*CF*NM*NC*Pi^2)/70887960 - 
       (CF*lm*NM*NC*Pi^2)/54 + (3106983839*CF*NC*NL*Pi^2)/110270160 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (54137904739814262259690*CF^2*NC*Pi^3)/(40542228711889429239*
         Sqrt[3]) + (68612722957659264685*CF*NC*NH*Pi^3)/
        (11118121133111046*Sqrt[3]) + (1414*CF^2*NC*Pi^4)/135 - 
       (2051559525003153183504253291571*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (137981421198044483472012600*Sqrt[3]) - 
       (462795339460718172245842*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) + 
       (8288*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (24748756452486519890144*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(500521342122091719*
         Sqrt[3]) + (15682908104607831928*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (1546797278280407493134*CF^2*NC*Pi*Log[3]^2)/(1501564026366275157*
         Sqrt[3]) + (1960363513075978991*CF*NC*NH*Pi*Log[3]^2)/
        (411782264189298*Sqrt[3]) + 
       (CF*NC*(-9*CA*(12726369148668793212456030737861 + 
            161137629042553372809600*lm) + 
          56*(4090618591902579966939704314156*CF + 
            2431*(7*(-19208539148974858707189600761 + 276697836423122400*lm)*
               NM + 818286799730400*(2963 + 2367*lm)*NL + 
              (866793853643686537 + 1936884854961856800*lm)*NH)))*Log[x]^2)/
        132695024017881124800 + (CF*NC*(-36948414493931917075*CA + 
          224*(329896779165530854*CF - 109395*(438932154554296*NM + 
              13413*NL)))*Log[x]^3)/248107860 + 
       (19555902383972011252600199354131*CF^2*NC*PolyGamma[2, 1])/
        450283905890997363 - (9380914706057473*CF*NM*NC*PolyGamma[2, 1])/
        54 - (101306582558480802551*CF*NC*NH*PolyGamma[2, 1])/
        900567811781994726 + CA*CF*NC*(19560780029101989980958680251723881734\
32459409427245014543618066447907/
          86831638995423733578113854748826332081325150306819072000000 - 
         (1582673901520070442152049067*Pi^2)/22002919575436800 - 
         (27068952369907131129845*Pi^3)/(40542228711889429239*Sqrt[3]) - 
         (709*Pi^4)/135 + lm*(5891435825671139/245646630028800 + 
           (11*Pi^2)/108) + (2051559525003153183504253291571*
           Im[PolyLog[2, (-1)^(1/3)]])/(275962842396088966944025200*
           Sqrt[3]) - (4144*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (12374378226243259945072*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (500521342122091719*Sqrt[3]) - (773398639140203746567*Pi*Log[3]^2)/
          (1501564026366275157*Sqrt[3]) - (19555902383972011252600199354131*
           PolyGamma[2, 1])/900567811781994726 - 
         (1898355654414420160649427912137425081*Zeta[3])/
          43785607008840583578120) + (1898355654392172207221491468948231441*
         CF^2*NC*Zeta[3])/21892803504420291789060 - 
       (8795671833678239*CF*NM*NC*Zeta[3])/27 + (5962*CF*NC*NL*Zeta[3])/3 - 
       (7357881883717398305831*CF*NC*NH*Zeta[3])/450283905890997363 + 
       CF*Log[x]*((-163693442783274449744525245654746322574551*NM*NC)/
          4139811943999689626388720000 + (4956771697*lm*NM*NC)/55135080 + 
         (61439562741297121*NC*NL)/19868477428800 + (4956771697*lm*NC*NL)/
          55135080 + (33047405924039081043704831149501370594075221*NC*NH)/
          736166217179991770244819049776192720000 + (4956771697*lm*NC*NH)/
          55135080 - (877864309131508*NM*NC*Pi^2)/81 + (8942*NC*NL*Pi^2)/
          27 - (15682908104607831928*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CA*NC*(-283621193989417801523681441532522133993676457413047270529/
            300656172426046078902146058480995316389760000 - 
           (4956771697*lm)/10024560 - (5278345289005038377*Pi^2)/141775920 + 
           (12374378226243259945072*Im[PolyLog[2, (-1)^(1/3)]])/
            (1501564026366275157*Sqrt[3]) - 612*Zeta[3]) + 
         CF*NC*(81034626751528452998092024583307139802960925279860884909/
            42950881775149439843163722640142188055680000 + 
           (5278345277236907717*Pi^2)/70887960 - (24748756452486519890144*
             Im[PolyLog[2, (-1)^(1/3)]])/(1501564026366275157*Sqrt[3]) + 
           1224*Zeta[3])), (-127903084336773348550026050628518847292733495112\
937851342138370193514792011*CF^2*NC)/
        1465283908047775504130671298886444353872361911427571840000000 + 
       (3779069685091912108141851689188547395397933232027535183*CF*NM*NC)/
        635166275088973485987844672804050204000000 + 
       (316417702408057*CF*lm*NM*NC)/112588038763200 + 
       (586895497002894177310783*CF*NC*NL)/438180037006032921600 + 
       (316417702408057*CF*lm*NC*NL)/112588038763200 + 
       (37318493479421556557126477322695270876639009678906906439613*CF*NC*
         NH)/1076338299970452712089874316041638033931040952744000000 + 
       (316417702408057*CF*lm*NC*NH)/112588038763200 + 
       (6606154947858440504720216304617*CF^2*NC*Pi^2)/231030655542086400 - 
       (396699232056856807*CF*NM*NC*Pi^2)/176715 + (2*CF*lm*NM*NC*Pi^2)/
        243 - (12813180257*CF*NC*NL*Pi^2)/744323580 + 
       (2*CF*lm*NC*NL*Pi^2)/243 + (2*CF*lm*NC*NH*Pi^2)/243 - 
       (34973322270358478153187125*CF^2*NC*Pi^3)/(35028485607072466862496*
         Sqrt[3]) - (1914631662195989369570*CF*NC*NH*Pi^3)/
        (450283905890997363*Sqrt[3]) - (3137*CF^2*NC*Pi^4)/540 + 
       (523469201089177048674307395713819*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (41725581770288651801936610240*Sqrt[3]) + 
       (9799794915554507452371638*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2253670948984441801815*Sqrt[3]) - 
       (4780*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (6994664454071695630637425*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(189197067322150669782*
         Sqrt[3]) - (875260188432452283232*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (6994664454071695630637425*CF^2*NC*Pi*Log[3]^2)/
        (9081459231463232149536*Sqrt[3]) - (54703761777028267702*CF*NC*NH*Pi*
         Log[3]^2)/(16677181699666569*Sqrt[3]) + 
       (CF*NC*(CA*(-1024465993846488531278285635811715539 + 
            40887907506292012678512000*lm) + 
          22*(93133272172743570710065052646319219*CF - 
            2227680*(2*(1641084182866405610631276457 + 75844957750011450*lm)*
               NM + 102285849966300*(1959 + 1483*lm)*NL + 
              (65102925524724539 + 151689915500022900*lm)*NH)))*Log[x]^2)/
        5971276080804650616000 + (CF*NC*(-3325905009792361583823*CA + 
          6651810012864079267922*CF - 2042040*(238780961813801*NM - 
            25211*NL))*Log[x]^3)/62026965 + 
       (704012485776199264322116698533632*CF^2*NC*PolyGamma[2, 1])/
        1350851717672992089 - (31660587132814301*CF*NM*NC*PolyGamma[2, 1])/
        243 + (1297321655980719880787*CF*NC*NH*PolyGamma[2, 1])/
        1350851717672992089 + CA*CF*NC*(3197577108420500372213903086818321825\
5267276859000207638982691234065725159/
          732641954023887752065335649443222176936180955713785920000000 - 
         (6606154947859209061663040635277*Pi^2)/462061311084172800 + 
         (34973322270358478153187125*Pi^3)/(70056971214144933724992*
           Sqrt[3]) + (28297*Pi^4)/9720 + 
         lm*(-316417702408057/20470552502400 - (11*Pi^2)/243) - 
         (523469201089177048674307395713819*Im[PolyLog[2, (-1)^(1/3)]])/
          (83451163540577303603873220480*Sqrt[3]) + 
         (2390*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (6994664454071695630637425*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (378394134644301339564*Sqrt[3]) + (6994664454071695630637425*Pi*
           Log[3]^2)/(18162918462926464299072*Sqrt[3]) - 
         (352006242888099632161058349266816*PolyGamma[2, 1])/
          1350851717672992089 - (5347709909405366935906352411649397669*
           Zeta[3])/10817620555125320648712) + 
       (5347709909404666929015738962659518361*CF^2*NC*Zeta[3])/
        5408810277562660324356 - (62366050415999950*CF*NM*NC*Zeta[3])/243 - 
       (100852*CF*NC*NL*Zeta[3])/81 + (20294047304848504552906*CF*NC*NH*
         Zeta[3])/1350851717672992089 + CF*Log[x]*
        ((-49055500812174425729266446274970045588057*NM*NC)/
          4398550190499670228038015000 - (6394538027*lm*NM*NC)/124053930 - 
         (68725122355657003*NC*NL)/35763259371840 - (6394538027*lm*NC*NL)/
          124053930 - (57585917751545179761338411481276644358095363*NC*NH)/
          1863420737236854168432198219745987822500 - (6394538027*lm*NC*NH)/
          124053930 - (477561923529104*NM*NC*Pi^2)/243 - 
         (50422*NC*NL*Pi^2)/243 + (875260188432452283232*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CF*NC*(2064113800844924752943732513239386631585996581035300805881213/
            20294291638758110325894858947467183856308800000 + 
           (52171058970857949293*Pi^2)/1945944 + (6994664454071695630637425*
             Im[PolyLog[2, (-1)^(1/3)]])/(567591201966452009346*Sqrt[3]) - 
           (2584*Zeta[3])/3) + CA*NC*
          (-2064113800841371015041338517771047777346089644779134789494613/
            40588583277516220651789717894934367712617600000 + 
           (6394538027*lm)/22555260 - (17390352990302109875*Pi^2)/1297296 - 
           (6994664454071695630637425*Im[PolyLog[2, (-1)^(1/3)]])/
            (1135182403932904018692*Sqrt[3]) + (1292*Zeta[3])/3)), 
      (-226332950565081205415547886756271235433009368161899218790921981540660\
76749*CF^2*NC)/
        5861135632191102016522685195545777415489447645710287360000000 + 
       (601796430276490722164572555445141863028679396372762068581*CF*NM*NC)/
        2032532080284715155161102952972960652800000 - 
       (6241246398783139*CF*lm*NM*NC)/1351056465158400 - 
       (4189226638168681509916457*CF*NC*NL)/1655346806467235481600 - 
       (6241246398783139*CF*lm*NC*NL)/1351056465158400 - 
       (197816519249370366113461972639360586409767590899543719799343129*CF*NC*
         NH)/3489264890137813838431257838749253845293377112277877248000 - 
       (6241246398783139*CF*lm*NC*NH)/1351056465158400 + 
       (16062609026209309686969958451*CF^2*NC*Pi^2)/7108635555141120 - 
       (1594691745563432619427*CF*NM*NC*Pi^2)/16540524 - 
       (CF*lm*NM*NC*Pi^2)/54 + (10422972437*CF*NC*NL*Pi^2)/330810480 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (109630321828403941075019155*CF^2*NC*Pi^3)/(70056971214144933724992*
         Sqrt[3]) + (13253079629284919345075*CF*NC*NH*Pi^3)/
        (1801135623563989452*Sqrt[3]) + (12679*CF^2*NC*Pi^4)/1080 - 
       (7283649186176832862825342466793161*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(417255817702886518019366102400*
         Sqrt[3]) - (318289405262897586276516931*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(15324962453094204252342*Sqrt[3]) + 
       (9242*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (21926064365680788215003831*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(378394134644301339564*
         Sqrt[3]) + (1514637671918276496580*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) + 
       (21926064365680788215003831*CF^2*NC*Pi*Log[3]^2)/
        (18162918462926464299072*Sqrt[3]) + (378659417979569124145*CF*NC*NH*
         Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) + 
       ((53970567169558603068901620060050941*CF^2*NC)/
          1990425360268216872000 + CA*CF*
          (-53970567232201307262925816707432571/3980850720536433744000 - 
           (38731*lm)/3)*NC + CF*NC*((-225538337964791687154199059503/
              194944796406360 + (7042*lm)/3)*NM + ((79195 + 63378*lm)*NL)/
            27 + (7687281233717862001*NH)/7212957467035320 + 
           (7042*lm*NH)/3))*Log[x]^2 + 
       (CF*NC*(-274494747306158521061*CA + 24*(22874563129764044161*CF - 
            1531530*(815986076422618*NM + 3521*NL)))*Log[x]^3)/82702620 + 
       (1584028093016413923731054688713647*CF^2*NC*PolyGamma[2, 1])/
        4052555153018976267 - (84428232354556417*CF*NM*NC*PolyGamma[2, 1])/
        54 - (1013748547710638125679*CF*NC*NH*PolyGamma[2, 1])/
        8105110306037952534 + CA*CF*NC*(2263329506509373371635354813428580564\
4519330215018199336584197391943109749/
          11722271264382204033045370391091554830978895291420574720000000 - 
         (16062609026303367473682396923*Pi^2)/14217271110282240 - 
         (109630321828403941075019155*Pi^3)/(140113942428289867449984*
           Sqrt[3]) - (4237*Pi^4)/720 + 
         lm*(6241246398783139/245646630028800 + (11*Pi^2)/108) + 
         (7283649186176832862825342466793161*Im[PolyLog[2, (-1)^(1/3)]])/
          (834511635405773036038732204800*Sqrt[3]) - 
         (4621*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (21926064365680788215003831*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (756788269288602679128*Sqrt[3]) - (21926064365680788215003831*Pi*
           Log[3]^2)/(36325836925852928598144*Sqrt[3]) - 
         (1584028093016413923731054688713647*PolyGamma[2, 1])/
          8105110306037952534 - (2147276887131395352260734981419483493649*
           Zeta[3])/5516986483113913530843120) + 
       (2147276887128099463669156187891613140849*CF^2*NC*Zeta[3])/
        2758493241556956765421560 - (79532315896446977*CF*NM*NC*Zeta[3])/
        27 + (21128*CF*NC*NL*Zeta[3])/9 - (77879812923649035974543*CF*NC*NH*
         Zeta[3])/4052555153018976267 + CF*Log[x]*
        ((-1185102479313256318301840612456518028816831*NM*NC)/
          3518840152399736182430412000 + (1848066179*lm*NM*NC)/18378360 + 
         (494995289910359863*NC*NL)/135105646515840 + (1848066179*lm*NC*NL)/
          18378360 + (43680142600447685941797354846579120379981597003*NC*NH)/
          816327356568721074106777396106322345280800 + (1848066179*lm*NC*NH)/
          18378360 - (2447958229277243*NM*NC*Pi^2)/27 + 
         (3521*NC*NL*Pi^2)/9 - (1514637671918276496580*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CA*NC*(-68356440052266160987853621679277092536219788393091323954111/
            7379742414093858300325403253624430493203200000 - 
           (1848066179*lm)/3341520 - (548989496604138134639*Pi^2)/661620960 + 
           (21926064365680788215003831*Im[PolyLog[2, (-1)^(1/3)]])/
            (2270364807865808037384*Sqrt[3]) - 684*Zeta[3]) + 
         CF*NC*(14460016162741098941224500382130603604599381004493207012373/
            780549678413773474072879190287199379088800000 + 
           (548989496539429290439*Pi^2)/330810480 - 
           (21926064365680788215003831*Im[PolyLog[2, (-1)^(1/3)]])/
            (1135182403932904018692*Sqrt[3]) + 1368*Zeta[3])), 
      (-123103710942627266818508682988811030118049413303237345595376778529890\
245419247*CF^2*NC)/
        167042365517446407470896528073054656341449257902743189760000000 + 
       (75218725696525204880145215522410692628802320087442011251967*CF*NM*
         NC)/1291227183896258487722098844610443678256000000 + 
       (3260089878440858779*CF*lm*NM*NC)/1097395613824910400 + 
       (169098395753435446542542549*CF*NC*NL)/106710749488334287296000 + 
       (3260089878440858779*CF*lm*NC*NL)/1097395613824910400 + 
       (13423200680789319921164721453642065145156008682786957707850620389*CF*
         NC*NH)/
        327118583450420047352930422382742547996254104276050992000000 + 
       (3260089878440858779*CF*lm*NC*NH)/1097395613824910400 + 
       (59094353903738568786500962911059*CF^2*NC*Pi^2)/243865691961091200 - 
       (1484182912523111374898*CF*NM*NC*Pi^2)/69324255 + 
       (2*CF*lm*NM*NC*Pi^2)/243 - (90477045881*CF*NC*NL*Pi^2)/4714049340 + 
       (2*CF*lm*NC*NL*Pi^2)/243 + (2*CF*lm*NC*NH*Pi^2)/243 - 
       (291839319007475381018749055*CF^2*NC*Pi^3)/(249577959950391326395284*
         Sqrt[3]) - (6834100269089428798645*CF*NC*NH*Pi^3)/
        (1350851717672992089*Sqrt[3]) - (1580*CF^2*NC*Pi^4)/243 + 
       (414487715043381752344081732842189553*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(28243003160764131188435843056200*
         Sqrt[3]) + (698246629573099900698030326*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(114937218398206531892565*Sqrt[3]) - 
       (5312*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (233471455205980304814999244*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5392116418681294088787*
         Sqrt[3]) - (3124160123012310307952*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (58367863801495076203749811*CF^2*NC*Pi*Log[3]^2)/
        (64705397024175529065444*Sqrt[3]) - (195260007688269394247*CF*NC*NH*
         Pi*Log[3]^2)/(50031545098999707*Sqrt[3]) + 
       (CF*NC*(74*CA*(-20619460501667229399230145201226637251 + 
            114237920231300631313548000*lm) + 
          143*(21340420659223707208174062086923997471*CF - 
            271320*(23*(302134462464421204967365799561 + 1722398490799786800*
                 lm)*NM + 19*(210905189094600*(13037 + 9886*lm)*NL + 
                (906943740972469267 + 2085008699389215600*lm)*NH))))*
         Log[x]^2)/1049451771201417345762000 + 
       (CF*NC*(-178169510009582410366151*CA + 
          190*(1875468526140311864687*CF - 408408*(384591309735172*NM - 
              4943*NL)))*Log[x]^3)/392837445 + 
       (57025011348093949136423593154744587*CF^2*NC*PolyGamma[2, 1])/
        12157665459056928801 - (284945284196472004*CF*NM*NC*PolyGamma[2, 1])/
        243 + (13589510821687725782864*CF*NC*NH*PolyGamma[2, 1])/
        12157665459056928801 + CA*CF*NC*(860865111486967565911470344549909001\
502187076857149164519969490914134273479/
          2336256860383865838753797595427337850929360250388016640000000 - 
         (177283061711218328379421269325907*Pi^2)/1463194151766547200 + 
         (291839319007475381018749055*Pi^3)/(499155919900782652790568*
           Sqrt[3]) + (3958*Pi^4)/1215 + 
         lm*(-3260089878440858779/199526475240892800 - (11*Pi^2)/243) - 
         (414487715043381752344081732842189553*Im[PolyLog[2, (-1)^(1/3)]])/
          (56486006321528262376871686112400*Sqrt[3]) + 
         (2656*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (116735727602990152407499622*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (5392116418681294088787*Sqrt[3]) + (58367863801495076203749811*Pi*
           Log[3]^2)/(129410794048351058130888*Sqrt[3]) - 
         (57025011348093949136423593154744587*PolyGamma[2, 1])/
          24315330918113857602 - (350921763131243797855618729555534547316803*
           Zeta[3])/78617057384373267814514460) + 
       (350921763131237687563214244099886074776273*CF^2*NC*Zeta[3])/
        39308528692186633907257230 - (560660376956494040*CF*NM*NC*Zeta[3])/
        243 - (118640*CF*NC*NL*Zeta[3])/81 + 
       (213577346568930343960240*CF*NC*NH*Zeta[3])/12157665459056928801 + 
       CF*Log[x]*((-79176273641626687506806163010637693454434633*NM*NC)/
          785428070973136766371831635000 - (45160094201*lm*NM*NC)/
          785674890 - (65504208309383539079*NC*NL)/28878831942760800 - 
         (45160094201*lm*NC*NL)/785674890 - 
         (1125267001688934126295258129053151082658639810619*NC*NH)/
          30612275871327040279004152353987087948030000 - 
         (45160094201*lm*NC*NH)/785674890 - (170929470989036*NM*NC*Pi^2)/
          9 - (19772*NC*NL*Pi^2)/81 + (3124160123012310307952*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(50031545098999707*Sqrt[3]) + 
         CF*NC*
          (1008371031925363453572813883870096710097316757605219191100769463/
            1156774623409212288576006960005629479809601600000 + 
           (356339020013202087934601*Pi^2)/1571349780 + 
           (233471455205980304814999244*Im[PolyLog[2, (-1)^(1/3)]])/
            (16176349256043882266361*Sqrt[3]) - 960*Zeta[3]) + 
         CA*NC*
          (-1008371031925158352251153854365287774382877578731083826318215263/
            2313549246818424577152013920011258959619203200000 + 
           (45160094201*lm)/142849980 - (118779673337749414097617*Pi^2)/
            1047566520 - (116735727602990152407499622*
             Im[PolyLog[2, (-1)^(1/3)]])/(16176349256043882266361*Sqrt[3]) + 
           480*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["v", 2, 0, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-412*NM - 144*lm*NM + 216*lm^2*NM + 722*NL - 144*lm*NL + 
         216*lm^2*NL - 412*NH - 144*lm*NH + 216*lm^2*NH - 
         CA*(5021 + 2016*lm + 1188*lm^2 - 6021*Zeta[3]) + 
         18*CF*(194 + 162*lm - 285*Zeta[3]) + 567*NM*Zeta[3] + 
         567*NH*Zeta[3]))/7776, 
      -(CF*NC*(81*CF - 2*CA*(28 + 33*lm) + 5*NM + 12*lm*NM - 4*NL + 
          12*lm*NL - 13*NH + 12*lm*NH))/216, 
      (CF*NC*(77758*NM - 76416*lm*NM + 150912*NL - 76416*lm*NL - 
         388802*NH - 76416*lm*NH + 426195*NM*Zeta[3] + 
         426195*NH*Zeta[3] + 216*CF*(-406194 + 342605*Zeta[3]) + 
         12*CA*(-1226390 + 35024*lm + 971595*Zeta[3])))/11197440, 
      -(CF*NC*(-1392698*NM - 180096*lm*NM - 201984*NL - 180096*lm*NL + 
          375862*NH - 180096*lm*NH + 1140615*NM*Zeta[3] - 
          288225*NH*Zeta[3] + 216*CF*(-409434 + 342605*Zeta[3]) + 
          12*CA*(-1008486 + 82544*lm + 971595*Zeta[3])))/11197440, 
      (CF*NC*(-497773490*NM - 26004480*lm*NM - 92140032*NL - 
         26004480*lm*NL + 310340110*NH - 26004480*lm*NH + 
         325226475*NM*Zeta[3] - 274886325*NH*Zeta[3] + 
         8*CA*(-932955398 + 17878080*lm + 841542345*Zeta[3]) + 
         80*CF*(-1130846818 + 943072011*Zeta[3])))/3135283200, 
      -(CF*NC*(-908831830*NM + 8448000*lm*NM - 145282048*NL + 
          8448000*lm*NL + 948860550*NH + 8448000*lm*NH - 
          96*CA*(247489006 + 484000*lm - 212502465*Zeta[3]) + 
          561845025*NM*Zeta[3] - 837822825*NH*Zeta[3] + 
          320*CF*(-975835822 + 813567321*Zeta[3])))/6270566400, 
      (CF*NC*(-3201825003678*NM + 183735336960*lm*NM - 261416345600*NL + 
         183735336960*lm*NL + 4273510528322*NH + 183735336960*lm*NH - 
         2*CA*(77373035454466 + 505272176640*lm - 64611489154275*Zeta[3]) + 
         2154095866125*NM*Zeta[3] - 3721175143875*NH*Zeta[3] + 
         476*CF*(-5050310942066 + 4206401534475*Zeta[3])))/24580620288000, 
      -(CF*NC*(-1667126154736*NM + 119114096640*lm*NM + 8389775360*NL + 
          119114096640*lm*NL + 2119436272422*NH + 119114096640*lm*NH - 
          11*CA*(11012112601298 + 59557048320*lm - 9115622178075*Zeta[3]) + 
          1289473857000*NM*Zeta[3] - 1820009921625*NH*Zeta[3] + 
          14*CF*(-151746843754166 + 126307843362225*Zeta[3])))/
       12290310144000, (CF*NC*(CA*(-2177524520206086686 - 7451574836428800*
            lm + 1800929430656866125*Zeta[3]) + 
         2*(9*CF*(-2409989743593517906 + 2005257019899238875*Zeta[3]) + 
           5*(81920*(1420093651 + 1653847398*lm)*NL + 
             63*NH*(35866429604306 + 2150526648320*lm - 30442225534875*
                Zeta[3]) + 63*NM*(-38661780272122 + 2150526648320*lm + 
               32653488396375*Zeta[3])))))/146008884510720000, 
      -(CF*NC*(-4*CA*(800409648575585606 + 1527063345561600*lm - 
            662915804934623625*Zeta[3]) + 72*CF*(-999092827309336426 + 
            831177409018485375*Zeta[3]) + 
          5*(2621440*(125370757 + 84731409*lm)*NL + 
            63*NH*(60134994923206 + 3525687377920*lm - 50562486599625*Zeta[
                3]) + 315*NM*(-20865820488558 + 705137475584*lm + 
              18100609913925*Zeta[3]))))/146008884510720000, 
      (CF*NC*(-115067142861257000106*NM + 2064994680707481600*lm*NM + 
         4291919687258537984*NL + 2064994680707481600*lm*NL + 
         37988853472799447526*NH + 2064994680707481600*lm*NH - 
         121*CA*(95427611919095531378 + 93863394577612800*lm - 
           79159253811371390475*Zeta[3]) + 99523079195662497375*NM*Zeta[3] - 
         31704971602885205625*NH*Zeta[3] + 286*CF*(-1017623093029170046466 + 
           846550204246697487075*Zeta[3])))/367475160536580096000, 
      -(CF*NC*(-160842415138266574482*NM + 1404142936078417920*lm*NM + 
          3851545944784175104*NL + 1404142936078417920*lm*NL + 
          29163577078036118718*NH + 1404142936078417920*lm*NH - 
          121*CA*(133561898656256059162 + 63824678912655360*lm - 
            110921529695848755975*Zeta[3]) + 137591252286599986875*NM*
           Zeta[3] - 24198343277399416125*NH*Zeta[3] + 
          1430*CF*(-318090173388389857634 + 264613727372264739315*Zeta[3])))/
       367475160536580096000, 
      (CF*NC*(-16*CA*(104748724257257166912412498 + 22978978011916428902400*
            lm - 87057239704246812913587675*Zeta[3]) + 
         416*CF*(-126104241358068075778948582 + 104904494568281007937762425*
            Zeta[3]) + 7*(8388608*(4077155105769943 + 1138413566089800*lm)*
            NL + 1287*NH*(7420128319976243200*lm - 
             4719*(-38765822167353494 + 32021292881930625*Zeta[3])) + 
           2145*NM*(4452076991985745920*lm + 143*(-7917177869719742566 + 
               6703126499371527225*Zeta[3])))))/27822279354545552228352000, 
      -(CF*NC*(-64*CA*(351710764087739014196806234 + 33022010054516952268800*
             lm - 292437110878248417000294375*Zeta[3]) + 
          1664*CF*(-469070393042668265750398142 + 390216538445593814325496125*
             Zeta[3]) + 35*(8388608*(6292333381169197 + 1308768534653580*lm)*
             NL + 1287*NH*(267564005558847688262 + 8530494327850270720*lm - 
              220254649468532303625*Zeta[3]) + 15015*NM*
             (-451190759535875136790 + 731185228101451776*lm + 
              379190337424128655425*Zeta[3]))))/278222793545455522283520000, 
      (CF*NC*(-9*CA*(179507112952514349624926125478 + 
           6433949639711646086594560*lm - 149291757364419770641548032025*
            Zeta[3]) + 450*CF*(-137408176224830161557879322730 + 
           114309648451589584175887255551*Zeta[3]) + 
         91*(201326592*(4038582395216401 + 574665258907740*lm)*NL + 
           143*NH*(36321450623815383625742 + 809058728088761794560*lm - 
             29822367066174040483125*Zeta[3]) + 715*NM*
            (-276788501465816059546922 + 161811745617752358912*lm + 
             231542334723641656089375*Zeta[3]))))/
       15135319968872780412223488000, 
      -(CF*NC*(-3*CA*(499400563814296399789489307834 + 
            5234697645289610674176000*lm - 415395403098725435664775872375*
             Zeta[3]) + 2*(CF*(-31532728968954123402868996160978 + 
              26232139223978762146518618046875*Zeta[3]) + 
            65*(32*(1048576*(8584253069675903 + 654571245428100*lm)*NL + 
                5005*NH*(11585983554357109942 + 137136403245957120*lm - 
                  9495028755320533425*Zeta[3])) + 11*NM*(
                -12588995611339914930217814 + 1996706031261135667200*lm + 
                10502953224283828505822625*Zeta[3])))))/
       10810942834909128865873920000, 
      (CF*NC*(-13*CA*(68019986832642041924233580777329214 + 
           21782777272262152321970995200*lm - 
           56582259638602921872381407918368125*Zeta[3]) + 
         10*(187*CF*(-21815035282059986245639309395147158 + 
             18148019377839914629987576433402625*Zeta[3]) + 
           273*(1610612736*(2690674596884716193 + 11709548174013690*lm)*NL + 
             2431*NH*(11930749264753134174422162 + 7757938059182226800640*
                lm - 9764702930306957672914875*Zeta[3]) + 
             187*NM*(-22832617799711770629808942834 + 
               100853194769368948408320*lm + 19021571071607051949114988875*
                Zeta[3])))))/4986482516944826234611150356480000, 
      -(CF*NC*(CA*(-139604403729354483974260092252531122 + 
            433463259341009379917404569600*lm + 
            116133904692658308255943802424640875*Zeta[3]) + 
          5*(34*CF*(-41377837062996580240874762865120022 + 
              34422451933242105211734512444412225*Zeta[3]) - 
            273*(187*NM*(8040096446768942390424475922 + 
                308755956586023160381440*lm - 6693103087500547616850826875*
                 Zeta[3]) + 65*(1073741824*(-10291410672769525 + 
                  827263236641688*lm)*NL + 187*NH*(4750091639784971698176*
                   lm + 935*(-454222380355408932934 + 371433667766309853705*
                     Zeta[3])))))))/623310314618103279326393794560000, 
      (CF*NC*(20*CA*(-268409878320592030420219849729507108642 + 
           1004466855619604760407637743370240*lm + 
           223288639974029800540153989943166704275*Zeta[3]) + 
         152*CF*(-1937010076284107389400387038971919710482 + 
           1611410942274772435077933262297350538875*Zeta[3]) - 
         455*(8589934592*(-4944036991512022327171 + 934548109981582856760*lm)*
            NL + 323*NM*(607958714549976012604082077882274 + 
             24853582470027922799371223040*lm - 
             505918329748881973920627838081875*Zeta[3]) + 
           4199*NH*(-81252321503163324165966259798 + 
             1911814036155994061490094080*lm + 66407838640526675539596974625*
              Zeta[3]))))/19201282011915544220742669639352320000, 
      -(CF*NC*(456*CF*(-865164001663587872747236587935171802358 + 
            719735800732761896747589180574002308625*Zeta[3]) + 
          4*CA*(-1657581500860342574875756952799898727738 + 
            5570335774279426340995213138329600*lm + 
            1378945481877656634868512248795125368375*Zeta[3]) - 
          455*(8589934592*(-3025049157818339335183 + 1036519371583340725080*
               lm)*NL + 323*NM*(861976974093930311164334977548994 + 
              27565429118395790418845368320*lm - 
              717177100362573163074579038095875*Zeta[3]) + 
            4199*NH*(-58587063024465853358148041558 + 
              2120417624491983878372720640*lm + 47870348075038475756791646625*
               Zeta[3]))))/19201282011915544220742669639352320000, 
      (CF*NC*(4*CA*(-6156693814884887291883048462493934519681026 + 
           16675350713081190049170064547826892800*lm + 
           5121789215207153990443987573598627654971875*Zeta[3]) + 
         7*(8*CF*(-28294225497172572899028516063511901511263378 + 
             23538165371877941758345806915903645535186875*Zeta[3]) - 
           2145*(412316860416*(-3321795862146261943351 + 
               1958916154391420384160*lm)*NL + 323*NM*
              (2500601110206980755305497886720*lm + 323*
                (349143685014876883537314915631682 - 
                 290469678564955947414909244567875*Zeta[3])) + 
             4199*NH*(-3930969934754319592964745671522 + 
               192353931554383135023499837440*lm + 
               3211600721781097830320531269875*Zeta[3])))))/
       58295092188175592254174745025073643520000, 
      -(CF*NC*(136*CA*(-219648070293157436567656029355534341958606 + 
            455677324221797175349727983986278400*lm + 
            182726866192339834922005661519683081831125*Zeta[3]) + 
          5*(16*CF*(-25892828847850382434225008682180216141857962 + 
              21540430356616350226768362633772891075540575*Zeta[3]) - 
            3003*(274877906944*(-2536715186189083775039 + 
                2730036569263432408980*lm)*NL + 323*NM*(
                160816507961517778554199548348455954 + 
                2323302594550188186803833405440*lm - 
                133786611671035489989965623400794875*Zeta[3]) + 
              4199*NH*(178715584196168322061833338880*lm + 
                323*(-9000376323547118033542513574 + 
                  7353349267763231565225017625*Zeta[3]))))))/
       58295092188175592254174745025073643520000, 
      (CF*NC*(78*CA*(-1300669759478722616668312586420522230330748174 + 
           2014586337193512118925265274052542464000*lm + 
           1082037717912454783762939171406056031656915125*Zeta[3]) + 
         92*CF*(-82142760951565301532430865899139148425837719762 + 
           68335159744041707412757117783952443035597454875*Zeta[3]) - 
         385*(18141941858304*(-1603986271643339821877119 + 
             4090470803776525314018600*lm)*NL + 52003*NM*
            (1427015431709781208709857070284800*lm + 
             23*(6831588673611187185332407632624116866 - 
               5683266090143921747197411212740083875*Zeta[3])) + 
           7429*NH*(9989108021968468460968999491993600*lm + 
             7429*(-18283722280318239514618808599366 + 
               14938708822658214131114375423625*Zeta[3])))))/
       164469886760239404279778347297407772917760000, 
      -(CF*NC*(425*CA*(-38919675178224349112206515644033297867812918 + 
            44459692223656086828879222927614017536*lm + 
            32377600417623344015281437403079484386691825*Zeta[3]) + 
          7*(46*CF*(-4096668205750199001478874751507036584064394778 + 
              3408048238295455764525042274512767546090922375*Zeta[3]) - 
            15*(274877906944*(1393288089132127059684149 + 
                119031952699185208581979080*lm)*NL + 14858*NM*(
                394024158542465427650354628586976477762 + 
                2202130435954316959834330040893440*lm - 
                327791115766879281955308280757944471875*Zeta[3]) + 
              22287*NH*(1468086957302877973222886693928960*lm + 
                7429*(-2327990199131196418381525575586 + 
                  1902201473574322513156699009875*Zeta[3]))))))/
       22427711830941736947242501904191969034240000}, 0, 24, 1]
 
CbarSeries["v", 2, 1, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(CA*(427680*lm^2 - 238820*Pi^2 + 11664*Pi^4 - 
            2160*lm*(-835 + 44*Pi^2) - 15*(-92141 + 70560*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 62208*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 11760*PolyGamma[2, 1] - 97344*Zeta[3])) + 
          2*(CF*(-349920*lm^2 - 24236*Pi^2 + 2160*Pi^4 + 77760*lm*(-14 + 
                Pi^2) + 15*(-42661 + 70560*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 62208*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                11760*PolyGamma[2, 1] - 43968*Zeta[3])) + 
            60*(NL*(-1221 - 648*lm^2 + 68*Pi^2 + 36*lm*(-53 + 4*Pi^2) - 
                1728*Zeta[3]) + NM*(-1221 - 648*lm^2 + 68*Pi^2 + 
                36*lm*(-53 + 4*Pi^2) + 144*PolyGamma[2, 1] - 1440*Zeta[3]) + 
              3*NH*(-3239 - 216*lm^2 + 12*lm*(-53 + 4*Pi^2) - 6672*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 1112*PolyGamma[2, 1] + 
                14640*Zeta[3])))))/3732480, 
      (CF*NC*(-3*CA*(190080*lm^2 - 227020*Pi^2 + 8856*Pi^4 - 
           3840*lm*(-30 + 11*Pi^2) + 5*(-258855 - 402144*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 141696*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 70816*PolyGamma[2, 1] + 615776*Zeta[3])) + 
         2*(-1920*(NL*(-27*lm^2 + 6*lm*(3 + Pi^2) + 8*(24 + Pi^2 - 
                 9*Zeta[3])) + NM*(192 - 27*lm^2 + 8*Pi^2 + 6*lm*
                (3 + Pi^2) + 6*PolyGamma[2, 1] - 60*Zeta[3]) + 
             NH*(5787 - 27*lm^2 + 6*lm*(3 + Pi^2) - 3036*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 506*PolyGamma[2, 1] + 628*
                Zeta[3])) + CF*(466560*lm^2 + 93796*Pi^2 + 8136*Pi^4 - 
             25920*lm*(9 + 4*Pi^2) + 15*(118523 - 402144*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 141696*Im[PolyLog[2, 
                   (-1)^(1/3)]]^2 + 70816*PolyGamma[2, 1] + 497312*
                Zeta[3])))))/3732480, 
      (CF*NC*(CF*(-524880*lm^2 - 176500*Pi^2 + 17292*Pi^4 + 
           2160*lm*(111 + 10*Pi^2) + 15*(-140831 + 416640*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 133056*Im[PolyLog[2, (-1)^(1/3)]]^
               2 - 69016*PolyGamma[2, 1] - 617072*Zeta[3])) + 
         CA*(320760*lm^2 - 72860*Pi^2 - 6726*Pi^4 - 
           60*lm*(-3471 + 220*Pi^2) - 15*(99085 + 208320*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 66528*Im[PolyLog[2, (-1)^(1/3)]]^
               2 - 34508*PolyGamma[2, 1] - 343816*Zeta[3])) + 
         30*(NM*(20583 - 1944*lm^2 - 2188*Pi^2 + 4*lm*(303 + 20*Pi^2) - 
             784*PolyGamma[2, 1] - 2528*Zeta[3]) + 
           NL*(9855 + 1212*lm - 1944*lm^2 - 364*Pi^2 + 80*lm*Pi^2 - 
             960*Zeta[3]) + NH*(321063 + 1212*lm - 1944*lm^2 + 80*lm*Pi^2 - 
             189168*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             29304*PolyGamma[2, 1] + 68208*Zeta[3]))))/933120, 
      (CF*NC*(3732480*(9*CF*(17 + 6*lm) - CA*(76 + 33*lm) + 
           2*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         7464960*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         CA*(35925120*lm^2 - 18429660*Pi^2 + 3316600*Sqrt[3]*Pi^3 + 
           821664*Pi^4 - 207360*lm*(-435 + 11*Pi^2) + 2558520*Sqrt[3]*Pi*
            Log[3]^2 - 15*(2462967 + 17718144*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 10575360*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             8187264*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
             3563296*PolyGamma[2, 1] - 26674592*Zeta[3])) - 
         2160*Log[x]*(2*(-8*(9*NM*(-28 + 99*lm + 18*lm^2 + 18*Pi^2) + 9*NL*
                (188 + 99*lm + 18*lm^2 + 18*Pi^2) + NH*(28374 + 891*lm + 
                 162*lm^2 - 16072*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             CF*(-131469 - 66096*lm - 11664*lm^2 + 1194*Pi^2 + 18952*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 31104*Zeta[3])) + 
           CA*(197997 + 96552*lm + 14256*lm^2 + 1038*Pi^2 - 
             18952*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 31104*Zeta[3])) + 
         4*(CF*(14696640*lm^2 - 2470212*Pi^2 + 1658300*Sqrt[3]*Pi^3 + 
             244944*Pi^4 - 116640*lm*(-177 + 8*Pi^2) + 1279260*Sqrt[3]*Pi*
              Log[3]^2 + 15*(3462003 - 8859072*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 5287680*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
               4093632*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               1781648*PolyGamma[2, 1] + 10573792*Zeta[3])) - 
           160*(-(NH*(10206*lm^2 + 70315*Sqrt[3]*Pi^3 - 324*lm*
                 (-39 + 2*Pi^2) + 54243*Sqrt[3]*Pi*Log[3]^2 + 
                12*(-201960 + 38229*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                  216972*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                  4117*PolyGamma[2, 1] - 77678*Zeta[3]))) + 
             27*NL*(675 - 378*lm^2 - 277*Pi^2 + 12*lm*(-39 + 2*Pi^2) - 2232*
                Zeta[3]) + 27*NM*(-378*lm^2 - 121*Pi^2 + 12*lm*
                (-39 + 2*Pi^2) + 6*(789 - 17*PolyGamma[2, 1] + 
                 242*Zeta[3]))))))/16796160, 
      -(CF*NC*(16796160*(-2*CA*(76 + 33*lm) + CF*(299 + 108*lm) + 
            4*(4*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          67184640*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          2160*Log[x]*(2*(-8*(9*NM*(-713 + 870*lm + 162*lm^2 + 176*Pi^2) + 
                2*(9*NL*(815 + 435*lm + 81*lm^2 + 81*Pi^2) + 
                  NH*(110310 + 3915*lm + 729*lm^2 - 62416*Sqrt[3]*
                     Im[PolyLog[2, (-1)^(1/3)]]))) + CF*(-1429041 - 
                581256*lm - 104976*lm^2 + 3834*Pi^2 + 231656*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 279936*Zeta[3])) + 
            CA*(2034147 + 852336*lm + 128304*lm^2 + 3870*Pi^2 - 
              231656*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 279936*Zeta[3])) - 
          5*CA*(57736800*lm^2 - 6779052*Pi^2 + 8107960*Sqrt[3]*Pi^3 + 
            497016*Pi^4 - 3888*lm*(-35037 + 484*Pi^2) + 6254712*Sqrt[3]*Pi*
             Log[3]^2 + 3*(-83803005 - 164938656*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 86686848*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              100075392*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              33882992*PolyGamma[2, 1] + 270996928*Zeta[3])) + 
          2*(CF*(236196000*lm^2 + 38976876*Pi^2 + 40539800*Sqrt[3]*Pi^3 + 
              1116504*Pi^4 - 699840*lm*(-423 + 11*Pi^2) + 31273560*Sqrt[3]*Pi*
               Log[3]^2 - 15*(6223311 + 164938656*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 86686848*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                100075392*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                33882992*PolyGamma[2, 1] - 235211776*Zeta[3])) - 
            20*(-(NH*(-330457887 + 1312200*lm^2 + 8738240*Sqrt[3]*Pi^3 - 
                 972*lm*(-1467 + 44*Pi^2) + 109832688*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] + 323564544*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6740928*Sqrt[3]*Pi*
                  Log[3]^2 - 15423936*PolyGamma[2, 1] - 187145472*Zeta[3])) + 
              243*NL*(12293 - 5400*lm^2 - 4772*Pi^2 + 4*lm*(-1467 + 
                  44*Pi^2) - 33216*Zeta[3]) + 81*NM*(228879 - 16200*lm^2 - 
                2828*Pi^2 + 12*lm*(-1467 + 44*Pi^2) - 13128*PolyGamma[2, 1] + 
                68784*Zeta[3])))))/100776960, 
      (CF*NC*(-97977600*(5*CA*(5155 + 2376*lm) - 2*(5*CF*(5105 + 1944*lm) + 
             12*(280*NM + 90*lm*NM + 135*NL + 90*lm*NL + 4*NH + 90*lm*
                NH)))*Log[x]^2 + 70543872000*(13*CA + 46*CF - 
           2*(2*NM + NL))*Log[x]^3 - 175*CA*(785220480*lm^2 - 
           393612372*Pi^2 + 187266800*Sqrt[3]*Pi^3 + 26300376*Pi^4 - 
           1399680*lm*(-1517 + 22*Pi^2) + 144462960*Sqrt[3]*Pi*Log[3]^2 - 
           135*(28507709 + 50377408*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             32690304*Im[PolyLog[2, (-1)^(1/3)]]^2 - 51364608*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 11798944*
              PolyGamma[2, 1] - 76658720*Zeta[3])) - 60480*Log[x]*
          (2*(4*(-2025*NM*(133 + 218*lm + 36*lm^2 - 2*Pi^2) - 4050*NL*
                (252 + 109*lm + 18*lm^2 + 24*Pi^2) - NH*(15927519 + 
                 441450*lm + 72900*lm^2 - 8991800*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) + 25*CF*(-1524099 - 653184*lm - 104976*
                lm^2 + 22779*Pi^2 + 267524*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] - 279936*Zeta[3])) + 
           25*CA*(940248*lm + 128304*lm^2 + 1053*Pi^2 + 
             4*(568533 - 66881*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 69984*
                Zeta[3]))) + 2*(25*CF*(4497171840*lm^2 - 1818316188*Pi^2 + 
             1310867600*Sqrt[3]*Pi^3 + 152749800*Pi^4 - 44089920*lm*
              (-163 + 4*Pi^2) + 1011240720*Sqrt[3]*Pi*Log[3]^2 - 
             945*(7477337 + 50377408*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               32690304*Im[PolyLog[2, (-1)^(1/3)]]^2 - 51364608*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 11798944*
                PolyGamma[2, 1] - 62181536*Zeta[3])) - 
           448*(-(NH*(-10913120577 + 27884250*lm^2 + 393391250*Sqrt[3]*
                 Pi^3 - 546750*lm*(-73 + 2*Pi^2) + 939240000*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 14566716000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 303473250*Sqrt[3]*Pi*
                 Log[3]^2 - 26004000*PolyGamma[2, 1] - 4539732000*Zeta[3])) + 
             91125*NM*(7127 - 306*lm^2 - 94*Pi^2 + 6*lm*(-73 + 2*Pi^2) - 128*
                PolyGamma[2, 1] + 8096*Zeta[3]) + 182250*NL*(-153*lm^2 + 3*
                lm*(-73 + 2*Pi^2) - 8*(-77 + 25*Pi^2 + 225*Zeta[3]))))))/
       17635968000, -(CF*NC*(-16329600*(5*CA*(27851 + 13530*lm) - 
            6*(5*CF*(8683 + 3690*lm) + 6490*NM + 2050*lm*NM + 3100*NL + 
              2050*lm*NL + 108*NH + 2050*lm*NH))*Log[x]^2 + 
          1632960000*(595*CA + 1744*CF - 182*NM - 82*NL)*Log[x]^3 + 
          11340*Log[x]*(2*(8*(150*NM*(169 + 7002*lm + 1215*lm^2 - 
                  600*Pi^2) + 75*NL*(33115 + 14004*lm + 2430*lm^2 + 
                  3270*Pi^2) + NH*(36228357 + 1050300*lm + 182250*lm^2 - 
                  20430400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
              25*CF*(-9255801 - 3112344*lm - 524880*lm^2 + 151350*Pi^2 + 
                1602808*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1399680*
                 Zeta[3])) + 25*CA*(-12722367 - 4513536*lm - 641520*lm^2 + 
              86670*Pi^2 + 1602808*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              1399680*Zeta[3])) - 175*CA*(666860040*lm^2 - 147065706*Pi^2 + 
            210368550*Sqrt[3]*Pi^3 + 16637724*Pi^4 - 160380*lm*
             (-10717 + 100*Pi^2) + 162284310*Sqrt[3]*Pi*Log[3]^2 + 
            5*(-1392223077 - 1370381496*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              768844224*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1557929376*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 310714132*PolyGamma[2, 
                1] + 2402280008*Zeta[3])) + 
          2*(50*CF*(1909644660*lm^2 - 177915123*Pi^2 + 736289925*Sqrt[3]*Pi^
                3 + 50067234*Pi^4 - 918540*lm*(-3059 + 50*Pi^2) + 
              567995085*Sqrt[3]*Pi*Log[3]^2 - 35*(450421893 + 685190748*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 384422112*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 778964688*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 155357066*
                 PolyGamma[2, 1] - 1068240388*Zeta[3])) - 
            7*(-(NH*(-649075063419 + 1515591000*lm^2 + 21451920000*Sqrt[3]*
                  Pi^3 - 9112500*lm*(-217 + 4*Pi^2) + 138352350000*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] + 794333952000*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 16548624000*Sqrt[3]*
                  Pi*Log[3]^2 - 18772688000*PolyGamma[2, 1] - 364778896000*
                  Zeta[3])) + 10125*NL*(807823 - 149688*lm^2 - 210828*Pi^2 + 
                900*lm*(-217 + 4*Pi^2) - 1926720*Zeta[3]) + 10125*NM*(
                4218679 - 149688*lm^2 + 30420*Pi^2 + 900*lm*(-217 + 4*Pi^2) - 
                114840*PolyGamma[2, 1] + 4703760*Zeta[3])))))/13226976000, 
      (CF*NC*(-517359053476125*CF + 99558713520000*CF*lm + 
         60275329632000*CF*lm^2 - 358026296292000*NM + 
         9945869472000*lm*NM + 6697258848000*lm^2*NM - 62506082268000*NL + 
         9945869472000*lm*NL + 6697258848000*lm^2*NL - 
         4079687321210976*NH + 9945869472000*lm*NH + 6697258848000*lm^2*
          NH - 48022812306000*CF*Pi^2 - 1728324864000*CF*lm*Pi^2 - 
         13658567328000*NM*Pi^2 - 192036096000*lm*NM*Pi^2 + 
         12314314656000*NL*Pi^2 - 192036096000*lm*NL*Pi^2 - 
         192036096000*lm*NH*Pi^2 + 32105547740000*Sqrt[3]*CF*Pi^3 + 
         158159248240000*Sqrt[3]*NH*Pi^3 + 3191399870400*CF*Pi^4 - 
         785847497568000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         143582280576000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         507263347584000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         1188822567744000*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         5856411020544000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         24767136828000*Sqrt[3]*CF*Pi*Log[3]^2 + 122008562928000*Sqrt[3]*NH*
          Pi*Log[3]^2 - 171460800*(105*CA*(66775 + 32384*lm) - 
           8*(35*CF*(49393 + 19872*lm) + 70*(1927 + 1104*lm)*NM + 
             109760*NL + 77280*lm*NL + 7047*NH + 77280*lm*NH))*Log[x]^2 + 
         48009024000*(10841*CA + 42828*CF - 8712*NM - 1472*NL)*Log[x]^3 + 
         199086488440000*CF*PolyGamma[2, 1] - 34842549168000*NM*
          PolyGamma[2, 1] + 20010208400000*NH*PolyGamma[2, 1] - 
         4900*CA*(7517331360*lm^2 - 5389663212*Pi^2 + 3276076300*Sqrt[3]*
            Pi^3 + 357005880*Pi^4 - 816480*lm*(-25391 + 264*Pi^2) + 
           2527258860*Sqrt[3]*Pi*Log[3]^2 - 35*(2380843791 + 
             2291100576*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             1478901888*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3465955008*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 580427080*
              PolyGamma[2, 1] - 3603412400*Zeta[3])) + 
         15120*Log[x]*(-16*(-66150*NM*(13190 + 5154*lm + 810*lm^2 - 4977*
                Pi^2) - 33075*NL*(28603 + 10308*lm + 1620*lm^2 + 2748*
                Pi^2) - 4*NH*(3579483066 + 85234275*lm + 13395375*lm^2 - 
               2017337350*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
           1225*CF*(-110157753 - 41127264*lm - 6298560*lm^2 + 2416392*Pi^2 + 
             21394784*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             16796160*Zeta[3]) + 1225*CA*(-80470851 - 29390688*lm - 
             3849120*lm^2 + 496584*Pi^2 + 10697392*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 8398080*Zeta[3])) + 1008935778704000*CF*
          Zeta[3] - 397202660064000*NM*Zeta[3] + 134233231104000*NL*
          Zeta[3] - 1681199111648000*NH*Zeta[3]))/1944365472000, 
      (91967891621*CF^2*NC)/167961600 - (255851*CF^2*lm*NC)/5184 - 
       (513*CF^2*lm^2*NC)/16 + (4196773849*CF*NM*NC)/17496000 - 
       (228149*CF*lm*NM*NC)/46656 - (57*CF*lm^2*NM*NC)/16 + 
       (7613743*CF*NC*NL)/186624 - (228149*CF*lm*NC*NL)/46656 - 
       (57*CF*lm^2*NC*NL)/16 + (42674595222437*CF*NC*NH)/18003384000 - 
       (228149*CF*lm*NC*NH)/46656 - (57*CF*lm^2*NC*NH)/16 + 
       (36192409*CF^2*NC*Pi^2)/1088640 + (131*CF^2*lm*NC*Pi^2)/216 + 
       (142031*CF*NM*NC*Pi^2)/23328 + (131*CF*lm*NM*NC*Pi^2)/1944 - 
       (158129*CF*NC*NL*Pi^2)/23328 + (131*CF*lm*NC*NL*Pi^2)/1944 + 
       (131*CF*lm*NC*NH*Pi^2)/1944 - (39826465*CF^2*NC*Pi^3)/
        (629856*Sqrt[3]) - (80296895*CF*NC*NH*Pi^3)/(314928*Sqrt[3]) - 
       (4771*CF^2*NC*Pi^4)/3240 + (313468153*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(209952*Sqrt[3]) - 
       (54614827*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(52488*Sqrt[3]) - 
       (2470*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (1137899*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (486*Sqrt[3]) - (2294197*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(243*Sqrt[3]) - 
       (1137899*CF^2*NC*Pi*Log[3]^2)/(23328*Sqrt[3]) - 
       (2294197*CF*NC*NH*Pi*Log[3]^2)/(11664*Sqrt[3]) - 
       (CF*NC*(-105*CA*(711985 + 438196*lm) + 
          2*(35*CF*(1916237 + 1075572*lm) + 28*(395371 + 149385*lm)*NM + 
            6024585*NL + 4182780*lm*NL + 425736*NH + 4182780*lm*NH))*
         Log[x]^2)/136080 - (CF*NC*(181521*CA + 497269*CF - 
          2*(62110*NM + 9959*NL))*Log[x]^3)/486 - 
       (512761793*CF^2*NC*PolyGamma[2, 1])/5668704 + 
       (18527*CF*NM*NC*PolyGamma[2, 1])/972 + 
       (135524341*CF*NC*NH*PolyGamma[2, 1])/2834352 + 
       (CF*NC*Log[x]*(2*(-11041239825*NL - 3854207700*lm*NL - 
            642978000*lm^2*NL - 159669355536*NH - 3854207700*lm*NH - 
            642978000*lm^2*NH - 1092709800*NL*Pi^2 - 
            294*NM*(37973077 + 13109550*lm + 2187000*lm^2 - 15494100*Pi^2) + 
            89932522400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            490*CF*(-247666413 - 72759870*lm - 11809800*lm^2 + 9460890*Pi^2 + 
              45515960*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 31492800*Zeta[
                3])) - 245*CA*(-665148891 - 209787660*lm - 28868400*lm^2 + 
            15943140*Pi^2 + 91031920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            62985600*Zeta[3])))/171460800 - (2346854351*CF^2*NC*Zeta[3])/
        2834352 + (116891*CF*NM*NC*Zeta[3])/486 - (6260*CF*NC*NL*Zeta[3])/
        81 + (1795725613*CF*NC*NH*Zeta[3])/1417176 + 
       (CA*CF*NC*(22214233800*lm^2 - 20625906825*Pi^2 + 11947939500*Sqrt[3]*
           Pi^3 + 895853520*Pi^4 - 12150*lm*(-4836607 + 34584*Pi^2) + 
          9216981900*Sqrt[3]*Pi*Log[3]^2 + 4*(-99562882131 - 
            70530334425*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            38893608000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 110603782800*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 12819044825*
             PolyGamma[2, 1] + 130548260950*Zeta[3])))/1133740800, 
      (CF*NC*(-6172588800*(7*CA*(21790603 + 12392160*lm) - 
           2*(7*CF*(21339223 + 10139040*lm) + 40*(-1560727*NM + 197148*lm*
                NM + 271306*NL + 197148*lm*NL + 26310*NH + 197148*lm*
                NH)))*Log[x]^2 + 1152216576000*(491703*CA + 1927994*CF - 
           835704*NM - 56328*NL)*Log[x]^3 + 15120*Log[x]*
          (2*(-160*(-11907*NM*(4846327 + 1062300*lm + 162000*lm^2 - 
                 3906000*Pi^2) - 4*(59535*NL*(173147 + 53115*lm + 
                   8100*lm^2 + 16782*Pi^2) + NH*(153916586133 + 3162201525*
                    lm + 482233500*lm^2 - 86690623600*Sqrt[3]*Im[PolyLog[2, 
                      (-1)^(1/3)]]))) - 49*CF*(-1140124926981 - 381167856000*
                lm - 56687040000*lm^2 + 51301819800*Pi^2 + 237958666400*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 151165440000*Zeta[3])) + 
           49*CA*(-1633592154981 - 542504304000*lm - 69284160000*lm^2 + 
             37367616600*Pi^2 + 237958666400*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 151165440000*Zeta[3])) - 
         49*CA*(427760403840000*lm^2 - 684162236808000*Pi^2 + 
           291499366340000*Sqrt[3]*Pi^3 + 26768092680000*Pi^4 - 
           1469664000*lm*(-808031 + 6600*Pi^2) + 224870939748000*Sqrt[3]*Pi*
            Log[3]^2 + 7*(-1073747360121417 - 805759054872000*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 499412822400000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 1541972158272000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 167182166816000*
              PolyGamma[2, 1] + 1304497308256000*Zeta[3])) + 
         2*(-320*(4*(-(NH*(-1322407246619421 + 1488654814500*lm^2 + 
                  53098006955000*Sqrt[3]*Pi^3 - 56260575*lm*(-39781 + 
                    600*Pi^2) + 4353295220400*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]] + 1966143343248000*Sqrt[3]*Im[PolyLog[3, 
                     -((-1)^(5/6)/Sqrt[3])]] + 40961319651000*Sqrt[3]*Pi*
                   Log[3]^2 + 11318855802800*PolyGamma[2, 1] - 
                  531290407306400*Zeta[3])) + 18753525*NL*(1388927 - 
                 79380*lm^2 - 187020*Pi^2 + 3*lm*(-39781 + 600*Pi^2) - 
                 2438208*Zeta[3])) + 2250423*NM*(165778861 - 2646000*lm^2 + 
               63530400*Pi^2 + 100*lm*(-39781 + 600*Pi^2) + 119438400*
                PolyGamma[2, 1] + 292012800*Zeta[3])) + 
           49*CF*(349985784960000*lm^2 - 686264276232000*Pi^2 + 
             291499366340000*Sqrt[3]*Pi^3 + 25357215240000*Pi^4 - 
             13226976000*lm*(-44191 + 600*Pi^2) + 224870939748000*Sqrt[3]*Pi*
              Log[3]^2 + 7*(-785038800111417 - 805759054872000*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 499412822400000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 + 1541972158272000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 167182166816000*
                PolyGamma[2, 1] + 1070384871904000*Zeta[3])))))/
       559977255936000, (536548978547391727*CF^2*NC)/466647713280000 - 
       (4048343*CF^2*lm*NC)/43200 - (957*CF^2*lm^2*NC)/16 + 
       (1224886694191*CF*NM*NC)/2000376000 - (3617693*CF*lm*NM*NC)/388800 - 
       (319*CF*lm^2*NM*NC)/48 + (208846991*CF*NC*NL)/1555200 - 
       (3617693*CF*lm*NC*NL)/388800 - (319*CF*lm^2*NC*NL)/48 + 
       (582995182576189*CF*NC*NH)/91142131500 - (3617693*CF*lm*NC*NH)/
        388800 - (319*CF*lm^2*NC*NH)/48 + (1769029789*CF^2*NC*Pi^2)/
        5443200 + (67*CF^2*lm*NC*Pi^2)/72 + (4554491*CF*NM*NC*Pi^2)/38880 + 
       (67*CF*lm*NM*NC*Pi^2)/648 - (68453*CF*NC*NL*Pi^2)/4320 + 
       (67*CF*lm*NC*NL*Pi^2)/648 + (67*CF*lm*NC*NH*Pi^2)/648 - 
       (36105988499*CF^2*NC*Pi^3)/(204073344*Sqrt[3]) - 
       (18312195965*CF*NC*NH*Pi^3)/(25509168*Sqrt[3]) - 
       (60541*CF^2*NC*Pi^4)/15552 + (2921143064983*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(850305600*Sqrt[3]) - 
       (8350760057*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(4251528*Sqrt[3]) - 
       (21667*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (5157998357*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (787320*Sqrt[3]) - (523205599*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (5157998357*CF^2*NC*Pi*Log[3]^2)/(37791360*Sqrt[3]) - 
       (523205599*CF*NC*NH*Pi*Log[3]^2)/(944784*Sqrt[3]) - 
       (CF*NC*(-11*CA*(17011523 + 61582500*lm) + 
          CF*(120948377 + 1108485000*lm) + 30*(60*(-273888 + 68425*lm)*NM + 
            5746685*NL + 4105500*lm*NL + 589584*NH + 4105500*lm*NH))*
         Log[x]^2)/680400 - (CF*NC*(3885749*CA + 7052505*CF - 4219020*NM - 
          293250*NL)*Log[x]^3)/2430 + (26226492271*CF^2*NC*PolyGamma[2, 1])/
        153055008 + (31465*CF*NM*NC*PolyGamma[2, 1])/108 + 
       (7384843183*CF*NC*NH*PolyGamma[2, 1])/76527504 - 
       (167287242823*CF^2*NC*Zeta[3])/95659380 + (43645*CF*NM*NC*Zeta[3])/
        54 - (5866*CF*NC*NL*Zeta[3])/27 + (124567819879*CF*NC*NH*Zeta[3])/
        38263752 + (CA*CF*NC*(-1233646368316107129 + 61405005971232000*lm^2 - 
          275234118505375680*Pi^2 + 49537416220628000*Sqrt[3]*Pi^3 + 
          3408785931297600*Pi^4 - 1592219280960*lm*(-103079 + 600*Pi^2) - 
          961873988437602240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          505542800181888000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          1834299754912396800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          38214578227341600*Sqrt[3]*Pi*Log[3]^2 - 143930989583248000*
           PolyGamma[2, 1] + 1642451736399846400*Zeta[3]))/1679931767808000 - 
       (CF*NC*Log[x]*(-80*(-1458*NM*(4724400217 + 512325870*lm + 
              83349000*lm^2 - 1989189300*Pi^2) - 535815*NL*
             (4698613 + 1394084*lm + 226800*lm^2 + 466600*Pi^2) - 
            4*NH*(9105815611623 + 186742779615*lm + 30380710500*lm^2 - 
              5127414870200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          CA*(-1238861917727403 - 396720083642400*lm - 53470050480000*lm^2 + 
            103209964111800*Pi^2 + 202193535594400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 116661928320000*Zeta[3]) + 
          CF*(1812533543995602 + 552401946331200*lm + 87496446240000*lm^2 - 
            218707666455600*Pi^2 - 404387071188800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 233323856640000*Zeta[3])))/
        555532992000, 
      (CF*NC*(-1120324867200*(11*CA*(806520611 + 1111017600*lm) - 
           20*(11*CF*(75429289 + 90901440*lm) + 72*(132*(-543517 + 11690*lm)*
                NM + 2310*(901 + 668*lm)*NL + (262327 + 1543080*lm)*NH)))*
          Log[x]^2 + 6901201181952000*(2899777*CA + 8541668*CF - 
           1440*(6417*NM + 167*NL))*Log[x]^3 + 166320*Log[x]*
          (4*(-40*(-194500845*NL*(950237 + 252924*lm + 37800*lm^2 + 
                 92760*Pi^2) + 793881*NM*(227592373 - 61966380*lm - 
                 9261000*lm^2 + 742614600*Pi^2) - NH*(2746123610572569 + 
                 49193931720780*lm + 7352131941000*lm^2 - 1546614232671200*
                  Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
             1089*CF*(-50333658396549 - 16667532907200*lm - 2430456840000*
                lm^2 + 6299491224600*Pi^2 + 12066036791200*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 6481218240000*Zeta[3])) + 
           1089*CA*(-145491658800501 - 47314093377600*lm - 5941116720000*
              lm^2 + 11280472711200*Pi^2 + 24132073582400*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 12962436480000*Zeta[3])) - 
         1331*CA*(-4490148170081290653 + 273338898053760000*lm^2 - 
           1492335030379107600*Pi^2 + 266056111245960000*Sqrt[3]*Pi^3 + 
           21364039684512000*Pi^4 - 777746188800*lm*(-977819 + 6600*Pi^2) - 
           4420056639067372800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           2588494865564160000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           9851677719278976000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                Sqrt[3])]] + 205243285818312000*Sqrt[3]*Pi*Log[3]^2 - 
           519305410846880000*PolyGamma[2, 1] + 6452619728929472000*
            Zeta[3]) + 4*(1331*CF*(-1479685451076646173 + 111820458294720000*
              lm^2 - 754971913569610800*Pi^2 + 133028055622980000*Sqrt[3]*
              Pi^3 + 10308701671632000*Pi^4 - 6999715699200*lm*
              (-26777 + 300*Pi^2) - 2210028319533686400*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 1294247432782080000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 4925838859639488000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 102621642909156000*
              Sqrt[3]*Pi*Log[3]^2 - 259652705423440000*PolyGamma[2, 1] + 
             2576065441491136000*Zeta[3]) - 
           160*(269578171170*NL*(10924411 - 383400*lm^2 - 1099020*Pi^2 + 12*
                lm*(-48229 + 600*Pi^2) - 16783200*Zeta[3]) + 
             4715653140*NM*(-21917700*lm^2 + 686*lm*(-48229 + 600*Pi^2) + 5*
                (-949050133 + 683908386*Pi^2 + 1232056000*PolyGamma[2, 1] + 
                 1365880880*Zeta[3])) - NH*(103356270826578000*lm^2 + 
               5210156696311105000*Sqrt[3]*Pi^3 - 3234938054040*lm*
                (-48229 + 600*Pi^2) + 4019263737154281000*Sqrt[3]*Pi*
                Log[3]^2 - 3*(42361784680243623879 + 829930864079548000*
                  Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 64308219794468496000*
                  Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                 450679789493934000*PolyGamma[2, 1] + 16558248086276820000*
                  Zeta[3]))))))/5589972957381120000, 
      (-5999694031750213147*CF^2*NC)/2099914709760000 - 
       (1363523*CF^2*lm*NC)/8640 - (1599*CF^2*lm^2*NC)/16 - 
       (124696999035079*CF*NM*NC)/108020304000 - (1219613*CF*lm*NM*NC)/
        77760 - (533*CF*lm^2*NM*NC)/48 + (1637765129*CF*NC*NL)/4665600 - 
       (1219613*CF*lm*NC*NL)/77760 - (533*CF*lm^2*NC*NL)/48 + 
       (102471844507921035527*CF*NC*NH)/6987466196726400 - 
       (1219613*CF*lm*NC*NH)/77760 - (533*CF*lm^2*NC*NH)/48 + 
       (94146054329*CF^2*NC*Pi^2)/32659200 + (95*CF^2*lm*NC*Pi^2)/72 + 
       (8863727*CF*NM*NC*Pi^2)/7776 + (95*CF*lm*NM*NC*Pi^2)/648 - 
       (246865*CF*NC*NL*Pi^2)/7776 + (95*CF*lm*NC*NL*Pi^2)/648 + 
       (95*CF*lm*NC*NH*Pi^2)/648 - (754401002621*CF^2*NC*Pi^3)/
        (1836660096*Sqrt[3]) - (388045492625*CF*NC*NH*Pi^3)/
        (229582512*Sqrt[3]) - (652769*CF^2*NC*Pi^4)/77760 + 
       (53635840311967*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (7652750400*Sqrt[3]) - (118524259553*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(38263752*Sqrt[3]) - 
       (41587*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (107771571803*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7085880*Sqrt[3]) - (11087014075*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (107771571803*CF^2*NC*Pi*Log[3]^2)/(340122240*Sqrt[3]) - 
       (11087014075*CF*NC*NH*Pi*Log[3]^2)/(8503056*Sqrt[3]) - 
       (CF*NC*(-99*CA*(-3596470057 + 727958000*lm) + 
          2*(11*CF*(-33697376443 + 5360418000*lm) + 
            20*(22*(-412211981 + 14890050*lm)*NM + 5*(693*(129897 + 
                  94540*lm)*NL + 2*(5858561 + 32758110*lm)*NH))))*Log[x]^2)/
        29937600 - (CF*NC*(38487621*CA + 5174288*CF - 
          60*(770438*NM + 23635*NL))*Log[x]^3)/4860 + 
       (5968802159057*CF^2*NC*PolyGamma[2, 1])/1377495072 + 
       (139613*CF*NM*NC*PolyGamma[2, 1])/48 + 
       (59610141349*CF*NC*NH*PolyGamma[2, 1])/344373768 - 
       (10796942105*CF^2*NC*Zeta[3])/344373768 + (93517*CF*NM*NC*Zeta[3])/
        24 - (4585*CF*NC*NL*Zeta[3])/9 + (1230895476529*CF*NC*NH*Zeta[3])/
        172186884 + CF*Log[x]*((-100253922337*NM*NC)/21432600 - 
         (141857*lm*NM*NC)/648 - 35*lm^2*NM*NC - (11008019*NC*NL)/12960 - 
         (141857*lm*NC*NL)/648 - 35*lm^2*NC*NL - (3112511535385489*NC*NH)/
          252073095120 - (141857*lm*NC*NH)/648 - 35*lm^2*NC*NH + 
         (766723*NM*NC*Pi^2)/324 - (27415*NC*NL*Pi^2)/324 + 
         (11087014075*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(75146066175721/208324872000 - (145637*lm)/72 - 315*lm^2 + 
           (22985771*Pi^2)/7776 + (107771571803*Im[PolyLog[2, (-1)^(1/3)]])/
            (21257640*Sqrt[3]) - 840*Zeta[3]) + 
         CA*NC*(890329241086813/833299488000 + (1877947*lm)/1296 + 
           (385*lm^2)/2 - (2511631*Pi^2)/1728 - 
           (107771571803*Im[PolyLog[2, (-1)^(1/3)]])/(42515280*Sqrt[3]) + 
           420*Zeta[3])) + (CA*CF*NC*(288557811171630000*lm^2 - 
          6809741514086919975*Pi^2 + 323449429873753750*Sqrt[3]*Pi^3 + 
          20385730171894500*Pi^4 - 30380710500*lm*(-25504183 + 125400*Pi^2) + 
          249518131616895750*Sqrt[3]*Pi*Log[3]^2 + 
          4*(1333521063112971339 - 1379781992025351075*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 682259008084290000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 2994217579402749000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 2559123925695688750*
             PolyGamma[2, 1] + 261957388946575000*Zeta[3])))/
        4724808096960000, 
      (CF*NC*(-3408028246022400*(1573*CA*(-2055262717 + 668556000*lm) - 
           48*(143*CF*(-959417371 + 250708500*lm) + 
             5*(1716*(-94236337 + 464275*lm)*NM + 70070*(15127 + 11370*lm)*
                NL + (160405811 + 796695900*lm)*NH)))*Log[x]^2 + 
         545829803882947584000*(18235392*CA + 17368133*CF - 94300380*NM - 
           795900*NL)*Log[x]^3 + 2162160*Log[x]*
          (2*(-160*(2012488335*NM*(18294496403 - 211237236*lm - 
                 31116960*lm^2 + 9216000360*Pi^2) - 2*(118334314098*NL*
                  (7654994 + 1796235*lm + 264600*lm^2 + 751450*Pi^2) + 
                 NH*(13457472648831872691 + 212556236683821030*lm + 
                   31311259510330800*lm^2 - 7580949356150170000*Sqrt[3]*
                    Im[PolyLog[2, (-1)^(1/3)]]))) - 20449*CF*
              (-47084063290464363 - 30671004264969600*lm - 4409820890496000*
                lm^2 + 39898689850920600*Pi^2 + 25157474684692000*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 11759522374656000*Zeta[3])) + 
           102245*CA*(-17953794983252757 - 8689641505534080*lm - 
             1077956217676800*lm^2 + 7715963961420120*Pi^2 + 
             5031494936938400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             2351904474931200*Zeta[3])) - 2924207*CA*(742349700236879719389 + 
           23526394450796160000*lm^2 - 563606289974158704000*Pi^2 + 
           30817906488747700000*Sqrt[3]*Pi^3 + 2211739542877032000*Pi^4 - 
           1166619283200*lm*(-56129611 + 323400*Pi^2) - 461346508133940072000*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 253454455681257600000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 1141143051697629120000*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 23773813577033940000*
            Sqrt[3]*Pi*Log[3]^2 - 812131666455420640000*PolyGamma[2, 1] + 
           5297483266228384000*Zeta[3]) + 
         2*(265837*CF*(211737550057165440000*lm^2 - 6230230113347589132000*
              Pi^2 + 338996971376224700000*Sqrt[3]*Pi^3 + 
             23725479489748344000*Pi^4 - 115495309036800*lm*(-3074951 + 29400*
                Pi^2) + 261511949347373340000*Sqrt[3]*Pi*Log[3]^2 - 
             11*(-899623004120683555131 + 461346508133940072000*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 253454455681257600000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 1141143051697629120000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 812131666455420640000*
                PolyGamma[2, 1] + 132672512937562976000*Zeta[3])) - 
           320*(-5*NH*(-6387539935488279466824459 + 3908866326010186741200*
                lm^2 + 265598560692721205950000*Sqrt[3]*Pi^3 - 
               2132147671417764*lm*(-2769401 + 29400*Pi^2) - 
               238788021053096368613760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               9834735275936190940320000*Sqrt[3]*Im[PolyLog[3, 
                  -((-1)^(5/6)/Sqrt[3])]] + 204890318248670644590000*Sqrt[3]*
                Pi*Log[3]^2 + 76155154073306289581600*PolyGamma[2, 1] - 
               2432395087979326067998400*Zeta[3]) + 3453429982860*NM*
              (-12734213214043 - 5659397100*lm^2 + 5062974067620*Pi^2 + 3087*
                lm*(-2769401 + 29400*Pi^2) + 9552867823800*PolyGamma[2, 1] + 
               9358570191600*Zeta[3]) + 2132147671417764*NL*
              (-9166500*lm^2 + 5*lm*(-2769401 + 29400*Pi^2) - 7*(-55421163 + 
                 4417100*Pi^2 + 77544000*Zeta[3]))))))/
       663183211717781314560000, (-7013797359580211947235063*CF^2*NC)/
        117389432105003520000 - (1556865523*CF^2*lm*NC)/6350400 - 
       (2475*CF^2*lm^2*NC)/16 - (10548789116362584971*CF*NM*NC)/
        431325073872000 - (1393144273*CF*lm*NM*NC)/57153600 - 
       (275*CF*lm^2*NM*NC)/16 + (2690994500669*CF*NC*NL)/3429216000 - 
       (1393144273*CF*lm*NC*NL)/57153600 - (275*CF*lm^2*NC*NL)/16 + 
       (125295475069515359989889*CF*NC*NH)/4186762700238518400 - 
       (1393144273*CF*lm*NC*NH)/57153600 - (275*CF*lm^2*NC*NH)/16 + 
       (21675689988847*CF^2*NC*Pi^2)/838252800 + (383*CF^2*lm*NC*Pi^2)/216 + 
       (1339103873*CF*NM*NC*Pi^2)/163296 + (383*CF*lm*NM*NC*Pi^2)/1944 - 
       (15575017*CF*NC*NL*Pi^2)/272160 + (383*CF*lm*NC*NL*Pi^2)/1944 + 
       (383*CF*lm*NC*NH*Pi^2)/1944 - (2311693237703*CF^2*NC*Pi^3)/
        (2754990144*Sqrt[3]) - (2420553981265*CF*NC*NH*Pi^3)/
        (688747536*Sqrt[3]) - (309097*CF^2*NC*Pi^4)/19440 + 
       (7361263771636039*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (562477154400*Sqrt[3]) - (2351434665077*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(573956280*Sqrt[3]) - 
       2019*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (2311693237703*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (74401740*Sqrt[3]) - (69158685179*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (2311693237703*CF^2*NC*Pi*Log[3]^2)/(3571283520*Sqrt[3]) - 
       (69158685179*CF*NC*NH*Pi*Log[3]^2)/(25509168*Sqrt[3]) - 
       (CF*NC*(-117*CA*(-10038976629923 + 355215876400*lm) + 
          2*(39*CF*(-30346416972077 + 871893514800*lm) + 
            140*(130*(-21399169283 + 207593694*lm)*NM + 
              77*(4095*(116083 + 85588*lm)*NL + 2*(36571879 + 175241430*lm)*
                 NH))))*Log[x]^2)/8172964800 + 
       (CF*NC*(-1804350437*CA + 28*(79964811*CF + 60383410*NM + 748895*NL))*
         Log[x]^3)/34020 + (192608255582081*CF^2*NC*PolyGamma[2, 1])/
        4132485216 + (34140079*CF*NM*NC*PolyGamma[2, 1])/1296 + 
       (294580521055*CF*NC*NH*PolyGamma[2, 1])/1033121304 + 
       CA*CF*NC*(6890228582185931580399167/234778864210007040000 + 
         (3025*lm^2)/32 - (17730183287813*Pi^2)/1371686400 + 
         (2311693237703*Pi^3)/(5509980288*Sqrt[3]) + (2335*Pi^4)/288 + 
         lm*(29077172003/114307200 - (4213*Pi^2)/3888) - 
         (7361263771636039*Im[PolyLog[2, (-1)^(1/3)]])/(1124954308800*
           Sqrt[3]) + (2019*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (2311693237703*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (148803480*Sqrt[3]) + (2311693237703*Pi*Log[3]^2)/
          (7142567040*Sqrt[3]) - (192608255582081*PolyGamma[2, 1])/
          8264970432 - (554065257559925*Zeta[3])/28927396512) + 
       (565060212773993*CF^2*NC*Zeta[3])/14463698256 + 
       (22101055*CF*NM*NC*Zeta[3])/648 - (28429*CF*NC*NL*Zeta[3])/27 + 
       (7259423061835*CF*NC*NH*Zeta[3])/516560652 + 
       CF*Log[x]*((-73493482319069*NM*NC)/3890016900 - (9051901*lm*NM*NC)/
          22680 - 63*lm^2*NM*NC - (265062989*NC*NL)/151200 - 
         (9051901*lm*NC*NL)/22680 - 63*lm^2*NC*NL - 
         (1490899963158568283*NC*NH)/58091390557200 - (9051901*lm*NC*NH)/
          22680 - 63*lm^2*NC*NH + (12098515*NM*NC*Pi^2)/972 - 
         (170191*NC*NL*Pi^2)/972 + (69158685179*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(181608478857184573883/2117413999008000 - (9290041*lm)/2520 - 
           567*lm^2 + (12281603*Pi^2)/504 + (2311693237703*
             Im[PolyLog[2, (-1)^(1/3)]])/(223205220*Sqrt[3]) - 
           1512*Zeta[3]) + CA*NC*(-4907129812073525221/120995085657600 + 
           (119574671*lm)/45360 + (693*lm^2)/2 - (330280393*Pi^2)/27216 - 
           (2311693237703*Im[PolyLog[2, (-1)^(1/3)]])/(446410440*Sqrt[3]) + 
           756*Zeta[3])), (2339284402296246799391309*CF^2*NC)/
        22010518519688160000 + (14081894*CF^2*lm*NC)/33075 + 
       254*CF^2*lm^2*NC + (548619459150266851*CF*NM*NC)/1331250228000 + 
       (12681719*CF*lm*NM*NC)/297675 + (254*CF*lm^2*NM*NC)/9 - 
       (2477806637*CF*NC*NL)/1488375 + (12681719*CF*lm*NC*NL)/297675 + 
       (254*CF*lm^2*NC*NL)/9 - (2050147162733167406204689*CF*NC*NH)/
        34540792276967776800 + (12681719*CF*lm*NC*NH)/297675 + 
       (254*CF*lm^2*NC*NH)/9 - (969245833957*CF^2*NC*Pi^2)/26195400 - 
       (32*CF^2*lm*NC*Pi^2)/9 - (138913979*CF*NM*NC*Pi^2)/945 - 
       (32*CF*lm*NM*NC*Pi^2)/81 + (930656*CF*NC*NL*Pi^2)/8505 - 
       (32*CF*lm*NC*NL*Pi^2)/81 - (32*CF*lm*NC*NH*Pi^2)/81 + 
       (1626028923761*CF^2*NC*Pi^3)/(1033121304*Sqrt[3]) + 
       (966262641260*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) + 
       (5431*CF^2*NC*Pi^4)/162 - (4616439100224953*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(210928932900*Sqrt[3]) - 
       (1990940414516*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (215233605*Sqrt[3]) + (33752*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        9 + (3252057847522*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (55801305*Sqrt[3]) + (441720064576*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (1626028923761*CF^2*NC*Pi*Log[3]^2)/(1339231320*Sqrt[3]) + 
       (27607504036*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       (CF*NC*(-65*CA*(-512610795311 + 28029466080*lm) + 
          12*(52*CF*(-107175403547 + 4777749900*lm) + 
            35*(39*(-18277516723 + 20223280*lm)*NM + 280280*(3707 + 2814*lm)*
               NL + (180053443 + 788707920*lm)*NH)))*Log[x]^2)/170270100 - 
       (CF*NC*(-713654997*CA + 40*(14808545*CF + 42*(2968437*NM + 
              6566*NL)))*Log[x]^3)/8505 - (170886461793079*CF^2*NC*
         PolyGamma[2, 1])/2324522934 - (7951723*CF*NM*NC*PolyGamma[2, 1])/
        27 + (880230993293*CF*NC*NH*PolyGamma[2, 1])/1162261467 - 
       (2740954372005947*CF^2*NC*Zeta[3])/40679151345 - 
       (8336198*CF*NM*NC*Zeta[3])/27 + (19568*CF*NC*NL*Zeta[3])/9 - 
       (25647787043510*CF*NC*NH*Zeta[3])/1162261467 + 
       CA*CF*NC*(-571203909259724800091099/11005259259844080000 - 
         (1397*lm^2)/9 + (17421867797531*Pi^2)/943034400 - 
         (1626028923761*Pi^3)/(2066242608*Sqrt[3]) - (27667*Pi^4)/1620 + 
         lm*(-257113609/595350 + (176*Pi^2)/81) + 
         (4616439100224953*Im[PolyLog[2, (-1)^(1/3)]])/(421857865800*
           Sqrt[3]) - (16876*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (1626028923761*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55801305*Sqrt[3]) - (1626028923761*Pi*Log[3]^2)/
          (2678462640*Sqrt[3]) + (170886461793079*PolyGamma[2, 1])/
          4649045868 + (1325340654315226*Zeta[3])/40679151345) + 
       CF*Log[x]*((-2494219450693*NM*NC)/5145525 + (242108*lm*NM*NC)/315 + 
         112*lm^2*NM*NC + (11551991*NC*NL)/3150 + (242108*lm*NC*NL)/315 + 
         112*lm^2*NC*NL + (1870035151172128207*NC*NH)/34232426578350 + 
         (242108*lm*NC*NH)/315 + 112*lm^2*NC*NH - (3957104*NM*NC*Pi^2)/
          27 + (29288*NC*NL*Pi^2)/81 - (441720064576*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CA*NC*(3423567994388527157/158806049925600 - (1578554*lm)/315 - 
           616*lm^2 + (633636007*Pi^2)/34020 + 
           (1626028923761*Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) - 
           1344*Zeta[3]) + CF*NC*(-3023068918534414117/56716446402000 + 
           (247988*lm)/35 + 1008*lm^2 - (7892207*Pi^2)/210 - 
           (3252057847522*Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) + 
           2688*Zeta[3])), (-180050312771922359149768372529*CF^2*NC)/
        290142655126529325120000 - (13518929*CF^2*lm*NC)/37632 - 
       (3621*CF^2*lm^2*NC)/16 - (197373311092535441167453*CF*NM*NC)/
        1010795933116569600 - (12099497*CF*lm*NM*NC)/338688 - 
       (1207*CF*lm^2*NM*NC)/48 + (7584179191*CF*NC*NL)/4838400 - 
       (12099497*CF*lm*NC*NL)/338688 - (1207*CF*lm^2*NC*NL)/48 + 
       (33734279495867074375387099*CF*NC*NH)/602893828834346649600 - 
       (12099497*CF*lm*NC*NH)/338688 - (1207*CF*lm^2*NC*NH)/48 + 
       (3593154679315783*CF^2*NC*Pi^2)/15088550400 + (55*CF^2*lm*NC*Pi^2)/
        24 + (2743541573*CF*NM*NC*Pi^2)/54432 + (55*CF*lm*NM*NC*Pi^2)/216 - 
       (1299421*CF*NC*NL*Pi^2)/13608 + (55*CF*lm*NC*NL*Pi^2)/216 + 
       (55*CF*lm*NC*NH*Pi^2)/216 - (25805698187759*CF^2*NC*Pi^3)/
        (16529940864*Sqrt[3]) - (6885979073155*CF*NC*NH*Pi^3)/
        (1033121304*Sqrt[3]) - (356369*CF^2*NC*Pi^4)/12960 + 
       (66016971916297991*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2892739651200*Sqrt[3]) - (22148963558089*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5165606520*Sqrt[3]) - 
       (19747*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (3686528312537*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (63772920*Sqrt[3]) - (393484518466*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (3686528312537*CF^2*NC*Pi*Log[3]^2)/(3061100160*Sqrt[3]) - 
       (196742259233*CF*NC*NH*Pi*Log[3]^2)/(38263752*Sqrt[3]) - 
       (CF*NC*(CA*(5749360207508917 - 39769419690000*lm) + 
          CF*(-11516642414451029 + 65077232220000*lm) + 
          210*(25*(-466456956403 + 1377295920*lm)*NM + 
            33*(12740*(110029 + 81900*lm)*NL + 3*(81465409 + 347802000*lm)*
               NH)))*Log[x]^2)/4086482400 + 
       (CF*NC*(-15001226947*CA + 27084259459*CF + 
          4200*(2133233*NM + 9555*NL))*Log[x]^3)/34020 + 
       (49795640454665989*CF^2*NC*PolyGamma[2, 1])/111577100832 + 
       (50297077*CF*NM*NC*PolyGamma[2, 1])/216 + 
       (24559087359769*CF*NC*NH*PolyGamma[2, 1])/55788550416 + 
       CA*CF*NC*(359082953028098299109590918663/1160570620506117300480000 + 
         (13277*lm^2)/96 - (3592883633022503*Pi^2)/30177100800 + 
         (25805698187759*Pi^3)/(33059881728*Sqrt[3]) + (361649*Pi^4)/25920 - 
         (5*lm*(-50465351 + 189728*Pi^2))/677376 - 
         (66016971916297991*Im[PolyLog[2, (-1)^(1/3)]])/(5785479302400*
           Sqrt[3]) + (19747*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (3686528312537*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (127545840*Sqrt[3]) + (3686528312537*Pi*Log[3]^2)/
          (6122200320*Sqrt[3]) - (49795640454665989*PolyGamma[2, 1])/
          223154201664 - (87643335244321169*Zeta[3])/390519852912) + 
       (87900598031930171*CF^2*NC*Zeta[3])/195259926456 + 
       (37414387*CF*NM*NC*Zeta[3])/108 - (3965*CF*NC*NL*Zeta[3])/2 + 
       (709544339944369*CF*NC*NH*Zeta[3])/27894275208 + 
       CF*Log[x]*((-135717487736335553*NM*NC)/1402480759680 - 
         (6093845*lm*NM*NC)/9072 - 105*lm^2*NM*NC - (17086927*NC*NL)/
          5184 - (6093845*lm*NC*NL)/9072 - 105*lm^2*NC*NL - 
         (67830800882456511869*NC*NH)/1394193373372800 - 
         (6093845*lm*NC*NH)/9072 - 105*lm^2*NC*NH + (5342375*NM*NC*Pi^2)/
          81 - (17815*NC*NL*Pi^2)/54 + (393484518466*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(2198259033127722657563321/2147057794994112000 - 
           (6252605*lm)/1008 - 945*lm^2 + (3924922555*Pi^2)/18144 + 
           (3686528312537*Im[PolyLog[2, (-1)^(1/3)]])/(191318760*Sqrt[3]) - 
           2520*Zeta[3]) + CA*NC*(-38947824131317271200441/
            76680635535504000 + (80368135*lm)/18144 + (1155*lm^2)/2 - 
           (1307233625*Pi^2)/12096 - (3686528312537*Im[PolyLog[2, (-1)^
                (1/3)]])/(382637520*Sqrt[3]) + 1260*Zeta[3])), 
      (264326945049764743741193327503*CF^2*NC)/290142655126529325120000 + 
       (142642901*CF^2*lm*NC)/235200 + (1449*CF^2*lm^2*NC)/4 + 
       (171382866593230633764421*CF*NM*NC)/46796108014656000 + 
       (128442701*CF*lm*NM*NC)/2116800 + (161*CF*lm^2*NM*NC)/4 - 
       (156049357841*CF*NC*NL)/49392000 + (128442701*CF*lm*NC*NL)/2116800 + 
       (161*CF*lm^2*NC*NL)/4 - (11086999913247821647460033293*CF*NC*NH)/
        104430099973380115334400 + (128442701*CF*lm*NC*NH)/2116800 + 
       (161*CF*lm^2*NC*NH)/4 - (36652402250145811*CF^2*NC*Pi^2)/
        130767436800 - (9*CF^2*lm*NC*Pi^2)/2 - (4880524333*CF*NM*NC*Pi^2)/
        3780 - (CF*lm*NM*NC*Pi^2)/2 + (49359*CF*NC*NL*Pi^2)/280 - 
       (CF*lm*NC*NL*Pi^2)/2 - (CF*lm*NC*NH*Pi^2)/2 + 
       (92759574932743*CF^2*NC*Pi^3)/(33059881728*Sqrt[3]) + 
       (64549621675*CF*NC*NH*Pi^3)/(4782969*Sqrt[3]) + 
       (475643*CF^2*NC*Pi^4)/8640 - (1497601153254843179*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(40498355116800*Sqrt[3]) - 
       (4407588058751*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (215233605*Sqrt[3]) + (23713*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        4 + (92759574932743*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (892820880*Sqrt[3]) + (29508398480*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) + 
       (92759574932743*CF^2*NC*Pi*Log[3]^2)/(42855402240*Sqrt[3]) + 
       (1844274905*CF*NC*NH*Pi*Log[3]^2)/(177147*Sqrt[3]) + 
       CF*((-2545795231842319*CF*NC)/778377600 + 
         CA*(17805143961169189/10897286400 - 19514*lm)*NC + 31932*CF*lm*NC - 
         (2789893522973*NM*NC)/180180 + 3548*lm*NM*NC + (13918*NC*NL)/3 + 
         3548*lm*NC*NL + (21035471*NC*NH)/23562 + 3548*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-13002842017*CA + 6*(3585309793*CF + 
            10080*(1819356*NM + 887*NL)))*Log[x]^3)/22680 - 
       (37122703799426129*CF^2*NC*PolyGamma[2, 1])/55788550416 - 
       (48611711*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (9866866418471*CF*NC*NH*PolyGamma[2, 1])/6973568802 - 
       (2991469213670700529*CF^2*NC*Zeta[3])/3905198529120 - 
       (26996141*CF*NM*NC*Zeta[3])/9 + 3914*CF*NC*NL*Zeta[3] - 
       (134662671525913*CF*NC*NH*Zeta[3])/3486784401 + 
       CA*CF*NC*(-2104896196506648622728944790977/4642282482024469201920000 - 
         (1771*lm^2)/8 + (939486497686589*Pi^2)/6706022400 - 
         (92759574932743*Pi^3)/(66119763456*Sqrt[3]) - (96511*Pi^4)/3456 + 
         lm*(-2605686511/4233600 + (11*Pi^2)/4) + 
         (1497601153254843179*Im[PolyLog[2, (-1)^(1/3)]])/
          (80996710233600*Sqrt[3]) - (23713*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 - 
         (92759574932743*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1785641760*Sqrt[3]) - (92759574932743*Pi*Log[3]^2)/
          (85710804480*Sqrt[3]) + (37122703799426129*PolyGamma[2, 1])/
          111577100832 + (2976586212802259089*Zeta[3])/7810397058240) + 
       CF*Log[x]*((-323343025482637891*NM*NC)/64929664800 + 
         (174397*lm*NM*NC)/140 + 180*lm^2*NM*NC + (435475591*NC*NL)/
          66150 + (174397*lm*NC*NL)/140 + 180*lm^2*NC*NL + 
         (155457156501565802179*NC*NH)/1578397697276400 + 
         (174397*lm*NC*NH)/140 + 180*lm^2*NC*NH - (3638890*NM*NC*Pi^2)/3 + 
         (1954*NC*NL*Pi^2)/3 - (29508398480*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(177147*Sqrt[3]) + 
         CA*NC*(2598039483773650097710843/8588231179976448000 - 
           (2271167*lm)/280 - 990*lm^2 + (50447559931*Pi^2)/362880 + 
           (92759574932743*Im[PolyLog[2, (-1)^(1/3)]])/(5356925280*Sqrt[3]) - 
           2160*Zeta[3]) + CF*NC*(-2671135043767674726029959/
            4294115589988224000 + (1607373*lm)/140 + 1620*lm^2 - 
           (16851036337*Pi^2)/60480 - (92759574932743*
             Im[PolyLog[2, (-1)^(1/3)]])/(2678462640*Sqrt[3]) + 
           4320*Zeta[3])), (-53025177194087887516094167989751*CF^2*NC)/
        8952973358190047746560000 - (12790900169*CF^2*lm*NC)/25401600 - 
       (5073*CF^2*lm^2*NC)/16 - (700874502171842718841307*CF*NM*NC)/
        561553296175872000 - (11448584369*CF*lm*NM*NC)/228614400 - 
       (1691*CF*lm^2*NM*NC)/48 + (828581783190499*CF*NC*NL)/288054144000 - 
       (11448584369*CF*lm*NC*NL)/228614400 - (1691*CF*lm^2*NC*NL)/48 + 
       (85963978742013951283695167075869*CF*NC*NH)/
        879719162175754091576985600 - (11448584369*CF*lm*NC*NH)/228614400 - 
       (1691*CF*lm^2*NC*NH)/48 + (175375325860545289*CF^2*NC*Pi^2)/
        78460462080 + (23*CF^2*lm*NC*Pi^2)/8 + (72583338491*CF*NM*NC*Pi^2)/
        272160 + (23*CF*lm*NM*NC*Pi^2)/72 - (10219201*CF*NC*NL*Pi^2)/
        68040 + (23*CF*lm*NC*NL*Pi^2)/72 + (23*CF*lm*NC*NH*Pi^2)/72 - 
       (2413775132698765*CF^2*NC*Pi^3)/(892616806656*Sqrt[3]) - 
       (328420892069515*CF*NC*NH*Pi^3)/(27894275208*Sqrt[3]) - 
       (1151953*CF^2*NC*Pi^4)/25920 + (1647999557550131053*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(43738223526144*Sqrt[3]) - 
       (2495476308562471*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (976299632280*Sqrt[3]) - (60995*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        12 - (482755026539753*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4821232752*Sqrt[3]) - (18766908118258*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(43046721*Sqrt[3]) - 
       (482755026539753*CF^2*NC*Pi*Log[3]^2)/(231419172096*Sqrt[3]) - 
       (9383454059129*CF*NC*NH*Pi*Log[3]^2)/(1033121304*Sqrt[3]) - 
       (CF*NC*(CA*(7431840231912850821 - 9599021838806400*lm) + 
          2*(17*CF*(-437298893142397189 + 461985008284800*lm) + 
            840*(51*(-20698532558027 + 20369709360*lm)*NM + 
              9189180*(150781 + 113052*lm)*NL + (266252429813 + 
                1038855177360*lm)*NH)))*Log[x]^2)/555761606400 + 
       (CF*NC*(-273195002611*CA + 48*(11145363116*CF + 
            315*(6171011*NM + 9421*NL)))*Log[x]^3)/68040 + 
       (4188283064252104055*CF^2*NC*PolyGamma[2, 1])/1004193907488 + 
       (147316519*CF*NM*NC*PolyGamma[2, 1])/72 + 
       (324220905083681*CF*NC*NH*PolyGamma[2, 1])/502096953744 + 
       CA*CF*NC*(2318755435109261214878842758943/783385168841629177824000 + 
         (18601*lm^2)/96 - (13490191430982949*Pi^2)/12070840320 + 
         (2413775132698765*Pi^3)/(1785233613312*Sqrt[3]) + 
         (1165201*Pi^4)/51840 + lm*(238688955259/457228800 - 
           (253*Pi^2)/144) - (1647999557550131053*Im[PolyLog[2, (-1)^(1/3)]])/
          (87476447052288*Sqrt[3]) + (60995*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          24 + (482755026539753*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9642465504*Sqrt[3]) + (482755026539753*Pi*Log[3]^2)/
          (462838344192*Sqrt[3]) - (4188283064252104055*PolyGamma[2, 1])/
          2008387814976 - (151920517800556252043*Zeta[3])/70293573524160) + 
       (151996808240332823483*CF^2*NC*Zeta[3])/35146786762080 + 
       (123443909*CF*NM*NC*Zeta[3])/36 - (20845*CF*NC*NL*Zeta[3])/6 + 
       (10839485538512585*CF*NC*NH*Zeta[3])/251048476872 + 
       CF*Log[x]*((-40392250455087733*NM*NC)/47703427200 - 
         (16083593*lm*NM*NC)/15120 - 165*lm^2*NM*NC - (329705034013*NC*NL)/
          57153600 - (16083593*lm*NC*NL)/15120 - 165*lm^2*NC*NL - 
         (2055942918888285229672799*NC*NH)/23933559963341508480 - 
         (16083593*lm*NC*NH)/15120 - 165*lm^2*NC*NH + (3088277*NM*NC*Pi^2)/
          9 - (10411*NC*NL*Pi^2)/18 + (18766908118258*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(129140163*Sqrt[3]) + 
         CF*NC*(1197248359963952717963416117/115941120929682048000 - 
           (16499393*lm)/1680 - 1485*lm^2 + (362912722163*Pi^2)/181440 + 
           (482755026539753*Im[PolyLog[2, (-1)^(1/3)]])/(14463698256*
             Sqrt[3]) - 3960*Zeta[3]) + CA*NC*(-1195749460288195456986616231/
            231882241859364096000 + (211846723*lm)/30240 + (1815*lm^2)/2 - 
           (1088572636369*Pi^2)/1088640 - (482755026539753*
             Im[PolyLog[2, (-1)^(1/3)]])/(28927396512*Sqrt[3]) + 
           1980*Zeta[3])), (135077045350086616033901947428991*CF^2*NC)/
        18801244052199100267776000 + (158451841*CF^2*lm*NC)/190512 + 
       (995*CF^2*lm^2*NC)/2 + (1368141504563700417661037*CF*NM*NC)/
        42116497213190400 + (142655221*CF*lm*NM*NC)/1714608 + 
       (995*CF*lm^2*NM*NC)/18 - (401439898274161*CF*NC*NL)/72013536000 + 
       (142655221*CF*lm*NC*NL)/1714608 + (995*CF*lm^2*NC*NL)/18 - 
       (25319807532876883873847676857191037*CF*NC*NH)/
        141421728125706968299840880400 + (142655221*CF*lm*NC*NH)/1714608 + 
       (995*CF*lm^2*NC*NH)/18 - (20898668858294327*CF^2*NC*Pi^2)/
        9807557760 - (50*CF^2*lm*NC*Pi^2)/9 - (58963125062*CF*NM*NC*Pi^2)/
        5103 - (50*CF*lm*NM*NC*Pi^2)/81 + (5507255*CF*NC*NL*Pi^2)/20412 - 
       (50*CF*lm*NC*NL*Pi^2)/81 - (50*CF*lm*NC*NH*Pi^2)/81 + 
       (393308296214345*CF^2*NC*Pi^3)/(83682825624*Sqrt[3]) + 
       (958898926267625*CF*NC*NH*Pi^3)/(41841412812*Sqrt[3]) + 
       (55445*CF^2*NC*Pi^4)/648 - (4881749933656182199*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(82009169111520*Sqrt[3]) - 
       (2950615980880970*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (73222472421*Sqrt[3]) + (80450*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        9 + (157323318485738*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (903981141*Sqrt[3]) + (109588448716300*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) + 
       (78661659242869*CF^2*NC*Pi*Log[3]^2)/(21695547384*Sqrt[3]) + 
       (27397112179075*CF*NC*NH*Pi*Log[3]^2)/(1549681956*Sqrt[3]) + 
       (CF*NC*(-323*CA*(-1384362662638031 + 3635794850688*lm) + 
          8*(969*CF*(-115387385526181 + 247895103456*lm) + 
            28*(2584*(-8430761902456 + 368891523*lm)*NM + 23279256*(53234 + 
                40947*lm)*NL + (259269390683 + 953215695432*lm)*NH)))*
         Log[x]^2)/35198235072 - (CF*NC*(-86523462451*CA + 
          32*(5170743481*CF + 27032787558*NM + 2579661*NL))*Log[x]^3)/
        20412 - (4420472044525691363*CF^2*NC*PolyGamma[2, 1])/753145430616 - 
       (4003275685*CF*NM*NC*PolyGamma[2, 1])/162 + 
       (231286901651590*CF*NC*NH*PolyGamma[2, 1])/94143178827 - 
       (19810339584562811225*CF^2*NC*Zeta[3])/2636009007156 - 
       (2290299595*CF*NM*NC*Zeta[3])/81 + (178838*CF*NC*NL*Zeta[3])/27 - 
       (6011385284492200*CF*NC*NH*Zeta[3])/94143178827 + 
       CA*CF*NC*(-53979860035196626024587556192819/
          15040995241759280214220800 - (10945*lm^2)/36 + 
         (1160951153584639*Pi^2)/1089728640 - (393308296214345*Pi^3)/
          (167365651248*Sqrt[3]) - (18695*Pi^4)/432 + 
         lm*(-2896123511/3429216 + (275*Pi^2)/81) + 
         (4881749933656182199*Im[PolyLog[2, (-1)^(1/3)]])/
          (164018338223040*Sqrt[3]) - (40225*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          9 - (78661659242869*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (903981141*Sqrt[3]) - (78661659242869*Pi*Log[3]^2)/
          (43391094768*Sqrt[3]) + (4420472044525691363*PolyGamma[2, 1])/
          1506290861232 + (4948480855885850879*Zeta[3])/1318004503578) + 
       CF*Log[x]*((-3368763102466766047*NM*NC)/70124037984 + 
         (6518195*lm*NM*NC)/3402 + 275*lm^2*NM*NC + (317604118409*NC*NL)/
          28576800 + (6518195*lm*NC*NL)/3402 + 275*lm^2*NC*NL + 
         (1083313633346684500141915607*NC*NH)/6480011360074713420960 + 
         (6518195*lm*NC*NH)/3402 + 275*lm^2*NC*NH - (95356135*NM*NC*Pi^2)/
          9 + (29773*NC*NL*Pi^2)/27 - (109588448716300*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(387420489*Sqrt[3]) + 
         CA*NC*(87550156286744020532868353/34782336278904614400 - 
           (84797845*lm)/6804 - (3025*lm^2)/2 + (85919904737*Pi^2)/81648 + 
           (78661659242869*Im[PolyLog[2, (-1)^(1/3)]])/(2711943423*Sqrt[3]) - 
           3300*Zeta[3]) + CF*NC*(-6287083578194321758931821/
            1242226295675164800 + (3337060*lm)/189 + 2475*lm^2 - 
           (10744920076*Pi^2)/5103 - (157323318485738*
             Im[PolyLog[2, (-1)^(1/3)]])/(2711943423*Sqrt[3]) + 
           6600*Zeta[3])), (-103762400757418639368292885893790663207*CF^2*NC)/
        1847410240569083592311669760000 - (31163400361*CF^2*lm*NC)/45722880 - 
       (6867*CF^2*lm^2*NC)/16 - (508097388786249959895609904067*CF*NM*NC)/
        74490606291025596672000 - (27892785601*CF*lm*NM*NC)/411505920 - 
       (763*CF*lm^2*NM*NC)/16 + (474369913111711*CF*NC*NL)/96018048000 - 
       (27892785601*CF*lm*NC*NL)/411505920 - (763*CF*lm^2*NC*NL)/16 + 
       (860182402484846910152581919970307663*CF*NC*NH)/
        5324112117673674100699891968000 - (27892785601*CF*lm*NC*NH)/
        411505920 - (763*CF*lm^2*NC*NH)/16 + 
       (998002956453682847*CF^2*NC*Pi^2)/47076277248 + 
       (761*CF^2*lm*NC*Pi^2)/216 + (2426639640907*CF*NM*NC*Pi^2)/2449440 + 
       (761*CF*lm*NM*NC*Pi^2)/1944 - (69031283*CF*NC*NL*Pi^2)/306180 + 
       (761*CF*lm*NC*NL*Pi^2)/1944 + (761*CF*lm*NC*NH*Pi^2)/1944 - 
       (11853936513143479*CF^2*NC*Pi^3)/(2677850419968*Sqrt[3]) - 
       (1644576909874885*CF*NC*NH*Pi^3)/(83682825624*Sqrt[3]) - 
       (1059979*CF^2*NC*Pi^4)/15552 + (195120918791358035611*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3280366764460800*Sqrt[3]) + 
       (8112738654733739*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2928898896840*Sqrt[3]) - (270677*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/36 - (11853936513143479*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(72318491280*Sqrt[3]) - 
       (93975823421422*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) - (11853936513143479*CF^2*NC*Pi*Log[3]^2)/
        (3471287581440*Sqrt[3]) - (46987911710711*CF*NC*NH*Pi*Log[3]^2)/
        (3099363912*Sqrt[3]) - 
       (CF*NC*(CA*(4027377449607784678831 - 914875459177680000*lm) + 
          2*(19*CF*(-211978800289850208389 + 39396550873680000*lm) + 
            840*(57*(-3927921683057303 + 1737061326000*lm)*NM + 
              17*(10270260*(752047 + 567100*lm)*NL + (1604834475407 + 
                  5824264446000*lm)*NH))))*Log[x]^2)/31678411564800 + 
       (CF*NC*(-3851221884662*CA + 7671173647575*CF + 625026298680*NM + 
          357273000*NL)*Log[x]^3)/102060 + (38921780505808806865*CF^2*NC*
         PolyGamma[2, 1])/1004193907488 + (69775964851*CF*NM*NC*
         PolyGamma[2, 1])/3888 + (114050379140599*CF*NC*NH*PolyGamma[2, 1])/
        125524238436 + CA*CF*NC*(2964412721316855766876117695214592891/
          105566299461090490989238272000 + (8393*lm^2)/32 - 
         (4989999945830280739*Pi^2)/470762772480 + (11853936513143479*Pi^3)/
          (5355700839936*Sqrt[3]) + (5348599*Pi^4)/155520 + 
         lm*(581552281451/823011840 - (8371*Pi^2)/3888) - 
         (195120918791358035611*Im[PolyLog[2, (-1)^(1/3)]])/
          (6560733528921600*Sqrt[3]) + (270677*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          72 + (11853936513143479*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (144636982560*Sqrt[3]) + (11853936513143479*Pi*Log[3]^2)/
          (6942575162880*Sqrt[3]) - (38921780505808806865*PolyGamma[2, 1])/
          2008387814976 - (1398077874165485123923*Zeta[3])/70293573524160) + 
       (1398198346719687316003*CF^2*NC*Zeta[3])/35146786762080 + 
       (63897980503*CF*NM*NC*Zeta[3])/1944 - (931601*CF*NC*NL*Zeta[3])/
        162 + (4368991205023393*CF*NC*NH*Zeta[3])/62762119218 + 
       CF*Log[x]*((-19737104083424558931193*NM*NC)/2026584697737600 - 
         (655460959*lm*NM*NC)/408240 - (495*lm^2*NM*NC)/2 - 
         (45428328769*NC*NL)/4762800 - (655460959*lm*NC*NL)/408240 - 
         (495*lm^2*NC*NL)/2 - (1092608148284510085172110671*NC*NH)/
          7623542776558486377600 - (655460959*lm*NC*NH)/408240 - 
         (495*lm^2*NC*NH)/2 + 1531687*NM*NC*Pi^2 - (77570*NC*NL*Pi^2)/81 + 
         (93975823421422*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(10089467831000290476035404293757/
            100520951846034335616000 - (672300859*lm)/45360 - (4455*lm^2)/2 + 
           (30789401717927*Pi^2)/1632960 + (11853936513143479*
             Im[PolyLog[2, (-1)^(1/3)]])/(216955473840*Sqrt[3]) - 
           5940*Zeta[3]) + CA*NC*(-10087467981861754991740722318691/
            201041903692068671232000 + (8624622149*lm)/816480 + 
           (5445*lm^2)/4 - (30788594137727*Pi^2)/3265920 - 
           (11853936513143479*Im[PolyLog[2, (-1)^(1/3)]])/(433910947680*
             Sqrt[3]) + 2970*Zeta[3])), 
      (197365437476830463508474929693370470467*CF^2*NC)/
        3562862606811804070886791680000 + (4215344201*CF^2*lm*NC)/3810240 + 
       (2651*CF^2*lm^2*NC)/4 + (302371853588995336350613002497*CF*NM*NC)/
        1034591754042022176000 + (3794471441*CF*lm*NM*NC)/34292160 + 
       (2651*CF*lm^2*NM*NC)/36 - (66840582445417*CF*NC*NL)/7201353600 + 
       (3794471441*CF*lm*NC*NL)/34292160 + (2651*CF*lm^2*NC*NL)/36 - 
       (9252650851990205719003121555327440753*CF*NC*NH)/
        32154835026476531739753294912000 + (3794471441*CF*lm*NC*NH)/
        34292160 + (2651*CF*lm^2*NC*NH)/36 - 
       (6306433713274124473*CF^2*NC*Pi^2)/392302310400 - 
       (121*CF^2*lm*NC*Pi^2)/18 - (10714553476297*CF*NM*NC*Pi^2)/102060 - 
       (121*CF*lm*NM*NC*Pi^2)/162 + (80885519*CF*NC*NL*Pi^2)/204120 - 
       (121*CF*lm*NC*NL*Pi^2)/162 - (121*CF*lm*NC*NH*Pi^2)/162 + 
       (541432574670350669*CF^2*NC*Pi^3)/(72301961339136*Sqrt[3]) + 
       (41860256399628835*CF*NC*NH*Pi^3)/(1129718145924*Sqrt[3]) + 
       (1099571*CF^2*NC*Pi^4)/8640 - (8152083490535012850161*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(88569902640441600*Sqrt[3]) - 
       (103033198266635813*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1412147682405*Sqrt[3]) + (466961*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/36 + (541432574670350669*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1952599264560*Sqrt[3]) + 
       (4784029302814724*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) + (541432574670350669*CF^2*NC*Pi*Log[3]^2)/
        (93724764698880*Sqrt[3]) + (1196007325703681*CF*NC*NH*Pi*Log[3]^2)/
        (41841412812*Sqrt[3]) + 
       (CF*NC*(CA*(53531348398402419319 - 30096837535564800*lm) + 
          2*(CF*(-53533873575513464479 + 24624685256371200*lm) + 
            3360*(56*(-1860469572218969 + 14541220980*lm)*NM + 
              134774640*(7819 + 6042*lm)*NL + (236075621009 + 814308374880*
                 lm)*NH)))*Log[x]^2)/555761606400 - 
       (CF*NC*(-6510256805209*CA + 2*(6443283669541*CF + 
            30240*(1285770237*NM + 22154*NL)))*Log[x]^3)/204120 - 
       (697758167001960832121*CF^2*NC*PolyGamma[2, 1])/13556617751088 - 
       (18303666113*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (3413763069581111*CF*NC*NH*PolyGamma[2, 1])/847288609443 - 
       (67444457496002018637763*CF^2*NC*Zeta[3])/948963242576160 - 
       (21183666910*CF*NM*NC*Zeta[3])/81 + (287870*CF*NC*NL*Zeta[3])/27 - 
       (85401700941578462*CF*NC*NH*Zeta[3])/847288609443 + 
       CA*CF*NC*(-276258965071956691363628025714375019451/
          9976015299073051398483016704000 - (29161*lm^2)/72 + 
         (573303401248605323*Pi^2)/71327692800 - (541432574670350669*Pi^3)/
          (144603922678272*Sqrt[3]) - (3329689*Pi^4)/51840 + 
         lm*(-77092497691/68584320 + (1331*Pi^2)/324) + 
         (8152083490535012850161*Im[PolyLog[2, (-1)^(1/3)]])/
          (177139805280883200*Sqrt[3]) - (466961*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/72 - (541432574670350669*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3905198529120*Sqrt[3]) - 
         (541432574670350669*Pi*Log[3]^2)/(187449529397760*Sqrt[3]) + 
         (697758167001960832121*PolyGamma[2, 1])/27113235502176 + 
         (67435194580853164731643*Zeta[3])/1897926485152320) + 
       CF*Log[x]*((-229906122012052477928437*NM*NC)/506646174434400 + 
         (96126899*lm*NM*NC)/34020 + (1210*lm^2*NM*NC)/3 + 
         (63776274559*NC*NL)/3572100 + (96126899*lm*NC*NL)/34020 + 
         (1210*lm^2*NC*NL)/3 + (388746622648730267751679537*NC*NH)/
          1438818311858694591825 + (96126899*lm*NC*NH)/34020 + 
         (1210*lm^2*NC*NH)/3 - (857186065*NM*NC*Pi^2)/9 + 
         (47938*NC*NL*Pi^2)/27 - (4784029302814724*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CA*NC*(14310961761570228595139301313439/775447342812264874752000 - 
           (1249495489*lm)/68040 - (6655*lm^2)/3 + (26001749019011*Pi^2)/
            3265920 + (541432574670350669*Im[PolyLog[2, (-1)^(1/3)]])/
            (11715595587360*Sqrt[3]) - 4840*Zeta[3]) + 
         CF*NC*(-100287814605317011633341913041977/
            2714065699842927061632000 + (98413799*lm)/3780 + 3630*lm^2 - 
           (26004253641971*Pi^2)/1632960 - (541432574670350669*
             Im[PolyLog[2, (-1)^(1/3)]])/(5857797793680*Sqrt[3]) + 
           9680*Zeta[3])), (-4391483645705444466565602121485899687059531*CF^2*
         NC)/8211058672361047145063401388728320 - (1653844326217*CF^2*lm*NC)/
        1844156160 - (9039*CF^2*lm^2*NC)/16 - 
       (918191503636480169087091797092601*CF*NM*NC)/
        34062071236676304504883200 - (1480205497777*CF*lm*NM*NC)/
        16597405440 - (3013*CF*lm^2*NM*NC)/48 + 
       (18696693728147317*CF*NC*NL)/2323636761600 - 
       (1480205497777*CF*lm*NC*NL)/16597405440 - (3013*CF*lm^2*NC*NL)/48 + 
       (374475963158082291054632251956053221457*CF*NC*NH)/
        1466260477207329847332750247987200 - (1480205497777*CF*lm*NC*NH)/
        16597405440 - (3013*CF*lm^2*NC*NH)/48 + 
       (1307665670794001431777*CF^2*NC*Pi^2)/6472988121600 + 
       (305*CF^2*lm*NC*Pi^2)/72 - (1942288830479*CF*NM*NC*Pi^2)/997920 + 
       (305*CF*lm*NM*NC*Pi^2)/648 - (36583405*CF*NC*NL*Pi^2)/112266 + 
       (305*CF*lm*NC*NL*Pi^2)/648 + (305*CF*lm*NC*NH*Pi^2)/648 - 
       (8257494464385373967*CF^2*NC*Pi^3)/(1192982362095744*Sqrt[3]) - 
       (212299352357888075*CF*NC*NH*Pi^3)/(6778308875544*Sqrt[3]) - 
       (3896927*CF^2*NC*Pi^4)/38880 + (1454002199166365984993833*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(16075437329240150400*Sqrt[3]) + 
       (666383474352417173*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (47448162128808*Sqrt[3]) - (193261*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/18 - (8257494464385373967*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(32217887865240*Sqrt[3]) - 
       (12131391563307890*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) - (8257494464385373967*CF^2*NC*Pi*Log[3]^2)/
        (1546458617531520*Sqrt[3]) - (6065695781653945*CF*NC*NH*Pi*Log[3]^2)/
        (251048476872*Sqrt[3]) - 
       (CF*NC*(CA*(211169964405238649090053 - 8017009606982376000*lm) + 
          2*(CF*(-211171935662980789431643 + 6559371496621944000*lm) + 
            69300*((29388231952573537 + 10516869483120*lm)*NM + 
              128035908*(108427 + 82140*lm)*NL + (3075987883883 + 
                10516869483120*lm)*NH)))*Log[x]^2)/174231263606400 + 
       (CF*NC*(-805014246667651*CA + 176*(9141134361862*CF + 
            945*(151764797*NM + 75295*NL)))*Log[x]^3)/2245320 + 
       (29244840300331306131019*CF^2*NC*PolyGamma[2, 1])/81339706506528 + 
       (203821658057*CF*NM*NC*PolyGamma[2, 1])/1296 + 
       (12556150398058309*CF*NC*NH*PolyGamma[2, 1])/10167463313316 + 
       CA*CF*NC*(172520499161545254545883294673408349075703227/
          645154609971225132826410109114368000 + (33143*lm^2)/96 - 
         (1307665018915889965657*Pi^2)/12945976243200 + 
         (8257494464385373967*Pi^3)/(2385964724191488*Sqrt[3]) + 
         (3926207*Pi^4)/77760 + lm*(2806174733137/3017710080 - 
           (3355*Pi^2)/1296) - (1454002199166365984993833*
           Im[PolyLog[2, (-1)^(1/3)]])/(32150874658480300800*Sqrt[3]) + 
         (193261*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 + 
         (8257494464385373967*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (64435775730480*Sqrt[3]) + (8257494464385373967*Pi*Log[3]^2)/
          (3092917235063040*Sqrt[3]) - (29244840300331306131019*
           PolyGamma[2, 1])/162679413013056 - (1411332880854630532566751*
           Zeta[3])/7828946751253320) + (352838330114646746603479*CF^2*NC*
         Zeta[3])/978618343906665 + (200219539469*CF*NM*NC*Zeta[3])/648 - 
       (490685*CF*NC*NL*Zeta[3])/54 + (546970260759194779*CF*NC*NH*Zeta[3])/
        5083731656658 + CF*Log[x]*((-83608653698596015062583583*NM*NC)/
          731597075883273600 - (697886689*lm*NM*NC)/299376 - 
         (715*lm^2*NM*NC)/2 - (315544447819*NC*NL)/20956320 - 
         (697886689*lm*NC*NL)/299376 - (715*lm^2*NC*NL)/2 - 
         (479345334276983600668248065737*NC*NH)/2099523680664207148391040 - 
         (697886689*lm*NC*NH)/299376 - (715*lm^2*NC*NH)/2 + 
         (227748313*NM*NC*Pi^2)/81 - (40865*NC*NL*Pi^2)/27 + 
         (12131391563307890*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (1114005506624504280745520394745998889/
            1154738024365313931615072000 - (715724509*lm)/33264 - 
           (6435*lm^2)/2 + (1609849325555561*Pi^2)/8981280 + 
           (8257494464385373967*Im[PolyLog[2, (-1)^(1/3)]])/
            (96653663595720*Sqrt[3]) - 8580*Zeta[3]) + 
         CA*NC*(-15595601238030494198950898397693026471/
            32332664682228790085222016000 + (834102769*lm)/54432 + 
           (7865*lm^2)/4 - (1609842403760681*Pi^2)/17962560 - 
           (8257494464385373967*Im[PolyLog[2, (-1)^(1/3)]])/
            (193307327191440*Sqrt[3]) + 4290*Zeta[3])), 
      (1188817454660613075323832609573460546746140347*CF^2*NC)/
        2822551418624109956115544227375360000 + (918957439*CF^2*lm*NC)/
        640332 + 861*CF^2*lm^2*NC + (33331198293230244009580489738271*CF*NM*
         NC)/12515458273323157152000 + (827069797*CF*lm*NM*NC)/5762988 + 
       (287*CF*lm^2*NM*NC)/3 - (142722111777151*CF*NC*NL)/9681819840 + 
       (827069797*CF*lm*NC*NL)/5762988 + (287*CF*lm^2*NC*NL)/3 - 
       (4954538928102605056083291483241155555499211*CF*NC*NH)/
        11149994516363488907810982667037664000 + (827069797*CF*lm*NC*NH)/
        5762988 + (287*CF*lm^2*NC*NH)/3 - (4589936845218652861*CF^2*NC*Pi^2)/
        38529691200 - 8*CF^2*lm*NC*Pi^2 - (60090734999699*CF*NM*NC*Pi^2)/
        62370 - (8*CF*lm*NM*NC*Pi^2)/9 + (17544503*CF*NC*NL*Pi^2)/31185 - 
       (8*CF*lm*NC*NL*Pi^2)/9 - (8*CF*lm*NC*NH*Pi^2)/9 + 
       (1707532654729613275*CF^2*NC*Pi^3)/(149122795261968*Sqrt[3]) + 
       (97472267203186645*CF*NC*NH*Pi^3)/(1694577218886*Sqrt[3]) + 
       (295817*CF^2*NC*Pi^4)/1620 - (11056273084416194539253*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(80377186646200752*Sqrt[3]) - 
       (3678080381471336482*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29655101330505*Sqrt[3]) + (54700*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 + (341506530945922655*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(805447196631*Sqrt[3]) + 
       (22279375360728376*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) + (341506530945922655*CF^2*NC*Pi*Log[3]^2)/
        (38661465438288*Sqrt[3]) + (2784921920091047*CF*NC*NH*Pi*Log[3]^2)/
        (62762119218*Sqrt[3]) + CF*((-1037498224277633868131*CF*NC)/
          725963598360 + CA*(1037487410769166796717/1451927196720 - 84216*lm)*
          NC + 137808*CF*lm*NC - (1009280825389142531*NM*NC)/87297210 + 
         15312*lm*NM*NC + (59224*NC*NL)/3 + 15312*lm*NC*NL + 
         (3133656042509*NC*NH)/669278610 + 15312*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-22277392972639*CA + 44451561893612*CF + 
          1496880*(217352167*NM + 638*NL))*Log[x]^3)/93555 - 
       (1527031833783001027165*CF^2*NC*PolyGamma[2, 1])/3389154437772 - 
       (111547577131*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (32081650918218427*CF*NC*NH*PolyGamma[2, 1])/5083731656658 - 
       (43258166433724819928047*CF^2*NC*Zeta[3])/65241222927111 - 
       (64602430855*CF*NM*NC*Zeta[3])/27 + (49400*CF*NC*NL*Zeta[3])/3 - 
       (389169910770214541*CF*NC*NH*Zeta[3])/2541865828329 + 
       CA*CF*NC*(-148596568685428817146022779924254346457834507/
          705637854656027489028886056843840000 - (3157*lm^2)/6 + 
         (4589922841968110371*Pi^2)/77059382400 - (1707532654729613275*Pi^3)/
          (298245590523936*Sqrt[3]) - (298121*Pi^4)/3240 + 
         lm*(-1528757245/1047816 + (44*Pi^2)/9) + 
         (11056273084416194539253*Im[PolyLog[2, (-1)^(1/3)]])/
          (160754373292401504*Sqrt[3]) - (27350*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 - (341506530945922655*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1610894393262*Sqrt[3]) - (341506530945922655*Pi*Log[3]^2)/
          (77322930876576*Sqrt[3]) + (1527031833783001027165*PolyGamma[2, 1])/
          6778308875544 + (21628601510709269229848*Zeta[3])/65241222927111) + 
       CF*Log[x]*((-5404061950389335516794363*NM*NC)/1270133812297350 + 
         (41845756*lm*NM*NC)/10395 + 572*lm^2*NM*NC + (80121979387*NC*NL)/
          2910600 + (41845756*lm*NC*NL)/10395 + 572*lm^2*NC*NL + 
         (300645302058091486034584539727*NC*NH)/717102290206201950864450 + 
         (41845756*lm*NC*NH)/10395 + 572*lm^2*NC*NH - 
         (7824689914*NM*NC*Pi^2)/9 + (8228*NC*NL*Pi^2)/3 - 
         (22279375360728376*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CA*NC*(125070015280281203344218653303017663/
            1010395771319649690163188000 - (24706658*lm)/945 - 3146*lm^2 + 
           (8908152784303*Pi^2)/149688 + (341506530945922655*
             Im[PolyLog[2, (-1)^(1/3)]])/(4832683179786*Sqrt[3]) - 
           6864*Zeta[3]) + CF*NC*(-25020060963124322965070613128251949/
            101039577131964969016318800 + (42836746*lm)/1155 + 5148*lm^2 - 
           (8908328112841*Pi^2)/74844 - (341506530945922655*
             Im[PolyLog[2, (-1)^(1/3)]])/(2416341589893*Sqrt[3]) + 
           13728*Zeta[3])), (-1572626029641316579601753039339898021501870283*
         CF^2*NC)/307914700213539267939877552077312000 - 
       (2125815555989*CF^2*lm*NC)/1844156160 - (11625*CF^2*lm^2*NC)/16 + 
       (4803738905198801813848152057821759*CF*NM*NC)/
        170310356183381522524416000 - (1902499770989*CF*lm*NM*NC)/
        16597405440 - (3875*CF*lm^2*NM*NC)/48 + 
       (655923815373743123*CF*NC*NL)/52281827136000 - 
       (1902499770989*CF*lm*NC*NL)/16597405440 - (3875*CF*lm^2*NC*NL)/48 + 
       (1891964637749680668349123686652534277296003*CF*NC*NH)/
        4865452152594976977953883345616435200 - (1902499770989*CF*lm*NC*NH)/
        16597405440 - (3875*CF*lm^2*NC*NH)/48 + 
       (567256230398430117577*CF^2*NC*Pi^2)/294226732800 + 
       (361*CF^2*lm*NC*Pi^2)/72 - (937037751268447*CF*NM*NC*Pi^2)/8981280 + 
       (361*CF*lm*NM*NC*Pi^2)/648 - (2049708497*CF*NC*NL*Pi^2)/4490640 + 
       (361*CF*lm*NC*NL*Pi^2)/648 + (361*CF*lm*NC*NH*Pi^2)/648 - 
       (1695135480407061631*CF^2*NC*Pi^3)/(162679413013056*Sqrt[3]) - 
       (1953330823136320985*CF*NC*NH*Pi^3)/(40669853253264*Sqrt[3]) - 
       (2768557*CF^2*NC*Pi^4)/19440 + (146032758903647919255067*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1096052545175464800*Sqrt[3]) + 
       (3501368072296780277*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (101674633133160*Sqrt[3]) - (133991*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - (1695135480407061631*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4393348345260*Sqrt[3]) - 
       (55809452089609171*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31381059609*Sqrt[3]) - (1695135480407061631*CF^2*NC*Pi*Log[3]^2)/
        (210880720572480*Sqrt[3]) - (55809452089609171*CF*NC*NH*Pi*Log[3]^2)/
        (1506290861232*Sqrt[3]) - 
       (CF*NC*(-23*CA*(-1007716889645834374221893 + 6136516252980313200*lm) + 
          44*(23*CF*(-45805383102527692715909 + 228217546598441400*lm) + 
            315*(69*(2623148447338447297 + 26833338812280*lm)*NM + 
              7362064710*(330719 + 251492*lm)*NL + (569342796101999 + 
                1851500378047320*lm)*NH)))*Log[x]^2)/2003659531473600 + 
       (CF*NC*(-7676434908483589*CA + 616*(24920304849224*CF - 
            858565712610*NM + 31122135*NL))*Log[x]^3)/2245320 + 
       (2439015096470154687785933*CF^2*NC*PolyGamma[2, 1])/732057358558752 + 
       (223095526247*CF*NM*NC*PolyGamma[2, 1])/162 + 
       (596573236481573027*CF*NC*NH*PolyGamma[2, 1])/366028679279376 + 
       CA*CF*NC*(172988547147350472326659267544870743455920390753/
          67741234046978638946773061457008640000 + (42625*lm^2)/96 - 
         (567256185811233946087*Pi^2)/588453465600 + 
         (1695135480407061631*Pi^3)/(325358826026112*Sqrt[3]) + 
         (557177*Pi^4)/7776 + lm*(3607820310989/3017710080 - 
           (3971*Pi^2)/1296) - (146032758903647919255067*
           Im[PolyLog[2, (-1)^(1/3)]])/(2192105090350929600*Sqrt[3]) + 
         (133991*Im[PolyLog[2, (-1)^(1/3)]]^2)/18 + 
         (1695135480407061631*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (8786696690520*Sqrt[3]) + (1695135480407061631*Pi*Log[3]^2)/
          (421761441144960*Sqrt[3]) - (2439015096470154687785933*
           PolyGamma[2, 1])/1464114717117504 - (41566383788857984872854677*
           Zeta[3])/25622007549556320) + (41566482587912197988634697*CF^2*NC*
         Zeta[3])/12811003774778160 + (232642938350*CF*NM*NC*Zeta[3])/81 - 
       (373009*CF*NC*NL*Zeta[3])/27 + (29379317511885519467*CF*NC*NH*
         Zeta[3])/183014339639688 + CF*Log[x]*
        ((-471950069544474533237034233*NM*NC)/365798537941636800 - 
         (4906358899*lm*NM*NC)/1496880 - (1001*lm^2*NM*NC)/2 - 
         (86283323171279*NC*NL)/3772137600 - (4906358899*lm*NC*NL)/
          1496880 - (1001*lm^2*NC*NL)/2 - (91098976063558058781910615899889*
           NC*NH)/260308131344851308163795350 - (4906358899*lm*NC*NH)/
          1496880 - (1001*lm^2*NC*NH)/2 - (19078535477*NM*NC*Pi^2)/324 - 
         (745657*NC*NL*Pi^2)/324 + (55809452089609171*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(40671558254943623811213275731856846711/
            4408999729394835011621184000 - (5031223639*lm)/166320 - 
           (9009*lm^2)/2 + (348922609110193*Pi^2)/204120 + 
           (1695135480407061631*Im[PolyLog[2, (-1)^(1/3)]])/
            (13180045035780*Sqrt[3]) - 12012*Zeta[3]) + 
         CA*NC*(-223692548109485036442275241952797332897/
            48498997023343185127833024000 + (5859871459*lm)/272160 + 
           (11011*lm^2)/4 - (348922372568293*Pi^2)/408240 - 
           (1695135480407061631*Im[PolyLog[2, (-1)^(1/3)]])/
            (26360090071560*Sqrt[3]) + 6006*Zeta[3])), 
      (182498418343086472981524099939718380179256486571*CF^2*NC)/
        58063914897410261954376909820293120000 + (840462271157*CF^2*lm*NC)/
        461039040 + (4381*CF^2*lm^2*NC)/4 + 
       (347454979712611156014928515052583819*CF*NM*NC)/
        14192529681948460210368000 + (756303436397*CF*lm*NM*NC)/4149351360 + 
       (4381*CF*lm^2*NM*NC)/36 - (6473293066293724973*CF*NC*NL)/
        287550049248000 + (756303436397*CF*lm*NC*NL)/4149351360 + 
       (4381*CF*lm^2*NC*NL)/36 - 
       (28793550535927393495603235242810675503923471*CF*NC*NH)/
        43403957892418425679195001731548000000 + (756303436397*CF*lm*NC*NH)/
        4149351360 + (4381*CF*lm^2*NC*NH)/36 - 
       (12564213198491502794773*CF^2*NC*Pi^2)/14672106408960 - 
       (169*CF^2*lm*NC*Pi^2)/18 - (1426894404030923*CF*NM*NC*Pi^2)/160380 - 
       (169*CF*lm*NM*NC*Pi^2)/162 + (1743238471*CF*NC*NL*Pi^2)/2245320 - 
       (169*CF*lm*NC*NL*Pi^2)/162 - (169*CF*lm*NC*NH*Pi^2)/162 + 
       (363258446934803033539*CF^2*NC*Pi^3)/(21473682517723392*Sqrt[3]) + 
       (1315841165902381475*CF*NC*NH*Pi^3)/(15251194969974*Sqrt[3]) + 
       (1318109*CF^2*NC*Pi^4)/5184 - (57776227926621381652417871*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(289357871926322707200*Sqrt[3]) - 
       (588794488168712010169*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2935855031719995*Sqrt[3]) + 
       (898313*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 + 
       (363258446934803033539*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (579921981574320*Sqrt[3]) + (300763695063401480*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) + 
       (363258446934803033539*CF^2*NC*Pi*Log[3]^2)/(27836255115567360*
         Sqrt[3]) + (37595461882925185*CF*NC*NH*Pi*Log[3]^2)/
        (564859072962*Sqrt[3]) + CF*((-198921954723183463581451*CF*NC)/
          19359029289600 + CA*(85252072615978950790879/16593453676800 - 
           (3411551*lm)/27)*NC + (620282*CF*lm*NC)/3 - 
         (167762747400395804971*NM*NC)/1571349780 + (620282*lm*NM*NC)/27 + 
         (2391701*NC*NL)/81 + (620282*lm*NC*NL)/27 + 
         (39064979066717*NC*NH)/5314859550 + (620282*lm*NC*NH)/27)*
        Log[x]^2 - (CF*NC*(-3901801301810567*CA + 
          10*(779960623488355*CF + 11088*(648390289881*NM + 310141*NL)))*
         Log[x]^3)/2245320 - (4326807923359548251963455*CF^2*NC*
         PolyGamma[2, 1])/1098086037838128 - 
       (1529167908442*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (653124443998203106*CF*NC*NH*PolyGamma[2, 1])/68630377364883 - 
       (5194026709883706290518802179*CF^2*NC*Zeta[3])/845526249135358560 - 
       (1761568501646*CF*NM*NC*Zeta[3])/81 + (663208*CF*NC*NL*Zeta[3])/27 - 
       (15451330333242990172*CF*NC*NH*Zeta[3])/68630377364883 + 
       CA*CF*NC*(-10557681459721155667323151440059624804720203093/
          6718138913749947664142782954414080000 - (48191*lm^2)/72 + 
         (56851609055636434841*Pi^2)/132779243520 - 
         (363258446934803033539*Pi^3)/(42947365035446784*Sqrt[3]) - 
         (6633809*Pi^4)/51840 + lm*(-1398970901837/754427520 + 
           (1859*Pi^2)/324) + (57776227926621381652417871*
           Im[PolyLog[2, (-1)^(1/3)]])/(578715743852645414400*Sqrt[3]) - 
         (898313*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 - 
         (363258446934803033539*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1159843963148640*Sqrt[3]) - (363258446934803033539*Pi*Log[3]^2)/
          (55672510231134720*Sqrt[3]) + (4326807923359548251963455*
           PolyGamma[2, 1])/2196172075676256 + (5194008386972365625658238699*
           Zeta[3])/1691052498270717120) + CF*Log[x]*
        ((-661389508553815639192235261*NM*NC)/16627206270074400 + 
         (2085099991*lm*NM*NC)/374220 + (2366*lm^2*NM*NC)/3 + 
         (425343404963053*NC*NL)/10373378400 + (2085099991*lm*NC*NL)/
          374220 + (2366*lm^2*NC*NL)/3 + (21232882665646763376466704658102*
           NC*NH)/33777006662394200886305625 + (2085099991*lm*NC*NH)/
          374220 + (2366*lm^2*NC*NH)/3 - (24014462312*NM*NC*Pi^2)/3 + 
         (331435*NC*NL*Pi^2)/81 - (300763695063401480*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CA*NC*(42257449789741436005476303586327856149/
            58198796428011822153399628800 - (2460726151*lm)/68040 - 
           (13013*lm^2)/3 + (15606194108093683*Pi^2)/35925120 + 
           (363258446934803033539*Im[PolyLog[2, (-1)^(1/3)]])/
            (3479531889445920*Sqrt[3]) - 9464*Zeta[3]) + 
         CF*NC*(-211299654676872078741732743194842749741/
            145496991070029555383499072000 + (2134289131*lm)/41580 + 
           7098*lm^2 - (15606256320015763*Pi^2)/17962560 - 
           (363258446934803033539*Im[PolyLog[2, (-1)^(1/3)]])/
            (1739765944722960*Sqrt[3]) + 18928*Zeta[3])), 
      (-69732723081427631002030775534747037649254900303362929*CF^2*NC)/
        1428626497392621106780005587162201812992000 - 
       (123490049114111*CF^2*lm*NC)/84998833920 - (14661*CF^2*lm^2*NC)/16 + 
       (62035694292303944106472408816044222733*CF*NM*NC)/
        25373462494080036545566156800 - (110509133446391*CF*lm*NM*NC)/
        764989505280 - (1629*CF*lm^2*NM*NC)/16 + 
       (1099969630754946348499*CF*NC*NL)/58315149987494400 - 
       (110509133446391*CF*lm*NC*NL)/764989505280 - (1629*CF*lm^2*NC*NL)/
        16 + (19184232001876379318469975607781250642556741351*CF*NC*NH)/
        33449983549090466723432948001112992000000 - 
       (110509133446391*CF*lm*NC*NH)/764989505280 - (1629*CF*lm^2*NC*NH)/
        16 + (17542396368607007977961603*CF^2*NC*Pi^2)/953686916582400 + 
       (1265*CF^2*lm*NC*Pi^2)/216 - (10537468106241581*CF*NM*NC*Pi^2)/
        6368544 + (1265*CF*lm*NM*NC*Pi^2)/1944 - (1982789191*CF*NC*NL*Pi^2)/
        3184272 + (1265*CF*lm*NC*NL*Pi^2)/1944 + (1265*CF*lm*NC*NH*Pi^2)/
        1944 - (471261664985335844977*CF^2*NC*Pi^3)/(31017541414489344*
         Sqrt[3]) - (2899295092355961355*CF*NC*NH*Pi^3)/
        (40669853253264*Sqrt[3]) - (1698941*CF^2*NC*Pi^4)/8640 + 
       (148234602157338289891818467*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (776213973897595833600*Sqrt[3]) + (532919592262655171867*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7828946751253320*Sqrt[3]) - 
       (724927*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (67323094997905120711*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (119666440642320*Sqrt[3]) - (82837002638741753*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (67323094997905120711*CF^2*NC*Pi*Log[3]^2)/(5743989150831360*
         Sqrt[3]) - (82837002638741753*CF*NC*NH*Pi*Log[3]^2)/
        (1506290861232*Sqrt[3]) - 
       (CF*NC*(CA*(11499016393186124217431667719 - 10864238877392852952000*
             lm) + 6*(CF*(-3833006387527231802920900513 + 
              2962974239288959896000*lm) + 24024*
             (125*(114815110126697261167 + 109630156483848*lm)*NM + 
              3*(4833678850*(1238789 + 945020*lm)*NL + (1465935925222031 + 
                  4567923186827000*lm)*NH))))*Log[x]^2)/104190295636627200 + 
       (CF*NC*(-476103943049591394*CA + 13*(73245203121795781*CF - 
            23100*(235164327862*NM - 614263*NL)))*Log[x]^3)/14594580 + 
       (67746648036970958383202389*CF^2*NC*PolyGamma[2, 1])/
        2196172075676256 + (2928016428104*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (2302816920616824385*CF*NC*NH*PolyGamma[2, 1])/1098086037838128 + 
       CA*CF*NC*(69732704165042500615227390516487705261634405054111947/
          2857252994785242213560011174324403625984000 + (17919*lm^2)/32 - 
         (114656184056279744683391*Pi^2)/12466495641600 + 
         (471261664985335844977*Pi^3)/(62035082828978688*Sqrt[3]) + 
         (15371429*Pi^4)/155520 + lm*(209636125818071/139089000960 - 
           (13915*Pi^2)/3888) - (148234602157338289891818467*
           Im[PolyLog[2, (-1)^(1/3)]])/(1552427947795191667200*Sqrt[3]) + 
         (724927*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 + 
         (67323094997905120711*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (239332881284640*Sqrt[3]) + (67323094997905120711*Pi*Log[3]^2)/
          (11487978301662720*Sqrt[3]) - (67746648036970958383202389*
           PolyGamma[2, 1])/4392344151352512 - 
         (319568313632135294960901529223*Zeta[3])/21983682477519322560) + 
       (319568435517880905821173450103*CF^2*NC*Zeta[3])/
        10991841238759661280 + (6443978631583*CF*NM*NC*Zeta[3])/243 - 
       (1646855*CF*NC*NL*Zeta[3])/81 + (127625128279971984265*CF*NC*NH*
         Zeta[3])/549043018919064 + CF*Log[x]*
        ((-325460060522388818105975743357*NM*NC)/23220891188535104064 - 
         (4761640649*lm*NM*NC)/1061424 - (1365*lm^2*NM*NC)/2 - 
         (10887479339067433*NC*NL)/323649406080 - (4761640649*lm*NC*NL)/
          1061424 - (1365*lm^2*NC*NL)/2 - 
         (54066031734302238433042269862948223*NC*NH)/
          104123252537940523265518140000 - (4761640649*lm*NC*NH)/1061424 - 
         (1365*lm^2*NC*NH)/2 - (1175818198405*NM*NC*Pi^2)/972 - 
         (3292445*NC*NL*Pi^2)/972 + (82837002638741753*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(4886264939341981489992592305855600065317921/
            55587933754921847354017951008000 - (4882377629*lm)/117936 - 
           (12285*lm^2)/2 + (3808820938249050821*Pi^2)/233513280 + 
           (67323094997905120711*Im[PolyLog[2, (-1)^(1/3)]])/
            (358999321926960*Sqrt[3]) - 16380*Zeta[3]) + 
         CA*NC*(-305391354592183966734448312047953145928891/
            6948491719365230919252243876000 + (62519953459*lm)/2122848 + 
           (15015*lm^2)/4 - (3808820543555031101*Pi^2)/467026560 - 
           (67323094997905120711*Im[PolyLog[2, (-1)^(1/3)]])/
            (717998643853920*Sqrt[3]) + 8190*Zeta[3])), 
      (27694389153199087440898689102074685693194443587960961*CF^2*NC)/
        1215533049252125101356937526892209525760000 + 
       (904258406153*CF^2*lm*NC)/397528560 + (2737*CF^2*lm^2*NC)/2 + 
       (9769527136411687050372783552515137886257*CF*NM*NC)/
        43170127160066728844886864000 + (813588767093*CF*lm*NM*NC)/
        3577757040 + (2737*CF*lm^2*NM*NC)/18 - 
       (230900397752092903949*CF*NC*NL)/6942279760416000 + 
       (813588767093*CF*lm*NC*NL)/3577757040 + (2737*CF*lm^2*NC*NL)/18 - 
       (108621235814381939100164481724784032211346186797*CF*NC*NH)/
        112893694478180325191586199503756348000000 + 
       (813588767093*CF*lm*NC*NH)/3577757040 + (2737*CF*lm^2*NC*NH)/18 - 
       (8307116523722895964957*CF^2*NC*Pi^2)/1419176959200 - 
       (98*CF^2*lm*NC*Pi^2)/9 - (120357178846993481*CF*NM*NC*Pi^2)/1459458 - 
       (98*CF*lm*NM*NC*Pi^2)/81 + (2180635583*CF*NC*NL*Pi^2)/2084940 - 
       (98*CF*lm*NC*NL*Pi^2)/81 - (98*CF*lm*NC*NH*Pi^2)/81 + 
       (3811322086069369057207*CF^2*NC*Pi^3)/(157026303410852304*Sqrt[3]) + 
       (34499362350675597655*CF*NC*NH*Pi^3)/(274521509459532*Sqrt[3]) + 
       (1118383*CF^2*NC*Pi^4)/3240 - (2221087591302098639377574479*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7859166485713157815200*Sqrt[3]) - 
       (8225598928021324412224*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (26422695285479955*Sqrt[3]) + 
       (300398*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (544474583724195579601*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (605811355751745*Sqrt[3]) + (3942784268648639732*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) + 
       (544474583724195579601*CF^2*NC*Pi*Log[3]^2)/(29078945076083760*
         Sqrt[3]) + (985696067162159933*CF*NC*NH*Pi*Log[3]^2)/
        (10167463313316*Sqrt[3]) + 
       (CF*NC*(CA*(3630163868160817208512013 - 19007225537332032000*lm) + 
          17*CF*(-427078316460873326546113 + 1829572511614848000*lm) + 
          1144*(5*(-17882668327603381853737 + 604171186819200*lm)*NM + 
            1015072558500*(3815 + 2976*lm)*NL + 2*(502442877056009 + 
              1510427967048000*lm)*NH))*Log[x]^2)/103363388528400 - 
       (CF*NC*(-12708604943337401*CA + 25414320615587446*CF + 
          514800*(599975484789*NM + 45136*NL))*Log[x]^3)/1042470 - 
       (170126086337883253862137873*CF^2*NC*PolyGamma[2, 1])/
        4941387170271576 - (13971960697639*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (17172685645786621825*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 - 
       (100104607804573506043481595817*CF^2*NC*Zeta[3])/1766545913372088420 - 
       (15944431141928*CF*NM*NC*Zeta[3])/81 + (960442*CF*NC*NL*Zeta[3])/
        27 - (198894074235218970923*CF*NC*NH*Zeta[3])/617673396283947 + 
       CA*CF*NC*(-55388697380581432884222586234557760091271018603957329/
          4862132197008500405427750107568838103040000 - (30107*lm^2)/36 + 
         (9493846295809546869643*Pi^2)/3243833049600 - 
         (3811322086069369057207*Pi^3)/(314052606821704608*Sqrt[3]) - 
         (74977*Pi^4)/432 + lm*(-1505975101733/650501280 + (539*Pi^2)/81) + 
         (2221087591302098639377574479*Im[PolyLog[2, (-1)^(1/3)]])/
          (15718332971426315630400*Sqrt[3]) - 
         (150199*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (544474583724195579601*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1211622711503490*Sqrt[3]) - (544474583724195579601*Pi*Log[3]^2)/
          (58157890152167520*Sqrt[3]) + (170126086337883253862137873*
           PolyGamma[2, 1])/9882774340543152 + (50052276544785237780029678531*
           Zeta[3])/1766545913372088420) + CF*Log[x]*
        ((-7186156971187284010084977324851*NM*NC)/19350742657112586720 + 
         (2614989503*lm*NM*NC)/347490 + (3185*lm^2*NM*NC)/3 + 
         (1142525397295339*NC*NL)/19264845600 + (2614989503*lm*NC*NL)/
          347490 + (3185*lm^2*NC*NL)/3 + 
         (2573235827508343257623558975125672223*NC*NH)/
          2811327818524394128168989780000 + (2614989503*lm*NC*NH)/347490 + 
         (3185*lm^2*NC*NH)/3 - 74071051465*NM*NC*Pi^2 + 
         (480025*NC*NL*Pi^2)/81 - (3942784268648639732*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CA*NC*(8393926461066280602164757168165576639469/
            2751793817661524605454822937600 - (3084522203*lm)/63180 - 
           (35035*lm^2)/6 + (25416867972034361*Pi^2)/8339760 + 
           (544474583724195579601*Im[PolyLog[2, (-1)^(1/3)]])/
            (3634868134510470*Sqrt[3]) - 12740*Zeta[3]) + 
         CF*NC*(-230837451487028961138304488906736475048339/
            37837164992845963325003815392000 + (1338237964*lm)/19305 + 
           9555*lm^2 - (12708444368032753*Pi^2)/2084940 - 
           (544474583724195579601*Im[PolyLog[2, (-1)^(1/3)]])/
            (1817434067255235*Sqrt[3]) + 25480*Zeta[3])), 
      (-155619828557344187663031964785368589350371656959386965473*CF^2*NC)/
        333804075833083585526482074692706769766400000 - 
       (561188934864611*CF^2*lm*NC)/311662391040 - (18183*CF^2*lm^2*NC)/16 + 
       (42844434909021519067745056837196475011651*CF*NM*NC)/
        1065929065680659971478688000000 - (502158130111691*CF*lm*NM*NC)/
        2804961519360 - (6061*CF*lm^2*NM*NC)/48 + 
       (2569726128106895663*CF*NC*NL)/93453766005600 - 
       (502158130111691*CF*lm*NC*NL)/2804961519360 - (6061*CF*lm^2*NC*NL)/
        48 + (2230069542282857726225951626942453454251052624413*CF*NC*NH)/
        2709448667476327804598068788090152352000000 - 
       (502158130111691*CF*lm*NC*NH)/2804961519360 - (6061*CF*lm^2*NC*NH)/
        48 + (501503140487875968856467239*CF^2*NC*Pi^2)/2861060749747200 + 
       (487*CF^2*lm*NC*Pi^2)/72 - (69802885109058659*CF*NM*NC*Pi^2)/
        3335904 + (487*CF*lm*NM*NC*Pi^2)/648 - (48485527637*CF*NC*NL*Pi^2)/
        58378320 + (487*CF*lm*NC*NL*Pi^2)/648 + (487*CF*lm*NC*NH*Pi^2)/
        648 - (162482302227318109548775*CF^2*NC*Pi^3)/(7537262563720910592*
         Sqrt[3]) - (338963575610361655975*CF*NC*NH*Pi^3)/
        (3294258113514384*Sqrt[3]) - (20604989*CF^2*NC*Pi^4)/77760 + 
       (70586164757467683936977330899*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (264067993919962102590720*Sqrt[3]) + (76202348416004300704451*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(634144686851518920*Sqrt[3]) - 
       (959815*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (32496460445463621909755*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(40710523106517264*Sqrt[3]) - 
       (9684673588867475885*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2541865828329*Sqrt[3]) - (32496460445463621909755*CF^2*NC*Pi*
         Log[3]^2)/(1954105109112828672*Sqrt[3]) - 
       (9684673588867475885*CF*NC*NH*Pi*Log[3]^2)/(122009559759792*
         Sqrt[3]) - (CF*NC*(-35*CA*(-3130811459378178435876764953 + 
            446507319005773945920*lm) + 
          10*CF*(-21915681023754040186507873339 + 2557269190669432599360*
             lm) + 144144*((181498016870319071405177 + 19712303057046600*lm)*
             NM + 3*(33835751950*(253879 + 194196*lm)*NL + 
              3*(729304112913491 + 2190255895227400*lm)*NH)))*Log[x]^2)/
        104190295636627200 + (CF*NC*(-4539369081936316645*CA + 
          9078707074705656143*CF - 180180*(5361967979262*NM - 1472653*NL))*
         Log[x]^3)/14594580 + (16922422691716507672280465761*CF^2*NC*
         PolyGamma[2, 1])/59296646043258912 + 
       (15169278743371*CF*NM*NC*PolyGamma[2, 1])/144 + 
       (39119357578667736863*CF*NC*NH*PolyGamma[2, 1])/14824161510814728 + 
       CA*CF*NC*(505764422852758935364440942664947293542230030517754305571/
          2169726492915043305922133485502594003481600000 + (66671*lm^2)/96 - 
         (501503139620515102586789459*Pi^2)/5722121499494400 + 
         (162482302227318109548775*Pi^3)/(15074525127441821184*Sqrt[3]) + 
         (20698493*Pi^4)/155520 + lm*(952938820952171/509993003520 - 
           (5357*Pi^2)/1296) - (70586164757467683936977330899*
           Im[PolyLog[2, (-1)^(1/3)]])/(528135987839924205181440*Sqrt[3]) + 
         (959815*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 + 
         (32496460445463621909755*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (81421046213034528*Sqrt[3]) + (32496460445463621909755*Pi*Log[3]^2)/
          (3908210218225657344*Sqrt[3]) - (16922422691716507672280465761*
           PolyGamma[2, 1])/118593292086517824 - 
         (15417141962955652450148706305317*Zeta[3])/118711885378604341824) + 
       (15417142887332494764332395760341*CF^2*NC*Zeta[3])/
        59355942689302170912 + (52657171942393*CF*NM*NC*Zeta[3])/216 - 
       (785710*CF*NC*NL*Zeta[3])/27 + (2431457823891308455451*CF*NC*NH*
         Zeta[3])/7412080755407364 + CF*Log[x]*
        ((-357399366185434250043022429600967*NM*NC)/2418842832139073340000 - 
         (116764804249*lm*NM*NC)/19459440 - 910*lm^2*NM*NC - 
         (1996650727005793*NC*NL)/41493513600 - (116764804249*lm*NC*NL)/
          19459440 - 910*lm^2*NC*NL - 
         (12637512540123893070838670974511189173*NC*NH)/
          16867966911146364769013938680000 - (116764804249*lm*NC*NH)/
          19459440 - 910*lm^2*NC*NH - (5361966194843*NM*NC*Pi^2)/324 - 
         (1570933*NC*NL*Pi^2)/324 + (9684673588867475885*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(4102748772283985161767618825241316925958211063/
            4911951964525821420736858943616000 - (119716152649*lm)/2162160 - 
           8190*lm^2 + (7262987475050784385*Pi^2)/46702656 + 
           (32496460445463621909755*Im[PolyLog[2, (-1)^(1/3)]])/
            (122131569319551792*Sqrt[3]) - 21840*Zeta[3]) + 
         CA*NC*(-45130232173070139158401558925705547473478717937/
            108062943219568071256210896759552000 + (139302373849*lm)/
            3538080 + 5005*lm^2 - (7262987362892698345*Pi^2)/93405312 - 
           (32496460445463621909755*Im[PolyLog[2, (-1)^(1/3)]])/
            (244263138639103584*Sqrt[3]) + 10920*Zeta[3])), 
      (207298096148851903867746157766790397229735304485024993531*CF^2*NC)/
        1314985753281844427831596051819753941504000000 + 
       (4839670905865*CF^2*lm*NC)/1731457728 + (6735*CF^2*lm^2*NC)/4 + 
       (503426565064322854907579967894373050456077*CF*NM*NC)/
        239834039778148493582704800000 + (4353780580945*CF*lm*NM*NC)/
        15583119552 + (2245*CF*lm^2*NM*NC)/12 - 
       (3353137624651224326641*CF*NC*NL)/70194162021984000 + 
       (4353780580945*CF*lm*NC*NL)/15583119552 + (2245*CF*lm^2*NC*NL)/12 - 
       (4496747390290817806846615674542086060378156214717317*CF*NC*NH)/
        3304037177554007941317114983636536285646400000 + 
       (4353780580945*CF*lm*NC*NH)/15583119552 + (2245*CF*lm^2*NC*NH)/12 - 
       (26512397292395285528685115*CF^2*NC*Pi^2)/724802056602624 - 
       (25*CF^2*lm*NC*Pi^2)/2 - (82819149380662505*CF*NM*NC*Pi^2)/108108 - 
       (25*CF*lm*NM*NC*Pi^2)/18 + (895161455*CF*NC*NL*Pi^2)/648648 - 
       (25*CF*lm*NC*NL*Pi^2)/18 - (25*CF*lm*NC*NH*Pi^2)/18 + 
       (85325596236678263190695*CF^2*NC*Pi^3)/(2512420854573636864*Sqrt[3]) + 
       (146975621134924049125*CF*NC*NH*Pi^3)/(823564528378596*Sqrt[3]) + 
       (2376965*CF^2*NC*Pi^4)/5184 - (34440613447508508739754965691*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(88022664639987367530240*Sqrt[3]) - 
       (13749717990987687157103*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29442431889534807*Sqrt[3]) + 
       (525275*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
       (17065119247335652638139*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13570174368839088*Sqrt[3]) + 
       (16797213843991319900*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2541865828329*Sqrt[3]) + (17065119247335652638139*CF^2*NC*Pi*
         Log[3]^2)/(651368369704276224*Sqrt[3]) + 
       (4199303460997829975*CF*NC*NH*Pi*Log[3]^2)/(30502389939948*Sqrt[3]) + 
       CF*((-7622293212232046694138953131*CF*NC)/17365049272771200 + 
         CA*(7622292316748630618513851531/34730098545542400 - (782089*lm)/3)*
          NC + 426594*CF*lm*NC - (9228951812529689022047*NM*NC)/1003917915 + 
         (142198*lm*NM*NC)/3 + 60627*NC*NL + (142198*lm*NC*NL)/3 + 
         (57560326287623*NC*NH)/3528923580 + (142198*lm*NC*NH)/3)*
        Log[x]^2 - (CF*NC*(-155526520323761645*CA + 
          22*(14138404283183935*CF + 39312*(6186662398167*NM + 71099*NL)))*
         Log[x]^3)/1945944 - (8910834833631139521868024087*CF^2*NC*
         PolyGamma[2, 1])/29648323021629456 - 
       (85088429986967*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (24412133681407659527*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 - 
       (30935060247313615751442725673569*CF^2*NC*Zeta[3])/
        59355942689302170912 - (47968464841127*CF*NM*NC*Zeta[3])/27 + 
       50216*CF*NC*NL*Zeta[3] - (277722121807111366693*CF*NC*NH*Zeta[3])/
        617673396283947 + CA*CF*NC*
        (-2280278384925850060651766152603206486127164232825390921591/
          28929686572200577412295113140034586713088000000 - (24695*lm^2)/24 + 
         (1395389294460637237041685*Pi^2)/76294953326592 - 
         (85325596236678263190695*Pi^3)/(5024841709147273728*Sqrt[3]) - 
         (2388485*Pi^4)/10368 + lm*(-8064215789425/2833294464 + 
           (275*Pi^2)/36) + (34440613447508508739754965691*
           Im[PolyLog[2, (-1)^(1/3)]])/(176045329279974735060480*Sqrt[3]) - 
         (525275*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 - 
         (17065119247335652638139*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27140348737678176*Sqrt[3]) - (17065119247335652638139*Pi*Log[3]^2)/
          (1302736739408552448*Sqrt[3]) + (8910834833631139521868024087*
           PolyGamma[2, 1])/59296646043258912 + 
         (30935057679697544449981044260657*Zeta[3])/118711885378604341824) + 
       CF*Log[x]*((-186193334394138507616931508313487*NM*NC)/
          53752062936423852000 + (1075881995*lm*NM*NC)/108108 + 
         1400*lm^2*NM*NC + (16290421300292837*NC*NL)/194788994400 + 
         (1075881995*lm*NC*NL)/108108 + 1400*lm^2*NC*NL + 
         (921649125303446301895306258075900605233*NC*NH)/
          709298008613704638537036121494000 + (1075881995*lm*NC*NH)/108108 + 
         1400*lm^2*NC*NH - (6186662454335*NM*NC*Pi^2)/9 + 
         (75299*NC*NL*Pi^2)/9 - (16797213843991319900*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CA*NC*(-30167642074411213384972302609134821211610437/
            8186586607543035701228098239360000 - (1268510795*lm)/19656 - 
           7700*lm^2 + (622104270389943857*Pi^2)/31135104 + 
           (17065119247335652638139*Im[PolyLog[2, (-1)^(1/3)]])/
            (81421046213034528*Sqrt[3]) - 16800*Zeta[3]) + 
         CF*NC*(82959209678338258380302669731817628558057883/
            11256556585371674089188635079120000 + (1101107195*lm)/12012 + 
           12600*lm^2 - (622104379173811049*Pi^2)/15567552 - 
           (17065119247335652638139*Im[PolyLog[2, (-1)^(1/3)]])/
            (40710523106517264*Sqrt[3]) + 33600*Zeta[3])), 
      (-510760526513326808606285519175901930055094926446018129801871*CF^2*NC)/
        114867873154325822078230596291313800184320000000 - 
       (3427630945646837*CF^2*lm*NC)/1558311955200 - (22227*CF^2*lm^2*NC)/
        16 + (3874211696695876120474671621908045873247983*CF*NM*NC)/
        7511880343642116082568928000000 - (3066833030769437*CF*lm*NM*NC)/
        14024807596800 - (7409*CF*lm^2*NM*NC)/48 + 
       (1541314034365694470823*CF*NC*NL)/39484216137366000 - 
       (3066833030769437*CF*lm*NC*NL)/14024807596800 - 
       (7409*CF*lm^2*NC*NL)/48 + 
       (686019672773379481107365779498416803336136933812651411*CF*NC*NH)/
        594726691959721429437080697054576531416352000000 - 
       (3066833030769437*CF*lm*NC*NH)/14024807596800 - 
       (7409*CF*lm^2*NC*NH)/48 + (45324522638763459425687428597*CF^2*NC*
         Pi^2)/27180077122598400 + (557*CF^2*lm*NC*Pi^2)/72 - 
       (9340564957624487897*CF*NM*NC*Pi^2)/38918880 + 
       (557*CF*lm*NM*NC*Pi^2)/648 - (63423502003*CF*NC*NL*Pi^2)/58378320 + 
       (557*CF*lm*NC*NL*Pi^2)/648 + (557*CF*lm*NC*NH*Pi^2)/648 - 
       (506632536173849218056175*CF^2*NC*Pi^3)/(16958840768372048832*
         Sqrt[3]) - (4297766123802290374165*CF*NC*NH*Pi^3)/
        (29648323021629456*Sqrt[3]) - (679829*CF^2*NC*Pi^4)/1944 + 
       (155511663119382000550866225593*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (424394990228510522020800*Sqrt[3]) + (14630572898829676302173573*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(74194928361627713640*Sqrt[3]) - 
       (311878*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (14475215319252834801605*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13085525284237692*Sqrt[3]) - 
       (122793317822922582119*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (14475215319252834801605*CF^2*NC*Pi*Log[3]^2)/(628105213643409216*
         Sqrt[3]) - (122793317822922582119*CF*NC*NH*Pi*Log[3]^2)/
        (1098086037838128*Sqrt[3]) - 
       (CF*NC*(-493*CA*(-76651762605560727886290536741 + 
            1612532449794316050000*lm) + 
          4*(3944*CF*(-4790735189227043909813693366 + 82459045728118434375*
               lm) + 15015*(26999*(6708050825552162129623 + 89137343295000*
                 lm)*NM + 2037953367450*(1540263 + 1180900*lm)*NL + 
              (827573073484026871 + 2406619131621705000*lm)*NH)))*Log[x]^2)/
        3776898216827736000 + (CF*NC*(-86433816758177636483*CA + 
          20*(8643377037033775193*CF - 18018*(63850267365526*NM - 
              2066575*NL)))*Log[x]^3)/29189160 + 
       (1407974268569179165420608675731*CF^2*NC*PolyGamma[2, 1])/
        533669814389330208 + (397506606980401*CF*NM*NC*PolyGamma[2, 1])/
        432 + (434333712005766229615*CF*NC*NH*PolyGamma[2, 1])/
        133417453597332552 + CA*CF*NC*
        (510760523631288522542384370842734527598943497394440151590871/
          229735746308651644156461192582627600368640000000 + 
         (81499*lm^2)/96 - (2385501190927734834481743823*Pi^2)/
          2861060749747200 + (506632536173849218056175*Pi^3)/
          (33917681536744097664*Sqrt[3]) + (3412513*Pi^4)/19440 + 
         lm*(5822017108015037/2549965017600 - (6127*Pi^2)/1296) - 
         (155511663119382000550866225593*Im[PolyLog[2, (-1)^(1/3)]])/
          (848789980457021044041600*Sqrt[3]) + 
         (155939*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (14475215319252834801605*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (26171050568475384*Sqrt[3]) + (14475215319252834801605*Pi*Log[3]^2)/
          (1256210427286818432*Sqrt[3]) - (1407974268569179165420608675731*
           PolyGamma[2, 1])/1067339628778660416 - 
         (3092254217674684521315542342866343*Zeta[3])/
          2671017421018597691040) + (3092254246285011456545127673951643*CF^2*
         NC*Zeta[3])/1335508710509298845520 + 
       (482640360508441*CF*NM*NC*Zeta[3])/216 - (365942*CF*NC*NL*Zeta[3])/
        9 + (30199053579124554338083*CF*NC*NH*Zeta[3])/66708726798666276 + 
       CF*Log[x]*((-124621057312668438508767167868119*NM*NC)/
          81840546952073910000 - (153113689451*lm*NM*NC)/19459440 - 
         1190*lm^2*NM*NC - (471234335207973979*NC*NL)/7012403798400 - 
         (153113689451*lm*NC*NL)/19459440 - 1190*lm^2*NC*NL - 
         (134711714977761074465448733340807141195239*NC*NH)/
          127673641550466834936666501868920000 - (153113689451*lm*NC*NH)/
          19459440 - 1190*lm^2*NC*NH - (63850264694921*NM*NC*Pi^2)/324 - 
         (2195095*NC*NL*Pi^2)/324 + (122793317822922582119*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(5661732241981574999891424400220239295120521041191/
            715122418364788706842572110908800000 - (156973145051*lm)/
            2162160 - 10710*lm^2 + (86433811391042118401*Pi^2)/58378320 + 
           (14475215319252834801605*Im[PolyLog[2, (-1)^(1/3)]])/
            (39256575852713076*Sqrt[3]) - 28560*Zeta[3]) + 
         CA*NC*(-5661732165648982613006686569140499480107356626341/
            1430244836729577413685144221817600000 + (182585895851*lm)/
            3538080 + 6545*lm^2 - (86433811196341532321*Pi^2)/116756640 - 
           (14475215319252834801605*Im[PolyLog[2, (-1)^(1/3)]])/
            (78513151705426152*Sqrt[3]) + 14280*Zeta[3])), 
      (368422483244372988542631891449097279694054166333382282322837*CF^2*NC)/
        366141345679413557874360025678562738087520000000 + 
       (20630202601189*CF^2*lm*NC)/6087156075 + 2044*CF^2*lm^2*NC + 
       (947482269489222728200618822223310197618019583*CF*NM*NC)/
        48566393055075069950497722000000 + (18556511431639*CF*lm*NM*NC)/
        54784404675 + (2044*CF*lm^2*NM*NC)/9 - 
       (1057400957310630506293*CF*NC*NL)/15793686454946400 + 
       (18556511431639*CF*lm*NC*NL)/54784404675 + (2044*CF*lm^2*NC*NL)/9 - 
       (1251394025353389229719489959746686715754969955817731907549*CF*NC*NH)/
        664406358006452291413502664223233354278420341200000 + 
       (18556511431639*CF*lm*NC*NH)/54784404675 + (2044*CF*lm^2*NC*NH)/9 - 
       (7611555120518842597144231*CF^2*NC*Pi^2)/40446543337200 - 
       (128*CF^2*lm*NC*Pi^2)/9 - (25996715578630821224*CF*NM*NC*Pi^2)/
        3648645 - (128*CF*lm*NM*NC*Pi^2)/81 + (6525212696*CF*NC*NL*Pi^2)/
        3648645 - (128*CF*lm*NC*NL*Pi^2)/81 - (128*CF*lm*NC*NH*Pi^2)/81 + 
       (295676378373515589631925*CF^2*NC*Pi^3)/(6359565288139518312*
         Sqrt[3]) + (1377953336283460235320*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) + (80689*CF^2*NC*Pi^4)/135 - 
       (591843206651785148874408093853*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1114036849349840120304600*Sqrt[3]) - 
       (18933975662533596092444608*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) + 
       (507824*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (118270551349406235852770*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68699007742247883*Sqrt[3]) + 
       (629921525158153250432*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (59135275674703117926385*CF^2*NC*Pi*Log[3]^2)/(1648776185813949192*
         Sqrt[3]) + (39370095322384578152*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + CF*((-170202703737204530499314696*CF*NC)/
          75369137468625 + CA*(6127297135311768037644766241/
            5426577897741000 - (9754096*lm)/27)*NC + (1773472*CF*lm*NC)/3 - 
         (3862591994749758611708989*NM*NC)/45176306175 + 
         (1773472*lm*NM*NC)/27 + (6792112*NC*NL)/81 + (1773472*lm*NC*NL)/
          27 + (17195470931801143*NC*NH)/738427259115 + 
         (1773472*lm*NC*NH)/27)*Log[x]^2 - 
       (4*CF*NC*(-419013570497854309*CA + 4*(209505381025437983*CF + 
            90090*(64698072271977*NM + 110842*NL)))*Log[x]^3)/3648645 - 
       (131141819952550521893868107767*CF^2*NC*PolyGamma[2, 1])/
        50031545098999707 - (388552908081550*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (1372883266259337586258*CF*NC*NH*PolyGamma[2, 1])/50031545098999707 - 
       (1197701428025267991657495767459372*CF^2*NC*Zeta[3])/
        250407883220493533535 - (144016481195732*CF*NM*NC*Zeta[3])/9 + 
       (623968*CF*NC*NL*Zeta[3])/9 - (30759190582215659377660*CF*NC*NH*
         Zeta[3])/50031545098999707 + CA*CF*NC*
        (-23026403744965382927590593392782681561039961686770187473607/
          45767668209926694734295003209820342260940000000 - (11242*lm^2)/9 + 
         (15223110138493753786968917*Pi^2)/161786173348800 - 
         (295676378373515589631925*Pi^3)/(12719130576279036624*Sqrt[3]) - 
         (243091*Pi^4)/810 + lm*(-34391971271839/9960800850 + 
           (704*Pi^2)/81) + (591843206651785148874408093853*
           Im[PolyLog[2, (-1)^(1/3)]])/(2228073698699680240609200*Sqrt[3]) - 
         (253912*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (59135275674703117926385*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (68699007742247883*Sqrt[3]) - (59135275674703117926385*Pi*Log[3]^2)/
          (3297552371627898384*Sqrt[3]) + (131141819952550521893868107767*
           PolyGamma[2, 1])/100063090197999414 + 
         (1197701413201619029315371168099707*Zeta[3])/
          500815766440987067070) + CF*Log[x]*
        ((-6507894074464032386653915333538987*NM*NC)/201570236011589445000 + 
         (15716248552*lm*NM*NC)/1216215 + (5440*lm^2*NM*NC)/3 + 
         (103178658069713*NC*NL)/894439260 + (15716248552*lm*NC*NL)/
          1216215 + (5440*lm^2*NC*NL)/3 + 
         (16602526165145910640385156873811893305174417*NC*NH)/
          9202077714749897128060238122202409000 + (15716248552*lm*NC*NH)/
          1216215 + (5440*lm^2*NC*NH)/3 - (57509397659872*NM*NC*Pi^2)/9 + 
         (935696*NC*NL*Pi^2)/81 - (629921525158153250432*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(-709259965649326863400825893245269789257332341249/
            2279452708537764003060698603521800000 - (9261562676*lm)/110565 - 
           (29920*lm^2)/3 + (1676053105080703301*Pi^2)/14594580 + 
           (59135275674703117926385*Im[PolyLog[2, (-1)^(1/3)]])/
            (206097023226743649*Sqrt[3]) - 21760*Zeta[3]) + 
         CF*NC*(1418519444336492759694717373269200451831849960923/
            2279452708537764003060698603521800000 + (16083815752*lm)/135135 + 
           16320*lm^2 - (1676053175135858471*Pi^2)/7297290 - 
           (118270551349406235852770*Im[PolyLog[2, (-1)^(1/3)]])/
            (206097023226743649*Sqrt[3]) + 43520*Zeta[3])), 
      (-691246655507399264911905530796842994541342064341380123051024305003*
         CF^2*NC)/16328816054446111566624487618330453246567360512000000 - 
       (1984549508742707*CF^2*lm*NC)/747989738496 - (26829*CF^2*lm^2*NC)/16 + 
       (1878005565075843002221618652157559324266148608422777*CF*NM*NC)/
        314890983640084664985724075620096000000 - 
       (1775509751512403*CF*lm*NM*NC)/6731907646464 - 
       (2981*CF*lm^2*NM*NC)/16 + (20527884987428216737741*CF*NC*NL)/
        379048474918713600 - (1775509751512403*CF*lm*NC*NL)/6731907646464 - 
       (2981*CF*lm^2*NC*NL)/16 + 
       (134650973380564917621753899665324947045749518100725753748401*CF*NC*
         NH)/85044013824825893300928341020573869347637803673600000 - 
       (1775509751512403*CF*lm*NC*NH)/6731907646464 - 
       (2981*CF*lm^2*NC*NH)/16 + (132423148141009569890556594719*CF^2*NC*
         Pi^2)/8363100653107200 + (1895*CF^2*lm*NC*Pi^2)/216 - 
       (271843159945343444*CF*NM*NC*Pi^2)/104247 + (1895*CF*lm*NM*NC*Pi^2)/
        1944 - (195758167277*CF*NC*NL*Pi^2)/140107968 + 
       (1895*CF*lm*NC*NL*Pi^2)/1944 + (1895*CF*lm*NC*NH*Pi^2)/1944 - 
       (8253686052905466163161365*CF^2*NC*Pi^3)/(203506089220464585984*
         Sqrt[3]) - (4445621841982299176975*CF*NC*NH*Pi^3)/
        (22236242266222092*Sqrt[3]) - (17621657*CF^2*NC*Pi^4)/38880 + 
       (35160994089091206038030293330259*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (71298358358389767699494400*Sqrt[3]) + 
       (13667503868775580228440611*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (44516957016976628184*Sqrt[3]) - 
       (265897*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (1650737210581093232632273*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1099184123875966128*
         Sqrt[3]) - (508071067655119905940*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (1650737210581093232632273*CF^2*NC*Pi*Log[3]^2)/(52760837946046374144*
         Sqrt[3]) - (127017766913779976485*CF*NC*NH*Pi*Log[3]^2)/
        (823564528378596*Sqrt[3]) + 
       CF*((114824111061224281575339483565217*CF*NC)/604303714692437760 - 
         (4257170*CF*lm*NC)/9 + CA*(-5467814808037652865521341580891/
            57552734732613120 + (23414435*lm)/81)*NC - 
         (11806938345782940614449129609*NM*NC)/377312509173600 - 
         (4257170*lm*NM*NC)/81 - (11083087*NC*NL)/162 - 
         (4257170*lm*NC*NL)/81 - (43496372564024570969*NC*NH)/
          2339337556876320 - (4257170*lm*NC*NH)/81)*Log[x]^2 + 
       (CF*NC*(-1642827348366337937969*CA + 4*(821413606685495258837*CF - 
            120120*(1063517441228267*NM - 4257170*NL)))*Log[x]^3)/
        58378320 + (39021268048221040142983880518919*CF^2*NC*PolyGamma[2, 1])/
        1601009443167990624 + (5203476120973537*CF*NM*NC*PolyGamma[2, 1])/
        648 + (3157912101651265517567*CF*NC*NH*PolyGamma[2, 1])/
        800504721583995312 + CA*CF*NC*
        (4838726584705570873997477221523814065001875928216298965602817132521/
          228603424762245561932742826656626345451943047168000000 + 
         (32791*lm^2)/32 - (132423148136484961462156879679*Pi^2)/
          16726201306214400 + (8253686052905466163161365*Pi^3)/
          (407012178440929171968*Sqrt[3]) + (5894099*Pi^4)/25920 + 
         lm*(3371813352180179/1223983208448 - (20845*Pi^2)/3888) - 
         (35160994089091206038030293330259*Im[PolyLog[2, (-1)^(1/3)]])/
          (142596716716779535398988800*Sqrt[3]) + 
         (265897*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (1650737210581093232632273*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2198368247751932256*Sqrt[3]) + (1650737210581093232632273*Pi*
           Log[3]^2)/(105521675892092748288*Sqrt[3]) - 
         (39021268048221040142983880518919*PolyGamma[2, 1])/
          3202018886335981248 - (165107171275567179531681531345896263*
           Zeta[3])/16026104526111586146240) + 
       (165107171507391384850509809817771823*CF^2*NC*Zeta[3])/
        8013052263055793073120 + (6621499507998703*CF*NM*NC*Zeta[3])/324 - 
       (3003985*CF*NC*NL*Zeta[3])/54 + (245192993601802667674727*CF*NC*NH*
         Zeta[3])/400252360791997656 + CF*Log[x]*
        ((-13553763675118510734094637817424108451749*NM*NC)/
          878794627030111013302080000 - (236804594699*lm*NM*NC)/23351328 - 
         1530*lm^2*NM*NC - (38665989880646501*NC*NL)/420744227904 - 
         (236804594699*lm*NC*NL)/23351328 - 1530*lm^2*NC*NL - 
         (77888717057648260922376201506135905424113339*NC*NH)/
          53539361249453946926895930892814016000 - (236804594699*lm*NC*NH)/
          23351328 - 1530*lm^2*NC*NH - (1063517435421997*NM*NC*Pi^2)/486 - 
         (2252515*NC*NL*Pi^2)/243 + (508071067655119905940*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(70664537720649658772266705713967576956313394539896689/
            943763558341050843851838781815056640000 - (242759183339*lm)/
            2594592 - 13770*lm^2 + (1095218222407174378523*Pi^2)/77837760 + 
           (1650737210581093232632273*Im[PolyLog[2, (-1)^(1/3)]])/
            (3297552371627898384*Sqrt[3]) - 36720*Zeta[3]) + 
         CA*NC*(-1837277977302688383921967191758466394415577116122672939/
            49075705033734643880295616654382945280000 + (282275998859*lm)/
            4245696 + 8415*lm^2 - (1095218222053809366523*Pi^2)/155675520 - 
           (1650737210581093232632273*Im[PolyLog[2, (-1)^(1/3)]])/
            (6595104743255796768*Sqrt[3]) + 18360*Zeta[3])), 
      (9326194590821818956890157847633890478680043609689263894001752452393*
         CF^2*NC)/1714525685716841714495571199924697590889572853760000000 + 
       (6329113282776541*CF^2*lm*NC)/1558311955200 + (9809*CF^2*lm^2*NC)/4 + 
       (2293399492926649529128298660977108868105137891944539*CF*NM*NC)/
        12634514775682409397575348713152000000 + 
       (5692218200753341*CF*lm*NM*NC)/14024807596800 + 
       (9809*CF*lm^2*NM*NC)/36 - (33158175923826843794623*CF*NC*NL)/
        360998547541632000 + (5692218200753341*CF*lm*NC*NL)/14024807596800 + 
       (9809*CF*lm^2*NC*NL)/36 - 
       (81539115128970989436346461831672027243139520740705322671817*CF*NC*
         NH)/31891505184309709987848127882715201005364176377600000 + 
       (5692218200753341*CF*lm*NC*NH)/14024807596800 + 
       (9809*CF*lm^2*NC*NH)/36 - (32721763539309665720517720769*CF^2*NC*
         Pi^2)/72480205660262400 - (289*CF^2*lm*NC*Pi^2)/18 - 
       (1935360347584524811609*CF*NM*NC*Pi^2)/29189160 - 
       (289*CF*lm*NM*NC*Pi^2)/162 + (133171976849*CF*NC*NL*Pi^2)/58378320 - 
       (289*CF*lm*NC*NL*Pi^2)/162 - (289*CF*lm*NC*NH*Pi^2)/162 + 
       (76243602501296304315863605*CF^2*NC*Pi^3)/(1221036535322787515904*
         Sqrt[3]) + (5630652094230359539070*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) + (19864177*CF^2*NC*Pi^4)/25920 - 
       (60657626708790951932843114666147*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (85558030030067721239393280*Sqrt[3]) - 
       (80723817099838686133029863*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (83469294406831177845*Sqrt[3]) + 
       (2578985*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 + 
       (15248720500259260863172721*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6595104743255796768*
         Sqrt[3]) + (2574012385933878646432*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (15248720500259260863172721*CF^2*NC*Pi*Log[3]^2)/
        (316565027676278244864*Sqrt[3]) + (160875774120867415402*CF*NC*NH*Pi*
         Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((-54563517875613020092403279909911*CF*NC)/10071728578207296000 + 
         CA*(54563516847026590491793069541791/20143457156414592000 - 
           (13249324*lm)/27)*NC + (2408968*CF*lm*NC)/3 - 
         (8339119371078810933732480979*NM*NC)/10480903032600 + 
         (2408968*lm*NM*NC)/27 + (9210532*NC*NL)/81 + (2408968*lm*NC*NL)/
          27 + (211041387649064743*NC*NH)/6498159880212 + 
         (2408968*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-6752092927421042029*CA + 8*(1688019196100870419*CF + 
            45045*(2407683165307905*NM + 602242*NL)))*Log[x]^3)/3648645 - 
       (164527608422743811499676307373707*CF^2*NC*PolyGamma[2, 1])/
        7204542494255957808 - (262805251721869*CF*NM*NC*PolyGamma[2, 1])/2 + 
       (33618565325553659015287*CF*NC*NH*PolyGamma[2, 1])/
        900567811781994726 - (1264153567274474399056176202353488993*CF^2*NC*
         Zeta[3])/28846988147000855063232 - (3885497593645513*CF*NM*NC*
         Zeta[3])/27 + (844798*CF*NC*NL*Zeta[3])/9 - 
       (371593544831440302161129*CF*NC*NH*Zeta[3])/450283905890997363 + 
       CA*CF*NC*
        (-717399572601820218513419637471574175444750003189511008384842322761/
          263773182417975648383934030757645783213780439040000000 - 
         (107899*lm^2)/72 + (1924809612972950170410723937*Pi^2)/
          8527083018854400 - (76243602501296304315863605*Pi^3)/
          (2442073070645575031808*Sqrt[3]) - (19938161*Pi^4)/51840 + 
         lm*(-10555780645294141/2549965017600 + (3179*Pi^2)/324) + 
         (60657626708790951932843114666147*Im[PolyLog[2, (-1)^(1/3)]])/
          (171116060060135442478786560*Sqrt[3]) - 
         (2578985*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 - 
         (15248720500259260863172721*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (13190209486511593536*Sqrt[3]) - (15248720500259260863172721*Pi*
           Log[3]^2)/(633130055352556489728*Sqrt[3]) + 
         (164527608422743811499676307373707*PolyGamma[2, 1])/
          14409084988511915616 + (1264153564979393598586714673095219457*
           Zeta[3])/57693976294001710126464) + 
       CF*Log[x]*((-2446884733101469942443134941061715305833*NM*NC)/
          8136987287315842715760000 + (160657835249*lm*NM*NC)/9729720 + 
         2312*lm^2*NM*NC + (273577471125809453*NC*NL)/1753100949600 + 
         (160657835249*lm*NC*NL)/9729720 + 2312*lm^2*NC*NL + 
         (49325465831068969098949720846150229628233603*NC*NH)/
          20077260468545230097585974084805256000 + (160657835249*lm*NC*NH)/
          9729720 + 2312*lm^2*NC*NH - (535040703525358*NM*NC*Pi^2)/9 + 
         (1266908*NC*NL*Pi^2)/81 - (2574012385933878646432*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(-7777675653980217518452082502634506832614971983652562611/
            1472271151012039316408868499631488358400000 - (189287978609*lm)/
            1769040 - 12716*lm^2 + (86426769001011356485*Pi^2)/186810624 + 
           (15248720500259260863172721*Im[PolyLog[2, (-1)^(1/3)]])/
            (39570628459534780608*Sqrt[3]) - 27744*Zeta[3]) + 
         CF*NC*(7777675448037144148769737460720071430030990612884151411/
            736135575506019658204434249815744179200000 + (164407020689*lm)/
            1081080 + 20808*lm^2 - (86426770210050916213*Pi^2)/93405312 - 
           (15248720500259260863172721*Im[PolyLog[2, (-1)^(1/3)]])/
            (19785314229767390304*Sqrt[3]) + 55488*Zeta[3])), 
      (-805989907097946424481686755489977851769922234102297550922473484456797\
3801*CF^2*NC)/20038070537405476979564735711267615095690419301573632000000 - 
       (1900433576766934057*CF^2*lm*NC)/600469540070400 - 
       (32025*CF^2*lm^2*NC)/16 + 
       (105931321753513946010305701109203566163384223591793382163*CF*NM*NC)/
        1626025664227772124128882362378368522240000 - 
       (1700120691134074057*CF*lm*NM*NC)/5404225860633600 - 
       (10675*CF*lm^2*NM*NC)/48 + (827623124863797271007*CF*NC*NL)/
        11239881516864000 - (1700120691134074057*CF*lm*NC*NL)/
        5404225860633600 - (10675*CF*lm^2*NC*NL)/48 + 
       (25124656146202458239669672103083893792808787975477175333999*CF*NC*
         NH)/11775324991129739072436231833617920371211388200960000 - 
       (1700120691134074057*CF*lm*NC*NH)/5404225860633600 - 
       (10675*CF*lm^2*NC*NH)/48 + (14222687228881362544219293749149*CF^2*NC*
         Pi^2)/94781807401881600 + (79*CF^2*lm*NC*Pi^2)/8 - 
       (679295428394715990937*CF*NM*NC*Pi^2)/24810786 + 
       (79*CF*lm*NM*NC*Pi^2)/72 - (2342380261099*CF*NC*NL*Pi^2)/
        1323241920 + (79*CF*lm*NC*NL*Pi^2)/72 + (79*CF*lm*NC*NH*Pi^2)/72 - 
       (259021733942062214988104095*CF^2*NC*Pi^3)/(4790220253958627947008*
         Sqrt[3]) - (54158064388605540152125*CF*NC*NH*Pi^3)/
        (200126180395998828*Sqrt[3]) - (14985581*CF^2*NC*Pi^4)/25920 + 
       (18627401265512753231990903480031797*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(28530312321564890120982297600*
         Sqrt[3]) + (183931440546488650323170329*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(400652613152789653656*Sqrt[3]) - 
       (670423*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (51804346788412442997620819*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(25873103223541971936*
         Sqrt[3]) - (6189493072983490303100*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (51804346788412442997620819*CF^2*NC*Pi*Log[3]^2)/
        (1241908954730014652928*Sqrt[3]) - (1547373268245872575775*CF*NC*NH*
         Pi*Log[3]^2)/(7412080755407364*Sqrt[3]) + 
       CF*((8020431915820730641402982041437061*CF*NC)/4454098708292513280 - 
         637398*CF*lm*NC + CA*(-5734608819149164845454397939370762331/
            6369361152858293990400 + 389521*lm)*NC - 
         (51239047680474929130728334607*NM*NC)/155955837125088 - 
         70822*lm*NM*NC - (14908337*NC*NL)/162 - 70822*lm*NC*NL - 
         (6678721489571958023*NC*NH)/259926395208480 - 70822*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-88299489318892636889349*CA + 
          884*(199772597805831645961*CF - 9240*(3775063992335219*NM - 
              1912194*NL)))*Log[x]^3)/330810480 + 
       (9726616942844108556604320985622023*CF^2*NC*PolyGamma[2, 1])/
        43227254965535746848 + (5040613022753489*CF*NM*NC*PolyGamma[2, 1])/
        72 + (101647031311154377808917*CF*NC*NH*PolyGamma[2, 1])/
        21613627482767873424 + CA*CF*NC*(104778687911153194829532112300961256\
822163249128105315477151852824906289513/
          520989833972542401468683128492957992487950901840914432000000 + 
         (117425*lm^2)/96 - (748562485727103763314932731711*Pi^2)/
          9977032358092800 + (259021733942062214988104095*Pi^3)/
          (9580440507917255894016*Sqrt[3]) + (3006217*Pi^4)/10368 + 
         lm*(3229782726875914057/982586520115200 - (869*Pi^2)/144) - 
         (18627401265512753231990903480031797*Im[PolyLog[2, (-1)^(1/3)]])/
          (57060624643129780241964595200*Sqrt[3]) + 
         (670423*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (51804346788412442997620819*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (51746206447083943872*Sqrt[3]) + (51804346788412442997620819*Pi*
           Log[3]^2)/(2483817909460029305856*Sqrt[3]) - 
         (9726616942844108556604320985622023*PolyGamma[2, 1])/
          86454509931071493696 - (103608305667477121907330706737149551071*
           Zeta[3])/1131689534997725852480640) + 
       (103608305689223433989628349781281368191*CF^2*NC*Zeta[3])/
        565844767498862926240320 + (20155257784343681*CF*NM*NC*Zeta[3])/
        108 - (448267*CF*NC*NL*Zeta[3])/6 + (8804380141033050491947357*CF*NC*
         NH*Zeta[3])/10806813741383936712 + 
       CF*Log[x]*((-1735393988957721552564435647435971477536013*NM*NC)/
          11260288487679155783777318400 - (2838953508269*lm*NM*NC)/
          220540320 - 1938*lm^2*NM*NC - (3697219386251681*NC*NL)/
          29967537600 - (2838953508269*lm*NC*NL)/220540320 - 
         1938*lm^2*NC*NL - (2086923432280672369737129017163804985925862251*
           NC*NH)/1060079352739188149152539431677717516800 - 
         (2838953508269*lm*NC*NH)/220540320 - 1938*lm^2*NC*NH - 
         (3775063989604781*NM*NC*Pi^2)/162 - (37349*NC*NL*Pi^2)/3 + 
         (6189493072983490303100*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1853020188851841*Sqrt[3]) + 
         CF*NC*(392232443883718793671531109359041417829688060083211924302181/
            555057549094238914896269646426452891796480000 - 
           (2910188031629*lm)/24504480 - 17442*lm^2 + 
           (27169073601888877373783*Pi^2)/203575680 + 
           (51804346788412442997620819*Im[PolyLog[2, (-1)^(1/3)]])/
            (77619309670625915808*Sqrt[3]) - 46512*Zeta[3]) + 
         CA*NC*(-509902176918453515955684402316499399979999885709980734581406\
3/14431496276450211787303010807087775186708480000 + (3382926232109*lm)/
            40098240 + 10659*lm^2 - (27169073600653029425063*Pi^2)/
            407151360 - (51804346788412442997620819*Im[PolyLog[2, (-1)^
                (1/3)]])/(155238619341251831616*Sqrt[3]) + 23256*Zeta[3])), 
      (7944681149608355003744342938267179924428201908016542739678742056278680\
07*CF^2*NC)/46516949461834142988275279329728392186424187664367360000000 + 
       (6695687342468381*CF^2*lm*NC)/1389975787200 + (5823*CF^2*lm^2*NC)/2 + 
       (63600747510235883602186975906162391621417379684682127351*CF*NM*NC)/
        37639482968235465836316721351351123200000 + 
       (6021201591729581*CF*lm*NM*NC)/12509782084800 + 
       (647*CF*lm^2*NM*NC)/2 - (955678109372701508481943*CF*NC*NL)/
        7728042980706048000 + (6021201591729581*CF*lm*NC*NL)/
        12509782084800 + (647*CF*lm^2*NC*NL)/2 - 
       (19429854213140532000222052755972483881789637492814543494137*CF*NC*
         NH)/5694911640055305354972879979056285893815031496000000 + 
       (6021201591729581*CF*lm*NC*NH)/12509782084800 + 
       (647*CF*lm^2*NC*NH)/2 + (355615744596836312916892686521*CF^2*NC*Pi^2)/
        51340145676019200 - 18*CF^2*lm*NC*Pi^2 - 
       (1260116487498011557789*CF*NM*NC*Pi^2)/2042040 - 
       2*CF*lm*NM*NC*Pi^2 + (2197228753*CF*NC*NL*Pi^2)/765765 - 
       2*CF*lm*NC*NL*Pi^2 - 2*CF*lm*NC*NH*Pi^2 + 
       (58347432847267839408778835*CF^2*NC*Pi^3)/(707646173880251855808*
         Sqrt[3]) + (30150252797235754174495*CF*NC*NH*Pi^3)/
        (66708726798666276*Sqrt[3]) + (209179*CF^2*NC*Pi^4)/216 - 
       (3926364521145951093617279878191379*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4214705229322086040599657600*Sqrt[3]) - 
       (224482039510386599592236939*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (166938588813662355690*Sqrt[3]) + 89738*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 + (11669486569453567881755767*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3822162976205064036*
         Sqrt[3]) + (3445743176826943334228*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (11669486569453567881755767*CF^2*NC*Pi*Log[3]^2)/
        (183463822857843073728*Sqrt[3]) + (861435794206735833557*CF*NC*NH*Pi*
         Log[3]^2)/(2470693585135788*Sqrt[3]) + 
       CF*((55148002635250466553771994208108149*CF*NC)/
          663475120089405624000 + CA*(-265134628497968954566156097398813/
            6379568462398131000 - 654874*lm)*NC + 1071612*CF*lm*NC - 
         (13366434877554218072826235601*NM*NC)/1805044411170 + 
         119068*lm*NM*NC + (454580*NC*NL)/3 + 119068*lm*NC*NL + 
         (800989658154369833*NC*NH)/18050444111700 + 119068*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-96718187827726336929*CA + 
          680*(284465763275718359*CF - 108108*(829888117755084*NM + 
              29767*NL)))*Log[x]^3)/27567540 - 
       (2147788089668470140646159521615253*CF^2*NC*PolyGamma[2, 1])/
        10806813741383936712 - (2399177079126203*CF*NM*NC*PolyGamma[2, 1])/
        2 + (67375690666806988965811*CF*NC*NH*PolyGamma[2, 1])/
        1350851717672992089 - (368715073129187026608991373741427881947*CF^2*
         NC*Zeta[3])/919497747185652255140520 - 1292659589657657*CF*NM*NC*
        Zeta[3] + 124906*CF*NC*NL*Zeta[3] - (1472007486870973296397990*CF*NC*
         NH*Zeta[3])/1350851717672992089 + 
       CA*CF*NC*(-11122553535487710025416854689479613919262596993399028955017\
316693035630473/
          1302474584931356003671707821232394981219877254602286080000000 - 
         (7117*lm^2)/4 - (118538581567946909971992060137*Pi^2)/
          34226763784012800 - (58347432847267839408778835*Pi^3)/
          (1415292347760503711616*Sqrt[3]) - (1049351*Pi^4)/2160 + 
         lm*(-11171820051916781/2274505833600 + 11*Pi^2) + 
         (3926364521145951093617279878191379*Im[PolyLog[2, (-1)^(1/3)]])/
          (8429410458644172081199315200*Sqrt[3]) - 
         44869*Im[PolyLog[2, (-1)^(1/3)]]^2 - (11669486569453567881755767*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7644325952410128072*
           Sqrt[3]) - (11669486569453567881755767*Pi*Log[3]^2)/
          (366927645715686147456*Sqrt[3]) + 
         (2147788089668470140646159521615253*PolyGamma[2, 1])/
          21613627482767873424 + (368715073032442794817635478943129986297*
           Zeta[3])/1838995494371304510281040) + 
       CF*Log[x]*((-1459055425148398402622527670472773197109333*NM*NC)/
          521309652207368323323024000 + (5309801936*lm*NM*NC)/255255 + 
         2907*lm^2*NM*NC + (916187696824783973*NC*NL)/4415217206400 + 
         (5309801936*lm*NC*NL)/255255 + 2907*lm^2*NC*NL + 
         (7261403571007208088635208934723751368899500063*NC*NH)/
          2208498651539975310734457149328578160000 + (5309801936*lm*NC*NH)/
          255255 + 2907*lm^2*NC*NH - (1659776235568529*NM*NC*Pi^2)/3 + 
         (62441*NC*NL*Pi^2)/3 - (3445743176826943334228*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(-314455635505814294695535954213635430696901032874007062809929/
            4509842586390691183532190877214929745846400000 - 
           (3127099513*lm)/23205 - (31977*lm^2)/2 - 
           (64478802637926259721*Pi^2)/73513440 + (11669486569453567881755767*
             Im[PolyLog[2, (-1)^(1/3)]])/(22932977857230384216*Sqrt[3]) - 
           34884*Zeta[3]) + CF*NC*
          (628911269383554351232029295644398298825020891041748458202333/
            4509842586390691183532190877214929745846400000 + 
           (32600837901*lm)/170170 + 26163*lm^2 + (193436406021113154313*
             Pi^2)/110270160 - (11669486569453567881755767*
             Im[PolyLog[2, (-1)^(1/3)]])/(11466488928615192108*Sqrt[3]) + 
           69768*Zeta[3])), (-26825363036636089979617369840477238262259649082\
216761699020098051079490669201*CF^2*NC)/
        7033362758629322419827222234654932898587337174852344832000000 - 
       (448943711034099889*CF^2*lm*NC)/120093908014080 - 
       (37851*CF^2*lm^2*NC)/16 + 
       (620244800348817013646700489779715291881255015213509497553*CF*NM*NC)/
        903347591237651180071601312432426956800000 - 
       (401592934864923409*CF*lm*NM*NC)/1080845172126720 - 
       (12617*CF*lm^2*NM*NC)/48 + (19152310659939317634705583*CF*NC*NL)/
        194746683113792409600 - (401592934864923409*CF*lm*NC*NL)/
        1080845172126720 - (12617*CF*lm^2*NC*NL)/48 + 
       (17192986496535334238710027779809933367235100694005095101776371*CF*NC*
         NH)/6078145693950791785919290255293955956316466556672000000 - 
       (401592934864923409*CF*lm*NC*NH)/1080845172126720 - 
       (12617*CF*lm^2*NC*NH)/48 + (1748777180442355154420207455363261*CF^2*
         NC*Pi^2)/1232163496224460800 + (265*CF^2*lm*NC*Pi^2)/24 - 
       (9288037064694465938741*CF*NM*NC*Pi^2)/33081048 + 
       (265*CF*lm*NM*NC*Pi^2)/216 - (585711265627*CF*NC*NL*Pi^2)/
        264648384 + (265*CF*lm*NC*NL*Pi^2)/216 + (265*CF*lm*NC*NH*Pi^2)/
        216 - (119282328715855309802316172205*CF^2*NC*Pi^3)/
        (1681367309139478409399808*Sqrt[3]) - 
       (1946585487673742177194625*CF*NC*NH*Pi^3)/(5403406870691968356*
         Sqrt[3]) - (18849233*CF^2*NC*Pi^4)/25920 + 
       (8529785367572970799319172580537767031*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10014139624869276432464786457600*
         Sqrt[3]) + (7188692387087675252953567643*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10817620555125320648712*Sqrt[3]) - 
       (834499*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (23856465743171061960463234441*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9081459231463232149536*
         Sqrt[3]) - (222466912876999105965100*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (23856465743171061960463234441*CF^2*NC*Pi*Log[3]^2)/
        (435910043110235143177728*Sqrt[3]) - (55616728219249776491275*CF*NC*
         NH*Pi*Log[3]^2)/(200126180395998828*Sqrt[3]) + 
       CF*((54239198633523067742866276837278002071*CF*NC)/
          3184680576429146995200 - 844560*CF*lm*NC + 
         CA*(-54239198632637614318231694709154317931/6369361152858293990400 + 
           516120*lm)*NC - (8845881467992083055693096549*NM*NC)/
          2625519143520 - 93840*lm*NM*NC - (2191453*NC*NL)/18 - 
         93840*lm*NC*NL - (135769754480403800507*NC*NH)/3898895928127200 - 
         93840*lm*NC*NH)*Log[x]^2 + (CF*NC*(-835881860015125351160251*CA + 
          8*(208970464623958771681499*CF - 413513100*(96536311609933*NM - 
              6256*NL)))*Log[x]^3)/330810480 + 
       (807656323863458115489298294454816489*CF^2*NC*PolyGamma[2, 1])/
        389045294689821721632 + (263398495725542615*CF*NM*NC*
         PolyGamma[2, 1])/432 + (67139821688280880225397*CF*NC*NH*
         PolyGamma[2, 1])/12157665459056928801 + 
       CA*CF*NC*(268253630362286736442532558666275972319553483922165573012451\
91279517731675701/
          14066725517258644839654444469309865797174674349704689664000000 + 
         (138787*lm^2)/96 - (1748777180441256433655720862195341*Pi^2)/
          2464326992448921600 + (119282328715855309802316172205*Pi^3)/
          (3362734618278956818799616*Sqrt[3]) + (18900113*Pi^4)/51840 + 
         lm*(763180680156816529/196517304023040 - (2915*Pi^2)/432) - 
         (8529785367572970799319172580537767031*Im[PolyLog[2, (-1)^(1/3)]])/
          (20028279249738552864929572915200*Sqrt[3]) + 
         (834499*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (23856465743171061960463234441*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(18162918462926464299072*Sqrt[3]) + 
         (23856465743171061960463234441*Pi*Log[3]^2)/
          (871820086220470286355456*Sqrt[3]) - 
         (807656323863458115489298294454816489*PolyGamma[2, 1])/
          778090589379643443264 - (107595909354771439343237295044404856329111*
           Zeta[3])/132407675594733924740234880) + 
       (107595909358101604767502842609119614069111*CF^2*NC*Zeta[3])/
        66203837797366962370117440 + (367657712423060675*CF*NM*NC*Zeta[3])/
        216 - (1776595*CF*NC*NL*Zeta[3])/18 + 
       (12970712818324874291379859*CF*NC*NH*Zeta[3])/12157665459056928801 + 
       CF*Log[x]*((-9530559025727587964570290022577880020772187*NM*NC)/
          6255715826488419879876288000 - (26336776447*lm*NM*NC)/1633632 - 
         (4845*lm^2*NM*NC)/2 - (2589773826247476007*NC*NL)/15894781943040 - 
         (26336776447*lm*NC*NL)/1633632 - (4845*lm^2*NC*NL)/2 - 
         (1874755306299858208028549170291378504355506032403*NC*NH)/
          715553563098952000677964116382459323840000 - 
         (26336776447*lm*NC*NH)/1633632 - (4845*lm^2*NC*NH)/2 - 
         (1448044674009595*NM*NC*Pi^2)/6 - (32895*NC*NL*Pi^2)/2 + 
         (222466912876999105965100*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CF*NC*
          (1296823413911062468171858660978230667737278008519402217994764911/
            194825199732077859128590645895684965020564480000 - 
           (80989066101*lm)/544544 - (43605*lm^2)/2 + 
           (3343527439462563924449807*Pi^2)/2646483840 + 
           (23856465743171061960463234441*Im[PolyLog[2, (-1)^(1/3)]])/
            (27244377694389696448608*Sqrt[3]) - 58140*Zeta[3]) + 
         CA*NC*
          (-1296823413866233507809344930154166677524772381572490811581117361/
            389650399464155718257181291791369930041128960000 + 
           (31373560927*lm)/297024 + (53295*lm^2)/4 - 
           (3343527439441417433564287*Pi^2)/5292967680 - 
           (23856465743171061960463234441*Im[PolyLog[2, (-1)^(1/3)]])/
            (54488755388779392897216*Sqrt[3]) + 29070*Zeta[3])), 
      (-270920630181671772270997268684069669144598257406338948258090159720857\
80458311*CF^2*NC)/
        211000882758879672594816667039647986957620115245570344960000000 + 
       (2549349474803708261*CF^2*lm*NC)/450352155052800 + 
       (13699*CF^2*lm^2*NC)/4 + 
       (2491299172751967605462873887041550662340922993562166601*CF*NM*NC)/
        158370896079532114318303175391379200000 + 
       (2292292217634195461*CF*lm*NM*NC)/4053169395475200 + 
       (13699*CF*lm^2*NM*NC)/36 - (677601567223400307749446127*CF*NC*NL)/
        4138367016168088704000 + (2292292217634195461*CF*lm*NC*NL)/
        4053169395475200 + (13699*CF*lm^2*NC*NL)/36 - 
       (17599876651882340310250321907305468380765720309801850598066815204481*
         CF*NC*NH)/
        3925423001405040568235165068592910575955049251312611904000000 + 
       (2292292217634195461*CF*lm*NC*NH)/4053169395475200 + 
       (13699*CF*lm^2*NC*NH)/36 + (2718570339136082448157111696780343*CF^2*
         NC*Pi^2)/17003856247897559040 - (361*CF^2*lm*NC*Pi^2)/18 - 
       (21586269908383341285583*CF*NM*NC*Pi^2)/3759210 - 
       (361*CF*lm*NM*NC*Pi^2)/162 + (1179127394659*CF*NC*NL*Pi^2)/
        330810480 - (361*CF*lm*NC*NL*Pi^2)/162 - (361*CF*lm*NC*NH*Pi^2)/
        162 + (31821486363145796045169033655*CF^2*NC*Pi^3)/
        (296711878083437366364672*Sqrt[3]) + (9656922473518103867043905*CF*NC*
         NH*Pi^3)/(16210220612075905068*Sqrt[3]) + (31311449*CF^2*NC*Pi^4)/
        25920 - (125491969800296144413813833264254437*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(103953006486532281305862835200*
         Sqrt[3]) - (1264822148507572847052829140407*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(689623310389239191355390*Sqrt[3]) + 
       (3998417*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 + 
       (6364297272629159209033806731*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1602610452611158614624*
         Sqrt[3]) + (1103648282687783299090732*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) + 
       (6364297272629159209033806731*CF^2*NC*Pi*Log[3]^2)/
        (76925301725335613501952*Sqrt[3]) + (275912070671945824772683*CF*NC*
         NH*Pi*Log[3]^2)/(600378541187996484*Sqrt[3]) + 
       CF*((4364276321294109522750410264835539971*CF*NC)/
          2274771840306533568000 + CA*(-2777266750183988434739938882488647807/
            2895164160390133632000 - (7742614*lm)/9)*NC + 1407748*CF*lm*NC - 
         (261668763828352542828845776*NM*NC)/3797428635 + 
         (1407748*lm*NM*NC)/9 + (5367538*NC*NL)/27 + (1407748*lm*NC*NL)/
          9 + (238595656173614503957*NC*NH)/4007198592797400 + 
         (1407748*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-8695049292559717052608*CA + 17390099296879174532593*CF - 
          12252240*(69507191360425618*NM + 351937*NL))*Log[x]^3)/41351310 - 
       (1008184380197844464690801150588874001*CF^2*NC*PolyGamma[2, 1])/
        583567942034732582448 - (886867462222821962*CF*NM*NC*
         PolyGamma[2, 1])/81 + (2391873498110533352352394*CF*NC*NH*
         PolyGamma[2, 1])/36472996377170786403 - 
       (104001930297833188453034827823502026764699*CF^2*NC*Zeta[3])/
        28373073341728698158621760 - (939648628213592200*CF*NM*NC*Zeta[3])/
        81 + (4418906*CF*NC*NL*Zeta[3])/27 - 
       (51715357726243916383291864*CF*NC*NH*Zeta[3])/36472996377170786403 + 
       CA*CF*NC*(387029472135162598362992266153825086185563188825824235282765\
2399177304008473/
          60285966502537049312804762011327996273605747213020098560000000 - 
         (150689*lm^2)/72 - (6220984757850168909167331540667*Pi^2)/
          77820852393123840 - (31821486363145796045169033655*Pi^3)/
          (593423756166874732729344*Sqrt[3]) - (2093591*Pi^4)/3456 + 
         lm*(-4255274908746838661/736939890086400 + (3971*Pi^2)/324) + 
         (125491969800296144413813833264254437*Im[PolyLog[2, (-1)^(1/3)]])/
          (207906012973064562611725670400*Sqrt[3]) - 
         (3998417*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 - 
         (6364297272629159209033806731*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3205220905222317229248*Sqrt[3]) - (6364297272629159209033806731*Pi*
           Log[3]^2)/(153850603450671227003904*Sqrt[3]) + 
         (1008184380197844464690801150588874001*PolyGamma[2, 1])/
          1167135884069465164896 + 
         (104001930293942227862220992929343824490539*Zeta[3])/
          56746146683457396317243520) + CF*Log[x]*
        ((-57097391160923747601798544932383766382693*NM*NC)/
          2193448747015574992944000 + (1426754013899*lm*NM*NC)/55135080 + 
         3610*lm^2*NM*NC + (137665941806743497659*NC*NL)/506646174434400 + 
         (1426754013899*lm*NC*NL)/55135080 + 3610*lm^2*NC*NL + 
         (1591601801177604777646707762718294491457393595290151*NC*NH)/
          367347310455924483348049828247845055376360000 + 
         (1426754013899*lm*NC*NH)/55135080 + 3610*lm^2*NC*NH - 
         (139014382721577359*NM*NC*Pi^2)/27 + (736364*NC*NL*Pi^2)/27 - 
         (1103648282687783299090732*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CA*NC*
          (-4827122323702704915477356563879037099078017774032731102632100113/
            5844755991962335773857719376870548950616934400000 - 
           (1680074645099*lm)/10024560 - 19855*lm^2 - 
           (39748796911304184733219*Pi^2)/756138240 + 
           (6364297272629159209033806731*Im[PolyLog[2, (-1)^(1/3)]])/
            (9615662715666951687744*Sqrt[3]) - 43320*Zeta[3]) + 
         CF*NC*
          (4827122322359144832145272083975179423371517875488442995804958313/
            2922377995981167886928859688435274475308467200000 + 
           (1459926953699*lm)/6126120 + 32490*lm^2 + 
           (4416532989203002928011*Pi^2)/42007680 - 
           (6364297272629159209033806731*Im[PolyLog[2, (-1)^(1/3)]])/
            (4807831357833475843872*Sqrt[3]) + 86640*Zeta[3])), 
      (-111303618807674532907354444263344028260547026188171404464183352199199\
58391004681*CF^2*NC)/
        308385905570670290715501282596408596322675553051218196480000000 - 
       (776245525795639298501*CF^2*lm*NC)/177356866880793600 - 
       (44343*CF^2*lm^2*NC)/16 + 
       (29693594915357840455056764449577246531640973934965473825149*CF*NM*
         NC)/4205238786795962389988488868219918592000000 - 
       (694323280502982729701*CF*lm*NM*NC)/1596211801927142400 - 
       (4927*CF*lm^2*NM*NC)/16 + (772568707375171769069674438819*CF*NC*NL)/
        5975801971346720088576000 - (694323280502982729701*CF*lm*NC*NL)/
        1596211801927142400 - (4927*CF*lm^2*NC*NL)/16 + 
       (2522800588005104991828031009086657001172952652633353874349899526833*
         CF*NC*NH)/
        682682261113920098823506968450940969731312913271758592000000 - 
       (694323280502982729701*CF*lm*NC*NH)/1596211801927142400 - 
       (4927*CF*lm^2*NC*NH)/16 + (832426033541132805730797450074400947*CF^2*
         NC*Pi^2)/62129474751933388800 + (2651*CF^2*lm*NC*Pi^2)/216 - 
       (2052522142587043496336257*CF*NM*NC*Pi^2)/725238360 + 
       (2651*CF*lm*NM*NC*Pi^2)/1944 - (18749159109311*CF*NC*NL*Pi^2)/
        6856799040 + (2651*CF*lm*NC*NL*Pi^2)/1944 + (2651*CF*lm*NC*NH*Pi^2)/
        1944 - (338202387424656252819714761695*CF^2*NC*Pi^3)/
        (3686074485421164205222656*Sqrt[3]) - 
       (7658734597225420523654315*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) - (35121697*CF^2*NC*Pi^4)/38880 + 
       (91484346506890272852946662956366017027*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(83425486259487895202764336412160*
         Sqrt[3]) + (2583161354455955773449439331999*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2758493241556956765421560*Sqrt[3]) - 
       (1540435*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/18 - 
       (67640477484931250563942952339*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19909352930515547404752*
         Sqrt[3]) - (875283953968619488417636*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (67640477484931250563942952339*CF^2*NC*Pi*Log[3]^2)/
        (955648940664746275428096*Sqrt[3]) - (218820988492154872104409*CF*NC*
         NH*Pi*Log[3]^2)/(600378541187996484*Sqrt[3]) + 
       CF*((510239321005311268559848212203342243143*CF*NC)/
          3173545329658415712000 - (3307064*CF*lm*NC)/3 + 
         CA*(-6633111173053961400416100945107291326969/
            82512178571118808512000 + (18188852*lm)/27)*NC - 
         (1245261452057655541295386514051*NM*NC)/36666732866400 - 
         (3307064*lm*NM*NC)/27 - (8569285*NC*NL)/54 - (3307064*lm*NC*NL)/
          27 - (872794624608598040017*NC*NH)/18816410783570400 - 
         (3307064*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-150054016981713690150009275*CA + 
          82992*(3616107984917412492219*CF + 1870*(-396987747335674327*NM + 
              3307064*NL)))*Log[x]^3)/6285399120 + 
       (7447110075670799741553925467389421635*CF^2*NC*PolyGamma[2, 1])/
        389045294689821721632 + (20622914943668288935*CF*NM*NC*
         PolyGamma[2, 1])/3888 + (155457042421915767557899*CF*NC*NH*
         PolyGamma[2, 1])/24315330918113857602 + 
       CA*CF*NC*(144694704449678033576624167127343921022766616173156445499280\
995471114326583761353/
          8018033544837427558603033347506623504389564379331673108480000000 + 
         (54197*lm^2)/32 - (36192436240915795992797012430997429*Pi^2)/
          5402563021907251200 + (338202387424656252819714761695*Pi^3)/
          (7372148970842328410445312*Sqrt[3]) + (35206529*Pi^4)/77760 + 
         lm*(1319911335465087436901/290220327623116800 - (29161*Pi^2)/3888) - 
         (91484346506890272852946662956366017027*Im[PolyLog[2, (-1)^(1/3)]])/
          (166850972518975790405528672824320*Sqrt[3]) + 
         (1540435*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 + 
         (67640477484931250563942952339*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(39818705861031094809504*Sqrt[3]) + 
         (67640477484931250563942952339*Pi*Log[3]^2)/
          (1911297881329492550856192*Sqrt[3]) - 
         (7447110075670799741553925467389421635*PolyGamma[2, 1])/
          778090589379643443264 - (139436170371205337506155862190997811532623*
           Zeta[3])/19351891048461112077418944) + 
       (139436170371833915268373775700154109498215*CF^2*NC*Zeta[3])/
        9675945524230556038709472 + (30150620881597683499*CF*NM*NC*Zeta[3])/
        1944 - (20814605*CF*NC*NL*Zeta[3])/162 + 
       (16751584020079676414572426*CF*NC*NH*Zeta[3])/12157665459056928801 + 
       CF*Log[x]*((-434748505762290205617302945834566426616146471*NM*NC)/
          29121435743997816682182720000 - (22797717127361*lm*NM*NC)/
          1142799840 - (5985*lm^2*NM*NC)/2 - (48987418252888291680857*NC*
           NL)/231030655542086400 - (22797717127361*lm*NC*NL)/1142799840 - 
         (5985*lm^2*NC*NL)/2 - 
         (438934493341383073585732412261446720666938652395461*NC*NH)/
          127772977549886776816712983738380888826560000 - 
         (22797717127361*lm*NC*NH)/1142799840 - (5985*lm^2*NC*NH)/2 - 
         (132329249110196465*NM*NC*Pi^2)/54 - (3468659*NC*NL*Pi^2)/162 + 
         (875283953968619488417636*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*
          (66830311849767186738222428077324817878728620756592991704397856987/
            1067791960070042112531698732312888750593478400000 - 
           (23367688547561*lm)/126977760 - (53865*lm^2)/2 + 
           (4617046676246305291692101*Pi^2)/386793792 + 
           (67640477484931250563942952339*Im[PolyLog[2, (-1)^(1/3)]])/
            (59728058791546642214256*Sqrt[3]) - 71820*Zeta[3]) + 
         CA*NC*
          (
           -17375881080859111490635915656309644374592661077072341569215710017\
37/55525181923642189851648334080270215030860876800000 + (298652487697771*lm)/
            2285599680 + (65835*lm^2)/4 - (1539015558747431563510871*Pi^2)/
            257862528 - (67640477484931250563942952339*
             Im[PolyLog[2, (-1)^(1/3)]])/(119456117583093284428512*Sqrt[3]) + 
           35910*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["v", 2, 1, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-3*CA*(62080*lm + 114048*lm^2 + 1593*(538 - 447*Zeta[3])) + 
         2*(9*CF*(-356914 - 17472*lm + 31104*lm^2 + 300243*Zeta[3]) + 
           4*(24*(1207 - 236*lm + 324*lm^2)*NL + NM*(-21406 - 5664*lm + 
               7776*lm^2 + 27405*Zeta[3]) + NH*(-21406 - 5664*lm + 7776*
                lm^2 + 27405*Zeta[3])))))/5598720, 
      -(CF*NC*(-95234*NM + 79104*lm*NM + 62208*lm^2*NM + 186432*NL + 
          79104*lm*NL + 62208*lm^2*NL - 337886*NH + 79104*lm*NH + 
          62208*lm^2*NH - 3*CA*(919114 + 290176*lm + 114048*lm^2 - 
            712071*Zeta[3]) + 199395*NM*Zeta[3] + 239085*NH*Zeta[3] + 
          18*CF*(-374386 + 44736*lm + 31104*lm^2 + 300243*Zeta[3])))/5598720, 
      (CF*NC*(-752229550*NM + 848670720*lm*NM + 328458240*lm^2*NM + 
         1402232832*NL + 848670720*lm*NL + 328458240*lm^2*NL - 
         4013472430*NH + 848670720*lm*NH + 328458240*lm^2*NH - 
         8*CA*(17433057002 + 870862080*lm + 225815040*lm^2 - 
           14030180775*Zeta[3]) + 2432434725*NM*Zeta[3] + 
         2965868325*NH*Zeta[3] + 80*CF*(-17320399006 + 101634048*lm + 
           36951552*lm^2 + 14430280005*Zeta[3])))/50164531200, 
      -(CF*NC*(-6332837270*NM + 689848320*lm*NM + 199065600*lm^2*NM + 
          1568432128*NL + 689848320*lm*NL + 199065600*lm^2*NL - 
          6367735770*NH + 689848320*lm*NH + 199065600*lm^2*NH - 
          32*CA*(15627897802 + 162113280*lm + 34214400*lm^2 - 
            12833901495*Zeta[3]) + 8543239425*NM*Zeta[3] + 
          5192411175*NH*Zeta[3] + 320*CF*(-16965712318 + 20335104*lm + 
            5598720*lm^2 + 14127635061*Zeta[3])))/100329062400, 
      -(CF*NC*(25297122063290*NM + 694372761600*lm*NM + 
          182078668800*lm^2*NM + 75686641664*NL + 694372761600*lm*NL + 
          182078668800*lm^2*NL + 4161337897290*NH + 694372761600*lm*NH + 
          182078668800*lm^2*NH + 70*CF*(480364606330654 + 93178183680*lm + 
            23410114560*lm^2 - 399630843246285*Zeta[3]) - 
          23933812368375*NM*Zeta[3] - 4029654423375*NH*Zeta[3] - 
          CA*(-2121817830225638 + 5093600870400*lm + 1001432678400*lm^2 + 
            1766657369784825*Zeta[3])))/196644962304000, 
      (CF*NC*(-3*CA*(-1327731236337638 + 4150300098560*lm + 
           786839961600*lm^2 + 1108377224386425*Zeta[3]) + 
         2*(35*CF*(1062457909863514 + 230026493952*lm + 55180984320*lm^2 - 
             883789353721575*Zeta[3]) + 35*NM*(524708070818 + 
             24536629248*lm + 6131220480*lm^2 - 422618094675*Zeta[3]) + 
           64*(256*(77613079 + 52415895*lm + 13097700*lm^2)*NL + 
             105*NH*(-533551214 + 127794944*lm + 31933440*lm^2 + 394132725*
                Zeta[3])))))/196644962304000, 
      -(CF*NC*(252*CF*(1895190960559072682 + 192931240550400*lm + 
            48847712256000*lm^2 - 1576558851789009375*Zeta[3]) - 
          2*CA*(-10786650142766005034 + 19015902349516800*lm + 
            3761273843712000*lm^2 + 8995970441157753375*Zeta[3]) + 
          5*(16384*(131762146777 + 63160629210*lm + 16695995400*lm^2)*NL + 
            315*NM*(88157512914170 + 3285154758656*lm + 868403773440*lm^2 - 
              66787282121175*Zeta[3]) + 315*NH*(-33964608597682 + 
              3285154758656*lm + 868403773440*lm^2 + 27455653053675*Zeta[
                3]))))/584035538042880000, 
      (CF*NC*(1008*CF*(1890739923521332114 + 67626359193600*lm + 
           20442046464000*lm^2 - 1572914205288034875*Zeta[3]) - 
         8*CA*(-9397776828730474258 + 6948210615091200*lm + 
           1574037577728000*lm^2 + 7827782007590314875*Zeta[3]) + 
         5*(131072*(31437548053 + 10974986820*lm + 3493513800*lm^2)*NL + 
           315*NM*(220536680733066 + 4566709436416*lm + 1453656637440*lm^2 - 
             167442940716975*Zeta[3]) + 315*NH*(-99206502637802 + 
             4566709436416*lm + 1453656637440*lm^2 + 82035231530175*
              Zeta[3]))))/1168071076085760000, 
      -(CF*NC*(-121*CA*(-3285229289000198308018 + 762157231924838400*lm + 
            236395336826880000*lm^2 + 2734231099795662544875*Zeta[3]) + 
          2*(11*CF*(517941271436998986463322 + 4506206961637785600*lm + 
              2127558031441920000*lm^2 - 430882748828070745350375*Zeta[3]) + 
            5*(131072*(36382920755983 + 7742606865840*lm + 3967817238000*
                 lm^2)*NL + 198*NM*(720042678218723486 + 5125449328885760*
                 lm + 2626614853632000*lm^2 - 563803606178938125*Zeta[3]) + 
              99*NH*(-584928222610822838 + 10250898657771520*lm + 
                5253229707264000*lm^2 + 487961640277736625*Zeta[3])))))/
       3674751605365800960000, 
      (CF*NC*(-121*CA*(-1069831633245361011826 + 36294575104327680*lm + 
           30314225546035200*lm^2 + 890070813634099502475*Zeta[3]) + 
         2*(2617096065847361536*NL - 25158831496888320*lm*NL + 
           333456481006387200*lm^2*NL - 60277187584155443220*NH - 
           25158831496888320*lm*NH + 333456481006387200*lm^2*NH + 
           11*CF*(188582779642514517403418 + 24886839821598720*lm + 
             272828029914316800*lm^2 - 156884734879779729767175*Zeta[3]) + 
           1155*NM*(170474523676945018 - 21782538092544*lm + 
             288706909962240*lm^2 - 137656633622282775*Zeta[3]) + 
           50451572623140438750*NH*Zeta[3])))/734950321073160192000, 
      (CF*NC*(-416*CF*(7573229250965180588998261862 - 12368906958544935321600*
            lm + 3533170266457767936000*lm^2 - 6300259918580173543658285625*
            Zeta[3]) + 176*CA*(-503602736084312351293429174 - 
           12221453851116385075200*lm + 5103468162661220352000*lm^2 + 
           418929223505912588252408625*Zeta[3]) - 
         5*(16777216*(7025808984418027 - 7139883791820780*lm + 
             1946818604530800*lm^2)*NL + 3003*NM*(-39889234961796956160*
              lm + 10876522224785817600*lm^2 + 143*(114659949751887188386 - 
               94399394633230561875*Zeta[3])) + 1287*NH*
            (-7747941333974645049818 - 93074881577526231040*lm + 
             25378551857833574400*lm^2 + 6489611671546490862375*Zeta[3]))))/
       317968906909092025466880000, 
      (CF*NC*(11648*CF*(919559456966350131198373214 - 1322845781698805760000*
            lm + 119310117057331200000*lm^2 - 764990481927235350419758125*
            Zeta[3]) - 704*CA*(-388320122387679756508909186 - 
           12041135786651811840000*lm + 1206357850246348800000*lm^2 + 
           323021885066034975341395875*Zeta[3]) + 
         5*(134217728*(-1893165611919377 - 2589511933008000*lm + 
             230094499635000*lm^2)*NL + 429*NM*(341158017541883639449906 - 
             810159459853664256000*lm + 71987787800248320000*lm^2 - 
             283424481549900528712875*Zeta[3]) + 1287*NH*
            (-270053153284554752000*lm + 23995929266749440000*lm^2 + 
             143*(-97343906069783305418 + 81487620056058591375*Zeta[3])))))/
       635937813818184050933760000, 
      -(CF*NC*(-99*CA*(-7918084691711196582420692415142 - 
            186939497814290207866880000*lm + 5014445336158808309760000*lm^2 + 
            6586694211088211052214614857625*Zeta[3]) + 
          2*(CF*(16846692212685978121906385476741582 - 
              15591348039210643708968960000*lm + 406170072228863473090560000*
               lm^2 - 14014904801472893908906675393159125*Zeta[3]) + 
            35*(84557168640*(-879739906914149 - 587901044716700*lm + 
                15249195561600*lm^2)*NL + 143*NM*(
                210110631938884819232048842 - 347631103368826454016000*lm + 
                9016984620465389568000*lm^2 - 175082437723704034308159375*
                 Zeta[3]) + 143*NH*(-347631103368826454016000*lm + 
                9016984620465389568000*lm^2 + 1573*(-9274547054808021662318 + 
                  7754575745696701501125*Zeta[3]))))))/
       1210825597509822432977879040000, 
      -(CF*NC*(-11*CA*(15000935654511646275101856277462 + 
            226466518553145688404787200*lm + 1670610307510677012480000*lm^2 - 
            12478834493556890242149539798625*Zeta[3]) + 
          2*(3*CF*(-1291747391962770413235950648097946 + 
              673856166911788000582041600*lm + 5011830922532031037440000*lm^
                2 + 1074614623120731947080752384834375*Zeta[3]) + 
            10*(1207959552*(37969592291861019 + 18571837681256860*lm + 
                138300186024000*lm^2)*NL + 143*NH*(
                6015927679952054850680266 + 156881319757117170647040*lm + 
                1168258956301172736000*lm^2 - 5022737383191228204879375*
                 Zeta[3]) + 572*NM*(-39983641190364838008204146 + 
                39220329939279292661760*lm + 292064739075293184000*lm^2 + 
                33330465054641100796324875*Zeta[3])))))/
       172975085358546061853982720000, 
      (CF*NC*(-65*CA*(211388829591903393293961572850898694 + 
           1860790840137926915582916034560*lm + 54247690570316704716423168000*
            lm^2 - 175850955266980258086065416360413225*Zeta[3]) + 
         34*CF*(-20673758060033443989854187954230069722 + 
           5633486202553879706347556044800*lm + 
           169705342158477391759933440000*lm^2 + 
           17198652767714075036050577561303022375*Zeta[3]) + 
         105*(402653184*(1270742439385133025667 + 500849491918284649140*lm + 
             15163920000821592000*lm^2)*NL + 9724*NM*
            (-39518223570944042118909452126 + 20739268061053021574922240*lm + 
             627910393896760246272000*lm^2 + 32927214079813003906837006125*
              Zeta[3]) + 2431*NH*(82957072244212086299688960*lm + 
             2511641575587040985088000*lm^2 - 26741*
              (-116335235110721735330546 + 96984219465272306860875*
                Zeta[3])))))/9972965033889652469222300712960000, 
      -(CF*NC*(-4*CA*(9740929366603178240495848082423302066 + 
            47083134054301341041461454438400*lm + 
            2190038294934318178646360064000*lm^2 - 
            8103413462841828262706331341078368875*Zeta[3]) + 
          5*(136*CF*(-3183160776878628751159103135821065494 + 
              429890236079778796552543272960*lm + 
              21080582518084346104617369600*lm^2 + 
              2648094753937699344232222927080847425*Zeta[3]) + 
            21*(34359738368*(27197281822894075174 + 8929370178389766105*lm + 
                441478810247775300*lm^2)*NL + 12155*NM*(
                -97048570107777754775887689382 + 25241532136609942484287488*
                 lm + 1247971733042326331719680*lm^2 + 
                80817415887617153805424188825*Zeta[3]) + 12155*NH*(
                25241532136609942484287488*lm + 1247971733042326331719680*
                 lm^2 - 133705*(-7276707433588133176502 + 
                  6057683175857914622385*Zeta[3]))))))/
       19945930067779304938444601425920000, 
      (CF*NC*(-(CA*(104577510885795201602034291650957725176562 + 
            265177412359782515613413370180403200*lm + 
            16769435608199311374712225923072000*lm^2 - 
            86997950953914395350370958525806529580875*Zeta[3])) + 
         1254*CF*(-5017400426265192595081087708124700140858 + 
           321830448344084311363266438758400*lm + 
           21882691093779005708628393984000*lm^2 + 
           4174012054511343259129375887996387192375*Zeta[3]) + 
         35*(171798691840*(26746326080101349119133 + 7373005487780225549256*
              lm + 507069933294696932160*lm^2)*NL + 
           4199*NH*(301660561497924233098910760960*lm + 
             20746356563806857383745945600*lm^2 - 
             4199*(-2973909260496478547380384978 + 
               2472518735564566514917966875*Zeta[3])) + 
           4199*NM*(301660561497924233098910760960*lm + 
             20746356563806857383745945600*lm^2 + 
             323*(-7727787730603608731995251412214 + 
               6432611805487417565497109252625*Zeta[3])))))/
       38402564023831088441485339278704640000, 
      -(CF*NC*(-33*CA*(4349364680565226307118615779554980820418 + 
            5556524651579129251356852879360000*lm + 
            456622399006069836622061371392000*lm^2 - 
            3618248726163882111268372809833441887875*Zeta[3]) + 
          114*CF*(-81828447109111206763908752330897523443182 + 
            2392802812512771046766568013824000*lm + 
            216294820581822554189397491712000*lm^2 + 
            68073683558557009915306811816974027909125*Zeta[3]) + 
          455*(17179869184*(16643246479525872817001 + 3818961549416698284600*
               lm + 350491276046232921600*lm^2)*NL + 
            4199*NH*(727274364519304091400719799134 + 
              15624972573875881884883353600*lm + 1434006733176354924763545600*
               lm^2 - 603982114092153455889479374125*Zeta[3]) + 
            1615*NM*(-769132226347683313862218849703618 + 
              40624928692077292900696719360*lm + 3728417506258522804385218560*
               lm^2 + 640053241059110401314412348803075*Zeta[3]))))/
       38402564023831088441485339278704640000, 
      (CF*NC*(-364*CA*(6478484469016927465432046874845395952094718 + 
           3996851503148279895069874979654860800*lm + 
           427052215654250295765422561034240000*lm^2 - 
           5389482873196207563950330401961276037604125*Zeta[3]) + 
         8*CF*(-20646128381294033344247997110532390466905196214 + 
           262415482553521293409338434564338483200*lm + 
           31795978601893726566534643407912960000*lm^2 + 
           17175665522880344817236702150773117791177704625*Zeta[3]) + 
         1155*(4535485464576*(234502248632034756070777 + 
             43628579698206131909280*lm + 5395279026545091684000*lm^2)*NL + 
           4199*NM*(-2182765454774663553359224573203418462 + 
             47124741381593112659293340958720*lm + 
             5827627911937845723414921216000*lm^2 + 
             1816162124886414522244399187632942125*Zeta[3]) + 
           29393*NH*(6732105911656158951327620136960*lm + 
             832518273133977960487845888000*lm^2 - 
             4199*(-88756679309582654541843184258 + 
               73641328015428906041021587875*Zeta[3])))))/
       466360737505404738033397960200589148160000, 
      -(CF*NC*(-80*CA*(78714678551807808954180603008301525771489454 + 
            22231881460854814613395086628827955200*lm + 
            3192312121572911391512581930116710400*lm^2 - 
            65483216832172711893443682579880191207001125*Zeta[3]) + 
          32*CF*(-14819232040820486216253854203692140896060419226 + 
            76504053194726977246094456814305280000*lm + 
            13059458679161910238006016986841088000*lm^2 + 
            12328227962574891687235997859406377786753090375*Zeta[3]) + 
          1155*(9895604649984*(161827213840150074875929 + 
              23122380220794496441800*lm + 4062639850943805331200*lm^2)*NL + 
            4199*NM*(-6738131283395730755491289880712822502 + 
              54491529705070751988652494028800*lm + 
              9574250488261449079900549939200*lm^2 + 
              5605967144037898657661903464776197625*Zeta[3]) + 
            4199*NH*(54491529705070751988652494028800*lm + 
              9574250488261449079900549939200*lm^2 - 
              4199*(-926262011700095596573196034266 + 
                767948177496181447714732158375*Zeta[3])))))/
       932721475010809476066795920401178296320000, 
      (CF*NC*(-(CA*(35152271695854769107294042266728766930735942152898 + 
            4187791539695474006962065289967101280256000*lm + 
            870259067244261714637708259847426382233600*lm^2 - 
            29243409615391476971053175721068436374464559043075*Zeta[3])) + 
         46*CF*(-61733723893136819056822778699583779210439925052786 + 
           114731582668561002133099320608497965465600*lm + 
           30957832431614053089878949955046788300800*lm^2 + 
           51356738908650737035393838942182176040381257374475*Zeta[3]) + 
         1155*(1649267441664*(3009110361901022820792505457 + 
             293996133621539665377221160*lm + 83063991691303319899762560*
              lm^2)*NL + 7429*NM*
            (-24888014847552869563393232910302502145502 + 
             65268306791910650036530916685250560*lm + 
             18440535344072631424002043108392960*lm^2 + 
             20705351109156833001809925360386922022125*Zeta[3]) + 
           81719*NH*(5933482435628240912411901516840960*lm + 
             1676412304006602856727458464399360*lm^2 - 
             7429*(-84668602857485453023191700210526 + 
               70158248100990659532185087950125*Zeta[3])))))/
       3947277282245745702714680335137786550026240000, 
      -(CF*NC*(-7*CA*(198490787768652447282092297208899030511981953722 + 
            8495424865998738667588380289545535488000*lm + 
            3000566986676094985350379749460515225600*lm^2 - 
            165125879858850641422100074466485856424105427575*Zeta[3]) + 
          2*(69*CF*(-870612951102237816036267141406655546069978444002 + 
              429679582806312024238553295328011878400*lm + 
              249058919842679820918410967346524979200*lm^2 + 
              724269322815393740701228042751134246181754580275*Zeta[3]) + 
            35*(2*(137438953472*(6447755593081985496137970469 + 
                  309328833590353011856501080*lm + 
                  198472711032485014276831680*lm^2)*NL + 200583*NH*
                 (47697516354316915680406875352830894 + 
                  211951317745634267632853812510720*lm + 
                  135992988922567759768927202181120*lm^2 - 
                  39508110222276038182671382218793125*Zeta[3])) + 
              7429*NM*(-19219298430597442634336063228303040346822 + 
                11445371158264250452174105875578880*lm + 
                7343621401818659027522068917780480*lm^2 + 
                15988974527979939779004072953192663687625*Zeta[3])))))/
       119614463098355930385293343489023834849280000}, 0, 22, 1]
 
CbarSeries["v", 2, 2, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(CF*(-2332800*lm^2 + 128176*Pi^2 + 3600*Pi^4 + 
            64800*lm*(-79 + 4*Pi^2) + 15*(-210425 + 296976*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 103680*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 49496*PolyGamma[2, 1] - 404368*Zeta[3])) + 
          60*(-2*NH*(22531 + 1080*lm^2 - 60*lm*(-53 + 2*Pi^2) + 
              82512*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 13752*PolyGamma[2, 
                1] - 167664*Zeta[3]) + NL*(-5915 - 2160*lm^2 + 28*Pi^2 + 
              120*lm*(-53 + 2*Pi^2) - 2880*Zeta[3]) + 
            NM*(-5915 - 2160*lm^2 + 28*Pi^2 + 120*lm*(-53 + 2*Pi^2) + 
              240*PolyGamma[2, 1] - 2400*Zeta[3])) + 
          CA*(712800*lm^2 - 306794*Pi^2 + 9720*Pi^4 - 
            3600*lm*(-835 + 22*Pi^2) + 30*(87287 - 74244*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 25920*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 12374*PolyGamma[2, 1] + 128956*Zeta[3]))))/11664000, 
      (CF*NC*(-(CA*(-18915345 + 7128000*lm^2 - 5310852*Pi^2 + 191160*Pi^4 - 
            3600*lm*(-4203 + 220*Pi^2) - 51581280*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 15292800*Im[PolyLog[2, (-1)^(1/3)]]^
              2 + 9140480*PolyGamma[2, 1] + 78517600*Zeta[3])) + 
         2*(-100*(NH*(1678131 - 5508*lm - 6480*lm^2 + 720*lm*Pi^2 - 499632*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 83272*PolyGamma[2, 1] - 
               495856*Zeta[3]) + 3*NL*(8121 - 1836*lm - 2160*lm^2 + 124*
                Pi^2 + 240*lm*Pi^2 - 2880*Zeta[3]) + 3*NM*(8121 - 2160*
                lm^2 + 124*Pi^2 + 12*lm*(-153 + 20*Pi^2) + 240*PolyGamma[2, 
                 1] - 2400*Zeta[3])) + CF*(20675325 + 11664000*lm^2 - 
             362844*Pi^2 + 75960*Pi^4 - 129600*lm*(-9 + 10*Pi^2) - 
             51581280*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             15292800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 9140480*
              PolyGamma[2, 1] + 66343840*Zeta[3]))))/46656000, 
      -(CF*NC*(-40*(NH*(29389977 - 155520*lm^2 + 540*lm*(-217 + 4*Pi^2) - 
              6986256*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 999352*PolyGamma[
                2, 1] - 12153616*Zeta[3]) + 9*NM*(84865 - 17280*lm^2 - 
              12132*Pi^2 + 60*lm*(-217 + 4*Pi^2) - 1200*PolyGamma[2, 1] - 
              5280*Zeta[3]) + 9*NL*(47245 - 17280*lm^2 - 4692*Pi^2 + 
              60*lm*(-217 + 4*Pi^2) - 2880*Zeta[3])) + 
          5*CA*(9983835 - 6842880*lm^2 + 374208*Pi^2 + 119664*Pi^4 + 
            2160*lm*(-6419 + 44*Pi^2) + 41017872*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 15863040*Im[PolyLog[2, (-1)^(1/3)]]^
              2 - 7180856*PolyGamma[2, 1] - 59404624*Zeta[3]) + 
          CF*(111974400*lm^2 + 9601068*Pi^2 - 1334880*Pi^4 - 
            388800*lm*(-1 + 4*Pi^2) + 5*(43553979 - 82035744*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 31726080*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 14361712*PolyGamma[2, 1] + 106546496*Zeta[3]))))/
       69984000, (CF*NC*(195955200*(-10*CA*(76 + 33*lm) + 
           9*CF*(251 + 120*lm) + 20*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 
             3*lm*NH))*Log[x]^2 + 3919104000*(11*CA + 36*CF - 2*(NM + NL))*
          Log[x]^3 - 7*CA*(6735960000*lm^2 - 2002262652*Pi^2 + 
           198800000*Sqrt[3]*Pi^3 + 70810200*Pi^4 - 1458000*lm*
            (-15637 + 132*Pi^2) + 153360000*Sqrt[3]*Pi*Log[3]^2 - 
           135*(-91052203 + 221061408*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             126748800*Im[PolyLog[2, (-1)^(1/3)]]^2 - 54528000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 41182912*
              PolyGamma[2, 1] - 356030048*Zeta[3])) + 
         10*(CF*(15431472000*lm^2 - 1563464268*Pi^2 + 278320000*Sqrt[3]*
              Pi^3 + 59943240*Pi^4 - 146966400*lm*(-143 + 3*Pi^2) + 
             214704000*Sqrt[3]*Pi*Log[3]^2 - 189*(-148956601 + 221061408*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 126748800*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 54528000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 41182912*
                PolyGamma[2, 1] - 293315744*Zeta[3])) - 
           140*(-(NH*(6123600*lm^2 + 32603200*Sqrt[3]*Pi^3 - 14580*lm*
                 (-887 + 12*Pi^2) + 25151040*Sqrt[3]*Pi*Log[3]^2 + 
                3*(-346434795 + 24641328*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                  402416640*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                  982600*PolyGamma[2, 1] - 84037360*Zeta[3]))) + 
             729*NL*(-5455 - 8400*lm^2 - 4388*Pi^2 + 20*lm*(-887 + 
                 12*Pi^2) - 25920*Zeta[3]) + 729*NM*(42833 - 8400*lm^2 - 
               3108*Pi^2 + 20*lm*(-887 + 12*Pi^2) - 1520*PolyGamma[2, 1] + 
               5600*Zeta[3]))) + 151200*Log[x]*
          (CA*(-1327104*lm - 213840*lm^2 + 3636*Pi^2 + 
             5*(-507399 + 22720*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 46656*
                Zeta[3])) + 16*(22599*NL + 11988*lm*NL + 2430*lm^2*NL + 
             408765*NH + 11988*lm*NH + 2430*lm^2*NH + 1620*NL*Pi^2 + 
             81*NM*(99 + 148*lm + 30*lm^2 + 20*Pi^2) - 232880*Sqrt[3]*NH*
              Im[PolyLog[2, (-1)^(1/3)]] + CF*(234474 + 182979*lm + 43740*
                lm^2 - 3789*Pi^2 - 14200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               29160*Zeta[3])))))/8817984000, 
      (-2*CF*NC*(-10*CA*(76 + 33*lm) + 6*CF*(359 + 180*lm) + 85*NM + 
          60*lm*NM + 100*NL + 60*lm*NL + 60*lm*NH)*Log[x]^2)/45 - 
       (8*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       (CF*NC*Log[x]*(CA*(2720001 + 1285524*lm + 213840*lm^2 - 12726*Pi^2 - 
            197336*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 233280*Zeta[3]) - 
          2*(171981*NL + 92124*lm*NL + 19440*lm^2*NL + 2686983*NH + 
            92124*lm*NH + 19440*lm^2*NH + 12960*NL*Pi^2 + 
            36*NM*(716 + 2559*lm + 540*lm^2 + 405*Pi^2) - 
            1530400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            CF*(2019126 + 1395792*lm + 349920*lm^2 - 27882*Pi^2 - 
              197336*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 233280*Zeta[3]))))/
        29160 - (CF*NC*(-7*CA*(3021559200*lm^2 - 364574844*Pi^2 + 
            172669000*Sqrt[3]*Pi^3 + 9227520*Pi^4 - 583200*lm*
             (-16813 + 77*Pi^2) + 133201800*Sqrt[3]*Pi*Log[3]^2 + 
            5*(190458927 - 2935851936*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1657221120*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1278737280*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 561090988*PolyGamma[2, 
                1] + 4744437176*Zeta[3])) + 
          4*(CF*(17305293600*lm^2 - 459256176*Pi^2 + 604341500*Sqrt[3]*Pi^3 + 
              9434880*Pi^4 - 64297800*lm*(-329 + 4*Pi^2) + 466206300*Sqrt[
                3]*Pi*Log[3]^2 - 35*(-495251163 + 1467925968*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 828610560*Im[PolyLog[2, 
                    (-1)^(1/3)]]^2 - 639368640*Sqrt[3]*Im[PolyLog[3, 
                   -((-1)^(5/6)/Sqrt[3])]] - 280545494*PolyGamma[2, 1] - 
                2042450092*Zeta[3])) - 35*(-(NH*(-4750205643 + 27468720*
                  lm^2 + 133910000*Sqrt[3]*Pi^3 - 58320*lm*(-929 + 7*Pi^2) + 
                 836026224*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 4958496000*
                  Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                 103302000*Sqrt[3]*Pi*Log[3]^2 - 76713352*PolyGamma[2, 1] - 
                 1589031824*Zeta[3])) + 243*NL*(-30655 - 113040*lm^2 - 
                67924*Pi^2 + 240*lm*(-929 + 7*Pi^2) - 365760*Zeta[3]) + 
              486*NM*(360445 - 56520*lm^2 - 23132*Pi^2 + 120*lm*
                 (-929 + 7*Pi^2) - 16956*PolyGamma[2, 1] + 64008*Zeta[3])))))/
        2204496000, (CF*NC*(1043375237415*CF + 2202732403200*CF*lm + 
         1481421312000*CF*lm^2 - 789515748000*NM + 184099910400*lm*NM + 
         82301184000*lm^2*NM + 10912255200*NL + 184099910400*lm*NL + 
         82301184000*lm^2*NL - 19258397643744*NH + 184099910400*lm*NH + 
         82301184000*lm^2*NH - 247136468472*CF*Pi^2 - 26453952000*CF*lm*
          Pi^2 + 22347057600*NM*Pi^2 - 1469664000*lm*NM*Pi^2 + 
         65498025600*NL*Pi^2 - 1469664000*lm*NL*Pi^2 - 
         1469664000*lm*NH*Pi^2 + 78248884000*Sqrt[3]*CF*Pi^3 + 
         756222880000*Sqrt[3]*NH*Pi^3 + 11650353120*CF*Pi^4 - 
         4367106075360*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         28100755200*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         2834100057600*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         2897444390400*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         28001852928000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         60363424800*Sqrt[3]*CF*Pi*Log[3]^2 + 583371936000*Sqrt[3]*NH*Pi*
          Log[3]^2 + 440899200*(-3*CA*(2301 + 1100*lm) + 
           3*CF*(6943 + 3600*lm) + 4*(400*NM + 150*lm*NM + 225*NL + 
             150*lm*NL + 4*NH + 150*lm*NH))*Log[x]^2 + 
         88179840000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 + 
         907468264640*CF*PolyGamma[2, 1] + 18750463200*NM*PolyGamma[2, 1] + 
         335651472800*NH*PolyGamma[2, 1] - 4*CA*(113164128000*lm^2 - 
           34528567653*Pi^2 + 9781110500*Sqrt[3]*Pi^3 + 1750226940*Pi^4 - 
           12247200*lm*(-32429 + 165*Pi^2) + 7545428100*Sqrt[3]*Pi*Log[3]^2 - 
           140*(-255850398 + 3899201853*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             2530446480*Im[PolyLog[2, (-1)^(1/3)]]^2 - 2587003920*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 810239522*
              PolyGamma[2, 1] - 6522374188*Zeta[3])) + 6054923701120*CF*
          Zeta[3] - 726724353600*NM*Zeta[3] + 458535168000*NL*Zeta[3] - 
         6759318238400*NH*Zeta[3] + 15120*Log[x]*
          (4*(30375*NL*(531 + 254*lm + 48*lm^2 + 40*Pi^2) + 
             405*NM*(26043 + 19050*lm + 3600*lm^2 + 520*Pi^2) + 
             NH*(271656969 + 7715250*lm + 1458000*lm^2 - 154331200*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) + 20*CA*(-22461522 - 
             10527975*lm - 1603800*lm^2 + 102681*Pi^2 + 1596916*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 1749600*Zeta[3]) + 
           5*CF*(131414475 + 95353200*lm + 20995200*lm^2 - 2600208*Pi^2 - 
             12775328*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             13996800*Zeta[3]))))/13226976000, 
      (CF*NC*(-97977600*(15*CF*(28345 + 15984*lm) - 4*CA*(36902 + 18315*lm) + 
           4*((9307 + 3330*lm)*NM + 9*(185*(3 + 2*lm)*NL + 2*(6 + 185*lm)*
                NH)))*Log[x]^2 - 11757312000*(515*CA + 1646*CF - 160*NM - 
           74*NL)*Log[x]^3 - 3*CF*(2158642483200*lm^2 - 234723182832*Pi^2 + 
           165587464000*Sqrt[3]*Pi^3 + 13192683840*Pi^4 - 
           195955200*lm*(-15149 + 126*Pi^2) + 127738900800*Sqrt[3]*Pi*
            Log[3]^2 - 35*(26813642805 + 205760144256*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 125467315200*
              Im[PolyLog[2, (-1)^(1/3)]]^2 - 175184778240*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 42331736096*
              PolyGamma[2, 1] - 306716918848*Zeta[3])) + 
         48*CA*(41224075200*lm^2 - 8254700523*Pi^2 + 5174608250*Sqrt[3]*
            Pi^3 + 480855690*Pi^4 - 340200*lm*(-411745 + 1386*Pi^2) + 
           3991840650*Sqrt[3]*Pi*Log[3]^2 - 35*(2023194708 + 
             6430004508*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             3920853600*Im[PolyLog[2, (-1)^(1/3)]]^2 - 5474524320*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1322866753*
              PolyGamma[2, 1] - 11044140098*Zeta[3])) + 
         15120*Log[x]*(-8*(405*NM*(46713 + 43954*lm + 8640*lm^2 + 240*
                Pi^2) + 135*NL*(278771 + 131862*lm + 25920*lm^2 + 21960*
                Pi^2) + NH*(575223267 + 17801370*lm + 3499200*lm^2 - 
               326540000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
           15*CF*(-226418097 - 145698912*lm - 33592320*lm^2 + 4377384*Pi^2 + 
             27034688*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             22394880*Zeta[3]) - 120*CA*(-18934959 - 8160129*lm - 
             1283040*lm^2 + 151047*Pi^2 + 1689668*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 1399680*Zeta[3])) + 
         448*(-(NH*(-199554833448 + 803066400*lm^2 + 7143062500*Sqrt[3]*Pi^
                3 - 72900*lm*(-23411 + 126*Pi^2) + 20599684440*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 264497400000*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 5510362500*Sqrt[3]*Pi*
               Log[3]^2 - 729614335*PolyGamma[2, 1] - 87420575870*Zeta[3])) + 
           1215*NL*(365185 - 660960*lm^2 - 564588*Pi^2 + 
             60*lm*(-23411 + 126*Pi^2) - 4043520*Zeta[3]) + 
           1215*NM*(7857110 - 660960*lm^2 - 114798*Pi^2 + 
             60*lm*(-23411 + 126*Pi^2) - 164907*PolyGamma[2, 1] + 
             7355466*Zeta[3]))))/39680928000, 
      (CF*NC*(-1866216162706875*CF + 3745063939680000*CF*lm + 
         2449900494720000*CF*lm^2 - 2692667926418400*NM + 
         310138295040000*lm*NM + 136105583040000*lm^2*NM - 
         212754190269600*NL + 310138295040000*lm*NL + 136105583040000*lm^2*
          NL - 44950461070829472*NH + 310138295040000*lm*NH + 
         136105583040000*lm^2*NH - 658858077750600*CF*Pi^2 - 
         32406091200000*CF*lm*Pi^2 - 180409510612800*NM*Pi^2 - 
         1800338400000*lm*NM*Pi^2 + 142886857680000*NL*Pi^2 - 
         1800338400000*lm*NL*Pi^2 - 1800338400000*lm*NH*Pi^2 + 
         241711983380000*Sqrt[3]*CF*Pi^3 + 1888481003360000*Sqrt[3]*NH*
          Pi^3 + 30164669892000*CF*Pi^4 - 8346274632679200*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] - 1598231229100800*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 5593291341120000*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 8950249441728000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 69927753724416000*Sqrt[3]*
          NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 186463530036000*Sqrt[3]*
          CF*Pi*Log[3]^2 + 1456828202592000*Sqrt[3]*NH*Pi*Log[3]^2 + 
         1028764800*(105*CF*(244921 + 133200*lm) - 
           7*CA*(1183249 + 610500*lm) + 4*(21*(1917 + 9250*lm)*NM + 
             175*(1577 + 1110*lm)*NL + 3*(3861 + 64750*lm)*NH))*Log[x]^2 + 
         720135360000*(5441*CA + 21640*CF - 4280*NM - 740*NL)*Log[x]^3 + 
         1846401911865280*CF*PolyGamma[2, 1] - 252236411532000*NM*
          PolyGamma[2, 1] + 1028047111151200*NH*PolyGamma[2, 1] + 
         15120*Log[x]*(4*(59535*NM*(579569 + 298870*lm + 54000*lm^2 - 151880*
                Pi^2) + 19845*NL*(2094269 + 896610*lm + 162000*lm^2 + 165000*
                Pi^2) + NH*(679844939097 + 17793225450*lm + 3214890000*
                lm^2 - 385404286400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
           490*CA*(-982587510*lm - 144342000*lm^2 + 20258586*Pi^2 + 
             5*(-453316827 + 40268552*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               31492800*Zeta[3])) - 245*CF*(-6661597929 - 4520441520*lm - 
             944784000*lm^2 + 161653968*Pi^2 + 805371040*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 629856000*Zeta[3])) + 
         12064569419826560*CF*Zeta[3] - 2887832810520000*NM*Zeta[3] + 
         1209827404800000*NL*Zeta[3] - 16855236439585600*NH*Zeta[3] - 
         980*CA*(763857864000*lm^2 - 323232522327*Pi^2 + 123322440500*Sqrt[3]*
            Pi^3 + 16859801700*Pi^4 - 306180000*lm*(-8860 + 33*Pi^2) + 
           95134454100*Sqrt[3]*Pi*Log[3]^2 + 7*(-239195452185 - 
             608329054860*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             407674296000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 652350542400*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 134577398824*
              PolyGamma[2, 1] + 1062847190768*Zeta[3]))))/5833096416000, 
      (1639089003353*CF^2*NC)/1417176000 - (167669*CF^2*lm*NC)/216 - 
       543*CF^2*lm^2*NC + (1061473777*CF*NM*NC)/1458000 - 
       (255635*CF*lm*NM*NC)/3888 - (181*CF*lm^2*NM*NC)/6 + 
       (1989437*CF*NC*NL)/25920 - (255635*CF*lm*NC*NL)/3888 - 
       (181*CF*lm^2*NC*NL)/6 + (645713006222287*CF*NC*NH)/60761421000 - 
       (255635*CF*lm*NC*NH)/3888 - (181*CF*lm^2*NC*NH)/6 + 
       (52938877*CF^2*NC*Pi^2)/340200 + 5*CF^2*lm*NC*Pi^2 + 
       (36403*CF*NM*NC*Pi^2)/1080 + (5*CF*lm*NM*NC*Pi^2)/18 - 
       (64309*CF*NC*NL*Pi^2)/1944 + (5*CF*lm*NC*NL*Pi^2)/18 + 
       (5*CF*lm*NC*NH*Pi^2)/18 - (222779165*CF^2*NC*Pi^3)/
        (1062882*Sqrt[3]) - (657374935*CF*NC*NH*Pi^3)/(531441*Sqrt[3]) - 
       (6473*CF^2*NC*Pi^4)/1080 + (11212118071*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1771470*Sqrt[3]) - 
       (1633269049*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) - 
       1302*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (50920952*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6561*Sqrt[3]) - (300514256*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (6365119*CF^2*NC*Pi*Log[3]^2)/(39366*Sqrt[3]) - 
       (18782141*CF*NC*NH*Pi*Log[3]^2)/(19683*Sqrt[3]) - 
       (CF*NC*(63*CF*(494069 + 317880*lm) - 14*CA*(727052 + 437085*lm) + 
          1445990*NM + 1112580*lm*NM + 1586935*NL + 1112580*lm*NL + 
          76032*NH + 1112580*lm*NH)*Log[x]^2)/5670 - 
       (2*CF*NC*(132935*CA + 433565*CF - 94404*NM - 15894*NL)*Log[x]^3)/
        243 - (10320124541*CF^2*NC*PolyGamma[2, 1])/25509168 + 
       (573347*CF*NM*NC*PolyGamma[2, 1])/8100 - 
       (4795550669*CF*NC*NH*PolyGamma[2, 1])/159432300 + 
       (CF*NC*Log[x]*(2*(-23814*NM*(14408521 + 6024750*lm + 1134000*lm^2 - 
              3530100*Pi^2) - 893025*NL*(382617 + 160660*lm + 30240*lm^2 + 
              31272*Pi^2) - 4*NH*(1299670100133 + 35868349125*lm + 
              6751269000*lm^2 - 736259927200*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]])) + 49*CF*(-147236132199 - 90528678000*lm - 
            19840464000*lm^2 + 4496335920*Pi^2 + 20368380800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 13226976000*Zeta[3]) - 
          98*CA*(-49055915631 - 19962024750*lm - 3031182000*lm^2 + 
            812487510*Pi^2 + 5092095200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            3306744000*Zeta[3])))/1157360400 - (212137690129*CF^2*NC*Zeta[3])/
        63772920 + (3137147*CF*NM*NC*Zeta[3])/4050 - 
       (2636*CF*NC*NL*Zeta[3])/9 + (382683987331*CF*NC*NH*Zeta[3])/
        79716150 + (CA*CF*NC*(-38628820467729 + 8464792248000*lm^2 - 
          3868719894000*Pi^2 + 1782233320000*Sqrt[3]*Pi^3 + 
          164227078800*Pi^4 - 6561000*lm*(-4454017 + 11880*Pi^2) - 
          53818166740800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          33212936736000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 65993553792000*
           Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          1374865704000*Sqrt[3]*Pi*Log[3]^2 + 10320124541000*
           PolyGamma[2, 1] + 97527558322000*Zeta[3]))/51018336000, 
      (CF*NC*(-18517766400*(7*CA*(34188697 + 21918600*lm) - 
           20*(56*CF*(720902 + 448335*lm) + 3*(-5158482*NM + 464940*lm*NM + 
               640731*NL + 464940*lm*NL + 43004*NH + 464940*lm*NH)))*
          Log[x]^2 + 10369949184000*(289771*CA + 1147515*CF - 475992*NM - 
           33210*NL)*Log[x]^3 + 15120*Log[x]*
          (2*(-8*(-1928934*NM*(398049 + 1198450*lm + 210000*lm^2 - 
                 2425300*Pi^2) - 5*(321489*NL*(3740801 + 1438140*lm + 
                   252000*lm^2 + 305400*Pi^2) + 2*NH*(9719382490089 + 
                   231173095230*lm + 40507614000*lm^2 - 5502271924240*Sqrt[3]*
                    Im[PolyLog[2, (-1)^(1/3)]]))) - 147*CF*(-2956174615059 - 
               1966945809600*lm - 396809280000*lm^2 + 122879102760*Pi^2 + 
               426894124000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 264539520000*
                Zeta[3])) + 147*CA*(-4038485531829 - 1692522799200*lm - 
             242494560000*lm^2 + 86363667720*Pi^2 + 426894124000*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 264539520000*Zeta[3])) - 
         49*CA*(6193796051520000*lm^2 - 5214900477183840*Pi^2 + 
           1568835905700000*Sqrt[3]*Pi^3 + 180743320296000*Pi^4 - 
           1636838280000*lm*(-13509 + 40*Pi^2) + 1210244841540000*Sqrt[3]*Pi*
            Log[3]^2 + 7*(-4363483835510019 - 5772180636504000*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 3845762167680000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 8298821770560000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1113501498795520*
              PolyGamma[2, 1] + 10552155792477440*Zeta[3])) + 
         2*(-16*(25*(-2*NH*(-15601562714085867 + 34488182559600*lm^2 + 
                 674028310719400*Sqrt[3]*Pi^3 - 9114213150*lm*(-8693 + 
                   40*Pi^2) - 877785631708944*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]] + 24958305448352640*Sqrt[3]*Im[PolyLog[3, 
                    -((-1)^(5/6)/Sqrt[3])]] + 519964696840680*Sqrt[3]*Pi*
                  Log[3]^2 + 394515918771744*PolyGamma[2, 1] - 
                 5878158478635072*Zeta[3]) + 20253807*NL*(14554639 - 
                 3405600*lm^2 - 4422600*Pi^2 + 900*lm*(-8693 + 40*Pi^2) - 
                 44409600*Zeta[3])) + 81015228*NM*(493381099 - 21285000*
                lm^2 + 240139350*Pi^2 + 5625*lm*(-8693 + 40*Pi^2) + 311711100*
                PolyGamma[2, 1] + 812206200*Zeta[3])) + 
           49*CF*(10135302629760000*lm^2 - 5543459244417600*Pi^2 + 
             1568835905700000*Sqrt[3]*Pi^3 + 171219897576000*Pi^4 - 
             13392313200000*lm*(-1171 + 8*Pi^2) + 1210244841540000*Sqrt[3]*Pi*
              Log[3]^2 + 7*(-3307045711752909 - 5772180636504000*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 3845762167680000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 + 8298821770560000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1113501498795520*
                PolyGamma[2, 1] + 8735508489079040*Zeta[3])))))/
       839965883904000, (16544099757056882389*CF^2*NC)/3499857849600000 - 
       (18503377*CF^2*lm*NC)/9000 - (7064*CF^2*lm^2*NC)/5 + 
       (1912126519897*CF*NM*NC)/833490000 - (28039777*CF*lm*NM*NC)/162000 - 
       (3532*CF*lm^2*NM*NC)/45 + (4219455961*CF*NC*NL)/9720000 - 
       (28039777*CF*lm*NC*NL)/162000 - (3532*CF*lm^2*NC*NL)/45 + 
       (82490454248782963*CF*NC*NH)/2187411156000 - (28039777*CF*lm*NC*NH)/
        162000 - (3532*CF*lm^2*NC*NH)/45 + (5166847451*CF^2*NC*Pi^2)/
        3888000 + (163*CF^2*lm*NC*Pi^2)/15 + (3634961*CF*NM*NC*Pi^2)/5400 + 
       (163*CF*lm*NM*NC*Pi^2)/270 - (188573*CF*NC*NL*Pi^2)/1800 + 
       (163*CF*lm*NC*NL*Pi^2)/270 + (163*CF*lm*NC*NH*Pi^2)/270 - 
       (154494416461*CF^2*NC*Pi^3)/(191318760*Sqrt[3]) - 
       (87217836433*CF*NC*NH*Pi^3)/(19131876*Sqrt[3]) - 
       (43313*CF^2*NC*Pi^4)/1944 + (7687894102801*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(398580750*Sqrt[3]) - 
       (48731149373*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15943230*Sqrt[3]) - (175574*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        45 - (44141261846*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1476225*Sqrt[3]) - (49838763676*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(295245*Sqrt[3]) - 
       (22070630923*CF^2*NC*Pi*Log[3]^2)/(35429400*Sqrt[3]) - 
       (12459690919*CF*NC*NH*Pi*Log[3]^2)/(3542940*Sqrt[3]) - 
       (CF*NC*(-5*CA*(1992668759 + 2987606160*lm) + 
          CF*(46155317843 + 48888100800*lm) + 360*(-48501246*NM + 
            7544460*lm*NM + 10461647*NL + 7544460*lm*NL + 768820*NH + 
            7544460*lm*NH))*Log[x]^2)/3402000 - 
       (CF*NC*(36239375*CA + 95232907*CF - 180*(243020*NM + 17963*NL))*
         Log[x]^3)/6075 - (2278423701077*CF^2*NC*PolyGamma[2, 1])/
        5739562800 + (3516887*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (17682415993*CF*NC*NH*PolyGamma[2, 1])/71744535 - 
       (29716448898011*CF^2*NC*Zeta[3])/2869781400 + 
       (5098487*CF*NM*NC*Zeta[3])/1350 - (16564*CF*NC*NL*Zeta[3])/15 + 
       (1206002690746*CF*NC*NH*Zeta[3])/71744535 + 
       (CA*CF*NC*(-18364495945749811623 + 2719529543453184000*lm^2 - 
          4079753945662636080*Pi^2 + 847865357537968000*Sqrt[3]*Pi^3 + 
          73222794497865600*Pi^4 - 19443654720*lm*(-486450347 + 
            1075800*Pi^2) - 20251758161362506240*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 12289680841713408000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 31395242953405900800*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 654067561529289600*Sqrt[3]*
           Pi*Log[3]^2 + 1250398927151057600*PolyGamma[2, 1] + 
          37527682682092220800*Zeta[3]))/6299744129280000 - 
       (CF*NC*Log[x]*(-80*(-13122*NM*(6739138649 + 1621379130*lm + 
              296352000*lm^2 - 3318539700*Pi^2) - 964467*NL*
             (58673801 + 22059580*lm + 4032000*lm^2 + 4936600*Pi^2) - 
            10*NH*(86324147109093 + 2127573694386*lm + 388873094400*lm^2 - 
              48841988402480*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          5*CA*(-5321579614515051 - 2307802716787680*lm - 342208323072000*
             lm^2 + 257050833616080*Pi^2 + 692134985745280*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 373318170624000*Zeta[3]) + 
          CF*(38563311751257381 + 26437231779638400*lm + 5599772559360000*
             lm^2 - 2960172765018000*Pi^2 - 6921349857452800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 3733181706240000*Zeta[3])))/
        2083248720000, 
      (CF*NC*(201658476096000*(-55*CA*(81212867 + 263159820*lm) + 
           11*CF*(3625231403 + 4306251600*lm) + 
           90*(22*(-69549833 + 1329090*lm)*NM + 77*(513619 + 379740*lm)*
              NL + 12*(299328 + 2436665*lm)*NH))*Log[x]^2 + 
         621108106375680000*(6939341*CA + 9*(2267897*CF - 2319840*NM - 
             63290*NL))*Log[x]^3 + 166320*Log[x]*
          (2*(-200*(-350101521*NL*(59244877 + 20584620*lm + 3528000*lm^2 + 
                 4973400*Pi^2) + 71449290*NM*(1491500799 - 100864638*lm - 
                 17287200*lm^2 + 667316300*Pi^2) - 2*NH*
                (167024908677826383 + 3603353385603510*lm + 617579083044000*
                  lm^2 - 94475063076024400*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) - 121*CF*(-229975541500693029 - 
               186853035767832000*lm - 36748507420800000*lm^2 + 
               27918322665244200*Pi^2 + 47261042357519200*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 24499004947200000*Zeta[3])) + 
           121*CA*(-335985444924641259 - 159613204642164000*lm - 
             22457421201600000*lm^2 + 24232929913067400*Pi^2 + 
             47261042357519200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             24499004947200000*Zeta[3])) - 1331*CA*(-834804233308519589853 + 
           160278615115819200000*lm^2 - 411607513892690337600*Pi^2 + 
           57894776887961020000*Sqrt[3]*Pi^3 + 5852434588893144000*Pi^4 - 
           13124466936000*lm*(-43713987 + 107800*Pi^2) - 
           1223793035168686449600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           794848166407451520000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           2143760881337070912000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                Sqrt[3])]] + 44661685027855644000*Sqrt[3]*Pi*Log[3]^2 - 
           3377154448006528000*PolyGamma[2, 1] + 2281601187976964896000*
            Zeta[3]) + 2*(121*CF*(2885015072084745600000*lm^2 - 
             4677560924488222629600*Pi^2 + 636842545767571220000*Sqrt[3]*
              Pi^3 + 62113072420703304000*Pi^4 - 2598644453328000*lm*
              (-1728367 + 9800*Pi^2) + 491278535306412084000*Sqrt[3]*Pi*
              Log[3]^2 - 11*(585373613821407254763 + 1223793035168686449600*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 794848166407451520000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 2143760881337070912000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3377154448006528000*
                PolyGamma[2, 1] - 1880027568311017888000*Zeta[3])) - 
           400*(-2*NH*(-14529523975102825305003 + 24242140536267654000*
                lm^2 + 636525737474714395000*Sqrt[3]*Pi^3 - 21835831864770*lm*
                (-2561017 + 9800*Pi^2) - 1031477259780238378800*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 23569638736206567312000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 491034140337636819000*
                Sqrt[3]*Pi*Log[3]^2 + 384473346733039440800*PolyGamma[2, 1] - 
               5402558138137595758400*Zeta[3]) + 242620354053*NL*
              (1593653879 - 199836000*lm^2 - 308805000*Pi^2 + 180*lm*
                (-2561017 + 9800*Pi^2) - 3602016000*Zeta[3]) + 
             2829391884*NM*(-17135937000*lm^2 + 15435*lm*(-2561017 + 
                 9800*Pi^2) + 2*(-503659625554 + 545196056125*Pi^2 + 
                 676344155550*PolyGamma[2, 1] + 653890295100*Zeta[3]))))))/
       251548783082150400000, (-176501094072904099*CF^2*NC)/
        3149872064640000 - (124339919*CF^2*lm*NC)/27000 - 
       (15673*CF^2*lm^2*NC)/5 - (990794161980929*CF*NM*NC)/135025380000 - 
       (187815569*CF*lm*NM*NC)/486000 - (15673*CF*lm^2*NM*NC)/90 + 
       (16040085179*CF*NC*NL)/9720000 - (187815569*CF*lm*NC*NL)/486000 - 
       (15673*CF*lm^2*NC*NL)/90 + (1443176438573827336537*CF*NC*NH)/
        13101499118862000 - (187815569*CF*lm*NC*NH)/486000 - 
       (15673*CF*lm^2*NC*NH)/90 + (526393324823*CF^2*NC*Pi^2)/40824000 + 
       (931*CF^2*lm*NC*Pi^2)/45 + (177396103*CF*NM*NC*Pi^2)/24300 + 
       (931*CF*lm*NM*NC*Pi^2)/810 - (13293329*CF*NC*NL*Pi^2)/48600 + 
       (931*CF*lm*NC*NL*Pi^2)/810 + (931*CF*lm*NC*NH*Pi^2)/810 - 
       (1060466575763*CF^2*NC*Pi^3)/(430467210*Sqrt[3]) - 
       (2342418790663*CF*NC*NH*Pi^3)/(172186884*Sqrt[3]) - 
       (43204*CF^2*NC*Pi^4)/675 + (89680917377011*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1793613375*Sqrt[3]) - 
       (202568970323*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (143489070*Sqrt[3]) - (146944*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        15 - (1211961800872*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (13286025*Sqrt[3]) - (1338525023236*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (151495225109*CF^2*NC*Pi*Log[3]^2)/(79716150*Sqrt[3]) - 
       (334631255809*CF*NC*NH*Pi*Log[3]^2)/(31886460*Sqrt[3]) - 
       (CF*NC*(-132*CA*(-6091457707 + 1986265050*lm) + 
          33*CF*(-34810782817 + 26002015200*lm) + 
          20*(44*(-1660995074 + 54170865*lm)*NM + 
            3*(231*(4686139 + 3439420*lm)*NL + 10*(10486711 + 79450602*lm)*
               NH)))*Log[x]^2)/18711000 - 
       (CF*NC*(209481223*CA + 197893846*CF - 310244100*NM - 10318260*NL)*
         Log[x]^3)/6075 + (487267082769557*CF^2*NC*PolyGamma[2, 1])/
        51656065200 + (9818879*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (628458065128*CF*NC*NH*PolyGamma[2, 1])/645700815 - 
       (119889868065359*CF^2*NC*Zeta[3])/5165606520 + 
       (13557358*CF*NM*NC*Zeta[3])/675 - (150548*CF*NC*NL*Zeta[3])/45 + 
       (30946820524036*CF*NC*NH*Zeta[3])/645700815 + 
       (CA*CF*NC*(-209692528278566341131 + 135761848390032480000*lm^2 - 
          905218883275913413200*Pi^2 + 58198405677873440000*Sqrt[3]*Pi^3 + 
          4666570462342656000*Pi^4 - 145827410400*lm*(-3250850059 + 
            6144600*Pi^2) - 1181205298956087283200*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 694282200999690240000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 2155003821672113664000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 44895912951502368000*
           Sqrt[3]*Pi*Log[3]^2 - 668530437559832204000*PolyGamma[2, 1] + 
          1940185716070247912000*Zeta[3]))/141744242908800000 + 
       CF*Log[x]*((-1238602886429*NM*NC)/107163000 - (8872213*lm*NM*NC)/
          4050 - 392*lm^2*NM*NC - (522513967*NC*NL)/81000 - 
         (8872213*lm*NC*NL)/4050 - 392*lm^2*NC*NL - 
         (46787674400237951*NC*NH)/472637053350 - (8872213*lm*NC*NH)/4050 - 
         392*lm^2*NC*NH + (5077097*NM*NC*Pi^2)/405 - (224891*NC*NL*Pi^2)/
          405 + (1338525023236*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7971615*Sqrt[3]) + CF*NC*(-2624761966130111/3124873080000 - 
           (7681513*lm)/225 - 7056*lm^2 + (97523497*Pi^2)/8100 + 
           (1211961800872*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) - 
           4704*Zeta[3]) + CA*NC*(31562777045180701/3124873080000 + 
           (119820743*lm)/8100 + 2156*lm^2 - (1293617*Pi^2)/225 - 
           (605980900436*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) + 
           2352*Zeta[3])), 
      (CF*NC*(-170401412301120*(143*CA*(-121547935459 + 28094913000*lm) - 
           20*(143*CF*(-9158474593 + 4597349400*lm) + 
             5*(143*(-10888886149 + 51081660*lm)*NM + 3003*(3249677 + 
                 2432460*lm)*NL + (1096802503 + 7304677380*lm)*NH)))*
          Log[x]^2 + 20468617645610534400*(96656317*CA + 84329235*CF - 
           450995300*NM - 4054100*NL)*Log[x]^3 + 216216*Log[x]*
          (-10*(20*(-59167157049*NL*(119147057 + 37676100*lm + 6350400*
                  lm^2 + 10225000*Pi^2) + 223609815*NM*(1029248404777 - 
                 9969096060*lm - 1680315840*lm^2 + 237665519280*Pi^2) - 4*NH*
                (28407169148079244836 + 557296931423457225*lm + 
                 93933778530992400*lm^2 - 16060335852859298000*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]])) + 20449*CF*
              (13298923180451823 - 34283295047988000*lm - 6614731335744000*
                lm^2 + 16730301576920400*Pi^2 + 9835707432958400*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 4409820890496000*Zeta[3])) + 
           20449*CA*(-33701017992121329 - 145637227152270000*lm - 
             20211679081440000*lm^2 + 80034245081305200*Pi^2 + 
             49178537164792000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             22049104452480000*Zeta[3])) - 265837*CA*
          (136732008985941600000*lm^2 - 1468803248233808831820*Pi^2 + 
           66268078829557220000*Sqrt[3]*Pi^3 + 6011627081456304000*Pi^4 - 
           802050757200*lm*(-611115739 + 1293600*Pi^2) + 51121089382801284000*
            Sqrt[3]*Pi*Log[3]^2 + 11*(130869759606125025951 - 
             110626263515038966800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             69278286189692160000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             223073844579496512000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] - 101500725390533940800*PolyGamma[2, 1] + 
             182520179353282064000*Zeta[3])) + 
         5*(265837*CF*(89497314972616320000*lm^2 - 593784334030321816200*
              Pi^2 + 26507231531822888000*Sqrt[3]*Pi^3 + 2344285284392620800*
              Pi^4 - 5774765451840*lm*(-24207749 + 117600*Pi^2) + 
             20448435753120513600*Sqrt[3]*Pi*Log[3]^2 + 
             11*(62383381260956895717 - 44250505406015586720*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 27711314475876864000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 + 89229537831798604800*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 40600290156213576320*
                PolyGamma[2, 1] + 57902169383392194560*Zeta[3])) - 
           32*(-(NH*(41305030764540633090000*lm^2 - 2665184589272205*lm*
                 (-35831249 + 117600*Pi^2) + 2*(-15926309452811134330484238 + 
                  703342333256156881787500*Sqrt[3]*Pi^3 - 
                  1314383775389265022041600*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]] + 26043761825713694822760000*Sqrt[3]*
                   Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                  542578371369035308807500*Sqrt[3]*Pi*Log[3]^2 + 
                  430787752799481393491175*PolyGamma[2, 1] - 
                  5811884662715610782953650*Zeta[3]))) + 177678972618147*NL*
              (2943803159 - 232470000*lm^2 - 416318700*Pi^2 + 15*lm*
                (-35831249 + 117600*Pi^2) - 5542668000*Zeta[3]) + 
             95928610635*NM*(-430580934000*lm^2 + 27783*lm*(-35831249 + 
                 117600*Pi^2) + 2*(-138703385313179 + 73195577070840*Pi^2 + 
                 87496104925845*PolyGamma[2, 1] + 51499197529290*
                  Zeta[3]))))))/20724475366180666080000, 
      (-4411395924378516155818343*CF^2*NC)/22010518519688160000 - 
       (3036572269*CF^2*lm*NC)/330750 - (31072*CF^2*lm^2*NC)/5 - 
       (15012691432199400257*CF*NM*NC)/89859390390000 - 
       (4578131869*CF*lm*NM*NC)/5953500 - (15536*CF*lm^2*NM*NC)/45 + 
       (31647439177*CF*NC*NL)/6378750 - (4578131869*CF*lm*NC*NL)/5953500 - 
       (15536*CF*lm^2*NC*NL)/45 + (24106251335618018213047859*CF*NC*NH)/
        86351980692419442000 - (4578131869*CF*lm*NC*NH)/5953500 - 
       (15536*CF*lm^2*NC*NH)/45 + (7392865498351*CF^2*NC*Pi^2)/53581500 + 
       (1616*CF^2*lm*NC*Pi^2)/45 + (2569404514*CF*NM*NC*Pi^2)/42525 + 
       (808*CF*lm*NM*NC*Pi^2)/405 - (26504311*CF*NC*NL*Pi^2)/42525 + 
       (808*CF*lm*NC*NL*Pi^2)/405 + (808*CF*lm*NC*NH*Pi^2)/405 - 
       (11002489858133*CF^2*NC*Pi^3)/(1721868840*Sqrt[3]) - 
       (501552452114*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) - 
       (629821*CF^2*NC*Pi^4)/4050 + (121490961508211557*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1054644664500*Sqrt[3]) + 
       (2445703784968*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (215233605*Sqrt[3]) - (108392*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (22004979716266*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (93002175*Sqrt[3]) - (1146405604832*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(885735*Sqrt[3]) - 
       (11002489858133*CF^2*NC*Pi*Log[3]^2)/(2232052200*Sqrt[3]) - 
       (71650350302*CF*NC*NH*Pi*Log[3]^2)/(2657205*Sqrt[3]) - 
       (CF*NC*(-117*CA*(-5355052823403 + 274676340400*lm) + 
          4*(39*CF*(-7672182002651 + 674205562800*lm) + 
            70*(26*(-81868779647 + 802625670*lm)*NM + 33033*(850613 + 
                631740*lm)*NL + 10*(331107961 + 2086826742*lm)*NH)))*
         Log[x]^2)/851350500 + (2*CF*NC*(-5662887208*CA + 4736669609*CF + 
          6992920200*NM + 97287960*NL)*Log[x]^3)/42525 + 
       (5292021547954831*CF^2*NC*PolyGamma[2, 1])/38742048900 + 
       (20703781*CF*NM*NC*PolyGamma[2, 1])/150 - 
       (55996397687033*CF*NC*NH*PolyGamma[2, 1])/19371024450 - 
       (966332452366259*CF^2*NC*Zeta[3])/135597171150 + 
       (11894581*CF*NM*NC*Zeta[3])/75 - (390568*CF*NC*NL*Zeta[3])/45 + 
       (1146034117316647*CF*NC*NH*Zeta[3])/9685512225 + 
       CA*CF*NC*(2655272009917428994298861/27513148149610200000 + 
         (85448*lm^2)/45 - (64902949943947*Pi^2)/943034400 + 
         (11002489858133*Pi^3)/(3443737680*Sqrt[3]) + (642749*Pi^4)/8100 + 
         lm*(79135229759/11907000 - (4444*Pi^2)/405) - 
         (121490961508211557*Im[PolyLog[2, (-1)^(1/3)]])/
          (2109289329000*Sqrt[3]) + (54196*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (11002489858133*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (93002175*Sqrt[3]) + (11002489858133*Pi*Log[3]^2)/
          (4464104400*Sqrt[3]) - (5292021547954831*PolyGamma[2, 1])/
          77484097800 + (2307257699101361*Zeta[3])/271194342300) + 
       CF*Log[x]*((-70696523676461*NM*NC)/3241680750 - (72126658*lm*NM*NC)/
          14175 - 896*lm^2*NM*NC - (111072821*NC*NL)/6750 - 
         (72126658*lm*NC*NL)/14175 - 896*lm^2*NC*NL - 
         (483907801940311709*NC*NH)/1901801476575 - (72126658*lm*NC*NH)/
          14175 - 896*lm^2*NC*NH + (33201992*NM*NC*Pi^2)/405 - 
         (584236*NC*NL*Pi^2)/405 + (1146405604832*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) + 
         CF*NC*(109654320422190212407/165422968672500 - (125202116*lm)/1575 - 
           16128*lm^2 + (2020238783*Pi^2)/17010 + 
           (22004979716266*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) - 
           10752*Zeta[3]) + CA*NC*(-5829967919180777209/18905482134000 + 
           (485602219*lm)/14175 + 4928*lm^2 - (9985847131*Pi^2)/170100 - 
           (11002489858133*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) + 
           5376*Zeta[3])), (23619906904906057276113619*CF^2*NC)/
        30014343435938400000 + (248720621*CF^2*lm*NC)/14700 + 
       10812*CF^2*lm^2*NC + (708190244819753083*CF*NM*NC)/285267906000 + 
       (367922921*CF*lm*NM*NC)/264600 + (1802*CF*lm^2*NM*NC)/3 - 
       (21861454693*CF*NC*NL)/1984500 + (367922921*CF*lm*NC*NL)/264600 + 
       (1802*CF*lm^2*NC*NL)/3 - (912903233544423312320117*CF*NC*NH)/
        1570036012589444400 + (367922921*CF*lm*NC*NH)/264600 + 
       (1802*CF*lm^2*NC*NH)/3 - (1027354362305729*CF^2*NC*Pi^2)/2918916000 - 
       72*CF^2*lm*NC*Pi^2 - (215994910*CF*NM*NC*Pi^2)/189 - 
       4*CF*lm*NM*NC*Pi^2 + (154073*CF*NC*NL*Pi^2)/126 - 
       4*CF*lm*NC*NL*Pi^2 - 4*CF*lm*NC*NH*Pi^2 + 
       (15952358184659*CF^2*NC*Pi^3)/(1291401630*Sqrt[3]) + 
       (10000387103945*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) + 
       (225326*CF^2*NC*Pi^4)/675 - (1293574527534380923*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(6327867987000*Sqrt[3]) - 
       (34587220739488*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (215233605*Sqrt[3]) + (204448*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 + (127618865477272*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (279006525*Sqrt[3]) + (4571605533232*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (15952358184659*CF^2*NC*Pi*Log[3]^2)/(1674039150*Sqrt[3]) + 
       (285725345827*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       CF*((-10803128279233*CF*NC)/2976750 + CA*(1132274467897/595350 - 
           81994*lm)*NC + 268344*CF*lm*NC - (20290953787*NM*NC)/1485 + 
         14908*lm*NM*NC + (98729*NC*NL)/5 + 14908*lm*NC*NL + 
         (31964687*NC*NH)/12285 + 14908*lm*NC*NH)*Log[x]^2 - 
       (2*CF*NC*(-4942903270*CA + 4473900393*CF + 
          18900*(1558327*NM + 3727*NL))*Log[x]^3)/14175 - 
       (61206585901080773*CF^2*NC*PolyGamma[2, 1])/174339220050 - 
       (78560737*CF*NM*NC*PolyGamma[2, 1])/60 + 
       (221637863079343*CF*NC*NH*PolyGamma[2, 1])/13947137604 + 
       CA*CF*NC*(-11554723220794360037455097/30014343435938400000 - 
         (9911*lm^2)/3 + (973037024791*Pi^2)/5544000 - (15952358184659*Pi^3)/
          (2582803260*Sqrt[3]) - (114823*Pi^4)/675 + 
         lm*(-6272261731/529200 + 22*Pi^2) + (1293574527534380923*
           Im[PolyLog[2, (-1)^(1/3)]])/(12655735974000*Sqrt[3]) - 
         (102224*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (63809432738636*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (279006525*Sqrt[3]) - (15952358184659*Pi*Log[3]^2)/
          (3348078300*Sqrt[3]) + (61206585901080773*PolyGamma[2, 1])/
          348678440100 - (10533822818441977*Zeta[3])/1220374540350) - 
       (4181470564740002*CF^2*NC*Zeta[3])/610187270175 - 
       (6437019*CF*NM*NC*Zeta[3])/10 + 18316*CF*NC*NL*Zeta[3] - 
       (1450332595432529*CF*NC*NH*Zeta[3])/6973568802 + 
       CF*Log[x]*((-172659326088671*NM*NC)/28814940 + (1060277*lm*NM*NC)/
          105 + 1680*lm^2*NM*NC + (219580637*NC*NL)/6300 + 
         (1060277*lm*NC*NL)/105 + 1680*lm^2*NC*NL + 
         (12279256101997479983*NC*NH)/21784271458950 + (1060277*lm*NC*NH)/
          105 + 1680*lm^2*NC*NH - (3115180*NM*NC*Pi^2)/3 + 
         (9134*NC*NL*Pi^2)/3 - (4571605533232*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CA*NC*(221092422634284322787/360922840740000 - (14132647*lm)/210 - 
           9240*lm^2 + (2229697091*Pi^2)/14175 + 
           (63809432738636*Im[PolyLog[2, (-1)^(1/3)]])/(837019575*Sqrt[3]) - 
           10080*Zeta[3]) + CF*NC*(-238371913050647971139/180461420370000 + 
           (5567862*lm)/35 + 30240*lm^2 - (1503469888*Pi^2)/4725 - 
           (127618865477272*Im[PolyLog[2, (-1)^(1/3)]])/(837019575*Sqrt[3]) + 
           20160*Zeta[3])), (-1915258771838565422093790013777*CF^2*NC)/
        669559973368913827200000 - (29618611097*CF^2*lm*NC)/1764000 - 
       (56631*CF^2*lm^2*NC)/5 - (3357776608001382628922009*CF*NM*NC)/
        2105824860659520000 - (44603173697*CF*lm*NM*NC)/31752000 - 
       (18877*CF*lm^2*NM*NC)/30 + (24228720870031*CF*NC*NL)/1905120000 - 
       (44603173697*CF*lm*NC*NL)/31752000 - (18877*CF*lm^2*NC*NL)/30 + 
       (225539509365964884944366803*CF*NC*NH)/355276720563097132800 - 
       (44603173697*CF*lm*NC*NH)/31752000 - (18877*CF*lm^2*NC*NH)/30 + 
       (34436391985708831*CF^2*NC*Pi^2)/22289904000 + (291*CF^2*lm*NC*Pi^2)/
        5 + (15780460067*CF*NM*NC*Pi^2)/37800 + (97*CF*lm*NM*NC*Pi^2)/30 - 
       (2020747*CF*NC*NL*Pi^2)/1575 + (97*CF*lm*NC*NL*Pi^2)/30 + 
       (97*CF*lm*NC*NH*Pi^2)/30 - (182245755530005*CF^2*NC*Pi^3)/
        (12397455648*Sqrt[3]) - (31095888117497*CF*NC*NH*Pi^3)/
        (387420489*Sqrt[3]) - (5431873*CF^2*NC*Pi^4)/16200 + 
       (3681835595666506861*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (15186883168800*Sqrt[3]) + (20798308745963*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(387420489*Sqrt[3]) - 
       (130862*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (36449151106001*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (66961566*Sqrt[3]) - (71076315697136*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23914845*Sqrt[3]) - 
       (36449151106001*CF^2*NC*Pi*Log[3]^2)/(3214155168*Sqrt[3]) - 
       (4442269731071*CF*NC*NH*Pi*Log[3]^2)/(71744535*Sqrt[3]) - 
       (CF*NC*(CA*(184964155523021849 - 1832904502228800*lm) + 
          8*(104*CF*(-440775772260067 + 7209851625900*lm) + 
            315*((-40154435156023 + 132244192080*lm)*NM + 
              14*(2574*(4899871 + 3669780*lm)*NL + 5*(344415199 + 
                  1889202744*lm)*NH))))*Log[x]^2)/20432412000 + 
       (CF*NC*(-224717835199*CA + 42*(9034169941*CF + 
            360*(11484085*NM + 61163*NL)))*Log[x]^3)/85050 + 
       (2118029379494137961*CF^2*NC*PolyGamma[2, 1])/1394713760400 + 
       (275953303*CF*NM*NC*PolyGamma[2, 1])/225 - 
       (631142108829452*CF*NC*NH*PolyGamma[2, 1])/87169610025 + 
       CA*CF*NC*(761657938150693207678048693819/535647978695131061760000 + 
         (207647*lm^2)/60 - (882558851769887*Pi^2)/1143072000 + 
         (182245755530005*Pi^3)/(24794911296*Sqrt[3]) + 
         (5515681*Pi^4)/32400 + lm*(770346745867/63504000 - (1067*Pi^2)/60) - 
         (3681835595666506861*Im[PolyLog[2, (-1)^(1/3)]])/
          (30373766337600*Sqrt[3]) + (65431*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (36449151106001*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (133923132*Sqrt[3]) + (36449151106001*Pi*Log[3]^2)/
          (6428310336*Sqrt[3]) - (2118029379494137961*PolyGamma[2, 1])/
          2789427520800 - (1711642677985687661*Zeta[3])/9762996322800) + 
       (363221277337931353*CF^2*NC*Zeta[3])/976299632280 + 
       (38702484*CF*NM*NC*Zeta[3])/25 - (300674*CF*NC*NL*Zeta[3])/15 + 
       (22866310327719776*CF*NC*NH*Zeta[3])/87169610025 + 
       CF*Log[x]*((-794707742777617717*NM*NC)/2921834916000 - 
         (22317709*lm*NM*NC)/2100 - 1848*lm^2*NM*NC - (42497288147*NC*NL)/
          1134000 - (22317709*lm*NC*NL)/2100 - 1848*lm^2*NC*NL - 
         (480107484422627649773*NC*NH)/821578237880400 - 
         (22317709*lm*NC*NH)/2100 - 1848*lm^2*NC*NH + 
         (22975832*NM*NC*Pi^2)/45 - (150046*NC*NL*Pi^2)/45 + 
         (71076315697136*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (71744535*Sqrt[3]) + CF*NC*(5861958930487957419711419/
            619343594709840000 - (58221327*lm)/350 - 33264*lm^2 + 
           (145859635267*Pi^2)/113400 + (36449151106001*
             Im[PolyLog[2, (-1)^(1/3)]])/(200884698*Sqrt[3]) - 
           22176*Zeta[3]) + CA*NC*(-5800805862420748732613033/
            1238687189419680000 + (299825999*lm)/4200 + 10164*lm^2 - 
           (87308164999*Pi^2)/136080 - (36449151106001*
             Im[PolyLog[2, (-1)^(1/3)]])/(401769396*Sqrt[3]) + 
           11088*Zeta[3])), (5142817657768262759881607087401*CF^2*NC)/
        596864890546003183104000 + (279321989*CF^2*lm*NC)/9408 + 
       (37905*CF^2*lm^2*NC)/2 + (1075464836348130421321547*CF*NM*NC)/
        40110949726848000 + (413050829*CF*lm*NM*NC)/169344 + 
       (12635*CF*lm^2*NM*NC)/12 - (1872689077037*CF*NC*NL)/71124480 + 
       (413050829*CF*lm*NC*NL)/169344 + (12635*CF*lm^2*NC*NL)/12 - 
       (183744246418691547376937066108363*CF*NC*NH)/
        146619860362625681929497600 + (413050829*CF*lm*NC*NH)/169344 + 
       (12635*CF*lm^2*NC*NH)/12 - (3337981459557713*CF^2*NC*Pi^2)/
        1005903360 - (225*CF^2*lm*NC*Pi^2)/2 - (15593093693*CF*NM*NC*Pi^2)/
        1296 - (25*CF*lm*NM*NC*Pi^2)/4 + (605015*CF*NC*NL*Pi^2)/252 - 
       (25*CF*lm*NC*NL*Pi^2)/4 - (25*CF*lm*NC*NH*Pi^2)/4 + 
       (4013547186078385*CF^2*NC*Pi^3)/(148769467776*Sqrt[3]) + 
       (778864521558935*CF*NC*NH*Pi^3)/(4649045868*Sqrt[3]) + 
       (582385*CF^2*NC*Pi^4)/864 - (3007530002499114013*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7289703921024*Sqrt[3]) - 
       (61427901386573761*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (162716605380*Sqrt[3]) + (157615*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 + (802709437215677*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(803538792*Sqrt[3]) + 
       (89013088178164*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) + (802709437215677*CF^2*NC*Pi*Log[3]^2)/
        (38569862016*Sqrt[3]) + (22253272044541*CF*NC*NH*Pi*Log[3]^2)/
        (172186884*Sqrt[3]) + CF*((-34963374625348381*CF*NC)/908107200 + 
         CA*(436012587521157/22422400 - 183205*lm)*NC + 599580*CF*lm*NC - 
         (155970330357031*NM*NC)/1081080 + 33310*lm*NM*NC + 
         (87687*NC*NL)/2 + 33310*lm*NC*NL + (17166776299*NC*NH)/2625480 + 
         33310*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-34423310429*CA + 9*(6457427863*CF + 
            840*(31237467*NM + 16655*NL)))*Log[x]^3)/5670 - 
       (1840636432031907091*CF^2*NC*PolyGamma[2, 1])/523017660150 - 
       (588969248*CF*NM*NC*PolyGamma[2, 1])/45 + 
       (14389124516131351*CF*NC*NH*PolyGamma[2, 1])/418414128120 - 
       (28867803766470722617*CF^2*NC*Zeta[3])/29288988968400 - 
       (251452501*CF*NM*NC*Zeta[3])/45 + 39985*CF*NC*NL*Zeta[3] - 
       (91946502532909409*CF*NC*NH*Zeta[3])/209207064060 + 
       CA*CF*NC*(-179219338134213310021655265431309/
          41780542338220222817280000 - (138985*lm^2)/24 + 
         (72280223369365027*Pi^2)/43589145600 - (4013547186078385*Pi^3)/
          (297538935552*Sqrt[3]) - (591025*Pi^4)/1728 + 
         lm*(-7039830799/338688 + (275*Pi^2)/8) + 
         (3007530002499114013*Im[PolyLog[2, (-1)^(1/3)]])/
          (14579407842048*Sqrt[3]) - (157615*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 - (802709437215677*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1607077584*Sqrt[3]) - (802709437215677*Pi*Log[3]^2)/
          (77139724032*Sqrt[3]) + (1840636432031907091*PolyGamma[2, 1])/
          1046035320300 + (27395546415980431777*Zeta[3])/58577977936800) + 
       CF*Log[x]*((-26392561539358129103*NM*NC)/389577988800 + 
         (1122417*lm*NM*NC)/56 + 3300*lm^2*NM*NC + (15886222049*NC*NL)/
          211680 + (1122417*lm*NC*NL)/56 + 3300*lm^2*NC*NL + 
         (24324063652232528615574653*NC*NH)/19944633302784590400 + 
         (1122417*lm*NC*NH)/56 + 3300*lm^2*NC*NH - (93713818*NM*NC*Pi^2)/
          9 + (19955*NC*NL*Pi^2)/3 - (89013088178164*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CA*NC*(282819026944378795581156181/38647040309894016000 - 
           (14933787*lm)/112 - 18150*lm^2 + (268414921753*Pi^2)/181440 + 
           (802709437215677*Im[PolyLog[2, (-1)^(1/3)]])/(4821232752*
             Sqrt[3]) - 19800*Zeta[3]) + CF*NC*(-286604576847767404503839011/
            19323520154947008000 + (8854353*lm)/28 + 59400*lm^2 - 
           (89703463691*Pi^2)/30240 - (802709437215677*
             Im[PolyLog[2, (-1)^(1/3)]])/(2410616376*Sqrt[3]) + 
           39600*Zeta[3])), (-1290733877404396058134070651666153*CF^2*NC)/
        37602488104398200535552000 - (7818684347*CF^2*lm*NC)/272160 - 
       19336*CF^2*lm^2*NC - (2168729149132425667079351*CF*NM*NC)/
        180499273770816000 - (11765548667*CF*lm*NM*NC)/4898880 - 
       (9668*CF*lm^2*NM*NC)/9 + (2088505156945757*CF*NC*NL)/72013536000 - 
       (11765548667*CF*lm*NC*NL)/4898880 - (9668*CF*lm^2*NC*NL)/9 + 
       (10191408923143173221915242079251*CF*NC*NH)/
        7689852816221626674624000 - (11765548667*CF*lm*NC*NH)/4898880 - 
       (9668*CF*lm^2*NC*NH)/9 + (430204503623983213*CF^2*NC*Pi^2)/
        24518894400 + (805*CF^2*lm*NC*Pi^2)/9 + (460051385147*CF*NM*NC*Pi^2)/
        204120 + (805*CF*lm*NM*NC*Pi^2)/162 - (1779320*CF*NC*NL*Pi^2)/729 + 
       (805*CF*lm*NC*NL*Pi^2)/162 + (805*CF*lm*NC*NH*Pi^2)/162 - 
       (10319396679500381*CF^2*NC*Pi^3)/(334731302496*Sqrt[3]) - 
       (1177191614138785*CF*NC*NH*Pi^3)/(6973568802*Sqrt[3]) - 
       (2140543*CF^2*NC*Pi^4)/3240 + (194669693020588906553*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(410045845557600*Sqrt[3]) + 
       (39360325265235287*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (244074908070*Sqrt[3]) - (244442*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (10319396679500381*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9039811410*Sqrt[3]) - 
       (269072368946008*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) - (10319396679500381*CF^2*NC*Pi*Log[3]^2)/
        (433910947680*Sqrt[3]) - (33634046118251*CF*NC*NH*Pi*Log[3]^2)/
        (258280326*Sqrt[3]) - 
       (CF*NC*(-34*CA*(-214149801668636969 + 395386696504800*lm) + 
          15*(85*CF*(-11402914693564201 + 34506475331328*lm) + 
            56*(51*(-43665951427201 + 57054357360*lm)*NM + 
              143*(64260*(420167 + 316652*lm)*NL + (4137362059 + 20348057520*
                   lm)*NH))))*Log[x]^2)/69470200800 + 
       (CF*NC*(-494667330760*CA + 955949927137*CF + 
          5040*(39004883*NM + 79163*NL))*Log[x]^3)/17010 + 
       (24336791357472326533*CF^2*NC*PolyGamma[2, 1])/1506290861232 + 
       (21296122676*CF*NM*NC*PolyGamma[2, 1])/2025 - 
       (50559560270481769*CF*NC*NH*PolyGamma[2, 1])/3138105960900 + 
       CA*CF*NC*(644718941632092045391716965488351/
          37602488104398200535552000 + (53174*lm^2)/9 - 
         (860334756167725361*Pi^2)/98075577600 + (10319396679500381*Pi^3)/
          (669462604992*Sqrt[3]) + (722101*Pi^4)/2160 + 
         lm*(203095835977/9797760 - (8855*Pi^2)/324) - 
         (194669693020588906553*Im[PolyLog[2, (-1)^(1/3)]])/
          (820091691115200*Sqrt[3]) + (122221*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 + (10319396679500381*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (18079622820*Sqrt[3]) + (10319396679500381*Pi*Log[3]^2)/
          (867821895360*Sqrt[3]) - (24336791357472326533*PolyGamma[2, 1])/
          3012581722464 - (83179006520394886313*Zeta[3])/52720180143120) + 
       (84312244902929429507*CF^2*NC*Zeta[3])/26360090071560 + 
       (31411936402*CF*NM*NC*Zeta[3])/2025 - (1141646*CF*NC*NL*Zeta[3])/
        27 + (839040403037675231*CF*NC*NH*Zeta[3])/1569052980450 + 
       CF*Log[x]*((-4853782890147889703*NM*NC)/584366983200 - 
         (19876225*lm*NM*NC)/972 - 3520*lm^2*NM*NC - (1116392841959*NC*NL)/
          14288400 - (19876225*lm*NC*NL)/972 - 3520*lm^2*NC*NL - 
         (257130708609312885031697*NC*NH)/209209440238999200 - 
         (19876225*lm*NC*NH)/972 - 3520*lm^2*NC*NH + (26018596*NM*NC*Pi^2)/
          9 - (190006*NC*NL*Pi^2)/27 + (269072368946008*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(129140163*Sqrt[3]) + 
         CF*NC*(9783969081965452878206509561/86955840697261536000 - 
           (17310145*lm)/54 - 63360*lm^2 + (492076096123*Pi^2)/34020 + 
           (10319396679500381*Im[PolyLog[2, (-1)^(1/3)]])/
            (27119434230*Sqrt[3]) - 42240*Zeta[3]) + 
         CA*NC*(-4883522716264730275473665807/86955840697261536000 + 
           (266538635*lm)/1944 + 19360*lm^2 - (983722978181*Pi^2)/136080 - 
           (10319396679500381*Im[PolyLog[2, (-1)^(1/3)]])/
            (54238868460*Sqrt[3]) + 21120*Zeta[3])), 
      (1920601838951909235564258278865353*CF^2*NC)/
        22561492862638920321331200 + (37478622829*CF^2*lm*NC)/762048 + 
       (62755*CF^2*lm^2*NC)/2 + (102957375218964344246379487*CF*NM*NC)/
        360998547541632000 + (55411993669*CF*lm*NM*NC)/13716864 + 
       (62755*CF*lm^2*NM*NC)/36 - (1640215588057273*CF*NC*NL)/28805414400 + 
       (55411993669*CF*lm*NC*NL)/13716864 + (62755*CF*lm^2*NC*NL)/36 - 
       (340343163553414158762468269502934651771*CF*NC*NH)/
        135764859000678689567847245184000 + (55411993669*CF*lm*NC*NH)/
        13716864 + (62755*CF*lm^2*NC*NH)/36 - 
       (1219641493886530889*CF^2*NC*Pi^2)/39230231040 - 
       (3025*CF^2*lm*NC*Pi^2)/18 - (52063833143519*CF*NM*NC*Pi^2)/408240 - 
       (3025*CF*lm*NM*NC*Pi^2)/324 + (89821105*CF*NC*NL*Pi^2)/20412 - 
       (3025*CF*lm*NC*NL*Pi^2)/324 - (3025*CF*lm*NC*NH*Pi^2)/324 + 
       (218154913722371005*CF^2*NC*Pi^3)/(4016775629952*Sqrt[3]) + 
       (42191237834110505*CF*NC*NH*Pi^3)/(125524238436*Sqrt[3]) + 
       (3274645*CF^2*NC*Pi^4)/2592 - (768895960570998471101*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(984110029338240*Sqrt[3]) - 
       (3560523280195787083*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (4393348345260*Sqrt[3]) + (2561185*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/18 + (43630982744474201*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(21695547384*Sqrt[3]) + 
       (4821855752469772*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) + (43630982744474201*CF^2*NC*Pi*Log[3]^2)/
        (1041386274432*Sqrt[3]) + (1205463938117443*CF*NC*NH*Pi*Log[3]^2)/
        (4649045868*Sqrt[3]) + CF*((-3027049070144036479*CF*NC)/8172964800 + 
         CA*(1011194833872410749/5448643200 - (3389815*lm)/9)*NC + 
         1232660*CF*lm*NC - (14888184048742051*NM*NC)/9729720 + 
         (616330*lm*NM*NC)/9 + (4844389*NC*NL)/54 + (616330*lm*NC*NL)/9 + 
         (46436467375763*NC*NH)/3142699560 + (616330*lm*NC*NH)/9)*
        Log[x]^2 - (CF*NC*(-2854794898669*CA + 5491449975503*CF + 
          7560*(2929948921*NM + 308165*NL))*Log[x]^3)/51030 - 
       (945850861838798855099*CF^2*NC*PolyGamma[2, 1])/28242953648100 - 
       (53076804836*CF*NM*NC*PolyGamma[2, 1])/405 + 
       (777492925319367259*CF*NC*NH*PolyGamma[2, 1])/11297181459240 - 
       (8772902043728635288069*CF^2*NC*Zeta[3])/790802702146800 - 
       (18456350137*CF*NM*NC*Zeta[3])/405 + (2178715*CF*NC*NL*Zeta[3])/27 - 
       (4873691832423600701*CF*NC*NH*Zeta[3])/5648590729620 + 
       CA*CF*NC*(-47972238143150333486922436022581727/
          1128074643131946016066560000 - (690305*lm^2)/72 + 
         (554315752276141727*Pi^2)/35663846400 - (218154913722371005*Pi^3)/
          (8033551259904*Sqrt[3]) - (1104455*Pi^4)/1728 + 
         lm*(-944288186039/27433728 + (33275*Pi^2)/648) + 
         (768895960570998471101*Im[PolyLog[2, (-1)^(1/3)]])/
          (1968220058676480*Sqrt[3]) - (2561185*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          36 - (43630982744474201*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (43391094768*Sqrt[3]) - (43630982744474201*Pi*Log[3]^2)/
          (2082772548864*Sqrt[3]) + (945850861838798855099*PolyGamma[2, 1])/
          56485907296200 + (8695442705243736758749*Zeta[3])/
          1581605404293600) + CF*Log[x]*((-2588069136308834809619*NM*NC)/
          3506201899200 + (504326779*lm*NM*NC)/13608 + 6050*lm^2*NM*NC + 
         (855659888983*NC*NL)/5715360 + (504326779*lm*NC*NL)/13608 + 
         6050*lm^2*NC*NL + (475662094279405401315293232059*NC*NH)/
          194400340802241402628800 + (504326779*lm*NC*NH)/13608 + 
         6050*lm^2*NC*NH - (325557442*NM*NC*Pi^2)/3 + (362615*NC*NL*Pi^2)/
          27 - (4821855752469772*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CA*NC*(73027117987013941085041475953/
            1043470088367138432000 - (6700192169*lm)/27216 - 33275*lm^2 + 
           (22708589068063*Pi^2)/1632960 + (43630982744474201*
             Im[PolyLog[2, (-1)^(1/3)]])/(130173284304*Sqrt[3]) - 
           36300*Zeta[3]) + CF*NC*(-73221772971703954654414098067/
            521735044183569216000 + (442580479*lm)/756 + 108900*lm^2 - 
           (22720983950647*Pi^2)/816480 - (43630982744474201*
             Im[PolyLog[2, (-1)^(1/3)]])/(65086642152*Sqrt[3]) + 
           72600*Zeta[3])), (-8299550340441234198638902136207612210557*CF^2*
         NC)/20783365206402190413506284800000 - (63426368987*CF^2*lm*NC)/
        1360800 - (156629*CF^2*lm^2*NC)/5 - (48353191215345424420430826593*CF*
         NM*NC)/646619846276263860000 - (95397480467*CF*lm*NM*NC)/
        24494400 - (156629*CF*lm^2*NM*NC)/90 + (806030605811069*CF*NC*NL)/
        13335840000 - (95397480467*CF*lm*NC*NL)/24494400 - 
       (156629*CF*lm^2*NC*NL)/90 + (2628738168540035944173211899827758154761*
         CF*NC*NH)/1018236442505090171758854338880000 - 
       (95397480467*CF*lm*NC*NH)/24494400 - (156629*CF*lm^2*NC*NH)/90 + 
       (2712769218324839269*CF^2*NC*Pi^2)/13621608000 + 
       (5929*CF^2*lm*NC*Pi^2)/45 + (2086954915273*CF*NM*NC*Pi^2)/510300 + 
       (5929*CF*lm*NM*NC*Pi^2)/810 - (317781607*CF*NC*NL*Pi^2)/72900 + 
       (5929*CF*lm*NC*NL*Pi^2)/810 + (5929*CF*lm*NC*NH*Pi^2)/810 - 
       (226164450292534169*CF^2*NC*Pi^3)/(3765727153080*Sqrt[3]) - 
       (31141801863135572*CF*NC*NH*Pi^3)/(94143178827*Sqrt[3]) - 
       (18194*CF^2*NC*Pi^4)/15 + (505413360911552981287*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(576626970315375*Sqrt[3]) + 
       (2617448928712103543*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (6590022517890*Sqrt[3]) - (2150368*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/15 - (452328900585068338*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(203395756725*Sqrt[3]) - 
       (71181261401452736*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5811307335*Sqrt[3]) - (226164450292534169*CF^2*NC*Pi*Log[3]^2)/
        (4881498161400*Sqrt[3]) - (4448828837590796*CF*NC*NH*Pi*Log[3]^2)/
        (17433922005*Sqrt[3]) - 
       (CF*NC*(-57*CA*(-17280481085942481581 + 5593266498619800*lm) + 
          5*(3040*CF*(-129567013672454054 + 68644634301243*lm) + 
            21*(38*(-10099883976952001 + 14527964931480*lm)*NM + 
              128035908*(5694071 + 4311780*lm)*NL + (122619335456447 + 
                552062667396240*lm)*NH)))*Log[x]^2)/824958634500 + 
       (CF*NC*(-27933509137105*CA + 55501809554572*CF + 3744003468240*NM + 
          3984084720*NL)*Log[x]^3)/85050 + (58060070715445909022597*CF^2*NC*
         PolyGamma[2, 1])/338915443777200 + 
       (707961322627*CF*NM*NC*PolyGamma[2, 1])/8100 - 
       (2779938531179723317*CF*NC*NH*PolyGamma[2, 1])/84728860944300 + 
       CA*CF*NC*(8298156144730475759368482042669874361263/
          41566730412804380827012569600000 + (1722919*lm^2)/180 - 
         (246611873194428247*Pi^2)/2476656000 + (226164450292534169*Pi^3)/
          (7531454306160*Sqrt[3]) + (1239953*Pi^4)/2025 + 
         lm*(1646166366097/48988800 - (65219*Pi^2)/1620) - 
         (505413360911552981287*Im[PolyLog[2, (-1)^(1/3)]])/
          (1153253940630750*Sqrt[3]) + (1075184*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          15 + (226164450292534169*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (203395756725*Sqrt[3]) + (226164450292534169*Pi*Log[3]^2)/
          (9762996322800*Sqrt[3]) - (58060070715445909022597*PolyGamma[2, 1])/
          677830887554400 - (16677882218617846401923*Zeta[3])/
          2372408106440400) + (3354846790924111284547*CF^2*NC*Zeta[3])/
        237240810644040 + (620945638147*CF*NM*NC*Zeta[3])/4050 - 
       (11196614*CF*NC*NL*Zeta[3])/135 + (43167873798601452563*CF*NC*NH*
         Zeta[3])/42364430472150 + CF*Log[x]*
        ((-404188853233795165864343*NM*NC)/2533230872172000 - 
         (895642253*lm*NM*NC)/24300 - 6292*lm^2*NM*NC - 
         (401534270807*NC*NL)/2646000 - (895642253*lm*NC*NL)/24300 - 
         6292*lm^2*NC*NL - (3511305733255075928481344358539*NC*NH)/
          1458002556016810519716000 - (895642253*lm*NC*NH)/24300 - 
         6292*lm^2*NC*NH + (495493523*NM*NC*Pi^2)/45 - 
         (1864126*NC*NL*Pi^2)/135 + (71181261401452736*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(17433922005*Sqrt[3]) + 
         CF*NC*(723084595733120624678798538352361/565430354133943137840000 - 
           (780970553*lm)/1350 - 113256*lm^2 + (5581477232957*Pi^2)/34020 + 
           (452328900585068338*Im[PolyLog[2, (-1)^(1/3)]])/
            (610187270175*Sqrt[3]) - 75504*Zeta[3]) + 
         CA*NC*(-361440750527622567008324882666113/565430354133943137840000 + 
           (11992603183*lm)/48600 + 34606*lm^2 - (27905314392271*Pi^2)/
            340200 - (226164450292534169*Im[PolyLog[2, (-1)^(1/3)]])/
            (610187270175*Sqrt[3]) + 37752*Zeta[3])), 
      (151811434322095326815061181521498766886789*CF^2*NC)/
        187050286857619713721556563200000 + (8228513669*CF^2*lm*NC)/105840 + 
       49588*CF^2*lm^2*NC + (149937314249699750255735261807*CF*NM*NC)/
        49266274002001056000 + (12164809109*CF*lm*NM*NC)/1905120 + 
       (24794*CF*lm^2*NM*NC)/9 - (1366120599251291*CF*NC*NL)/12002256000 + 
       (12164809109*CF*lm*NC*NL)/1905120 + (24794*CF*lm^2*NC*NL)/9 - 
       (4321913515427801544339529821535304076769*CF*NC*NH)/
        916412798254581154582968904992000 + (12164809109*CF*lm*NC*NH)/
        1905120 + (24794*CF*lm^2*NC*NH)/9 - 
       (70257767143182187969*CF^2*NC*Pi^2)/245188944000 - 
       242*CF^2*lm*NC*Pi^2 - (2197611125773*CF*NM*NC*Pi^2)/1620 - 
       (121*CF*lm*NM*NC*Pi^2)/9 + (86481263*CF*NC*NL*Pi^2)/11340 - 
       (121*CF*lm*NC*NL*Pi^2)/9 - (121*CF*lm*NC*NH*Pi^2)/9 + 
       (13877150872245013447*CF^2*NC*Pi^3)/(135566177510880*Sqrt[3]) + 
       (537111683695798295*CF*NC*NH*Pi^3)/(847288609443*Sqrt[3]) + 
       (36122449*CF^2*NC*Pi^4)/16200 - (233068916894441963480503*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(166068567450828000*Sqrt[3]) - 
       (47996490795534588253*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29655101330505*Sqrt[3]) + (3653254*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + (13877150872245013447*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3661123621050*Sqrt[3]) + 
       (245536769689507792*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) + (13877150872245013447*CF^2*NC*Pi*Log[3]^2)/
        (175733933810400*Sqrt[3]) + (15346048105594237*CF*NC*NH*Pi*Log[3]^2)/
        (31381059609*Sqrt[3]) + CF*((-596294150499618857053*CF*NC)/
          173675502000 + CA*(119312149372084414013/69470200800 - 
           (2171224*lm)/3)*NC + 2368608*CF*lm*NC - (74791692078885107*NM*NC)/
          4594590 + (394768*lm*NM*NC)/3 + (7728787*NC*NL)/45 + 
         (394768*lm*NC*NL)/3 + (8038752383663*NC*NH)/261891630 + 
         (394768*lm*NC*NH)/3)*Log[x]^2 - 
       (4*CF*NC*(-5496739474112*CA + 10898282638843*CF + 
          9450*(5169172909*NM + 98692*NL))*Log[x]^3)/42525 - 
       (26422654013234622359867*CF^2*NC*PolyGamma[2, 1])/84728860944300 - 
       (284593060687*CF*NM*NC*PolyGamma[2, 1])/216 + 
       (2628277892441878897*CF*NC*NH*PolyGamma[2, 1])/20334926626632 - 
       (63344678718184588630189*CF^2*NC*Zeta[3])/593102026610100 - 
       (36577649839*CF*NM*NC*Zeta[3])/108 + 152724*CF*NC*NL*Zeta[3] - 
       (16215541284839339663*CF*NC*NH*Zeta[3])/10167463313316 + 
       CA*CF*NC*(-3457186329440676221015710932961958977/
          8520876770117516113409100000 - (136367*lm^2)/9 + 
         (6386920708389149231*Pi^2)/44579808000 - (13877150872245013447*Pi^3)/
          (271132355021760*Sqrt[3]) - (36470929*Pi^4)/32400 + 
         lm*(-207290415079/3810240 + (1331*Pi^2)/18) + 
         (233068916894441963480503*Im[PolyLog[2, (-1)^(1/3)]])/
          (332137134901656000*Sqrt[3]) - (1826627*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/15 - (13877150872245013447*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(7322247242100*Sqrt[3]) - 
         (13877150872245013447*Pi*Log[3]^2)/(351467867620800*Sqrt[3]) + 
         (26422654013234622359867*PolyGamma[2, 1])/169457721888600 + 
         (63237663672896368483741*Zeta[3])/1186204053220200) + 
       CF*Log[x]*((-18554769098604754933651*NM*NC)/2345584140900 + 
         (61139782*lm*NM*NC)/945 + (31460*lm^2*NM*NC)/3 + 
         (1336374611393*NC*NL)/4762800 + (61139782*lm*NC*NL)/945 + 
         (31460*lm^2*NC*NL)/3 + (6054910451613081847712262376319*NC*NH)/
          1312202300415129467744400 + (61139782*lm*NC*NH)/945 + 
         (31460*lm^2*NC*NH)/3 - (10338422114*NM*NC*Pi^2)/9 + 
         (228844*NC*NL*Pi^2)/9 - (245536769689507792*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CA*NC*(6360467814080101470975016253207431/
            10177746374410976481120000 - (405638101*lm)/945 - 
           (173030*lm^2)/3 + (87843468661877*Pi^2)/680400 + 
           (13877150872245013447*Im[PolyLog[2, (-1)^(1/3)]])/
            (21966741726300*Sqrt[3]) - 62920*Zeta[3]) + 
         CF*NC*(-909125587541494230294879920047759/726981883886498320080000 + 
           (107414714*lm)/105 + 188760*lm^2 - (87853099279601*Pi^2)/340200 - 
           (13877150872245013447*Im[PolyLog[2, (-1)^(1/3)]])/
            (10983370863150*Sqrt[3]) + 125840*Zeta[3])), 
      (-5897720391402631677240309493791786555566886533*CF^2*NC)/
        1282977917556413616416156466988800000 - (278190182531*CF^2*lm*NC)/
        3841992 - (243088*CF^2*lm^2*NC)/5 - (33693653813681024949501275520677*
         CF*NM*NC)/113722192964330610660000 - (2091407526127*CF*lm*NM*NC)/
        345779280 - (121544*CF*lm^2*NM*NC)/45 + 
       (425673528320344001*CF*NC*NL)/3630682440000 - 
       (2091407526127*CF*lm*NC*NL)/345779280 - (121544*CF*lm^2*NC*NL)/45 + 
       (106670211557403614556671936301850149217*CF*NC*NH)/
        22461097996435812612327669240000 - (2091407526127*CF*lm*NC*NH)/
        345779280 - (121544*CF*lm^2*NC*NH)/45 + 
       (9080551390746272997541*CF^2*NC*Pi^2)/4045617576000 + 
       (2812*CF^2*lm*NC*Pi^2)/15 - (127547032765913*CF*NM*NC*Pi^2)/935550 + 
       (1406*CF*lm*NM*NC*Pi^2)/135 - (6916418851*CF*NC*NL*Pi^2)/935550 + 
       (1406*CF*lm*NC*NL*Pi^2)/135 + (1406*CF*lm*NC*NH*Pi^2)/135 - 
       (82144535354989458001*CF^2*NC*Pi^3)/(745613976309840*Sqrt[3]) - 
       (57573140811443593*CF*NC*NH*Pi^3)/(94143178827*Sqrt[3]) - 
       (51113339*CF^2*NC*Pi^4)/24300 + (2211167226276148552617047*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1435306904396442000*Sqrt[3]) + 
       (1222211908184758738*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1412147682405*Sqrt[3]) - (10804612*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - (11734933622141351143*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2876597130825*Sqrt[3]) - 
       (131595750426156784*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5811307335*Sqrt[3]) - (11734933622141351143*CF^2*NC*Pi*Log[3]^2)/
        (138076662279600*Sqrt[3]) - (8224734401634799*CF*NC*NH*Pi*Log[3]^2)/
        (17433922005*Sqrt[3]) - 
       (CF*NC*(CA*(1466320245819172446999997 - 78923916636393628800*lm) + 
          2*(CF*(-1466251434528977804347639 + 129148227223189574400*lm) + 
            166320*(13*(41207948301016279 + 3318395267880*lm)*NM + 
              51*(1882881*(591033 + 449240*lm)*NL + (202141959247 + 
                  845865460440*lm)*NH))))*Log[x]^2)/108894539754000 + 
       (2*CF*NC*(-2602374175727291*CA + 121*(42963674883733*CF - 
            249480*(4697291*NM - 2042*NL)))*Log[x]^3)/1403325 + 
       (2777427381968092164091639*CF^2*NC*PolyGamma[2, 1])/1525119496997400 + 
       (628961112139*CF*NM*NC*PolyGamma[2, 1])/900 - 
       (47522844096214028059*CF*NC*NH*PolyGamma[2, 1])/762559748498700 - 
       (3915210541170703699365487*CF^2*NC*Zeta[3])/58717100634399900 + 
       (674881833659*CF*NM*NC*Zeta[3])/450 - (6896552*CF*NC*NL*Zeta[3])/
        45 + (700328335652362187621*CF*NC*NH*Zeta[3])/381279874249350 + 
       CA*CF*NC*(1621829501606685950045144196365767002551227687/
          705637854656027489028886056843840000 + (668492*lm^2)/45 - 
         (1816106250626598357839*Pi^2)/1618247030400 + 
         (82144535354989458001*Pi^3)/(1491227952619680*Sqrt[3]) + 
         (51518267*Pi^4)/48600 + lm*(3280061173231/62868960 - 
           (7733*Pi^2)/135) - (2211167226276148552617047*
           Im[PolyLog[2, (-1)^(1/3)]])/(2870613808792884000*Sqrt[3]) + 
         (5402306*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (11734933622141351143*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (5753194261650*Sqrt[3]) + (11734933622141351143*Pi*Log[3]^2)/
          (276153324559200*Sqrt[3]) - (2777427381968092164091639*
           PolyGamma[2, 1])/3050238993994800 + (3923769459931907346677347*
           Zeta[3])/117434201268799800) + CF*Log[x]*
        ((-508494639245833706557199*NM*NC)/209362716312750 - 
         (9820698922*lm*NM*NC)/155925 - (32032*lm^2*NM*NC)/3 - 
         (4046668460489*NC*NL)/14553000 - (9820698922*lm*NC*NL)/155925 - 
         (32032*lm^2*NC*NL)/3 - (8677512325647626442278478667*NC*NH)/
          1949201278097340267000 - (9820698922*lm*NC*NH)/155925 - 
         (32032*lm^2*NC*NH)/3 - (2272846928*NM*NC*Pi^2)/45 - 
         (1148488*NC*NL*Pi^2)/45 + (131595750426156784*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(17433922005*Sqrt[3]) + 
         CF*NC*(28809354658890848484221457986112651593/
            2020791542639299380326376000 - (17144103044*lm)/17325 - 
           192192*lm^2 + (10407868379876147*Pi^2)/5613300 + 
           (11734933622141351143*Im[PolyLog[2, (-1)^(1/3)]])/
            (8629791392475*Sqrt[3]) - 128128*Zeta[3]) + 
         CA*NC*(-2939600533083178795459224633034258537/
            412406437273326404148240000 + (5969807861*lm)/14175 + 
           (176176*lm^2)/3 - (10407743623098617*Pi^2)/11226600 - 
           (11734933622141351143*Im[PolyLog[2, (-1)^(1/3)]])/
            (17259582784950*Sqrt[3]) + 64064*Zeta[3])), 
      (64048912624347970328101873923308098583080004837*CF^2*NC)/
        8467654255872329868346632682126080000 + (1514021501501*CF^2*lm*NC)/
        12806640 + 75400*CF^2*lm^2*NC + (15398727942715783981492447762902929*
         CF*NM*NC)/473084322731615340345600 + (2238236993501*CF*lm*NM*NC)/
        230519520 + (37700*CF*lm^2*NM*NC)/9 - (310023192715165669*CF*NC*NL)/
        1452272976000 + (2238236993501*CF*lm*NC*NL)/230519520 + 
       (37700*CF*lm^2*NC*NL)/9 - 
       (40273855484547877595924954727178436493266113*CF*NC*NH)/
        4778569078441495246204706857301856000 + (2238236993501*CF*lm*NC*NH)/
        230519520 + (37700*CF*lm^2*NC*NH)/9 - 
       (86154519366979479271*CF^2*NC*Pi^2)/33345696384 - 
       338*CF^2*lm*NC*Pi^2 - (5396579702859479*CF*NM*NC*Pi^2)/374220 - 
       (169*CF*lm*NM*NC*Pi^2)/9 + (1573827229*CF*NC*NL*Pi^2)/124740 - 
       (169*CF*lm*NC*NL*Pi^2)/9 - (169*CF*lm*NC*NH*Pi^2)/9 + 
       (163483315577241613225*CF^2*NC*Pi^3)/(894736771571808*Sqrt[3]) + 
       (2885911126506394735*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) + 
       (12134759*CF^2*NC*Pi^4)/3240 - (29067134295242339371880099*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12056577996930112800*Sqrt[3]) - 
       (270954882850337851643*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (88965303991515*Sqrt[3]) + (1196234*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + (32696663115448322645*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4832683179786*Sqrt[3]) + 
       (1319273657831494736*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31381059609*Sqrt[3]) + (32696663115448322645*CF^2*NC*Pi*Log[3]^2)/
        (231968792629728*Sqrt[3]) + (82454603614468421*CF*NC*NH*Pi*Log[3]^2)/
        (94143178827*Sqrt[3]) + CF*((-32144399003935430288137*CF*NC)/
          1037090854800 + CA*(1125155123651800305438767/72596359836000 - 
           1315028*lm)*NC + 4303728*CF*lm*NC - (15106765622759183323*NM*NC)/
          87297210 + 239096*lm*NM*NC + (4667377*NC*NL)/15 + 
         239096*lm*NC*NL + (5693370888053*NC*NH)/95611230 + 
         239096*lm*NC*NH)*Log[x]^2 - 
       (2*CF*NC*(-1100199175081193*CA + 50*(43925555370617*CF + 
            12474*(18308867619*NM + 59774*NL)))*Log[x]^3)/467775 - 
       (1307396969110643196845257*CF^2*NC*PolyGamma[2, 1])/457535849099220 - 
       (14356214616749*CF*NM*NC*PolyGamma[2, 1])/1080 + 
       (210714258523115242843*CF*NC*NH*PolyGamma[2, 1])/915071698198440 - 
       (35627473626782930921267431*CF^2*NC*Zeta[3])/35230260380639940 - 
       (1174796054669*CF*NM*NC*Zeta[3])/540 + (822068*CF*NC*NL*Zeta[3])/3 - 
       (1282727489775317427557*CF*NC*NH*Zeta[3])/457535849099220 + 
       CA*CF*NC*(-80058359202081775455754890186437461041642572587/
          21169135639680824670866581705315200000 - (207350*lm^2)/9 + 
         (48729718301418630787*Pi^2)/37721376000 - 
         (163483315577241613225*Pi^3)/(1789473543143616*Sqrt[3]) - 
         (12232103*Pi^4)/6480 + lm*(-3467208737501/41912640 + 
           (1859*Pi^2)/18) + (29067134295242339371880099*
           Im[PolyLog[2, (-1)^(1/3)]])/(24113155993860225600*Sqrt[3]) - 
         (598117*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (32696663115448322645*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9665366359572*Sqrt[3]) - (32696663115448322645*Pi*Log[3]^2)/
          (463937585259456*Sqrt[3]) + (1307396969110643196845257*
           PolyGamma[2, 1])/915071698198440 + (35616308828974472355058879*
           Zeta[3])/70460520761279880) + CF*Log[x]*
        ((-426484688345820179324047087*NM*NC)/5080535249189400 + 
         (1119467336*lm*NM*NC)/10395 + (52052*lm^2*NM*NC)/3 + 
         (1046181779645*NC*NL)/2095632 + (1119467336*lm*NC*NL)/10395 + 
         (52052*lm^2*NC*NL)/3 + (2458288379983157370812690230609993*NC*NH)/
          297495007251258637901480400 + (1119467336*lm*NC*NH)/10395 + 
         (52052*lm^2*NC*NH)/3 - (329560187998*NM*NC*Pi^2)/27 + 
         (410696*NC*NL*Pi^2)/9 - (1319273657831494736*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CA*NC*(1681890448369027277880024001009504613/
            314928552099631072258656000 - (674508328*lm)/945 - 
           (286286*lm^2)/3 + (1759900099700489*Pi^2)/1496880 + 
           (32696663115448322645*Im[PolyLog[2, (-1)^(1/3)]])/
            (28996099078716*Sqrt[3]) - 104104*Zeta[3]) + 
         CF*NC*(-129519479361859625806102095110234581639/
            12124749255835796281958256000 + (1968394402*lm)/1155 + 
           312312*lm^2 - (1759937667233261*Pi^2)/748440 - 
           (32696663115448322645*Im[PolyLog[2, (-1)^(1/3)]])/
            (14498049539358*Sqrt[3]) + 208208*Zeta[3])), 
      (-82143726626188755272036210987655572965386443027*CF^2*NC)/
        1568084121457838864508635681875200000 - (41681341557551*CF^2*lm*NC)/
        384199200 - (363987*CF^2*lm^2*NC)/5 + 
       (9347433577916577952592820973890407*CF*NM*NC)/
        6451149855431118277440000 - (62657868689111*CF*lm*NM*NC)/
        6915585600 - (40443*CF*lm^2*NM*NC)/10 + 
       (4672211706718586071*CF*NC*NL)/21784094640000 - 
       (62657868689111*CF*lm*NC*NL)/6915585600 - (40443*CF*lm^2*NC*NL)/10 + 
       (2088669700570657606519694019504497165318203597*CF*NC*NH)/
        250874876618178500425747110008347440000 - 
       (62657868689111*CF*lm*NC*NH)/6915585600 - (40443*CF*lm^2*NC*NH)/10 + 
       (382908635534638496989193*CF^2*NC*Pi^2)/15283444176000 + 
       (3887*CF^2*lm*NC*Pi^2)/15 - (11529092199101447*CF*NM*NC*Pi^2)/
        3742200 + (3887*CF*lm*NM*NC*Pi^2)/270 - (5617154218*CF*NC*NL*Pi^2)/
        467775 + (3887*CF*lm*NC*NL*Pi^2)/270 + (3887*CF*lm*NC*NH*Pi^2)/
        270 - (95550260154917220821*CF^2*NC*Pi^3)/(497075984206560*Sqrt[3]) - 
       (8210643739142481658*CF*NC*NH*Pi^3)/(7625597484987*Sqrt[3]) - 
       (6264011*CF^2*NC*Pi^4)/1800 + (828326366494162058845859*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(318957089865876000*Sqrt[3]) + 
       (92291965975568949439*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (53379182394909*Sqrt[3]) - (1929382*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (13650037164988174403*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1917731420550*Sqrt[3]) - 
       (18767185689468529504*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (470715894135*Sqrt[3]) - (13650037164988174403*CF^2*NC*Pi*Log[3]^2)/
        (92051108186400*Sqrt[3]) - (1172949105591783094*CF*NC*NH*Pi*
         Log[3]^2)/(1412147682405*Sqrt[3]) - 
       (CF*NC*(-23*CA*(-10912672689970587900535453 + 93646753636331095200*
             lm) + 46*CF*(-10912591078379094588115381 + 153240142313996337600*
             lm) + 9240*(207*(32274378636737656547 + 204746061560040*lm)*
             NM + 57424104738*(968077 + 738060*lm)*NL + 
            4*(2693374196835991 + 10595608685732070*lm)*NH))*Log[x]^2)/
        1669716276228000 + (CF*NC*(-12959654429286199*CA + 
          8*(3239257324924448*CF - 3465*(91200739374*NM - 1759043*NL)))*
         Log[x]^3)/311850 + (59134894808684013075051427*CF^2*NC*
         PolyGamma[2, 1])/3050238993994800 + 
       (42771353459137*CF*NM*NC*PolyGamma[2, 1])/8100 - 
       (767785512856847541943*CF*NC*NH*PolyGamma[2, 1])/6863037736488300 - 
       (326871123687109523033320111*CF^2*NC*Zeta[3])/117434201268799800 + 
       (59194811013217*CF*NM*NC*Zeta[3])/4050 - (12123592*CF*NC*NL*Zeta[3])/
        45 + (10844839213648126591577*CF*NC*NH*Zeta[3])/3431518868244150 + 
       CA*CF*NC*(16428677188036272399013290256685698666721928763/
          627233648583135545803454272750080000 + (444873*lm^2)/20 - 
         (1732617686166028051757*Pi^2)/138311712000 + 
         (95550260154917220821*Pi^3)/(994151968413120*Sqrt[3]) + 
         (18916417*Pi^4)/10800 + lm*(98254399579031/1257379200 - 
           (42757*Pi^2)/540) - (828326366494162058845859*
           Im[PolyLog[2, (-1)^(1/3)]])/(637914179731752000*Sqrt[3]) + 
         (964691*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (13650037164988174403*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3835462841100*Sqrt[3]) + (13650037164988174403*Pi*Log[3]^2)/
          (184102216372800*Sqrt[3]) - (59134894808684013075051427*
           PolyGamma[2, 1])/6100477987989600 + (326900523157156684353520051*
           Zeta[3])/234868402537599600) + CF*Log[x]*
        ((-118728150771329755640614081*NM*NC)/3628953749421000 - 
         (64213059313*lm*NM*NC)/623700 - (52052*lm^2*NM*NC)/3 - 
         (762737295433387*NC*NL)/1571724000 - (64213059313*lm*NC*NL)/
          623700 - (52052*lm^2*NC*NL)/3 - 
         (15300225882844012687258533134466977*NC*NH)/
          1952310985086384811228465125 - (64213059313*lm*NC*NH)/623700 - 
         (52052*lm^2*NC*NH)/3 - (91199344123*NM*NC*Pi^2)/45 - 
         (224367*NC*NL*Pi^2)/5 + (18767185689468529504*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(528109683676455654347650456577694674497/
            3367985904398832300543960000 - (56096851213*lm)/34650 - 
           312312*lm^2 + (77755983856998407*Pi^2)/3742200 + 
           (13650037164988174403*Im[PolyLog[2, (-1)^(1/3)]])/
            (5753194261650*Sqrt[3]) - 208208*Zeta[3]) + 
         CA*NC*(-1056212291186651726298929823938672600921/
            13471943617595329202175840000 + (77986018513*lm)/113400 + 
           (286286*lm^2)/3 - (77755839124992527*Pi^2)/7484400 - 
           (13650037164988174403*Im[PolyLog[2, (-1)^(1/3)]])/
            (11506388523300*Sqrt[3]) + 104104*Zeta[3])), 
      (87509414769580011642830772361865231425807718329*CF^2*NC)/
        1269619130409845378011156920268800000 + (1637076187541*CF^2*lm*NC)/
        9408960 + (221949*CF^2*lm^2*NC)/2 + 
       (5921468634359325856664093749360463689*CF*NM*NC)/
        17031035618338152252441600 + (2420192161181*CF*lm*NM*NC)/169361280 + 
       (24661*CF*lm^2*NM*NC)/4 - (13651344043737669191*CF*NC*NL)/
        35943756156000 + (2420192161181*CF*lm*NC*NL)/169361280 + 
       (24661*CF*lm^2*NC*NL)/4 - 
       (2170286438210589125267664927449151307245373825303*CF*NC*NH)/
        150524925970907100255448266005008464000000 + 
       (2420192161181*CF*lm*NC*NH)/169361280 + (24661*CF*lm^2*NC*NH)/4 - 
       (84838828886497024051783*CF^2*NC*Pi^2)/3742884288000 - 
       (8281*CF^2*lm*NC*Pi^2)/18 - (76242462341866873*CF*NM*NC*Pi^2)/
        498960 - (8281*CF*lm*NM*NC*Pi^2)/324 + (6438119597*CF*NC*NL*Pi^2)/
        320760 - (8281*CF*lm*NC*NL*Pi^2)/324 - (8281*CF*lm*NC*NH*Pi^2)/
        324 + (50178418821424366331971*CF^2*NC*Pi^3)/(161052618882925440*
         Sqrt[3]) + (356182666726142304265*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) + (14483833*CF^2*NC*Pi^4)/2400 - 
       (1235772717889097776803507737*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (310026291349631472000*Sqrt[3]) - (38417130688438858700977*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7046052076127988*Sqrt[3]) + 
       (56584619*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 + 
       (7168345545917766618853*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (621344980258200*Sqrt[3]) + (20353295241493845958*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (7168345545917766618853*CF^2*NC*Pi*Log[3]^2)/(29824559052393600*
         Sqrt[3]) + (10176647620746922979*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + 
       (CF*NC*(-115*CA*(-225661878950655959296297 + 3782428507652034240*lm) + 
          6*(575*CF*(-15043858243449350784947 + 412628564471131008*lm) + 
            88*(115*(-5762554201372315985501 + 1302489155527560*lm)*NM + 
              2900207310*(67053829 + 51646740*lm)*NL + (39447736271494381 + 
                149786252885669400*lm)*NH)))*Log[x]^2)/190824717283200 - 
       (CF*NC*(-16753335068112289*CA + 33493487461988651*CF + 
          9900*(20978246591056*NM + 11190127*NL))*Log[x]^3)/400950 - 
       (530261345048940197473756999*CF^2*NC*PolyGamma[2, 1])/
        20589113209464900 - (435560059378661*CF*NM*NC*PolyGamma[2, 1])/
        3240 + (1615858183872207450889*CF*NC*NH*PolyGamma[2, 1])/
        4117822641892980 - (8810415454375808855541867277*CF^2*NC*Zeta[3])/
        905920981216455600 - (16000208495741*CF*NM*NC*Zeta[3])/1620 + 
       (12688988*CF*NC*NL*Zeta[3])/27 - (9724377234958897992131*CF*NC*NH*
         Zeta[3])/2058911320946490 + CA*CF*NC*
        (-30015531049352843965878826543862084538760171913521/
          870958723461153929315653647304396800000 - (271271*lm^2)/8 + 
         (45682409381217250406713*Pi^2)/4030798464000 - 
         (50178418821424366331971*Pi^3)/(322105237765850880*Sqrt[3]) - 
         (393713411*Pi^4)/129600 + lm*(-3749116237661/30792960 + 
           (91091*Pi^2)/648) + (1235772717889097776803507737*
           Im[PolyLog[2, (-1)^(1/3)]])/(620052582699262944000*Sqrt[3]) - 
         (56584619*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 - 
         (7168345545917766618853*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1242689960516400*Sqrt[3]) - (7168345545917766618853*Pi*Log[3]^2)/
          (59649118104787200*Sqrt[3]) + (530261345048940197473756999*
           PolyGamma[2, 1])/41178226418929800 + (1761986280193590872218125809*
           Zeta[3])/362368392486582240) + CF*Log[x]*
        ((-53897916602858746418911408787*NM*NC)/60966422990272800 + 
         (18413353777*lm*NM*NC)/106920 + (82810*lm^2*NM*NC)/3 + 
         (17634347079171103*NC*NL)/20746756800 + (18413353777*lm*NC*NL)/
          106920 + (82810*lm^2*NC*NL)/3 + 
         (13272078792393444406358679596523997213*NC*NH)/
          937109272841464709389663260000 + (18413353777*lm*NC*NH)/106920 + 
         (82810*lm^2*NC*NH)/3 - (20978253941555*NM*NC*Pi^2)/162 + 
         (12680707*NC*NL*Pi^2)/162 - (20353295241493845958*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(847555813077430299893361455583579404057/
            19486204161164672596004340000 - (22169615377*lm)/19440 - 
           (455455*lm^2)/3 + (134020445403325867*Pi^2)/12830400 + 
           (7168345545917766618853*Im[PolyLog[2, (-1)^(1/3)]])/
            (3728069881549200*Sqrt[3]) - 165620*Zeta[3]) + 
         CF*NC*(-6780593535673610569777235461798071038479/
            77944816644658690384017360000 + (16199842477*lm)/5940 + 
           496860*lm^2 - (134020992392877283*Pi^2)/6415200 - 
           (7168345545917766618853*Im[PolyLog[2, (-1)^(1/3)]])/
            (1864034940774600*Sqrt[3]) + 331240*Zeta[3])), 
      (-121964152200530816562051367013982455033607476798946173003*CF^2*NC)/
        206640618372861267230679379571675619379200000 - 
       (69632616936517*CF^2*lm*NC)/441698400 - (528696*CF^2*lm^2*NC)/5 + 
       (149402811724919722005608843625788441210573*CF*NM*NC)/
        2590207629604003730693211840000 - (104661243529477*CF*lm*NM*NC)/
        7950571200 - (29372*CF*lm^2*NM*NC)/5 + 
       (2521806575186789470081*CF*NC*NL)/6749438655960000 - 
       (104661243529477*CF*lm*NC*NL)/7950571200 - (29372*CF*lm^2*NC*NL)/5 + 
       (3162835243164833369603014677198777409715985886109*CF*NC*NH)/
        225787388956360650383172399007512696000000 - 
       (104661243529477*CF*lm*NC*NH)/7950571200 - (29372*CF*lm^2*NC*NH)/5 + 
       (3142035613306358912401399*CF^2*NC*Pi^2)/11353415673600 + 
       (5243*CF^2*lm*NC*Pi^2)/15 - (6932462717459885107*CF*NM*NC*Pi^2)/
        145945800 + (5243*CF*lm*NM*NC*Pi^2)/270 - 
       (65342366957*CF*NC*NL*Pi^2)/3474900 + (5243*CF*lm*NC*NL*Pi^2)/270 + 
       (5243*CF*lm*NC*NH*Pi^2)/270 - (100964175994530585277331*CF^2*NC*Pi^3)/
        (314052606821704608*Sqrt[3]) - (499233998483282412287*CF*NC*NH*Pi^3)/
        (274521509459532*Sqrt[3]) - (3320569*CF^2*NC*Pi^4)/600 + 
       (33192194018833839283290811291*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (7859166485713157815200*Sqrt[3]) + (34156373184472701048575*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10569078114191982*Sqrt[3]) - 
       598766*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (14423453713504369325333*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1211622711503490*Sqrt[3]) - 
       (285276570561875664164*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4236443047215*Sqrt[3]) - 
       (14423453713504369325333*CF^2*NC*Pi*Log[3]^2)/(58157890152167520*
         Sqrt[3]) - (71319142640468916041*CF*NC*NH*Pi*Log[3]^2)/
        (50837316566580*Sqrt[3]) - 
       (CF*NC*(CA*(1029798929664635713929961973 - 1362286613234320693920*
             lm) + 88*(CF*(-23404494156441966090245161 + 50663551731854901840*
               lm) + 39*((103002736238366999856901 + 72170301612328920*lm)*
               NM + 33*(17577014*(162794117 + 124422660*lm)*NL + 
                (586110130806709 + 2186978836737240*lm)*NH))))*Log[x]^2)/
        620180331170400 + (CF*NC*(-801001706413288921*CA + 
          520*(3080672877125402*CF - 467360440976352*NM + 889622019*NL))*
         Log[x]^3)/1737450 + (50960060925612342269493041647*CF^2*NC*
         PolyGamma[2, 1])/247069358513578800 + 
       (293831473372079*CF*NM*NC*PolyGamma[2, 1])/8100 - 
       (5918019259356648530287*CF*NC*NH*PolyGamma[2, 1])/30883669814197350 - 
       (856867159844054051963717329063*CF^2*NC*Zeta[3])/
        17665459133720884200 + (577092841709399*CF*NM*NC*Zeta[3])/4050 - 
       (6809576*CF*NC*NL*Zeta[3])/15 + (80705469184111716393773*CF*NC*NH*
         Zeta[3])/15441834907098675 + CA*CF*NC*
        (60982038207698985626125579745299180543263329166041267029/
          206640618372861267230679379571675619379200000 + (161546*lm^2)/5 - 
         (24244100791644043415071*Pi^2)/175207032000 + 
         (100964175994530585277331*Pi^3)/(628105213643409216*Sqrt[3]) + 
         (30052897*Pi^4)/10800 + lm*(164103761384197/1445558400 - 
           (57673*Pi^2)/540) - (33192194018833839283290811291*
           Im[PolyLog[2, (-1)^(1/3)]])/(15718332971426315630400*Sqrt[3]) + 
         299383*Im[PolyLog[2, (-1)^(1/3)]]^2 + (14423453713504369325333*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2423245423006980*
           Sqrt[3]) + (14423453713504369325333*Pi*Log[3]^2)/
          (116315780304335040*Sqrt[3]) - (50960060925612342269493041647*
           PolyGamma[2, 1])/494138717027157600 + 
         (856874473266492448135751783581*Zeta[3])/35330918267441768400) + 
       CF*Log[x]*((-99117367422735321389141708786771*NM*NC)/
          241884283213907334000 - (62584458181*lm*NM*NC)/386100 - 
         (81536*lm^2*NM*NC)/3 - (182637107338645969*NC*NL)/224756532000 - 
         (62584458181*lm*NC*NL)/386100 - (81536*lm^2*NC*NL)/3 - 
         (18603072279031792719968694236011202549*NC*NH)/
          1405663909262197064084494890000 - (62584458181*lm*NC*NH)/386100 - 
         (81536*lm^2*NC*NH)/3 - (14162412830893*NM*NC*Pi^2)/405 - 
         (10209121*NC*NL*Pi^2)/135 + (285276570561875664164*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) + 
         CF*NC*(10966314118513544497057685546322002254128280909/
            6432318048783813765250648616640000 - (54714195781*lm)/21450 - 
           489216*lm^2 + (400499310693523819*Pi^2)/1737450 + 
           (14423453713504369325333*Im[PolyLog[2, (-1)^(1/3)]])/
            (3634868134510470*Sqrt[3]) - 326144*Zeta[3]) + 
         CA*NC*(-5483151619675815528979686570772897033418672723/
            6432318048783813765250648616640000 + (75940054981*lm)/70200 + 
           (448448*lm^2)/3 - (1601996793600204253*Pi^2)/13899600 - 
           (14423453713504369325333*Im[PolyLog[2, (-1)^(1/3)]])/
            (7269736269020940*Sqrt[3]) + 163072*Zeta[3])), 
      (202362033889353104100308401171245241861276632259373503*CF^2*NC)/
        330624989396578027569087007314680991006720 + 
       (8799248701753*CF^2*lm*NC)/35335872 + (317695*CF^2*lm^2*NC)/2 + 
       (425950898786627937589431433624694861864999*CF*NM*NC)/
        115120339093511276919698304000 + (13009009897393*CF*lm*NM*NC)/
        636045696 + (317695*CF*lm^2*NM*NC)/36 - 
       (87247215703511760451*CF*NC*NL)/134988773119200 + 
       (13009009897393*CF*lm*NC*NL)/636045696 + (317695*CF*lm^2*NC*NL)/36 - 
       (32183840673303269185317792846861957453941293200611*CF*NC*NH)/
        1354724333738163902299034394045076176000000 + 
       (13009009897393*CF*lm*NC*NH)/636045696 + (317695*CF*lm^2*NC*NH)/36 - 
       (49708914489882125487536957*CF^2*NC*Pi^2)/258857877358080 - 
       (1225*CF^2*lm*NC*Pi^2)/2 - (10453245728012341109*CF*NM*NC*Pi^2)/
        6486480 - (1225*CF*lm*NM*NC*Pi^2)/36 + (2861346145*CF*NC*NL*Pi^2)/
        92664 - (1225*CF*lm*NC*NL*Pi^2)/36 - (1225*CF*lm*NC*NH*Pi^2)/36 + 
       (641882841941323608522295*CF^2*NC*Pi^3)/(1256210427286818432*
         Sqrt[3]) + (5291888177121944522705*CF*NC*NH*Pi^3)/
        (1647129056757192*Sqrt[3]) + (24330173*CF^2*NC*Pi^4)/2592 - 
       (40082600452944919498577659933*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6287333188570526252160*Sqrt[3]) - (2966089217160842711867149*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(317072343425759460*Sqrt[3]) + 
       (5759075*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
       (18339509769752103100637*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(969298169202792*Sqrt[3]) + 
       (302393610121253972726*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) + 
       (18339509769752103100637*CF^2*NC*Pi*Log[3]^2)/(46526312121734016*
         Sqrt[3]) + (151196805060626986363*CF*NC*NH*Pi*Log[3]^2)/
        (61004779879896*Sqrt[3]) + CF*((-43972758123329816266853981*CF*NC)/
          19082471728320 + CA*(2858239243069372477339672129/
            2480721324681600 - (7591155*lm)/2)*NC + 12421890*CF*lm*NC - 
         (5752381864445565605181*NM*NC)/297457160 + 690105*lm*NM*NC + 
         (32192173*NC*NL)/36 + 690105*lm*NC*NL + (22977829838729291*NC*NH)/
          120470149800 + 690105*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-125036983605000314*CA + 250053587748120547*CF + 
          77220*(24631377077924*NM + 2070315*NL))*Log[x]^3)/347490 - 
       (10552653253705698454470778724*CF^2*NC*PolyGamma[2, 1])/
        46325504721296025 - (1470201281968817*CF*NM*NC*PolyGamma[2, 1])/
        1080 + (530160710014750777091*CF*NC*NH*PolyGamma[2, 1])/
        823564528378596 - (10149780149539656467460449726999*CF^2*NC*Zeta[3])/
        105992754802325305200 + (7678496060503*CF*NM*NC*Zeta[3])/540 + 
       (2326340*CF*NC*NL*Zeta[3])/3 - (3158989243781194477441*CF*NC*NH*
         Zeta[3])/411782264189298 + CA*CF*NC*
        (-25295222900642496898037698450817513935673406590359227749/
          82656247349144506892271751828670247751680000 - (3494645*lm^2)/72 + 
         (13081291338296105917372591*Pi^2)/136240988083200 - 
         (641882841941323608522295*Pi^3)/(2512420854573636864*Sqrt[3]) - 
         (24471293*Pi^4)/5184 + lm*(-20152847077873/115644672 + 
           (13475*Pi^2)/72) + (40082600452944919498577659933*
           Im[PolyLog[2, (-1)^(1/3)]])/(12574666377141052504320*Sqrt[3]) - 
         (5759075*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
         (18339509769752103100637*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1938596338405584*Sqrt[3]) - (18339509769752103100637*Pi*Log[3]^2)/
          (93052624243468032*Sqrt[3]) + (5276326626852849227235389362*
           PolyGamma[2, 1])/46325504721296025 + 
         (10149687986920886983685490302879*Zeta[3])/211985509604650610400) + 
       CF*Log[x]*((-19884213587927232322662291003047*NM*NC)/
          2150082517456954080 + (8220386489*lm*NM*NC)/30888 + 
         (127400*lm^2*NM*NC)/3 + (8352618097475087*NC*NL)/5993507520 + 
         (8220386489*lm*NC*NL)/30888 + (127400*lm^2*NC*NL)/3 + 
         (197155442903973997376406342059102436731*NC*NH)/
          8433983455573182384506969340000 + (8220386489*lm*NC*NH)/30888 + 
         (127400*lm^2*NC*NH)/3 - (24631378668955*NM*NC*Pi^2)/18 + 
         (2325115*NC*NL*Pi^2)/18 - (302393610121253972726*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CA*NC*(425873679617095724060251754899780316685371693/
            1286463609756762753050129723328000 - (9889836089*lm)/5616 - 
           (700700*lm^2)/3 + (1000286853043996591*Pi^2)/11119680 + 
           (18339509769752103100637*Im[PolyLog[2, (-1)^(1/3)]])/
            (5815789015216752*Sqrt[3]) - 254800*Zeta[3]) + 
         CF*NC*(-38715964154587343690098611486775390793001013/
            58475618625307397865914987424000 + (7236603689*lm)/1716 + 
           764400*lm^2 - (1000287629121466759*Pi^2)/5559840 - 
           (18339509769752103100637*Im[PolyLog[2, (-1)^(1/3)]])/
            (2907894507608376*Sqrt[3]) + 509600*Zeta[3])), 
      (-213902300932908835001260249236989246047107732137609881481249*CF^2*NC)/
        32545897393725649588832002282538910052224000000 - 
       (2897707355912641*CF^2*lm*NC)/12985932960 - 149629*CF^2*lm^2*NC + 
       (10787027828957843486539969954766920996172357*CF*NM*NC)/
        10792531790016682211221716000000 - (4355011478066521*CF*lm*NM*NC)/
        233746793280 - (149629*CF*lm^2*NM*NC)/18 + 
       (79027516715996231029*CF*NC*NL)/126551974799250 - 
       (4355011478066521*CF*lm*NC*NL)/233746793280 - (149629*CF*lm^2*NC*NL)/
        18 + (6603750597121338325068241402557609272025338148977*CF*NC*NH)/
        290298071515320836206935941581087752000000 - 
       (4355011478066521*CF*lm*NC*NH)/233746793280 - (149629*CF*lm^2*NC*NH)/
        18 + (4111594285078942863698665331*CF^2*NC*Pi^2)/1359003856129920 + 
       (1385*CF^2*lm*NC*Pi^2)/3 - (3097670165628996943*CF*NM*NC*Pi^2)/
        4864860 + (1385*CF*lm*NM*NC*Pi^2)/54 - (27763850717*CF*NC*NL*Pi^2)/
        972972 + (1385*CF*lm*NC*NL*Pi^2)/54 + (1385*CF*lm*NC*NH*Pi^2)/54 - 
       (45798960100252610450029*CF^2*NC*Pi^3)/(88327295668604421*Sqrt[3]) - 
       (7321774865852841504425*CF*NC*NH*Pi^3)/(2470693585135788*Sqrt[3]) - 
       (10339052*CF^2*NC*Pi^4)/1215 + (20600109273012872597868190543*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3094546803749555889735*Sqrt[3]) + 
       (2723883368214410377919917*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (475608515138639190*Sqrt[3]) - 
       (8113024*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (732783361604041767200464*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(38166115412359935*Sqrt[3]) - 
       (836774270383181886220*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (45798960100252610450029*CF^2*NC*Pi*Log[3]^2)/(114498346237079805*
         Sqrt[3]) - (209193567595795471555*CF*NC*NH*Pi*Log[3]^2)/
        (91507169819844*Sqrt[3]) - 
       (CF*NC*(-7*CA*(-8443448570552942355703106671 + 1675148884981910137800*
             lm) + CF*(-118208259563122882312379883557 + 
            38376138092312850429600*lm) + 
          54054*(24*(19177164208004917381129 + 1643424223766325*lm)*NM + 
            11*(1318276050*(3551417 + 2719956*lm)*NL + (1006038067156063 + 
                3585652851853800*lm)*NH)))*Log[x]^2)/3255946738644600 + 
       (CF*NC*(-36936291285878452481*CA + 56*(1319146223488579157*CF - 
            19305*(13289389348181*NM - 2946619*NL)))*Log[x]^3)/7297290 + 
       (194730478573442632024706669677*CF^2*NC*PolyGamma[2, 1])/
        88944969064888368 + (275294402810821*CF*NM*NC*PolyGamma[2, 1])/
        1350 - (87682688960115247127431*CF*NC*NH*PolyGamma[2, 1])/
        277953028327776150 - (152019105044044616858303080981547*CF^2*NC*
         Zeta[3])/222584785084883140920 + (939767351018221*CF*NM*NC*Zeta[3])/
        675 - (2212856*CF*NC*NL*Zeta[3])/3 + 
       (1160849062870421932859069*CF*NC*NH*Zeta[3])/138976514163888075 + 
       CA*CF*NC*(106951140741419681521518156173645629955629853577075350517637/
          32545897393725649588832002282538910052224000000 + 
         (1645919*lm^2)/36 - (13524981109356539435426831*Pi^2)/
          8940814842960 + (45798960100252610450029*Pi^3)/(176654591337208842*
           Sqrt[3]) + (5194456*Pi^4)/1215 + 
         lm*(6828012412630681/42499416960 - (15235*Pi^2)/108) - 
         (20600109273012872597868190543*Im[PolyLog[2, (-1)^(1/3)]])/
          (6189093607499111779470*Sqrt[3]) + 
         (4056512*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (366391680802020883600232*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (38166115412359935*Sqrt[3]) + (45798960100252610450029*Pi*Log[3]^2)/
          (228996692474159610*Sqrt[3]) - (194730478573442632024706669677*
           PolyGamma[2, 1])/177889938129776736 + 
         (152019252485912740437213063803267*Zeta[3])/445169570169766281840) + 
       CF*Log[x]*((-3944675927570646286718324643046289*NM*NC)/
          806280944046357780000 - (80148274411*lm*NM*NC)/324324 - 
         (123760*lm^2*NM*NC)/3 - (59024196917592559*NC*NL)/44951306400 - 
         (80148274411*lm*NC*NL)/324324 - (123760*lm^2*NC*NL)/3 - 
         (272786272736482334633600892971356163369*NC*NH)/
          12650975183359773576760454010000 - (80148274411*lm*NC*NH)/324324 - 
         (123760*lm^2*NC*NH)/3 - (13289386312993*NM*NC*Pi^2)/27 - 
         (3317899*NC*NL*Pi^2)/27 + (836774270383181886220*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(3717219609719485097492489129119421335105370729549/
            202618018536690133605395431424160000 - (70113689851*lm)/18018 - 
           742560*lm^2 + (18468134984975500603*Pi^2)/7297290 + 
           (732783361604041767200464*Im[PolyLog[2, (-1)^(1/3)]])/
            (114498346237079805*Sqrt[3]) - 495040*Zeta[3]) + 
         CA*NC*(-142969964448285759990661887162584056124048411989/
            15586001425899241046568879340320000 + (97176660331*lm)/58968 + 
           (680680*lm^2)/3 - (7387253689563251215*Pi^2)/5837832 - 
           (366391680802020883600232*Im[PolyLog[2, (-1)^(1/3)]])/
            (114498346237079805*Sqrt[3]) + 247520*Zeta[3])), 
      (5588618871435222417186365692021877839570049108499504283237*CF^2*NC)/
        1061279262838879877896695726604529675616000000 + 
       (37647852928867*CF^2*lm*NC)/108216108 + 221960*CF^2*lm^2*NC + 
       (17617029716095482096526005291531706593376253*CF*NM*NC)/
        449688824584028425467571500000 + (55662588427627*CF*lm*NM*NC)/
        1947889944 + (110980*CF*lm^2*NM*NC)/9 - 
       (45047913875385363583*CF*NC*NL)/42541916376960 + 
       (55662588427627*CF*lm*NC*NL)/1947889944 + (110980*CF*lm^2*NC*NL)/9 - 
       (6548618819566981420161630648534389650033324851001*CF*NC*NH)/
        172845469646512854405103666895656978440000 + 
       (55662588427627*CF*lm*NC*NH)/1947889944 + (110980*CF*lm^2*NC*NH)/9 - 
       (175714283930824315925817521*CF^2*NC*Pi^2)/113250321344160 - 
       800*CF^2*lm*NC*Pi^2 - (20561593578474947293*CF*NM*NC*Pi^2)/1216215 - 
       (400*CF*lm*NM*NC*Pi^2)/9 + (3741771785*CF*NC*NL*Pi^2)/81081 - 
       (400*CF*lm*NC*NL*Pi^2)/9 - (400*CF*lm*NC*NH*Pi^2)/9 + 
       (1717671953059486441998545*CF^2*NC*Pi^3)/(2119855096046506104*
         Sqrt[3]) + (9511379560880559726560*CF*NC*NH*Pi^3)/
        (1853020188851841*Sqrt[3]) + (1147129*CF^2*NC*Pi^4)/81 - 
       (367783833152761535352177380641*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (37134561644994670676820*Sqrt[3]) - (143493450856326917854327676*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(9274366045203464205*Sqrt[3]) + 
       (4274800*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (687068781223794576799418*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22899669247415961*Sqrt[3]) + 
       (4348059227831113017856*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) + 
       (343534390611897288399709*CF^2*NC*Pi*Log[3]^2)/(549592061937983064*
         Sqrt[3]) + (271753701739444563616*CF*NC*NH*Pi*Log[3]^2)/
        (68630377364883*Sqrt[3]) + CF*((-15688739036841614201888876*CF*NC)/
          842636319525 + CA*(439284997749934198495518497/47187633893400 - 
           (18313460*lm)/3)*NC + 19978320*CF*lm*NC - 
         (1018347177072788326441318*NM*NC)/5019589575 + 
         (3329720*lm*NM*NC)/3 + (12922670*NC*NL)/9 + (3329720*lm*NC*NL)/
          3 + (529445381420*NC*NH)/1654653 + (3329720*lm*NC*NH)/3)*
        Log[x]^2 - (2*CF*NC*(-1808624111943411173*CA + 3617187045727985326*
           CF + 1081080*(32372801371277*NM + 416215*NL))*Log[x]^3)/
        1216215 - (821243063339838350244927801601*CF^2*NC*PolyGamma[2, 1])/
        416929542491664225 - (3723221834589187*CF*NM*NC*PolyGamma[2, 1])/
        270 + (170413970731244728679273*CF*NC*NH*PolyGamma[2, 1])/
        166771816996665690 - (57551968323694187000101444579186*CF^2*NC*
         Zeta[3])/59620924576307984175 + (161513176311293*CF*NM*NC*Zeta[3])/
        135 + (3712120*CF*NC*NL*Zeta[3])/3 - 
       (1006616744663459050862167*CF*NC*NH*Zeta[3])/83385908498332845 + 
       CA*CF*NC*(-1397154393936119217489732313087161184416869145604712341753/
          530639631419439938948347863302264837808000000 - (610390*lm^2)/9 + 
         (25840335151949541526812973*Pi^2)/33308918042400 - 
         (1717671953059486441998545*Pi^3)/(4239710192093012208*Sqrt[3]) - 
         (1152889*Pi^4)/162 + lm*(-86233048667947/354161808 + 
           (2200*Pi^2)/9) + (367783833152761535352177380641*
           Im[PolyLog[2, (-1)^(1/3)]])/(74269123289989341353640*Sqrt[3]) - 
         (2137400*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (343534390611897288399709*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (22899669247415961*Sqrt[3]) - (343534390611897288399709*Pi*
           Log[3]^2)/(1099184123875966128*Sqrt[3]) + 
         (821243063339838350244927801601*PolyGamma[2, 1])/
          833859084983328450 + (57551886536818802417928081819841*Zeta[3])/
          119241849152615968350) + CF*Log[x]*
        ((-6460016233753309109442802721620637*NM*NC)/67190078670529815000 + 
         (10791852574*lm*NM*NC)/27027 + (190400*lm^2*NM*NC)/3 + 
         (261064494737749*NC*NL)/118053936 + (10791852574*lm*NC*NL)/27027 + 
         (190400*lm^2*NC*NL)/3 + (4689604636359253034022521520808887799*NC*
           NH)/125588866368745657029969016200 + (10791852574*lm*NC*NH)/
          27027 + (190400*lm^2*NC*NH)/3 - (388473620789792*NM*NC*Pi^2)/27 + 
         206140*NC*NL*Pi^2 - (4348059227831113017856*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CA*NC*(1855404699770291613424853172018705745105636567/
            825888662513682609804600943305000 - (6487489487*lm)/2457 - 
           (1047200*lm^2)/3 + (516748838602900339*Pi^2)/694980 + 
           (343534390611897288399709*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) - 380800*Zeta[3]) + 
         CF*NC*(-2698773242628871515469430074732204875991120637/
            600646300009950988948800686040000 + (19010734748*lm)/3003 + 
           1142400*lm^2 - (516748915498323229*Pi^2)/347490 - 
           (687068781223794576799418*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) + 761600*Zeta[3])), 
      (-91661013021492754128614737654285768716419534676570742822163*CF^2*NC)/
        1266925071555064214098131576742431619680000000 - 
       (18792926590031719*CF^2*lm*NC)/60871560750 - (1034944*CF^2*lm^2*NC)/
        5 + (440612299153988570395202535663422516423263579*CF*NM*NC)/
        31221252678262544968177107000000 - (28242725075358919*CF*lm*NM*NC)/
        1095688093500 - (517472*CF*lm^2*NM*NC)/45 + 
       (795372898215858671071117*CF*NC*NL)/789684322747320000 - 
       (28242725075358919*CF*lm*NC*NL)/1095688093500 - 
       (517472*CF*lm^2*NC*NL)/45 + 
       (1997011363737665907318086995173515455079539187896014023*CF*NC*NH)/
        55755627371223884009726315348866549820283000000 - 
       (28242725075358919*CF*lm*NC*NH)/1095688093500 - 
       (517472*CF*lm^2*NC*NH)/45 + (15453101129682108297724671823*CF^2*NC*
         Pi^2)/471876338934000 + (26944*CF^2*lm*NC*Pi^2)/45 - 
       (16062900228711633058*CF*NM*NC*Pi^2)/2027025 + 
       (13472*CF*lm*NM*NC*Pi^2)/405 - (768704812586*CF*NC*NL*Pi^2)/
        18243225 + (13472*CF*lm*NC*NL*Pi^2)/405 + (13472*CF*lm*NC*NH*Pi^2)/
        405 - (5153739374461966972752283*CF^2*NC*Pi^3)/(6359565288139518312*
         Sqrt[3]) - (26020712558926020546800*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (571909*CF^2*NC*Pi^4)/45 + 
       (56862529732645498513502246191363*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5570184246749200601523000*Sqrt[3]) + 
       (1351138266187506566723394568*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (139115490678051963075*Sqrt[3]) - 
       (19828528*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (10307478748923933945504566*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(343495038711239415*
         Sqrt[3]) - (11895182884080466535680*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (5153739374461966972752283*CF^2*NC*Pi*Log[3]^2)/(8243880929069745960*
         Sqrt[3]) - (743448930255029158480*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) - 
       (CF*NC*(-493*CA*(-62721406142629443009081697513 + 
            1823996382432193569600*lm) + 
          4*(4437*CF*(-3484522475249487874444795249 + 165817852948381233600*
               lm) + 140140*(5365*(4975976539283932138261 + 54364621866984*
                 lm)*NM + 27*(61616126*(228511331 + 175318580*lm)*NL + 
                (3155122153917343 + 10802451715421080*lm)*NH))))*Log[x]^2)/
        157370759034489000 + (2*CF*NC*(-167275039347165323967*CA + 
          14*(23896414378493889371*CF - 17160*(318812440894183*NM - 
              8765929*NL)))*Log[x]^3)/6081075 + 
       (57931834807735352857115371830061*CF^2*NC*PolyGamma[2, 1])/
        2501577254949985350 + (353470520771209*CF*NM*NC*PolyGamma[2, 1])/
        675 - (627820034001338320272359*CF*NC*NH*PolyGamma[2, 1])/
        1250788627474992675 - (2178225517377479730432370333108781*CF^2*NC*
         Zeta[3])/250407883220493533535 + (9208611700084178*CF*NM*NC*
         Zeta[3])/675 - (52253104*CF*NC*NL*Zeta[3])/45 + 
       (16207676601701251117584242*CF*NC*NH*Zeta[3])/1250788627474992675 + 
       CA*CF*NC*(5728813239083936983064419926658938435860838199774323941693/
          158365633944383026762266447092803952460000000 + (2846096*lm^2)/45 - 
         (6181240446086382673964518339*Pi^2)/377501071147200 + 
         (5153739374461966972752283*Pi^3)/(12719130576279036624*Sqrt[3]) + 
         (25843681*Pi^4)/4050 + lm*(44278746747429319/199216017000 - 
           (74096*Pi^2)/405) - (56862529732645498513502246191363*
           Im[PolyLog[2, (-1)^(1/3)]])/(11140368493498401203046000*Sqrt[3]) + 
         (9914264*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (5153739374461966972752283*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (343495038711239415*Sqrt[3]) + (5153739374461966972752283*Pi*
           Log[3]^2)/(16487761858139491920*Sqrt[3]) - 
         (57931834807735352857115371830061*PolyGamma[2, 1])/
          5003154509899970700 + (5445564437995619039485367149483586*Zeta[3])/
          1252039416102467667675) + CF*Log[x]*
        ((-10975060517549727250705792682993809*NM*NC)/
          194371299011175536250 - (2228099961508*lm*NM*NC)/6081075 - 
         60928*lm^2*NM*NC - (4507778685078678227*NC*NL)/2191376187000 - 
         (2228099961508*lm*NC*NL)/6081075 - 60928*lm^2*NC*NL - 
         (407582232319428773043154900700028112883377*NC*NH)/
          11969403895356265775312484550211250 - (2228099961508*lm*NC*NH)/
          6081075 - 60928*lm^2*NC*NH - (510099889598336*NM*NC*Pi^2)/81 - 
         (78352712*NC*NL*Pi^2)/405 + (11895182884080466535680*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(1542556359056079898566633409826129555078716916453/
            7887379614317522501940133576200000 - (3900438316616*lm)/675675 - 
           1096704*lm^2 + (334550050434197305243*Pi^2)/12162150 + 
           (10307478748923933945504566*Im[PolyLog[2, (-1)^(1/3)]])/
            (1030485116133718245*Sqrt[3]) - 731136*Zeta[3]) + 
         CA*NC*(-385639081889970818003499551061802715412480848297/
            3943689807158761250970066788100000 + (1349827631954*lm)/552825 + 
           335104*lm^2 - (66910009689763049717*Pi^2)/4864860 - 
           (5153739374461966972752283*Im[PolyLog[2, (-1)^(1/3)]])/
            (1030485116133718245*Sqrt[3]) + 365568*Zeta[3])), 
      (2273981315268476051793390379734222414511623566595120285571339*CF^2*NC)/
        52305906525630508267765717954080391155360000000 + 
       (11587419092483491*CF^2*lm*NC)/24348624300 + 303688*CF^2*lm^2*NC + 
       (18027897589882803824324481852664675231630327049*CF*NM*NC)/
        43709753749567562955447949800000 + (17133207854797291*CF*lm*NM*NC)/
        438275237400 + (151844*CF*lm^2*NM*NC)/9 - 
       (106055714939922746305691*CF*NC*NL)/63174745819785600 + 
       (17133207854797291*CF*lm*NC*NL)/438275237400 + 
       (151844*CF*lm^2*NC*NL)/9 - 
       (601142780696077980316633390891860088038089274209635757*CF*NC*NH)/
        10238017104389365930311616497522703314201496875 + 
       (17133207854797291*CF*lm*NC*NH)/438275237400 + 
       (151844*CF*lm^2*NC*NH)/9 - (3672892871193805644262480019*CF^2*NC*
         Pi^2)/314584225956000 - (9248*CF^2*lm*NC*Pi^2)/9 - 
       (643554946342041281267*CF*NM*NC*Pi^2)/3648645 - 
       (4624*CF*lm*NM*NC*Pi^2)/81 + (49071346889*CF*NC*NL*Pi^2)/729729 - 
       (4624*CF*lm*NC*NL*Pi^2)/81 - (4624*CF*lm*NC*NH*Pi^2)/81 + 
       (7935457787738069355668303*CF^2*NC*Pi^3)/(6359565288139518312*
         Sqrt[3]) + (4921936043642237446400*CF*NC*NH*Pi^3)/
        (617673396283947*Sqrt[3]) + (42136693*CF^2*NC*Pi^4)/2025 - 
       (20883121986241663047383277795341*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1392546061687300150380750*Sqrt[3]) - 
       (229861231255109850481269196*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9274366045203464205*Sqrt[3]) + 
       (92888272*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
       (15870915575476138711336606*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(343495038711239415*
         Sqrt[3]) + (2250027905665022832640*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) + 
       (7935457787738069355668303*CF^2*NC*Pi*Log[3]^2)/(8243880929069745960*
         Sqrt[3]) + (140626744104063927040*CF*NC*NH*Pi*Log[3]^2)/
        (22876792454961*Sqrt[3]) + 
       CF*((-190072115021937216906003367073*CF*NC)/1356644474435250 + 
         CA*(18102108795292945400966717093/258408471321000 - 
           (257179604*lm)/27)*NC + (93519856*CF*lm*NC)/3 - 
         (11474327248171582139427760*NM*NC)/5421156741 + 
         (46759928*lm*NM*NC)/27 + (906123902*NC*NL)/405 + 
         (46759928*lm*NC*NL)/27 + (1803887832131545994*NC*NH)/
          3481157078685 + (46759928*lm*NC*NH)/27)*Log[x]^2 - 
       (2*CF*NC*(-211460416835964773965*CA + 422919312316644513014*CF + 
          1801800*(3046828843755841*NM + 5844991*NL))*Log[x]^3)/18243225 - 
       (6901899132897984701370339472849*CF^2*NC*PolyGamma[2, 1])/
        416929542491664225 - (37699711792747381*CF*NM*NC*PolyGamma[2, 1])/
        270 + (788487852517111579533517*CF*NC*NH*PolyGamma[2, 1])/
        500315450989997070 - (4142531099981655425790868163363578*CF^2*NC*
         Zeta[3])/417346472034155889225 + (974890326124313*CF*NM*NC*Zeta[3])/
        45 + (17257448*CF*NC*NL*Zeta[3])/9 - 
       (4621813241554819679301683*CF*NC*NH*Zeta[3])/250157725494998535 + 
       CA*CF*NC*
        (-361769738823134897704995375598822901592004565147823115349867/
          16642788439973343539743637530843760822160000000 - (835142*lm^2)/9 + 
         (162039390493256906733314303*Pi^2)/27757431702000 - 
         (7935457787738069355668303*Pi^3)/(12719130576279036624*Sqrt[3]) - 
         (42321653*Pi^4)/4050 + lm*(-26544243330238891/79686406800 + 
           (25432*Pi^2)/81) + (20883121986241663047383277795341*
           Im[PolyLog[2, (-1)^(1/3)]])/(2785092123374600300761500*Sqrt[3]) - 
         (46444136*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
         (7935457787738069355668303*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (343495038711239415*Sqrt[3]) - (7935457787738069355668303*Pi*
           Log[3]^2)/(16487761858139491920*Sqrt[3]) + 
         (6901899132897984701370339472849*PolyGamma[2, 1])/
          833859084983328450 + (4142530221149195688608385633038251*Zeta[3])/
          834692944068311778450) + CF*Log[x]*
        ((-1081676589320967748282069361624561471*NM*NC)/
          1088479274462583003000 + (710081453726*lm*NM*NC)/1216215 + 
         92480*lm^2*NM*NC + (2989045367172952541*NC*NL)/876550474800 + 
         (710081453726*lm*NC*NL)/1216215 + 92480*lm^2*NC*NL + 
         (59261109721873346171389316144289529170908789*NC*NH)/
          1022453079416655236451137569133601000 + (710081453726*lm*NC*NH)/
          1216215 + 92480*lm^2*NC*NH - (12187315397393120*NM*NC*Pi^2)/81 + 
         (25876924*NC*NL*Pi^2)/81 - (2250027905665022832640*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CA*NC*(13416062584132969283224570660932671720777276450977/
            1139726354268882001530349301760900000 - (426616085263*lm)/
            110565 - 508640*lm^2 + (84584136956456945147*Pi^2)/14594580 + 
           (7935457787738069355668303*Im[PolyLog[2, (-1)^(1/3)]])/
            (1030485116133718245*Sqrt[3]) - 554880*Zeta[3]) + 
         CF*NC*(-53664266107892274855229089800919343202020693392283/
            2279452708537764003060698603521800000 + (1251449562652*lm)/
            135135 + 1664640*lm^2 - (422920697225923255057*Pi^2)/36486450 - 
           (15870915575476138711336606*Im[PolyLog[2, (-1)^(1/3)]])/
            (1030485116133718245*Sqrt[3]) + 1109760*Zeta[3])), 
      (-129880498525667011219070116547835458241109288706411218987186068482609*
         CF^2*NC)/164858239011234780239958769223528614508612774400000000 - 
       (33289602809941571*CF^2*lm*NC)/79505712000 - (1403503*CF^2*lm^2*NC)/
        5 + (12344852575074214109483015714908432685531907507785509*CF*NM*NC)/
        68226379788685010746906883051020800000 - 
       (50027578606311971*CF*lm*NM*NC)/1431102816000 - 
       (1403503*CF*lm^2*NM*NC)/90 + (621900495796049418331699*CF*NC*NL)/
        394842161373660000 - (50027578606311971*CF*lm*NC*NL)/1431102816000 - 
       (1403503*CF*lm^2*NC*NL)/90 + 
       (31822824286001145594302184911119909132847415913416126432739*CF*NC*
         NH)/579845548805631090688147779685730927370257752320000 - 
       (50027578606311971*CF*lm*NC*NH)/1431102816000 - 
       (1403503*CF*lm^2*NC*NH)/90 + (1767677487006014959158691731667*CF^2*NC*
         Pi^2)/5033347615296000 + (34391*CF^2*lm*NC*Pi^2)/45 - 
       (1716740630232773093218*CF*NM*NC*Pi^2)/18243225 + 
       (34391*CF*lm*NM*NC*Pi^2)/810 - (2533231911127*CF*NC*NL*Pi^2)/
        41698800 + (34391*CF*lm*NC*NL*Pi^2)/810 + (34391*CF*lm*NC*NH*Pi^2)/
        810 - (188065653351534816956093741*CF^2*NC*Pi^3)/
        (152629566915348439488*Sqrt[3]) - (119963564590443541382590*CF*NC*NH*
         Pi^3)/(16677181699666569*Sqrt[3]) - (299793181*CF^2*NC*Pi^4)/16200 + 
       (4084926119770243254551098270229947*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(267368843843961628873104000*Sqrt[3]) + 
       (6622972874453220852840337511*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (417346472034155889225*Sqrt[3]) - 
       (9470938*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (188065653351534816956093741*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4121940464534872980*
         Sqrt[3]) - (54840486669917047489184*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (188065653351534816956093741*CF^2*NC*Pi*Log[3]^2)/
        (197853142297673903040*Sqrt[3]) - (3427530416869815468074*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) - 
       (CF*NC*(-403*CA*(-2040647663360849558629931712031529 + 
            8531438093759011983552000*lm) + 
          22*(31*CF*(-2411674502467629546689107044571007 + 
              16498814164790155406208000*lm) + 
            18200*(31*(35506206667099526565590630677 + 50362680600702550080*
                 lm)*NM + 2*(8182867997304*(124155227 + 95397060*lm)*NL + 
                (236244583056421302037 + 780621549310889526240*lm)*NH))))*
         Log[x]^2)/390279482405532720000 + 
       (CF*NC*(-14406757441926650535475*CA + 12*(2401125937847096489583*CF - 
            40040*(15420903808557103*NM - 54058334*NL)))*Log[x]^3)/
        24324300 + (1627189586549531872954077048327761*CF^2*NC*
         PolyGamma[2, 1])/6670872679866627600 - 
       (12312069991332301*CF*NM*NC*PolyGamma[2, 1])/1350 - 
       (5819045955005445981406987*CF*NC*NH*PolyGamma[2, 1])/
        7504731764849956050 - (174332811108571928240470587926966029*CF^2*NC*
         Zeta[3])/1669385888136623556900 + (90493964043923689*CF*NM*NC*
         Zeta[3])/675 - (80007746*CF*NC*NL*Zeta[3])/45 + 
       (73481174129278023415261133*CF*NC*NH*Zeta[3])/3752365882424978025 + 
       CA*CF*NC*
        (16884464777232761479456063233693563887603537911869769144574965307216\
67/4286314214292104286238927999811743977223932134400000000 + 
         (15438533*lm^2)/180 - (34660342878059570486800614253*Pi^2)/
          197386180992000 + (188065653351534816956093741*Pi^3)/
          (305259133830696878976*Sqrt[3]) + (300893693*Pi^4)/32400 + 
         lm*(78431416321364771/260200512000 - (378301*Pi^2)/1620) - 
         (4084926119770243254551098270229947*Im[PolyLog[2, (-1)^(1/3)]])/
          (534737687687923257746208000*Sqrt[3]) + 
         (4735469*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (188065653351534816956093741*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (8243880929069745960*Sqrt[3]) + (188065653351534816956093741*Pi*
           Log[3]^2)/(395706284595347806080*Sqrt[3]) - 
         (1627189586549531872954077048327761*PolyGamma[2, 1])/
          13341745359733255200 + (174332813712487359595405304634922297*
           Zeta[3])/3338771776273247113800) + 
       CF*Log[x]*((-715762074262828320087850191845646995897*NM*NC)/
          1126659778243732068336000 - (3684405137473*lm*NM*NC)/6949800 - 
         87856*lm^2*NM*NC - (13744822936534986521*NC*NL)/4382752374000 - 
         (3684405137473*lm*NC*NL)/6949800 - 87856*lm^2*NC*NL - 
         (2311014593459439898986047067316174200042782257*NC*NH)/
          44169973030799506214689142986571563200 - (3684405137473*lm*NC*NH)/
          6949800 - 87856*lm^2*NC*NH - (6168361497102122*NM*NC*Pi^2)/81 - 
         (119977228*NC*NL*Pi^2)/405 + (54840486669917047489184*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(475520675792393700818116933177710351653523748734834359579/
            230042367345631143188885703067420056000000 - (3226468915873*lm)/
            386100 - 1581408*lm^2 + (28813514534535035274637*Pi^2)/97297200 + 
           (188065653351534816956093741*Im[PolyLog[2, (-1)^(1/3)]])/
            (12365821393604618940*Sqrt[3]) - 1054272*Zeta[3]) + 
         CA*NC*(-951041348869533633924233689096033041154956595031952206233/
            920169469382524572755542812269680224000000 + (4461509028673*lm)/
            1263600 + 483208*lm^2 - (28813514510333268281233*Pi^2)/
            194594400 - (188065653351534816956093741*Im[PolyLog[2, (-1)^
                (1/3)]])/(24731642787209237880*Sqrt[3]) + 527136*Zeta[3])), 
      (435175569069191595942576538979510072989583815794859981548795325359101*
         CF^2*NC)/1285894264287631285871678399943523193167179640320000000 + 
       (12293676371981261*CF^2*lm*NC)/19238419200 + (815745*CF^2*lm^2*NC)/2 + 
       (327250063977611557437659503873144907364228125104780277*CF*NM*NC)/
        75807088654094456385452092278912000000 + 
       (18178792973345261*CF*lm*NM*NC)/346291545600 + 
       (271915*CF*lm^2*NM*NC)/12 - (12102144418318225430363*CF*NC*NL)/
        4679610801465600 + (18178792973345261*CF*lm*NC*NL)/346291545600 + 
       (271915*CF*lm^2*NC*NL)/12 - 
       (608494079837723506817661125354199890984849784866168635880821*CF*NC*
         NH)/6858388211679507524268414598433376560293371264000000 + 
       (18178792973345261*CF*lm*NC*NH)/346291545600 + 
       (271915*CF*lm^2*NC*NH)/12 - (72031365487311785758496518261*CF^2*NC*
         Pi^2)/929233405900800 - (2601*CF^2*lm*NC*Pi^2)/2 - 
       (38047991605106973767*CF*NM*NC*Pi^2)/20790 - (289*CF*lm*NM*NC*Pi^2)/
        4 + (46043202509*CF*NC*NL*Pi^2)/480480 - (289*CF*lm*NC*NL*Pi^2)/4 - 
       (289*CF*lm*NC*NH*Pi^2)/4 + (3429871115857868927817354505*CF^2*NC*
         Pi^3)/(1831554802984181273856*Sqrt[3]) + 
       (134090738356361792976215*CF*NC*NH*Pi^3)/(11118121133111046*
         Sqrt[3]) + (129037837*CF^2*NC*Pi^4)/4320 - 
       (14241372629011826700931977646915291*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(641685225225507909295449600*Sqrt[3]) - 
       (4295929215819396558281314151*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (111292392542441570460*Sqrt[3]) + 
       (5852471*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
       (685974223171573785563470901*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9892657114883695152*
         Sqrt[3]) + (30649311624311266965992*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (685974223171573785563470901*CF^2*NC*Pi*Log[3]^2)/
        (474847541514417367296*Sqrt[3]) + (3831163953038908370749*CF*NC*NH*
         Pi*Log[3]^2)/(411782264189298*Sqrt[3]) + 
       CF*((-4684379263303060046117885530565113*CF*NC)/5035864289103648000 + 
         CA*(669197059625437073550788009423443/1438818368315328000 - 
           14471930*lm)*NC + 47362680*CF*lm*NC - 
         (153449662524123211028531205673*NM*NC)/6987268688400 + 
         2631260*lm*NM*NC + (16976251*NC*NL)/5 + 2631260*lm*NC*NL + 
         (5685934753178598767*NC*NH)/6987268688400 + 2631260*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-2663681385203865378579*CA + 
          80*(66591980242085805763*CF + 270270*(4694416100460617*NM + 
              1315630*NL)))*Log[x]^3)/16216200 - 
       (4522773778666253687761858867853866*CF^2*NC*PolyGamma[2, 1])/
        33771292941824802225 - (28247247903031747*CF*NM*NC*PolyGamma[2, 1])/
        20 + (128044104470037352006768579*CF*NC*NH*PolyGamma[2, 1])/
        54034068706919683560 - (112056190339836939734039958381582607409*CF^2*
         NC*Zeta[3])/1081762055512532064871200 + 
       (9146577684660829*CF*NM*NC*Zeta[3])/30 + 2895695*CF*NC*NL*Zeta[3] - 
       (745420680740043175476828101*CF*NC*NH*Zeta[3])/27017034353459841780 + 
       CA*CF*NC*
        (
         -4351755653338244502521172346417907023926233869193511429702340665169\
01/2571788528575262571743356799887046386334359280640000000 - 
         (2991065*lm^2)/24 + (7061898568862489900067546179*Pi^2)/
          182202628608000 - (3429871115857868927817354505*Pi^3)/
          (3663109605968362547712*Sqrt[3]) - (129537229*Pi^4)/8640 + 
         lm*(-28165657508993261/62962099200 + (3179*Pi^2)/8) + 
         (14241372629011826700931977646915291*Im[PolyLog[2, (-1)^(1/3)]])/
          (1283370450451015818590899200*Sqrt[3]) - 
         (5852471*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
         (685974223171573785563470901*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (19785314229767390304*Sqrt[3]) - (685974223171573785563470901*Pi*
           Log[3]^2)/(949695083028834734592*Sqrt[3]) + 
         (2261386889333126843880929433926933*PolyGamma[2, 1])/
          33771292941824802225 + (22411237385410086885762596327985428557*
           Zeta[3])/432704822205012825948480) + 
       CF*Log[x]*((-23749250795839162629659250707210516808739*NM*NC)/
          2324853510661669347360000 + (40097592317*lm*NM*NC)/48048 + 
         131784*lm^2*NM*NC + (332894302570078517*NC*NL)/64929664800 + 
         (40097592317*lm*NC*NL)/48048 + 131784*lm^2*NC*NL + 
         (320439010495370929404622242964838544690422593*NC*NH)/
          3653430358213358661264610668864480000 + (40097592317*lm*NC*NH)/
          48048 + 131784*lm^2*NC*NH - 1564805367274933*NM*NC*Pi^2 + 
         (1447414*NC*NL*Pi^2)/3 - (30649311624311266965992*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(2381867524723934904383068471326995956909523359900904531/
            200764247865278088601209340858839321600000 - (48156447485*lm)/
            8736 - 724812*lm^2 + (1183858303970836687007*Pi^2)/28828800 + 
           (685974223171573785563470901*Im[PolyLog[2, (-1)^(1/3)]])/
            (59355942689302170912*Sqrt[3]) - 790704*Zeta[3]) + 
         CF*NC*(-2015427228435462269272117686926892404009536361559846067/
            84938720250694575946665490363355097600000 + (106045872279*lm)/
            8008 + 2372112*lm^2 - (2130944960448768945947*Pi^2)/25945920 - 
           (685974223171573785563470901*Im[PolyLog[2, (-1)^(1/3)]])/
            (29677971344651085456*Sqrt[3]) + 1581408*Zeta[3])), 
      (-165924657234048100796764074066431875212442369246411566621422804693148\
27992327*CF^2*NC)/
        1953711877397034005507561731848592471829815881903429120000000 - 
       (3323638516125410849*CF^2*lm*NC)/5957039088000 - 
       (1870152*CF^2*lm^2*NC)/5 + 
       (1484350147056556715708571163074909093604809709746695387063*CF*NM*NC)/
        677510693428238385053700984324320217600000 - 
       (4994723800800617249*CF*lm*NM*NC)/107226703584000 - 
       (311692*CF*lm^2*NM*NC)/15 + (34735256625964155015513131*CF*NC*NL)/
        14490080588823840000 - (4994723800800617249*CF*lm*NC*NL)/
        107226703584000 - (311692*CF*lm^2*NC*NL)/15 + 
       (47123331133100544641900955774140359165205783659607857516163573*CF*NC*
         NH)/574047093317574779781266301888873618096555174796800000 - 
       (4994723800800617249*CF*lm*NC*NH)/107226703584000 - 
       (311692*CF*lm^2*NC*NH)/15 + (2875425467221357027152026194599637*CF^2*
         NC*Pi^2)/770102185140288000 + (4809*CF^2*lm*NC*Pi^2)/5 - 
       (5323869525613309310122*CF*NM*NC*Pi^2)/4922775 + 
       (1603*CF*lm*NM*NC*Pi^2)/30 - (2251514894347*CF*NC*NL*Pi^2)/
        26254800 + (1603*CF*lm*NC*NL*Pi^2)/30 + (1603*CF*lm*NC*NH*Pi^2)/
        30 - (42699174564294574133167713475*CF^2*NC*Pi^3)/
        (23352323738048311241664*Sqrt[3]) - (1619367213040923006524185*CF*NC*
         NH*Pi^3)/(150094635296999121*Sqrt[3]) - (426892139*CF^2*NC*Pi^4)/
        16200 + (15560107014596955287138097281930339533*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(695426362838144196698943504000*
         Sqrt[3]) + (188658710350437331805292693133*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7512236496614806006050*Sqrt[3]) - 
       (39888866*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (8539834912858914826633542695*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(126131378214767113188*
         Sqrt[3]) - (740282154532993374411056*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (8539834912858914826633542695*CF^2*NC*Pi*Log[3]^2)/
        (6054306154308821433024*Sqrt[3]) - (46267634658312085900691*CF*NC*NH*
         Pi*Log[3]^2)/(5559060566555523*Sqrt[3]) - 
       (CF*NC*(CA*(89182758453995957770023782515669002769 - 
            52714598275654774955034739200*lm) + 
          88*(CF*(-2026880872911715371636564765151254941 + 
              1960460266449970969402118400*lm) + 139230*
             ((4216567530454036897639412971679 + 782262868973788762560*lm)*
               NM + 49097207983824*(20709263 + 15932940*lm)*NL + 
              (244355807377655265763 + 782262868973788762560*lm)*NH)))*
         Log[x]^2)/3980850720536433744000 + 
       (CF*NC*(-2613334317149792133335463*CA + 
          34*(153725545182996867820697*CF - 2162160*(19948798091706797*NM - 
              9028666*NL)))*Log[x]^3)/413513100 + 
       (1381802395215754843775847932007197419*CF^2*NC*PolyGamma[2, 1])/
        540340687069196835600 - (2261888586001907*CF*NM*NC*PolyGamma[2, 1])/
        10 - (52553174481211698673300789*CF*NC*NH*PolyGamma[2, 1])/
        45028390589099736300 - (2770618068227668721958133473920772557959*CF^2*
         NC*Zeta[3])/2298744367964130637851300 + 
       (59438195964419723*CF*NM*NC*Zeta[3])/45 - 
       (39845242*CF*NC*NL*Zeta[3])/15 + (651004159368253582320194531*CF*NC*
         NH*Zeta[3])/22514195294549868150 + 
       CA*CF*NC*(319085879214442160805927329857190603857413061201155345133610\
852588170579151/75142764515270538673367758917253556608839072380901120000000 + 
         (1714306*lm^2)/15 - (191695031144820646178197553442977*Pi^2)/
          102680291352038400 + (42699174564294574133167713475*Pi^3)/
          (46704647476096622483328*Sqrt[3]) + (428277131*Pi^4)/32400 + 
         lm*(7830504889946422049/19495764288000 - (17633*Pi^2)/60) - 
         (15560107014596955287138097281930339533*Im[PolyLog[2, (-1)^(1/3)]])/
          (1390852725676288393397887008000*Sqrt[3]) + 
         (19944433*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (8539834912858914826633542695*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (252262756429534226376*Sqrt[3]) + (8539834912858914826633542695*Pi*
           Log[3]^2)/(12108612308617642866048*Sqrt[3]) - 
         (1381802395215754843775847932007197419*PolyGamma[2, 1])/
          1080681374138393671200 + (69265451838420617464323689789198539867*
           Zeta[3])/114937218398206531892565) + 
       CF*Log[x]*((-361265648132666928377274815241295665017227*NM*NC)/
          51558097471058405603376000 - (3285020524933*lm*NM*NC)/4375800 - 
         124032*lm^2*NM*NC - (38640048437583649333*NC*NL)/8278532262000 - 
         (3285020524933*lm*NC*NL)/4375800 - 124032*lm^2*NC*NL - 
         (23992766747919845930585203721977090665326763649*NC*NH)/
          305792120982458119947847912983956976000 - (3285020524933*lm*NC*NH)/
          4375800 - 124032*lm^2*NC*NH - (7979519231999246*NM*NC*Pi^2)/9 - 
         (19917812*NC*NL*Pi^2)/45 + (740282154532993374411056*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CF*NC*(9165530035388098093477455640509836759949442043801568506281649/
            422797742474127298456142894738899663673100000 - 
           (2877966105733*lm)/243100 - 2232576*lm^2 + 
           (5226668625357280459315883*Pi^2)/1654052400 + 
           (8539834912858914826633542695*Im[PolyLog[2, (-1)^(1/3)]])/
            (378394134644301339564*Sqrt[3]) - 1488384*Zeta[3]) + 
         CA*NC*
          (-73324240254242781334919394838103728957640789955196473886891747/
            6764763879586036775298286315822394618769600000 + 
           (3975779539333*lm)/795600 + 682176*lm^2 - 
           (69688914996601560507847*Pi^2)/44108064 - 
           (8539834912858914826633542695*Im[PolyLog[2, (-1)^(1/3)]])/
            (756788269288602679128*Sqrt[3]) + 744192*Zeta[3])), 
      (1403436339450144664441599332044509435999585896527369151048978836922282\
1685703*CF^2*NC)/
        5861135632191102016522685195545777415489447645710287360000000 + 
       (4692690042311928341*CF^2*lm*NC)/5559903148800 + 
       (1077699*CF^2*lm^2*NC)/2 + 
       (20289961393134216558667800698814954719537679565929201556739*CF*NM*
         NC)/451673795618825590035800656216213478400000 + 
       (6939653316146407541*CF*lm*NM*NC)/100078256678400 + 
       (359233*CF*lm^2*NM*NC)/12 - (214418107449807804918523*CF*NC*NL)/
        55200307005043200 + (6939653316146407541*CF*lm*NC*NL)/
        100078256678400 + (359233*CF*lm^2*NC*NL)/12 - 
       (205204456792335511543633853299841066693286645252987124266780061*CF*NC*
         NH)/1565582981775203944857999005151473503899695931264000000 + 
       (6939653316146407541*CF*lm*NC*NH)/100078256678400 + 
       (359233*CF*lm^2*NC*NH)/12 - (8994452529655269633512318484462821*CF^2*
         NC*Pi^2)/23616467010968832000 - (3249*CF^2*lm*NC*Pi^2)/2 - 
       (86782104648014586960817*CF*NM*NC*Pi^2)/4594590 - 
       (361*CF*lm*NM*NC*Pi^2)/4 + (656131839091*CF*NC*NL*Pi^2)/4900896 - 
       (361*CF*lm*NC*NL*Pi^2)/4 - (361*CF*lm*NC*NH*Pi^2)/4 + 
       (769761262416612140697314411575*CF^2*NC*Pi^3)/
        (280227884856579734899968*Sqrt[3]) + (16071490742427859998669305*CF*
         NC*NH*Pi^3)/(900567811781994726*Sqrt[3]) + (907260887*CF^2*NC*Pi^4)/
        21600 - (268541594061903703698954906869145160009*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8345116354057730360387322048000*
         Sqrt[3]) - (40659791550918161641423867627*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(693437215072135939020*Sqrt[3]) + 
       (40692661*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
       (153952252483322428139462882315*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1513576538577205358256*
         Sqrt[3]) + (3673483598269225142552984*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) + 
       (153952252483322428139462882315*CF^2*NC*Pi*Log[3]^2)/
        (72651673851705857196288*Sqrt[3]) + (459185449783653142819123*CF*NC*
         NH*Pi*Log[3]^2)/(33354363399333138*Sqrt[3]) + 
       CF*((-4043006278614178529316442518190066243*CF*NC)/
          884633493452540832000 + CA*(4043006318764348072786622209116944543/
            1769266986905081664000 - 21474332*lm)*NC + 70279632*CF*lm*NC - 
         (1402703093910031169660478678121*NM*NC)/6188723695440 + 
         3904424*lm*NM*NC + (25164607*NC*NL)/5 + 3904424*lm*NC*NL + 
         (15847460307155093261*NC*NH)/12741489961200 + 3904424*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-264317643322837503359655*CA + 
          8*(66079396348118311533653*CF + 781080300*(2856446346039599*NM + 
              114836*NL)))*Log[x]^3)/275675400 - 
       (415450940220847898885681972632735507*CF^2*NC*PolyGamma[2, 1])/
        405255515301897626700 - (855893190213478303*CF*NM*NC*
         PolyGamma[2, 1])/60 + (112941041062668028105013971*CF*NC*NH*
         PolyGamma[2, 1])/32420441224151810136 - 
       (60218778399479493920467987751109457710277*CF^2*NC*Zeta[3])/
        55169864831139135308431200 + (115298566522090607*CF*NM*NC*Zeta[3])/
        30 + 4273727*CF*NC*NL*Zeta[3] - (653470678740730501674011189*CF*NC*
         NH*Zeta[3])/16210220612075905068 + 
       CA*CF*NC*(-14034363369182868372334883331049881917818379502746625038097\
775097969130868103/
          11722271264382204033045370391091554830978895291420574720000000 - 
         (3951563*lm^2)/24 + (2286919025329241155893474599897*Pi^2)/
          12009390801408000 - (769761262416612140697314411575*Pi^3)/
          (560455769713159469799936*Sqrt[3]) - (910379927*Pi^4)/43200 + 
         lm*(-10752681902047341941/18196046668800 + (3971*Pi^2)/8) + 
         (268541594061903703698954906869145160009*Im[PolyLog[2, (-1)^(1/3)]])/
          (16690232708115460720774644096000*Sqrt[3]) - 
         (40692661*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 - 
         (153952252483322428139462882315*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3027153077154410716512*Sqrt[3]) - 
         (153952252483322428139462882315*Pi*Log[3]^2)/
          (145303347703411714392576*Sqrt[3]) + 
         (415450940220847898885681972632735507*PolyGamma[2, 1])/
          810511030603795253400 + (2408751125772873078306768011894961536317*
           Zeta[3])/4413589186491130824674496) + 
       CF*Log[x]*((-326777861332635824729707465347196884775075501*NM*NC)/
          3127857913244209939938144000 + (4774648774537*lm*NM*NC)/4084080 + 
         184110*lm^2*NM*NC + (519968053694379847*NC*NL)/68987768850 + 
         (4774648774537*lm*NC*NL)/4084080 + 184110*lm^2*NC*NL + 
         (2210745671500232626402360846151672343680292652537*NC*NH)/
          17036989597594095254237240866249031520000 + 
         (4774648774537*lm*NC*NH)/4084080 + 184110*lm^2*NC*NH - 
         (145678763654517017*NM*NC*Pi^2)/9 + (2136322*NC*NL*Pi^2)/3 - 
         (3673483598269225142552984*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CA*NC*
          (-297048927815598713843008783148847305292188127363130564961890277/
            324708666220129765214317743159474941700940800000 - 
           (5731637825737*lm)/742560 - 1012605*lm^2 + 
           (7831633725685945562791*Pi^2)/32672640 + 
           (153952252483322428139462882315*Im[PolyLog[2, (-1)^(1/3)]])/
            (9081459231463232149536*Sqrt[3]) - 1104660*Zeta[3]) + 
         CF*NC*
          (297048925451819376578477632969483677098942933106220504067257967/
            162354333110064882607158871579737470850470400000 + 
           (12632126393811*lm)/680680 + 3313980*lm^2 - 
           (1057270554629673231851489*Pi^2)/2205403200 - 
           (153952252483322428139462882315*Im[PolyLog[2, (-1)^(1/3)]])/
            (4540729615731616074768*Sqrt[3]) + 2209320*Zeta[3])), 
      (-125912493675724728718631551934993731979095088674815333432883174909533\
9395124907*CF^2*NC)/
        13881637023610504775974780726292630720896060213524364800000000 - 
       (824013466833261030289*CF^2*lm*NC)/1125880387632000 - 
       (2453261*CF^2*lm^2*NC)/5 + 
       (64858664855614696601524845872555761524277314529986581284361*CF*NM*
         NC)/2540665100355893943951378691216200816000000 - 
       (1238325233679631223089*CF*lm*NM*NC)/20265846977376000 - 
       (2453261*CF*lm^2*NM*NC)/90 + (127513402529394814455034739*CF*NC*NL)/
        35799022631211840000 - (1238325233679631223089*CF*lm*NC*NL)/
        20265846977376000 - (2453261*CF*lm^2*NC*NL)/90 + 
       (20027593147183713377950608102160065772219266621081760496120159*CF*NC*
         NH)/166658833543812032839722474741931050415128921715200000 - 
       (1238325233679631223089*CF*lm*NC*NH)/20265846977376000 - 
       (2453261*CF*lm^2*NC*NH)/90 + (18356394717758354496434175643875217*
         CF^2*NC*Pi^2)/466114480479648000 + (53789*CF^2*lm*NC*Pi^2)/45 - 
       (385792335747117557456059*CF*NM*NC*Pi^2)/31808700 + 
       (53789*CF*lm*NM*NC*Pi^2)/810 - (65499367151503*CF*NC*NL*Pi^2)/
        551350800 + (53789*CF*lm*NC*NL*Pi^2)/810 + (53789*CF*lm*NC*NH*Pi^2)/
        810 - (12310423052752368895939164199*CF^2*NC*Pi^3)/
        (4636123095053708849448*Sqrt[3]) - (42781041610644955752238895*CF*NC*
         NH*Pi^3)/(2701703435345984178*Sqrt[3]) - (74494516*CF^2*NC*Pi^4)/
        2025 + (7922662426741025406105031342079261*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(246540333464153010909551925*Sqrt[3]) + 
       (201020393768235915425654200501*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5200779113041019542650*Sqrt[3]) - 
       (10997504*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (3517263729357819684554046914*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(35772554745784790505*
         Sqrt[3]) - (9778523796718847029083176*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (1758631864678909842277023457*CF^2*NC*Pi*Log[3]^2)/
        (858541313898834972120*Sqrt[3]) - (1222315474589855878635397*CF*NC*
         NH*Pi*Log[3]^2)/(100063090197999414*Sqrt[3]) - 
       (CF*NC*(-361*CA*(-6514104808443211010979624920692829909 + 
            536521553682661689734592000*lm) + 
          52*(19*CF*(-4760307359675000256113727751501325851 + 
              641574725033112929682624000*lm) + 196350*
             (2*(70931734102642132979221985681177 + 1724516845716145440960*
                 lm)*NM + 31*(993030625995408*(145463 + 112040*lm)*NL + 
                (35755488026739683711 + 111259151336525512320*lm)*NH))))*
         Log[x]^2)/9952126801341084360000 + 
       (CF*NC*(-27656317006701445359557117*CA + 
          320*(172851980816969886118595*CF - 306306*(169452781388863096*NM - 
              9951953*NL)))*Log[x]^3)/413513100 + 
       (389233918600639065624893924449994992693*CF^2*NC*PolyGamma[2, 1])/
        14589198550868314561200 - (1140931307157109363*CF*NM*NC*
         PolyGamma[2, 1])/324 - (2087297226769475534209729721*CF*NC*NH*
         PolyGamma[2, 1])/1215766545905692880100 - 
       (1678536036563832949414658224616511307978469*CF^2*NC*Zeta[3])/
        124132195870063054443970200 + (10562810500726784497*CF*NM*NC*
         Zeta[3])/810 - (524197042*CF*NC*NL*Zeta[3])/135 + 
       (25421861166961553196681671839*CF*NC*NH*Zeta[3])/
        607883272952846440050 + CA*CF*NC*(96855764362529278417800310389596796\
854859298896448224398795951615969793638839/
          2135636465170846888611504727121943187830163109772979200000000 + 
         (26985871*lm^2)/180 - (798104118161604439462946796801239*Pi^2)/
          40531693954752000 + (12310423052752368895939164199*Pi^3)/
          (9272246190107417698896*Sqrt[3]) + (12451612*Pi^4)/675 + 
         lm*(1941399747115895792689/3684699450432000 - (591679*Pi^2)/1620) - 
         (7922662426741025406105031342079261*Im[PolyLog[2, (-1)^(1/3)]])/
          (493080666928306021819103850*Sqrt[3]) + 
         (5498752*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1758631864678909842277023457*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (35772554745784790505*Sqrt[3]) + (1758631864678909842277023457*Pi*
           Log[3]^2)/(1717082627797669944240*Sqrt[3]) - 
         (389233918600639065624893924449994992693*PolyGamma[2, 1])/
          29178397101736629122400 + 
         (1678536036979716961103186415457403635970993*Zeta[3])/
          248264391740126108887940400) + CF*Log[x]*
        ((-764579106166428254036630843007968854356526993*NM*NC)/
          10053829006856389092658320000 - (287504503302871*lm*NM*NC)/
          275675400 - 171836*lm^2*NM*NC - (29799118781560449329*NC*NL)/
          4382752374000 - (287504503302871*lm*NC*NL)/275675400 - 
         171836*lm^2*NC*NL - 
         (132881598840147111450218573195921898137361252541*NC*NH)/
          1154118650159600001093490510294289232000 - 
         (287504503302871*lm*NC*NH)/275675400 - 171836*lm^2*NC*NH - 
         (90374816733461401*NM*NC*Pi^2)/9 - (87348244*NC*NL*Pi^2)/135 + 
         (9778523796718847029083176*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CF*NC*
          (21699580396744729315456626795388921190546321085556341275284646303/
            96130855130959469964765121330107713003568000000 - 
           (251976284777071*lm)/15315300 - 3093048*lm^2 + 
           (27656317000120642020511901*Pi^2)/827026200 + 
           (3517263729357819684554046914*Im[PolyLog[2, (-1)^(1/3)]])/
            (107317664237354371515*Sqrt[3]) - 2062032*Zeta[3]) + 
         CA*NC*
          (-10849790197790809240161341115049842882896901326487667970934554089/
            96130855130959469964765121330107713003568000000 + 
           (347794813528471*lm)/50122800 + 945098*lm^2 - 
           (27656316999674808309421133*Pi^2)/1654052400 - 
           (1758631864678909842277023457*Im[PolyLog[2, (-1)^(1/3)]])/
            (107317664237354371515*Sqrt[3]) + 1031016*Zeta[3])), 
      (4245879946349053057166483099994249963315396875490046802986748827682535\
626743*CF^2*NC)/
        304328196286845681627139423614876904265798243142649536000000 + 
       (4947117661027718861*CF^2*lm*NC)/4503521550528 + 701480*CF^2*lm^2*NC + 
       (67486362050309781128702080209978044810270193455426701514761*CF*NM*
         NC)/145180862877479653940078782355211475200000 + 
       (7316465383976004941*CF*lm*NM*NC)/81063387909504 + 
       (350740*CF*lm^2*NM*NC)/9 - (944296202913435122436064097*CF*NC*NL)/
        165534680646723548160 + (7316465383976004941*CF*lm*NC*NL)/
        81063387909504 + (350740*CF*lm^2*NC*NL)/9 - 
       (223467000192453963193020298103192041020708592191447072194259256961189*
         CF*NC*NH)/
        1177626900421512170470549520577873172786514775393783571200000 + 
       (7316465383976004941*CF*lm*NC*NH)/81063387909504 + 
       (350740*CF*lm^2*NC*NH)/9 + (2252260156066186285170238048993*CF^2*NC*
         Pi^2)/23356945395463680 - (18050*CF^2*lm*NC*Pi^2)/9 - 
       (1782152426185732878711449*CF*NM*NC*Pi^2)/9189180 - 
       (9025*CF*lm*NM*NC*Pi^2)/81 + (2026344081785*CF*NC*NL*Pi^2)/
        11027016 - (9025*CF*lm*NC*NL*Pi^2)/81 - (9025*CF*lm*NC*NH*Pi^2)/
        81 + (574436403427268108131174570385*CF^2*NC*Pi^3)/
        (145502940213993323890368*Sqrt[3]) + (314602166937321402085149665*CF*
         NC*NH*Pi^3)/(12157665459056928801*Sqrt[3]) + 
       (37576357*CF^2*NC*Pi^4)/648 - (7938998677477609397436925803854713487*
         CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(173321647353506707484967457920*
         Sqrt[3]) - (12871900842974524238782338325801*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(147776423654836969576155*Sqrt[3]) + 
       (50059490*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (114887280685453621626234914077*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(785895510415087397556*
         Sqrt[3]) + (143818133457061212381782704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) + (114887280685453621626234914077*CF^2*NC*Pi*Log[3]^2)/
        (37722984499924195082688*Sqrt[3]) + (8988633341066325773861419*CF*NC*
         NH*Pi*Log[3]^2)/(450283905890997363*Sqrt[3]) + 
       CF*((3937076623225581359213148362806417*CF*NC)/3402436513279003200 + 
         CA*(-153545979557986911876136323736591819/265390048035762249600 - 
           (280797770*lm)/9)*NC + 102108280*CF*lm*NC - 
         (226845926547953697341805495054437*NM*NC)/97472398203180 + 
         (51054140*lm*NM*NC)/9 + (197254732*NC*NL)/27 + 
         (51054140*lm*NC*NL)/9 + (956169775568844450967*NC*NH)/
          515211247645380 + (51054140*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-114674021766906875658497*CA + 
          208*(1102634696890780361482*CF + 58905*(2248643367417664856*NM + 
              12763535*NL)))*Log[x]^3)/41351310 - 
       (78422042250592990700871275639947934627*CF^2*NC*PolyGamma[2, 1])/
        10941898913151235920900 - (465945645293670344227*CF*NM*NC*
         PolyGamma[2, 1])/3240 + (21966412587443412518951235991*CF*NC*NH*
         PolyGamma[2, 1])/4376759565260494368360 - 
       (331178019011898389576561974105487580565247*CF^2*NC*Zeta[3])/
        28645891354629935640916200 + (73728762814233494333*CF*NM*NC*Zeta[3])/
        1620 + (166844320*CF*NC*NL*Zeta[3])/27 - 
       (126394373094102006531321361769*CF*NC*NH*Zeta[3])/
        2188379782630247184180 + CA*CF*NC*
        (-5519643927765173632899373862180612573880964560104570011210336633731\
7777757659/7912533103457987722305625013986799510910754321708887936000000 - 
         (1929070*lm^2)/9 - (592700042160619079036916029207*Pi^2)/
          12293129155507200 - (574436403427268108131174570385*Pi^3)/
          (291005880427986647780736*Sqrt[3]) - (12563959*Pi^4)/432 + 
         lm*(-11337176671403399501/14738797801728 + (99275*Pi^2)/162) + 
         (7938998677477609397436925803854713487*Im[PolyLog[2, (-1)^(1/3)]])/
          (346643294707013414969934915840*Sqrt[3]) - 
         (25029745*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
         (114887280685453621626234914077*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1571791020830174795112*Sqrt[3]) - 
         (114887280685453621626234914077*Pi*Log[3]^2)/
          (75445968999848390165376*Sqrt[3]) + 
         (78422042250592990700871275639947934627*PolyGamma[2, 1])/
          21883797826302471841800 + 
         (331178018821435419810977745496440718019567*Zeta[3])/
          57291782709259871281832400) + CF*Log[x]*
        ((-3741699946714067798927833930127626392010524169*NM*NC)/
          3518840152399736182430412000 + (8868965073037*lm*NM*NC)/5513508 + 
         252700*lm^2*NM*NC + (2200733096194895680129*NC*NL)/
          202658469773760 + (8868965073037*lm*NC*NL)/5513508 + 
         252700*lm^2*NC*NL + 
         (41464515896592354015032851339490593939013544620085463*NC*NH)/
          220408386273554690008829896948707033225816000 + 
         (8868965073037*lm*NC*NH)/5513508 + 252700*lm^2*NC*NH - 
         (4497286734865333334*NM*NC*Pi^2)/27 + (27801370*NC*NL*Pi^2)/27 - 
         (143818133457061212381782704*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CA*NC*
          (-8378736446858415701130331576060705849605648889049392980125838827/
            438356699397175183039328953265291171296270080000 - 
           (10642209491437*lm)/1002456 - 1389850*lm^2 + 
           (35284314048909805513411*Pi^2)/50893920 + 
           (114887280685453621626234914077*Im[PolyLog[2, (-1)^(1/3)]])/
            (4715373062490524385336*Sqrt[3]) - 1516200*Zeta[3]) + 
         CF*NC*
          (644518187873918413690269752490175488467954272811834232881740049/
            16859873053737507039974190510203506588318080000 + 
           (7824017469337*lm)/306306 + 4548600*lm^2 - 
           (35284314076544963960923*Pi^2)/25446960 - 
           (114887280685453621626234914077*Im[PolyLog[2, (-1)^(1/3)]])/
            (2357686531245262192668*Sqrt[3]) + 3032400*Zeta[3])), 
      (-108299648685318367209708279852034898669960597318804653655270669351446\
1337463132133*CF^2*NC)/
        1127535967242763250428551564493118930304782490843516530880000000 - 
       (3847655615583506515121*CF^2*lm*NC)/4064428199351520 - 
       634672*CF^2*lm^2*NC + 
       (3499603430323896935868006715113603384378966003515642914543*CF*NM*NC)/
        12098405239789971161673231862934289600000 - 
       (5782339696187627441201*CF*lm*NM*NC)/73159707588327360 - 
       (317336*CF*lm^2*NM*NC)/9 + (4422683705526176266039459697*CF*NC*NL)/
        853685995906674298368 - (5782339696187627441201*CF*lm*NC*NL)/
        73159707588327360 - (317336*CF*lm^2*NC*NL)/9 + 
       (20052492664926319087783206780409107390105748269347779035199712793761*
         CF*NC*NH)/
        116213180962649227349067386899132220998669221255965484000000 - 
       (5782339696187627441201*CF*lm*NC*NH)/73159707588327360 - 
       (317336*CF*lm^2*NC*NH)/9 + (2775224900831686907032424624598178303*
         CF^2*NC*Pi^2)/6730693098126117120 + (13220*CF^2*lm*NC*Pi^2)/9 - 
       (1164879368252499803074781*CF*NM*NC*Pi^2)/8729721 + 
       (6610*CF*lm*NM*NC*Pi^2)/81 - (50854861190729*CF*NC*NL*Pi^2)/
        314269956 + (6610*CF*lm*NC*NL*Pi^2)/81 + (6610*CF*lm*NC*NH*Pi^2)/
        81 - (203891730733489357924134813892891*CF^2*NC*Pi^3)/
        (53908839349284526501381344*Sqrt[3]) - 
       (831302942548510605067210085*CF*NC*NH*Pi^3)/(36472996377170786403*
         Sqrt[3]) - (27246301*CF^2*NC*Pi^4)/540 + 
       (39520878354518477259118400678112924861401*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(871498383246436048100306014305600*
         Sqrt[3]) + (180144116694871574808461383236688*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3103304896751576361099255*Sqrt[3]) - 
       (14914004*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (29127390104784193989162116270413*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(207981633291992771996070*
         Sqrt[3]) - (380024202307890562316438896*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) - (29127390104784193989162116270413*CF^2*NC*Pi*Log[3]^2)/
        (9983118398015653055811360*Sqrt[3]) - 
       (23751512644243160144777431*CF*NC*NH*Pi*Log[3]^2)/
        (1350851717672992089*Sqrt[3]) + 
       CF*((31186589821955423615480952949382765182681*CF*NC)/
          6303013640849353428000 - 91740208*CF*lm*NC + 
         CA*(-1155058882306033141960041012206074004563/
            466889899322174328000 + (252285572*lm)/9)*NC - 
         (765091398627518945099681411713*NM*NC)/477805873545 - 
         (45870104*lm*NM*NC)/9 - (178484480*NC*NL)/27 - 
         (45870104*lm*NC*NL)/9 - (688704229951159906511*NC*NH)/
          409827128808825 - (45870104*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-91979303621799252235284145*CA + 
          912*(201708999090690536526633*CF - 85085*(751579967238132392*NM - 
              5733763*NL)))*Log[x]^3)/130945815 + 
       (727341073544910170661589992884014742233*CF^2*NC*PolyGamma[2, 1])/
        2626055739156296621016 - (379664547194551508567*CF*NM*NC*
         PolyGamma[2, 1])/8100 - (81222258799196177564132921689*CF*NC*NH*
         PolyGamma[2, 1])/32825696739453707762700 - 
       (6061044496942200364274086613490845283200926*CF^2*NC*Zeta[3])/
        40820395180347658288305585 + (522231413658946324633*CF*NM*NC*
         Zeta[3])/4050 - (150277072*CF*NC*NL*Zeta[3])/27 + 
       (974426374090861863395240958311*CF*NC*NH*Zeta[3])/
        16412848369726853881350 + CA*CF*NC*(108299648684799647263655883688296\
9760700643050771675256158142289896580362576367883/
          2255071934485526500857103128986237860609564981687033061760000000 + 
         (1745348*lm^2)/9 - (13876124504154330093597898165339860179*Pi^2)/
          67306930981261171200 + (203891730733489357924134813892891*Pi^3)/
          (107817678698569053002762688*Sqrt[3]) + (81950423*Pi^4)/3240 + 
         lm*(9065439954182499315761/13301765016059520 - (36355*Pi^2)/81) - 
         (39520878354518477259118400678112924861401*
           Im[PolyLog[2, (-1)^(1/3)]])/(1742996766492872096200612028611200*
           Sqrt[3]) + (7457002*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (29127390104784193989162116270413*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(415963266583985543992140*Sqrt[3]) + 
         (29127390104784193989162116270413*Pi*Log[3]^2)/
          (19966236796031306111622720*Sqrt[3]) - 
         (727341073544910170661589992884014742233*PolyGamma[2, 1])/
          5252111478312593242032 + 
         (6061044497136951954236062288871986040982877*Zeta[3])/
          81640790360695316576611170) + CF*Log[x]*
        ((-477638608973373047504436317680349021220804899*NM*NC)/
          586473358733289363738402000 - (74596212362267*lm*NM*NC)/52378326 - 
         234080*lm^2*NM*NC - (18704909581423318020461*NC*NL)/
          1925255462850720 - (74596212362267*lm*NC*NL)/52378326 - 
         234080*lm^2*NC*NL - 
         (273909479836820581340526533536737139463233415134068037*NC*NH)/
          1653062897051660175066224227115302749193620000 - 
         (74596212362267*lm*NC*NH)/52378326 - 234080*lm^2*NC*NH - 
         (3006319868919631904*NM*NC*Pi^2)/27 - (25041772*NC*NL*Pi^2)/27 + 
         (380024202307890562316438896*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1350851717672992089*Sqrt[3]) + CF*NC*(7293295623836925899824529126\
6040285288968804412217671747229060388503/
            31232914832048731791552187920151995954859243200000 - 
           (65400673449707*lm)/2909907 - 4213440*lm^2 + 
           (28301324190398162453162009*Pi^2)/80582040 + 
           (29127390104784193989162116270413*Im[PolyLog[2, (-1)^(1/3)]])/
            (623944899875978315988210*Sqrt[3]) - 2808960*Zeta[3]) + 
         CA*NC*
          (
           -56102274029109790567194913607084011408165507583997535121792879931\
31/4805063820315189506392644295407999377670652800000 + (90200763244187*lm)/
            9523332 + 1287440*lm^2 - (28301324190336085734532853*Pi^2)/
            161164080 - (29127390104784193989162116270413*
             Im[PolyLog[2, (-1)^(1/3)]])/(1247889799751956631976420*
             Sqrt[3]) + 1404480*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["v", 2, 2, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-2*CA*(21334298402 + 1417144320*lm + 821145600*lm^2 - 
           17988837075*Zeta[3]) + 20*CF*(-16298963014 - 79792128*lm + 
           268738560*lm^2 + 13592100105*Zeta[3]) + 
         3*(1024*(290179 + 44040*lm + 97200*lm^2)*NL + 
           15*NM*(-27381950 + 3006464*lm + 6635520*lm^2 + 
             22369725*Zeta[3]) + 15*NH*(-27381950 + 3006464*lm + 
             6635520*lm^2 + 22369725*Zeta[3]))))/125411328000, 
      -(CF*NC*(-8*CA*(22042870562 + 2238289920*lm + 821145600*lm^2 - 
            17988837075*Zeta[3]) + 80*CF*(-16338859078 + 188946432*lm + 
            268738560*lm^2 + 13592100105*Zeta[3]) + 
          3*(4096*(312199 + 141240*lm + 97200*lm^2)*NL + 
            15*NM*(-32228334 + 38567936*lm + 26542080*lm^2 + 
              52798725*Zeta[3]) + 15*NH*(-174801410 + 38567936*lm + 
              26542080*lm^2 + 126159075*Zeta[3]))))/250822656000, 
      (CF*NC*(3091978458310*NM + 7864745656320*lm*NM + 
         3554869248000*lm^2*NM + 13993935798272*NL + 7864745656320*lm*NL + 
         3554869248000*lm^2*NL - 38824505885690*NH + 7864745656320*lm*NH + 
         3554869248000*lm^2*NH - 4*CA*(769567357350874 + 17035046461440*lm + 
           4887945216000*lm^2 - 633452472577575*Zeta[3]) + 
         7123911960375*NM*Zeta[3] + 28691854860375*NH*Zeta[3] + 
         2520*CF*(-18599218614802 + 37132812288*lm + 25391923200*lm^2 + 
           15478528542715*Zeta[3])))/655483207680000, 
      -(CF*NC*(-2*CA*(6040203746606186 + 47691726888960*lm + 
            11802599424000*lm^2 - 4995909839858175*Zeta[3]) + 
          140*CF*(-1415213767294066 + 1113582256128*lm + 551809843200*lm^2 + 
            1177645051371915*Zeta[3]) + 
          3*(16384*(439043327 + 241700970*lm + 87318000*lm^2)*NL + 
            210*NM*(-513875186 + 18857279488*lm + 6812467200*lm^2 + 
              36328819275*Zeta[3]) + 35*NH*(-731111582894 + 
              113143676928*lm + 40874803200*lm^2 + 565365759525*Zeta[3]))))/
       983224811520000, (CF*NC*(-23107234878471870*NM + 
         5919972725882880*lm*NM + 1910265348096000*lm^2*NM + 
         12714111327797248*NL + 5919972725882880*lm*NL + 
         1910265348096000*lm^2*NL - 60718419223424550*NH + 
         5919972725882880*lm*NH + 1910265348096000*lm^2*NH - 
         2*CA*(12369678802435528334 + 22965853714513920*lm + 
           5253229707264000*lm^2 - 10271295062396731125*Zeta[3]) + 
         37557175390552125*NM*Zeta[3] + 48989829950609625*NH*Zeta[3] + 
         756*CF*(-697434517932372826 + 106839850352640*lm + 
           45482508288000*lm^2 + 580241765464201575*Zeta[3])))/
       778714050723840000, -(CF*NC*(-15542494230657870*NM + 
          282273504952320*lm*NM + 107686526976000*lm^2*NM + 
          1329080864899072*NL + 282273504952320*lm*NL + 
          107686526976000*lm^2*NL - 10709713037487870*NH + 
          282273504952320*lm*NH + 107686526976000*lm^2*NH - 
          10*CA*(1391295126849875710 + 230630996606976*lm + 
            59227589836800*lm^2 - 1157077676870601885*Zeta[3]) + 
          16110434411119125*NM*Zeta[3] + 9021540699604125*NH*Zeta[3] + 
          252*CF*(-1375164948216555638 + 14393472122880*lm + 
            7691894784000*lm^2 + 1144015388108723025*Zeta[3])))/
       194678512680960000, 
      -(CF*NC*(154*CF*(2072639872648135441511854 + 26314966868085964800*lm + 
            7199131938324480000*lm^2 - 1724230266639016835593125*Zeta[3]) - 
          363*CA*(-30312885739507181238398 + 5298850586256998400*lm + 
            933220806819840000*lm^2 + 25221152097734402620125*Zeta[3]) + 
          15*(262144*(55814992769479 + 69003700490340*lm + 15663801384000*lm^
                2)*NL + 3465*NH*(20751308629469066 + 5220463509766144*lm + 
              1185042294374400*lm^2 - 20174035650944175*Zeta[3]) + 
            3465*NM*(5220463509766144*lm + 1185042294374400*lm^2 - 
              275*(-758958379373902 + 658273339320597*Zeta[3])))))/
       73495032107316019200000, 
      (CF*NC*(770*CF*(186105108741827618822198 + 1832357767739867136*lm + 
           547324732794470400*lm^2 - 154821244098108366677745*Zeta[3]) - 
         363*CA*(-11940371278301508752606 + 1905196761352765440*lm + 
           354747511996416000*lm^2 + 9935096415055102082925*Zeta[3]) + 
         3*(262144*(192547655233121 + 121999353080220*lm + 29771596008000*
              lm^2)*NL + 231*NM*(5085875067284608646 + 138447612181217280*
              lm + 33785477332992000*lm^2 - 4117328364664139625*Zeta[3]) + 
           693*NH*(-240288301122346158 + 46149204060405760*lm + 
             11261825777664000*lm^2 + 182780269283737125*Zeta[3]))))/
       14699006421463203840000, 
      -(CF*NC*(-11*CA*(-7770366118796198995256606246 + 
            723181055684965407129600*lm + 139901766692272865280000*lm^2 + 
            6465013987925983057344401625*Zeta[3]) + 
          2*(117*CF*(13593781118117115187184178982 + 67722759491350324838400*
               lm + 21523348721888133120000*lm^2 - 
              11308733870222753202334721625*Zeta[3]) + 
            35*(4194304*(7328046731541667 + 3713364340325640*lm + 
                953005155102000*lm^2)*NL + 1001*NM*(835020431245003216642 + 
                15559419486598594560*lm + 3993200133931008000*lm^2 - 
                666947267667866059875*Zeta[3]) + 9009*NH*(
                -19809180798940509262 + 1728824387399843840*lm + 
                443688903770112000*lm^2 + 15979114143907039125*Zeta[3])))))/
       154568218636364179046400000, 
      (CF*NC*(104*CF*(1103830148102540483979080353826 + 
           2270568239161639383859200*lm + 805772806558391992320000*lm^2 - 
           918283583632433760091204729875*Zeta[3]) - 
         132*CA*(-20983087230774467244345140614 + 938991654035571238502400*
            lm + 193982342319612887040000*lm^2 + 
           17457102860916224309670491625*Zeta[3]) + 
         105*(16777216*(22232731883281561 + 9429182822879820*lm + 
             2642799681522000*lm^2)*NL + 429*NM*(37441308048675544686446 + 
             368753932221315809280*lm + 103353895341785088000*lm^2 - 
             30187639695819477997125*Zeta[3]) + 1287*NH*
            (-2441626662405363942938 + 122917977407105269760*lm + 
             34451298447261696000*lm^2 + 2003201658583368618375*Zeta[3]))))/
       2782227935454555222835200000, 
      -(CF*NC*(-440*CA*(-3401479304298675369671213457998 + 
            63300754390870967199989760*lm + 14686076386377310666752000*lm^2 + 
            2829794917471631672895273266325*Zeta[3]) + 
          3*(48*CF*(475732176686892464433860499622606 + 
              335948271547895888058777600*lm + 146860763863773106667520000*lm^
                2 - 395765061241657382026323518071125*Zeta[3]) + 
            5*(536870912*(1268988096452336003 + 443154418911264060*lm + 
                145893061025712000*lm^2)*NL + 143*NM*(
                400829404811060237148904898 + 1663753265998044636119040*lm + 
                547732452638780817408000*lm^2 - 327430705776791598570463875*
                 Zeta[3]) + 143*NH*(-57800011503347119630949182 + 
                1663753265998044636119040*lm + 547732452638780817408000*
                 lm^2 + 47805105586860257374864125*Zeta[3])))))/
       864875426792730309269913600000, 
      (CF*NC*(8*CF*(7916816963172848531867450698295794 + 
           1413578589182217510558105600*lm + 968518678487334251397120000*
            lm^2 - 6586059218227438345391614220476875*Zeta[3]) - 
         484*CA*(-2606175968921702181195849273086 + 
           17033473405577401152307200*lm + 4891508477208758845440000*lm^2 + 
           2168118070086978586789714900125*Zeta[3]) + 
         15*(268435456*(898182138024645937 + 236207423171259540*lm + 
             106904095906608000*lm^2)*NL + 1001*NM*
            (47816417365405923961749238 + 63343104245316704010240*lm + 
             28668181551406645248000*lm^2 - 39432054381794579973092625*
              Zeta[3]) + 286*NH*(-15588815800873411388851702 + 
             221700864858608464035840*lm + 100338635429923258368000*lm^2 + 
             12949303475130407036276625*Zeta[3]))))/
       432437713396365154634956800000, 
      -(CF*NC*(34*CF*(439223875148729369093552252627103813442 + 
            2915472556060673579732592230400*lm + 
            19963847763709117408582041600000*lm^2 - 
            365393630606552282986212102320055751875*Zeta[3]) - 
          25*CA*(-10904550229846238344768256385038466382 + 
            17992263965791821376013671071744*lm + 
            8296087848474677678677426176000*lm^2 + 
            9071592552995606953712486740045964565*Zeta[3]) + 
          135*(4294967296*(465590126133508423297 + 58275132443925016620*lm + 
              65036480591562480000*lm^2)*NL + 2431*NM*
             (486312390258804362822328614734 + 102957543404659193854033920*
               lm + 114903149809831174471680000*lm^2 - 
              403145727430440827758335535125*Zeta[3]) + 
            7293*NH*(-8926630808048286394541828062 + 
              34319181134886397951344640*lm + 38301049936610391490560000*lm^
                2 + 7432782045845164687880326125*Zeta[3]))))/
       56988371622226585538413146931200000, 
      (CF*NC*(CA*(109031779454250796002976485604451505788 + 
           2738929382274232435384044748800*lm - 
           30768339313383428705715486720000*lm^2 - 
           90704260944608867936080460801311520250*Zeta[3]) + 
         5*(68*CF*(19080204533971791090944802325846539194 - 
             625426733723887273643417272320*lm + 
             296165832963049046365175808000*lm^2 - 
             15872964353455792458310249621486454775*Zeta[3]) + 
           9*(2147483648*(234866170344191673799 - 78830593242910268760*lm + 
               57889391890874544000*lm^2)*NL + 2431*NM*
              (617611973506613232027770648314 - 69636943624553308964782080*
                lm + 51138018296304764977152000*lm^2 - 
               513226420000697656499227356375*Zeta[3]) + 
             7293*NH*(-23212314541517769654927360*lm + 
               17046006098768254992384000*lm^2 + 41327*
                (-152364190761171633261466 + 127020695004894734418375*
                  Zeta[3]))))))/14247092905556646384603286732800000, 
      -(CF*NC*(-2*CA*(-766105678462816664098296905429059632468766 - 
            331240981669889589299891835135590400*lm + 
            68947196178760117800420727848960000*lm^2 + 
            637328037260804097182538317625714159442125*Zeta[3]) + 
          5*(76*CF*(259610496841500567947187834797024106116702 - 
              8107791773834846964806183980892160*lm + 
              1187607206906872842495285264384000*lm^2 - 
              215971898259653471847385409278196145617325*Zeta[3]) + 
            7*(34359738368*(-81326558077299144461497 - 
                126693723912180048744120*lm + 20848078005753686688000*lm^2)*
               NL + 264537*NM*(-16455782013442852543717703680*lm + 
                2707880204861141818540032000*lm^2 + 323*
                 (343841894306485113159140948378 - 
                  285993149384608028892812658375*Zeta[3])) + 
              4199*NH*(-1036714266846899710254215331840*lm + 
                170596452906251934568022016000*lm^2 + 4199*
                 (-27029538742302165912224880962 + 
                  22544956003519881257370919875*Zeta[3]))))))/
       128008546746103628138284464262348800000, 
      (CF*NC*(CA*(7042068132247026505090828782444793381644308 + 
           2923077140143527074776372226713190400*lm - 
           134861973856734903480949281914880000*lm^2 - 
           5858341011381696180492724539241173321174750*Zeta[3]) + 
         3*(76*CF*(2145141606511408358816344113378470542843814 - 
             45873676546182448140484405415116800*lm + 
             1935817806556003399248075816960000*lm^2 - 
             1784559167254605329572189786520618087033625*Zeta[3]) + 
           35*(34359738368*(-243697261335299836254647 - 
               155962244281183740920520*lm + 6796536834955611744000*lm^2)*
              NL + 4199*NM*(11835399842774207297254328179077802 - 
               1276213838720547169174699376640*lm + 
               55614962480959660970999808000*lm^2 - 
               9846908131985093561294671338945375*Zeta[3]) + 
             37791*NH*(-141801537635616352130522152960*lm + 
               6179440275662184552333312000*lm^2 + 12597*
                (-866892247264221610633879966 + 723108672251363912791402125*
                  Zeta[3]))))))/384025640238310884414853392787046400000, 
      (CF*NC*(-196*CA*(109304667193775586698564968001779404623428286 + 
           32673563981158132796936706226284134400*lm + 
           368499581802581866220407593369600000*lm^2 - 
           90931276163853002919783748601187963068824125*Zeta[3]) + 
         3*(8*CF*(-66692959018591712450421821045213559712911092534 + 
             853353437195899274276136460031203737600*lm + 
             9848988822723551697163621131878400000*lm^2 + 
             55482364990743309380064185624674548216328352625*Zeta[3]) + 
           385*(274877906944*(7569848573978656477181819 + 
               3614839283040478164912240*lm + 41362669677750581160000*lm^2)*
              NL + 4199*NM*(-3675545632742176319579562453776324602 + 
               236637165053850020100026337853440*lm + 
               2707712328324871330159656960000*lm^2 + 
               3058117589856352367631598177952460375*Zeta[3]) + 
             4199*NH*(236637165053850020100026337853440*lm + 
               2707712328324871330159656960000*lm^2 - 4199*
                (-3619262733543178579554639428042 + 
                 3018350488732936475075549967375*Zeta[3]))))))/
       777267895842341230055663267000981913600000, 
      -(CF*NC*(-40*CA*(263667426313297043809415601932909143072025438 + 
            50194440764095719610259240144716431360*lm + 
            2159454169670356583930602796875776000*lm^2 - 
            219346746237609052511624327969235222685006125*Zeta[3]) + 
          16*CF*(-52848617322687301779289651497855497445103871786 + 
            374943713898263416155666244979549798400*lm + 
            17668261388212008413977659247165440000*lm^2 + 
            43965154584898253103963030216675076060349817375*Zeta[3]) + 
          385*(6597069766656*(341305991684415858676586 + 
              135858090945694557745305*lm + 6183430542421557925500*lm^2)*
             NL + 20995*NM*(-1237537451331512598660072714760587398 + 
              42689464364536452604556721782784*lm + 
              1942963690670472524542142054400*lm^2 + 
              1029619971622573417985007056728005225*Zeta[3]) + 
            440895*NH*(2032831636406497743074129608704*lm + 
              92522080508117739263911526400*lm^2 - 1356277*(
                -87511595267120572014170542 + 72955710989740780615138725*
                 Zeta[3])))))/259089298614113743351887755666993971200000, 
      (CF*NC*(-68*CA*(34334166881809514887519936441167884658283532937446 + 
           3881349582133861315920782380003459124428800*lm + 
           254232063234472637981741511543474880512000*lm^2 - 
           28562836169452634426423201431945609695306572645625*Zeta[3]) + 
         5*(184*CF*(-217851211048888139452854889849126678863361258457054 + 
             814493977070116437922433805946668680478720*lm + 
             61498032687548321914950911092729892044800*lm^2 + 
             181232028815041244193883809512621379499824747756525*Zeta[3]) + 
           693*(37145*NM*(341760521956814269525525832512045056*lm + 
               24421534202925941081640886169763840*lm^2 + 23*
                (-864330903753702820758696017055807829802 + 
                 719088610806446798093423814344248646175*Zeta[3])) + 
             3*(1099511627776*(11159697733392386412898525943 + 
                 3848585822829853605534074040*lm + 
                 275012367628030940212905600*lm^2)*NL + 37145*NH*
                (113920173985604756508508610837348352*lm + 
                 8140511400975313693880295389921280*lm^2 - 7429*
                  (-860137973299629553033964118803302 + 
                   716758451436662785965297638180025*Zeta[3])))))))/
       39472772822457457027146803351377865500262400000, 
      -(CF*NC*(-34*CA*(286349020313252464026250483150481050828800*lm + 
            24216543913182043070583278472655798272000*lm^2 - 
            563*(-7934825796457833911501631219639939264196763458 + 
              6601038659693262180399639037476929620586695875*Zeta[3])) + 
          5*(92*CF*(-30287615293983675159773868458822981496304238798366 + 
              57418071372009188190175556938802890014720*lm + 
              5857914970303324252647022302476422348800*lm^2 + 
              25196490458151248790948357968265129940110210696525*Zeta[3]) + 
            63*(549755813888*(30075467298535564437049530679 + 
                9121668355716577131057907320*lm + 864466176122225427339388800*
                 lm^2)*NL + 4754560*NM*(
                -130016214752258320877984720486708525938 + 
                1054711731666732896027869641179136*lm + 
                99955685958894449028464105226240*lm^2 + 
                108165317724955540349204600945393419275*Zeta[3]) + 
              111435*NH*(45001033884447270230522438023643136*lm + 
                4264775934246163158547801822986240*lm^2 - 7429*
                 (-340215556245425357524574843754818 + 
                  283374117138326899152505045083075*Zeta[3]))))))/
       1794216946475338955779400152335357522739200000}, 0, 20, 1]
 
CbarSeries["v", 2, 3, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(7*CA*(96552063 + 24057000*lm^2 - 8795304*Pi^2 + 218700*Pi^4 - 
            10800*lm*(-9721 + 165*Pi^2) - 2579424*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 17496000*Im[PolyLog[2, (-1)^(1/3)]]^
              2 + 429904*PolyGamma[2, 1] + 10832528*Zeta[3]) + 
          CF*(-826686000*lm^2 + 57854196*Pi^2 + 567000*Pi^4 + 
            1020600*lm*(-1649 + 60*Pi^2) + 7*(-135929601 + 5158848*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 34992000*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 859808*PolyGamma[2, 1] + 18964544*Zeta[3])) + 
          70*(45*NL*(-31739 - 9720*lm^2 - 540*Pi^2 + 48*lm*(-626 + 
                15*Pi^2) - 8640*Zeta[3]) + 45*NM*(-31739 - 9720*lm^2 - 
              540*Pi^2 + 48*lm*(-626 + 15*Pi^2) + 720*PolyGamma[2, 1] - 
              7200*Zeta[3]) + NH*(-9179019 - 437400*lm^2 + 2160*lm*(-626 + 
                15*Pi^2) - 67222128*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              11203688*PolyGamma[2, 1] + 128731216*Zeta[3]))))/4408992000, 
      (CF*NC*(2*(CF*(2976069600*lm^2 - 191983338*Pi^2 + 11430720*Pi^4 - 
             73483200*lm*(-20 + 3*Pi^2) - 35*(-103642947 + 218734296*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 55987200*Im[PolyLog[2, 
                   (-1)^(1/3)]]^2 - 38869516*PolyGamma[2, 1] - 293691512*
                Zeta[3])) - 140*(NH*(255014199 - 787320*lm^2 + 4860*lm*
                (-251 + 12*Pi^2) - 12081552*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 2013592*PolyGamma[2, 1] - 189906256*
                Zeta[3]) + 27*NL*(60625 - 29160*lm^2 - 1068*Pi^2 + 180*lm*
                (-251 + 12*Pi^2) - 25920*Zeta[3]) + 27*NM*(60625 - 29160*
                lm^2 - 1068*Pi^2 + 180*lm*(-251 + 12*Pi^2) + 2160*
                PolyGamma[2, 1] - 21600*Zeta[3]))) - 
         7*CA*(173210400*lm^2 - 102625542*Pi^2 + 3499200*Pi^4 - 
           97200*lm*(-5029 + 132*Pi^2) - 5*(20672757 + 218734296*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 55987200*Im[PolyLog[2, 
                 (-1)^(1/3)]]^2 - 38869516*PolyGamma[2, 1] - 
             335619704*Zeta[3]))))/8817984000, 
      -(CF*NC*(-70*(NH*(4482794421 - 19683000*lm^2 + 3240*lm*(-8599 + 
                42*Pi^2) + 354155472*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              81433288*PolyGamma[2, 1] - 4396587536*Zeta[3]) + 
            27*NM*(1956395 - 729000*lm^2 - 416052*Pi^2 + 120*lm*(-8599 + 
                42*Pi^2) - 16560*PolyGamma[2, 1] - 93600*Zeta[3]) + 
            27*NL*(1058195 - 729000*lm^2 - 217332*Pi^2 + 120*lm*(-8599 + 
                42*Pi^2) - 60480*Zeta[3])) + 7*CA*(-202561209 - 
            1082565000*lm^2 + 12377043*Pi^2 + 17330760*Pi^4 + 
            16200*lm*(-179639 + 462*Pi^2) + 7089915492*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2246486400*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 1290332314*PolyGamma[2, 1] - 
            10364887748*Zeta[3]) + CF*(37200870000*lm^2 + 1207485306*Pi^2 - 
            257871600*Pi^4 - 3061800*lm*(-4373 + 84*Pi^2) + 
            7*(7012974303 - 14179830984*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              4492972800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 2580664628*PolyGamma[
                2, 1] + 19318781416*Zeta[3]))))/13226976000, 
      (CF*NC*(14914895525145*CF + 15755312462400*CF*lm + 
         10820989065600*CF*lm^2 - 875866672800*NM + 1006572873600*lm*NM + 
         400777372800*lm^2*NM + 703360778400*NL + 1006572873600*lm*NL + 
         400777372800*lm^2*NL - 61411968505440*NH + 1006572873600*lm*NH + 
         400777372800*lm^2*NH - 834987280464*CF*Pi^2 - 190468454400*CF*lm*
          Pi^2 + 149425637760*NM*Pi^2 - 7054387200*lm*NM*Pi^2 + 
         182933976960*NL*Pi^2 - 7054387200*lm*NL*Pi^2 - 
         7054387200*lm*NH*Pi^2 + 37355444000*Sqrt[3]*CF*Pi^3 + 
         2115220240000*Sqrt[3]*NH*Pi^3 + 17804979360*CF*Pi^4 - 
         14700762888000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         4319996782080*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         8459973849600*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         1383218726400*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         78323583744000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         28817056800*Sqrt[3]*CF*Pi*Log[3]^2 + 1631741328000*Sqrt[3]*NH*Pi*
          Log[3]^2 + 26453952000*(-2*CA*(76 + 33*lm) + CF*(597 + 324*lm) + 
           4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         105815808000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
         2643488658160*CF*PolyGamma[2, 1] + 56435097600*NM*PolyGamma[2, 1] + 
         1797678512000*NH*PolyGamma[2, 1] + 21376751012960*CF*Zeta[3] + 
         38799129600*NM*Zeta[3] + 878271206400*NL*Zeta[3] - 
         4938100025600*NH*Zeta[3] + 75600*Log[x]*
          (4*(243*NM*(16193 + 15360*lm + 3240*lm^2 + 1800*Pi^2) + 
             243*NL*(29153 + 15360*lm + 3240*lm^2 + 1800*Pi^2) + 
             NH*(151310001 + 3732480*lm + 787320*lm^2 - 86335520*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) + 4*CA*(-48357660 - 
             26039880*lm - 4330260*lm^2 + 245187*Pi^2 + 762356*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 3149280*Zeta[3]) + 
           CF*(330103203 + 313353360*lm + 85030560*lm^2 - 5942808*Pi^2 - 
             6098848*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             25194240*Zeta[3])) - 28*CA*(78724126800*lm^2 - 
           18544778766*Pi^2 + 667061500*Sqrt[3]*Pi^3 + 519499980*Pi^4 - 
           7873200*lm*(-37839 + 176*Pi^2) + 514590300*Sqrt[3]*Pi*Log[3]^2 + 
           5*(48140391753 - 52502724600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             30214192320*Im[PolyLog[2, (-1)^(1/3)]]^2 + 4940066880*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 9441030922*
              PolyGamma[2, 1] + 90581649620*Zeta[3]))))/238085568000, 
      -(CF*NC*(-25*CA*(76 + 33*lm) + 2*(9*CF*(391 + 225*lm) + 
             5*(22*NM + 15*lm*NM + 25*NL + 15*lm*NL + 15*lm*NH)))*
          Log[x]^2)/45 - (10*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + (CF*NC*Log[x]*(-4*(243*NL*(137707 + 73404*lm + 16200*lm^2 + 
              9000*Pi^2) + 243*NM*(55325 + 73404*lm + 16200*lm^2 + 
              10128*Pi^2) + NH*(598408179 + 17837172*lm + 3936600*lm^2 - 
              341538880*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          27*CF*(-61892035 - 54727488*lm - 15746400*lm^2 + 1097640*Pi^2 + 
            3438688*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 4665600*Zeta[3]) - 
          108*CA*(-9331853 - 4654098*lm - 801900*lm^2 + 76077*Pi^2 + 
            429836*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 583200*Zeta[3])))/
        6298560 + (CF*NC*(9*CF*(-5416446672000*lm^2 + 235806791760*Pi^2 - 
            63185892000*Sqrt[3]*Pi^3 + 379118880*Pi^4 + 122472000*lm*
             (-58121 + 408*Pi^2) - 48743402400*Sqrt[3]*Pi*Log[3]^2 + 
            7*(-783165178305 + 1201125080640*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 674281843200*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              334240473600*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              221939753392*PolyGamma[2, 1] - 1746134780384*Zeta[3])) + 
          252*CA*(80503749315 + 39405366000*lm^2 - 4871982978*Pi^2 + 
            1128319500*Sqrt[3]*Pi^3 + 46106820*Pi^4 - 648000*lm*
             (-221501 + 561*Pi^2) - 150140635080*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 84285230400*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 41780059200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 870417900*Sqrt[3]*Pi*
             Log[3]^2 + 27742469174*PolyGamma[2, 1] + 250544226508*Zeta[3]) + 
          1120*(-(NH*(-245484313785 + 1612037700*lm^2 + 7471163000*Sqrt[3]*
                Pi^3 - 145800*lm*(-26201 + 102*Pi^2) + 5784765600*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 276646492800*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 5763468600*Sqrt[3]*Pi*
                Log[3]^2 + 2991931966*PolyGamma[2, 1] - 31121652868*
                Zeta[3])) + 2430*NL*(-922855 - 663390*lm^2 - 337806*Pi^2 + 
              60*lm*(-26201 + 102*Pi^2) - 1531440*Zeta[3]) + 
            243*NM*(21674345 - 6633900*lm^2 - 2884176*Pi^2 + 
              600*lm*(-26201 + 102*Pi^2) - 1353870*PolyGamma[2, 1] + 
              1301220*Zeta[3]))))/476171136000, 
      (CF*NC*(-47617113600*(CA*(20077 + 9900*lm) - 
           2*(5*CF*(8263 + 4860*lm) + 2*(45*(23 + 10*lm)*NM + 675*NL + 450*
                lm*NL + 8*NH + 450*lm*NH)))*Log[x]^2 + 
         28570268160000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 + 
         15120*Log[x]*(2*(16*(14580*NM*(49169 + 30501*lm + 6075*lm^2 + 
                 1275*Pi^2) + 32805*NL*(27463 + 13556*lm + 2700*lm^2 + 
                 1800*Pi^2) + 2*NH*(8679810099 + 222352290*lm + 
                 44286750*lm^2 - 4943564600*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) - 5*CF*(-33165220785 - 30344572512*lm - 
               7652750400*lm^2 + 684869256*Pi^2 + 1717519264*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 2267481600*Zeta[3])) + 
           5*CA*(-39603336171 - 19621694016*lm - 3117787200*lm^2 + 
             299140776*Pi^2 + 1717519264*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             2267481600*Zeta[3])) - 5*CA*(52640719084800*lm^2 - 
           13083144918192*Pi^2 + 2103961098400*Sqrt[3]*Pi^3 + 
           514820359872*Pi^4 - 352719360*lm*(-575759 + 1650*Pi^2) + 
           1623055704480*Sqrt[3]*Pi*Log[3]^2 + 7*(16191263883015 - 
             26204469398400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             17435119518720*Im[PolyLog[2, (-1)^(1/3)]]^2 + 11129524830720*
              Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             5101644473248*PolyGamma[2, 1] + 47644062698816*Zeta[3])) + 
         2*(-448*(-2*NH*(-5019704377587 + 26704910250*lm^2 + 216280951250*
                Sqrt[3]*Pi^3 - 3936600*lm*(-17537 + 75*Pi^2) - 517795179000*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 8008574652000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 166845305250*Sqrt[3]*
                Pi*Log[3]^2 + 192615748955*PolyGamma[2, 1] - 1410645422090*
                Zeta[3]) + 54675*NL*(-1556653 - 976860*lm^2 - 619320*Pi^2 + 
               144*lm*(-17537 + 75*Pi^2) - 3628800*Zeta[3]) + 
             21870*NM*(11605940 - 2442150*lm^2 - 671250*Pi^2 + 360*lm*
                (-17537 + 75*Pi^2) - 404217*PolyGamma[2, 1] + 10369566*
                Zeta[3])) + CF*(646045188768000*lm^2 - 69586130217456*Pi^2 + 
             10519805492000*Sqrt[3]*Pi^3 + 2150838567360*Pi^4 - 
             11904278400*lm*(-83011 + 600*Pi^2) + 8115278522400*Sqrt[3]*Pi*
              Log[3]^2 + 35*(16672234094541 - 26204469398400*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 17435119518720*
                Im[PolyLog[2, (-1)^(1/3)]]^2 + 11129524830720*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 5101644473248*
                PolyGamma[2, 1] + 40093394320448*Zeta[3])))))/2857026816000, 
      -(CF*NC*(-21163161600*(CA*(802287 + 404250*lm) - 
            5*(20*CF*(31508 + 19845*lm) + 36521*NM + 14700*lm*NM + 
              21945*NL + 14700*lm*NL + 324*NH + 14700*lm*NH))*Log[x]^2 + 
          14814213120000*(475*CA + 1597*CF - 149*NM - 70*NL)*Log[x]^3 - 
          CA*(4213221732720000*lm^2 - 781893104016960*Pi^2 + 
            279728971480000*Sqrt[3]*Pi^3 + 30369599840160*Pi^4 - 
            19399564800*lm*(-814586 + 1575*Pi^2) + 215790920856000*Sqrt[3]*Pi*
             Log[3]^2 + 7*(571195555643565 - 2389479450640320*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 1509918264921600*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 1479709171584000*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 466800242096336*PolyGamma[2, 1] + 
              4251835703027872*Zeta[3])) + 
          56*(CF*(172073639615355 + 369340866180000*lm^2 - 30830880078072*Pi^
                2 + 9990320410000*Sqrt[3]*Pi^3 + 925904853720*Pi^4 - 
              1488034800*lm*(-353059 + 1800*Pi^2) - 597369862660080*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 377479566230400*
               Im[PolyLog[2, (-1)^(1/3)]]^2 + 369927292896000*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 7706818602000*Sqrt[3]*Pi*
               Log[3]^2 + 116700060524084*PolyGamma[2, 1] + 920610597406408*
               Zeta[3]) - 40*(-(NH*(-66964967066601 + 341982283500*lm^2 + 
                 2606099006000*Sqrt[3]*Pi^3 - 787320*lm*(-1076347 + 
                   3150*Pi^2) - 251158669440*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]] + 96500123193600*Sqrt[3]*Im[PolyLog[3, 
                    -((-1)^(5/6)/Sqrt[3])]] + 2010419233200*Sqrt[3]*Pi*
                  Log[3]^2 + 1251147816790*PolyGamma[2, 1] - 22483462030420*
                  Zeta[3])) + 196830*NL*(-1912103 - 1737450*lm^2 - 
                1173110*Pi^2 + 4*lm*(-1076347 + 3150*Pi^2) - 7081200*
                 Zeta[3]) + 19683*NM*(109016365 - 17374500*lm^2 - 
                4534920*Pi^2 + 40*lm*(-1076347 + 3150*Pi^2) - 3474822*
                 PolyGamma[2, 1] + 95563956*Zeta[3]))) + 
          75600*Log[x]*(CA*(-716000345517 - 334211426352*lm - 
              54561276000*lm^2 + 6837926688*Pi^2 + 45670036160*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 39680928000*Zeta[3]) + 
            8*(12239974881*NL + 6017495508*lm*NL + 1240029000*lm^2*NL + 
              209247988659*NH + 6017495508*lm*NH + 1240029000*lm^2*NH + 
              841995000*NL*Pi^2 + 729*NM*(11859311 + 8254452*lm + 
                1701000*lm^2 + 288960*Pi^2) - 119135954560*Sqrt[3]*NH*Im[
                PolyLog[2, (-1)^(1/3)]] + CF*(148444991607 + 127131552216*
                 lm + 33480783000*lm^2 - 2997239760*Pi^2 - 11417509040*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 9920232000*Zeta[3])))))/
       25713241344000, (CF*NC*(75989241241307415*CF + 395169824762798400*CF*
          lm + 254430916021296000*CF*lm^2 - 97777903390624800*NM + 
         24582807099043200*lm*NM + 9423367260048000*lm^2*NM + 
         7281427251016800*NL + 24582807099043200*lm*NL + 
         9423367260048000*lm^2*NL - 2335892182760173536*NH + 
         24582807099043200*lm*NH + 9423367260048000*lm^2*NH - 
         39236306491112976*CF*Pi^2 - 2099914709760000*CF*lm*Pi^2 - 
         8794170593308800*NM*Pi^2 - 77774618880000*lm*NM*Pi^2 + 
         7535604427344000*NL*Pi^2 - 77774618880000*lm*NL*Pi^2 - 
         77774618880000*lm*NH*Pi^2 + 8420786383660000*Sqrt[3]*CF*Pi^3 + 
         106821604256080000*Sqrt[3]*NH*Pi^3 + 1335011054902560*CF*Pi^4 - 
         403262775512049600*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         270398556112473600*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         281862218536819200*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         311809690092096000*Sqrt[3]*CF*Im[PolyLog[3, 
            -((-1)^(5/6)/Sqrt[3])]] + 3955451403310848000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6496035210252000*Sqrt[3]*CF*
          Pi*Log[3]^2 + 82405237568976000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         9258883200*(455*CA*(72689 + 39600*lm) - 
           4*(7*CF*(5149193 + 3159000*lm) + 2184*(-418 + 375*lm)*NM + 
             1163750*NL + 819000*lm*NL + 34506*NH + 819000*lm*NH))*
          Log[x]^2 + 12962436480000*(11451*CA + 45796*CF - 8912*NM - 
           1560*NL)*Log[x]^3 + 82863747833718320*CF*PolyGamma[2, 1] - 
         8820925062203520*NM*PolyGamma[2, 1] + 95259949774062080*NH*
          PolyGamma[2, 1] + 15120*Log[x]*
          (4*(178605*NM*(8302931 + 5346360*lm + 1020600*lm^2 - 1772040*
                Pi^2) + 178605*NL*(11682353 + 5346360*lm + 1020600*lm^2 + 
               808200*Pi^2) + NH*(38342981607981 + 954886627800*lm + 
               182284263000*lm^2 - 21800327399200*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]])) - 245*CF*(-380015231853 - 336111631920*lm - 
             80353879200*lm^2 + 9041285448*Pi^2 + 28057597280*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 23808556800*Zeta[3]) + 
           490*CA*(-113631921939 - 53288704440*lm - 8184191400*lm^2 + 
             1236726630*Pi^2 + 7014399320*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 5952139200*Zeta[3])) + 645304448627611360*CF*
          Zeta[3] - 102983939421431040*NM*Zeta[3] + 53314501242240000*NL*
          Zeta[3] - 791477993354531840*NH*Zeta[3] - 
         1960*CA*(26443122413400*lm^2 - 8787347027775*Pi^2 + 
           2148159791750*Sqrt[3]*Pi^3 + 372308787018*Pi^4 - 
           49601160*lm*(-2069251 + 4400*Pi^2) + 1657151839350*Sqrt[3]*Pi*
            Log[3]^2 + 7*(2383318991520 - 14696165288340*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 10271946739680*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 11363326898400*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3019815883153*
              PolyGamma[2, 1] + 28083190336706*Zeta[3]))))/104995735488000, 
      -(CF*NC*(-55553299200*(35*CA*(17894489 + 10655436*lm) - 
            2*(28*CF*(48131714 + 32692815*lm) + 84*(63718 + 403615*lm)*NM + 
              15*(7*(458089 + 322892*lm)*NL + 4*(27828 + 565061*lm)*NH)))*
           Log[x]^2 + 15554923776000*(1282475*CA + 4618485*CF - 931916*NM - 
            161446*NL)*Log[x]^3 - 49*CA*(117646114536720000*lm^2 - 
            38330884688427360*Pi^2 + 13314293147288000*Sqrt[3]*Pi^3 + 
            1464844075248960*Pi^4 - 10912255200*lm*(-40861149 + 63800*Pi^2) + 
            10271026142193600*Sqrt[3]*Pi*Log[3]^2 - 
            21*(4047249128240517 + 24732957014697920*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 16221341153203200*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 23476631182156800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                   Sqrt[3])]] - 4785239013092192*PolyGamma[2, 1] - 
              46572251048469184*Zeta[3])) + 15120*Log[x]*
           (2*(4*(428652*NM*(269719001 + 129487395*lm + 25515000*lm^2 - 
                  47771850*Pi^2) + 5*(107163*NL*(103589916*lm + 20412000*
                     lm^2 + 341*(671549 + 48360*Pi^2)) + 2*NH*
                   (205990611076077 + 5550503084154*lm + 1093705578000*lm^2 - 
                    117060542665360*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) - 
              49*CF*(-115282381231083 - 96892223917680*lm - 24106163760000*
                 lm^2 + 3012933497040*Pi^2 + 10868810732480*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 7142567040000*Zeta[3])) + 
            49*CA*(-138897144111963 - 62340744504240*lm - 9821029680000*lm^
                2 + 2011283997840*Pi^2 + 10868810732480*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 7142567040000*Zeta[3])) + 
          2*(49*CF*(-59258302627888287 + 288767735681040000*lm^2 - 
              43364029006004256*Pi^2 + 13314293147288000*Sqrt[3]*Pi^3 + 
              1363578346992960*Pi^4 - 26784626400*lm*(-15759699 + 
                63800*Pi^2) - 519392097308656320*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 340648164217267200*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 493009254825292800*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 10271026142193600*Sqrt[3]*Pi*
               Log[3]^2 + 100490019274936032*PolyGamma[2, 1] + 
              844062317500833984*Zeta[3]) - 
            8*(5*(-4*NH*(3275374779715500*lm^2 - 303807105*lm*(-27139749 + 
                    63800*Pi^2) + 2*(-426456234249638391 + 17924895595633250*
                     Sqrt[3]*Pi^3 - 11740717481749620*Sqrt[3]*Im[PolyLog[2, 
                       (-1)^(1/3)]] + 663733276912591200*Sqrt[3]*
                     Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                    13827776602345650*Sqrt[3]*Pi*Log[3]^2 + 9553121120357304*
                     PolyGamma[2, 1] - 166077604378542192*Zeta[3])) + 
                33756345*NL*(-52074599 - 388119600*lm^2 - 324386520*Pi^2 + 
                  36*lm*(-27139749 + 63800*Pi^2) - 2402231040*Zeta[3])) + 
              81015228*NM*(9985969883 - 808582500*lm^2 + 628107550*Pi^2 + 
                75*lm*(-27139749 + 63800*Pi^2) + 899877900*PolyGamma[2, 1] + 
                10761307800*Zeta[3])))))/7559692955136000, 
      (CF*NC*(10999553241600*(161*CF*(28811729 + 19799640*lm) - 
           7*CA*(129321557 + 92764980*lm) + 6*(882*(-311977 + 22310*lm)*NM + 
             5*(1127*(4817 + 3492*lm)*NL + 18*(14899 + 218638*lm)*NH)))*
          Log[x]^2 + 21559124353536000*(349861*CA + 1397949*CF - 
           582*(970*NM + 69*NL))*Log[x]^3 + 166320*Log[x]*
          (2*(-8*(11573604*NM*(99420682 - 64350315*lm - 11907000*lm^2 + 
                 89125050*Pi^2) - 5*(2893401*NL*(121587913 + 51480252*lm + 
                   9525600*lm^2 + 8797320*Pi^2) + 2*NH*(3159057525015165 + 
                   74476506308526*lm + 13780690282800*lm^2 - 1793659778490160*
                    Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) - 
             49*CF*(-2919467806717569 - 2641822036359840*lm - 607475326752000*
                lm^2 + 107370816175800*Pi^2 + 279474058590880*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 179992689408000*Zeta[3])) + 
           49*CA*(-3523242012811539 - 1652524462617120*lm - 
             247489947936000*lm^2 + 74268919903320*Pi^2 + 279474058590880*
              Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 179992689408000*
              Zeta[3])) - 3773*CA*(-424031525627366493 + 372613794471072000*
            lm^2 - 224967810853833120*Pi^2 + 48907960253404000*Sqrt[3]*Pi^3 + 
           6968695530545280*Pi^4 - 7652750400*lm*(-189506609 + 323400*Pi^2) - 
           1644071120120625600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           1162325933769369600*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           1810991899668902400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                Sqrt[3])]] + 37728997909768800*Sqrt[3]*Pi*Log[3]^2 + 
           310530918509001440*PolyGamma[2, 1] + 3318525817503513280*
            Zeta[3]) + 2*(49*CF*(70424007155032608000*lm^2 - 
             19341314394766301376*Pi^2 + 3765912939512108000*Sqrt[3]*Pi^3 + 
             508870681683154560*Pi^4 - 15910068081600*lm*(-6922009 + 29400*
                Pi^2) + 2905132839052197600*Sqrt[3]*Pi*Log[3]^2 - 
             77*(335569099686815043 + 1644071120120625600*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 1162325933769369600*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 1810991899668902400*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 310530918509001440*
                PolyGamma[2, 1] - 2775885069671938240*Zeta[3])) - 
           176*(5*(-2*NH*(-23558175067107722175 + 72617347445214600*lm^2 + 
                 1098616614325223000*Sqrt[3]*Pi^3 - 16405583670*lm*
                  (-11594299 + 29400*Pi^2) - 2890393556351537040*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] + 40680203776156828800*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 847504245336600600*
                  Sqrt[3]*Pi*Log[3]^2 + 971797927707422368*PolyGamma[2, 1] - 
                 8370423979843987264*Zeta[3]) + 2734263945*NL*(30639477 - 
                 53116560*lm^2 - 51144920*Pi^2 + 12*lm*(-11594299 + 
                   29400*Pi^2) - 426504960*Zeta[3])) + 364568526*NM*
              (28253173199 - 1991871000*lm^2 + 14488976700*Pi^2 + 450*lm*
                (-11594299 + 29400*Pi^2) + 14138378280*PolyGamma[2, 1] + 
               38026132560*Zeta[3])))))/748409602558464000, 
      (42705880967724735499*CF^2*NC)/3779846477568000 - 
       (92066989*CF^2*lm*NC)/4800 - (207207*CF^2*lm^2*NC)/16 + 
       (434284719181*CF*NM*NC)/62511750 - (157682539*CF*lm*NM*NC)/129600 - 
       (23023*CF*lm^2*NM*NC)/48 + (9172703909*CF*NC*NL)/13996800 - 
       (157682539*CF*lm*NC*NL)/129600 - (23023*CF*lm^2*NC*NL)/48 + 
       (19278021035942020319*CF*NC*NH)/118120202424000 - 
       (157682539*CF*lm*NC*NH)/129600 - (23023*CF*lm^2*NC*NH)/48 + 
       (2046168224659*CF^2*NC*Pi^2)/449064000 + (4655*CF^2*lm*NC*Pi^2)/72 + 
       (63088723*CF*NM*NC*Pi^2)/23328 + (4655*CF*lm*NM*NC*Pi^2)/1944 - 
       (11128013*CF*NC*NL*Pi^2)/23328 + (4655*CF*lm*NC*NL*Pi^2)/1944 + 
       (4655*CF*lm*NC*NH*Pi^2)/1944 - (55092828767347*CF^2*NC*Pi^3)/
        (20662426080*Sqrt[3]) - (43911124448947*CF*NC*NH*Pi^3)/
        (2066242608*Sqrt[3]) - (2148419*CF^2*NC*Pi^4)/24300 + 
       (543788554590337*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6887475360*Sqrt[3]) + (7598540010233*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(344373768*Sqrt[3]) - 
       (780052*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (7870404109621*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (79716150*Sqrt[3]) - (6273017778421*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) - 
       (7870404109621*CF^2*NC*Pi*Log[3]^2)/(3826375200*Sqrt[3]) - 
       (6273017778421*CF*NC*NH*Pi*Log[3]^2)/(382637520*Sqrt[3]) - 
       (CF*NC*(-3*CA*(1504057241 + 1667816150*lm) + 
          CF*(28583466722 + 24562383300*lm) + 15*(-525947516*NM + 
            60647860*lm*NM + 83706875*NL + 60647860*lm*NL + 4631604*NH + 
            60647860*lm*NH))*Log[x]^2)/340200 - 
       (CF*NC*(8728085*CA + 28182709*CF - 26*(435166*NM + 33323*NL))*
         Log[x]^3)/486 - (1116106011243751*CF^2*NC*PolyGamma[2, 1])/
        309936391200 + (362575811*CF*NM*NC*PolyGamma[2, 1])/97200 - 
       (154384242639689*CF*NC*NH*PolyGamma[2, 1])/38742048900 - 
       (6965748610007593*CF^2*NC*Zeta[3])/154968195600 + 
       (560008211*CF*NM*NC*Zeta[3])/48600 - (337997*CF*NC*NL*Zeta[3])/81 + 
       (1270936995906481*CF*NC*NH*Zeta[3])/19371024450 + 
       (CA*CF*NC*(-2226106281907141692903 + 897428868734558160000*lm^2 - 
          718713972880409580480*Pi^2 + 151174722137600168000*Sqrt[3]*Pi^3 + 
          15689995734355084800*Pi^4 - 235802922616800*lm*
           (-14497833 + 19000*Pi^2) - 4476467381387654184000*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 2948476804519873536000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 5597783996866566220800*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 116620499934720129600*
           Sqrt[3]*Pi*Log[3]^2 + 612518978970570548800*PolyGamma[2, 1] + 
          8872863689471923971200*Zeta[3]))/340186182981120000 + 
       (CF*NC*Log[x]*(10*(4*(-393660*NM*(11164820833 + 5500898907*lm + 
                1050197400*lm^2 - 7523828970*Pi^2) - 4822335*NL*(
                1076820205 + 449052972*lm + 85730400*lm^2 + 80560680*Pi^2) - 
              2*NH*(43330265120719497 + 1082741931864810*lm + 
                206710354242000*lm^2 - 24590229691410320*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + CF*(-203324999612432469 - 
              186742296515622960*lm - 44649436516272000*lm^2 + 
              10194256366244496*Pi^2 + 24681587287771456*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 13229462671488000*Zeta[3])) + 
          CA*(1247859703384325391 + 592164248396036400*lm + 
            90952555866480000*lm^2 - 40801771265456880*Pi^2 - 
            123407936438857280*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            66147313357440000*Zeta[3])))/22499086176000, 
      (-122204796550421967593*CF^2*NC)/6749725852800000 + 
       (22054031*CF^2*lm*NC)/500 + (281043*CF^2*lm^2*NC)/10 + 
       (339434950607*CF*NM*NC)/22325625 + (9221714*CF*lm*NM*NC)/3375 + 
       (10409*CF*lm^2*NM*NC)/10 - (6161940409*CF*NC*NL)/2430000 + 
       (9221714*CF*lm*NC*NL)/3375 + (10409*CF*lm^2*NC*NL)/10 - 
       (162032074869844322551*CF*NC*NH)/374328546253200 + 
       (9221714*CF*lm*NC*NH)/3375 + (10409*CF*lm^2*NC*NH)/10 - 
       (13687267570183*CF^2*NC*Pi^2)/673596000 - (784*CF^2*lm*NC*Pi^2)/5 - 
       (159769237*CF*NM*NC*Pi^2)/4050 - (784*CF*lm*NM*NC*Pi^2)/135 + 
       (14231959*CF*NC*NL*Pi^2)/12150 - (784*CF*lm*NC*NL*Pi^2)/135 - 
       (784*CF*lm*NC*NH*Pi^2)/135 + (332213799869*CF^2*NC*Pi^3)/
        (51018336*Sqrt[3]) + (7871479499779*CF*NC*NH*Pi^3)/
        (129140163*Sqrt[3]) + (1400497*CF^2*NC*Pi^4)/5400 - 
       (2969315286756661*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (17218688400*Sqrt[3]) - (11899895554018*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) + 
       (1813238*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
       (47459114267*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (196830*Sqrt[3]) + (17991953142352*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) + 
       (47459114267*CF^2*NC*Pi*Log[3]^2)/(9447840*Sqrt[3]) + 
       (1124497071397*CF*NC*NH*Pi*Log[3]^2)/(23914845*Sqrt[3]) + 
       (CF*NC*(-55*CA*(-60617191 + 1368164160*lm) + 
          8*(11*CF*(3664695781 + 4197776400*lm) + 20*(-4969016151*NM + 
              85510260*lm*NM + 115894207*NL + 85510260*lm*NL + 
              7983510*NH + 85510260*lm*NH)))*Log[x]^2)/1782000 + 
       (4*CF*NC*(95204025*CA + 280774978*CF - 60*(4619875*NM + 129561*NL))*
         Log[x]^3)/6075 + (1662716453399929*CF^2*NC*PolyGamma[2, 1])/
        464904586800 - (989635*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (1033073117546407*CF*NC*NH*PolyGamma[2, 1])/58113073350 - 
       (CA*CF*NC*(2869156844308311480000*lm^2 - 4826597302490569366950*Pi^2 + 
          543904585818025162500*Sqrt[3]*Pi^3 + 67317559732905174000*Pi^4 - 
          74246984380800*lm*(-150621379 + 215600*Pi^2) + 
          419583537631047982500*Sqrt[3]*Pi*Log[3]^2 - 
          11*(528766690665805444719 + 1309468041459687501000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 917914455440952480000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 1830909982390027560000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 81473106216596521000*
             PolyGamma[2, 1] - 2819199533729054462000*Zeta[3])))/
        501167144570400000 + (24101406415363717*CF^2*NC*Zeta[3])/
        232452293400 - 30234*CF*NM*NC*Zeta[3] + (507392*CF*NC*NL*Zeta[3])/
        45 - (4496904955161353*CF*NC*NH*Zeta[3])/29056536675 + 
       CF*Log[x]*((-320146706023*NM*NC)/1701000 + (6588652*lm*NM*NC)/675 + 
         1764*lm^2*NM*NC + (6046552409*NC*NL)/243000 + 
         (6588652*lm*NC*NL)/675 + 1764*lm^2*NC*NL + 
         (71645169882525493*NC*NH)/162046989720 + (6588652*lm*NC*NH)/675 + 
         1764*lm^2*NC*NH - (17994788*NM*NC*Pi^2)/405 + 
         (252128*NC*NL*Pi^2)/135 - (17991953142352*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
         CA*NC*(-1856449669548767/16533720000 - (44572486*lm)/675 - 
           9702*lm^2 + (50408017*Pi^2)/6480 + 
           (47459114267*Im[PolyLog[2, (-1)^(1/3)]])/(1180980*Sqrt[3]) - 
           7056*Zeta[3]) + CF*NC*(576278412686201/3306744000 + 
           (5331802*lm)/25 + 47628*lm^2 - (892254089*Pi^2)/48600 - 
           (47459114267*Im[PolyLog[2, (-1)^(1/3)]])/(590490*Sqrt[3]) + 
           14112*Zeta[3])), (26827220434679619610213*CF^2*NC)/
        850465457452800000 - (2967233927*CF^2*lm*NC)/54000 - 
       (147315*CF^2*lm^2*NC)/4 - (15891097757417171*CF*NM*NC)/540101520000 - 
       (5066472677*CF*lm*NM*NC)/1458000 - (49105*CF*lm^2*NM*NC)/36 + 
       (201214339123*CF*NC*NL)/43740000 - (5066472677*CF*lm*NC*NL)/
        1458000 - (49105*CF*lm^2*NC*NL)/36 + 
       (1676184254333340225001453*CF*NC*NH)/2829923809674192000 - 
       (5066472677*CF*lm*NC*NH)/1458000 - (49105*CF*lm^2*NC*NH)/36 + 
       (61300300337231*CF^2*NC*Pi^2)/1347192000 + (7154*CF^2*lm*NC*Pi^2)/45 + 
       (1251685457*CF*NM*NC*Pi^2)/36450 + (7154*CF*lm*NM*NC*Pi^2)/1215 - 
       (57295873*CF*NC*NL*Pi^2)/36450 + (7154*CF*lm*NC*NL*Pi^2)/1215 + 
       (7154*CF*lm*NC*NH*Pi^2)/1215 - (143778544343413*CF^2*NC*Pi^3)/
        (13774950720*Sqrt[3]) - (30351722171288*CF*NC*NH*Pi^3)/
        (387420489*Sqrt[3]) - (31800811*CF^2*NC*Pi^4)/97200 + 
       (394431116722787239*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1549681956000*Sqrt[3]) + (201484827690904*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1937102445*Sqrt[3]) - 
       (827323*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (20539792049059*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (53144100*Sqrt[3]) - (69375364962944*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23914845*Sqrt[3]) - 
       (20539792049059*CF^2*NC*Pi*Log[3]^2)/(2550916800*Sqrt[3]) - 
       (4335960310184*CF*NC*NH*Pi*Log[3]^2)/(71744535*Sqrt[3]) - 
       (CF*NC*(-1089*CA*(-23324453053 + 12334464800*lm) + 
          8*(264*CF*(1018936789 + 31221614025*lm) + 
            5*(33*(-63187050037 + 1850169720*lm)*NM + 1386*(59805147 + 
                44051660*lm)*NL + 5*(1243078247 + 12211120152*lm)*NH)))*
         Log[x]^2)/224532000 - (4*CF*NC*(181351206*CA + 
          5*(61673998*CF - 63236010*NM - 2202583*NL))*Log[x]^3)/6075 + 
       (18841551540429847*CF^2*NC*PolyGamma[2, 1])/1549681956000 + 
       (784312273*CF*NM*NC*PolyGamma[2, 1])/16200 - 
       (1172165206680881*CF*NC*NH*PolyGamma[2, 1])/77484097800 - 
       (117211505780774813*CF^2*NC*Zeta[3])/774840978000 + 
       (510099073*CF*NM*NC*Zeta[3])/8100 - (6418282*CF*NC*NL*Zeta[3])/405 + 
       (9206251655882239*CF*NC*NH*Zeta[3])/38742048900 + 
       (CA*CF*NC*(-251657857004572627995 + 95704826910503580000*lm^2 - 
          282458182536975186945*Pi^2 + 22192218319405796550*Sqrt[3]*Pi^3 + 
          2146934621871917640*Pi^4 - 30623756184*lm*(-11939104921 + 
            13490400*Pi^2) - 541159492143664091908*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 351804816828111427200*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 821746141198568923680*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 17119711274970185910*
           Sqrt[3]*Pi*Log[3]^2 - 77551826140409250252*PolyGamma[2, 1] + 
          1121558412205702364376*Zeta[3]))/12756981861792000 + 
       CF*Log[x]*((2946481800797*NM*NC)/214326000 - (159635279*lm*NM*NC)/
          12150 - 2450*lm^2*NM*NC - (49657254391*NC*NL)/1458000 - 
         (159635279*lm*NC*NL)/12150 - 2450*lm^2*NC*NL - 
         (19346415958809669683*NC*NH)/34029867841200 - (159635279*lm*NC*NH)/
          12150 - 2450*lm^2*NC*NH + (20498092*NM*NC*Pi^2)/405 - 
         (3194833*NC*NL*Pi^2)/1215 + (69375364962944*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) + 
         CF*NC*(-133395030713717543/1249949232000 - (128214029*lm)/450 - 
           66150*lm^2 + (1304111321*Pi^2)/32400 + 
           (20539792049059*Im[PolyLog[2, (-1)^(1/3)]])/(159432300*Sqrt[3]) - 
           19600*Zeta[3]) + CA*NC*(558517943058014309/6249746160000 + 
           (2172733069*lm)/24300 + 13475*lm^2 - (718473317*Pi^2)/38880 - 
           (20539792049059*Im[PolyLog[2, (-1)^(1/3)]])/(318864600*Sqrt[3]) + 
           9800*Zeta[3])), (57765207140655744497941*CF^2*NC)/
        425232728726400000 + (345358751*CF^2*lm*NC)/3000 + 
       (731997*CF^2*lm^2*NC)/10 + (173608352940462877*CF*NM*NC)/
        270050760000 + (577157801*CF*lm*NM*NC)/81000 + 
       (27111*CF*lm^2*NM*NC)/10 - (23731155803*CF*NC*NL)/1822500 + 
       (577157801*CF*lm*NC*NL)/81000 + (27111*CF*lm^2*NC*NL)/10 - 
       (628193205715843640215416077*CF*NC*NH)/444095900703871416000 + 
       (577157801*CF*lm*NC*NH)/81000 + (27111*CF*lm^2*NC*NH)/10 - 
       (54418140529351*CF^2*NC*Pi^2)/265356000 - (1764*CF^2*lm*NC*Pi^2)/5 - 
       (6347417341*CF*NM*NC*Pi^2)/12150 - (196*CF*lm*NM*NC*Pi^2)/15 + 
       (4712191*CF*NC*NL*Pi^2)/1350 - (196*CF*lm*NC*NL*Pi^2)/15 - 
       (196*CF*lm*NC*NH*Pi^2)/15 + (472999373472073*CF^2*NC*Pi^3)/
        (20662426080*Sqrt[3]) + (954265249147*CF*NC*NH*Pi^3)/
        (4782969*Sqrt[3]) + (1481207*CF^2*NC*Pi^4)/1800 - 
       (395497503678972989*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (774840978000*Sqrt[3]) - (1085280518050906*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1937102445*Sqrt[3]) + 
       (584318*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (67571339067439*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (79716150*Sqrt[3]) + (2181177712336*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(295245*Sqrt[3]) + 
       (67571339067439*CF^2*NC*Pi*Log[3]^2)/(3826375200*Sqrt[3]) + 
       (136323607021*CF*NC*NH*Pi*Log[3]^2)/(885735*Sqrt[3]) + 
       (CF*NC*(-143*CA*(-2774350761733 + 512579944800*lm) + 
          20*(143*CF*(-164883203377 + 125815077360*lm) + 
            286*(-524640450329 + 2329908840*lm)*NM + 
            14*(858*(74344889 + 55474020*lm)*NL + 5*(1112850131 + 
                9519341832*lm)*NH)))*Log[x]^2)/486486000 + 
       (CF*NC*(1809803567*CA + 1491880518*CF - 240*(32986670*NM + 
            308189*NL))*Log[x]^3)/4050 - (126718113476786537*CF^2*NC*
         PolyGamma[2, 1])/1394713760400 - (1218963283*CF*NM*NC*
         PolyGamma[2, 1])/2700 + (4010362607562499*CF*NC*NH*PolyGamma[2, 1])/
        69735688020 + (242204675200451683*CF^2*NC*Zeta[3])/697356880200 - 
       (148094483*CF*NM*NC*Zeta[3])/1350 + (1716092*CF*NC*NL*Zeta[3])/45 - 
       (17479901507090093*CF*NC*NH*Zeta[3])/34867844010 + 
       CF*Log[x]*((-87002184558571*NM*NC)/26790750 + (2236958*lm*NM*NC)/
          75 + 5292*lm^2*NM*NC + (1104710503*NC*NL)/13500 + 
         (2236958*lm*NC*NL)/75 + 5292*lm^2*NC*NL + 
         (918078319832822371*NC*NH)/633933825525 + (2236958*lm*NC*NH)/75 + 
         5292*lm^2*NC*NH - (65619196*NM*NC*Pi^2)/135 + 
         (854518*NC*NL*Pi^2)/135 - (2181177712336*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) + 
         CA*NC*(283178609001324709/2343654810000 - (15081569*lm)/75 - 
           29106*lm^2 + (2681925637*Pi^2)/32400 + 
           (67571339067439*Im[PolyLog[2, (-1)^(1/3)]])/(478296900*Sqrt[3]) - 
           21168*Zeta[3]) + CF*NC*(-3760774945648256999/9374619240000 + 
           (16362072*lm)/25 + 142884*lm^2 - (943033429*Pi^2)/5400 - 
           (67571339067439*Im[PolyLog[2, (-1)^(1/3)]])/(239148450*Sqrt[3]) + 
           42336*Zeta[3])) - (CA*CF*NC*(156931495371975721320000*lm^2 - 
          1061390527349078856979350*Pi^2 + 40154099312477957152500*Sqrt[3]*
           Pi^3 + 4440287860704276966000*Pi^4 - 64966111333200*lm*
           (-9423123211 + 11642400*Pi^2) + 30976019469625852660500*Sqrt[3]*Pi*
           Log[3]^2 + 11*(54765336543939730465641 - 81393386257132641136200*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 55906005956389333920000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 135168084958367357064000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 43464312922537782191000*
             PolyGamma[2, 1] + 196088218820287366622000*Zeta[3])))/
        10524510035978400000, (-8087416669218369432272709797*CF^2*NC)/
        23771360001263212800000 - (72173346787*CF^2*lm*NC)/529200 - 
       (363987*CF^2*lm^2*NC)/4 - (1756165424207581288691*CF*NM*NC)/
        2156625369360000 - (123004131337*CF*lm*NM*NC)/14288400 - 
       (13481*CF*lm^2*NM*NC)/4 + (8490163751203*CF*NC*NL)/428652000 - 
       (123004131337*CF*lm*NC*NL)/14288400 - (13481*CF*lm^2*NC*NL)/4 + 
       (4867644033865216896530990669*CF*NC*NH)/2664575404223228496000 - 
       (123004131337*CF*lm*NC*NH)/14288400 - (13481*CF*lm^2*NC*NH)/4 + 
       (5196979153380893*CF^2*NC*Pi^2)/9430344000 + 346*CF^2*lm*NC*Pi^2 + 
       (42183852194*CF*NM*NC*Pi^2)/127575 + (346*CF*lm*NM*NC*Pi^2)/27 - 
       (12514384*CF*NC*NL*Pi^2)/2835 + (346*CF*lm*NC*NL*Pi^2)/27 + 
       (346*CF*lm*NC*NH*Pi^2)/27 - (12541632970583167*CF^2*NC*Pi^3)/
        (371923669440*Sqrt[3]) - (283231524695350*CF*NC*NH*Pi^3)/
        (1162261467*Sqrt[3]) - (32179129*CF^2*NC*Pi^4)/32400 + 
       (162211361217998061533*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (227803247532000*Sqrt[3]) + (2210961753697754*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5811307335*Sqrt[3]) - 
       (2261243*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (12541632970583167*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10044234900*Sqrt[3]) - (129477268432160*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (12541632970583167*CF^2*NC*Pi*Log[3]^2)/(482123275200*Sqrt[3]) - 
       (8092329277010*CF*NC*NH*Pi*Log[3]^2)/(43046721*Sqrt[3]) - 
       (CF*NC*(CA*(56871290566468339 - 4086925606764000*lm) + 
          8*(13*CF*(-937672319351143 + 192914320599000*lm) + 
            175*(65*(-859890965161 + 8165685528*lm)*NM + 
              7*(2574*(39567219 + 29457740*lm)*NL + (9488212337 + 
                  75824222760*lm)*NH))))*Log[x]^2)/20432412000 + 
       (CF*NC*(-87309329873*CA + 14*(2274057277*CF + 9905394840*NM + 
            147288700*NL))*Log[x]^3)/85050 + 
       (14442651793508199637*CF^2*NC*PolyGamma[2, 1])/41841412812000 + 
       (24373185677*CF*NM*NC*PolyGamma[2, 1])/48600 - 
       (100050440218130069*CF*NC*NH*PolyGamma[2, 1])/2092070640600 - 
       (69376764004076926241*CF^2*NC*Zeta[3])/146444944842000 + 
       (10640922077*CF*NM*NC*Zeta[3])/24300 - (4080890*CF*NC*NL*Zeta[3])/
        81 + (756089487652955131*CF*NC*NH*Zeta[3])/1046035320300 + 
       CF*Log[x]*((5050544108953327*NM*NC)/11114334000 - 
         (71531107*lm*NM*NC)/1890 - 6930*lm^2*NM*NC - (71875412621*NC*NL)/
          680400 - (71531107*lm*NC*NL)/1890 - 6930*lm^2*NC*NL - 
         (872297998809710142749*NC*NH)/492946942728240 - 
         (71531107*lm*NC*NH)/1890 - 6930*lm^2*NC*NH + 
         (164045156*NM*NC*Pi^2)/405 - (2034217*NC*NL*Pi^2)/243 + 
         (129477268432160*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(422287700731076991337469/
            142925444933040000 - (57705757*lm)/70 - 187110*lm^2 + 
           (100973788487*Pi^2)/226800 + (12541632970583167*
             Im[PolyLog[2, (-1)^(1/3)]])/(30132704700*Sqrt[3]) - 
           55440*Zeta[3]) + CA*NC*(-27985580492689141530559/
            20417920704720000 + (970209977*lm)/3780 + 38115*lm^2 - 
           (98675613181*Pi^2)/453600 - (12541632970583167*
             Im[PolyLog[2, (-1)^(1/3)]])/(60265409400*Sqrt[3]) + 
           27720*Zeta[3])) + CA*CF*NC*((148291*lm^2)/8 - 
         (3441616942869607*Pi^2)/12573792000 + (12541632970583167*Pi^3)/
          (743847338880*Sqrt[3]) + (32843449*Pi^4)/64800 + 
         lm*(2027222166107/28576800 - (1903*Pi^2)/27) + 
         (12541632970583167*Pi*Log[3]^2)/(964246550400*Sqrt[3]) + 
         (1041812030762116130279036322 - 793444707545746168134054525*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 503932700656279041576660000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 1391337645965096530142673000*
            Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
           1153870751467993808353741175*PolyGamma[2, 1] + 
           1824879056989536253526201150*Zeta[3])/6685695000355278600000), 
      (75825637853335861465909569779*CF^2*NC)/21394224001136891520000 + 
       (784772797*CF^2*lm*NC)/2940 + (339039*CF^2*lm^2*NC)/2 + 
       (3228234758732881633*CF*NM*NC)/326761419600 + 
       (327712078*CF*lm*NM*NC)/19845 + (12557*CF*lm^2*NM*NC)/2 - 
       (688808948603*CF*NC*NL)/14288400 + (327712078*CF*lm*NC*NL)/19845 + 
       (12557*CF*lm^2*NC*NL)/2 - (845899991557179115136306323*CF*NC*NH)/
        209835313082579244060 + (327712078*CF*lm*NC*NH)/19845 + 
       (12557*CF*lm^2*NC*NH)/2 - (15745112278042951*CF^2*NC*Pi^2)/
        6810804000 - 720*CF^2*lm*NC*Pi^2 - (111674645849*CF*NM*NC*Pi^2)/
        17010 - (80*CF*lm*NM*NC*Pi^2)/3 + (3440119*CF*NC*NL*Pi^2)/378 - 
       (80*CF*lm*NC*NL*Pi^2)/3 - (80*CF*lm*NC*NH*Pi^2)/3 + 
       (114406557184768601*CF^2*NC*Pi^3)/(1673656512480*Sqrt[3]) + 
       (5946118998685915*CF*NC*NH*Pi^3)/(10460353203*Sqrt[3]) + 
       (12139561*CF^2*NC*Pi^4)/5400 - (1372798603907721128239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1025114613894000*Sqrt[3]) - 
       (86009218736881802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (52301766015*Sqrt[3]) + (1491094*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 + (114406557184768601*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(45199057050*Sqrt[3]) + 
       (2718225827970704*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) + (114406557184768601*CF^2*NC*Pi*Log[3]^2)/
        (2169554738400*Sqrt[3]) + (169889114248169*CF*NC*NH*Pi*Log[3]^2)/
        (387420489*Sqrt[3]) + 
       (CF*NC*(-351*CA*(-122599251003841 + 4444425832000*lm) + 
          224*(468*CF*(-755389464559 + 73051642125*lm) + 
            25*(286*(-166862242073 + 177094890*lm)*NM + 3003*(22433231 + 
                16866180*lm)*NL + (7017192731 + 50649138540*lm)*NH)))*
         Log[x]^2)/3405402000 - (CF*NC*(-58415783459*CA + 
          48*(1160251812*CF + 175*(37268357*NM + 93701*NL)))*Log[x]^3)/
        14175 - (55597657856857989599*CF^2*NC*PolyGamma[2, 1])/
        37657271530800 - (7065173737*CF*NM*NC*PolyGamma[2, 1])/1350 + 
       (381094996797022121*CF*NC*NH*PolyGamma[2, 1])/2353579470675 + 
       CA*CF*NC*((-138127*lm^2)/4 + (8554050106305811*Pi^2)/7429968000 - 
         (114406557184768601*Pi^3)/(3347313024960*Sqrt[3]) - 
         (12369961*Pi^4)/10800 + lm*(-5349188513/39690 + (440*Pi^2)/3) - 
         (114406557184768601*Pi*Log[3]^2)/(4339109476800*Sqrt[3]) + 
         (-16713665720823332276803877139 + 2148781251558183942302864184*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1435535956923804545585529600*
            Im[PolyLog[2, (-1)^(1/3)]]^2 - 4061433475651153018893094080*
            Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           7107006349622185598368074760*PolyGamma[2, 1] - 
           7281859775237060791951964560*Zeta[3])/9627400800511601184000) + 
       (35340393199823211887*CF^2*NC*Zeta[3])/26360090071560 - 
       (895993*CF*NM*NC*Zeta[3])/75 + (1001968*CF*NC*NL*Zeta[3])/9 - 
       (3313644790542093758*CF*NC*NH*Zeta[3])/2353579470675 + 
       CF*Log[x]*((-427192761232663*NM*NC)/9430344 + (8323562*lm*NM*NC)/
          105 + 13860*lm^2*NM*NC + (1763574781*NC*NL)/7560 + 
         (8323562*lm*NC*NL)/105 + 13860*lm^2*NC*NL + 
         (320516494721041288720151*NC*NH)/77639143479697800 + 
         (8323562*lm*NC*NH)/105 + 13860*lm^2*NC*NH - 
         (148970876*NM*NC*Pi^2)/27 + (499544*NC*NL*Pi^2)/27 - 
         (2718225827970704*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CA*NC*(797606365884229598903911/
            128632900439736000 - (55966691*lm)/105 - 76230*lm^2 + 
           (213328509083*Pi^2)/226800 + (114406557184768601*
             Im[PolyLog[2, (-1)^(1/3)]])/(271194342300*Sqrt[3]) - 
           55440*Zeta[3]) + CF*NC*(-8259122158373755336651939/
            643164502198680000 + (61086708*lm)/35 + 374220*lm^2 - 
           (43248460393*Pi^2)/22680 - (114406557184768601*
             Im[PolyLog[2, (-1)^(1/3)]])/(135597171150*Sqrt[3]) + 
           110880*Zeta[3])), (-53697681092132231965594605387227*CF^2*NC)/
        6836816018981491006464000 - (14702531773*CF^2*lm*NC)/48384 - 
       (3234465*CF^2*lm^2*NC)/16 - (20622993082442233627618069*CF*NM*NC)/
        2165991285249792000 - (25026944053*CF*lm*NM*NC)/1306368 - 
       (119795*CF*lm^2*NM*NC)/16 + (182341708088341*CF*NC*NL)/2743372800 - 
       (25026944053*CF*lm*NC*NL)/1306368 - (119795*CF*lm^2*NC*NL)/16 + 
       (90790269775437194548480103267*CF*NC*NH)/18271374200387852544000 - 
       (25026944053*CF*lm*NC*NH)/1306368 - (119795*CF*lm^2*NC*NH)/16 + 
       (1018539611081476423*CF^2*NC*Pi^2)/140107968000 + 
       (5495*CF^2*lm*NC*Pi^2)/8 + (60665822557*CF*NM*NC*Pi^2)/23328 + 
       (5495*CF*lm*NM*NC*Pi^2)/216 - (889574*CF*NC*NL*Pi^2)/81 + 
       (5495*CF*lm*NC*NL*Pi^2)/216 + (5495*CF*lm*NC*NH*Pi^2)/216 - 
       (632177796637255921*CF^2*NC*Pi^3)/(6694626049920*Sqrt[3]) - 
       (18583470557726165*CF*NC*NH*Pi^3)/(27894275208*Sqrt[3]) - 
       (169381463*CF^2*NC*Pi^4)/64800 + (14644852384955924338033*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8200916911152000*Sqrt[3]) + 
       (163381147865205313*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (139471376040*Sqrt[3]) - (11010901*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/30 - (632177796637255921*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(180796228200*Sqrt[3]) - 
       (1061912603298638*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) - (632177796637255921*CF^2*NC*Pi*Log[3]^2)/
        (8678218953600*Sqrt[3]) - (530956301649319*CF*NC*NH*Pi*Log[3]^2)/
        (1033121304*Sqrt[3]) - 
       (CF*NC*(CA*(3443313905377338311 - 47200930600824000*lm) + 
          2*(11*CF*(-304460924410948789 + 10532439059688000*lm) + 
            4900*(5*(-51391112429407 + 175142599632*lm)*NM + 
              5148*(226820109 + 170107420*lm)*NL + 5*(25639008091 + 
                175142599632*lm)*NH)))*Log[x]^2)/81729648000 + 
       (CF*NC*(-3983623952639*CA + 6119556152756*CF + 
          19600*(205808565*NM + 1215053*NL))*Log[x]^3)/340200 + 
       (1820557727832420535399*CF^2*NC*PolyGamma[2, 1])/376572715308000 + 
       (28202314186*CF*NM*NC*PolyGamma[2, 1])/6075 - 
       (331052561381130289*CF*NC*NH*PolyGamma[2, 1])/2510484768720 - 
       (1542529045251482170201*CF^2*NC*Zeta[3])/659002251789000 + 
       (49954275919*CF*NM*NC*Zeta[3])/12150 - (22673497*CF*NC*NL*Zeta[3])/
        162 + (2423796518514152711*CF*NC*NH*Zeta[3])/1255242384360 + 
       CA*CF*NC*(53098631061854165684172464964437/
          13673632037962982012928000 + (1317745*lm^2)/32 - 
         (339067867144287101*Pi^2)/93405312000 + (632177796637255921*Pi^3)/
          (13389252099840*Sqrt[3]) + (172019063*Pi^4)/129600 + 
         lm*(412230694823/2612736 - (60445*Pi^2)/432) - 
         (14644852384955924338033*Im[PolyLog[2, (-1)^(1/3)]])/
          (16401833822304000*Sqrt[3]) + (11010901*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/60 + (632177796637255921*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(361592456400*Sqrt[3]) + 
         (632177796637255921*Pi*Log[3]^2)/(17356437907200*Sqrt[3]) - 
         (1820557727832420535399*PolyGamma[2, 1])/753145430616000 + 
         (416784380013588318439*Zeta[3])/329501125894500) + 
       CF*Log[x]*((5394080734469315983*NM*NC)/3005315913600 - 
         (207365237*lm*NM*NC)/2160 - 17325*lm^2*NM*NC - 
         (156423664039*NC*NL)/544320 - (207365237*lm*NC*NL)/2160 - 
         17325*lm^2*NC*NL - (8179872153581776541701*NC*NH)/
          1690103803639680 - (207365237*lm*NC*NH)/2160 - 17325*lm^2*NC*NH + 
         (239934331*NM*NC*Pi^2)/81 - (11312021*NC*NL*Pi^2)/486 + 
         (1061912603298638*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (129140163*Sqrt[3]) + CF*NC*(1079530013455703935683934163/
            19762691067559440000 - (167864237*lm)/80 - 467775*lm^2 + 
           (170921304541*Pi^2)/30240 + (632177796637255921*
             Im[PolyLog[2, (-1)^(1/3)]])/(542388684600*Sqrt[3]) - 
           138600*Zeta[3]) + CA*NC*(-854816687142378756540233719/
            31620305708095104000 + (2804925607*lm)/4320 + (190575*lm^2)/2 - 
           (31498342563*Pi^2)/11200 - (632177796637255921*
             Im[PolyLog[2, (-1)^(1/3)]])/(1084777369200*Sqrt[3]) + 
           69300*Zeta[3])), (14133206585626755430611776153849593*CF^2*NC)/
        282018660782986504016640000 + (53118060797*CF^2*lm*NC)/94080 + 
       (2866347*CF^2*lm^2*NC)/8 + (328268139126379716296321671*CF*NM*NC)/
        2526989832791424000 + (88698981557*CF*lm*NM*NC)/2540160 + 
       (106161*CF*lm^2*NM*NC)/8 - (93978658241501*CF*NC*NL)/640120320 + 
       (88698981557*CF*lm*NC*NL)/2540160 + (106161*CF*lm^2*NC*NL)/8 - 
       (40810452613945886097011232091749913*CF*NC*NH)/
        3958736229790893412096435200 + (88698981557*CF*lm*NC*NH)/2540160 + 
       (106161*CF*lm^2*NC*NH)/8 - (28185388754883631*CF^2*NC*Pi^2)/
        1061424000 - (5445*CF^2*lm*NC*Pi^2)/4 - 
       (11110196524213*CF*NM*NC*Pi^2)/136080 - (605*CF*lm*NM*NC*Pi^2)/12 + 
       (32333851*CF*NC*NL*Pi^2)/1512 - (605*CF*lm*NC*NL*Pi^2)/12 - 
       (605*CF*lm*NC*NH*Pi^2)/12 + (226220347853482127*CF^2*NC*Pi^3)/
        (1255242384360*Sqrt[3]) + (182300225303402185*CF*NC*NH*Pi^3)/
        (125524238436*Sqrt[3]) + (9857507*CF^2*NC*Pi^4)/1800 - 
       (19645599034253405435189*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6150687683364000*Sqrt[3]) - (3797260244644709851*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(878669669052*Sqrt[3]) + 
       (3442934*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (452440695706964254*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (67798585575*Sqrt[3]) + (20834311463245964*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) + 
       (226220347853482127*CF^2*NC*Pi*Log[3]^2)/(1627166053800*Sqrt[3]) + 
       (5208577865811491*CF*NC*NH*Pi*Log[3]^2)/(4649045868*Sqrt[3]) + 
       (CF*NC*(CA*(36139149155768362793 - 284944250190600000*lm) + 
          34*CF*(-2088772619703420631 + 41141683182600000*lm) + 
          1400*(17*(-9524686711981589 + 2176808634000*lm)*NM + 
            11231220*(4359203 + 3294900*lm)*NL + 523*(11202723859 + 
              70756686000*lm)*NH))*Log[x]^2)/231567336000 - 
       (CF*NC*(-2518419289111*CA + 4306973170984*CF + 14947843621200*NM + 
          8456910000*NL)*Log[x]^3)/56700 - (901608804253912894643*CF^2*NC*
         PolyGamma[2, 1])/50209695374400 - 
       (40705569584*CF*NM*NC*PolyGamma[2, 1])/675 + 
       (7699376881915883543*CF*NC*NH*PolyGamma[2, 1])/18828635765400 + 
       CA*CF*NC*(-14074452418276643238946226710158361/
          564037321565973008033280000 - (1167771*lm^2)/16 + 
         (28161719338224961*Pi^2)/2122848000 - (226220347853482127*Pi^3)/
          (2510484768720*Sqrt[3]) - (10002707*Pi^4)/3600 + 
         lm*(-1447604167207/5080320 + (6655*Pi^2)/24) + 
         (19645599034253405435189*Im[PolyLog[2, (-1)^(1/3)]])/
          (12301375366728000*Sqrt[3]) - (1721467*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/5 - (226220347853482127*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (67798585575*Sqrt[3]) - (226220347853482127*Pi*Log[3]^2)/
          (3254332107600*Sqrt[3]) + (901608804253912894643*PolyGamma[2, 1])/
          100419390748800 - (325080668266655035751*Zeta[3])/70293573524160) + 
       (1550200633143504375883*CF^2*NC*Zeta[3])/175733933810400 + 
       (2153462269*CF*NM*NC*Zeta[3])/225 + (2607055*CF*NC*NL*Zeta[3])/9 - 
       (33332933886043988257*CF*NC*NH*Zeta[3])/9414317882700 + 
       CF*Log[x]*((-292958794763669439091*NM*NC)/500885985600 + 
         (31770541*lm*NM*NC)/168 + 32670*lm^2*NM*NC + (25182303793*NC*NL)/
          42336 + (31770541*lm*NC*NL)/168 + 32670*lm^2*NC*NL + 
         (227268626729146459864962487*NC*NH)/21540203967007357632 + 
         (31770541*lm*NC*NH)/168 + 32670*lm^2*NC*NH - 
         (1779486416*NM*NC*Pi^2)/27 + (1300805*NC*NL*Pi^2)/27 - 
         (20834311463245964*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CA*NC*(5437643728103663254054063711/
            65216880522946152000 - (426315791*lm)/336 - 179685*lm^2 + 
           (2463060323713*Pi^2)/226800 + (226220347853482127*
             Im[PolyLog[2, (-1)^(1/3)]])/(203395756725*Sqrt[3]) - 
           130680*Zeta[3]) + CF*NC*(-218927143389908230327159538797/
            1304337610458923040000 + (233793549*lm)/56 + 882090*lm^2 - 
           (164697280121*Pi^2)/7560 - (452440695706964254*
             Im[PolyLog[2, (-1)^(1/3)]])/(203395756725*Sqrt[3]) + 
           261360*Zeta[3])), (-527008003585709240510999414542818857*CF^2*NC)/
        4351145052080363204828160000 - (1896717623135*CF^2*lm*NC)/3048192 - 
       (6610065*CF^2*lm^2*NC)/16 - (1332502764072328631713541431*CF*NM*NC)/
        15161938996748544000 - (3225975254375*CF*lm*NM*NC)/82301184 - 
       (2203355*CF*lm^2*NM*NC)/144 + (54536448785646853*CF*NC*NL)/
        288054144000 - (3225975254375*CF*lm*NC*NL)/82301184 - 
       (2203355*CF*lm^2*NC*NL)/144 + (1188251550009291756702506736204974263*
         CF*NC*NH)/97168980185776474660548864000 - 
       (3225975254375*CF*lm*NC*NH)/82301184 - (2203355*CF*lm^2*NC*NH)/144 + 
       (934721934274439861*CF^2*NC*Pi^2)/9552816000 + (91355*CF^2*lm*NC*Pi^2)/
        72 + (36160748429293*CF*NM*NC*Pi^2)/2449440 + 
       (91355*CF*lm*NM*NC*Pi^2)/1944 - (3042682049*CF*NC*NL*Pi^2)/122472 + 
       (91355*CF*lm*NC*NL*Pi^2)/1944 + (91355*CF*lm*NC*NH*Pi^2)/1944 - 
       (64166588287242164423*CF^2*NC*Pi^3)/(271132355021760*Sqrt[3]) - 
       (11149848589306130935*CF*NC*NH*Pi^3)/(6778308875544*Sqrt[3]) - 
       (599786957*CF^2*NC*Pi^4)/97200 + (194729042512893256319837*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(47448162128808000*Sqrt[3]) + 
       (753101688871601626301*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (237240810644040*Sqrt[3]) - (36706439*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - (9166655469606023489*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1046035320300*Sqrt[3]) - 
       (637134205103207482*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) - (9166655469606023489*CF^2*NC*Pi*Log[3]^2)/
        (50209695374400*Sqrt[3]) - (318567102551603741*CF*NC*NH*Pi*Log[3]^2)/
        (251048476872*Sqrt[3]) - 
       (CF*NC*(-51*CA*(-23836412993197213403 + 60785451250524000*lm) + 
          14*(17*CF*(-10163330651964634693 + 63943137029772000*lm) + 
            150*(1071*(-163233506687679 + 250609982480*lm)*NM + 
              11*(612612*(52831671 + 39829940*lm)*NL + (4043620763591 + 
                  24400299203280*lm)*NH))))*Log[x]^2)/2084106024000 + 
       (CF*NC*(-154939718423387*CA + 168*(1750375277751*CF + 
            50*(9012344247*NM + 21906467*NL)))*Log[x]^3)/1020600 + 
       (3789146606592732595137623*CF^2*NC*PolyGamma[2, 1])/
        61004779879896000 + (95823626759*CF*NM*NC*PolyGamma[2, 1])/2430 - 
       (997018212741547782241*CF*NC*NH*PolyGamma[2, 1])/3050238993994800 - 
       (859706473786987835654197*CF^2*NC*Zeta[3])/30502389939948000 + 
       (106412491933*CF*NM*NC*Zeta[3])/2430 - (18881863*CF*NC*NL*Zeta[3])/
        54 + (7109736504753399804359*CF*NC*NH*Zeta[3])/1525119496997400 + 
       CA*CF*NC*(3681851951261400226066841028608590961/
          60916030729125084867594240000 + (24236905*lm^2)/288 - 
         (934509228290412311*Pi^2)/19105632000 + (64166588287242164423*Pi^3)/
          (542264710043520*Sqrt[3]) + (202365119*Pi^4)/64800 - 
         (55*lm*(-965743302619 + 773521056*Pi^2))/164602368 - 
         (194729042512893256319837*Im[PolyLog[2, (-1)^(1/3)]])/
          (94896324257616000*Sqrt[3]) + (36706439*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/90 + (9166655469606023489*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(2092070640600*Sqrt[3]) + 
         (9166655469606023489*Pi*Log[3]^2)/(100419390748800*Sqrt[3]) - 
         (3789146606592732595137623*PolyGamma[2, 1])/122009559759792000 + 
         (873489395620780864895257*Zeta[3])/61004779879896000) + 
       CF*Log[x]*((-393134597939789486873*NM*NC)/7012403798400 - 
         (90020645077*lm*NM*NC)/408240 - 39325*lm^2*NM*NC - 
         (40305762018511*NC*NL)/57153600 - (90020645077*lm*NC*NL)/408240 - 
         39325*lm^2*NC*NL - (31600027164354401626488182933*NC*NH)/
          2643570486859993891200 - (90020645077*lm*NC*NH)/408240 - 
         39325*lm^2*NC*NH + 18549781*NM*NC*Pi^2 - (28277117*NC*NL*Pi^2)/
          486 + (637134205103207482*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*(1114523784815513331715343740513/
            1437433284995547840000 - (73074716077*lm)/15120 - 1061775*lm^2 + 
           (2197868653991*Pi^2)/29160 + (9166655469606023489*
             Im[PolyLog[2, (-1)^(1/3)]])/(3138105960900*Sqrt[3]) - 
           314600*Zeta[3]) + CA*NC*(-5451883314250302687406836976267/
            14086846192956368832000 + (1214983627847*lm)/816480 + 
           (432575*lm^2)/2 - (10979536531189*Pi^2)/291600 - 
           (9166655469606023489*Im[PolyLog[2, (-1)^(1/3)]])/
            (6276211921800*Sqrt[3]) + 157300*Zeta[3])), 
      (9430908435302745492225712175063529257*CF^2*NC)/
        15229007682281271216898560000 + (14680011739*CF^2*lm*NC)/13230 + 
       (2815263*CF^2*lm^2*NC)/4 + (49829550469054682933699441*CF*NM*NC)/
        30083212295136000 + (98035194751*CF*lm*NM*NC)/1428840 + 
       (104269*CF*lm^2*NM*NC)/4 - (28083354193442999*CF*NC*NL)/
        72013536000 + (98035194751*CF*lm*NC*NL)/1428840 + 
       (104269*CF*lm^2*NC*NL)/4 - (22125826997219043730942788919913437762493*
         CF*NC*NH)/916412798254581154582968904992000 + 
       (98035194751*CF*lm*NC*NH)/1428840 + (104269*CF*lm^2*NC*NH)/4 - 
       (1259239432294568171*CF^2*NC*Pi^2)/4191264000 - 2420*CF^2*lm*NC*Pi^2 - 
       (17206382741173*CF*NM*NC*Pi^2)/17010 - (2420*CF*lm*NM*NC*Pi^2)/27 + 
       (314541007*CF*NC*NL*Pi^2)/6804 - (2420*CF*lm*NC*NL*Pi^2)/27 - 
       (2420*CF*lm*NC*NH*Pi^2)/27 + (116748698650659161887*CF^2*NC*Pi^3)/
        (271132355021760*Sqrt[3]) + (11515180488661469305*CF*NC*NH*Pi^3)/
        (3389154437772*Sqrt[3]) + (131578447*CF^2*NC*Pi^4)/10800 - 
       (2341618041099352336853281*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (332137134901656000*Sqrt[3]) - (307925418579943178852*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(29655101330505*Sqrt[3]) + 
       (66018821*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
       (116748698650659161887*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7322247242100*Sqrt[3]) + (1316020627275596492*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) + 
       (116748698650659161887*CF^2*NC*Pi*Log[3]^2)/(351467867620800*
         Sqrt[3]) + (329005156818899123*CF*NC*NH*Pi*Log[3]^2)/
        (125524238436*Sqrt[3]) + CF*((-1491298741197747857*CF*NC)/416988000 + 
         CA*(24448328732809909189/13621608000 - (26948878*lm)/9)*NC + 
         14699388*CF*lm*NC - (4920247513353217*NM*NC)/405405 + 
         (4899796*lm*NM*NC)/9 + (290585218*NC*NL)/405 + 
         (4899796*lm*NC*NL)/9 + (37724280908557*NC*NH)/392837445 + 
         (4899796*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-63544630314686*CA + 122691875253379*CF + 
          37800*(10899218344*NM + 1224949*NL))*Log[x]^3)/127575 - 
       (1241233203972455480926783*CF^2*NC*PolyGamma[2, 1])/6100477987989600 - 
       (473188580779*CF*NM*NC*PolyGamma[2, 1])/675 + 
       (721352336540187717821*CF*NC*NH*PolyGamma[2, 1])/762559748498700 + 
       CA*CF*NC*(-168263635790060128899257861985173203/
          543893131510045400603520000 - (1146959*lm^2)/8 + 
         (13391531200475749577*Pi^2)/89159616000 - 
         (116748698650659161887*Pi^3)/(542264710043520*Sqrt[3]) - 
         (44375749*Pi^4)/7200 + lm*(-1599830155121/2857680 + 
           (13310*Pi^2)/27) + (2341618041099352336853281*
           Im[PolyLog[2, (-1)^(1/3)]])/(664274269803312000*Sqrt[3]) - 
         (66018821*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
         (116748698650659161887*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (14644494484200*Sqrt[3]) - (116748698650659161887*Pi*Log[3]^2)/
          (702935735241600*Sqrt[3]) + (1241233203972455480926783*
           PolyGamma[2, 1])/12200955975979200 - 
         (1978565223225662858795033*Zeta[3])/42703345915927200) + 
       (78305289541447811560901*CF^2*NC*Zeta[3])/854066918318544 + 
       (140784789892*CF*NM*NC*Zeta[3])/675 + (2061202*CF*NC*NL*Zeta[3])/3 - 
       (3107904610619027249179*CF*NC*NH*Zeta[3])/381279874249350 + 
       CF*Log[x]*((-852605389423499378743*NM*NC)/116873396640 + 
         (1173252146*lm*NM*NC)/2835 + 70785*lm^2*NM*NC + 
         (39624939857791*NC*NL)/28576800 + (1173252146*lm*NC*NL)/2835 + 
         70785*lm^2*NC*NL + (2591768331375810591522297266561*NC*NH)/
          104976184033210357419552 + (1173252146*lm*NC*NH)/2835 + 
         70785*lm^2*NC*NH - (21798927079*NM*NC*Pi^2)/27 + 
         (3086963*NC*NL*Pi^2)/27 - (1316020627275596492*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CA*NC*(2663076359375295711933071509357/2817369238591273766400 - 
           (7857615128*lm)/2835 - (778635*lm^2)/2 + (505908197676719*Pi^2)/
            4082400 + (116748698650659161887*Im[PolyLog[2, (-1)^(1/3)]])/
            (43933483452600*Sqrt[3]) - 283140*Zeta[3]) + 
         CF*NC*(-66664048292507707823443928809969/35217115482390922080000 + 
           (1922856067*lm)/210 + 1911195*lm^2 - (101243621152171*Pi^2)/
            408240 - (116748698650659161887*Im[PolyLog[2, (-1)^(1/3)]])/
            (21966741726300*Sqrt[3]) + 566280*Zeta[3])), 
      (-435201380798697174484154769309810583514509*CF^2*NC)/
        249400382476826284962075417600000 - (3239873082707*CF^2*lm*NC)/
        2721600 - (6314121*CF^2*lm^2*NC)/8 - (36653424272743318013479377631*
         CF*NM*NC)/53745026184001152000 - (5507273933807*CF*lm*NM*NC)/
        73483200 - (701569*CF*lm^2*NM*NC)/24 + (24304056839813*CF*NC*NL)/
        50803200 - (5507273933807*CF*lm*NC*NL)/73483200 - 
       (701569*CF*lm^2*NC*NL)/24 + 
       (72618371585103868190585872345274281003567*CF*NC*NH)/
        2618322280727374727379911157120000 - (5507273933807*CF*lm*NC*NH)/
        73483200 - (701569*CF*lm^2*NC*NH)/24 + 
       (350154131660042965453*CF^2*NC*Pi^2)/267478848000 + 
       (39809*CF^2*lm*NC*Pi^2)/18 - (101603057999*CF*NM*NC*Pi^2)/21870 + 
       (39809*CF*lm*NM*NC*Pi^2)/486 - (569096891*CF*NC*NL*Pi^2)/10935 + 
       (39809*CF*lm*NC*NL*Pi^2)/486 + (39809*CF*lm*NC*NH*Pi^2)/486 - 
       (19618754022104884091*CF^2*NC*Pi^3)/(36150980669568*Sqrt[3]) - 
       (12673165356885178201*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) - 
       (2598517229*CF^2*NC*Pi^4)/194400 + (388859919443358789848701*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(44284951320220800*Sqrt[3]) + 
       (6597021712658161528*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (847288609443*Sqrt[3]) - (151528663*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - (19618754022104884091*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(976299632280*Sqrt[3]) - 
       (7241808775362958972*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (52301766015*Sqrt[3]) - (19618754022104884091*CF^2*NC*Pi*Log[3]^2)/
        (46862382349440*Sqrt[3]) - (1810452193840739743*CF*NC*NH*Pi*
         Log[3]^2)/(627621192180*Sqrt[3]) - 
       (CF*NC*(CA*(88764297349404842672911 - 39549184726667616000*lm) + 
          2*(19*CF*(-4667610277217017813343 + 5109224821148448000*lm) + 
            840*(5225*(74793337465547 + 819179865504*lm)*NM + 
              9*(10161580*(61838961 + 46801720*lm)*NL + (87183781844787 + 
                  475579421917600*lm)*NH))))*Log[x]^2)/11313718416000 + 
       (CF*NC*(-516258564751651*CA + 1022318137885333*CF + 
          323400*(184555407*NM + 334298*NL))*Log[x]^3)/255150 + 
       (144998792807073452311405171*CF^2*NC*PolyGamma[2, 1])/
        183014339639688000 + (28992571833407*CF*NM*NC*PolyGamma[2, 1])/
        97200 - (6805577842986064675481*CF*NC*NH*PolyGamma[2, 1])/
        9150716981984400 - (281771966830544244687751793*CF^2*NC*Zeta[3])/
        640550188738908000 + (23544061874207*CF*NM*NC*Zeta[3])/48600 - 
       (21646625*CF*NC*NL*Zeta[3])/27 + (47462677986177591863239*CF*NC*NH*
         Zeta[3])/4575358490992200 + CA*CF*NC*
        (27191096581977649386037904543273114644669/
          31175047809603285620259427200000 + (7717259*lm^2)/48 - 
         (26933950799312923861*Pi^2)/41150592000 + 
         (19618754022104884091*Pi^3)/(72301961339136*Sqrt[3]) + 
         (2623994989*Pi^4)/388800 + lm*(90652908770677/146966400 - 
           (437899*Pi^2)/972) - (388859919443358789848701*
           Im[PolyLog[2, (-1)^(1/3)]])/(88569902640441600*Sqrt[3]) + 
         (151528663*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 + 
         (19618754022104884091*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1952599264560*Sqrt[3]) + (19618754022104884091*Pi*Log[3]^2)/
          (93724764698880*Sqrt[3]) - (144998792807073452311405171*
           PolyGamma[2, 1])/366028679279376000 + 
         (282413129371780401012196853*Zeta[3])/1281100377477816000) + 
       CF*Log[x]*((-13233987759851319908687*NM*NC)/7895784536640 - 
         (3409225853*lm*NM*NC)/7290 - (165165*lm^2*NM*NC)/2 - 
         (481498153999*NC*NL)/302400 - (3409225853*lm*NC*NL)/7290 - 
         (165165*lm^2*NC*NL)/2 - (101895451423640938088499280246073*NC*NH)/
          3749149429757512764984000 - (3409225853*lm*NC*NH)/7290 - 
         (165165*lm^2*NC*NH)/2 + (4739900627*NM*NC*Pi^2)/81 - 
         (64860257*NC*NL*Pi^2)/486 + (7241808775362958972*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(156905298045*Sqrt[3]) + 
         CF*NC*(70099364352995453786999057344209097/
            6785164249607317654080000 - (5547507031*lm)/540 - 
           (4459455*lm^2)/2 + (4124867887187917*Pi^2)/4082400 + 
           (19618754022104884091*Im[PolyLog[2, (-1)^(1/3)]])/
            (2928898896840*Sqrt[3]) - 660660*Zeta[3]) + 
         CA*NC*(-70079823917776994047740747318422701/
            13570328499214635308160000 + (45929854333*lm)/14580 + 
           (1816815*lm^2)/4 - (4124248039092589*Pi^2)/8164800 - 
           (19618754022104884091*Im[PolyLog[2, (-1)^(1/3)]])/
            (5857797793680*Sqrt[3]) + 330330*Zeta[3])), 
      (146536755805717490657840570757423423707585273*CF^2*NC)/
        20201430980622929081928108825600000 + (2173131482849*CF^2*lm*NC)/
        1058400 + (26039871*CF^2*lm^2*NC)/20 + 
       (216833280111530215334337313061263*CF*NM*NC)/
        10345917540420221760000 + (3627718676909*CF*lm*NM*NC)/28576800 + 
       (2893319*CF*lm^2*NM*NC)/60 - (168160004027792789*CF*NC*NL)/
        180033840000 + (3627718676909*CF*lm*NC*NL)/28576800 + 
       (2893319*CF*lm^2*NC*NL)/60 - 
       (13008989579569166453041779708408276467733103*CF*NC*NH)/
        247431455528736911737401604347840000 + (3627718676909*CF*lm*NC*NH)/
        28576800 + (2893319*CF*lm^2*NC*NH)/60 - 
       (51288430186099387663*CF^2*NC*Pi^2)/15466464000 - 
       (20449*CF^2*lm*NC*Pi^2)/5 - (1058817516250853*CF*NM*NC*Pi^2)/85050 - 
       (20449*CF*lm*NM*NC*Pi^2)/135 + (15874987843*CF*NC*NL*Pi^2)/170100 - 
       (20449*CF*lm*NC*NL*Pi^2)/135 - (20449*CF*lm*NC*NH*Pi^2)/135 + 
       (6953057325907136298899*CF^2*NC*Pi^3)/(7320573585587520*Sqrt[3]) + 
       (676339047335173767419*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) + 
       (163146841*CF^2*NC*Pi^4)/6480 - (130851458374770145960368347*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8967702642344712000*Sqrt[3]) - 
       (18547168999501563412528*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (800687735923635*Sqrt[3]) + (43885127*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + (6953057325907136298899*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(197700675536700*Sqrt[3]) + 
       (386479455620099295668*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1412147682405*Sqrt[3]) + 
       (6953057325907136298899*CF^2*NC*Pi*Log[3]^2)/(9489632425761600*
         Sqrt[3]) + (96619863905024823917*CF*NC*NH*Pi*Log[3]^2)/
        (16945772188860*Sqrt[3]) + 
       (CF*NC*(-57*CA*(-920674463654463408871 + 311295919354580160*lm) + 
          38*CF*(-2759946887631687621379 + 2292269951610999360*lm) + 
          336*(57*(-20591306275066379299 + 168450172810920*lm)*NM + 
            1109644536*(11370653 + 8652915*lm)*NL + 
            (1852137232545617 + 9601659850222440*lm)*NH))*Log[x]^2)/
        2639867630400 - (CF*NC*(-470730257451125*CA + 934277309791212*CF + 
          3378887937059040*NM + 69292543320*NL)*Log[x]^3)/85050 - 
       (368335183589172068626969339*CF^2*NC*PolyGamma[2, 1])/
        164712905675719200 - (8873430200791*CF*NM*NC*PolyGamma[2, 1])/1080 + 
       (83823862150252239387619*CF*NC*NH*PolyGamma[2, 1])/
        41178226418929800 + CA*CF*NC*
        (-146511491110100065581599467875047791799366927/
          40402861961245858163856217651200000 - (31826509*lm^2)/120 + 
         (541490281525233851*Pi^2)/326592000 - (6953057325907136298899*Pi^3)/
          (14641147171175040*Sqrt[3]) - (823586621*Pi^4)/64800 + 
         lm*(-59197325072479/57153600 + (224939*Pi^2)/270) + 
         (130851458374770145960368347*Im[PolyLog[2, (-1)^(1/3)]])/
          (17935405284689424000*Sqrt[3]) - 
         (43885127*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
         (6953057325907136298899*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (395401351073400*Sqrt[3]) - (6953057325907136298899*Pi*Log[3]^2)/
          (18979264851523200*Sqrt[3]) + (368335183589172068626969339*
           PolyGamma[2, 1])/329425811351438400 - 
         (122807952907726205888502361*Zeta[3])/230598067946006880) + 
       (612830781012535716528805121*CF^2*NC*Zeta[3])/576495169865017200 + 
       (1848134571713*CF*NM*NC*Zeta[3])/540 + (7550972*CF*NC*NL*Zeta[3])/
        5 - (359357522386772043613661*CF*NC*NH*Zeta[3])/20589113209464900 + 
       CF*Log[x]*((-37639018736860123243636727*NM*NC)/422205145362000 + 
         (23926309121*lm*NM*NC)/28350 + 143143*lm^2*NM*NC + 
         (214510492164259*NC*NL)/71442000 + (23926309121*lm*NC*NL)/28350 + 
         143143*lm^2*NC*NL + (1189427536288103665011930159509747*NC*NH)/
          22143413819505309768186750 + (23926309121*lm*NC*NH)/28350 + 
         143143*lm^2*NC*NH - (1340839271309*NM*NC*Pi^2)/135 + 
         (33938476*NC*NL*Pi^2)/135 - (386479455620099295668*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) + 
         CA*NC*(2773977398940550880774949818186882431/
            274799152109096364990240000 - (320002857031*lm)/56700 - 
           (1574573*lm^2)/2 + (1881075003616483*Pi^2)/1360800 + 
           (6953057325907136298899*Im[PolyLog[2, (-1)^(1/3)]])/
            (1186204053220200*Sqrt[3]) - 572572*Zeta[3]) + 
         CF*NC*(-2774696371667443426069351449749881981/
            137399576054548182495120000 + (9821377423*lm)/525 + 
           3864861*lm^2 - (1881298637932619*Pi^2)/680400 - 
           (6953057325907136298899*Im[PolyLog[2, (-1)^(1/3)]])/
            (593102026610100*Sqrt[3]) + 1145144*Zeta[3])), 
      (-565696844470856209556600209355039216737015773761*CF^2*NC)/
        23093602516015445095490816405798400000 - 
       (4964020648345877*CF^2*lm*NC)/2305195200 - (11410425*CF^2*lm^2*NC)/8 - 
       (41662178902574266470789995939793997*CF*NM*NC)/
        10917330524575738623360000 - (8434589272368377*CF*lm*NM*NC)/
        62240270400 - (1267825*CF*lm^2*NM*NC)/24 + 
       (10665716724911813281*CF*NC*NL)/9681819840000 - 
       (8434589272368377*CF*lm*NC*NL)/62240270400 - (1267825*CF*lm^2*NC*NL)/
        24 + (29082863439360889293471688240991829097002239*CF*NC*NH)/
        494862911057473823474803208695680000 - 
       (8434589272368377*CF*lm*NC*NH)/62240270400 - (1267825*CF*lm^2*NC*NH)/
        24 + (729856411287342309913973*CF^2*NC*Pi^2)/42323383872000 + 
       (330733*CF^2*lm*NC*Pi^2)/90 - (8462572813651441*CF*NM*NC*Pi^2)/
        4209975 + (330733*CF*lm*NM*NC*Pi^2)/2430 - 
       (1723072029263*CF*NC*NL*Pi^2)/16839900 + (330733*CF*lm*NC*NL*Pi^2)/
        2430 + (330733*CF*lm*NC*NH*Pi^2)/2430 - 
       (12422485513389797769287*CF^2*NC*Pi^3)/(10736841258861696*Sqrt[3]) - 
       (363174592259219773543*CF*NC*NH*Pi^3)/(45753584909922*Sqrt[3]) - 
       (5248947509*CF^2*NC*Pi^4)/194400 + (1828792536737619309836456621*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(103342097116543824000*Sqrt[3]) + 
       (14107644660969632704912*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (800687735923635*Sqrt[3]) - (294199087*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - (1774640787627113967041*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(41422998683880*Sqrt[3]) - 
       (415056676867679741192*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1412147682405*Sqrt[3]) - 
       (1774640787627113967041*CF^2*NC*Pi*Log[3]^2)/(1988303936826240*
         Sqrt[3]) - (51882084608459967649*CF*NC*NH*Pi*Log[3]^2)/
        (8472886094430*Sqrt[3]) - 
       (CF*NC*(CA*(90120630937935464079712775 - 6638099831136428054400*lm) + 
          2*(CF*(-90107203602512536605919549 + 16293517767334868860800*lm) + 
            9240*(13*(87486623512723016761 + 5023839668767920*lm)*NM + 
              9*(184940756*(51691683 + 39237740*lm)*NL + (1446871840867077 + 
                  7256657299331440*lm)*NH))))*Log[x]^2)/871156318032000 + 
       (CF*NC*(-15034822640503108*CA + 30016380749478541*CF - 
          2205465000082344*NM + 518456106168*NL)*Log[x]^3)/561330 + 
       (1109952930249457693844063561*CF^2*NC*PolyGamma[2, 1])/
        109808603783812800 + (170667882193841*CF*NM*NC*PolyGamma[2, 1])/
        97200 - (129879387656321554090223*CF*NC*NH*PolyGamma[2, 1])/
        82356452837859600 - (27775711533046096921927182881*CF^2*NC*Zeta[3])/
        4227631245676792800 + (266667220547201*CF*NM*NC*Zeta[3])/48600 - 
       (231172591*CF*NC*NL*Zeta[3])/135 + (888721024398336954524017*CF*NC*
         NH*Zeta[3])/41178226418929800 + 
       CA*CF*NC*(12444672734960300166036361648553055197330421408611/
          1016118510704679584201595921855129600000 + (13946075*lm^2)/48 - 
         (42932492172492742821193*Pi^2)/4979221632000 + 
         (12422485513389797769287*Pi^3)/(21473682517723392*Sqrt[3]) + 
         (5291281333*Pi^4)/388800 + lm*(12619198330998377/11316412800 - 
           (3638063*Pi^2)/4860) - (1828792536737619309836456621*
           Im[PolyLog[2, (-1)^(1/3)]])/(206684194233087648000*Sqrt[3]) + 
         (294199087*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 + 
         (1774640787627113967041*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (82845997367760*Sqrt[3]) + (1774640787627113967041*Pi*Log[3]^2)/
          (3976607873652480*Sqrt[3]) - (1109952930249457693844063561*
           PolyGamma[2, 1])/219617207567625600 + 
         (27784507239684413218272857909*Zeta[3])/8455262491353585600) + 
       CF*Log[x]*((-1885679370634403603540745427*NM*NC)/60296462298072000 - 
         (1303478577193*lm*NM*NC)/1403325 - (325325*lm^2*NM*NC)/2 - 
         (3516229366173173*NC*NL)/1047816000 - (1303478577193*lm*NC*NL)/
          1403325 - (325325*lm^2*NC*NL)/2 - 
         (40884409435056930018332351477590651*NC*NH)/
          708589242224169912581976000 - (1303478577193*lm*NC*NH)/1403325 - 
         (325325*lm^2*NC*NH)/2 - (397761121082*NM*NC*Pi^2)/405 - 
         (692856307*NC*NL*Pi^2)/2430 + (415056676867679741192*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) + 
         CF*NC*(97225224171889980536383264666710977373883/
            727484955350147776917495360000 - (4250114596897*lm)/207900 - 
           (8783775*lm^2)/2 + (601266685329473411*Pi^2)/44906400 + 
           (1774640787627113967041*Im[PolyLog[2, (-1)^(1/3)]])/
            (124268996051640*Sqrt[3]) - 1301300*Zeta[3]) + 
         CA*NC*(-97220937110317989661033677806900151076351/
            1454969910700295553834990720000 + (797000967659*lm)/127575 + 
           (3578575*lm^2)/4 - (601252304266665299*Pi^2)/89812800 - 
           (1774640787627113967041*Im[PolyLog[2, (-1)^(1/3)]])/
            (248537992103280*Sqrt[3]) + 650650*Zeta[3])), 
      (187355220724879348482765436391620469341261798103*CF^2*NC)/
        2283982666419109954499091732441600000 + (295098215851*CF^2*lm*NC)/
        81675 + (45815679*CF^2*lm^2*NC)/20 + 
       (190429258994407017806421001212194219*CF*NM*NC)/
        724108657242268378080000 + (3940739417123*CF*lm*NM*NC)/17641800 + 
       (1696877*CF*lm^2*NM*NC)/20 - (12828324763691987479*CF*NC*NL)/
        6224027040000 + (3940739417123*CF*lm*NC*NL)/17641800 + 
       (1696877*CF*lm^2*NC*NL)/20 - 
       (486280403854630671953522835901297256094540636929*CF*NC*NH)/
        4515747779127213007663447980150253920000 + 
       (3940739417123*CF*lm*NC*NH)/17641800 + (1696877*CF*lm^2*NC*NH)/20 - 
       (1025056568500085915777*CF^2*NC*Pi^2)/28791417600 - 
       (33124*CF^2*lm*NC*Pi^2)/5 - (20276411570696789*CF*NM*NC*Pi^2)/
        133650 - (33124*CF*lm*NM*NC*Pi^2)/135 + (47563769669*CF*NC*NL*Pi^2)/
        267300 - (33124*CF*lm*NC*NL*Pi^2)/135 - (33124*CF*lm*NC*NH*Pi^2)/
        135 + (94734795710665002586141*CF^2*NC*Pi^3)/(48315785664877632*
         Sqrt[3]) + (4152079439829572151397*CF*NC*NH*Pi^3)/
        (274521509459532*Sqrt[3]) + (528589243*CF^2*NC*Pi^4)/10800 - 
       (13299839723765310802994896579*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (465039437024447208000*Sqrt[3]) - (116600489571245881363436*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2402063207770905*Sqrt[3]) + 
       (49680085*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
       (13533542244380714655163*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(186403494077460*Sqrt[3]) + 
       (2372616822759755515084*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4236443047215*Sqrt[3]) + 
       (13533542244380714655163*CF^2*NC*Pi*Log[3]^2)/(8947367715718080*
         Sqrt[3]) + (593154205689938878771*CF*NC*NH*Pi*Log[3]^2)/
        (50837316566580*Sqrt[3]) + 
       (CF*NC*(-8073*CA*(-4207078480740909272769 + 277892731109593600*lm) + 
          10*(299*CF*(-22714879129104743974417 + 3683341835979886080*lm) + 
            704*(966*(-42570127057778779933 + 59979061282140*lm)*NM + 
              44663192574*(1700917 + 1297260*lm)*NL + (12052467930482627 + 
                57939773198547240*lm)*NH)))*Log[x]^2)/159020597736000 - 
       (CF*NC*(-12042239888195917*CA + 77*(312285100376359*CF + 
            1080*(1170979118603*NM + 4122404*NL)))*Log[x]^3)/200475 - 
       (11863064666333576065352804323*CF^2*NC*PolyGamma[2, 1])/
        494138717027157600 - (28994852355859*CF*NM*NC*PolyGamma[2, 1])/300 + 
       (12731821194879049491046*CF*NC*NH*PolyGamma[2, 1])/3088366981419735 + 
       CA*CF*NC*(-128802457287958705785043979684226620998533232951/
          3140476166326276187436251132107200000 - (18665647*lm^2)/40 + 
         (35876782957574031156199*Pi^2)/2015399232000 - 
         (94734795710665002586141*Pi^3)/(96631571329755264*Sqrt[3]) - 
         (11840647*Pi^4)/480 + lm*(-5845755349943/3207600 + 
           (182182*Pi^2)/135) + (13299839723765310802994896579*
           Im[PolyLog[2, (-1)^(1/3)]])/(930078874048894416000*Sqrt[3]) - 
         (49680085*Im[PolyLog[2, (-1)^(1/3)]]^2)/18 - 
         (13533542244380714655163*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (372806988154920*Sqrt[3]) - (13533542244380714655163*Pi*Log[3]^2)/
          (17894735431436160*Sqrt[3]) + (11863064666333576065352804323*
           PolyGamma[2, 1])/988277434054315200 - 
         (32772103063938039886391326801*Zeta[3])/5435525887298733600) + 
       (32760600565191503235317964373*CF^2*NC*Zeta[3])/2717762943649366800 + 
       (22297816103443*CF*NM*NC*Zeta[3])/450 + (46718126*CF*NC*NL*Zeta[3])/
        15 - (21726364331184024123248*CF*NC*NH*Zeta[3])/617673396283947 + 
       CF*Log[x]*((-46699547709623229710510965057*NM*NC)/43547444993052000 + 
         (36148692359*lm*NM*NC)/22275 + 273273*lm^2*NM*NC + 
         (1372411380150229*NC*NL)/224532000 + (36148692359*lm*NC*NL)/
          22275 + 273273*lm^2*NC*NL + 
         (61808069362928008781380875883910265229*NC*NH)/
          562265563704878825633797956000 + (36148692359*lm*NC*NH)/22275 + 
         273273*lm^2*NC*NH - (5464579923173*NM*NC*Pi^2)/45 + 
         (70010941*NC*NL*Pi^2)/135 - (2372616822759755515084*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) + 
         CA*NC*(1493301978208054052403325676669795836921/
            14389812303629296686280128000 - (43895981909*lm)/4050 - 
           (3006003*lm^2)/2 + (96319548280509439*Pi^2)/6415200 + 
           (13533542244380714655163*Im[PolyLog[2, (-1)^(1/3)]])/
            (1118420964464760*Sqrt[3]) - 1093092*Zeta[3]) + 
         CF*NC*(-7466885018812130802883446324235547598137/
            35974530759073241715700320000 + (59446721893*lm)/1650 + 
           7378371*lm^2 - (96321696002119759*Pi^2)/3207600 - 
           (13533542244380714655163*Im[PolyLog[2, (-1)^(1/3)]])/
            (559210482232380*Sqrt[3]) + 2186184*Zeta[3])), 
      (-563980113484260001420187308247944708321392140975873*CF^2*NC)/
        1679706109532225435108760605515622400000 - 
       (233130710236217*CF^2*lm*NC)/62726400 - (39358683*CF^2*lm^2*NC)/16 + 
       (441717675958914583994532671762065567*CF*NM*NC)/
        150273843691218990462720000 - (396004812226817*CF*lm*NM*NC)/
        1693612800 - (1457729*CF*lm^2*NM*NC)/16 + 
       (184616805111740708033*CF*NC*NL)/78422740704000 - 
       (396004812226817*CF*lm*NC*NL)/1693612800 - (1457729*CF*lm^2*NC*NL)/
        16 + (588135039677527668732036499223485297398000806149*CF*NC*NH)/
        5002059078417835946950280839551050496000 - 
       (396004812226817*CF*lm*NC*NH)/1693612800 - (1457729*CF*lm^2*NC*NH)/
        16 + (29960564125774941084361*CF^2*NC*Pi^2)/134359948800 + 
       (140777*CF^2*lm*NC*Pi^2)/24 - (6016707742015560389*CF*NM*NC*Pi^2)/
        134719200 + (140777*CF*lm*NM*NC*Pi^2)/648 - 
       (122355822329*CF*NC*NL*Pi^2)/641520 + (140777*CF*lm*NC*NL*Pi^2)/
        648 + (140777*CF*lm*NC*NH*Pi^2)/648 - 
       (10092546429335332535365751*CF^2*NC*Pi^3)/(4348420709838986880*
         Sqrt[3]) - (157172794890353269051115*CF*NC*NH*Pi^3)/
        (9882774340543152*Sqrt[3]) - (1111668649*CF^2*NC*Pi^4)/21600 + 
       (56747788953298403504653114739*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1674141973288009948800*Sqrt[3]) + (6450837595906808441888309*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(172948550959505160*Sqrt[3]) - 
       (180836929*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
       (1441792347047904647909393*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16776314466971400*Sqrt[3]) - 
       (4490651282581521972889*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (1441792347047904647909393*CF^2*NC*Pi*Log[3]^2)/(805263094414627200*
         Sqrt[3]) - (4490651282581521972889*CF*NC*NH*Pi*Log[3]^2)/
        (366028679279376*Sqrt[3]) - 
       (CF*NC*(-161*CA*(-7928618983619715288283723 + 92432895660679860000*
             lm) + 110*(69*CF*(-336357695952345883821857 + 
              9625243680368316000*lm) + 20*(391*(594461308596998949499 + 
                3145504470708600*lm)*NM + 143*(133855722*(84451841 + 
                  64253100*lm)*NL + 5*(368262313293181 + 1720129018247640*
                   lm)*NH))))*Log[x]^2)/954123586416000 + 
       (CF*NC*(-186456626408736125*CA + 372800915951853324*CF - 
          62795908835298320*NM + 1010701263000*NL)*Log[x]^3)/534600 + 
       (5708000551742279227887045388987*CF^2*NC*PolyGamma[2, 1])/
        44472484532444184000 + (231408794391143*CF*NM*NC*PolyGamma[2, 1])/
        97200 - (3504605527138303052881831*CF*NC*NH*PolyGamma[2, 1])/
        1111812113311104600 - (22523337080031391493240280590893*CF^2*NC*
         Zeta[3])/244598664928443012000 + (3086860318446863*CF*NM*NC*
         Zeta[3])/48600 - (31011682*CF*NC*NL*Zeta[3])/9 + 
       (23589517236557341608495269*CF*NC*NH*Zeta[3])/555906056655552300 + 
       CA*CF*NC*(789565774087477617361695034090214750484602971311421/
          4703177106690231218304529695443742720000 + (16035019*lm^2)/32 - 
         (29960539857946929848453*Pi^2)/268719897600 + 
         (10092546429335332535365751*Pi^3)/(8696841419677973760*Sqrt[3]) + 
         (3357530267*Pi^4)/129600 + lm*(592388896923617/307929600 - 
           (1548547*Pi^2)/1296) - (56747788953298403504653114739*
           Im[PolyLog[2, (-1)^(1/3)]])/(3348283946576019897600*Sqrt[3]) + 
         (180836929*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (1441792347047904647909393*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33552628933942800*Sqrt[3]) + (1441792347047904647909393*Pi*
           Log[3]^2)/(1610526188829254400*Sqrt[3]) - 
         (5708000551742279227887045388987*PolyGamma[2, 1])/
          88944969064888368000 + (22524338992047600863027759476393*Zeta[3])/
          489197329856886024000) + CF*Log[x]*
        ((-39551777283724572489389494433*NM*NC)/80690853957714000 - 
         (373420872877*lm*NM*NC)/213840 - (910910*lm^2*NM*NC)/3 - 
         (15105907211801663*NC*NL)/2263282560 - (373420872877*lm*NC*NL)/
          213840 - (910910*lm^2*NC*NL)/3 - 
         (3600155795910670691394737689525320067*NC*NH)/
          31140861989808673419718040640 - (373420872877*lm*NC*NH)/213840 - 
         (910910*lm^2*NC*NH)/3 - (142716368688059*NM*NC*Pi^2)/4860 - 
         (185929315*NC*NL*Pi^2)/324 + (4490651282581521972889*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(14231704298685504058196445803007166389681653/
            8418040197623138561473874880000 - (304884004477*lm)/7920 - 
           8198190*lm^2 + (124300277898615299*Pi^2)/712800 + 
           (1441792347047904647909393*Im[PolyLog[2, (-1)^(1/3)]])/
            (50328943400914200*Sqrt[3]) - (7287280*Zeta[3])/3) + 
         CA*NC*(-3557902058201008806330905830056723883977929/
            4209020098811569280736937440000 + (456058628077*lm)/38880 + 
           (5010005*lm^2)/3 - (41433274419252209*Pi^2)/475200 - 
           (1441792347047904647909393*Im[PolyLog[2, (-1)^(1/3)]])/
            (100657886801828400*Sqrt[3]) + (3643640*Zeta[3])/3)), 
      (130553707617825060875722901550494592944796007273403*CF^2*NC)/
        145159787243525654885942274550732800000 + (2547853421765*CF^2*lm*NC)/
        418176 + (30901689*CF^2*lm^2*NC)/8 + 
       (39680157856838282124953059844525511803*CF*NM*NC)/
        12165025441670108751744000 + (4252885014029*CF*lm*NM*NC)/11290752 + 
       (1144507*CF*lm^2*NM*NC)/8 - (45297944526257743219*CF*NC*NL)/
        10650001824000 + (4252885014029*CF*lm*NC*NL)/11290752 + 
       (1144507*CF*lm^2*NC*NL)/8 - 
       (1761312774367948553707520764786318589917310698357*CF*NC*NH)/
        8414436855516545977012635987857616000000 + 
       (4252885014029*CF*lm*NC*NH)/11290752 + (1144507*CF*lm^2*NC*NH)/8 - 
       (9239950554367565407027633*CF^2*NC*Pi^2)/24890180515200 - 
       (41405*CF^2*lm*NC*Pi^2)/4 - (1172430134659772411*CF*NM*NC*Pi^2)/
        641520 - (41405*CF*lm*NM*NC*Pi^2)/108 + (3455726729*CF*NC*NL*Pi^2)/
        10692 - (41405*CF*lm*NC*NL*Pi^2)/108 - (41405*CF*lm*NC*NH*Pi^2)/
        108 + (57795375267089321257193*CF^2*NC*Pi^3)/(15098683020274260*
         Sqrt[3]) + (48390154742099728107935*CF*NC*NH*Pi^3)/
        (1647129056757192*Sqrt[3]) + (975944333*CF^2*NC*Pi^4)/10800 - 
       (552862110430908255863875963*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (10334209711654382400*Sqrt[3]) - (4367707917975680755628851*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(45296049060822780*Sqrt[3]) + 
       (447111119*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
       (33025928724051040718396*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(233004367596825*Sqrt[3]) + 
       (2765151699548555891882*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) + 
       (8256482181012760179599*CF^2*NC*Pi*Log[3]^2)/(2796052411161900*
         Sqrt[3]) + (1382575849774277945941*CF*NC*NH*Pi*Log[3]^2)/
        (61004779879896*Sqrt[3]) + CF*((-9239394437221443393200329*CF*NC)/
          2074181709600 + CA*(46198268319924141760979957/20741817096000 - 
           (55951181*lm)/2)*NC + 137334717*CF*lm*NC - 
         (9846060934240600015867*NM*NC)/448957080 + 5086471*lm*NM*NC + 
         (1198362191*NC*NL)/180 + 5086471*lm*NC*NL + 
         (281519230349059*NC*NH)/249420600 + 5086471*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-508445310885174283*CA + 40*(25414031787468653*CF + 
            495*(238049205898090*NM + 137334717*NL)))*Log[x]^3)/801900 - 
       (82915486849762500540974817073*CF^2*NC*PolyGamma[2, 1])/
        329425811351438400 - (6135239160563617*CF*NM*NC*PolyGamma[2, 1])/
        5400 + (1469082417728157917812933*CF*NC*NH*PolyGamma[2, 1])/
        185302018885184100 + CA*CF*NC*
        (-130552906588624822368961548571608954852549880650749/
          290319574487051309771884549101465600000 - (12589577*lm^2)/16 + 
         (18704335278550852426373*Pi^2)/100769961600 - 
         (57795375267089321257193*Pi^3)/(30197366040548520*Sqrt[3]) - 
         (982569133*Pi^4)/21600 + lm*(-6308712579821/2052864 + 
           (455455*Pi^2)/216) + (552862110430908255863875963*
           Im[PolyLog[2, (-1)^(1/3)]])/(20668419423308764800*Sqrt[3]) - 
         (447111119*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
         (16512964362025520359198*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (233004367596825*Sqrt[3]) - (8256482181012760179599*Pi*Log[3]^2)/
          (5592104822323800*Sqrt[3]) + (82915486849762500540974817073*
           PolyGamma[2, 1])/658851622702876800 - 
         (236745161036976263540410589941*Zeta[3])/3623683924865822400) + 
       (236730439577670923216130067261*CF^2*NC*Zeta[3])/1811841962432911200 + 
       (199958401948687*CF*NM*NC*Zeta[3])/300 + (54763124*CF*NC*NL*Zeta[3])/
        9 - (6238031305076214617072567*CF*NC*NH*Zeta[3])/92651009442592050 + 
       CF*Log[x]*((-1483920728298306293353723988*NM*NC)/116644941945675 + 
         (105816268649*lm*NM*NC)/35640 + 496860*lm^2*NM*NC + 
         (81645670950102223*NC*NL)/6915585600 + (105816268649*lm*NC*NL)/
          35640 + 496860*lm^2*NC*NL + 
         (11185636933717969909463665448171113747*NC*NH)/
          52384990407286847108738940000 + (105816268649*lm*NC*NH)/35640 + 
         496860*lm^2*NC*NH - (238049302477469*NM*NC*Pi^2)/162 + 
         (6080191*NC*NL*Pi^2)/6 - (2765151699548555891882*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CA*NC*(1925841326615701438658353291704792156420463/
            1870675599471808569216416640000 - (128353838249*lm)/6480 - 
           2732730*lm^2 + (254213507414674339*Pi^2)/1603800 + 
           (16512964362025520359198*Im[PolyLog[2, (-1)^(1/3)]])/
            (699013102790475*Sqrt[3]) - 1987440*Zeta[3]) + 
         CF*NC*(-385171961212365499495553417364659476638299/
            187067559947180856921641664000 + (87124395449*lm)/1320 + 
           13415220*lm^2 - (127107272950431479*Pi^2)/400950 - 
           (33025928724051040718396*Im[PolyLog[2, (-1)^(1/3)]])/
            (699013102790475*Sqrt[3]) + 3974880*Zeta[3])), 
      (-25045981332336266873573976078315065374754893551610287146491*CF^2*NC)/
        5579296696067254215228343248435241723238400000 - 
       (39200822878922011*CF^2*lm*NC)/6360456960 - (65233035*CF^2*lm^2*NC)/
        16 + (3505277806918652723622777240418356128562977*CF*NM*NC)/
        6216498311049608953663708416000 - (66573483706233811*CF*lm*NM*NC)/
        171732337920 - (7248115*CF*lm^2*NM*NC)/48 + 
       (344754072034707186182159*CF*NC*NL)/72893937484368000 - 
       (66573483706233811*CF*lm*NC*NL)/171732337920 - 
       (7248115*CF*lm^2*NC*NL)/48 + 
       (57480913262686135622067706389650330583033612639997*CF*NC*NH)/
        256684610603020528856659148345382854400000 - 
       (66573483706233811*CF*lm*NC*NH)/171732337920 - 
       (7248115*CF*lm^2*NC*NH)/48 + (7132993520051579281722281*CF^2*NC*Pi^2)/
        2521342961280 + (651455*CF^2*lm*NC*Pi^2)/72 - 
       (261113155972114564997*CF*NM*NC*Pi^2)/350269920 + 
       (651455*CF*lm*NM*NC*Pi^2)/1944 - (1699967968445*CF*NC*NL*Pi^2)/
        5003856 + (651455*CF*lm*NC*NL*Pi^2)/1944 + 
       (651455*CF*lm*NC*NH*Pi^2)/1944 - (93727826294158958276460253*CF^2*NC*
         Pi^3)/(21198550960465061040*Sqrt[3]) - 
       (899181298862697350610845*CF*NC*NH*Pi^3)/(29648323021629456*
         Sqrt[3]) - (567453278*CF^2*NC*Pi^4)/6075 + 
       (13186866525872253767049673158041*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (212197495114255261010400*Sqrt[3]) + (425981428430851748666598109*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(5707302181663670280*Sqrt[3]) - 
       (478663696*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (13389689470594136896637179*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81784533026485575*Sqrt[3]) - 
       (25690894253219924303167*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (13389689470594136896637179*CF^2*NC*Pi*Log[3]^2)/
        (3925657585271307600*Sqrt[3]) - (25690894253219924303167*CF*NC*NH*Pi*
         Log[3]^2)/(1098086037838128*Sqrt[3]) - 
       (CF*NC*(CA*(78952972954943165044000823949 - 140778211421188840999500*
             lm) + 5*(8*CF*(-3947634322311111494854001191 + 
              17277325947145903213575*lm) + 
            2145*(3*(1293209012262708569461651 + 795525670247588280*lm)*NM + 
              19*(91585494*(1799338763 + 1371497940*lm)*NL + 
                (28587634527801161 + 125609316354882360*lm)*NH))))*Log[x]^2)/
        4651352483778000 + (CF*NC*(-92940709103695196277*CA + 
          520*(357446678304729472*CF + 165*(-518358358911254*NM + 
              891473661*NL)))*Log[x]^3)/20849400 + 
       (1994233957256014496544236996533*CF^2*NC*PolyGamma[2, 1])/
        1235346792567894000 - (5168481833609837*CF*NM*NC*PolyGamma[2, 1])/
        32400 - (148025470831078467734353*CF*NC*NH*PolyGamma[2, 1])/
        24706935851357880 - (108562982726424628342508889423361*CF^2*NC*
         Zeta[3])/88327295668604421000 + (12110846317264363*CF*NM*NC*
         Zeta[3])/16200 - (533777458*CF*NC*NL*Zeta[3])/81 + 
       (982142473135280921364347*CF*NC*NH*Zeta[3])/12353467925678940 + 
       CA*CF*NC*(25045951341472784761428167367095986248478356623924130973303/
          11158593392134508430456686496870483446476800000 + 
         (79729265*lm^2)/96 - (13139723394391154979928117*Pi^2)/
          9289158278400 + (93727826294158958276460253*Pi^3)/
          (42397101920930122080*Sqrt[3]) + (190236851*Pi^4)/4050 + 
         lm*(99577840301844211/31224061440 - (7166005*Pi^2)/3888) - 
         (13186866525872253767049673158041*Im[PolyLog[2, (-1)^(1/3)]])/
          (424394990228510522020800*Sqrt[3]) + 
         (239331848*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (13389689470594136896637179*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (163569066052971150*Sqrt[3]) + (13389689470594136896637179*Pi*
           Log[3]^2)/(7851315170542615200*Sqrt[3]) - 
         (1994233957256014496544236996533*PolyGamma[2, 1])/
          2470693585135788000 + (13570457810471175346643752773017*Zeta[3])/
          22081823917151105250) + CF*Log[x]*
        ((-25376348941372642300151415235453*NM*NC)/3628264248208610010 - 
         (26130565867583*lm*NM*NC)/8339760 - 541450*lm^2*NM*NC - 
         (20445077379889330481*NC*NL)/1618247030400 - 
         (26130565867583*lm*NC*NL)/8339760 - 541450*lm^2*NC*NL - 
         (352307586039294852378983213283498392707*NC*NH)/
          1598017917898076662327636296000 - (26130565867583*lm*NC*NH)/
          8339760 - 541450*lm^2*NC*NH - (518357606557795*NM*NC*Pi^2)/972 - 
         (39514943*NC*NL*Pi^2)/36 + (25690894253219924303167*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(182077322331337602715535568867327306672708239731/
            8683629365858148583088375632464000 - (21364138201583*lm)/308880 - 
           14619150*lm^2 + (92940235672403314799*Pi^2)/41698800 + 
           (13389689470594136896637179*Im[PolyLog[2, (-1)^(1/3)]])/
            (245353599079456725*Sqrt[3]) - 4331600*Zeta[3]) + 
         CA*NC*(-3641542784810409021958168779726245548799311151303/
            347345174634325943323535025298560000 + (31877646115583*lm)/
            1516320 + 2977975*lm^2 - (92940185237634037907*Pi^2)/83397600 - 
           (13389689470594136896637179*Im[PolyLog[2, (-1)^(1/3)]])/
            (490707198158913450*Sqrt[3]) + 2165800*Zeta[3])), 
      (4902486753269173453644059419961300953177733498460849570517*CF^2*NC)/
        512384390455155999357704992203236484787200000 + 
       (27344474212217*CF^2*lm*NC)/2760615 + 6279651*CF^2*lm^2*NC + 
       (2584825959766696328200396695048572719467931*CF*NM*NC)/
        64755190740100093267330296000 + (91286534664649*CF*lm*NM*NC)/
        149073210 + (697739*CF*lm^2*NM*NC)/3 - 
       (106694322742783539493*CF*NC*NL)/12856073630400 + 
       (91286534664649*CF*lm*NC*NL)/149073210 + (697739*CF*lm^2*NC*NL)/3 - 
       (190518429026580848506854089357060105096548837231369*CF*NC*NH)/
        489877995682103911099204401418085581500000 + 
       (91286534664649*CF*lm*NC*NH)/149073210 + (697739*CF*lm^2*NC*NH)/3 - 
       (606892417241580686367397423*CF^2*NC*Pi^2)/161786173348800 - 
       15680*CF^2*lm*NC*Pi^2 - (79362538528073478131*CF*NM*NC*Pi^2)/
        3648645 - (15680*CF*lm*NM*NC*Pi^2)/27 + (19566970001*CF*NC*NL*Pi^2)/
        34749 - (15680*CF*lm*NC*NL*Pi^2)/27 - (15680*CF*lm*NC*NH*Pi^2)/27 + 
       (2718486903710286174918956791*CF^2*NC*Pi^3)/(381573917288371098720*
         Sqrt[3]) + (909808881098152196086660*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) + (1293180091*CF^2*NC*Pi^4)/8100 - 
       (183529011147997110152446752342301*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1909777456028297349093600*Sqrt[3]) - 
       (33550225223625803161281524*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (183448998696332259*Sqrt[3]) + 
       (85868076*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (388355271958612310702708113*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1472121594476740350*
         Sqrt[3]) + (415912631359155289639616*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (388355271958612310702708113*CF^2*NC*Pi*Log[3]^2)/
        (70661836534883536800*Sqrt[3]) + (25994539459947205602476*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((-872398054334415469572359254*CF*NC)/19380635349075 + 
         CA*(9970315865171052467109937207/442985950836000 - (158518360*lm)/3)*
          NC + 259393680*CF*lm*NC - (2358336924964258727636842*NM*NC)/
          9035261235 + (28821520*lm*NM*NC)/3 + (113014460*NC*NL)/9 + 
         (28821520*lm*NC*NL)/3 + (4850357039074216*NC*NH)/2151252675 + 
         (28821520*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-11283064504197251859*CA + 40*(564117095565998119*CF + 
            85800*(35585913674525*NM + 3242421*NL)))*Log[x]^3)/1737450 - 
       (77200540748696125869130321666361*CF^2*NC*PolyGamma[2, 1])/
        30018927059399824200 - (8980299992607626*CF*NM*NC*PolyGamma[2, 1])/
        675 + (54715407246471685484631037*CF*NC*NH*PolyGamma[2, 1])/
        3752365882424978025 + CA*CF*NC*
        (-7506924484658444964301526464960743423420132809108936066087/
          1569177195768915248032971538622411734660800000 - (7675129*lm^2)/6 + 
         (1213784630617859128162712017*Pi^2)/647144693395200 - 
         (2718486903710286174918956791*Pi^3)/(763147834576742197440*
           Sqrt[3]) - (1300706491*Pi^4)/16200 + 
         lm*(-135413767834669/27104220 + (86240*Pi^2)/27) + 
         (183529011147997110152446752342301*Im[PolyLog[2, (-1)^(1/3)]])/
          (3819554912056594698187200*Sqrt[3]) - 
         (42934038*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (388355271958612310702708113*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2944243188953480700*Sqrt[3]) - (388355271958612310702708113*Pi*
           Log[3]^2)/(141323673069767073600*Sqrt[3]) + 
         (77200540748696125869130321666361*PolyGamma[2, 1])/
          60037854118799648400 - (362356367338292592087957090723796*Zeta[3])/
          536588321186771857575) + (2898818880835856429082276818087003*CF^2*
         NC*Zeta[3])/2146353284747087430300 + 
       (1921096832704516*CF*NM*NC*Zeta[3])/225 + 
       (102121040*CF*NC*NL*Zeta[3])/9 - (462609530454594138898976326*CF*NC*
         NH*Zeta[3])/3752365882424978025 + CF*Log[x]*
        ((-3603984885930884900608117841062717*NM*NC)/24188428321390733400 + 
         (60289217288*lm*NM*NC)/11583 + 866320*lm^2*NM*NC + 
         (874746759945701*NC*NL)/40135095 + (60289217288*lm*NC*NL)/11583 + 
         866320*lm^2*NC*NL + (879456269032834956195128504811023948647*NC*
           NH)/2218028116563077185535923755000 + (60289217288*lm*NC*NH)/
          11583 + 866320*lm^2*NC*NH - (1423436655137776*NM*NC*Pi^2)/81 + 
         (17009720*NC*NL*Pi^2)/9 - (415912631359155289639616*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(1918231665934674883792581821151620069346884223043/
            195381660731808343119488451730440000 - (36530253364*lm)/1053 - 
           4764760*lm^2 + (22565978731531849453*Pi^2)/13899600 + 
           (388355271958612310702708113*Im[PolyLog[2, (-1)^(1/3)]])/
            (8832729566860442100*Sqrt[3]) - 3465280*Zeta[3]) + 
         CF*NC*(-3069176267811667609548679649299074066256230777781/
            156305328585446674495590761384352000 + (49697155808*lm)/429 + 
           23390640*lm^2 - (2507332819521779819*Pi^2)/772200 - 
           (388355271958612310702708113*Im[PolyLog[2, (-1)^(1/3)]])/
            (4416364783430221050*Sqrt[3]) + 6930560*Zeta[3])), 
      (-102936154672952723068112325910904670669396029497842460842270037*CF^2*
         NC)/1757478459261185077796928123257101142820096000000 - 
       (192335912988140239*CF^2*lm*NC)/19478899440 - (13058595*CF^2*lm^2*NC)/
        2 + (2394931745953394241570198388477505775921521551*CF*NM*NC)/
        194265572220300279801990888000000 - (326585194038724939*CF*lm*NM*NC)/
        525930284880 - (1450955*CF*lm^2*NM*NC)/6 + 
       (23909739480288411812791*CF*NC*NL)/2650688635795200 - 
       (326585194038724939*CF*lm*NC*NL)/525930284880 - 
       (1450955*CF*lm^2*NC*NL)/6 + 
       (344971800008526136273891076249114672418457804281799*CF*NC*NH)/
        844097469483009816047859891674239771200000 - 
       (326585194038724939*CF*lm*NC*NH)/525930284880 - 
       (1450955*CF*lm^2*NC*NH)/6 + (239447930986552554244378549229*CF^2*NC*
         Pi^2)/6795019280649600 + (121960*CF^2*lm*NC*Pi^2)/9 - 
       (120406937174500944148*CF*NM*NC*Pi^2)/10945935 + 
       (121960*CF*lm*NM*NC*Pi^2)/243 - (1273847473154*CF*NC*NL*Pi^2)/
        2189187 + (121960*CF*lm*NC*NL*Pi^2)/243 + (121960*CF*lm*NC*NH*Pi^2)/
        243 - (6148453947083496040055474813*CF^2*NC*Pi^3)/
        (763147834576742197440*Sqrt[3]) - (924151935774006852462620*CF*NC*NH*
         Pi^3)/(16677181699666569*Sqrt[3]) - (7900492699*CF^2*NC*Pi^4)/
        48600 + (586420161792194559926241669422029*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5347376876879232577462080*Sqrt[3]) + 
       (913816077134260272992168144*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (6420714954371629065*Sqrt[3]) - 
       (813129346*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (6148453947083496040055474813*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(20609702322674364900*
         Sqrt[3]) - (422469456353831703982912*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (6148453947083496040055474813*CF^2*NC*Pi*Log[3]^2)/
        (989265711488369515200*Sqrt[3]) - (26404341022114481498932*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((1376823955848392863398516046753*CF*NC)/3255946738644600 - 
         275373228*CF*lm*NC + CA*(-145695735572090897215400516363/
            689089256856000 + (504850918*lm)/9)*NC - 
         (1834878674375036371878161*NM*NC)/13900401900 - 
         (91791076*lm*NM*NC)/9 - (5411096977*NC*NL)/405 - 
         (91791076*lm*NC*NL)/9 - (37917824751177509*NC*NH)/15489019260 - 
         (91791076*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-4081085413090624662777*CA + 2800*(2915038328537414111*CF - 
            858*(996632915281258*NM - 206529921*NL)))*Log[x]^3)/72972900 + 
       (6020533655545583464704754989305939*CF^2*NC*PolyGamma[2, 1])/
        300189270593998242000 - (135452206037635*CF*NM*NC*PolyGamma[2, 1])/
        36 - (163661196046398055562479373*CF*NC*NH*PolyGamma[2, 1])/
        15009463529699912100 - (2376039806738743995738597028483672391*CF^2*NC*
         Zeta[3])/150244729932296120121000 + 
       (479543782847527*CF*NM*NC*Zeta[3])/54 - (976975924*CF*NC*NL*Zeta[3])/
        81 + (1072217549450912963786439427*CF*NC*NH*Zeta[3])/
        7504731764849956050 + CA*CF*NC*
        (3216754277009464136020412568864200432711897710276512092947931/
          109842403703824067362308007703568821426256000000 + 
         (15960505*lm^2)/12 - (478895854332065602492847754127*Pi^2)/
          27180077122598400 + (6148453947083496040055474813*Pi^3)/
          (1526295669153484394880*Sqrt[3]) + (2646506633*Pi^4)/32400 + 
         lm*(488455140568616539/95623688160 - (670780*Pi^2)/243) - 
         (586420161792194559926241669422029*Im[PolyLog[2, (-1)^(1/3)]])/
          (10694753753758465154924160*Sqrt[3]) + 
         (406564673*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (6148453947083496040055474813*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (41219404645348729800*Sqrt[3]) + (6148453947083496040055474813*Pi*
           Log[3]^2)/(1978531422976739030400*Sqrt[3]) - 
         (6020533655545583464704754989305939*PolyGamma[2, 1])/
          600378541187996484000 + (594010473088105736627979067097953379*
           Zeta[3])/75122364966148060060500) + 
       CF*Log[x]*((-681999858520469390160734751770573351*NM*NC)/
          7256528496417220020000 - (19703995342589*lm*NM*NC)/3648645 - 
         928200*lm^2*NM*NC - (842775307468992907*NC*NL)/36778341600 - 
         (19703995342589*lm*NC*NL)/3648645 - 928200*lm^2*NC*NL - 
         (55036337147693441589490432760020623278069*NC*NH)/
          136630531980285554629012903308000 - (19703995342589*lm*NC*NH)/
          3648645 - 928200*lm^2*NC*NH - (1993265428798192*NM*NC*Pi^2)/243 - 
         (54249338*NC*NL*Pi^2)/27 + (422469456353831703982912*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(2794693227074213093139562589773499686405347894505177/
            10941373000981267214691353296904640000 - (16129174593089*lm)/
            135135 - 25061400*lm^2 + (8162164647368989373693*Pi^2)/
            291891600 + (6148453947083496040055474813*
             Im[PolyLog[2, (-1)^(1/3)]])/(61829106968023094700*Sqrt[3]) - 
           7425600*Zeta[3]) + CA*NC*
          (-26872046325002869329105412302184071177961132798409/
            210411019249639754128679871094320000 + (24014305528589*lm)/
            663390 + 5105100*lm^2 - (8162164005755049252539*Pi^2)/583783200 - 
           (6148453947083496040055474813*Im[PolyLog[2, (-1)^(1/3)]])/
            (123658213936046189400*Sqrt[3]) + 3712800*Zeta[3])), 
      (7885008637092324870232960212652743245526538108062693927430537*CF^2*NC)/
        79885384511872048990769460148050051946368000000 + 
       (3376274736081899*CF^2*lm*NC)/216432216 + 9890073*CF^2*lm^2*NC + 
       (15597620357508458059952417976478502355026763287*CF*NM*NC)/
        32377595370050046633665148000000 + (5635723508306543*CF*lm*NM*NC)/
        5843669832 + 366299*CF*lm^2*NM*NC - (12042151105827153215767*CF*NC*
         NL)/779935133577600 + (5635723508306543*CF*lm*NC*NL)/5843669832 + 
       366299*CF*lm^2*NC*NL - 
       (6196997161921218616309951925448048357777868062072259877*CF*NC*NH)/
        8920900379395821441556210455818647971245280000 + 
       (5635723508306543*CF*lm*NC*NH)/5843669832 + 366299*CF*lm^2*NC*NH - 
       (24365990928008967818520613*CF^2*NC*Pi^2)/665786721600 - 
       23120*CF^2*lm*NC*Pi^2 - (933326931718825022513*CF*NM*NC*Pi^2)/
        3648645 - (23120*CF*lm*NM*NC*Pi^2)/27 + 
       (230141970881*CF*NC*NL*Pi^2)/243243 - (23120*CF*lm*NC*NL*Pi^2)/27 - 
       (23120*CF*lm*NC*NH*Pi^2)/27 + (373453047962480821133547607*CF^2*NC*
         Pi^3)/(29351839791413161440*Sqrt[3]) + 
       (541480574447226818067580*CF*NC*NH*Pi^3)/(5559060566555523*Sqrt[3]) + 
       (733097477*CF^2*NC*Pi^4)/2700 - (6852811633785030740007298013131*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(41133668283686404442016*Sqrt[3]) - 
       (9268652260501607743044467372*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) + 
       (1289482844*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
       (373453047962480821133547607*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(792680858564398650*
         Sqrt[3]) + (247533976890160831116608*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (373453047962480821133547607*CF^2*NC*Pi*Log[3]^2)/
        (38048681211091135200*Sqrt[3]) + (15470873555635051944788*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((-238317169922786422203535484273*CF*NC)/542657789774100 + 
         CA*(4766348054865786824038977542723/21706311590964000 - 95678924*lm)*
          NC + 469696536*CF*lm*NC - (277347426297146995631283763*NM*NC)/
          90352612350 + 17396168*lm*NM*NC + (1022054926*NC*NL)/45 + 
         17396168*lm*NC*NL + (57618298672644691*NC*NH)/13437055170 + 
         17396168*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-2347566818257752253709*CA + 220*(21341249884809487939*CF + 
            32760*(4205156564652206*NM + 58712067*NL)))*Log[x]^3)/
        36486450 - (2299066976601562567222673703701467*CF^2*NC*
         PolyGamma[2, 1])/90056781178199472600 - 
       (69685997914892629*CF*NM*NC*PolyGamma[2, 1])/450 + 
       (580794895617536573671791673*CF*NC*NH*PolyGamma[2, 1])/
        22514195294549868150 + CA*CF*NC*
        (-2710471179677054009895195321494161558033792370834754754873681/
          54921201851912033681154003851784410713128000000 - 
         (4029289*lm^2)/2 + (696580661536688229774955109*Pi^2)/
          38067334905600 - (373453047962480821133547607*Pi^3)/
          (58703679582826322880*Sqrt[3]) - (736796677*Pi^4)/5400 + 
         lm*(-8360034946586975/1062485424 + (127160*Pi^2)/27) + 
         (6852811633785030740007298013131*Im[PolyLog[2, (-1)^(1/3)]])/
          (82267336567372808884032*Sqrt[3]) - 
         (644741422*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
         (373453047962480821133547607*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1585361717128797300*Sqrt[3]) - (373453047962480821133547607*Pi*
           Log[3]^2)/(76097362422182270400*Sqrt[3]) + 
         (2299066976601562567222673703701467*PolyGamma[2, 1])/
          180113562356398945200 - (149673531097276525696128903817454701*
           Zeta[3])/22536709489844418018150) + 
       (598692933037707130204876990605099919*CF^2*NC*Zeta[3])/
        45073418979688836036300 + (71285682180752113*CF*NM*NC*Zeta[3])/675 + 
       (182876072*CF*NC*NL*Zeta[3])/9 - (2445045142549174861418654327*CF*NC*
         NH*Zeta[3])/11257097647274934075 + 
       CF*Log[x]*((-2085502352261460013514006045163442337*NM*NC)/
          1209421416069536670000 + (3564801710692*lm*NM*NC)/405405 + 
         1456560*lm^2*NM*NC + (11302367067690017959*NC*NL)/292183491600 + 
         (3564801710692*lm*NC*NL)/405405 + 1456560*lm^2*NC*NL + 
         (387355791187160473961079879639828400820827*NC*NH)/
          547172749502000721157142150866800 + (3564801710692*lm*NC*NH)/
          405405 + 1456560*lm^2*NC*NH - (16820626481933200*NM*NC*Pi^2)/81 + 
         (10154644*NC*NL*Pi^2)/3 - (247533976890160831116608*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(24400820098809367876874923337088247008918409647089/
            273534325024531680367283832422616000 - (2158171486946*lm)/36855 - 
           8011080*lm^2 + (4695127905972392538893*Pi^2)/291891600 + 
           (373453047962480821133547607*Im[PolyLog[2, (-1)^(1/3)]])/
            (4756085151386391900*Sqrt[3]) - 5826240*Zeta[3]) + 
         CF*NC*(-976033146480357379787819405809496553104903451632447/
            5470686500490633607345676648452320000 + (2941499631292*lm)/
            15015 + 39327120*lm^2 - (4695128527549998786491*Pi^2)/145945800 - 
           (373453047962480821133547607*Im[PolyLog[2, (-1)^(1/3)]])/
            (2378042575693195950*Sqrt[3]) + 11652480*Zeta[3])), 
      (-3474579309094129975552807418712878308144766058426565620172280929*CF^2*
         NC)/4652148862750195794168339149798208907464960000000 - 
       (19417281624196999*CF^2*lm*NC)/1264863600 - (20296419*CF^2*lm^2*NC)/
        2 + (51041823175486909166450249836401846534341332673*CF*NM*NC)/
        249770021426100359745416856000000 - (32966499137128099*CF*lm*NM*NC)/
        34151317200 - (6765473*CF*lm^2*NM*NC)/18 + 
       (404996802754443893484497*CF*NC*NL)/24613537332384000 - 
       (32966499137128099*CF*lm*NC*NL)/34151317200 - 
       (6765473*CF*lm^2*NC*NL)/18 + 
       (10749549878033763441904902301256778514048018484003117471*CF*NC*NH)/
        14960516164204172603852029956962950013889600000 - 
       (32966499137128099*CF*lm*NC*NH)/34151317200 - 
       (6765473*CF*lm^2*NC*NH)/18 + (14657666364200017405494010783937*CF^2*
         NC*Pi^2)/33975096403248000 + (178024*CF^2*lm*NC*Pi^2)/9 - 
       (236302210039287293312*CF*NM*NC*Pi^2)/1563705 + 
       (178024*CF*lm*NM*NC*Pi^2)/243 - (136915811879*CF*NC*NL*Pi^2)/
        142155 + (178024*CF*lm*NC*NL*Pi^2)/243 + (178024*CF*lm*NC*NH*Pi^2)/
        243 - (19402433441406516570890853313*CF^2*NC*Pi^3)/
        (1373666102238135955392*Sqrt[3]) - (14639202231825510068348920*CF*NC*
         NH*Pi^3)/(150094635296999121*Sqrt[3]) - (13258440539*CF^2*NC*Pi^4)/
        48600 + (225150595981596192474839860899961261*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1203159797297827329928968000*Sqrt[3]) + 
       (139657976689886378097681197744*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (536588321186771857575*Sqrt[3]) - 
       (445387862*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (19402433441406516570890853313*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37097464180813856820*
         Sqrt[3]) - (6692206734548804602673792*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (19402433441406516570890853313*CF^2*NC*Pi*Log[3]^2)/
        (1780678280679065127360*Sqrt[3]) - (418262920909300287667112*CF*NC*
         NH*Pi*Log[3]^2)/(5559060566555523*Sqrt[3]) + 
       CF*((708248461675785103582659229151*CF*NC)/136804484817000 - 
         490396620*CF*lm*NC + CA*(-404713438611846672940198805551/
            156347982648000 + (899060470*lm)/9)*NC - 
         (140439133753697086134369233*NM*NC)/77445096300 - 
         (163465540*lm*NM*NC)/9 - (1069395421*NC*NL)/45 - 
         (163465540*lm*NC*NL)/9 - (1338249060553676617*NC*NH)/
          292944494700 - (163465540*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-50305074605795680060053*CA + 8*(12576253583229668201959*CF - 
            31531500*(133775172649570*NM - 3502833*NL)))*Log[x]^3)/
        72972900 + (664132077220381859981901463277691227*CF^2*NC*
         PolyGamma[2, 1])/2701703435345984178000 - 
       (1524730099109684663*CF*NM*NC*PolyGamma[2, 1])/24300 - 
       (2581209395367337018613436523*CF*NC*NH*PolyGamma[2, 1])/
        135085171767299208900 - (38195284584915521608321690826166067289*CF^2*
         NC*Zeta[3])/193171795627237868727000 + 
       (1284550337958138937*CF*NM*NC*Zeta[3])/12150 - 
       (1720973716*CF*NC*NL*Zeta[3])/81 + (16721488139932982359493292197*CF*
         NC*NH*Zeta[3])/67542585883649604450 + 
       CA*CF*NC*(835235390364130739620186569956883537735227826064564117714421\
9/22366100301683633625809322835568312055120000000 + (74420203*lm^2)/36 - 
         (1724431333216959601328187172187*Pi^2)/7994140330176000 + 
         (19402433441406516570890853313*Pi^3)/(2747332204476271910784*
           Sqrt[3]) + (13315408219*Pi^4)/97200 + 
         lm*(49303354702958899/6209330400 - (979132*Pi^2)/243) - 
         (225150595981596192474839860899961261*Im[PolyLog[2, (-1)^(1/3)]])/
          (2406319594595654659857936000*Sqrt[3]) + 
         (222693931*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (19402433441406516570890853313*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(74194928361627713640*Sqrt[3]) + 
         (19402433441406516570890853313*Pi*Log[3]^2)/(3561356561358130254720*
           Sqrt[3]) - (664132077220381859981901463277691227*PolyGamma[2, 1])/
          5403406870691968356000 + (9548822312832100238992322091571272641*
           Zeta[3])/96585897813618934363500) + 
       CF*Log[x]*((-3764226596948825317584671111909644291*NM*NC)/
          3109940784178808580000 - (425890874647*lm*NM*NC)/47385 - 
         1537480*lm^2*NM*NC - (2734818346275288853*NC*NL)/68302634400 - 
         (425890874647*lm*NC*NL)/47385 - 1537480*lm^2*NC*NL - 
         (4553779373591313540119919693082367035988453*NC*NH)/
          6423332276762617161409929597132000 - (425890874647*lm*NC*NH)/
          47385 - 1537480*lm^2*NC*NH - (9364261818736160*NM*NC*Pi^2)/81 - 
         (95570090*NC*NL*Pi^2)/27 + (6692206734548804602673792*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CF*NC*(88654302406609107704926871118673868477348857794618469/
            28962457943773942627124170491806400000 - (348989968747*lm)/1755 - 
           41511960*lm^2 + (4790958959748609897833*Pi^2)/13899600 + 
           (19402433441406516570890853313*Im[PolyLog[2, (-1)^(1/3)]])/
            (111292392542441570460*Sqrt[3]) - 12299840*Zeta[3]) + 
         CA*NC*(-11081787568939107785162388585421372278383699858917823/
            7240614485943485656781042622951600000 + (5704748478317*lm)/
            94770 + 8456140*lm^2 - (1596986302082997583333*Pi^2)/9266400 - 
           (19402433441406516570890853313*Im[PolyLog[2, (-1)^(1/3)]])/
            (222584785084883140920*Sqrt[3]) + 6149920*Zeta[3])), 
      (2997218279192567504744889897631348427060848386328779367141348111*CF^2*
         NC)/3041789641028974173110067905637290439496320000000 + 
       (8977887245772073*CF^2*lm*NC)/375750375 + (75744639*CF^2*lm^2*NC)/5 + 
       (17906384177167107518305485589522469037987135647*CF*NM*NC)/
        3122125267826254496817710700000 + (29972673461795321*CF*lm*NM*NC)/
        20290520250 + (2805357*CF*lm^2*NM*NC)/5 - 
       (7256795803574596978710239*CF*NC*NL)/263228107582440000 + 
       (29972673461795321*CF*lm*NC*NL)/20290520250 + 
       (2805357*CF*lm^2*NC*NL)/5 - 
       (10749813446079409395835643425276739459171088380152655296555709*CF*NC*
         NH)/8969485833087105934082285967013650282758674606200000 + 
       (29972673461795321*CF*lm*NC*NH)/20290520250 + 
       (2805357*CF*lm^2*NC*NH)/5 - (129268895010847318955284236847*CF^2*NC*
         Pi^2)/377501071147200 - (166464*CF^2*lm*NC*Pi^2)/5 - 
       (1644065579429454238511*CF*NM*NC*Pi^2)/552825 - 
       (18496*CF*lm*NM*NC*Pi^2)/15 + (1040580565313*CF*NC*NL*Pi^2)/675675 - 
       (18496*CF*lm*NC*NL*Pi^2)/15 - (18496*CF*lm*NC*NH*Pi^2)/15 + 
       (6842277689356664243608922909*CF^2*NC*Pi^3)/(312196841417758171680*
         Sqrt[3]) + (25217434152293936236827220*CF*NC*NH*Pi^3)/
        (150094635296999121*Sqrt[3]) + (401982323*CF^2*NC*Pi^4)/900 - 
       (3061266462007796435897762399782721*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10937816339071157544808800*Sqrt[3]) - 
       (169185434279474847128438982572*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (288932172946723307925*Sqrt[3]) + 
       (231773036*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (6842277689356664243608922909*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(8431241859275876550*
         Sqrt[3]) + (11527969898191513708263872*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) + 
       (6842277689356664243608922909*CF^2*NC*Pi*Log[3]^2)/
        (404699609245242074400*Sqrt[3]) + (720498118636969606766492*CF*NC*NH*
         Pi*Log[3]^2)/(5559060566555523*Sqrt[3]) + 
       CF*((-159277683912777019582400053507*CF*NC)/38761270698150 + 
         CA*(44597759634766956343387711118479/21706311590964000 - 
           (7513718344*lm)/45)*NC + (4098391824*CF*lm*NC)/5 - 
         (4836650211073450225118631536*NM*NC)/135528918525 + 
         (1366130608*lm*NM*NC)/45 + (80188713652*NC*NL)/2025 + 
         (1366130608*lm*NC*NL)/45 + (952186794547841035342*NC*NH)/
          121840497753975 + (1366130608*lm*NC*NH)/45)*Log[x]^2 - 
       (CF*NC*(-2486813585856490011283*CA + 8*(621701884664563149791*CF + 
            120120*(40930293691128449*NM + 85383163*NL)))*Log[x]^3)/
        4054050 - (22066723479999946609456947640381307*CF^2*NC*
         PolyGamma[2, 1])/90056781178199472600 - 
       (26842444388458309*CF*NM*NC*PolyGamma[2, 1])/15 + 
       (496493408913982663079317558*CF*NC*NH*PolyGamma[2, 1])/
        11257097647274934075 + CA*CF*NC*
        (-1217619882903856812583667210889147577305306312095563108324960049/
          2471454083336041515651930173330298482090760000000 - 
         (30858927*lm^2)/10 + (76040526089510233460699058137*Pi^2)/
          444118907232000 - (6842277689356664243608922909*Pi^3)/
          (624393682835516343360*Sqrt[3]) - (403757939*Pi^4)/1800 + 
         lm*(-44461948775208221/3689185500 + (101728*Pi^2)/15) + 
         (3061266462007796435897762399782721*Im[PolyLog[2, (-1)^(1/3)]])/
          (21875632678142315089617600*Sqrt[3]) - 
         (115886518*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (6842277689356664243608922909*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (16862483718551753100*Sqrt[3]) - (6842277689356664243608922909*Pi*
           Log[3]^2)/(809399218490484148800*Sqrt[3]) + 
         (22066723479999946609456947640381307*PolyGamma[2, 1])/
          180113562356398945200 - (99284037006026327556950969488540132*
           Zeta[3])/1609764963560315572725) + 
       (794272004818786063107932015291978417*CF^2*NC*Zeta[3])/
        6439059854241262290900 + (171720666602526086*CF*NM*NC*Zeta[3])/135 + 
       (1580286544*CF*NC*NL*Zeta[3])/45 - (4164008625425639866181899924*CF*
         NC*NH*Zeta[3])/11257097647274934075 + 
       CF*Log[x]*((-1652559814189464681406119531508260499*NM*NC)/
          83729174958660231000 + (3239014725524*lm*NM*NC)/225225 + 
         2372112*lm^2*NM*NC + (24222263877697291727*NC*NL)/365229364500 + 
         (3239014725524*lm*NC*NL)/225225 + 2372112*lm^2*NC*NL + 
         (303365457055322594369148195913921614270341451229*NC*NH)/
          248456098298247222457626429299465043000 + (3239014725524*lm*NC*NH)/
          225225 + 2372112*lm^2*NC*NH - (65488470050111120*NM*NC*Pi^2)/27 + 
         (789810344*NC*NL*Pi^2)/135 - (11527969898191513708263872*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CA*NC*(46690156244016397781225787897169511376413162677879421/
            61545223130519628082638862295088600000 - (1959490315162*lm)/
            20475 - 13046616*lm^2 + (236839336095765282613*Pi^2)/1544400 + 
           (6842277689356664243608922909*Im[PolyLog[2, (-1)^(1/3)]])/
            (50587451155655259300*Sqrt[3]) - 9488448*Zeta[3]) + 
         CF*NC*(-373521275998733692522885320722722148300432926872792163/
            246180892522078512330555449180354400000 + (8025224246772*lm)/
            25025 + 64047024*lm^2 - (710518025238713473553*Pi^2)/2316600 - 
           (6842277689356664243608922909*Im[PolyLog[2, (-1)^(1/3)]])/
            (25293725577827629650*Sqrt[3]) + 18976896*Zeta[3])), 
      (-324607258979721881159365766837409344773923581165616513361505607804432\
7*CF^2*NC)/348061605371088167604364078180201766571567421440000000 - 
       (80495274144974519927*CF^2*lm*NC)/3462915456000 - 
       (245810565*CF^2*lm^2*NC)/16 + 
       (2455764038372421157347236396943775344244548913520651657*CF*NM*NC)/
        818716557464220128962882596612249600000 - 
       (136652228627423339927*CF*lm*NM*NC)/93498717312000 - 
       (9104095*CF*lm^2*NM*NC)/16 + (1094639362762972923331940689*CF*NC*NL)/
        37904847491871360000 - (136652228627423339927*CF*lm*NC*NL)/
        93498717312000 - (9104095*CF*lm^2*NC*NL)/16 + 
       (8420048477116705237486803396769194322874286497471638681299302893*CF*
         NC*NH)/6888565119810897357375195622666483417158662097561600000 - 
       (136652228627423339927*CF*lm*NC*NH)/93498717312000 - 
       (9104095*CF*lm^2*NC*NH)/16 + (134555100752144191160607501470911*CF^2*
         NC*Pi^2)/25885787735808000 + (1129123*CF^2*lm*NC*Pi^2)/40 - 
       (4583176439156438836363*CF*NM*NC*Pi^2)/2316600 + 
       (1129123*CF*lm*NM*NC*Pi^2)/1080 - (602076218196077*CF*NC*NL*Pi^2)/
        389188800 + (1129123*CF*lm*NC*NL*Pi^2)/1080 + 
       (1129123*CF*lm*NC*NH*Pi^2)/1080 - (1972882181679689621757914505133*
         CF^2*NC*Pi^3)/(82419966134288157323520*Sqrt[3]) - 
       (299159783235262841164436555*CF*NC*NH*Pi^3)/(1801135623563989452*
         Sqrt[3]) - (28737149707*CF^2*NC*Pi^4)/64800 + 
       (1278585782657356840144213154077997881*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4125119305021122274042176000*Sqrt[3]) + 
       (41362288147400148719329093115111*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(90146837959377672072600*Sqrt[3]) - 
       (1421529137*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
       (281840311668527088822559215019*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(317978264406975915600*
         Sqrt[3]) - (34189689512601467561649892*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (281840311668527088822559215019*CF^2*NC*Pi*Log[3]^2)/
        (15262956691534843948800*Sqrt[3]) - (8547422378150366890412473*CF*NC*
         NH*Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) - 
       (CF*NC*(-6479*CA*(-4508883422900905385961833684294549 + 
            24833342447520852647001600*lm) + 
          14*(589*CF*(-7085388156019548859149929733517591 + 
              95785749440437574495577600*lm) + 
            5720*(31*(8957730168097372344094712840489 + 
                11784053608963441565760*lm)*NM + 11*(4463382543984*
                 (9725243673 + 7440456940*lm)*NL + (8706340156357958699603 + 
                  33209605625260608048960*lm)*NH))))*Log[x]^2)/
        936670757773278528000 + (CF*NC*(-813279468618868518316629*CA + 
          56*(29045690067298155564231*CF - 2860*(3744196839254437911*NM - 
              12648776798*NL)))*Log[x]^3)/97297200 + 
       (24086244844623058094585890941602350777*CF^2*NC*PolyGamma[2, 1])/
        8105110306037952534000 - (44390127129256555103*CF*NM*NC*
         PolyGamma[2, 1])/48600 - (52503374593062665384713148297*CF*NC*NH*
         PolyGamma[2, 1])/1621022061207590506800 - 
       (508971046142013036223581863860819423271*CF^2*NC*Zeta[3])/
        210732867956986765884000 + (30493815938735718187*CF*NM*NC*Zeta[3])/
        24300 - (29310654703*CF*NC*NL*Zeta[3])/810 + 
       (336720892297482158928011013823*CF*NC*NH*Zeta[3])/
        810511030603795253400 + CA*CF*NC*(22722508050898294785573413694288270\
978357565605372650212871687525976889/
          4872862475195234346461097094522824732001943900160000000 + 
         (100145045*lm^2)/32 - (376905044013769998385708520291*Pi^2)/
          145018418688000 + (1972882181679689621757914505133*Pi^3)/
          (164839932268576314647040*Sqrt[3]) + (5769109103*Pi^4)/25920 + 
         lm*(204363006280902299927/16999766784000 - (12420353*Pi^2)/2160) - 
         (1278585782657356840144213154077997881*Im[PolyLog[2, (-1)^(1/3)]])/
          (8250238610042244548084352000*Sqrt[3]) + 
         (1421529137*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (281840311668527088822559215019*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(635956528813951831200*Sqrt[3]) + 
         (281840311668527088822559215019*Pi*Log[3]^2)/
          (30525913383069687897600*Sqrt[3]) - 
         (24086244844623058094585890941602350777*PolyGamma[2, 1])/
          16210220612075905068000 + (508971054723806474326343463233872706411*
           Zeta[3])/421465735913973531768000) + 
       CF*Log[x]*((-2652919863406607353301582915697664636534873*NM*NC)/
          175758925406022202660416000 - (940929304694003*lm*NM*NC)/
          64864800 - 2470950*lm^2*NM*NC - (3560540845744628819317*NC*NL)/
          52593028488000 - (940929304694003*lm*NC*NL)/64864800 - 
         2470950*lm^2*NC*NL - 
         (57588871185058932078160899552398298217261858783157*NC*NH)/
          47703570873263466711864274425497288256000 - 
         (940929304694003*lm*NC*NH)/64864800 - 2470950*lm^2*NC*NH - 
         (249613121612219191*NM*NC*Pi^2)/162 - (7325123149*NC*NL*Pi^2)/
          1215 + (34189689512601467561649892*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CF*NC*(168778669393838830657886517697672252102657786474540957883/
            4670033021302286365488657129940106400000 - (771747311714003*lm)/
            2402400 - 66715650*lm^2 + (21124141711513735153891*Pi^2)/
            5054400 + (281840311668527088822559215019*
             Im[PolyLog[2, (-1)^(1/3)]])/(953934793220927746800*Sqrt[3]) - 
           19767600*Zeta[3]) + CA*NC*
          (-1718473719682398263858599682328080837846630136879911055601/
            95098854251973831442678108827871257600000 + (1144919076134003*lm)/
            11793600 + 13590225*lm^2 - (21124141678547923156643*Pi^2)/
            10108800 - (281840311668527088822559215019*
             Im[PolyLog[2, (-1)^(1/3)]])/(1907869586441855493600*Sqrt[3]) + 
           9883800*Zeta[3])), (9872959462651036993105880300721539956217931296\
842427753363170915765490317*CF^2*NC)/
        1041574354072981341556059503954253786465415508659200000000 + 
       (6869326538854756661*CF^2*lm*NC)/192384192000 + 
       (905614803*CF^2*lm^2*NC)/40 + 
       (9197163237613625819879497741015232586704173778770342567*CF*NM*NC)/
        136452759577370021493813766102041600000 + 
       (11466956359173491861*CF*lm*NM*NC)/5194373184000 + 
       (33541289*CF*lm^2*NM*NC)/40 - (200015796032385900905391419*CF*NC*NL)/
        4211649721319040000 + (11466956359173491861*CF*lm*NC*NL)/
        5194373184000 + (33541289*CF*lm^2*NC*NL)/40 - 
       (62154879233489752532106213893711508412226054383789695202158278111*CF*
         NC*NH)/30998543039149038108188380301999175377213979439027200000 + 
       (11466956359173491861*CF*lm*NC*NH)/5194373184000 + 
       (33541289*CF*lm^2*NC*NH)/40 - (50198716143037670191802321085277*CF^2*
         NC*Pi^2)/16538142164544000 - (938961*CF^2*lm*NC*Pi^2)/20 - 
       (1663813813719091700791403*CF*NM*NC*Pi^2)/48648600 - 
       (104329*CF*lm*NM*NC*Pi^2)/60 + (52700327147371*CF*NC*NL*Pi^2)/
        21621600 - (104329*CF*lm*NC*NL*Pi^2)/60 - (104329*CF*lm*NC*NH*Pi^2)/
        60 + (847704139445220712847004732347*CF^2*NC*Pi^3)/
        (23180615475268544247240*Sqrt[3]) + (2277951296019363127464851515*CF*
         NC*NH*Pi^3)/(8105110306037952534*Sqrt[3]) + 
       (963215393*CF^2*NC*Pi^4)/1350 - 
       (14852247256855372679840839758554512901*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(32485314527041337908082136000*
         Sqrt[3]) - (404520999865046959793489153387023*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(405660770817199524326700*Sqrt[3]) + 
       (364791032*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (1695408278890441425694009464694*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1252039416102467667675*
         Sqrt[3]) + (520674581947283000563394632*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) + 
       (847704139445220712847004732347*CF^2*NC*Pi*Log[3]^2)/
        (30048945986459224024200*Sqrt[3]) + (65084322743410375070424329*CF*NC*
         NH*Pi*Log[3]^2)/(300189270593998242*Sqrt[3]) + 
       CF*((-25475846563296124841372747335575533*CF*NC)/699425595708840000 + 
         CA*(19106885587973522478522739769256521/1049138393563260000 - 
           (12692090554*lm)/45)*NC + (6922958484*CF*lm*NC)/5 - 
         (25808667243465944833300067501839*NM*NC)/62885418195600 + 
         (2307652828*lm*NM*NC)/45 + (135350636737*NC*NL)/2025 + 
         (2307652828*lm*NC*NL)/45 + (2057665945365007011469*NC*NH)/
          149957535697200 + (2307652828*lm*NC*NH)/45)*Log[x]^2 - 
       (CF*NC*(-90397031131786341339133*CA + 80*(2259924695966810482901*CF + 
            6006*(3782288223965180347*NM + 1153826414*NL)))*Log[x]^3)/
        16216200 - (131653822660860524779100849801116953349*CF^2*NC*
         PolyGamma[2, 1])/58356794203473258244800 - 
       (55393679351410666339*CF*NM*NC*PolyGamma[2, 1])/2700 + 
       (106729387130065557151411612717*CF*NC*NH*PolyGamma[2, 1])/
        1458919855086831456120 + CA*CF*NC*
        (-7594584154285109103989608966489327843367016790117061232619175661158\
95909/160242208318920206393239923685269813302371616716800000000 - 
         (368954179*lm^2)/80 + (2895912702948787835568979769*Pi^2)/
          1908137088000 - (847704139445220712847004732347*Pi^3)/
          (46361230950537088494480*Sqrt[3]) - (966971237*Pi^4)/2700 + 
         lm*(-17010510018122397461/944431488000 + (1147619*Pi^2)/120) + 
         (14852247256855372679840839758554512901*Im[PolyLog[2, (-1)^(1/3)]])/
          (64970629054082675816164272000*Sqrt[3]) - 
         (182395516*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (847704139445220712847004732347*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1252039416102467667675*Sqrt[3]) - 
         (847704139445220712847004732347*Pi*Log[3]^2)/
          (60097891972918448048400*Sqrt[3]) + 
         (131653822660860524779100849801116953349*PolyGamma[2, 1])/
          116713588406946516489600 - 
         (31031838109336299988901493495767914087927*Zeta[3])/
          58415150997676731503044800) + 
       (31031835915433972162274370258099795745567*CF^2*NC*Zeta[3])/
        29207575498838365751522400 + (20252084558386746991*CF*NM*NC*Zeta[3])/
        1350 + (2646617749*CF*NC*NL*Zeta[3])/45 - 
       (89185964728557201867339481135*CF*NC*NH*Zeta[3])/
        145891985508683145612 + CF*Log[x]*
        ((-503827040223760241693902825041640918063811*NM*NC)/
          2253319556487464136672000 + (82366669290809*lm*NM*NC)/3603600 + 
         3755844*lm^2*NM*NC + (80552321278625578159*NC*NL)/730458729000 + 
         (82366669290809*lm*NC*NL)/3603600 + 3755844*lm^2*NC*NL + 
         (438430441250338054012648225954443567195719213859319*NC*NH)/
          214666068929685600203389234914737797152000 + 
         (82366669290809*lm*NC*NH)/3603600 + 3755844*lm^2*NC*NH - 
         (756457645058809901*NM*NC*Pi^2)/27 + (1322839394*NC*NL*Pi^2)/135 - 
         (520674581947283000563394632*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CA*NC*(162352072016404165873336361515568641228664308977774198294863/
            27950147632494183897449612922691536804000000 - 
           (99592472212409*lm)/655200 - 20657142*lm^2 + 
           (90397027362305762913523*Pi^2)/64864800 + 
           (847704139445220712847004732347*Im[PolyLog[2, (-1)^(1/3)]])/
            (3756118248307403003025*Sqrt[3]) - 15023376*Zeta[3]) + 
         CF*NC*(-259763319108132812316296494143993255505853213499056032383233\
3/223601181059953471179596903381532294432000000 + (204240569650827*lm)/
            400400 + 101407788*lm^2 - (30132342585924185258221*Pi^2)/
            10810800 - (1695408278890441425694009464694*
             Im[PolyLog[2, (-1)^(1/3)]])/(3756118248307403003025*Sqrt[3]) + 
           30046752*Zeta[3])), (-12054232450566245975605754418212098644425672\
5849556641162971024585188774144431979*CF^2*NC)/
        1055004413794398362974083335198239934788100576227851724800000000 - 
       (983157440369820592273*CF^2*lm*NC)/28593787622400 - 
       (363543093*CF^2*lm^2*NC)/16 + 
       (142876478786740390462874188245167320507098001707331494684677*CF*NM*
         NC)/3484340709059511694561890776525075404800000 - 
       (1668943571841403333873*CF*lm*NM*NC)/772032265804800 - 
       (13464559*CF*lm^2*NM*NC)/16 + (294924371475628918593153377*CF*NC*NL)/
        6018956552280672000 - (1668943571841403333873*CF*lm*NC*NL)/
        772032265804800 - (13464559*CF*lm^2*NC*NL)/16 + 
       (29807465358002672790064230087926359347964545070175206306672857841*CF*
         NC*NH)/14761210971023351480089704905713893036768561637632000000 - 
       (1668943571841403333873*CF*lm*NC*NH)/772032265804800 - 
       (13464559*CF*lm^2*NC*NH)/16 + (14195779640583804380755117160202083*
         CF^2*NC*Pi^2)/230030522834112000 + (315875*CF^2*lm*NC*Pi^2)/8 - 
       (123066254521803710148359*CF*NM*NC*Pi^2)/4922775 + 
       (315875*CF*lm*NM*NC*Pi^2)/216 - (457355498864291*CF*NC*NL*Pi^2)/
        189034560 + (315875*CF*lm*NC*NL*Pi^2)/216 + 
       (315875*CF*lm*NC*NH*Pi^2)/216 - (248214468622837624579616106349541*
         CF^2*NC*Pi^3)/(6305127409273044035249280*Sqrt[3]) - 
       (1484206503862670282678171545*CF*NC*NH*Pi^3)/(5403406870691968356*
         Sqrt[3]) - (22710131843*CF^2*NC*Pi^4)/32400 + 
       (18772489356676487294846402753826349084303*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(37553023593259786621742949216000*
         Sqrt[3]) + (6050812305540637862772446231903*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7726871825089514749080*Sqrt[3]) - 
       (1105161961*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (248214468622837624579616106349541*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(170277360589935602803800*
         Sqrt[3]) - (169623600441448032306076748*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (248214468622837624579616106349541*CF^2*NC*Pi*Log[3]^2)/
        (8173313308316908934582400*Sqrt[3]) - 
       (42405900110362008076519187*CF*NC*NH*Pi*Log[3]^2)/
        (200126180395998828*Sqrt[3]) - 
       (CF*NC*(CA*(7370058391508116681144945155365918485391 - 
            5699661586623102370590798480000*lm) + 
          13*(CF*(-1133855135354886173938789161913732915519 + 
              2152319759983549146936385440000*lm) + 
            916300*(11*(45570355385116212189478720370911 + 
                7908837584560175390400*lm)*NM + 666319251209040*(170511063 + 
                130563860*lm)*NL + (23668033086034991007163 + 
                86997213430161929294400*lm)*NH)))*Log[x]^2)/
        19904253602682168720000 + (CF*NC*(-33022251046945289658754749*CA + 
          136*(485621325982306425776673*CF - 140140*(1370117818234395729*
               NM - 602458954*NL)))*Log[x]^3)/330810480 + 
       (2068453767605226006793973813347746316697*CF^2*NC*PolyGamma[2, 1])/
        58356794203473258244800 - (599456866828867220189*CF*NM*NC*
         PolyGamma[2, 1])/48600 - (259223682716790946434167116037*CF*NC*NH*
         PolyGamma[2, 1])/4863066183622771520400 - 
       (14365749520054586456724838171581503638253323*CF^2*NC*Zeta[3])/
        496528783480252217775880800 + (359625616486960527541*CF*NM*NC*
         Zeta[3])/24300 - (9689952671*CF*NC*NL*Zeta[3])/162 + 
       (1647505141853253747798815950963*CF*NC*NH*Zeta[3])/
        2431533091811385760200 + CA*CF*NC*(1205423244489641627092789550416844\
13098723840798436779929382678749789940864467979/
          2110008827588796725948166670396479869576201152455703449600000000 + 
         (148110149*lm^2)/32 - (10828207200637477440383674671557*Pi^2)/
          350923757184000 + (248214468622837624579616106349541*Pi^3)/
          (12610254818546088070498560*Sqrt[3]) + (22785941843*Pi^4)/64800 + 
         lm*(2495824457634890658673/140369502873600 - (3474625*Pi^2)/432) - 
         (18772489356676487294846402753826349084303*
           Im[PolyLog[2, (-1)^(1/3)]])/(75106047186519573243485898432000*
           Sqrt[3]) + (1105161961*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (248214468622837624579616106349541*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(340554721179871205607600*Sqrt[3]) + 
         (248214468622837624579616106349541*Pi*Log[3]^2)/
          (16346626616633817869164800*Sqrt[3]) - 
         (2068453767605226006793973813347746316697*PolyGamma[2, 1])/
          116713588406946516489600 + 
         (14365749553189405042148631493807663756117087*Zeta[3])/
          993057566960504435551761600) + CF*Log[x]*
        ((-885432934717085596324504338107300064592507247*NM*NC)/
          4825837923291066764475993600 - (717814680585029*lm*NM*NC)/
          31505760 - 3866310*lm^2*NM*NC - (218462605392700469761*NC*NL)/
          1965014251200 - (717814680585029*lm*NC*NL)/31505760 - 
         3866310*lm^2*NC*NL - 
         (29152135818038531045380234415610674001144783925727*NC*NH)/
          14603133940794938789346206456784884160000 - 
         (717814680585029*lm*NC*NH)/31505760 - 3866310*lm^2*NC*NH - 
         (15984707870366974151*NM*NC*Pi^2)/810 - (2421777449*NC*NL*Pi^2)/
          243 + (169623600441448032306076748*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(50031545098999707*Sqrt[3]) + 
         CF*NC*
          (307549993164389614500973460221940315587288241428854035896263204594\
1/7305944989952919717322149221088186188271168000000 - (589236365920229*lm)/
            1166880 - 104390370*lm^2 + (41277813718223620822676993*Pi^2)/
            827026200 + (248214468622837624579616106349541*
             Im[PolyLog[2, (-1)^(1/3)]])/(510832081769806808411400*Sqrt[3]) - 
           30930480*Zeta[3]) + CA*NC*(-15377499651950332071742585223809713145\
84199072005276174335090786983/
            7305944989952919717322149221088186188271168000000 + 
           (872846906879429*lm)/5728320 + 21264705*lm^2 - 
           (41277813709346140401906031*Pi^2)/1654052400 - 
           (248214468622837624579616106349541*Im[PolyLog[2, (-1)^(1/3)]])/
            (1021664163539613616822800*Sqrt[3]) + 15465240*Zeta[3])), 
      (1724581347799106516294325001787983476757857879448785529674736543143955\
7012042773*CF^2*NC)/
        197813327586449693057640625349669987772768858042722198400000000 + 
       (1451227391781275245*CF^2*lm*NC)/27799515744 + 
       (132414021*CF^2*lm^2*NC)/4 + 
       (159052007388913305011245796746099723213908787993022863698959*CF*NM*
         NC)/203253208028471515516110295297296065280000 + 
       (2422614441347956993*CF*lm*NM*NC)/750586925088 + 
       (4904223*CF*lm^2*NM*NC)/4 - (1543725462238596092551591967*CF*NC*NL)/
        19474668311379240960 + (2422614441347956993*CF*lm*NC*NL)/
        750586925088 + (4904223*CF*lm^2*NC*NL)/4 - 
       (15175242470904038261885532346628674347459783843945046268092192603*CF*
         NC*NH)/4649781455872355716228257045299876306582096915854080000 + 
       (2422614441347956993*CF*lm*NC*NH)/750586925088 + 
       (4904223*CF*lm^2*NC*NH)/4 - (11746382252165161502017843279232279*CF^2*
         NC*Pi^2)/472329340219376640 - 64980*CF^2*lm*NC*Pi^2 - 
       (64393830895108135524008447*CF*NM*NC*Pi^2)/165405240 - 
       (7220*CF*lm*NM*NC*Pi^2)/3 + (6914471494213*CF*NC*NL*Pi^2)/1837836 - 
       (7220*CF*lm*NC*NL*Pi^2)/3 - (7220*CF*lm*NC*NH*Pi^2)/3 + 
       (1122018587885047285040608807013167*CF^2*NC*Pi^3)/
        (18915382227819132105747840*Sqrt[3]) + 
       (22246552486669785819260249555*CF*NC*NH*Pi^3)/(48630661836227715204*
         Sqrt[3]) + (3997626923*CF^2*NC*Pi^4)/3600 - 
       (82052819851704853333539103597754166152921*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(112659070779779359865228847648000*
         Sqrt[3]) - (200901353791930319198194040517151*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(121698231245159857298010*Sqrt[3]) + 
       (560282963*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (1122018587885047285040608807013167*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(510832081769806808411400*
         Sqrt[3]) + (2542463141333689807915457092*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) + (1122018587885047285040608807013167*CF^2*NC*Pi*Log[3]^2)/
        (24519939924950726803747200*Sqrt[3]) + 
       (635615785333422451978864273*CF*NC*NH*Pi*Log[3]^2)/
        (1801135623563989452*Sqrt[3]) + 
       CF*((-94285691864548737863579761885856178931*CF*NC)/
          315940533375907440000 + CA*(50769219050941409942226643923188338829/
            340243651327900320000 - (4165459034*lm)/9)*NC + 
         2272068564*CF*lm*NC - (227681582271251589124544598237283*NM*NC)/
          48736199101590 + (757356188*lm*NM*NC)/9 + (44392817672*NC*NL)/
          405 + (757356188*lm*NC*NL)/9 + (1136141741061699055543*NC*NH)/
          48736199101590 + (757356188*lm*NC*NH)/9)*Log[x]^2 - 
       (8*CF*NC*(-204262121531952228693323*CA + 408524203199338581990231*CF + 
          1276275*(4323391606559903182*NM + 189339047*NL))*Log[x]^3)/
        34459425 - (573206862410596673647207386377788263389*CF^2*NC*
         PolyGamma[2, 1])/29178397101736629122400 - 
       (157479812741496133522*CF*NM*NC*PolyGamma[2, 1])/675 + 
       (47863523212674567449592420403*CF*NC*NH*PolyGamma[2, 1])/
        405255515301897626700 + CA*CF*NC*
        (-4927375273832580978945584096260812846748013845913030782238664690162\
288967755203/
          113036187192256967461508928771239993013010776024412684800000000 - 
         (53946453*lm^2)/8 + (15455766118597246015293652907163557*Pi^2)/
          1242971947945728000 - (1122018587885047285040608807013167*Pi^3)/
          (37830764455638264211495680*Sqrt[3]) - (4011489323*Pi^4)/7200 + 
         lm*(-3593856242739362737/136470350016 + (39710*Pi^2)/3) + 
         (82052819851704853333539103597754166152921*
           Im[PolyLog[2, (-1)^(1/3)]])/(225318141559558719730457695296000*
           Sqrt[3]) - (560282963*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
         (1122018587885047285040608807013167*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1021664163539613616822800*
           Sqrt[3]) - (1122018587885047285040608807013167*Pi*Log[3]^2)/
          (49039879849901453607494400*Sqrt[3]) + 
         (573206862410596673647207386377788263389*PolyGamma[2, 1])/
          58356794203473258244800 - 
         (36047498539522439302818753584590246618133*Zeta[3])/
          8866585419290218174569300) + 
       (2883799840087303389988486726833504612679*CF^2*NC*Zeta[3])/
        354663416771608726982772 + (117379534702659954806*CF*NM*NC*Zeta[3])/
        675 + (862006478*CF*NC*NL*Zeta[3])/9 - 
       (199299137731564461313419818597*CF*NC*NH*Zeta[3])/
        202627757650948813350 + CF*Log[x]*
        ((-7062794561961744220876260222556043393766300389*NM*NC)/
          2815072121919788945944329600 + (27118767906437*lm*NM*NC)/765765 + 
         5799465*lm^2*NM*NC + (7089998837121041731051*NC*NL)/
          39736954857600 + (27118767906437*lm*NC*NL)/765765 + 
         5799465*lm^2*NC*NL + 
         (214070161810427525619063688881029556550045821040633*NC*NH)/
          64399820678905680061016770474421339145600 + 
         (27118767906437*lm*NC*NH)/765765 + 5799465*lm^2*NC*NH - 
         (8646783213588789767*NM*NC*Pi^2)/27 + (430873279*NC*NL*Pi^2)/27 - 
         (2542463141333689807915457092*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CA*NC*
          (60542203602531961462026736229208224219774137634979192699188799097/
            1685987305373750703997419051020350658831808000000 - 
           (32770984490087*lm)/139230 - (63794115*lm^2)/2 + 
           (1245026254545767914208507*Pi^2)/105019200 + 
           (1122018587885047285040608807013167*Im[PolyLog[2, (-1)^(1/3)]])/
            (3064992490618840850468400*Sqrt[3]) - 23197860*Zeta[3]) + 
         CF*NC*
          (-78704864987390207607628021021451808852009764809336372434689414436\
1/10958917484929379575983223831632279282406752000000 + (134586101105697*lm)/
            170170 + 156585555*lm^2 - (3735078766751949394478113*Pi^2)/
            157528800 - (1122018587885047285040608807013167*
             Im[PolyLog[2, (-1)^(1/3)]])/(1532496245309420425234200*
             Sqrt[3]) + 46395720*Zeta[3])), 
      (-226114790902207820326991826901693661250248558767576880461761990016880\
8519347146677*CF^2*NC)/
        1643372259948966680786552887520335283035310512970307494400000000 - 
       (4486295056416031116473*CF^2*lm*NC)/90070431010560 - 
       (263288415*CF^2*lm^2*NC)/8 + 
       (6515902777068687340201110117228912818491308677138346634435993*CF*NM*
         NC)/12195192481708290930966617717837763916800000 - 
       (7615291718663299328873*CF*lm*NM*NC)/2431901637285120 - 
       (87762805*CF*lm^2*NM*NC)/72 + (141427353112634273445824047123*CF*NC*
         NL)/1752720148024131686400 - (7615291718663299328873*CF*lm*NC*NL)/
        2431901637285120 - (87762805*CF*lm^2*NC*NL)/72 + 
       (40796852818662711454975207414224188227099512066168939624620942623597*
         CF*NC*NH)/
        12554409930855360433816294022309666027771661672806016000000 - 
       (7615291718663299328873*CF*lm*NC*NH)/2431901637285120 - 
       (87762805*CF*lm^2*NC*NH)/72 + (2363606891727634136109122722530674701*
         CF^2*NC*Pi^2)/3269972355364915200 + (976505*CF^2*lm*NC*Pi^2)/18 - 
       (25413178587428995842481817*CF*NM*NC*Pi^2)/82702620 + 
       (976505*CF*lm*NM*NC*Pi^2)/486 - (733375877128553*CF*NC*NL*Pi^2)/
        198486288 + (976505*CF*lm*NC*NL*Pi^2)/486 + 
       (976505*CF*lm*NC*NH*Pi^2)/486 - (4952792087593321732356370066710299*
         CF^2*NC*Pi^3)/(78571587715556394900798720*Sqrt[3]) - 
       (580997860799586386952858565265*CF*NC*NH*Pi^3)/
        (1313027869578148310508*Sqrt[3]) - (210047799403*CF^2*NC*Pi^4)/
        194400 + (52624135150145275910849013658503128003851*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(66852635407781158601344590912000*
         Sqrt[3]) + (387868672042583577467356117068083*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(298713840329028740640570*Sqrt[3]) - 
       (10073653681*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
       (707541726799045961765195723815757*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(303131125445819424771600*
         Sqrt[3]) - (66399755519952729937469550316*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) - (707541726799045961765195723815757*CF^2*NC*Pi*Log[3]^2)/
        (14550294021399332389036800*Sqrt[3]) - 
       (16599938879988182484367387579*CF*NC*NH*Pi*Log[3]^2)/
        (48630661836227715204*Sqrt[3]) + 
       CF*((79683097299002897091725326577532576846329*CF*NC)/
          9186578585853308640000 - (6838718146*CF*lm*NC)/3 + 
         CA*(-1035880265115122256601945369428667394546537/
            238851043232186024640000 + (37612949803*lm)/81)*NC - 
         (862608750914318152855304115327025*NM*NC)/233933755687632 - 
         (6838718146*lm*NM*NC)/81 - (14874330557*NC*NL)/135 - 
         (6838718146*lm*NC*NL)/81 - (46294028165746332423979*NC*NH)/
          1949447964063600 - (6838718146*lm*NC*NH)/81)*Log[x]^2 + 
       (CF*NC*(-486108219082507626803530947*CA + 
          1768*(549896173303330452831513*CF - 3850*(59577892749463662117*
               NM - 3419359073*NL)))*Log[x]^3)/413513100 + 
       (9864098261373412256738894025568864429261499*CF^2*NC*PolyGamma[2, 1])/
        23634501652406669589144000 - (5139885956444738684641*CF*NM*NC*
         PolyGamma[2, 1])/32400 - (20194397974798501872959358347861*CF*NC*NH*
         PolyGamma[2, 1])/236345016524066695891440 - 
       (1318082385957683497136690562002084320964537281*CF^2*NC*Zeta[3])/
        3867195332875041311523687000 + (2803833088298727078559*CF*NM*NC*
         Zeta[3])/16200 - (7797582881*CF*NC*NL*Zeta[3])/81 + 
       (127299604006228753033738371405739*CF*NC*NH*Zeta[3])/
        118172508262033347945720 + CA*CF*NC*(14697461407703435055137985455925\
489608098730872625979250824924814994708541704558213/
          21363839379336566850225187537764358679459036668613997427200000000 + 
         (965390855*lm^2)/144 - (622001813609390060693120731079115323*Pi^2)/
          1721038081771008000 + (4952792087593321732356370066710299*Pi^3)/
          (157143175431112789801597440*Sqrt[3]) + (70224254201*Pi^4)/129600 + 
         lm*(11388053244435125116073/442163934051840 - (10741555*Pi^2)/972) - 
         (52624135150145275910849013658503128003851*
           Im[PolyLog[2, (-1)^(1/3)]])/(133705270815562317202689181824000*
           Sqrt[3]) + (10073653681*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 + 
         (707541726799045961765195723815757*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(606262250891638849543200*Sqrt[3]) + 
         (707541726799045961765195723815757*Pi*Log[3]^2)/
          (29100588042798664778073600*Sqrt[3]) - 
         (9864098261373412256738894025568864429261499*PolyGamma[2, 1])/
          47269003304813339178288000 + 
         (659041193184974955177383366936028258476220383*Zeta[3])/
          3867195332875041311523687000) + CF*Log[x]*
        ((-342180867672377476920460307158790928320598553*NM*NC)/
          156683049457502167677792000 - (5777083206463861*lm*NM*NC)/
          165405240 - (11813725*lm^2*NM*NC)/2 - 
         (127225208471185407026159*NC*NL)/715265187436800 - 
         (5777083206463861*lm*NC*NL)/165405240 - (11813725*lm^2*NC*NL)/2 - 
         (25414847120266962499936858326610491575674224974909533*NC*NH)/
          7903614356047515280215694558224437076960000 - 
         (5777083206463861*lm*NC*NH)/165405240 - (11813725*lm^2*NC*NH)/2 - 
         (6619765860530754803*NM*NC*Pi^2)/27 - (7795629871*NC*NL*Pi^2)/
          486 + (66399755519952729937469550316*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12157665459056928801*Sqrt[3]) + 
         CF*NC*(2204580368225193574398945033960201151072183958576244182387038\
58791457/45521657245091269007930314377549467788458816000000 - 
           (4745777974256611*lm)/6126120 - (318970575*lm^2)/2 + 
           (299143519344869893126129523*Pi^2)/508939200 + 
           (707541726799045961765195723815757*Im[PolyLog[2, (-1)^(1/3)]])/
            (909393376337458274314800*Sqrt[3]) - 47254900*Zeta[3]) + 
         CA*NC*(-286595447853281116856882944789932343072588244315304129359243\
6066145341/1183563088372372994206188173816286162499929216000000 + 
           (7020570854866861*lm)/30073680 + (129950975*lm^2)/4 - 
           (299143519336110508555157411*Pi^2)/1017878400 - 
           (707541726799045961765195723815757*Im[PolyLog[2, (-1)^(1/3)]])/
            (1818786752674916548629600*Sqrt[3]) + 23627450*Zeta[3])), 
      (2881497284356820895174726437737423707541845539251970644563387129097445\
98540442119*CF^2*NC)/
        381497131773867265182592634602934976418911369082392811200000000 + 
       (7642534528393082717*CF^2*lm*NC)/102120670080 + 
       (189845397*CF^2*lm^2*NC)/4 + 
       (4347070581464022719988231691130599944663976142250007662000161*CF*NM*
         NC)/483936209591598846466929274517371584000000 + 
       (12758585138276816237*CF*lm*NM*NC)/2757258092160 + 
       (7031311*CF*lm^2*NM*NC)/4 - (1690169019490515167784775451*CF*NC*NL)/
        13137673067200281600 + (12758585138276816237*CF*lm*NC*NL)/
        2757258092160 + (7031311*CF*lm^2*NC*NL)/4 - 
       (881214314059203275690441758290176523619831481168499379553827208630383\
9*CF*NC*NH)/1700316915047103133834483265005485329691759301370703552000000 + 
       (12758585138276816237*CF*lm*NC*NH)/2757258092160 + 
       (7031311*CF*lm^2*NC*NH)/4 - (107912991016085235847235098877512433*
         CF^2*NC*Pi^2)/607280580282055680 - 88445*CF^2*lm*NC*Pi^2 - 
       (103716717976105166790468557*CF*NM*NC*Pi^2)/23629320 - 
       (88445*CF*lm*NM*NC*Pi^2)/27 + (26836449140419*CF*NC*NL*Pi^2)/
        4725864 - (88445*CF*lm*NC*NL*Pi^2)/27 - (88445*CF*lm*NC*NH*Pi^2)/
        27 + (4355637628717698377009737714194619*CF^2*NC*Pi^3)/
        (46428665468283324259562880*Sqrt[3]) + 
       (953926939236602967668767604905*CF*NC*NH*Pi^3)/
        (1313027869578148310508*Sqrt[3]) + (18235466809*CF^2*NC*Pi^4)/10800 - 
       (44806651678828446484717810636107330103511*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(39503830013688866446249076448000*
         Sqrt[3]) - (8754100979892982498555825021089341*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3285852243619316147046270*Sqrt[3]) + 
       (7576802387*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
       (622233946959671196715676816313517*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(179122937763438751001400*
         Sqrt[3]) + (109020221627040339162144869132*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) + (622233946959671196715676816313517*CF^2*NC*Pi*Log[3]^2)/
        (8597901012645060048067200*Sqrt[3]) + 
       (27255055406760084790536217283*CF*NC*NH*Pi*Log[3]^2)/
        (48630661836227715204*Sqrt[3]) + 
       CF*((-6063361162705947554928421651006936004959*CF*NC)/
          2843464800383166960000 + 
         CA*(6063361172195956182957902999366436375979/
            5686929600766333920000 - (6660475745*lm)/9)*NC + 
         3632986770*CF*lm*NC - (2444787658438155210165481237523779*NM*NC)/
          46415427715800 + (1210995590*lm*NM*NC)/9 + (14188967611*NC*NL)/
          81 + (1210995590*lm*NC*NL)/9 + (154125748740374257579981*NC*NH)/
          4007198592797400 + (1210995590*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-10723389703390205499615537*CA + 
          8*(2680847368299213140169323*CF + 3828825*(13981690632448319596*
               NM + 86499685*NL)))*Log[x]^3)/29536650 - 
       (371680873895546152197167126413486009384111*CF^2*NC*PolyGamma[2, 1])/
        2363450165240666958914400 - (1578922307813484824201*CF*NM*NC*
         PolyGamma[2, 1])/600 + (109961027830939962831153722725459*CF*NC*NH*
         PolyGamma[2, 1])/590862541310166739728600 + 
       CA*CF*NC*(-67799936088159630081929825072791374082850963293620000624433\
503023723340138471653/
          179528062011231654203573004519028224197134761921126028800000000 - 
         (77344421*lm^2)/8 + (141990777647538881797083590908999859*Pi^2)/
          1598106790215936000 - (4355637628717698377009737714194619*Pi^3)/
          (92857330936566648519125760*Sqrt[3]) - (2032452401*Pi^4)/2400 + 
         lm*(-18927220323399786797/501319653120 + (972895*Pi^2)/54) + 
         (44806651678828446484717810636107330103511*
           Im[PolyLog[2, (-1)^(1/3)]])/(79007660027377732892498152896000*
           Sqrt[3]) - (7576802387*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
         (622233946959671196715676816313517*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(358245875526877502002800*Sqrt[3]) - 
         (622233946959671196715676816313517*Pi*Log[3]^2)/
          (17195802025290120096134400*Sqrt[3]) + 
         (371680873895546152197167126413486009384111*PolyGamma[2, 1])/
          4726900330481333917828800 - 
         (69707436346466669117478542438080953984480331*Zeta[3])/
          2872773675850030688560453200) + 
       (69707436071115844588334167136098437015586009*CF^2*NC*Zeta[3])/
        1436386837925015344280226600 + (596007345786739038799*CF*NM*NC*
         Zeta[3])/300 + (1368958360*CF*NC*NL*Zeta[3])/9 - 
       (456409345844781681159376866708941*CF*NC*NH*Zeta[3])/
        295431270655083369864300 + CF*Log[x]*
        ((-276665168949135026772300153594709719519528863*NM*NC)/
          9915018744434308769880000 + (14081206301945*lm*NM*NC)/262548 + 
         8756055*lm^2*NM*NC + (543685366735613086037*NC*NL)/1930080664512 + 
         (14081206301945*lm*NC*NL)/262548 + 8756055*lm^2*NC*NL + 
         (157067558476405786319552783072416025161364771957144167453*NC*NH)/
          29755132146929883151192036088075449485485160000 + 
         (14081206301945*lm*NC*NH)/262548 + 8756055*lm^2*NC*NH - 
         (97871834427936122393*NM*NC*Pi^2)/27 + (684302290*NC*NL*Pi^2)/27 - 
         (109020221627040339162144869132*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (12157665459056928801*Sqrt[3]) + 
         CA*NC*
          (799440203588049013517877540011643632229825732554752843794000208114\
1/84540220598026642443299155272591868749994944000000 - (17007059592305*lm)/
            47736 - (96316605*lm^2)/2 + (85787117482603208850987103*Pi^2)/
            945172800 + (622233946959671196715676816313517*
             Im[PolyLog[2, (-1)^(1/3)]])/(1074737626580632506008400*
             Sqrt[3]) - 35024220*Zeta[3]) + 
         CF*NC*
          (
           -79944020541921384377676406312651913653060327824450669350106473547\
41/42270110299013321221649577636295934374997472000000 + (11654605755575*lm)/
            9724 + 236413485*lm^2 - (85787117497387175013351359*Pi^2)/
            472586400 - (622233946959671196715676816313517*
             Im[PolyLog[2, (-1)^(1/3)]])/(537368813290316253004200*Sqrt[3]) + 
           70048440*Zeta[3])), (-94597429961032616590655792749318596415774830\
6658891862347247557812619101216416808427*CF^2*NC)/
        57987564029627824307754080459646116415674528100523707302400000000 - 
       (2764137453127190773561*CF^2*lm*NC)/39034124363520 - 
       (374289615*CF^2*lm^2*NC)/8 + 
       (136594704952375775869701773688778176419049184384755567269137987*CF*
         NM*NC)/20325320802847151551611029529729606528000000 - 
       (4691854676861887968361*CF*lm*NM*NC)/1053921357815040 - 
       (41587735*CF*lm^2*NM*NC)/24 + (1391734018927371591697178476411817*CF*
         NC*NL)/10756443548424096159436800 - 
       (4691854676861887968361*CF*lm*NC*NL)/1053921357815040 - 
       (41587735*CF*lm^2*NC*NL)/24 + (14435148928120102363010811906971178778\
797951762587256177499526530344301*CF*NC*NH)/
        2826304561011629209129318849386895614687635460945080570880000 - 
       (4691854676861887968361*CF*lm*NC*NH)/1053921357815040 - 
       (41587735*CF*lm^2*NC*NH)/24 + 
       (321599353295382059747201351675506610183*CF^2*NC*Pi^2)/
        38461103417863526400 + (1320305*CF^2*lm*NC*Pi^2)/18 - 
       (34819961472076882596029063429*CF*NM*NC*Pi^2)/9428098680 + 
       (1320305*CF*lm*NM*NC*Pi^2)/486 - (175036465908001*CF*NC*NL*Pi^2)/
        31691088 + (1320305*CF*lm*NC*NL*Pi^2)/486 + 
       (1320305*CF*lm*NC*NH*Pi^2)/486 - 
       (173855355595951860680755335138361303*CF^2*NC*Pi^3)/
        (1764289287794766321863389440*Sqrt[3]) - 
       (152348435982776300632731480485*CF*NC*NH*Pi^3)/(218837978263024718418*
         Sqrt[3]) - (316621952003*CF^2*NC*Pi^4)/194400 + 
       (4942377206158477808621915696111595507519419*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4074537895697623082027404742208000*
         Sqrt[3]) + (6510755115806125932140655995140153*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3103304896751576361099255*Sqrt[3]) - 
       (14987237881*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
       (24836479370850265811536476448337329*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6806671635010672538053200*
         Sqrt[3]) - (34822499653206011573195766968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (24836479370850265811536476448337329*CF^2*NC*Pi*Log[3]^2)/
        (326720238480512281826553600*Sqrt[3]) - 
       (4352812456650751446649470871*CF*NC*NH*Pi*Log[3]^2)/
        (8105110306037952534*Sqrt[3]) + 
       CF*((32525754591771219283079472616321377249991129*CF*NC)/
          324154987243681033440000 - (10818404680*CF*lm*NC)/3 + 
         CA*(-32525754592752075446105113451284884982551949/
            648309974487362066880000 + (59501225740*lm)/81)*NC - 
         (5082157717863348167447320231433299*NM*NC)/114673409650800 - 
         (10818404680*lm*NM*NC)/81 - (23515557328*NC*NL)/135 - 
         (10818404680*lm*NC*NL)/81 - (62057087458273413481499*NC*NH)/
          1602879437118960 - (10818404680*lm*NC*NH)/81)*Log[x]^2 + 
       (CF*NC*(-15340105994583585095226353299*CA + 
          304*(100921749908413834374770662*CF - 
            60775*(722398433039252968611*NM - 5409202340*NL)))*Log[x]^3)/
        1122392700 + (344244879538194060647299667871266957044690477*CF^2*NC*
         PolyGamma[2, 1])/70903504957220008767432000 - 
       (12766984221699520433987*CF*NM*NC*PolyGamma[2, 1])/6480 - 
       (474193644416024748256256804800469*CF*NC*NH*PolyGamma[2, 1])/
        3545175247861000438371600 - 
       (15576102100174243198598212769506545744777768412*CF^2*NC*Zeta[3])/
        3936252392390667049229467125 + (6496973996334118440973*CF*NM*NC*
         Zeta[3])/3240 - (12251969015*CF*NC*NL*Zeta[3])/81 + 
       (2967010524974541771252224214117931*CF*NC*NH*Zeta[3])/
        1772587623930500219185800 + CA*CF*NC*(1299415246706294547290570180088\
998969476092737121627413989653521348947307539694759/
          159306494586889627219104616647379440702402549726713481600000000 + 
         (457465085*lm^2)/48 - (535998922158618501862069779346073485633*Pi^2)/
          128203678059545088000 + (173855355595951860680755335138361303*Pi^3)/
          (3528578575589532643726778880*Sqrt[3]) + (317466947203*Pi^4)/
          388800 + lm*(7016183578207073102761/191622065057280 - 
           (14523355*Pi^2)/972) - 
         (4942377206158477808621915696111595507519419*
           Im[PolyLog[2, (-1)^(1/3)]])/(8149075791395246164054809484416000*
           Sqrt[3]) + (14987237881*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 + 
         (24836479370850265811536476448337329*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13613343270021345076106400*
           Sqrt[3]) + (24836479370850265811536476448337329*Pi*Log[3]^2)/
          (653440476961024563653107200*Sqrt[3]) - 
         (344244879538194060647299667871266957044690477*PolyGamma[2, 1])/
          141807009914440017534864000 + 
         (124608816806635013753684839598469732540312940331*Zeta[3])/
          62980038278250672787671474000) + CF*Log[x]*
        ((-3594633055826001694746308826821155087043530308623*NM*NC)/
          140753606095989447297216480000 - (1383551662378229*lm*NM*NC)/
          26409240 - (17665725*lm^2*NM*NC)/2 - (64221596584681274981231863*
           NC*NL)/231030655542086400 - (1383551662378229*lm*NC*NL)/
          26409240 - (17665725*lm^2*NC*NL)/2 - 
         (8027835994226104160207058488144505082267503613256936431*NC*NH)/
          1586940381169593768063575258030690639225875200 - 
         (1383551662378229*lm*NC*NH)/26409240 - (17665725*lm^2*NC*NH)/2 - 
         (240799477677139002442*NM*NC*Pi^2)/81 - (12249328405*NC*NL*Pi^2)/
          486 + (34822499653206011573195766968*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CF*NC*(8848768753482642967881218320503997788207688018816282263099879\
6427255457/1606264191362506206422683950179245506249903936000000 - 
           (1137323077525979*lm)/978120 - (476974575*lm^2)/2 + 
           (9440065227046472881482386351*Pi^2)/1381406400 + 
           (24836479370850265811536476448337329*Im[PolyLog[2, (-1)^(1/3)]])/
            (20420014905032017614159600*Sqrt[3]) - 70662900*Zeta[3]) + 
         CA*NC*(-884876875341578319935759921362492005904408914678951443034461\
91624828257/3212528382725012412845367900358491012499807872000000 + 
           (1680439716841229*lm)/4801680 + (194322975*lm^2)/4 - 
           (116544015148262189096237327*Pi^2)/34108800 - 
           (24836479370850265811536476448337329*Im[PolyLog[2, (-1)^(1/3)]])/
            (40840029810064035228319200*Sqrt[3]) + 35331450*Zeta[3]))}, 0, 
     39, 1]
 
CbarSeries["v", 2, 3, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-3*CA*(207866374390394 + 4387788554240*lm + 
           1907490816000*lm^2 - 172882066519575*Zeta[3]) + 
         2*(315*CF*(-12492530876566 - 1248067584*lm + 44590694400*lm^2 + 
             10396294630785*Zeta[3]) + 32*(6144*(8377809 + 2718940*lm + 
               2646000*lm^2)*NL + 35*NM*(-2690650046 + 477290496*lm + 
               464486400*lm^2 + 2043208125*Zeta[3]) + 
             35*NH*(-2690650046 + 477290496*lm + 464486400*lm^2 + 2043208125*
                Zeta[3])))))/1966449623040000, 
      -(CF*NC*(-(CA*(627986911725422 + 16978347294720*lm + 5722472448000*
              lm^2 - 518646199558725*Zeta[3])) + 
          2*(315*CF*(-12492946899094 + 28479062016*lm + 44590694400*lm^2 + 
              10396294630785*Zeta[3]) + 2*(32768*(27852367 + 13448820*lm + 
                7938000*lm^2)*NL + 105*NH*(-20590498838 + 4197056512*lm + 
                2477260800*lm^2 + 15163884225*Zeta[3]) + 35*NM*(
                -19238206334 + 12591169536*lm + 7431782400*lm^2 + 
                19891007325*Zeta[3])))))/655483207680000, 
      (CF*NC*(-1780383794190750*NM + 55227599266775040*lm*NM + 
         24692988837888000*lm^2*NM + 100363187771408384*NL + 
         55227599266775040*lm*NL + 24692988837888000*lm^2*NL - 
         298894130349169950*NH + 55227599266775040*lm*NH + 
         24692988837888000*lm^2*NH - 2*CA*(33490057816237533298 + 
           238301358916239360*lm + 67905719304192000*lm^2 - 
           27766538990248660875*Zeta[3]) + 45150918245866125*NM*Zeta[3] + 
         223982690299570125*NH*Zeta[3] + 252*CF*(-5656334323193619698 + 
           3124583326679040*lm + 2645677375488000*lm^2 + 4706120803273843275*
            Zeta[3])))/9344568608686080000, 
      -(CF*NC*(31596069941235450*NM + 78859986052055040*lm*NM + 
          29552928620544000*lm^2*NM + 141095547559215104*NL + 
          78859986052055040*lm*NL + 29552928620544000*lm^2*NL - 
          514747700245023210*NH + 78859986052055040*lm*NH + 
          29552928620544000*lm^2*NH - 8*CA*(28244857163591782186 + 
            80075052953763840*lm + 20317638426624000*lm^2 - 
            23453477194718303775*Zeta[3]) + 71333385249443625*NM*Zeta[3] + 
          396232184305101375*NH*Zeta[3] + 1008*CF*(-5136995685128763818 + 
            1276747180277760*lm + 791596302336000*lm^2 + 4273842872525802975*
             Zeta[3])))/9344568608686080000, 
      (CF*NC*(-121*CA*(358894112704549257111674 + 336799330057322496000*lm + 
           78983853716275200000*lm^2 - 298336589073456097476375*Zeta[3]) + 
         154*CF*(-7896581967423517555888814 + 589767093275590656000*lm + 
           304652007191347200000*lm^2 + 6569420197602551829049125*Zeta[3]) + 
         25*(2097152*(186276866130031 + 99144694465740*lm + 
             33142943988000*lm^2)*NL + 693*NM*(-79405595903388854 + 
             300031016288911360*lm + 100296957100032000*lm^2 + 
             588510200831778225*Zeta[3]) + 693*NH*(-2533973762777936006 + 
             300031016288911360*lm + 100296957100032000*lm^2 + 
             2001455388647339625*Zeta[3]))))/587960256858528153600000, 
      -(CF*NC*(-2904641151638640335922*NM + 811846879776205701120*lm*NM + 
          255017727125618688000*lm^2*NM + 1697676539925622685696*NL + 
          811846879776205701120*lm*NL + 255017727125618688000*lm^2*NL - 
          9687465340026831437850*NH + 811846879776205701120*lm*NH + 
          255017727125618688000*lm^2*NH - 121*CA*(189218228431375470692282 + 
            51655222550813736960*lm + 11591714869346304000*lm^2 - 
            157369592499235767581175*Zeta[3]) + 4413329446316292376875*NM*
           Zeta[3] + 7823882225554494474375*NH*Zeta[3] + 
          154*CF*(-4787293094545146255317102 + 95141951499204034560*lm + 
            44710900210335744000*lm^2 + 3982619827570793658358725*Zeta[3])))/
       117592051371705630720000, 
      (CF*NC*(-704*CA*(8438945663843019816822571774 + 
           485986381169766904627200*lm + 110824074509297909760000*lm^2 - 
           7019933392884250361914516125*Zeta[3]) + 
         4992*CF*(-43830233597219636138310508538 + 157816101828068219289600*
            lm + 76724359275667783680000*lm^2 + 36462749190076869718183500375*
            Zeta[3]) + 35*(134217728*(24984818536466681 + 9398802595602420*
              lm + 3019716385686000*lm^2)*NL + 429*NM*
            (-59034671042239002070246 + 2940526644061211197440*lm + 
             944754015130877952000*lm^2 + 61296808315835464997625*Zeta[3]) + 
           1287*NH*(980175548020403732480*lm + 314918005043625984000*lm^2 + 
             4719*(-4409139640861515646 + 3634719142911436125*Zeta[3])))))/
       12718756276363681018675200000, 
      -(CF*NC*(-11264*CA*(2345524820584730898300365078 - 
            1372290095522355609600*lm + 1223591533821296640000*lm^2 - 
            1951251770712260381014274625*Zeta[3]) + 
          26624*CF*(-41210381149602940922564426438 - 8767018909143819878400*
             lm + 2541305493321154560000*lm^2 + 34283207709329350287842951625*
             Zeta[3]) + 5*(7516192768*(1754341302152849 - 159649898599620*
               lm + 66680446833000*lm^2)*NL + 429*NM*
             (-1748098302844196538753194 - 2797108189432161239040*lm + 
              1168258956301172736000*lm^2 + 1556008153272213883617375*Zeta[
                3]) + 1287*NH*(-932369396477387079680*lm + 
              389419652100390912000*lm^2 + 16731*(-11482042237254116326 + 
                9713005060387253625*Zeta[3])))))/
       25437512552727362037350400000, 
      -(CF*NC*(10*(77*(4294967296*(54398204279183053 + 47130729663277260*lm + 
                10021362519168000*lm^2)*NL + 39*NM*(
                453303563519641571636520634 + 5190383142061357022576640*lm + 
                1103626263620172644352000*lm^2 - 379523938358046830125152375*
                 Zeta[3]) + 429*NH*(1696299989894533421535358 + 
                471853012914668820234240*lm + 100329660329106604032000*lm^2 - 
                1622703574534661986492125*Zeta[3])) + 
            CF*(488000972370952073544783876580962166 + 
              326387049956412602894348451840*lm + 
              89483121080587218176704512000*lm^2 - 
              405971400680836821149389738597955025*Zeta[3])) - 
          11*CA*(-9568512374483488901511357433859414 + 
            99023900775832774927554969600*lm + 16570948348256892254945280000*
             lm^2 + 7960202439725106148808203547198625*Zeta[3])))/
       48433023900392897319115161600000, 
      (CF*NC*(-11*CA*(-2719974107496520274903787619343702 + 
           22299370575602449102405632000*lm + 4007582360214345193881600000*
            lm^2 + 2262789324434789695687160391998625*Zeta[3]) + 
         2*(3*CF*(255889061413674998648156264555249434 + 
             116717268450475990358949888000*lm + 
             36068241241929106744934400000*lm^2 - 
             212875929522857632017162762485274375*Zeta[3]) + 
           10*(6006*NM*(29960477661283463045618242 + 
               286360492974640673587200*lm + 66726313023881871360000*lm^2 - 
               24639422046851314691863875*Zeta[3]) + 
             5*(2147483648*(270820724216651533 + 160176411346131180*lm + 
                 37323519216984000*lm^2)*NL + 429*NH*
                (-4983557669360901725447782 + 801809380328993886044160*lm + 
                 186833676466869239808000*lm^2 + 3871604738260738451597625*
                  Zeta[3]))))))/6919003414341842474159308800000, 
      -(CF*NC*(612*CF*(404088404358814071422687547302404570378 + 
            95059742337131144215503097036800*lm + 
            31513016352106912929546240000000*lm^2 - 
            336164072752266805743426637527784539375*Zeta[3]) - 
          990*CA*(-4430533432756747678766844607025092954 + 
            21209824237121036590281979330560*lm + 
            3968305762857907554091008000000*lm^2 + 
            3685817042914415145580028492072540775*Zeta[3]) + 
          35*(4294967296*(38621487174257350844363 + 19349328028822949937780*
               lm + 4751707808476629000000*lm^2)*NL + 36465*NH*
             (-30016297907530006857412973774 + 2279027316148929531249426432*
               lm + 559671730085148858777600000*lm^2 + 
              24313622080791016854274519125*Zeta[3]) + 65637*NM*
             (1266126286749405295138570240*lm + 310928738936193810432000000*
               lm^2 - 3179*(-70038504188972582720551606 + 
                57574493213072370670760625*Zeta[3])))))/
       531891468474114798358522704691200000, 
      (CF*NC*(1632*CF*(608372370444876488620649837749491153682 + 
           63523166061408628525226577100800*lm + 
           23010827220608121476669767680000*lm^2 - 
           506109431784587833239775918939710826875*Zeta[3]) - 
         528*CA*(-30542109587682625524516320960287634986 + 
           73728924409017450734862257356800*lm + 
           14488298620382891300125409280000*lm^2 + 
           25408292971975039498231505183652489375*Zeta[3]) + 
         35*(68719476736*(5008598329623200971223 + 2206806291138456287280*
              lm + 578283410268551988000*lm^2)*NL + 12155*NM*
            (4470595934037522506571106704562 + 12476394371431311377103323136*
              lm + 3269381600885602785008025600*lm^2 - 
             3689928891715159723304110711275*Zeta[3]) + 
           7293*NH*(-444101870378165195630834432318 + 
             20793990619052185628505538560*lm + 5448969334809337975013376000*
              lm^2 + 364276865429407298509896880125*Zeta[3]))))/
       1063782936948229596717045409382400000, 
      -(CF*NC*(9728*CF*(569958249604854481699666535874421443799358 + 
            23293201588693616701642261502361600*lm + 
            9682987952692811018829519912960000*lm^2 - 
            474152462659893047876710195494451539376125*Zeta[3]) - 
          13056*CA*(-6349419026294926190871370937872766423042 + 
            6957246665629860314109011243827200*lm + 
            1469676457598255267200704184320000*lm^2 + 
            5282136958104096644472023255447466043875*Zeta[3]) + 
          595*(2199023255552*(23773839256336820204231 + 
              9228710077822777376835*lm + 2666382199367850463500*lm^2)*NL + 
            20995*NM*(820144974704515681313970102752434 + 
              966618150982586100657596399616*lm + 
              279277754922590733157898649600*lm^2 - 
              679403574610393222770991631095275*Zeta[3]) + 
            4199*NH*(4833090754912930503287981998080*lm + 
              1396388774612953665789493248000*lm^2 + 
              247*(-653856159054924164233053402842 + 
                539748547443509876409745182375*Zeta[3])))))/
       3072205121906487075318827142296371200000, 
      (CF*NC*(107008*CF*(96930276008661483947347025131970686754222 + 
           1325643586534438417123702839705600*lm + 
           698645527842953127828054343680000*lm^2 - 
           80637011189683571806720920468315097993125*Zeta[3]) - 
         56576*CA*(-2534347521953685782007444345923194470554 + 
           1137474450776575065550511878963200*lm + 
           269178157953904682566900776960000*lm^2 + 
           2108343767114562745307442025287151362375*Zeta[3]) + 
         7735*(95*NM*(25991659627139486931992359437876826 + 
             11127290301522604870542318108672*lm + 
             3768126230277490019801864601600*lm^2 - 
             21580024004809997063356100589683175*Zeta[3]) + 
           7*(274877906944*(1643921794826429996363 + 549382914034736761980*
                lm + 186042074282658594000*lm^2)*NL + 88179*NH*
              (-93557154697351520257850210834 + 1712575845957245185850081280*
                lm + 579943705217085298704384000*lm^2 + 
               77521609517259223124376442875*Zeta[3])))))/
       3072205121906487075318827142296371200000, 
      -(CF*NC*(4*CF*(14298206812200296289999519597301545116588069183618 + 
            47789071957245081379620799072501235712000*lm + 
            41477150279780831807713042923257856000000*lm^2 - 
            11894783698261450697303256825582453349150506547875*Zeta[3]) - 
          10*CA*(-73373735200161383377566622121283559082946076646 + 
            11762634784573452500625774075710747443200*lm + 
            3379619652426586295443284978932121600000*lm^2 + 
            61040164389732725907796039185003032919588956025*Zeta[3]) + 
          1155*(12597*NM*(7404292346195964997040654398300961902 + 
              932401017562675613505407051366400*lm + 
              422333978674368293050200883200000*lm^2 - 
              6154677219243507234527704155739165125*Zeta[3]) + 
            5*(274877906944*(32004872311560046130539261 + 
                8545943723756517795356640*lm + 3870912135870470510820000*
                 lm^2)*NL + 20995*NH*(111888122107521073620648846163968*
                 lm + 50680077440924195166024105984000*lm^2 + 
                4199*(-2737777620872316027170039386186 + 
                  2273899679570681801155275533775*Zeta[3]))))))/
       9327214750108094760667959204011782963200000, 
      (CF*NC*(16*CF*(12642374550265170140168028888166231714348715698954 + 
           1377762316925914538991674979463987200*lm + 
           13892086706847863728431106180534763520000*lm^2 - 
           10517284626597453593129319229154028767212547451375*Zeta[3]) - 
         40*CA*(-60404475427457476255148416766291677405581627646 + 
           2635606900738936835343810823404304465920*lm + 
           1131947805743159266761053096191721472000*lm^2 + 
           50250930249834533625199405326325746249692903325*Zeta[3]) + 
         1155*(1099511627776*(44544667109961067908445189 + 
             6843271831913854599181920*lm + 6482490559665612864372000*lm^2)*
            NL + 4199*NM*(82124947912493835936989162133427364102 + 
             1791916397051977074482757060526080*lm + 
             1697445522100617111397547900928000*lm^2 - 
             68300444595705739510964765528204195625*Zeta[3]) + 
           188955*NH*(39820364378932823877394601345024*lm + 
             37721011602235935808834397798400*lm^2 + 
             37791*(-328570357654335576862671435218 + 
               273309277433824154588245054875*Zeta[3])))))/
       18654429500216189521335918408023565926400000, 
      -(CF*NC*(-25*CA*(-659147989229708816279290059026064238960814475365702 + 
            1579136764092505489683209088651793721720832*lm + 
            4593740293328419599844016410823054201978880*lm^2 + 
            548350058762103666950834587688121555264079293576585*Zeta[3]) + 
          7*(46*CF*(4588616753960737090789799918548366454948073257353706 - 
              3474626294724511091391900119032081573478400*lm + 
              1750860924899312947427843634842214334464000*lm^2 - 
              3817304115337987620143343966136615028936915908173375*Zeta[3]) + 
            165*(8796093022208*(7777169369337909817115728843 - 
                1909295404903018935941097960*lm + 
                2055284562230920340970249600*lm^2)*NL + 22287*NM*(
                -753548705002972266046806869818736640*lm + 
                811166787656087510781635242387046400*lm^2 + 
                23*(5232938890864579083745671027920583145426 - 
                  4352957131356102801590902639233578014875*Zeta[3])) + 
              37145*NH*(-452129223001783359628084121891241984*lm + 
                486700072593652506468981145432227840*lm^2 + 
                7429*(-33473454112315136046666091396281062 + 
                  27869773653608393115466058354578425*Zeta[3]))))))/
       78945545644914914054293606702755731000524800000, 
      (CF*NC*(CA*(2367102921273799830577836204909687672749575692980374 + 
           20577752487753958110236778860057822704435200*lm - 
           5203108858967807800199635090387954040832000*lm^2 - 
           1969210302643871621934431085704302150044027162506625*Zeta[3]) + 
         2*(23*CF*(4929369283459394875513457121295229799142160433443878 - 
             3488876128221043712748246851038607101132800*lm + 
             555272486925418223736719950357607743488000*lm^2 - 
             4100778653962669355248608726344487492841635214385625*Zeta[3]) + 
           105*(2199023255552*(-8177432798458575902220057499 - 
               10709158781652192164615031720*lm + 
               2048571402588314842385347200*lm^2)*NL + 81719*NM*
              (29988546164203515146314782520284619150102 - 
               288178871599653612246714386491637760*lm + 
               55126178183170167817714215262617600*lm^2 - 
               24947393955055941016767800209371284066625*Zeta[3]) + 
             222870*NH*(-105665586253206324490461941713600512*lm + 
               20212932000495728199828545596293120*lm^2 + 7429*
                (-2503922829781506528970616937544786 + 
                 2085901561090436786746342759741275*Zeta[3]))))))/
       7176867785901355823117600609341430090956800000}, 0, 18, 1]
 
CbarSeries["v", 2, 4, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(3*CF*(-8230118400*lm^2 + 571362336*Pi^2 + 3175200*Pi^4 + 
            30481920*lm*(-544 + 15*Pi^2) + 35*(-231398195 + 60351360*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] - 39191040*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 10058560*PolyGamma[2, 1] - 
              120574976*Zeta[3])) + 12*CA*(314344800*lm^2 - 104019648*Pi^2 + 
            2143260*Pi^4 - 26460*lm*(-53411 + 660*Pi^2) - 
            35*(-35894897 + 7543920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              4898880*Im[PolyLog[2, (-1)^(1/3)]]^2 - 1257320*PolyGamma[2, 
                1] - 20995024*Zeta[3])) + 
          560*(9*NL*(-503321 - 136080*lm^2 - 13578*Pi^2 + 126*lm*(-3481 + 
                60*Pi^2) - 90720*Zeta[3]) + 9*NM*(-503321 - 136080*lm^2 - 
              13578*Pi^2 + 126*lm*(-3481 + 60*Pi^2) + 7560*PolyGamma[2, 1] - 
              75600*Zeta[3]) + NH*(-15068961 - 1224720*lm^2 + 
              1134*lm*(-3481 + 60*Pi^2) - 329721384*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 54953564*PolyGamma[2, 1] + 605782648*Zeta[
                3]))))/144027072000, 
      (CF*NC*(CF*(1036994918400*lm^2 - 72311938704*Pi^2 + 2789095680*Pi^4 - 
           342921600*lm*(-2329 + 168*Pi^2) - 35*(-30040388397 + 
             55155145728*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             12227604480*Im[PolyLog[2, (-1)^(1/3)]]^2 - 9800529728*
              PolyGamma[2, 1] - 77107316608*Zeta[3])) - 
         8*CA*(19803722400*lm^2 - 10242608436*Pi^2 + 334348560*Pi^4 - 
           595350*lm*(-108149 + 1848*Pi^2) - 35*(-447418557 + 
             3447196608*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             764225280*Im[PolyLog[2, (-1)^(1/3)]]^2 - 612533108*
              PolyGamma[2, 1] - 5358212392*Zeta[3])) - 
         3920*(NH*(2863018539 - 7348320*lm^2 + 2430*lm*(-5983 + 168*Pi^2) + 
             718018656*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             119669776*PolyGamma[2, 1] - 3665289632*Zeta[3]) + 
           81*NL*(85969 - 90720*lm^2 - 8112*Pi^2 + 30*lm*(-5983 + 168*
                Pi^2) - 60480*Zeta[3]) + 81*NM*(85969 - 90720*lm^2 - 
             8112*Pi^2 + 30*lm*(-5983 + 168*Pi^2) + 5040*PolyGamma[2, 1] - 
             50400*Zeta[3]))))/1296243648000, 
      (CF*NC*(CF*(-1777705574400*lm^2 - 22772216016*Pi^2 + 8560339200*Pi^4 + 
           121927680*lm*(-9079 + 60*Pi^2) + 35*(-55890408915 + 
             91118022144*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             30412247040*Im[PolyLog[2, (-1)^(1/3)]]^2 - 16799588224*
              PolyGamma[2, 1] - 118719046400*Zeta[3])) - 
         448*CA*(-606236400*lm^2 - 1330992*Pi^2 + 9191070*Pi^4 + 
           1890*lm*(-995563 + 1320*Pi^2) + 5*(-177231537 + 711859548*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 237595680*Im[PolyLog[2, 
                 (-1)^(1/3)]]^2 - 131246783*PolyGamma[2, 1] - 
             991900186*Zeta[3])) + 3360*(NH*(3931911327 - 14696640*lm^2 + 
             504*lm*(-53393 + 120*Pi^2) + 1638312512*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 291369940*PolyGamma[2, 1] - 
             6238345640*Zeta[3]) + 3*NM*(6663125 - 4898880*lm^2 - 
             2487888*Pi^2 + 168*lm*(-53393 + 120*Pi^2) - 
             47880*PolyGamma[2, 1] - 337680*Zeta[3]) + 
           3*NL*(2651537 - 4898880*lm^2 - 1520208*Pi^2 + 
             168*lm*(-53393 + 120*Pi^2) - 241920*Zeta[3]))))/432081216000, 
      (CF*NC*(555532992000*(-14*CA*(76 + 33*lm) + 9*CF*(577 + 336*lm) + 
           28*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         15554923776000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         40*CA*(11977291307520*lm^2 - 2525870766429*Pi^2 - 
           31363577000*Sqrt[3]*Pi^3 + 56427106302*Pi^4 - 
           22504230*lm*(-2146811 + 6600*Pi^2) - 24194759400*Sqrt[3]*Pi*
            Log[3]^2 - 7*(-6525116328069 + 4689538496724*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 2748499477920*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 165906921600*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 825307762778*
              PolyGamma[2, 1] - 8686266609076*Zeta[3])) + 
         211680*Log[x]*(4*(6561*NM*(49423 + 39000*lm + 8400*lm^2 + 4200*
                Pi^2) + 6561*NL*(74623 + 39000*lm + 8400*lm^2 + 4200*Pi^2) + 
             NH*(12563210811 + 255879000*lm + 55112400*lm^2 - 7170144800*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
           5*CF*(5134428975 + 5451403680*lm + 1587237120*lm^2 - 
             93463632*Pi^2 + 29260480*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             264539520*Zeta[3]) + 4*CA*(-1793121300*lm - 303118200*lm^2 + 
             24942735*Pi^2 - 2*(1635374049 + 9143900*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 82668600*Zeta[3]))) + 
         7*(-560*(2187*NL*(-25053647 - 10160640*lm^2 - 4314720*Pi^2 + 1050*
                lm*(-26717 + 120*Pi^2) - 17841600*Zeta[3]) + 
             10935*NM*(1080689 - 2032128*lm^2 - 752064*Pi^2 + 210*lm*
                (-26717 + 120*Pi^2) - 240912*PolyGamma[2, 1] - 784224*
                Zeta[3]) - NH*(-3271429318293 + 22221319680*lm^2 + 
               125477534000*Sqrt[3]*Pi^3 - 2296350*lm*(-26717 + 120*Pi^2) - 
               796979297760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               4646253830400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               96796954800*Sqrt[3]*Pi*Log[3]^2 + 199515242128*PolyGamma[2, 
                 1] + 371694733856*Zeta[3])) + CF*(447981804748800*lm^2 - 
             28552369367088*Pi^2 - 358440880000*Sqrt[3]*Pi^3 + 
             397977662880*Pi^4 - 9258883200*lm*(-75121 + 600*Pi^2) - 
             276511536000*Sqrt[3]*Pi*Log[3]^2 + 5*(107700283796481 - 
               75032615947584*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               43975991646720*Im[PolyLog[2, (-1)^(1/3)]]^2 - 2654510745600*
                Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               13204924204448*PolyGamma[2, 1] + 119096953901248*Zeta[3])))))/
       34998578496000, (-2*CF*NC*(-35*CA*(76 + 33*lm) + 
          3*CF*(4061 + 2520*lm) + 35*(9*NM + 6*lm*NM + 10*NL + 6*lm*NL + 
            6*lm*NH))*Log[x]^2)/105 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/3 + 
       (CF*NC*Log[x]*(CA*(120797760099 + 62244338220*lm + 10912255200*lm^2 - 
            1272571560*Pi^2 - 3085742960*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            5952139200*Zeta[3]) - 4*(4146805692*NL + 2198000610*lm*NL + 
            496011600*lm^2*NL + 86824203789*NH + 2198000610*lm*NH + 
            496011600*lm^2*NH + 248005800*NL*Pi^2 + 
            3645*NM*(615995 + 603018*lm + 136080*lm^2 + 76020*Pi^2) - 
            49581232400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            CF*(56429866887 + 57551517360*lm + 17856417600*lm^2 - 
              1071608130*Pi^2 - 1542871480*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 2976069600*Zeta[3]))))/496011600 + 
       (CF*NC*(CF*(-25522963358054400*lm^2 + 1111762204357536*Pi^2 - 
            105840983528000*Sqrt[3]*Pi^3 + 5698379665440*Pi^4 + 
            55553299200*lm*(-647447 + 3000*Pi^2) - 81648758721600*Sqrt[3]*Pi*
             Log[3]^2 + 35*(-710038756879875 + 697294892757504*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 407326313157120*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 111975440532480*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 125791201158464*PolyGamma[2, 1] - 
              1059621497800960*Zeta[3])) + 
          560*(6561*NL*(-404822299 - 192961440*lm^2 - 89572320*Pi^2 + 
              840*lm*(-601297 + 1500*Pi^2) - 358041600*Zeta[3]) + 
            19683*NM*(95713891 - 64320480*lm^2 - 27782920*Pi^2 + 
              280*lm*(-601297 + 1500*Pi^2) - 10398348*PolyGamma[2, 1] - 
              12430296*Zeta[3]) - NH*(-182879005534605 + 1266020007840*lm^
                2 + 6073700969000*Sqrt[3]*Pi^3 - 5511240*lm*(-601297 + 
                1500*Pi^2) - 25830482621280*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 224900470166400*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 4685426461800*Sqrt[3]*Pi*Log[3]^
                2 + 7707458421076*PolyGamma[2, 1] + 15830243888552*Zeta[
                3])) + 80*CA*(48741770301840*lm^2 - 6243885336798*Pi^2 + 
            661506147050*Sqrt[3]*Pi^3 + 10679543091*Pi^4 - 
            19289340*lm*(-9830291 + 16500*Pi^2) + 510304742010*Sqrt[3]*Pi*
             Log[3]^2 + 14*(10535074648776 - 10895232699336*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 6364473643080*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 1749616258320*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 1965487518101*PolyGamma[2, 1] + 
              18912033861322*Zeta[3]))))/104995735488000, 
      (94828504053239*CF^2*NC)/79361856000 + (285577*CF^2*lm*NC)/140 + 
       (6408*CF^2*lm^2*NC)/5 - (11999941*CF*NM*NC)/151200 + 
       (502381*CF*lm*NM*NC)/5040 + (178*CF*lm^2*NM*NC)/5 + 
       (12956521*CF*NC*NL)/151200 + (502381*CF*lm*NC*NL)/5040 + 
       (178*CF*lm^2*NC*NL)/5 - (88367402752717*CF*NC*NH)/14880348000 + 
       (502381*CF*lm*NC*NH)/5040 + (178*CF*lm^2*NC*NH)/5 - 
       (8683863523*CF^2*NC*Pi^2)/83349000 - 10*CF^2*lm*NC*Pi^2 + 
       (37859*CF*NM*NC*Pi^2)/3780 - (5*CF*lm*NM*NC*Pi^2)/18 + 
       (2769*CF*NC*NL*Pi^2)/140 - (5*CF*lm*NC*NL*Pi^2)/18 - 
       (5*CF*lm*NC*NH*Pi^2)/18 + (57951191*CF^2*NC*Pi^3)/(2834352*Sqrt[3]) + 
       (5414042305*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) + 
       (174437*CF^2*NC*Pi^4)/75600 - (1412533773023*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(434010150*Sqrt[3]) - 
       (73993897316*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (18600435*Sqrt[3]) + (26239*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        35 + (57951191*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (76545*Sqrt[3]) + (618747692*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) + 
       (57951191*CF^2*NC*Pi*Log[3]^2)/(3674160*Sqrt[3]) + 
       (154686923*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) + 
       (CF*NC*(-10*CA*(9575 + 4851*lm) + 5*CF*(100867 + 63504*lm) + 
          14*(7*(179 + 90*lm)*NM + 945*NL + 630*lm*NL + 8*NH + 
            630*lm*NH))*Log[x]^2)/210 + 14*CF*NC*(13*CA + 46*CF - 
         2*(2*NM + NL))*Log[x]^3 + (3794337007387*CF^2*NC*PolyGamma[2, 1])/
        18749238480 + (22826*CF*NM*NC*PolyGamma[2, 1])/4725 + 
       (34275724829*CF*NC*NH*PolyGamma[2, 1])/93002175 - 
       (CF*NC*Log[x]*(4*(-67825131381*NL - 33869325420*lm*NL - 
            6944162400*lm^2*NL - 1519434627351*NH - 33869325420*lm*NH - 
            6944162400*lm^2*NH - 4050761400*NL*Pi^2 - 
            6561*NM*(8863123 + 5162220*lm + 1058400*lm^2 + 256200*Pi^2) + 
            866246768800*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            45*CF*(-19597517097 - 20382770016*lm - 5555329920*lm^2 + 
              396434574*Pi^2 + 463609528*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              925888320*Zeta[3])) - 45*CA*(-40760744997 - 20879149032*lm - 
            3394923840*lm^2 + 396713052*Pi^2 + 927219056*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1851776640*Zeta[3])))/992023200 + 
       (85384252525373*CF^2*NC*Zeta[3])/46873096200 - 
       (395348*CF*NM*NC*Zeta[3])/4725 + (304*CF*NC*NL*Zeta[3])/3 - 
       (111170086742*CF*NC*NH*Zeta[3])/93002175 - 
       (CA*CF*NC*(4111633001710080*lm^2 - 926946865126512*Pi^2 + 
          71558130646800*Sqrt[3]*Pi^3 + 28892854264176*Pi^4 - 
          2083248720*lm*(-8038127 + 15400*Pi^2) + 55201986498960*Sqrt[3]*Pi*
           Log[3]^2 + 7*(1848435655455927 - 1627238906522496*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 1124482899375360*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 378527907421440*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 303546960590960*
             PolyGamma[2, 1] + 3209328326961760*Zeta[3])))/20999147097600, 
      -(CF*NC*(-21*CA*(291677 + 148720*lm) + CF*(30628622 + 20442240*lm) + 
           112*(11243*NM + 5070*lm*NM + 7545*NL + 5070*lm*NL + 81*NH + 
             5070*lm*NH))*Log[x]^2)/5670 - 
       (16*CF*NC*(2255*CA + 7838*CF - 712*NM - 338*NL)*Log[x]^3)/81 + 
       (CF*NC*Log[x]*(-16*(78732*NM*(1731373 + 1072905*lm + 226800*lm^2 + 
              52150*Pi^2) + 98415*NL*(1717591 + 858324*lm + 181440*lm^2 + 
              107800*Pi^2) + 4*NH*(824534854944 + 21117989115*lm + 
              4464104400*lm^2 - 470061419800*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]])) + CF*(-36210702016623 - 36227780271360*lm - 
            10285296537600*lm^2 + 724024983240*Pi^2 + 1698309877760*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1714216089600*Zeta[3]) + 
          CA*(19340900228589 + 9433450939680*lm + 1571364748800*lm^2 - 
            213851858400*Pi^2 - 849154938880*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 857108044800*Zeta[3])))/4464104400 - 
       (CF*NC*(CF*(2541352780289433600*lm^2 - 170964789410463984*Pi^2 + 
            29126014403584000*Sqrt[3]*Pi^3 + 3268350585843840*Pi^4 - 
            7999675084800*lm*(-472459 + 1650*Pi^2) + 22468639682764800*
             Sqrt[3]*Pi*Log[3]^2 - 35*(-50060730158501265 + 70020622580827776*
               Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 46430914159687680*
               Im[PolyLog[2, (-1)^(1/3)]]^2 - 30814134422077440*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 13192169187358336*
               PolyGamma[2, 1] - 113803390660647680*Zeta[3])) - 
          224*(-(NH*(-54174520782859131 + 315147914222400*lm^2 + 
               2303300957020000*Sqrt[3]*Pi^3 - 248005800*lm*(-3425299 + 
                 6600*Pi^2) - 6348953727307200*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 85287944008512000*Sqrt[3]*Im[PolyLog[3, 
                  -((-1)^(5/6)/Sqrt[3])]] + 1776832166844000*Sqrt[3]*Pi*
                Log[3]^2 + 2232378209533160*PolyGamma[2, 1] - 
               12894300429381680*Zeta[3])) + 4428675*NL*(-141935507 - 
              71160768*lm^2 - 41799920*Pi^2 + 56*lm*(-3425299 + 6600*Pi^2) - 
              221760000*Zeta[3]) + 295245*NM*(3603542551 - 1067411520*lm^2 - 
              313141200*Pi^2 + 840*lm*(-3425299 + 6600*Pi^2) - 
              179522388*PolyGamma[2, 1] + 3359265624*Zeta[3])) - 
          10*CA*(38826223032199680*lm^2 - 6963189755963256*Pi^2 + 
            1456300720179200*Sqrt[3]*Pi^3 + 192749671269792*Pi^4 - 
            2777664960*lm*(-55468481 + 72600*Pi^2) + 1123431984138240*Sqrt[3]*
             Pi*Log[3]^2 + 7*(12661962268603905 - 17505155645206944*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 11607728539921920*
               Im[PolyLog[2, (-1)^(1/3)]]^2 + 7703533605519360*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3298042296839584*
               PolyGamma[2, 1] + 32810649226701248*Zeta[3]))))/
        944961619392000, (CF*NC*(173623374477662929281*CF + 
         464355068981487868800*CF*lm + 290058614964908697600*CF*lm^2 - 
         49889590449281074800*NM + 22634515612891274400*lm*NM + 
         8057183749025241600*lm^2*NM + 15464496377275933680*NL + 
         22634515612891274400*lm*NL + 8057183749025241600*lm^2*NL - 
         1690034990474659889808*NH + 22634515612891274400*lm*NH + 
         8057183749025241600*lm^2*NH - 31293359569392725952*CF*Pi^2 - 
         1697781042840960000*CF*lm*Pi^2 - 5579562796867382400*NM*Pi^2 - 
         47160584523360000*lm*NM*Pi^2 + 5465103279094166400*NL*Pi^2 - 
         47160584523360000*lm*NL*Pi^2 - 47160584523360000*lm*NH*Pi^2 + 
         3889596602687180000*Sqrt[3]*CF*Pi^3 + 84552925056162640000*Sqrt[3]*
          NH*Pi^3 + 829716375198553920*CF*Pi^4 - 267832867477754927040*
          Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 351163545189450470400*
          Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 196525431913310438400*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 144026205630931008000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3130874024936765184000*
          Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         3000545950644396000*Sqrt[3]*CF*Pi*Log[3]^2 + 65226542186182608000*
          Sqrt[3]*NH*Pi*Log[3]^2 + 5499776620800*
          (7*CF*(24117929 + 15770160*lm) - CA*(29483837 + 16865310*lm) - 
           6982410*NM + 3066420*lm*NM + 4357570*NL + 3066420*lm*NL + 
           96228*NH + 3066420*lm*NH)*Log[x]^2 + 5389781088384000*
          (15289*CA + 61422*CF - 11832*NM - 2086*NL)*Log[x]^3 + 
         52307949245519598400*CF*PolyGamma[2, 1] - 4486686968499563520*NM*
          PolyGamma[2, 1] + 101486834841224053760*NH*PolyGamma[2, 1] + 
         166320*Log[x]*(4*(131710704085611*NL + 62215470738540*lm*NL + 
             12249502473600*lm^2*NL + 2755050052934325*NH + 
             62215470738540*lm*NH + 12249502473600*lm^2*NH + 
             8308111631400*NL*Pi^2 + 413343*NM*(190760007 + 150517780*lm + 
               29635200*lm^2 - 35830200*Pi^2) - 1568699908277600*Sqrt[3]*NH*
              Im[PolyLog[2, (-1)^(1/3)]] - 14*CF*(-119366446382544 - 
               121921684927560*lm - 31498720646400*lm^2 + 2686426873875*
                Pi^2 + 5154514448300*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               5249786774400*Zeta[3])) + 35*CA*(-99500865905067 - 
             48906469300248*lm - 7699687269120*lm^2 + 1239958377396*Pi^2 + 
             4123611558640*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             4199829419520*Zeta[3])) + 470828439784299175040*CF*Zeta[3] - 
         53129540487948503040*NM*Zeta[3] + 33729250051107072000*NL*
          Zeta[3] - 507949235437578260480*NH*Zeta[3] - 
         77*CA*(1175814974994664221 + 575513124930374400*lm^2 - 
           167709573841486680*Pi^2 + 25257120796670000*Sqrt[3]*Pi^3 + 
           5877748769064480*Pi^4 - 343736038800*lm*(-6834379 + 9800*Pi^2) - 
           1739174464141265760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           1276139168268249600*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           935235101499552000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           19484064614574000*Sqrt[3]*Pi*Log[3]^2 + 339662008087789600*
            PolyGamma[2, 1] + 3615108311929304000*Zeta[3])))/
       31183733439936000, 
      (CF*NC*(-916629436800*(-(CA*(342796493 + 203531790*lm)) + 
           CF*(1903472099 + 1332208080*lm) - 31068744*NM + 37005780*lm*NM + 
           52323915*NL + 37005780*lm*NL + 1378296*NH + 37005780*lm*NH)*
          Log[x]^2 - 898296848064000*(193245*CA + 741841*CF - 142652*NM - 
           25174*NL)*Log[x]^3 + 166320*Log[x]*
          (2*(-498074871806883*NL - 233777109284460*lm*NL - 
             47248080969600*lm^2*NL - 9385322956507506*NH - 
             233777109284460*lm*NH - 47248080969600*lm^2*NH - 
             32745004903800*NL*Pi^2 - 183708*NM*(2348954033 + 1272547245*
                lm + 257191200*lm^2 - 329218050*Pi^2) + 5342491161610400*
              Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
             14*CF*(-459525916269264 - 454334600861640*lm - 121495065350400*
                lm^2 + 10689186875265*Pi^2 + 28414609762460*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 20249177558400*Zeta[3])) - 
           7*CA*(-978719856924579 - 461860190814780*lm - 74246984380800*
              lm^2 + 13847383175850*Pi^2 + 56829219524920*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 40498355116800*Zeta[3])) + 
         77*CA*(1146864337750221237 + 1031958835908739200*lm^2 - 
           280651551147790740*Pi^2 + 69615793918027000*Sqrt[3]*Pi^3 + 
           9262361299474080*Pi^4 - 744017400*lm*(-5542157193 + 
             5929000*Pi^2) - 3530316882825228720*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 2454551305822425600*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 2577773397650371200*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 53703612451049400*Sqrt[3]*
            Pi*Log[3]^2 + 674148984471020320*PolyGamma[2, 1] + 
           7030538649010855040*Zeta[3]) + 
         44*(-4*NH*(-17920980553768937586 + 82087634674558800*lm^2 + 
             818068959121592500*Sqrt[3]*Pi^3 - 651015225*lm*(-343352091 + 
               539000*Pi^2) - 2086149056655127800*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 30291924886330968000*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] + 631081768465228500*Sqrt[3]*Pi*
              Log[3]^2 + 741143349982942480*PolyGamma[2, 1] - 
             6004476508954971040*Zeta[3]) + 14467005*NL*(-32530195339 - 
             22696511040*lm^2 - 16059739080*Pi^2 + 180*lm*(-343352091 + 
               539000*Pi^2) - 103833273600*Zeta[3]) + 4960116*NM*
            (474441038631 - 66198157200*lm^2 + 37517925550*Pi^2 + 
             525*lm*(-343352091 + 539000*Pi^2) + 41956696020*
              PolyGamma[2, 1] + 536090096040*Zeta[3])) - 
         7*CF*(74301036185429222400*lm^2 - 7503891976824828696*Pi^2 + 
           1531547466196594000*Sqrt[3]*Pi^3 + 189655855261709760*Pi^4 - 
           589261780800*lm*(-190991253 + 539000*Pi^2) + 1181479473923086800*
            Sqrt[3]*Pi*Log[3]^2 + 11*(2258837857746536661 - 
             7060633765650457440*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             4909102611644851200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             5155546795300742400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] + 1348297968942040640*PolyGamma[2, 1] + 
             12121191324240918400*Zeta[3]))))/31183733439936000, 
      (CF*NC*(891361583749627319637*CF + 6905022930996169795200*CF*lm + 
         4304253306234238156800*CF*lm^2 - 1304744584618198735704*NM + 
         336277657667477988000*lm*NM + 119562591839839948800*lm^2*NM + 
         132457772384380729440*NL + 336277657667477988000*lm*NL + 
         119562591839839948800*lm^2*NL - 31750537929867413898120*NH + 
         336277657667477988000*lm*NH + 119562591839839948800*lm^2*NH - 
         751069462153391439408*CF*Pi^2 - 20373372514091520000*CF*lm*Pi^2 - 
         637957506186288288000*NM*Pi^2 - 565927014280320000*lm*NM*Pi^2 + 
         95618219865639609600*NL*Pi^2 - 565927014280320000*lm*NL*Pi^2 - 
         565927014280320000*lm*NH*Pi^2 + 99741219260005708000*Sqrt[3]*CF*
          Pi^3 + 1604040440890653920000*Sqrt[3]*NH*Pi^3 + 
         17032220268496836480*CF*Pi^4 - 4416293460902202337920*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] - 6267487990164289996800*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 3310556614268362905600*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 3693274861741925644800*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 59395326039836785152000*
          Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         76943226286290117600*Sqrt[3]*CF*Pi*Log[3]^2 + 1237402625829933024000*
          Sqrt[3]*NH*Pi*Log[3]^2 - 8249664931200*
          (CA*(327135133 + 261242520*lm) - 
           2*(CF*(1184514833 + 854975520*lm) + 3*(-131609689 + 7916440*lm)*
              NM + 5*(98*(66907 + 48468*lm)*NL + 3*(82947 + 1583288*lm)*
                NH)))*Log[x]^2 + 5389781088384000*(421509*CA + 1697254*CF - 
           673560*NM - 48468*NL)*Log[x]^3 + 813613167444314307840*CF*
          PolyGamma[2, 1] - 501135627550496843520*NM*PolyGamma[2, 1] + 
         1834171245475210118400*NH*PolyGamma[2, 1] - 
         14*CA*(46971018222794265600*lm^2 - 23086790673487487640*Pi^2 + 
           3562186402143061000*Sqrt[3]*Pi^3 + 640632267548048160*Pi^4 - 
           515604058200*lm*(-372166147 + 431200*Pi^2) + 2747972367367504200*
            Sqrt[3]*Pi*Log[3]^2 - 33*(-963976298681793957 + 
             4779538377599786080*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             3582853478645414400*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             3997050716170915200*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] - 880533731000340160*PolyGamma[2, 1] - 
             10520014868872675520*Zeta[3])) + 166320*Log[x]*
          (4*(8680203*NM*(-357328851 + 133126720*lm + 25401600*lm^2 - 
               139604400*Pi^2) + 2480058*NL*(1046748053 + 465943520*lm + 
               88905600*lm^2 + 69217400*Pi^2) + NH*(52325447498032119 + 
               1155566954324160*lm + 220491044524800*lm^2 - 29759562910772800*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
           7*CF*(-17190179064002361 - 18290885667909120*lm - 
             4535815773081600*lm^2 + 556017597695160*Pi^2 + 1057420824383840*
              Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 755969295513600*Zeta[3]) + 
           7*CA*(-8987779862498877 - 4513746034546560*lm - 692971854220800*
              lm^2 + 191124964724940*Pi^2 + 528710412191920*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 377984647756800*Zeta[3])) + 
         8200748242996785315840*CF*Zeta[3] - 1357474768137491351040*NM*
          Zeta[3] + 692015553061975296000*NL*Zeta[3] - 
         10627814695620250867200*NH*Zeta[3]))/93551200319808000, 
      (89449812393247680623*CF^2*NC)/17718030363600000 - 
       (2672768986*CF^2*lm*NC)/23625 - (370176*CF^2*lm^2*NC)/5 + 
       (22918023713951*CF*NM*NC)/1250235000 - (2393121293*CF*lm*NM*NC)/
        425250 - (30848*CF*lm^2*NM*NC)/15 - (500312176*CF*NC*NL)/455625 - 
       (2393121293*CF*lm*NC*NL)/425250 - (30848*CF*lm^2*NC*NL)/15 + 
       (25173392235820282873*CF*NC*NH)/44295075909000 - 
       (2393121293*CF*lm*NC*NH)/425250 - (30848*CF*lm^2*NC*NH)/15 + 
       (8162514726229*CF^2*NC*Pi^2)/589396500 + (1344*CF^2*lm*NC*Pi^2)/5 + 
       (121964684*CF*NM*NC*Pi^2)/14175 + (112*CF*lm*NM*NC*Pi^2)/15 - 
       (10331324*CF*NC*NL*Pi^2)/6075 + (112*CF*lm*NC*NL*Pi^2)/15 + 
       (112*CF*lm*NC*NH*Pi^2)/15 - (9008247909521*CF^2*NC*Pi^3)/
        (1291401630*Sqrt[3]) - (10308251173948*CF*NC*NH*Pi^3)/
        (129140163*Sqrt[3]) - (561353*CF^2*NC*Pi^4)/2025 + 
       (28990829210657947*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (112997642625*Sqrt[3]) + (917392708194944*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4519905705*Sqrt[3]) - 
       (905392*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (10295140468024*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (39858075*Sqrt[3]) - (23561716969024*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) - 
       (1286892558503*CF^2*NC*Pi*Log[3]^2)/(239148450*Sqrt[3]) - 
       (1472607310564*CF*NC*NH*Pi*Log[3]^2)/(23914845*Sqrt[3]) - 
       (CF*NC*(-25*CA*(1472356531 + 1391898816*lm) + 
          22*CF*(12948784577 + 10352966400*lm) + 
          240*(-282933547*NM + 26361720*lm*NM + 36288994*NL + 
            26361720*lm*NL + 1568085*NH + 26361720*lm*NH))*Log[x]^2)/
        850500 - (4*CF*NC*(70492920*CA + 259907551*CF - 
          240*(400720*NM + 31383*NL))*Log[x]^3)/6075 - 
       (39839817666107771*CF^2*NC*PolyGamma[2, 1])/2847540594150 + 
       (182634518*CF*NM*NC*PolyGamma[2, 1])/19845 - 
       (66673234972792471*CF*NC*NH*PolyGamma[2, 1])/2847540594150 + 
       (CA*CF*NC*(396806771276497612800*lm^2 - 213423996608910319176*Pi^2 + 
          40785743235147279600*Sqrt[3]*Pi^3 + 5072077554746479200*Pi^4 - 
          41248324656*lm*(-38567905423 + 34927200*Pi^2) + 
          31463287638542187120*Sqrt[3]*Pi*Log[3]^2 - 
          11*(10390072880865615669 + 136372860606934982688*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 96250577681763187200*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 137294346059093180160*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 22310297893020351760*
             PolyGamma[2, 1] - 288022694129342503520*Zeta[3])))/
        35081700119928000 - (8842659177308153*CF^2*NC*Zeta[3])/56950811883 + 
       (585322156*CF*NM*NC*Zeta[3])/19845 - (193568*CF*NC*NL*Zeta[3])/15 + 
       (297107289699375209*CF*NC*NH*Zeta[3])/1423770297075 - 
       (CF*NC*Log[x]*(5*CA*(-270546626339914857 - 132747730533815040*lm - 
            20789155626624000*lm^2 + 6904204052712120*Pi^2 + 
            20178475317327040*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            11339539432704000*Zeta[3]) + 
          2*(-40*(-177147*NM*(5315489287 + 6818220640*lm + 1333584000*lm^2 - 
                6949689600*Pi^2) - 1240029*NL*(2210612219 + 974031520*lm + 
                190512000*lm^2 + 151376400*Pi^2) - 5*NH*(10153315521499719 + 
                241565466342816*lm + 47248080969600*lm^2 - 5772620657410880*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            CF*(1266512694815048439 + 1328213053232755200*lm + 
              340186182981120000*lm^2 - 45971882762393700*Pi^2 - 
              100892376586635200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              56697697163520000*Zeta[3]))))/7030964430000, 
      (-3128290395825163004999*CF^2*NC)/141744242908800000 + 
       (425589991*CF^2*lm*NC)/1500 + (883512*CF^2*lm^2*NC)/5 - 
       (9321279106673*CF*NM*NC)/370440000 + (745863091*CF*lm*NM*NC)/54000 + 
       (24542*CF*lm^2*NM*NC)/5 - (17875699*CF*NC*NL)/270000 + 
       (745863091*CF*lm*NC*NL)/54000 + (24542*CF*lm^2*NC*NL)/5 - 
       (12201311917708652040707*CF*NC*NH)/7486570925064000 + 
       (745863091*CF*lm*NC*NH)/54000 + (24542*CF*lm^2*NC*NH)/5 - 
       (1916480836243*CF^2*NC*Pi^2)/26061750 - (3528*CF^2*lm*NC*Pi^2)/5 - 
       (1228864307*CF*NM*NC*Pi^2)/9450 - (98*CF*lm*NM*NC*Pi^2)/5 + 
       (6102929*CF*NC*NL*Pi^2)/1350 - (98*CF*lm*NC*NL*Pi^2)/5 - 
       (98*CF*lm*NC*NH*Pi^2)/5 + (377858722033499*CF^2*NC*Pi^3)/
        (20662426080*Sqrt[3]) + (21228277365659*CF*NC*NH*Pi^3)/
        (86093442*Sqrt[3]) + (966931*CF^2*NC*Pi^4)/1080 - 
       (156862085854150019*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (258280326000*Sqrt[3]) - (468150496718344*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(502211745*Sqrt[3]) + 
       (759962*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (53979817433357*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (79716150*Sqrt[3]) + (24260888417896*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) + 
       (53979817433357*CF^2*NC*Pi*Log[3]^2)/(3826375200*Sqrt[3]) + 
       (3032611052237*CF*NC*NH*Pi*Log[3]^2)/(15943230*Sqrt[3]) + 
       (CF*NC*(-55*CA*(-10101723517 + 28968619680*lm) + 
          8*(143*CF*(8234641601 + 9115999200*lm) + 
            135*(33*(-517659437 + 8128120*lm)*NM + 7*(242*(214943 + 
                  158340*lm)*NL + 15*(187855 + 2554552*lm)*NH))))*Log[x]^2)/
        12474000 + (2*CF*NC*(64169015*CA + 190035406*CF - 183195000*NM - 
          5225220*NL)*Log[x]^3)/675 + (7732569818855939*CF^2*NC*
         PolyGamma[2, 1])/421857865800 - (919159277*CF*NM*NC*
         PolyGamma[2, 1])/9450 + (36942613175033971*CF*NC*NH*
         PolyGamma[2, 1])/406791513450 - 
       (CA*CF*NC*(15784543212960004560000*lm^2 - 19976845735532947037175*
           Pi^2 + 1782076197790489658750*Sqrt[3]*Pi^3 + 270908630121017889000*
           Pi^4 - 5413842611100*lm*(-11915244401 + 11642400*Pi^2) + 
          1374744495438377736750*Sqrt[3]*Pi*Log[3]^2 - 
          22*(392010445319612445309 + 2690184772398672825850*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2019754468677327480000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 2999442535501915062000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 243575949293962078500*
             PolyGamma[2, 1] - 6390150197663115954000*Zeta[3])))/
        584695001998800000 + (85762770279947321*CF^2*NC*Zeta[3])/
        210928932900 - (322240577*CF*NM*NC*Zeta[3])/4725 + 
       (187852*CF*NC*NL*Zeta[3])/5 - (114516606578356109*CF*NC*NH*Zeta[3])/
        203395756725 + CF*Log[x]*((-121668603949*NM*NC)/147000 + 
         (8527096*lm*NM*NC)/225 + 7056*lm^2*NM*NC + (711975007*NC*NL)/
          7875 + (8527096*lm*NC*NL)/225 + 7056*lm^2*NC*NL + 
         (482198305076911421*NC*NH)/270078316200 + (8527096*lm*NC*NH)/225 + 
         7056*lm^2*NC*NH - (1973606*NM*NC*Pi^2)/15 + (93338*NC*NL*Pi^2)/
          15 - (24260888417896*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7971615*Sqrt[3]) + CA*NC*(-3566027318198219479/9374619240000 - 
           (58012228*lm)/225 - 38808*lm^2 + (5833919821*Pi^2)/226800 + 
           (53979817433357*Im[PolyLog[2, (-1)^(1/3)]])/(478296900*Sqrt[3]) - 
           21168*Zeta[3]) + CF*NC*(6679346154223908521/9374619240000 + 
           (26434984*lm)/25 + 254016*lm^2 - (7015764379*Pi^2)/113400 - 
           (53979817433357*Im[PolyLog[2, (-1)^(1/3)]])/(239148450*Sqrt[3]) + 
           42336*Zeta[3])), (138330793120598590867301*CF^2*NC)/
        1275698186179200000 - (19051858187*CF^2*lm*NC)/47250 - 
       (1312776*CF^2*lm^2*NC)/5 - (21668882375317099*CF*NM*NC)/
        270050760000 - (34042119137*CF*lm*NM*NC)/1701000 - 
       (36466*CF*lm^2*NM*NC)/5 + (31634646461*CF*NC*NL)/6378750 - 
       (34042119137*CF*lm*NC*NL)/1701000 - (36466*CF*lm^2*NC*NL)/5 + 
       (10661933425773500089945283*CF*NC*NH)/4244885714511288000 - 
       (34042119137*CF*lm*NC*NH)/1701000 - (36466*CF*lm^2*NC*NH)/5 + 
       (2106186300297587*CF^2*NC*Pi^2)/15324309000 + (4144*CF^2*lm*NC*Pi^2)/
        5 + (1571652167*CF*NM*NC*Pi^2)/12150 + (1036*CF*lm*NM*NC*Pi^2)/45 - 
       (83826523*CF*NC*NL*Pi^2)/12150 + (1036*CF*lm*NC*NL*Pi^2)/45 + 
       (1036*CF*lm*NC*NH*Pi^2)/45 - (6408073269196609*CF^2*NC*Pi^3)/
        (185961834720*Sqrt[3]) - (413858144816102*CF*NC*NH*Pi^3)/
        (1162261467*Sqrt[3]) - (20853559*CF^2*NC*Pi^4)/16200 + 
       (16454306228558876423*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (16271660538000*Sqrt[3]) + (7497019060901318*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(8135830269*Sqrt[3]) - 
       (3560362*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (6408073269196609*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5022117450*Sqrt[3]) - (945961473865376*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(71744535*Sqrt[3]) - 
       (6408073269196609*CF^2*NC*Pi*Log[3]^2)/(241061637600*Sqrt[3]) - 
       (59122592116586*CF*NC*NH*Pi*Log[3]^2)/(215233605*Sqrt[3]) - 
       (CF*NC*(CA*(8270781757601 - 7728069333600*lm) + 
          8*(44*CF*(87903606731 + 143703768600*lm) + 
            5*(11*(-120349782473 + 3193417080*lm)*NM + 1386*(34351781 + 
                25344580*lm)*NL + 5*(569597449 + 7025517576*lm)*NH)))*
         Log[x]^2)/37422000 - (4*CF*NC*(177872611*CA + 426503513*CF - 
          353307900*NM - 12672290*NL)*Log[x]^3)/2025 - 
       (290234301626549771*CF^2*NC*PolyGamma[2, 1])/51255730694700 + 
       (18549559759*CF*NM*NC*PolyGamma[2, 1])/132300 - 
       (1051448002155942029*CF*NC*NH*PolyGamma[2, 1])/10251146138940 + 
       (CA*CF*NC*(25329927676151230070400*lm^2 - 41133335697133361286255*
           Pi^2 + 3626649066701820863550*Sqrt[3]*Pi^3 + 418062675929994988200*
           Pi^4 - 185617460952*lm*(-548143575307 + 430768800*Pi^2) + 
          2797700708598547523310*Sqrt[3]*Pi*Log[3]^2 - 
          11*(3564158449918508033841 + 9675132062392619336724*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 6812921018312023305600*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 12208148546611843738080*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 162531208910867871760*
             PolyGamma[2, 1] - 21940694932513209646640*Zeta[3])))/
        631470602158704000 - (1685369056168658411*CF^2*NC*Zeta[3])/
        2562786534735 + (11369158559*CF*NM*NC*Zeta[3])/66150 - 
       (8099972*CF*NC*NL*Zeta[3])/135 + (4845777587087043619*CF*NC*NH*
         Zeta[3])/5125573069470 + CF*Log[x]*((3532193474441*NM*NC)/
          13395375 - (823910279*lm*NM*NC)/14175 - 11088*lm^2*NM*NC - 
         (39794054831*NC*NL)/283500 - (823910279*lm*NC*NL)/14175 - 
         11088*lm^2*NC*NL - (32914166315004015247*NC*NH)/12761200440450 - 
         (823910279*lm*NC*NH)/14175 - 11088*lm^2*NC*NH + 
         (22728592*NM*NC*Pi^2)/135 - (4031338*NC*NL*Pi^2)/405 + 
         (945961473865376*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (215233605*Sqrt[3]) + CF*NC*(-76844402430509862439/84371573160000 - 
           (2535974516*lm)/1575 - 399168*lm^2 + (1148807029*Pi^2)/9720 + 
           (6408073269196609*Im[PolyLog[2, (-1)^(1/3)]])/(15066352350*
             Sqrt[3]) - 66528*Zeta[3]) + CA*NC*(42894890722883078567/
            84371573160000 + (11263426669*lm)/28350 + 60984*lm^2 - 
           (7050914953*Pi^2)/136080 - (6408073269196609*
             Im[PolyLog[2, (-1)^(1/3)]])/(30132704700*Sqrt[3]) + 
           33264*Zeta[3])), (133209323025049991967743*CF^2*NC)/
        765418911707520000 + (491014031*CF^2*lm*NC)/540 + 
       (2830296*CF^2*lm^2*NC)/5 + (19964582008229653*CF*NM*NC)/18003384000 + 
       (860367659*CF*lm*NM*NC)/19440 + (235858*CF*lm^2*NM*NC)/15 - 
       (8580876707*CF*NC*NL)/378000 + (860367659*CF*lm*NC*NL)/19440 + 
       (235858*CF*lm^2*NC*NL)/15 - (5135114398523516501054678317*CF*NC*NH)/
        799372621266968548800 + (860367659*CF*lm*NC*NH)/19440 + 
       (235858*CF*lm^2*NC*NH)/15 - (2531005746193427*CF^2*NC*Pi^2)/
        2918916000 - 1960*CF^2*lm*NC*Pi^2 - (17379030647*CF*NM*NC*Pi^2)/
        8505 - (490*CF*lm*NM*NC*Pi^2)/9 + (6637883*CF*NC*NL*Pi^2)/405 - 
       (490*CF*lm*NC*NL*Pi^2)/9 - (490*CF*lm*NC*NH*Pi^2)/9 + 
       (44828801682372001*CF^2*NC*Pi^3)/(557885504160*Sqrt[3]) + 
       (6742120077553315*CF*NC*NH*Pi^3)/(6973568802*Sqrt[3]) + 
       (6299041*CF^2*NC*Pi^4)/1800 - (106073536333098251957*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(48814981614000*Sqrt[3]) - 
       (438375934867307818*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (122037454035*Sqrt[3]) + (2691122*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 + (6404114526053143*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2152336050*Sqrt[3]) + 
       (1541056017726472*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) + (6404114526053143*CF^2*NC*Pi*Log[3]^2)/
        (103312130400*Sqrt[3]) + (192632002215809*CF*NC*NH*Pi*Log[3]^2)/
        (258280326*Sqrt[3]) + 
       (CF*NC*(-429*CA*(-1342342245267 + 210984004000*lm) + 
          8*(41184*CF*(-1667803427 + 1798159125*lm) + 
            25*(143*(-136853646619 + 575410920*lm)*NM + 2002*(55219669 + 
                41100780*lm)*NL + 7*(1103359973 + 11754823080*lm)*NH)))*
         Log[x]^2)/162162000 + (CF*NC*(3411850581*CA + 
          4*(677461639*CF - 50*(71532168*NM + 685013*NL)))*Log[x]^3)/2025 - 
       (81372964216352595893*CF^2*NC*PolyGamma[2, 1])/307534384168200 - 
       (7979146327*CF*NM*NC*PolyGamma[2, 1])/5670 + 
       (3807900600074496293*CF*NC*NH*PolyGamma[2, 1])/10983370863150 - 
       (CA*CF*NC*(21298047239604507948576000*lm^2 - 
          104375149941900107312838810*Pi^2 + 3298211840577996415573500*
           Sqrt[3]*Pi^3 + 441639662068675393923600*Pi^4 - 
          6334195854987000*lm*(-13743451801 + 11642400*Pi^2) + 
          2544334848445882949156700*Sqrt[3]*Pi*Log[3]^2 - 
          143*(-102484205699507686086723 + 623712393638617721507160*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 463463026315237043424000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 854042466611205465451200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 227844299805787268500400*
             PolyGamma[2, 1] - 1740373496159364170350400*Zeta[3])))/
        246273534841894560000 + (53489760643569442637*CF^2*NC*Zeta[3])/
        30753438416820 + (90144413*CF*NM*NC*Zeta[3])/2835 + 
       (4154780*CF*NC*NL*Zeta[3])/27 - (12232878092219714107*CF*NC*NH*
         Zeta[3])/5491685431575 + CF*Log[x]*((-28297952515789*NM*NC)/
          1786050 + (3826093*lm*NM*NC)/27 + 25872*lm^2*NM*NC + 
         (2711606911*NC*NL)/7560 + (3826093*lm*NC*NL)/27 + 
         25872*lm^2*NC*NL + (6475295030679501849541*NC*NH)/
          924275517615450 + (3826093*lm*NC*NH)/27 + 25872*lm^2*NC*NH - 
         (15794234*NM*NC*Pi^2)/9 + (2068570*NC*NL*Pi^2)/81 - 
         (1541056017726472*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (129140163*Sqrt[3]) + CA*NC*(10555190302690007587/10124588779200 - 
           (51866639*lm)/54 - 142296*lm^2 + (73011227269*Pi^2)/226800 + 
           (6404114526053143*Im[PolyLog[2, (-1)^(1/3)]])/(12914016300*
             Sqrt[3]) - 77616*Zeta[3]) + CF*NC*(-577293555963223855697/
            253114719480000 + (11928076*lm)/3 + 931392*lm^2 - 
           (3106513483*Pi^2)/4536 - (6404114526053143*
             Im[PolyLog[2, (-1)^(1/3)]])/(6457008150*Sqrt[3]) + 
           155232*Zeta[3])), (174573643608273371232189557*CF^2*NC)/
        1247996400066318672000 - (169278640894*CF^2*lm*NC)/138915 - 
       (27686016*CF^2*lm^2*NC)/35 - (574837081058610452807*CF*NM*NC)/
        188704719819000 - (151028656439*CF*lm*NM*NC)/2500470 - 
       (769056*CF*lm^2*NM*NC)/35 + (63532599252611*CF*NC*NL)/1312746750 - 
       (151028656439*CF*lm*NC*NL)/2500470 - (769056*CF*lm^2*NC*NL)/35 + 
       (661780011516175729209252637*CF*NC*NH)/71372555470265049000 - 
       (151028656439*CF*lm*NC*NH)/2500470 - (769056*CF*lm^2*NC*NH)/35 + 
       (383115818916275699*CF^2*NC*Pi^2)/214540326000 + 
       (46400*CF^2*lm*NC*Pi^2)/21 + (258858523496*CF*NM*NC*Pi^2)/178605 + 
       (11600*CF*lm*NM*NC*Pi^2)/189 - (464360936*CF*NC*NL*Pi^2)/19845 + 
       (11600*CF*lm*NC*NL*Pi^2)/189 + (11600*CF*lm*NC*NH*Pi^2)/189 - 
       (33349680441044029*CF^2*NC*Pi^3)/(244074908070*Sqrt[3]) - 
       (4596645918468680*CF*NC*NH*Pi^3)/(3486784401*Sqrt[3]) - 
       (67763602*CF^2*NC*Pi^4)/14175 + (2026480527655557125009*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(597983524771500*Sqrt[3]) + 
       (2985098688621576112*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (854262178245*Sqrt[3]) - (82458464*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/105 - (266797443528352232*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(52732233225*Sqrt[3]) - 
       (14709266939099776*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (301327047*Sqrt[3]) - (33349680441044029*CF^2*NC*Pi*Log[3]^2)/
        (316393399350*Sqrt[3]) - (919329183693736*CF*NC*NH*Pi*Log[3]^2)/
        (903981141*Sqrt[3]) - 
       (CF*NC*(-819*CA*(-182316175139821 + 18309951352000*lm) + 
          8*(117*CF*(-219618914492827 + 104866085016000*lm) + 
            350*(13*(-8251851745369 + 74904346440*lm)*NM + 2574*(507819023 + 
                378304780*lm)*NL + 7*(14110656751 + 139108071960*lm)*NH)))*
         Log[x]^2)/17878360500 - (2*CF*NC*(486782882362*CA + 90191765717*CF - 
          5600*(174108774*NM + 2702177*NL))*Log[x]^3)/297675 + 
       (19471861278459789949*CF^2*NC*PolyGamma[2, 1])/25627865347350 + 
       (970122326209*CF*NM*NC*PolyGamma[2, 1])/595350 - 
       (32638837741927166*CF*NC*NH*PolyGamma[2, 1])/87169610025 - 
       (34121018450182576949*CF^2*NC*Zeta[3])/12813932673675 + 
       (307550637409*CF*NM*NC*Zeta[3])/297675 - 
       (129997408*CF*NC*NL*Zeta[3])/567 + (2130157936110442076*CF*NC*NH*
         Zeta[3])/610187270175 + (CA*CF*NC*(-43702355597341140836284641 + 
          46170132568265731044096000*lm^2 - 336325065362532132212844540*
           Pi^2 + 8700131234737802109404000*Sqrt[3]*Pi^3 + 
          931928974629296055350400*Pi^4 - 76393580868000*lm*
           (-2430515803357 + 1688148000*Pi^2) - 215779646584763722670958320*
           Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 150011466803204279632128000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 322153430863434043822502400*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6711529809654875912968800*
           Sqrt[3]*Pi*Log[3]^2 - 145135465225127890363866400*
           PolyGamma[2, 1] + 581132309802034844736097600*Zeta[3]))/
        382039714306015920000 + CF*Log[x]*((28621066206508456*NM*NC)/
          6807529575 - (1344475912*lm*NM*NC)/6615 - 38016*lm^2*NM*NC - 
         (217248815216*NC*NL)/416745 - (1344475912*lm*NC*NL)/6615 - 
         38016*lm^2*NC*NL - (883240777400235276226*NC*NH)/92427551761545 - 
         (1344475912*lm*NC*NH)/6615 - 38016*lm^2*NC*NH + 
         (920235536*NM*NC*Pi^2)/567 - (64789904*NC*NL*Pi^2)/1701 + 
         (14709266939099776*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (903981141*Sqrt[3]) + CF*NC*(3233908658781153495132149/
            375179292949230000 - (4162437088*lm)/735 - 1368576*lm^2 + 
           (18316744321*Pi^2)/13230 + (266797443528352232*
             Im[PolyLog[2, (-1)^(1/3)]])/(158196699675*Sqrt[3]) - 
           228096*Zeta[3]) + CA*NC*(-11033669308065597094529/
            2679852092494500 + (9154948396*lm)/6615 + 209088*lm^2 - 
           (132021860557*Pi^2)/198450 - (133398721764176116*
             Im[PolyLog[2, (-1)^(1/3)]])/(158196699675*Sqrt[3]) + 
           114048*Zeta[3])), (305559839058298503133602555563*CF^2*NC)/
        32091336001705337280000 + (13442554039*CF^2*lm*NC)/5292 + 
       (7905216*CF^2*lm^2*NC)/5 + (592253117346540001001*CF*NM*NC)/
        23962504104000 + (117762673907*CF*lm*NM*NC)/952560 + 
       (658768*CF*lm^2*NM*NC)/15 - (23311656937669*CF*NC*NL)/166698000 + 
       (117762673907*CF*lm*NC*NL)/952560 + (658768*CF*lm^2*NC*NL)/15 - 
       (5472796413873373098592311890249*CF*NC*NH)/251802375699095092872000 + 
       (117762673907*CF*lm*NC*NH)/952560 + (658768*CF*lm^2*NC*NH)/15 - 
       (835093173367114693*CF^2*NC*Pi^2)/71513442000 - 4840*CF^2*lm*NC*Pi^2 - 
       (257134071428*CF*NM*NC*Pi^2)/8505 - (1210*CF*lm*NM*NC*Pi^2)/9 + 
       (144902362*CF*NC*NL*Pi^2)/2835 - (1210*CF*lm*NC*NL*Pi^2)/9 - 
       (1210*CF*lm*NC*NH*Pi^2)/9 + (5133600463725056063*CF^2*NC*Pi^3)/
        (17573393381040*Sqrt[3]) + (204066173139204985*CF*NC*NH*Pi^3)/
        (62762119218*Sqrt[3]) + (72715907*CF^2*NC*Pi^4)/6300 - 
       (72840822650634646841857*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (10763703445887000*Sqrt[3]) - (2632909372963433870*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(219667417263*Sqrt[3]) + 
       (57619628*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
       (5133600463725056063*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (474590099025*Sqrt[3]) + (46643696717532568*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) + 
       (5133600463725056063*CF^2*NC*Pi*Log[3]^2)/(22780324753200*Sqrt[3]) + 
       (5830462089691571*CF*NC*NH*Pi*Log[3]^2)/(2324522934*Sqrt[3]) + 
       (CF*NC*(CA*(9113622667090474 - 289443288634500*lm) + 
          13*CF*(-1253059030596169 + 145733683788000*lm) + 
          175*(13*(-22537654590263 + 23132330760*lm)*NM + 
            1430*(280647461 + 210293916*lm)*NL + 
            (33980656169 + 300720299880*lm)*NH))*Log[x]^2)/141891750 - 
       (CF*NC*(-270687684929*CA + 4*(66703728689*CF + 
            350*(963172932*NM + 2503499*NL)))*Log[x]^3)/14175 - 
       (114129427827973713739*CF^2*NC*PolyGamma[2, 1])/19770067553670 - 
       (541140038393*CF*NM*NC*PolyGamma[2, 1])/28350 + 
       (112738244231534592851*CF*NC*NH*PolyGamma[2, 1])/98850337768350 + 
       (3180824709078320629036*CF^2*NC*Zeta[3])/345976182189225 + 
       (95487315907*CF*NM*NC*Zeta[3])/14175 + (14448404*CF*NC*NL*Zeta[3])/
        27 - (369556771354656506749*CF*NC*NH*Zeta[3])/49425168884175 - 
       (CA*CF*NC*(334365020201477632511541436839 + 
          17441114819016422844148608000*lm^2 - 419348587242093909516040111110*
           Pi^2 + 3515487030758686529414368500*Sqrt[3]*Pi^3 + 
          424471568349155039310351600*Pi^4 - 22929963011422582500*lm*
           (-3109208357 + 2328480*Pi^2) - 81438953356315560555069800280*
           Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 59435062792755071775689952000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 130173462624664506917743473600*
           Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          2711947138013843894119655700*Sqrt[3]*Pi*Log[3]^2 - 
          208415400298353293817627548000*PolyGamma[2, 1] + 
          365329496469169736688466805600*Zeta[3]))/72205506003837008880000 + 
       CF*Log[x]*((-54552005990439829*NM*NC)/216112050 + 
         (427628311*lm*NM*NC)/945 + 81312*lm^2*NM*NC + 
         (38524641677*NC*NL)/31752 + (427628311*lm*NC*NL)/945 + 
         81312*lm^2*NC*NL + (686363964055917878368481*NC*NH)/
          29114678804886675 + (427628311*lm*NC*NH)/945 + 81312*lm^2*NC*NH - 
         23761222*NM*NC*Pi^2 + (7202422*NC*NL*Pi^2)/81 - 
         (46643696717532568*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CA*NC*(54705938353846631239899727/
            1350645454617228000 - (5779669181*lm)/1890 - 447216*lm^2 + 
           (3493340255983*Pi^2)/793800 + (5133600463725056063*
             Im[PolyLog[2, (-1)^(1/3)]])/(2847540594150*Sqrt[3]) - 
           243936*Zeta[3]) + CF*NC*(-551659838286742623250121467/
            6753227273086140000 + (1339120684*lm)/105 + 2927232*lm^2 - 
           (101378466641*Pi^2)/11340 - (5133600463725056063*
             Im[PolyLog[2, (-1)^(1/3)]])/(1423770297075*Sqrt[3]) + 
           487872*Zeta[3])), (-105876468538029555305392910159009521*CF^2*NC)/
        11844783752885433168698880000 - (4812901615241*CF^2*lm*NC)/1481760 - 
       (73645506*CF^2*lm^2*NC)/35 - (787833078445667430085445849*CF*NM*NC)/
        17688928829539968000 - (8580311120177*CF*lm*NM*NC)/53343360 - 
       (4091417*CF*lm^2*NM*NC)/70 + (5280199873094479*CF*NC*NL)/
        22404211200 - (8580311120177*CF*lm*NC*NL)/53343360 - 
       (4091417*CF*lm^2*NC*NL)/70 + (359560656601879748128159475546639*CF*NC*
         NH)/12086514033556564457856000 - (8580311120177*CF*lm*NC*NH)/
        53343360 - (4091417*CF*lm^2*NC*NH)/70 + 
       (92157420651824504029*CF^2*NC*Pi^2)/3432645216000 + 
       (36905*CF^2*lm*NC*Pi^2)/7 + (12390817990211*CF*NM*NC*Pi^2)/952560 + 
       (36905*CF*lm*NM*NC*Pi^2)/252 - (6590799809*CF*NC*NL*Pi^2)/95256 + 
       (36905*CF*lm*NC*NL*Pi^2)/252 + (36905*CF*lm*NC*NH*Pi^2)/252 - 
       (96976454644180913951*CF^2*NC*Pi^3)/(210880720572480*Sqrt[3]) - 
       (1593033089611587935*CF*NC*NH*Pi^3)/(376572715308*Sqrt[3]) - 
       (3423220097*CF^2*NC*Pi^4)/226800 + (2586976572108806431365353*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(258328882701288000*Sqrt[3]) + 
       (1061555292240557548363*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (92260315250460*Sqrt[3]) - (238936819*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - 
       (96976454644180913951*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5695081188300*Sqrt[3]) - (1274426471689270348*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(8135830269*Sqrt[3]) - 
       (96976454644180913951*CF^2*NC*Pi*Log[3]^2)/(273363897038400*Sqrt[3]) - 
       (318606617922317587*CF*NC*NH*Pi*Log[3]^2)/(97629963228*Sqrt[3]) - 
       (CF*NC*(CA*(43809448714578041219 - 827005827479832000*lm) + 
          2*(CF*(-41221146031003428071 + 2706564526297632000*lm) + 
            10500*((-2097956796413447 + 7160223614544*lm)*NM + 
              1716*(5565658369 + 4172624484*lm)*NL + 7*(123153544861 + 
                1022889087792*lm)*NH)))*Log[x]^2)/286053768000 + 
       (CF*NC*(-49293484366591*CA + 65659830625244*CF + 
          8400*(7862237397*NM + 49674101*NL))*Log[x]^3)/1190700 + 
       (116747098425825945910901*CF^2*NC*PolyGamma[2, 1])/8303428372541400 + 
       (1617611245561*CF*NM*NC*PolyGamma[2, 1])/99225 - 
       (9856100292785413678031*CF*NC*NH*PolyGamma[2, 1])/8303428372541400 - 
       (18695205795201834638861*CF^2*NC*Zeta[3])/1186204053220200 + 
       (861493954397*CF*NM*NC*Zeta[3])/99225 - (142491115*CF*NC*NL*Zeta[3])/
        189 + (46042389586714325532169*CF*NC*NH*Zeta[3])/4151714186270700 + 
       CA*CF*NC*(101489710154399363503204224686206747/
          23689567505770866337397760000 + (45005587*lm^2)/140 - 
         (103139554485651839*Pi^2)/7705152000 + (96976454644180913951*Pi^3)/
          (421761441144960*Sqrt[3]) + (3476363297*Pi^4)/453600 + 
         lm*(138033408310171/106686720 - (405955*Pi^2)/504) - 
         (2586976572108806431365353*Im[PolyLog[2, (-1)^(1/3)]])/
          (516657765402576000*Sqrt[3]) + 
         (238936819*Im[PolyLog[2, (-1)^(1/3)]]^2)/210 + 
         (96976454644180913951*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (11390162376600*Sqrt[3]) + (96976454644180913951*Pi*Log[3]^2)/
          (546727794076800*Sqrt[3]) - (116747098425825945910901*
           PolyGamma[2, 1])/16606856745082800 + 
         (140677485379178019709169*Zeta[3])/16606856745082800) + 
       CF*Log[x]*((633737113072432252811*NM*NC)/24543413294400 - 
         (97673223373*lm*NM*NC)/158760 - 113256*lm^2*NM*NC - 
         (7433503460921*NC*NL)/4445280 - (97673223373*lm*NC*NL)/158760 - 
         113256*lm^2*NC*NL - (171511025404368440514442757*NC*NH)/
          5590018330538241600 - (97673223373*lm*NC*NH)/158760 - 
         113256*lm^2*NC*NH + (2616618892*NM*NC*Pi^2)/189 - 
         (71079485*NC*NL*Pi^2)/567 + (1274426471689270348*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(24407490807*Sqrt[3]) + 
         CF*NC*(1555476608069649245015189034263/6847772454909345960000 - 
           (75946758613*lm)/4410 - 4077216*lm^2 + (3770767610003*Pi^2)/
            190512 + (96976454644180913951*Im[PolyLog[2, (-1)^(1/3)]])/
            (17085243564900*Sqrt[3]) - 679536*Zeta[3]) + 
         CA*NC*(-1237679550192778640032385059237/10956435927854953536000 + 
           (1326132772943*lm)/317520 + 622908*lm^2 - (93444402274691*Pi^2)/
            9525600 - (96976454644180913951*Im[PolyLog[2, (-1)^(1/3)]])/
            (34170487129800*Sqrt[3]) + 339768*Zeta[3])), 
      (314433514676798868772143652106858059*CF^2*NC)/
        1692111964697919024099840000 + (14986266209*CF^2*lm*NC)/2352 + 
       (19828116*CF^2*lm^2*NC)/5 + (19243456756231524350979713*CF*NM*NC)/
        46796108014656000 + (131282836717*CF*lm*NM*NC)/423360 + 
       (550781*CF*lm^2*NM*NC)/5 - (85474884768697*CF*NC*NL)/148176000 + 
       (131282836717*CF*lm*NC*NL)/423360 + (550781*CF*lm^2*NC*NL)/5 - 
       (386600203127272645970087381132540861*CF*NC*NH)/
        5938104344686340118144652800 + (131282836717*CF*lm*NC*NH)/423360 + 
       (550781*CF*lm^2*NC*NH)/5 - (1637689247778735839*CF^2*NC*Pi^2)/
        10216206000 - 10890*CF^2*lm*NC*Pi^2 - (236927888519*CF*NM*NC*Pi^2)/
        540 - (605*CF*lm*NM*NC*Pi^2)/2 + (1070429393*CF*NC*NL*Pi^2)/7560 - 
       (605*CF*lm*NC*NL*Pi^2)/2 - (605*CF*lm*NC*NH*Pi^2)/2 + 
       (6923576675525472317*CF^2*NC*Pi^3)/(7531454306160*Sqrt[3]) + 
       (1823172211510812365*CF*NC*NH*Pi^3)/(188286357654*Sqrt[3]) + 
       (90155263*CF^2*NC*Pi^4)/2700 - (87082272060250758354853*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4613015762523000*Sqrt[3]) - 
       (117404666218000101497*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3295011258945*Sqrt[3]) + (22436084*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + (6923576675525472317*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(203395756725*Sqrt[3]) + 
       (416725076916757112*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) + (6923576675525472317*CF^2*NC*Pi*Log[3]^2)/
        (9762996322800*Sqrt[3]) + (52090634614594639*CF*NC*NH*Pi*Log[3]^2)/
        (6973568802*Sqrt[3]) + CF*((-784857379551879631*CF*NC)/425675250 + 
         CA*(11248107430183243721/11918907000 - 6484962*lm)*NC + 
         42447024*CF*lm*NC - (189565562219435*NM*NC)/36036 + 
         1179084*lm*NM*NC + (98686585*NC*NL)/63 + 1179084*lm*NC*NL + 
         (7500312283*NC*NH)/48620 + 1179084*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-16471039487477*CA + 56*(507328564633*CF + 
            9450*(166737071*NM + 98257*NL)))*Log[x]^3)/66150 - 
       (196518120875503013089*CF^2*NC*PolyGamma[2, 1])/2278032475320 - 
       (1219864372429*CF*NM*NC*PolyGamma[2, 1])/4725 + 
       (494154253091422447903*CF*NC*NH*PolyGamma[2, 1])/148275506652525 + 
       CA*CF*NC*(-218959565615348248918689211459256083/
          2368956750577086633739776000 - (6058591*lm^2)/10 + 
         (1388042874018664349*Pi^2)/17336592000 - (6923576675525472317*Pi^3)/
          (15062908612320*Sqrt[3]) - (91462063*Pi^4)/5400 + 
         lm*(-419402281507/169344 + (6655*Pi^2)/4) + 
         (87082272060250758354853*Im[PolyLog[2, (-1)^(1/3)]])/
          (9226031525046000*Sqrt[3]) - (11218042*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/5 - (6923576675525472317*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(406791513450*Sqrt[3]) - 
         (6923576675525472317*Pi*Log[3]^2)/(19525992645600*Sqrt[3]) + 
         (196518120875503013089*PolyGamma[2, 1])/4556064950640 - 
         (474419078224041841447*Zeta[3])/11390162376600) + 
       (459000346541004941503*CF^2*NC*Zeta[3])/5695081188300 + 
       (670067871292*CF*NM*NC*Zeta[3])/4725 + 1635738*CF*NC*NL*Zeta[3] - 
       (3278117345353839008494*CF*NC*NH*Zeta[3])/148275506652525 + 
       CF*Log[x]*((-48538312012403156887*NM*NC)/12985932960 + 
         (1609427809*lm*NM*NC)/1260 + 226512*lm^2*NM*NC + 
         (782091895*NC*NL)/216 + (1609427809*lm*NC*NL)/1260 + 
         226512*lm^2*NC*NL + (56735079617701506088523035319*NC*NH)/
          807757648762775911200 + (1609427809*lm*NC*NH)/1260 + 
         226512*lm^2*NC*NH - 333463376*NM*NC*Pi^2 + 272018*NC*NL*Pi^2 - 
         (416725076916757112*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CA*NC*(123386863890742255980145770341/
            195650641568838456000 - (21699377579*lm)/2520 - 1245816*lm^2 + 
           (12113010457487*Pi^2)/198450 + (6923576675525472317*
             Im[PolyLog[2, (-1)^(1/3)]])/(1220374540350*Sqrt[3]) - 
           679536*Zeta[3]) + CF*NC*(-154490350110670952806532363113/
            122281650980524035000 + (1264563289*lm)/35 + 8154432*lm^2 - 
           (347256378097*Pi^2)/2835 - (6923576675525472317*
             Im[PolyLog[2, (-1)^(1/3)]])/(610187270175*Sqrt[3]) + 
           1359072*Zeta[3])), (-22950819252575300277543803757168642743*CF^2*
         NC)/106603053775968898518289920000 - (2178234677033*CF^2*lm*NC)/
        277830 - (177512016*CF^2*lm^2*NC)/35 - 
       (7012178762552066753187431*CF*NM*NC)/13648864837608000 - 
       (3880885556501*CF*lm*NM*NC)/10001880 - (14792668*CF*lm^2*NM*NC)/
        105 + (2190536601455473*CF*NC*NL)/2520473760 - 
       (3880885556501*CF*lm*NC*NL)/10001880 - (14792668*CF*lm^2*NC*NL)/
        105 + (219126478306911510294066007477562861*CF*NC*NH)/
        2569372072220051012658744000 - (3880885556501*CF*lm*NC*NH)/
        10001880 - (14792668*CF*lm^2*NC*NH)/105 + 
       (360372385579386435841*CF^2*NC*Pi^2)/858161304000 + 
       (242000*CF^2*lm*NC*Pi^2)/21 + (1570954275713*CF*NM*NC*Pi^2)/19845 + 
       (60500*CF*lm*NM*NC*Pi^2)/189 - (3641856284*CF*NC*NL*Pi^2)/19845 + 
       (60500*CF*lm*NC*NL*Pi^2)/189 + (60500*CF*lm*NC*NH*Pi^2)/189 - 
       (323175490086253551113*CF^2*NC*Pi^3)/(237240810644040*Sqrt[3]) - 
       (10265379338563650880*CF*NC*NH*Pi^3)/(847288609443*Sqrt[3]) - 
       (1192840429*CF^2*NC*Pi^4)/28350 + (7775429030622352353465779*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(290619993038949000*Sqrt[3]) + 
       (7019774680825841236172*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (207585709313535*Sqrt[3]) - (623115064*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - (646350980172507102226*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(12813932673675*Sqrt[3]) - 
       (32849213883403682816*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (73222472421*Sqrt[3]) - (323175490086253551113*CF^2*NC*Pi*Log[3]^2)/
        (307534384168200*Sqrt[3]) - (2053075867712730176*CF*NC*NH*Pi*
         Log[3]^2)/(219667417263*Sqrt[3]) - 
       (CF*NC*(-17*CA*(-89250057364131918733 + 313261958305296000*lm) + 
          28*(17*CF*(-6304462836583101643 + 73230068175264000*lm) + 
            300*(765*(-89263757382857 + 150679152624*lm)*NM + 
              13*(3366*(3498425503 + 2634250920*lm)*NL + 7*(174758678263 + 
                  1266698370960*lm)*NH))))*Log[x]^2)/607864257000 + 
       (2*CF*NC*(-91820383521607*CA + 18*(9433408732141*CF + 
            2800*(1139355336*NM + 3136013*NL)))*Log[x]^3)/297675 + 
       (8168624806141777981140947*CF^2*NC*PolyGamma[2, 1])/
        37365427676436300 + (28166553730457*CF*NM*NC*PolyGamma[2, 1])/
        198450 - (125625629937586676546333*CF*NC*NH*PolyGamma[2, 1])/
        37365427676436300 - (1735559058614250554859851*CF^2*NC*Zeta[3])/
        9341356919109075 + (10216487865257*CF*NM*NC*Zeta[3])/99225 - 
       (46216144*CF*NC*NL*Zeta[3])/21 + (585564487390031843676067*CF*NC*NH*
         Zeta[3])/18682713838218150 + CA*CF*NC*
        (5703873610283444709353480468753918777/
          53301526887984449259144960000 + (81359674*lm^2)/105 - 
         (8186299554189540179*Pi^2)/39007332000 + 
         (323175490086253551113*Pi^3)/(474481621288080*Sqrt[3]) + 
         (1207360429*Pi^4)/56700 + lm*(62417006483623/20003760 - 
           (332750*Pi^2)/189) - (7775429030622352353465779*
           Im[PolyLog[2, (-1)^(1/3)]])/(581239986077898000*Sqrt[3]) + 
         (311557532*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 + 
         (323175490086253551113*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (12813932673675*Sqrt[3]) + (323175490086253551113*Pi*Log[3]^2)/
          (615068768336400*Sqrt[3]) - (8168624806141777981140947*
           PolyGamma[2, 1])/74730855352872600 + 
         (3532910587665913956828139*Zeta[3])/37365427676436300) + 
       CF*Log[x]*((-5848917131725387133*NM*NC)/20452844412 - 
         (10996203922*lm*NM*NC)/6615 - 302016*lm^2*NM*NC - 
         (59724724010401*NC*NL)/12502350 - (10996203922*lm*NC*NL)/6615 - 
         302016*lm^2*NC*NL - (6144940954970398839826122283*NC*NH)/
          69902104219855607700 - (10996203922*lm*NC*NH)/6615 - 
         302016*lm^2*NC*NH + (6077058976*NM*NC*Pi^2)/63 - 
         (69203216*NC*NL*Pi^2)/189 + (32849213883403682816*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(219667417263*Sqrt[3]) + 
         CF*NC*(476291709718354608873862061012789/123259904188368227280000 - 
           (34328609128*lm)/735 - 10872576*lm^2 + (18194948922461*Pi^2)/
            59535 + (646350980172507102226*Im[PolyLog[2, (-1)^(1/3)]])/
            (38441798021025*Sqrt[3]) - 1812096*Zeta[3]) + 
         CA*NC*(-47586151116898556560234863406643/24651980837673645456000 + 
           (74463972451*lm)/6615 + 1661088*lm^2 - (12975306628973*Pi^2)/
            85050 - (323175490086253551113*Im[PolyLog[2, (-1)^(1/3)]])/
            (38441798021025*Sqrt[3]) + 906048*Zeta[3])), 
      (943078808873623531386983704247242913611*CF^2*NC)/
        319809161327906695554869760000 + (13957756087909*CF^2*lm*NC)/952560 + 
       (45598696*CF^2*lm^2*NC)/5 + (2713079371480624830152069899*CF*NM*NC)/
        421164972131904000 + (24454667104501*CF*lm*NM*NC)/34292160 + 
       (11399674*CF*lm^2*NM*NC)/45 - (8668143264345689*CF*NC*NL)/
        4500846000 + (24454667104501*CF*lm*NC*NL)/34292160 + 
       (11399674*CF*lm^2*NC*NL)/45 - 
       (138689486204255971376958929207993248234961*CF*NC*NH)/
        785496684218212418213973347136000 + (24454667104501*CF*lm*NC*NH)/
        34292160 + (11399674*CF*lm^2*NC*NH)/45 - 
       (125516628618671360836289*CF^2*NC*Pi^2)/58354968672000 - 
       (204490*CF^2*lm*NC*Pi^2)/9 - (641374196938847*CF*NM*NC*Pi^2)/102060 - 
       (102245*CF*lm*NM*NC*Pi^2)/162 + (72755420023*CF*NC*NL*Pi^2)/204120 - 
       (102245*CF*lm*NC*NL*Pi^2)/162 - (102245*CF*lm*NC*NH*Pi^2)/162 + 
       (14695320070009744910351*CF^2*NC*Pi^3)/(5693779455456960*Sqrt[3]) + 
       (66397076993166238340*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) + 
       (19733353211*CF^2*NC*Pi^4)/226800 - (335756387827376333947527353*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(6974879832934776000*Sqrt[3]) - 
       (8570266559552553863023*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (88965303991515*Sqrt[3]) + (3509551331*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/315 + (14695320070009744910351*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(153767192084100*Sqrt[3]) + 
       (30352949482590280384*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31381059609*Sqrt[3]) + (14695320070009744910351*CF^2*NC*Pi*Log[3]^2)/
        (7380825220036800*Sqrt[3]) + (1897059342661892524*CF*NC*NH*Pi*
         Log[3]^2)/(94143178827*Sqrt[3]) + 
       (CF*NC*(-6783*CA*(-175105819344451718917 + 251088496731072000*lm) + 
          10982*CF*(-215258325427350078079 + 1015095740795136000*lm) + 
          58800*(1615*(-73360564485026015 + 3260889567936*lm)*NM + 
            7205484*(967951879 + 730878960*lm)*NL + 
            163*(4762062059917 + 32308813817280*lm)*NH))*Log[x]^2)/
        92395367064000 - (CF*NC*(-5948267038342237*CA + 11513374514621978*
           CF + 57506400*(589264059*NM + 69394*NL))*Log[x]^3)/1786050 - 
       (528602354145718677857641459*CF^2*NC*PolyGamma[2, 1])/
        448385132117235600 - (49986272526944*CF*NM*NC*PolyGamma[2, 1])/
        14175 + (7079161899680006384531*CF*NC*NH*PolyGamma[2, 1])/
        800687735923635 + CA*CF*NC*((-62698207*lm^2)/45 + 
         (1911889993212279137*Pi^2)/1778112000 - 
         (14695320070009744910351*Pi^3)/(11387558910913920*Sqrt[3]) - 
         (6654127337*Pi^4)/151200 + lm*(-390620720962439/68584320 + 
           (1124695*Pi^2)/324) - (14695320070009744910351*Pi*Log[3]^2)/
          (14761650440073600*Sqrt[3]) + 
         (-605638555399324898463845970266920328799 + 
           3298919163387216322342022317602478560*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] - 
           2290585036335405450670214183142144000*Im[PolyLog[2, (-1)^(1/3)]]^
             2 - 6549369383867792331650462241086707200*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           242372456020032285802499032758408438400*PolyGamma[2, 1] - 
           203389541812491813796898344819337382400*Zeta[3])/
          411183207421594322856261120000) + (11008801407140484639747379*CF^2*
         NC*Zeta[3])/11209628302930890 + (34131747987362*CF*NM*NC*Zeta[3])/
        14175 + (40537718*CF*NC*NL*Zeta[3])/9 - 
       (47287685837752113777458*CF*NC*NH*Zeta[3])/800687735923635 + 
       CF*Log[x]*((-93428795246487147996833*NM*NC)/1753100949600 + 
         (111068965579*lm*NM*NC)/34020 + 572572*lm^2*NM*NC + 
         (139511163056651*NC*NL)/14288400 + (111068965579*lm*NC*NL)/34020 + 
         572572*lm^2*NC*NL + (298459446378979005543380262671777*NC*NH)/
          1574642760498155361293280 + (111068965579*lm*NC*NH)/34020 + 
         572572*lm^2*NC*NH - (14229951542*NM*NC*Pi^2)/3 + 
         (60704332*NC*NL*Pi^2)/81 - (30352949482590280384*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CA*NC*(2488074626741003898737213030848429/295823770052083745472000 - 
           (1494463213529*lm)/68040 - 3149146*lm^2 + (23693247643405169*Pi^2)/
            28576800 + (14695320070009744910351*Im[PolyLog[2, (-1)^(1/3)]])/
            (922603152504600*Sqrt[3]) - 1717716*Zeta[3]) + 
         CF*NC*(-12444704388458493094178097450227327/
            739559425130209363680000 + (87531962089*lm)/945 + 20612592*lm^2 - 
           (4741836625288909*Pi^2)/2857680 - (14695320070009744910351*
             Im[PolyLog[2, (-1)^(1/3)]])/(461301576252300*Sqrt[3]) + 
           3435432*Zeta[3])), (-1187772215294741605840411612793196136073*CF^2*
         NC)/282766873556492386578316800000 - (873185260161743*CF^2*lm*NC)/
        50009400 - (78985764*CF^2*lm^2*NC)/7 - 
       (371685960657120502559746475720387*CF*NM*NC)/
        72421422782941552320000 - (1555035791824043*CF*lm*NM*NC)/
        1800338400 - (2194049*CF*lm^2*NM*NC)/7 + 
       (3402184716357882461*CF*NC*NL)/1260236880000 - 
       (1555035791824043*CF*lm*NC*NL)/1800338400 - (2194049*CF*lm^2*NC*NL)/
        7 + (2042720262969878157405494023735556272672583*CF*NC*NH)/
        9164127982545811545829689049920000 - (1555035791824043*CF*lm*NC*NH)/
        1800338400 - (2194049*CF*lm^2*NC*NH)/7 + 
       (1144278993545911125020137*CF^2*NC*Pi^2)/175064906016000 + 
       (22166716*CF^2*lm*NC*Pi^2)/945 - (1089270716878997*CF*NM*NC*Pi^2)/
        5358150 + (5541679*CF*lm*NM*NC*Pi^2)/8505 - 
       (4774386062303*CF*NC*NL*Pi^2)/10716300 + (5541679*CF*lm*NC*NL*Pi^2)/
        8505 + (5541679*CF*lm*NC*NH*Pi^2)/8505 - 
       (109717259149285400437*CF^2*NC*Pi^3)/(30125817224640*Sqrt[3]) - 
       (107168617383958559479*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) - 
       (72275188271*CF^2*NC*Pi^4)/680400 + (161875902513392948432309*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2460275073345600*Sqrt[3]) + 
       (18788841021573662132552*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (207585709313535*Sqrt[3]) - (639091739*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - (109717259149285400437*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(813583026900*Sqrt[3]) - 
       (428674469535834237916*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(366112362105*Sqrt[3]) - 
       (109717259149285400437*CF^2*NC*Pi*Log[3]^2)/(39051985291200*Sqrt[3]) - 
       (107168617383958559479*CF*NC*NH*Pi*Log[3]^2)/(4393348345260*
         Sqrt[3]) - (CF*NC*(-19*CA*(-571214003909773774170037 + 
            349068920842254412800*lm) + 
          14*(133*CF*(-11634828954956790160283 + 23314436271467827200*lm) + 
            120*(19*(21331343174449841521 + 37778021736174720*lm)*NM + 
              21616452*(43962681353 + 33205375840*lm)*NL + 
              21*(5270981197343639 + 34180114904158080*lm)*NH)))*Log[x]^2)/
        277186101192000 + (CF*NC*(-8529585707893073*CA + 16809921995957991*
           CF + 858225640713840*NM + 2590019315520*NL)*Log[x]^3)/893025 + 
       (745283154005500568209185881*CF^2*NC*PolyGamma[2, 1])/
        224192566058617800 + (90906097838747*CF*NM*NC*PolyGamma[2, 1])/
        95256 - (1947038771168147131623563*CF*NC*NH*PolyGamma[2, 1])/
        224192566058617800 - (653872416800355396589951679*CF^2*NC*Zeta[3])/
        224192566058617800 + (348147942954367*CF*NM*NC*Zeta[3])/238140 - 
       (5509880636*CF*NC*NL*Zeta[3])/945 + (9037450569301679716602997*CF*NC*
         NH*Zeta[3])/112096283029308900 + 
       CA*CF*NC*(14537116538287576711005348598308015219209/
          6927788402134063471168761600000 + (24134539*lm^2)/14 - 
         (470666877474281060611*Pi^2)/144027072000 + 
         (109717259149285400437*Pi^3)/(60251634449280*Sqrt[3]) + 
         (72984523183*Pi^4)/1360800 + lm*(25005455042427673/3600676800 - 
           (60958469*Pi^2)/17010) - (161875902513392948432309*
           Im[PolyLog[2, (-1)^(1/3)]])/(4920550146691200*Sqrt[3]) + 
         (639091739*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 + 
         (109717259149285400437*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1627166053800*Sqrt[3]) + (109717259149285400437*Pi*Log[3]^2)/
          (78103970582400*Sqrt[3]) - (745283154005500568209185881*
           PolyGamma[2, 1])/448385132117235600 + 
         (26230935628338877175784185*Zeta[3])/17935405284689424) + 
       CF*Log[x]*((-343789687363393380287928773*NM*NC)/26598924157806000 - 
         (3658604371708*lm*NM*NC)/893025 - 736164*lm^2*NM*NC - 
         (6210708180965761*NC*NL)/500094000 - (3658604371708*lm*NC*NL)/
          893025 - 736164*lm^2*NC*NL - (13444574774148294626470454946773*NC*
           NH)/58580459839961136952875 - (3658604371708*lm*NC*NH)/893025 - 
         736164*lm^2*NC*NH + (681685257023*NM*NC*Pi^2)/2835 - 
         (8253737596*NC*NL*Pi^2)/8505 + (428674469535834237916*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1098337086315*Sqrt[3]) + 
         CF*NC*(475921878750312374913632370770284693/
            7916024957875203929760000 - (11456922015682*lm)/99225 - 
           26501904*lm^2 + (68123063424829523*Pi^2)/14288400 + 
           (109717259149285400437*Im[PolyLog[2, (-1)^(1/3)]])/
            (2440749080700*Sqrt[3]) - 4416984*Zeta[3]) + 
         CA*NC*(-475849745113058582872823412915744217/
            15832049915750407859520000 + (24724214037094*lm)/893025 + 
           4048902*lm^2 - (68104583811999947*Pi^2)/28576800 - 
           (109717259149285400437*Im[PolyLog[2, (-1)^(1/3)]])/
            (4881498161400*Sqrt[3]) + 2208492*Zeta[3])), 
      (10929488647971633286664319245256456124514057*CF^2*NC)/
        254639886310373055654555993600000 + (3048900305921*CF^2*lm*NC)/
        97200 + 19523504*CF^2*lm^2*NC + (1019468455529471045707983428503357*
         CF*NM*NC)/10345917540420221760000 + (5341935850721*CF*lm*NM*NC)/
        3499200 + (4880876*CF*lm^2*NM*NC)/9 - (40978311778559983*CF*NC*NL)/
        7348320000 + (5341935850721*CF*lm*NC*NL)/3499200 + 
       (4880876*CF*lm^2*NC*NL)/9 - 
       (327204912798494188149616751915803108111754371*CF*NC*NH)/
        742294366586210735212204813043520000 + (5341935850721*CF*lm*NC*NH)/
        3499200 + (4880876*CF*lm^2*NC*NH)/9 - 
       (11085882053222439187273*CF^2*NC*Pi^2)/396972576000 - 
       (2004002*CF^2*lm*NC*Pi^2)/45 - (45217180710677197*CF*NM*NC*Pi^2)/
        510300 - (1002001*CF*lm*NM*NC*Pi^2)/810 + 
       (120878228471*CF*NC*NL*Pi^2)/145800 - (1002001*CF*lm*NC*NL*Pi^2)/
        810 - (1002001*CF*lm*NC*NH*Pi^2)/810 + 
       (145036958952235406383313*CF^2*NC*Pi^3)/(21961720756762560*Sqrt[3]) + 
       (17819177406142878487673*CF*NC*NH*Pi^3)/(274521509459532*Sqrt[3]) + 
       (6744108371*CF^2*NC*Pi^4)/32400 - (437795175546877852787301809*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3843301132433448000*Sqrt[3]) - 
       (577814397642877224476533*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2402063207770905*Sqrt[3]) + (1152450299*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + (20719565564605058054759*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(84728860944300*Sqrt[3]) + 
       (10182387089224501992956*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4236443047215*Sqrt[3]) + 
       (20719565564605058054759*CF^2*NC*Pi*Log[3]^2)/(4066985325326400*
         Sqrt[3]) + (2545596772306125498239*CF*NC*NH*Pi*Log[3]^2)/
        (50837316566580*Sqrt[3]) + 
       (CF*NC*(-969*CA*(-2280630100763715431287 + 651023329790433600*lm) + 
          10*(323*CF*(-1367051373581258721347 + 1278373083952124160*lm) + 
            168*(19*(-439678171123097899303 + 3593310586505640*lm)*NM + 
              100876776*(894318967 + 676795035*lm)*NL + (11111039482163843 + 
                68272901143607160*lm)*NH)))*Log[x]^2)/13199338152000 - 
       (CF*NC*(-11142488583323089*CA + 22129898759742926*CF + 
          2520*(27168841854114*NM + 586555697*NL))*Log[x]^3)/255150 - 
       (37436391343807178343898914541*CF^2*NC*PolyGamma[2, 1])/
        2421279713433072240 - (1371261400860577*CF*NM*NC*PolyGamma[2, 1])/
        28350 + (4678807748149427352386839*CF*NC*NH*PolyGamma[2, 1])/
        216185688699381450 + CA*CF*NC*
        (-9561405475099699883538446478161984447762113/
          445619801043152847395472988800000 - (26844818*lm^2)/9 + 
         (36176354486155094363*Pi^2)/2590963200 - 
         (145036958952235406383313*Pi^3)/(43923441513525120*Sqrt[3]) - 
         (50431381*Pi^4)/480 + (121*lm*(-705197343811 + 393513120*Pi^2))/
          6998400 + (437795175546877852787301809*Im[PolyLog[2, (-1)^(1/3)]])/
          (7686602264866896000*Sqrt[3]) - 
         (1152450299*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
         (20719565564605058054759*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (169457721888600*Sqrt[3]) - (20719565564605058054759*Pi*Log[3]^2)/
          (8133970650652800*Sqrt[3]) + (37436391343807178343898914541*
           PolyGamma[2, 1])/4842559426866144480 - 
         (1934814977886044648022262093*Zeta[3])/302659964179134030) + 
       (38642694309764964291522349541*CF^2*NC*Zeta[3])/3026599641791340300 + 
       (529584590528243*CF*NM*NC*Zeta[3])/14175 + 
       (511945252*CF*NC*NL*Zeta[3])/45 - (15688547680208457731229641*CF*NC*
         NH*Zeta[3])/108092844349690725 + CF*Log[x]*
        ((-234370658056634814655123031*NM*NC)/316653859021500 + 
         (186873505247*lm*NM*NC)/24300 + (4008004*lm^2*NM*NC)/3 + 
         (494249108381591*NC*NL)/20412000 + (186873505247*lm*NC*NL)/24300 + 
         (4008004*lm^2*NC*NL)/3 + (125184859369947562950956719086446471*NC*
           NH)/265720965834063717218241000 + (186873505247*lm*NC*NH)/
          24300 + (4008004*lm^2*NC*NH)/3 - (3018786307417*NM*NC*Pi^2)/45 + 
         (766915877*NC*NL*Pi^2)/405 - (10182387089224501992956*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) + 
         CA*NC*(10236343715910166530141302412181104223/
            96987936038504599408320000 - (2510116211317*lm)/48600 - 
           (22044022*lm^2)/3 + (8906512040581681*Pi^2)/816480 + 
           (20719565564605058054759*Im[PolyLog[2, (-1)^(1/3)]])/
            (508373165665800*Sqrt[3]) - 4008004*Zeta[3]) + 
         CF*NC*(-10237072062825810340785179417662583101/
            48493968019252299704160000 + (147645166097*lm)/675 + 
           48096048*lm^2 - (44538222307479773*Pi^2)/2041200 - 
           (20719565564605058054759*Im[PolyLog[2, (-1)^(1/3)]])/
            (254186582832900*Sqrt[3]) + 8016008*Zeta[3])), 
      (-2520119576472705016216720078548203733958582965151*CF^2*NC)/
        32817224628021948293592212787187200000 - (53475389532889*CF^2*lm*NC)/
        1470150 - 23489232*CF^2*lm^2*NC - 
       (34094906690033389551011830134744203*CF*NM*NC)/
        806393731928889784680000 - (95202395296189*CF*lm*NM*NC)/52925400 - 
       (1957436*CF*lm^2*NM*NC)/3 + (320512676989950607*CF*NC*NL)/
        43222410000 - (95202395296189*CF*lm*NC*NL)/52925400 - 
       (1957436*CF*lm^2*NC*NL)/3 + 
       (13645874273337960854936491600381290381745573*CF*NC*NH)/
        25305489769984456882234254990120000 - (95202395296189*CF*lm*NC*NH)/
        52925400 - (1957436*CF*lm^2*NC*NH)/3 + 
       (571308367339192312323127*CF^2*NC*Pi^2)/5731291566000 + 
       (2025296*CF^2*lm*NC*Pi^2)/45 - (3746212502000993*CF*NM*NC*Pi^2)/
        200475 + (506324*CF*lm*NM*NC*Pi^2)/405 - 
       (201471186566*CF*NC*NL*Pi^2)/200475 + (506324*CF*lm*NC*NL*Pi^2)/
        405 + (506324*CF*lm*NC*NH*Pi^2)/405 - 
       (1621487173522163174074201*CF^2*NC*Pi^3)/(181184196243291120*
         Sqrt[3]) - (15726222163170507335858*CF*NC*NH*Pi^3)/
        (205891132094649*Sqrt[3]) - (2003185379*CF^2*NC*Pi^4)/8100 + 
       (10529900357276297032902466729*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (69755915553667081200*Sqrt[3]) + (1614143982197438722601404*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7206189623312715*Sqrt[3]) - 
       (474640868*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (1621487173522163174074201*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4893091719533325*Sqrt[3]) - 
       (35945650658675445339104*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(12709329141645*Sqrt[3]) - 
       (1621487173522163174074201*CF^2*NC*Pi*Log[3]^2)/(234868402537599600*
         Sqrt[3]) - (2246603166167215333694*CF*NC*NH*Pi*Log[3]^2)/
        (38127987424935*Sqrt[3]) - 
       (CF*NC*(-57*CA*(-380772169278574597326643 + 38193497453397686400*lm) + 
          10*(19*CF*(-228390204535008856794059 + 74998140453944547840*lm) + 
            3696*(7*(31466537898788626219 + 1529930113877880*lm)*NM + 
              3*(1200914*(3926795801 + 2972599980*lm)*NL + 
                3*(201391767509197 + 1189945644127240*lm)*NH))))*Log[x]^2)/
        36298179918000 + (2*CF*NC*(-34281527760517524*CA + 
          68384643242981153*CF - 9019576613789280*NM + 1700327188560*NL)*
         Log[x]^3)/467775 + (455308597832530806075454056017*CF^2*NC*
         PolyGamma[2, 1])/9079798925374020900 + 
       (190614290603563*CF*NM*NC*PolyGamma[2, 1])/132300 - 
       (18862348309121588809412921*CF*NC*NH*PolyGamma[2, 1])/
        907979892537402090 - (2312744070568783764429950896811*CF^2*NC*
         Zeta[3])/49938894089557114950 + (490616913629561*CF*NM*NC*Zeta[3])/
        22050 - (213766592*CF*NC*NL*Zeta[3])/15 + 
       (87107248377694377489222247*CF*NC*NH*Zeta[3])/453989946268701045 + 
       CA*CF*NC*(866177170369486785904050031200121394868424359949/
          22561841931765089451844646291191200000 + (10765898*lm^2)/3 - 
         (2790240889265081890901*Pi^2)/55983312000 + 
         (1621487173522163174074201*Pi^3)/(362368392486582240*Sqrt[3]) + 
         (673129249*Pi^4)/5400 + lm*(139153097291389/9622800 - 
           (2784782*Pi^2)/405) - (10529900357276297032902466729*
           Im[PolyLog[2, (-1)^(1/3)]])/(139511831107334162400*Sqrt[3]) + 
         (237320434*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (1621487173522163174074201*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9786183439066650*Sqrt[3]) + (1621487173522163174074201*Pi*
           Log[3]^2)/(469736805075199200*Sqrt[3]) - 
         (455308597832530806075454056017*PolyGamma[2, 1])/
          18159597850748041800 + (1156876141300315896068990641819*Zeta[3])/
          49938894089557114950) + CF*Log[x]*
        ((-16423363772144550725611257401*NM*NC)/57156021553380750 - 
         (4377082325278*lm*NM*NC)/467775 - 1665664*lm^2*NM*NC - 
         (93100057740689*NC*NL)/3118500 - (4377082325278*lm*NC*NL)/467775 - 
         1665664*lm^2*NC*NL - (55253502191622342011370616952213218*NC*NH)/
          99645362187773893956840375 - (4377082325278*lm*NC*NH)/467775 - 
         1665664*lm^2*NC*NH - (3904226828936*NM*NC*Pi^2)/405 - 
         (960937016*NC*NL*Pi^2)/405 + (35945650658675445339104*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(38127987424935*Sqrt[3]) + 
         CF*NC*(9291770953344751165362463255407091190069/
            10337944102344205250932828800 - (13742408742712*lm)/51975 - 
           59963904*lm^2 + (137088111927088349*Pi^2)/1871100 + 
           (1621487173522163174074201*Im[PolyLog[2, (-1)^(1/3)]])/
            (14679275158599975*Sqrt[3]) - 9993984*Zeta[3]) + 
         CA*NC*(-14518035478285731341375433785627404974191/
            32306075319825641409165090000 + (2684367693839*lm)/42525 + 
           9161152*lm^2 - (45694090590498733*Pi^2)/1247400 - 
           (1621487173522163174074201*Im[PolyLog[2, (-1)^(1/3)]])/
            (29358550317199950*Sqrt[3]) + 4996992*Zeta[3])), 
      (192892281067227366809378000123040814482649193235259*CF^2*NC)/
        326609521297932723493370117739148800000 + (3305067327785*CF^2*lm*NC)/
        52272 + (196786044*CF^2*lm^2*NC)/5 + 
       (18573250681349542377987152105477897*CF*NM*NC)/
        12615581939509742409216 + (28954736750053*CF*lm*NM*NC)/9408960 + 
       (5466279*CF*lm^2*NM*NC)/5 - (286838416652282881*CF*NC*NL)/
        19758816000 + (28954736750053*CF*lm*NC*NL)/9408960 + 
       (5466279*CF*lm^2*NC*NL)/5 - 
       (5560408964945521959573767471818993713340210328689*CF*NC*NH)/
        5418897334952655609196137576180304704000 + 
       (28954736750053*CF*lm*NC*NH)/9408960 + (5466279*CF*lm^2*NC*NH)/5 - 
       (581447187744266790357923*CF^2*NC*Pi^2)/1659345367680 - 
       82810*CF^2*lm*NC*Pi^2 - (30611084113412779*CF*NM*NC*Pi^2)/24948 - 
       (41405*CF*lm*NM*NC*Pi^2)/18 + (64310856701*CF*NC*NL*Pi^2)/35640 - 
       (41405*CF*lm*NC*NL*Pi^2)/18 - (41405*CF*lm*NC*NH*Pi^2)/18 + 
       (1889766290443303649250727*CF^2*NC*Pi^3)/(120789464162194080*
         Sqrt[3]) + (123934598854247318084465*CF*NC*NH*Pi^3)/
        (823564528378596*Sqrt[3]) + (834731989*CF^2*NC*Pi^4)/1800 - 
       (11766270528416321404805931223*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (46503943702444720800*Sqrt[3]) - (809121482036280280577327*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1441237924662543*Sqrt[3]) + 
       (275846298*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (269966612920471949892961*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(466008735193650*Sqrt[3]) + 
       (14163954154771122066796*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) + 
       (269966612920471949892961*CF^2*NC*Pi*Log[3]^2)/(22368419289295200*
         Sqrt[3]) + (3540988538692780516699*CF*NC*NH*Pi*Log[3]^2)/
        (30502389939948*Sqrt[3]) + CF*((-1130216724969020682198077*CF*NC)/
          268875406800 + CA*(16956406924067366308467659/8066262204000 - 
           (344244901*lm)/3)*NC + 751079784*CF*lm*NC - 
         (2570705263427444734823*NM*NC)/174594420 + (62589982*lm*NM*NC)/3 + 
         (137619872*NC*NL)/5 + (62589982*lm*NC*NL)/3 + 
         (14827673653990291*NC*NH)/4015671660 + (62589982*lm*NC*NH)/3)*
        Log[x]^2 - (CF*NC*(-173067840087514781*CA + 
          120*(2880349004627698*CF + 1155*(8412586954620*NM + 
              31294991*NL)))*Log[x]^3)/311850 - 
       (3565386895472163946995523082453*CF^2*NC*PolyGamma[2, 1])/
        18159597850748041800 - (1248918480115949*CF*NM*NC*PolyGamma[2, 1])/
        1890 + (10699737633813742204126811*CF*NC*NH*PolyGamma[2, 1])/
        216185688699381450 + CA*CF*NC*
        (-84387282238558833228013258737080669792634235384639/
          285783331135691133056698853021755200000 - (60129069*lm^2)/10 + 
         (82390765327131189934553*Pi^2)/470259820800 - 
         (1889766290443303649250727*Pi^3)/(241578928324388160*Sqrt[3]) - 
         (280452263*Pi^4)/1200 + lm*(-8409303737057/342144 + 
           (455455*Pi^2)/36) + (11766270528416321404805931223*
           Im[PolyLog[2, (-1)^(1/3)]])/(93007887404889441600*Sqrt[3]) - 
         (137923149*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (269966612920471949892961*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (932017470387300*Sqrt[3]) - (269966612920471949892961*Pi*Log[3]^2)/
          (44736838578590400*Sqrt[3]) + (3565386895472163946995523082453*
           PolyGamma[2, 1])/36319195701496083600 - 
         (4054534534280409962401453778189*Zeta[3])/49938894089557114950) + 
       (4053518196929650477405581942599*CF^2*NC*Zeta[3])/
        24969447044778557475 + (517565777581231*CF*NM*NC*Zeta[3])/945 + 
       (80162264*CF*NC*NL*Zeta[3])/3 - (35951290980495980401302889*CF*NC*NH*
         Zeta[3])/108092844349690725 + CF*Log[x]*
        ((-580401546552535933530194117*NM*NC)/57733355104425 + 
         (20096298469*lm*NM*NC)/1188 + 2914912*lm^2*NM*NC + 
         (279219759475847*NC*NL)/4989600 + (20096298469*lm*NC*NL)/1188 + 
         2914912*lm^2*NC*NL + (92134178704529207690788981926874524403*NC*
           NH)/84339834555731823845069693400 + (20096298469*lm*NC*NH)/
          1188 + 2914912*lm^2*NC*NH - (8412605330939*NM*NC*Pi^2)/9 + 
         (40039727*NC*NL*Pi^2)/9 - (14163954154771122066796*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CA*NC*(4163884006705964603562726562746722280667807/
            3273682299075664996128729120000 - (24503645413*lm)/216 - 
           16032016*lm^2 + (115360110306047419*Pi^2)/831600 + 
           (269966612920471949892961*Im[PolyLog[2, (-1)^(1/3)]])/
            (2796052411161900*Sqrt[3]) - 8744736*Zeta[3]) + 
         CF*NC*(-33311541632389007244175274368201358903429/
            13094729196302659984514916480 + (15911942293*lm)/33 + 
           104936832*lm^2 - (346088356513221869*Pi^2)/1247400 - 
           (269966612920471949892961*Im[PolyLog[2, (-1)^(1/3)]])/
            (1398026205580950*Sqrt[3]) + 17489472*Zeta[3])), 
      (-82078113528592020411953253359156277505953708233869987*CF^2*NC)/
        61729199525309284740246952252699123200000 - 
       (2358782491698869*CF^2*lm*NC)/32931360 - (231146682*CF^2*lm^2*NC)/5 - 
       (17186751738246565431517212029606460949*CF*NM*NC)/
        85155178091690761262208000 - (4198343019487853*CF*lm*NM*NC)/
        1185528960 - (38524447*CF*lm^2*NM*NC)/30 + 
       (96847720029153209947*CF*NC*NL)/5228182713600 - 
       (4198343019487853*CF*lm*NC*NL)/1185528960 - (38524447*CF*lm^2*NC*NL)/
        30 + (140681015579761126534284403946108080747839495079*CF*NC*NH)/
        115159565559796695354817563602414976000 - 
       (4198343019487853*CF*lm*NC*NH)/1185528960 - (38524447*CF*lm^2*NC*NH)/
        30 + (1594037801747965782178913*CF^2*NC*Pi^2)/1075501627200 + 
       (739375*CF^2*lm*NC*Pi^2)/9 - (1990088408832015307*CF*NM*NC*Pi^2)/
        4490640 + (739375*CF*lm*NM*NC*Pi^2)/324 - 
       (341680718821*CF*NC*NL*Pi^2)/160380 + (739375*CF*lm*NC*NL*Pi^2)/
        324 + (739375*CF*lm*NC*NH*Pi^2)/324 - 
       (66825306610245350978996623*CF^2*NC*Pi^3)/(3261315532379240160*
         Sqrt[3]) - (2561388634843551710344175*CF*NC*NH*Pi^3)/
        (14824161510814728*Sqrt[3]) - (4358862391*CF^2*NC*Pi^4)/8100 + 
       (2869181605498733971156487610283*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8789245359762052231200*Sqrt[3]) + (26905723105618592903281339*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(51884565287851548*Sqrt[3]) - 
       (331820476*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (66825306610245350978996623*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(88075650951599850*Sqrt[3]) - 
       (146365064848202954876810*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (66825306610245350978996623*CF^2*NC*Pi*Log[3]^2)/
        (4227631245676792800*Sqrt[3]) - (73182532424101477438405*CF*NC*NH*Pi*
         Log[3]^2)/(549043018919064*Sqrt[3]) - 
       (CF*NC*(-23*CA*(-322779477179341864055080841 + 5077514637667122651000*
             lm) + 330*(92*CF*(-489035156452224816672709 + 
              25177758533886558600*lm) + 385*(69*(506456385339568157519 + 
                2422102793062680*lm)*NM + 6169531914*(35724657 + 
                27088780*lm)*NL + (30612262168481209 + 167125092721324920*
                 lm)*NH)))*Log[x]^2)/834858138114000 + 
       (CF*NC*(-4115127952032651707*CA + 40*(205666267311896768*CF + 
            1155*(-46171892394070*NM + 686700573*NL)))*Log[x]^3)/1871100 + 
       (121873406473607518457508452868977*CF^2*NC*PolyGamma[2, 1])/
        163436380656732376200 - (90193430173707397*CF*NM*NC*PolyGamma[2, 1])/
        793800 - (3804638701791337392834979021*CF*NC*NH*PolyGamma[2, 1])/
        81718190328366188100 - (6364043639137162996242069606173*CF^2*NC*
         Zeta[3])/8989000936120280691 + (136130784724997603*CF*NM*NC*
         Zeta[3])/396900 - (878574892*CF*NC*NL*Zeta[3])/27 + 
       (17475002269207815343630664879*CF*NC*NH*Zeta[3])/
        40859095164183094050 + CA*CF*NC*
        (82076586245138765880598575899121810045476156976062371/
          123458399050618569480493904505398246400000 + (423768917*lm^2)/60 - 
         (522740281277907991527847*Pi^2)/705389731200 + 
         (66825306610245350978996623*Pi^3)/(6522631064758480320*Sqrt[3]) + 
         (4388437391*Pi^4)/16200 + lm*(6135936553459949/215550720 - 
           (8133125*Pi^2)/648) - (2869181605498733971156487610283*
           Im[PolyLog[2, (-1)^(1/3)]])/(17578490719524104462400*Sqrt[3]) + 
         (165910238*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (66825306610245350978996623*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (176151301903199700*Sqrt[3]) + (66825306610245350978996623*Pi*
           Log[3]^2)/(8455262491353585600*Sqrt[3]) - 
         (121873406473607518457508452868977*PolyGamma[2, 1])/
          326872761313464752400 + (25457797284588141798009033345335*Zeta[3])/
          71912007488962245528) + CF*Log[x]*
        ((-236243547565990264671521149661*NM*NC)/45724817242704600 - 
         (2143310196079*lm*NM*NC)/106920 - 3539536*lm^2*NM*NC - 
         (126687934926564791*NC*NL)/1886068800 - (2143310196079*lm*NC*NL)/
          106920 - 3539536*lm^2*NC*NL - 
         (13851399043786376277933792318073588045*NC*NH)/
          11040851069113984212445487136 - (2143310196079*lm*NC*NH)/106920 - 
         3539536*lm^2*NC*NH - (46171438343291*NM*NC*Pi^2)/162 - 
         (292611839*NC*NL*Pi^2)/54 + (146365064848202954876810*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(230404172268056043072736945819616893329679987/
            17677884415008590979095137248000 - (1686019842559*lm)/2970 - 
           127423296*lm^2 + (2057474053562937047*Pi^2)/1871100 + 
           (66825306610245350978996623*Im[PolyLog[2, (-1)^(1/3)]])/
            (264226952854799550*Sqrt[3]) - 21237216*Zeta[3]) + 
         CA*NC*(-576008212863873312453305603770165528460556193/
            88389422075042954895475686240000 + (2624970254959*lm)/19440 + 
           19467448*lm^2 - (228606761969926079*Pi^2)/415800 - 
           (66825306610245350978996623*Im[PolyLog[2, (-1)^(1/3)]])/
            (528453905709599100*Sqrt[3]) + 10618608*Zeta[3])), 
      (29336292537208274358957457222249907627769456083740009*CF^2*NC)/
        3779338746447507228994711362410150400000 + 
       (71205937057711*CF^2*lm*NC)/588060 + (376891424*CF^2*lm^2*NC)/5 + 
       (144011472193030340284784359782885173*CF*NM*NC)/
        6719947766074081539000 + (124767673333759*CF*lm*NM*NC)/21170160 + 
       (94222856*CF*lm^2*NM*NC)/45 - (713506222479497116721*CF*NC*NL)/
        20539289232000 + (124767673333759*CF*lm*NC*NL)/21170160 + 
       (94222856*CF*lm^2*NC*NL)/45 - 
       (642848253214691452283383979160034957059721754652793*CF*NC*NH)/
        285762164147893948141202567493883255875000 + 
       (124767673333759*CF*lm*NC*NH)/21170160 + (94222856*CF*lm^2*NC*NH)/
        45 - (601310026980292796088037*CF^2*NC*Pi^2)/141421480200 - 
       (1324960*CF^2*lm*NC*Pi^2)/9 - (9358386804322427633*CF*NM*NC*Pi^2)/
        561330 - (331240*CF*lm*NM*NC*Pi^2)/81 + 
       (148795486021*CF*NC*NL*Pi^2)/40095 - (331240*CF*lm*NC*NL*Pi^2)/81 - 
       (331240*CF*lm*NC*NH*Pi^2)/81 + (169884328012711707257124227*CF^2*NC*
         Pi^3)/(4891973298568860240*Sqrt[3]) + 
       (1827570670951427948214340*CF*NC*NH*Pi^3)/(5559060566555523*
         Sqrt[3]) + (3939441233*CF^2*NC*Pi^4)/4050 - 
       (143205211045299601406129796173*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (269058531421287313200*Sqrt[3]) - (377942369214690054589386586*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(305748331160553765*Sqrt[3]) + 
       (5059922504*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
       (24269189716101672465303461*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(18873353775342825*Sqrt[3]) + 
       (835460878149224204897984*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (24269189716101672465303461*CF^2*NC*Pi*Log[3]^2)/
        (905920981216455600*Sqrt[3]) + (52216304884326512806124*CF*NC*NH*Pi*
         Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((-37038425260315034453530951*CF*NC)/725963598360 + 
         CA*(77166057313454248646784023/3024848326500 - (774265492*lm)/3)*
          NC + 1689306528*CF*lm*NC - (15718333067235834318445*NM*NC)/
          78567489 + (140775544*lm*NM*NC)/3 + (1669453994*NC*NL)/27 + 
         (140775544*lm*NC*NL)/3 + (403212507832074067*NC*NH)/45176306175 + 
         (140775544*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-9575074296135998689*CA + 80*(239309471922901222*CF + 
            10395*(86338046515363*NM + 52790829*NL)))*Log[x]^3)/1403325 - 
       (29630240990204129444691836403092*CF^2*NC*PolyGamma[2, 1])/
        12257728549254928215 - (4692890448074093*CF*NM*NC*PolyGamma[2, 1])/
        525 + (934825513120472212081072399*CF*NC*NH*PolyGamma[2, 1])/
        8755520392324948725 + CA*CF*NC*
        (-359367229732820627439789307502016207670575078831370717/
          92593799287963927110370428379048684800000 - (518225708*lm^2)/45 + 
         (2590255703031442308554753*Pi^2)/1218400444800 - 
         (169884328012711707257124227*Pi^3)/(9783946597137720480*Sqrt[3]) - 
         (3965940433*Pi^4)/8100 + lm*(-181183796809471/3849120 + 
           (1821820*Pi^2)/81) + (143205211045299601406129796173*
           Im[PolyLog[2, (-1)^(1/3)]])/(538117062842574626400*Sqrt[3]) - 
         (2529961252*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
         (24269189716101672465303461*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (37746707550685650*Sqrt[3]) - (24269189716101672465303461*Pi*
           Log[3]^2)/(1811841962432911200*Sqrt[3]) + 
         (14815120495102064722345918201546*PolyGamma[2, 1])/
          12257728549254928215 - (2681541354779561507087158674433663*Zeta[3])/
          2696700280836084207300) + (1340711166525710718356679063833669*CF^2*
         NC*Zeta[3])/674175070209021051825 + 
       (36399417876794326*CF*NM*NC*Zeta[3])/4725 + 
       (1592655064*CF*NC*NL*Zeta[3])/27 - (6287326897115143060386490402*CF*
         NC*NH*Zeta[3])/8755520392324948725 + 
       CF*Log[x]*((-489476795800258339504237905607*NM*NC)/3657985379416368 + 
         (469186413488*lm*NM*NC)/13365 + (18019456*lm^2*NM*NC)/3 + 
         (90231348077527147*NC*NL)/740955600 + (469186413488*lm*NC*NL)/
          13365 + (18019456*lm^2*NC*NL)/3 + 
         (24705579982152493550587997622109463050397*NC*NH)/
          10350797877294360199167644190000 + (469186413488*lm*NC*NH)/13365 + 
         (18019456*lm^2*NC*NH)/3 - (345352345049008*NM*NC*Pi^2)/27 + 
         (29469076*NC*NL*Pi^2)/3 - (835460878149224204897984*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(1961193442297067694830675823078716091624813977/
            132584133112564432343213529360000 - (285678364504*lm)/1215 - 
           (99107008*lm^2)/3 + (19149584494847447323*Pi^2)/11226600 + 
           (24269189716101672465303461*Im[PolyLog[2, (-1)^(1/3)]])/
            (113240122652056950*Sqrt[3]) - 18019456*Zeta[3]) + 
         CF*NC*(-784479511555509803148787167409907220081000803/
            26516826622512886468642705872000 + (1488741717632*lm)/1485 + 
           216233472*lm^2 - (19149663396947917681*Pi^2)/5613300 - 
           (24269189716101672465303461*Im[PolyLog[2, (-1)^(1/3)]])/
            (56620061326028475*Sqrt[3]) + 36038912*Zeta[3])), 
      (-160048260302899686184259418062924050578925504895706606669799*CF^2*NC)/
        7322826913588271157487200513571254761750400000 - 
       (2003772909030154*CF^2*lm*NC)/14907321 - (433590912*CF^2*lm^2*NC)/5 + 
       (17965190327437165414859140366283563556237*CF*NM*NC)/
        8830253282740921809181404000 - (8914571612744881*CF*lm*NM*NC)/
        1341658890 - (12044192*CF*lm^2*NM*NC)/5 + 
       (78111907620225892243423*CF*NC*NL)/1822348437109200 - 
       (8914571612744881*CF*lm*NC*NL)/1341658890 - (12044192*CF*lm^2*NC*NL)/
        5 + (1544225021008692274272761698419805304592823801031*CF*NC*NH)/
        590417694520442041614054891516287718750 - 
       (8914571612744881*CF*lm*NC*NH)/1341658890 - (12044192*CF*lm^2*NC*NH)/
        5 + (1139552768889863418113540681*CF^2*NC*Pi^2)/53086088130075 + 
       (3879680*CF^2*lm*NC*Pi^2)/27 - (89203793049261928616*CF*NM*NC*Pi^2)/
        10945935 + (969920*CF*lm*NM*NC*Pi^2)/243 - 
       (1339314544000*CF*NC*NL*Pi^2)/312741 + (969920*CF*lm*NC*NL*Pi^2)/
        243 + (969920*CF*lm*NC*NH*Pi^2)/243 - 
       (702327204558857398325133529*CF^2*NC*Pi^3)/(15898913220348795780*
         Sqrt[3]) - (2053767246583058084724800*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (6717105802*CF^2*NC*Pi^4)/6075 + 
       (373659530218227953084625207061459*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (557018424674920060152300*Sqrt[3]) + (2425945018486861287973159472*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2140238318123876355*Sqrt[3]) - 
       (1982269088*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (2809308818235429593300534116*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1717475193556197075*
         Sqrt[3]) - (938865027009397981588480*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (702327204558857398325133529*CF^2*NC*Pi*Log[3]^2)/
        (20609702322674364900*Sqrt[3]) - (58679064188087373849280*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) - 
       (CF*NC*(CA*(2096764233806206574393208343791 - 
            4994803646078721707232000*lm) + 
          80*(5*CF*(-10483740784796323969836636817 + 81733150572197264300160*
               lm) + 6006*(105*(31556969197811112389731 + 18000771400600560*
                 lm)*NM + 2*(12429459900*(100145231 + 76032306*lm)*NL + 
                (185314631875013191 + 945040498531529400*lm)*NH))))*
         Log[x]^2)/16279733693223000 + 
       (4*CF*NC*(-146688164361841901693*CA + 520*(564145336601581337*CF - 
            60060*(3293352939152*NM - 5430879*NL)))*Log[x]^3)/18243225 + 
       (666340076195579017806928447167997*CF^2*NC*PolyGamma[2, 1])/
        61288642746274641075 - (301156108880907496*CF*NM*NC*PolyGamma[2, 1])/
        99225 - (6047146206663810206085012847*CF*NC*NH*PolyGamma[2, 1])/
        61288642746274641075 - (18262219942706452793526088790457454*CF^2*NC*
         Zeta[3])/1752855182543454734745 + (516595231867385008*CF*NM*NC*
         Zeta[3])/99225 - (5677200320*CF*NC*NL*Zeta[3])/81 + 
       (55247999651719104689856982306*CF*NC*NH*Zeta[3])/
        61288642746274641075 + CA*CF*NC*
        (80023923568997843783299274597907718378157519881788009893351/
          7322826913588271157487200513571254761750400000 + 
         (66243056*lm^2)/5 - (18232840113193685220156680243*Pi^2)/
          1698754820162400 + (702327204558857398325133529*Pi^3)/
          (31797826440697591560*Sqrt[3]) + (1125983767*Pi^4)/2025 + 
         lm*(2605564365368381/48787596 - (5334560*Pi^2)/243) - 
         (373659530218227953084625207061459*Im[PolyLog[2, (-1)^(1/3)]])/
          (1114036849349840120304600*Sqrt[3]) + 
         (991134544*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (1404654409117714796650267058*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1717475193556197075*Sqrt[3]) + (702327204558857398325133529*Pi*
           Log[3]^2)/(41219404645348729800*Sqrt[3]) - 
         (666340076195579017806928447167997*PolyGamma[2, 1])/
          122577285492549282150 + (1826238740292168270254761099264354*
           Zeta[3])/350571036508690946949) + 
       CF*Log[x]*((-1510545652748081691136946676977779*NM*NC)/
          18141321241043050050 - (148347182264704*lm*NM*NC)/3648645 - 
         7128576*lm^2*NM*NC - (722132313061199837*NC*NL)/5057021970 - 
         (148347182264704*lm*NC*NL)/3648645 - 7128576*lm^2*NC*NL - 
         (38182118730883452815910769277701476548947*NC*NH)/
          14232347081279745273855510761250 - (148347182264704*lm*NC*NH)/
          3648645 - 7128576*lm^2*NC*NH - (1370032961757824*NM*NC*Pi^2)/
          243 - (315184480*NC*NL*Pi^2)/27 + (938865027009397981588480*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(68435311292953550948842248269551590061800809839/
            372155544251063510703787527105600 - (467675453691136*lm)/405405 - 
           256628736*lm^2 + (32597153715096213158*Pi^2)/2027025 + 
           (2809308818235429593300534116*Im[PolyLog[2, (-1)^(1/3)]])/
            (5152425580668591225*Sqrt[3]) - 42771456*Zeta[3]) + 
         CA*NC*(-2619787722990932399193732335764421057515228817627/
            28493158856722050038258732544022500 + (90725182246592*lm)/
            331695 + 39207168*lm^2 - (97791369574163172367*Pi^2)/12162150 - 
           (1404654409117714796650267058*Im[PolyLog[2, (-1)^(1/3)]])/
            (5152425580668591225*Sqrt[3]) + 21385728*Zeta[3])), 
      (2459520648450957738064351154838629839765309789643343258043543*CF^2*NC)/
        25106835132302643968527544617958587754572800000 + 
       (22049366032556119*CF^2*lm*NC)/99382140 + (690639824*CF^2*lm^2*NC)/5 + 
       (546494921417541369363142324072551848917147*CF*NM*NC)/
        1798755298336113701870286000 + (38636704754822431*CF*lm*NM*NC)/
        3577757040 + (172659956*CF*lm^2*NM*NC)/45 - 
       (1593471404521500916259*CF*NC*NL)/20539289232000 + 
       (38636704754822431*CF*lm*NC*NL)/3577757040 + 
       (172659956*CF*lm^2*NC*NL)/45 - 
       (16055571352210925586808942314093750917089880951369947*CF*NC*NH)/
        3429145969774727377694430809926599070500000 + 
       (38636704754822431*CF*lm*NC*NH)/3577757040 + 
       (172659956*CF*lm^2*NC*NH)/45 - (2692072297805004969028910129*CF^2*NC*
         Pi^2)/53928724449600 - (2265760*CF^2*lm*NC*Pi^2)/9 - 
       (1622429194789789701383*CF*NM*NC*Pi^2)/7297290 - 
       (566440*CF*lm*NM*NC*Pi^2)/81 + (3788365239547*CF*NC*NL*Pi^2)/
        521235 - (566440*CF*lm*NC*NL*Pi^2)/81 - (566440*CF*lm*NC*NH*Pi^2)/
        81 + (2139768011934744506086421377*CF^2*NC*Pi^3)/
        (29351839791413161440*Sqrt[3]) + (11376609754787725418637100*CF*NC*
         NH*Pi^3)/(16677181699666569*Sqrt[3]) + (15692548921*CF^2*NC*Pi^4)/
        8100 - (22412315004918394643000173965481*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(20986565450860410429600*Sqrt[3]) - 
       (2373039052538536505613142954*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (917244993481661295*Sqrt[3]) + (9831017924*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + (305681144562106358012345911*CF^2*
         NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(113240122652056950*
         Sqrt[3]) + (5200735887902960191376960*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (305681144562106358012345911*CF^2*NC*Pi*Log[3]^2)/
        (5435525887298733600*Sqrt[3]) + (325045992993935011961060*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((-650128248383493311190456092147*CF*NC)/1085315579548200 + 
         CA*(166700599370086962583902843797/556572092076000 - 
           (1646360716*lm)/3)*NC + 3592059744*CF*lm*NC - 
         (24106049782302744674436901*NM*NC)/9035261235 + 
         (299338312*lm*NM*NC)/3 + (3546651758*NC*NL)/27 + 
         (299338312*lm*NC*NL)/3 + (912790155286440709*NC*NH)/45176306175 + 
         (299338312*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-2961721017691382235509*CA + 40*(148078055838852846703*CF + 
            540540*(1159612064984053*NM + 112251867*NL)))*Log[x]^3)/
        36486450 - (4244675781485694314738852720904889*CF^2*NC*
         PolyGamma[2, 1])/147092742591059138580 - 
       (563840613153583411*CF*NM*NC*PolyGamma[2, 1])/4725 + 
       (5751549337982571043633036559*CF*NC*NH*PolyGamma[2, 1])/
        26266561176974846175 + CA*CF*NC*
        (-165544469753755864730964943499083285826639476700959803193127/
          3379766267809971303455631006263656043884800000 - 
         (949629758*lm^2)/45 + (1330200182139722177609540837*Pi^2)/
          53294268867840 - (2139768011934744506086421377*Pi^3)/
          (58703679582826322880*Sqrt[3]) - (15783179321*Pi^4)/16200 + 
         lm*(-56108008236582559/650501280 + (3115420*Pi^2)/81) + 
         (22412315004918394643000173965481*Im[PolyLog[2, (-1)^(1/3)]])/
          (41973130901720820859200*Sqrt[3]) - 
         (4915508962*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
         (305681144562106358012345911*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (226480245304113900*Sqrt[3]) - (305681144562106358012345911*Pi*
           Log[3]^2)/(10871051774597467200*Sqrt[3]) + 
         (4244675781485694314738852720904889*PolyGamma[2, 1])/
          294185485182118277160 - (2467236313773106779508694591949244639*
           Zeta[3])/210342621905214568169400) + 
       (616804292717046517971909940952959636*CF^2*NC*Zeta[3])/
        26292827738151821021175 + (495771740041820378*CF*NM*NC*Zeta[3])/
        4725 + (3332535976*CF*NC*NL*Zeta[3])/27 - 
       (38684391134977570662822240482*CF*NC*NH*Zeta[3])/
        26266561176974846175 + CF*Log[x]*
        ((-16912341854913864034194199174081661*NM*NC)/9675371328556293360 + 
         (12039060363392*lm*NM*NC)/173745 + 11781952*lm^2*NM*NC + 
         (186405264592245073*NC*NL)/740955600 + (12039060363392*lm*NC*NL)/
          173745 + 11781952*lm^2*NC*NL + 
         (130142871983141150932051649333390902545259*NC*NH)/
          26275102303901068197887096790000 + (12039060363392*lm*NC*NH)/
          173745 + 11781952*lm^2*NC*NH - (4638448664513840*NM*NC*Pi^2)/27 + 
         (185015012*NC*NL*Pi^2)/9 - (5200735887902960191376960*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(227173040511682582478649904454616919941055790782291/
            1367671625122658401836419162113080000 - (7322201704576*lm)/
            15795 - 64800736*lm^2 + (5923410675735116067563*Pi^2)/291891600 + 
           (305681144562106358012345911*Im[PolyLog[2, (-1)^(1/3)]])/
            (679440735912341700*Sqrt[3]) - 35345856*Zeta[3]) + 
         CF*NC*(-363477052209984399821440157260812996331017960406489/
            1094137300098126721469135329690464000 + (38262141077408*lm)/
            19305 + 424150272*lm^2 - (5923414931214094081541*Pi^2)/
            145945800 - (305681144562106358012345911*Im[PolyLog[2, (-1)^
                (1/3)]])/(339720367956170850*Sqrt[3]) + 70691712*Zeta[3])), 
      (-371991315805126405306679716377331443060517687897799233707985427*CF^2*
         NC)/1085501401308379018639279134952915411741824000000 - 
       (41653674447242801*CF^2*lm*NC)/172161990 - (5461479024*CF^2*lm^2*NC)/
        35 + (1763326474971274844068175619586769936100156227*CF*NM*NC)/
        20603924326395484221423276000000 - (74115000419073557*CF*lm*NM*NC)/
        6197831640 - (455123252*CF*lm^2*NM*NC)/105 + 
       (479700014131021844488957*CF*NC*NL)/5154116791824000 - 
       (74115000419073557*CF*lm*NC*NL)/6197831640 - 
       (455123252*CF*lm^2*NC*NL)/105 + 
       (3071339917382841004393561506182344380013960740954068617*CF*NC*NH)/
        576096522922154199452664376067668643844000000 - 
       (74115000419073557*CF*lm*NC*NH)/6197831640 - 
       (455123252*CF*lm^2*NC*NH)/105 + (2402718774519897116520241161649*CF^2*
         NC*Pi^2)/7927522494091200 + (5086400*CF^2*lm*NC*Pi^2)/21 - 
       (1132428554783477721188*CF*NM*NC*Pi^2)/8513505 + 
       (1271600*CF*lm*NM*NC*Pi^2)/189 - (6362624976769*CF*NC*NL*Pi^2)/
        773955 + (1271600*CF*lm*NC*NL*Pi^2)/189 + 
       (1271600*CF*lm*NC*NH*Pi^2)/189 - (724549333493459457122269225331*CF^2*
         NC*Pi^3)/(8013052263055793073120*Sqrt[3]) - 
       (37633497638080078349430860*CF*NC*NH*Pi^3)/(50031545098999707*
         Sqrt[3]) - (122618063437*CF^2*NC*Pi^4)/56700 + 
       (370139705916518759982995672455460459*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(280737286036159710316759200*Sqrt[3]) + 
       (317757465103365970221908909312*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (134835014041804210365*Sqrt[3]) - 
       (26415813596*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - 
       (724549333493459457122269225331*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(216401874388080831450*
         Sqrt[3]) - (120427192441856250718178752*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4323713773987629*Sqrt[3]) - 
       (724549333493459457122269225331*CF^2*NC*Pi*Log[3]^2)/
        (10387289970627879909600*Sqrt[3]) - (7526699527616015669886172*CF*NC*
         NH*Pi*Log[3]^2)/(12971141321962887*Sqrt[3]) - 
       (CF*NC*(-221*CA*(-1250282402908561566240845386561 + 
            438773205829919936976000*lm) + 
          80*(5440*CF*(-1269816625675418115919200652 + 1458422303468767972335*
               lm) + 3003*(7*(144219666822700879956640739 + 
                10483983385490300400*lm)*NM + 126780490980*(761701981 + 
                578857860*lm)*NL + 3*(5090836857102544159 + 
                24462627899477367600*lm)*NH)))*Log[x]^2)/
        151944181136748000 + (CF*NC*(-1858512483634713226451*CA + 
          160*(23231149102383505763*CF + 715*(-13558204213358212*NM + 
              2741305437*NL)))*Log[x]^3)/4054050 + 
       (171035645960786006693763123269901221*CF^2*NC*PolyGamma[2, 1])/
        1103195569432943539350 - (3782987301066864589*CF*NM*NC*
         PolyGamma[2, 1])/66150 - (219731241166653952588054108229*CF*NC*NH*
         PolyGamma[2, 1])/1103195569432943539350 - 
       (936196842840286523413426203243087169*CF^2*NC*Zeta[3])/
        6310278657156437045082 + (848068926495805537*CF*NM*NC*Zeta[3])/
        11025 - (9042131768*CF*NC*NL*Zeta[3])/63 + 
       (998423926942021620200111821771*CF*NC*NH*Zeta[3])/
        551597784716471769675 + CA*CF*NC*
        (23249449019762227952866742601330227496972721432223322570263927/
          135687675163547377329909891869114426467728000000 + 
         (2503177886*lm^2)/105 - (282672788128922570234997190477*Pi^2)/
          1865299410374400 + (724549333493459457122269225331*Pi^3)/
          (16026104526111586146240*Sqrt[3]) + (123228431437*Pi^4)/113400 + 
         lm*(108306240314168021/1126878480 - (6993800*Pi^2)/189) - 
         (370139705916518759982995672455460459*Im[PolyLog[2, (-1)^(1/3)]])/
          (561474572072319420633518400*Sqrt[3]) + 
         (13207906798*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 + 
         (724549333493459457122269225331*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(432803748776161662900*Sqrt[3]) + 
         (724549333493459457122269225331*Pi*Log[3]^2)/
          (20774579941255759819200*Sqrt[3]) - 
         (171035645960786006693763123269901221*PolyGamma[2, 1])/
          2206391138865887078700 + (9361980597055213704296608592285103397*
           Zeta[3])/126205573143128740901640) + 
       CF*Log[x]*((-815105619897567395893625909052033469*NM*NC)/
          651226916345135130000 - (20292194000642*lm*NM*NC)/257985 - 
         13705536*lm^2*NM*NC - (4133604949367807611*NC*NL)/14302688400 - 
         (20292194000642*lm*NC*NL)/257985 - 13705536*lm^2*NC*NL - 
         (39183418441758127554034746739811320151681039*NC*NH)/
          7173102928964991618023177423670000 - (20292194000642*lm*NC*NH)/
          257985 - 13705536*lm^2*NC*NH - (18077602076667248*NM*NC*Pi^2)/
          189 - (167352692*NC*NL*Pi^2)/7 + (120427192441856250718178752*NC*
           NH*Im[PolyLog[2, (-1)^(1/3)]])/(12971141321962887*Sqrt[3]) + 
         CF*NC*(17097651087958279412263843961686131445259050106881427/
            6757906853547253279662306448088160000 - (64078966261928*lm)/
            28665 - 493399296*lm^2 + (78057448075188065384339*Pi^2)/
            340540200 + (724549333493459457122269225331*
             Im[PolyLog[2, (-1)^(1/3)]])/(649205623164242494350*Sqrt[3]) - 
           82233216*Zeta[3]) + CA*NC*
          (-4274412398454589574337329705992652453234740451058989/
            3378953426773626639831153224044080000 + (136357825938251*lm)/
            257985 + 75380448*lm^2 - (321224023255972655719*Pi^2)/2802800 - 
           (724549333493459457122269225331*Im[PolyLog[2, (-1)^(1/3)]])/
            (1298411246328484988700*Sqrt[3]) + 41116608*Zeta[3])), 
      (4395585683183679988578820582486655623563643940924770598468539957*CF^2*
         NC)/3690704764448488663373549058839912399922201600000 + 
       (1567775104177833*CF^2*lm*NC)/4008004 + (1217764944*CF^2*lm^2*NC)/5 + 
       (419721541834208442629292073225714276785450167*CF*NM*NC)/
        99930849907561872326127000000 + (4578839010181687*CF*lm*NM*NC)/
        240480240 + (33826804*CF*lm^2*NM*NC)/5 - 
       (273246837958026355320077*CF*NC*NL)/1671289571952000 + 
       (4578839010181687*CF*lm*NC*NL)/240480240 + (33826804*CF*lm^2*NC*NL)/
        5 - (311502759300115480106544101406794008037041811970693708347*CF*NC*
         NH)/33453376422734330405835789209319929892169800000 + 
       (4578839010181687*CF*lm*NC*NH)/240480240 + (33826804*CF*lm^2*NC*NH)/
        5 - (1498108888838034194058482307551*CF^2*NC*Pi^2)/2642507498030400 - 
       416160*CF^2*lm*NC*Pi^2 - (157428920842993577917*CF*NM*NC*Pi^2)/
        54054 - 11560*CF*lm*NM*NC*Pi^2 + (1843262133236*CF*NC*NL*Pi^2)/
        135135 - 11560*CF*lm*NC*NL*Pi^2 - 11560*CF*lm*NC*NH*Pi^2 + 
       (1168387823783293622727213646153*CF^2*NC*Pi^3)/(8013052263055793073120*
         Sqrt[3]) + (22566350806560549640599640*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) + (69725442557*CF^2*NC*Pi^4)/18900 - 
       (577105231322911230138223344352128181*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(280737286036159710316759200*Sqrt[3]) - 
       (6650136450328294031394213302*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1284142990874325813*Sqrt[3]) + (14248562716*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + (1168387823783293622727213646153*
         CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (216401874388080831450*Sqrt[3]) + (10316046082999108407131264*CF*NC*
         NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*
         Sqrt[3]) + (1168387823783293622727213646153*CF^2*NC*Pi*Log[3]^2)/
        (10387289970627879909600*Sqrt[3]) + (644752880187444275445704*CF*NC*
         NH*Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((-265049510629873748075914134293*CF*NC)/38960046445320 + 
         CA*(172282375684517038454061290792251/50648060378916000 - 
           1111311828*lm)*NC + 7274041056*CF*lm*NC - 
         (19492323827136105710238451*NM*NC)/557732175 + 
         202056696*lm*NM*NC + (9303790906*NC*NL)/35 + 202056696*lm*NC*NL + 
         (1258592272223802539*NC*NH)/29113619535 + 202056696*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-26518544578077884324851*CA + 
          160*(331478444485945310266*CF + 2837835*(566477328337895*NM + 
              8419029*NL)))*Log[x]^3)/28378350 - 
       (736706186420922152061508352936990807*CF^2*NC*PolyGamma[2, 1])/
        2206391138865887078700 - (7417301715159776387*CF*NM*NC*
         PolyGamma[2, 1])/4725 + (2256890996532011159549439587*CF*NC*NH*
         PolyGamma[2, 1])/5253312235394969235 + 
       CA*CF*NC*
        (-49949827515592699827202607071269649954153528777563732327719281/
          83879653737465651440307933155452554543686400000 - 
         (186047422*lm^2)/5 + (176248099133072866856057899297*Pi^2)/
          621766470124800 - (1168387823783293622727213646153*Pi^3)/
          (16026104526111586146240*Sqrt[3]) - (70075016957*Pi^4)/37800 + 
         lm*(-1329896861021579/8744736 + 63580*Pi^2) + 
         (577105231322911230138223344352128181*Im[PolyLog[2, (-1)^(1/3)]])/
          (561474572072319420633518400*Sqrt[3]) - 
         (7124281358*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
         (1168387823783293622727213646153*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(432803748776161662900*Sqrt[3]) - 
         (1168387823783293622727213646153*Pi*Log[3]^2)/
          (20774579941255759819200*Sqrt[3]) + 
         (736706186420922152061508352936990807*PolyGamma[2, 1])/
          4412782277731774157400 - (84138608028341445238555082597209287589*
           Zeta[3])/631027865715643704508200) + 
       (21034623685300307047585957196824152106*CF^2*NC*Zeta[3])/
        78878483214455463063525 + (6578231534717548826*CF*NM*NC*Zeta[3])/
        4725 + 246474840*CF*NC*NL*Zeta[3] - (15172094642710509518238517946*
         CF*NC*NH*Zeta[3])/5253312235394969235 + 
       CF*Log[x]*((-111688077268073219182595220754349531*NM*NC)/
          4977042864483690000 + (5897634175766*lm*NM*NC)/45045 + 
         22139712*lm^2*NM*NC + (5374522022585893321*NC*NL)/10821610800 + 
         (5897634175766*lm*NC*NL)/45045 + 22139712*lm^2*NC*NL + 
         (564496661706452978632983590718908861455224059*NC*NH)/
          57453138697710075721499925841014000 + (5897634175766*lm*NC*NH)/
          45045 + 22139712*lm^2*NC*NH - (6797728044548096*NM*NC*Pi^2)/3 + 
         41056020*NC*NL*Pi^2 - (10316046082999108407131264*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(51642633238341626486097555240689263484713445362891453/
            28721104127575826438564802404374680000 - (3583451932363*lm)/
            4095 - 121768416*lm^2 + (841857770496891478819*Pi^2)/3603600 + 
           (1168387823783293622727213646153*Im[PolyLog[2, (-1)^(1/3)]])/
            (1298411246328484988700*Sqrt[3]) - 66419136*Zeta[3]) + 
         CF*NC*(-82628221167961131241709352154524966061065437453017453/
            22976883302060661150851841923499744000 + (18770333955704*lm)/
            5005 + 797029632*lm^2 - (53037046102603739813699*Pi^2)/
            113513400 - (1168387823783293622727213646153*
             Im[PolyLog[2, (-1)^(1/3)]])/(649205623164242494350*Sqrt[3]) + 
           132838272*Zeta[3])), 
      (-10919212119197644021630600271964758116075342339441155384233555009*
         CF^2*NC)/2118389214288035584844511577140255841792080000000 - 
       (903652416693183614*CF^2*lm*NC)/2152024875 - (9476443008*CF^2*lm^2*NC)/
        35 + (348949732625080455442302937690724339654699865449*CF*NM*NC)/
        191230172654358087930084780375000 - (803857572222984007*CF*lm*NM*NC)/
        38736447750 - (263234528*CF*lm^2*NM*NC)/35 + 
       (264615824739728166025063907*CF*NC*NL)/1381947564807810000 - 
       (803857572222984007*CF*lm*NC*NL)/38736447750 - 
       (263234528*CF*lm^2*NC*NL)/35 + 
       (164523665903860778789385618323584348050180219860689243413251*CF*NC*
         NH)/15806720359741971116757410401403666874050230500000 - 
       (803857572222984007*CF*lm*NC*NH)/38736447750 - 
       (263234528*CF*lm^2*NC*NH)/35 + (33524042676221659547620907653*CF^2*NC*
         Pi^2)/8023808192400 + (13835008*CF^2*lm*NC*Pi^2)/35 - 
       (28637022282824357318452*CF*NM*NC*Pi^2)/14189175 + 
       (3458752*CF*lm*NM*NC*Pi^2)/315 - (58657637276248*CF*NC*NL*Pi^2)/
        3869775 + (3458752*CF*lm*NC*NL*Pi^2)/315 + 
       (3458752*CF*lm*NC*NH*Pi^2)/315 - (1594737653455597593835970289833*
         CF^2*NC*Pi^3)/(9014683795937767207260*Sqrt[3]) - 
       (660607039825317147802895680*CF*NC*NH*Pi^3)/(450283905890997363*
         Sqrt[3]) - (57439480558*CF^2*NC*Pi^4)/14175 + 
       (1967334758155626596225169819408891353*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(789573616976699185265885250*Sqrt[3]) + 
       (369841667932998219700978961569952*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(78878483214455463063525*Sqrt[3]) - 
       (48345430688*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - 
       (6378950613822390375343881159332*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(973808434746363741525*
         Sqrt[3]) - (2113942527441014872969266176*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(38913423965888661*Sqrt[3]) - 
       (1594737653455597593835970289833*CF^2*NC*Pi*Log[3]^2)/
        (11685701216956364898300*Sqrt[3]) - (132121407965063429560579136*CF*
         NC*NH*Pi*Log[3]^2)/(116740271897665983*Sqrt[3]) - 
       (CF*NC*(-1421*CA*(-19433679791134878793827398929813 + 
            982585564824513790483200*lm) + 
          4*(29*CF*(-476125076840902252752648752892467 + 
              78785497106838287564198400*lm) + 
            40040*(2030*(82058571839134325208456379 + 780821332505176248*lm)*
               NM + 113127207336*(18423357553 + 14011371290*lm)*NL + 
              (347608163573601848849 + 1585067304985507783440*lm)*NH)))*
         Log[x]^2)/1101595313241423000 + 
       (4*CF*NC*(-67858767015437737855594*CA + 
          7*(19388186487422580172273*CF - 68640*(131842910532039543*NM - 
              3402761599*NL)))*Log[x]^3)/42567525 + 
       (10730301395461281440689319387358847661*CF^2*NC*PolyGamma[2, 1])/
        4964380062448245927075 - (2065397809395467713*CF*NM*NC*
         PolyGamma[2, 1])/2205 - (1912764550064956680443210287496*CF*NC*NH*
         PolyGamma[2, 1])/4964380062448245927075 - 
       (1457905998855776337691271729335521892498*CF^2*NC*Zeta[3])/
        709906348930099167571725 + (7296167358495593338*CF*NM*NC*Zeta[3])/
        6615 - (265723035328*CF*NC*NL*Zeta[3])/945 + 
       (17293830926085819233175637874288*CF*NC*NH*Zeta[3])/
        4964380062448245927075 + CA*CF*NC*
        (267520684102665611931091445305671748799767162335359804007188385733/
          103801071500113743657381067279872536247811920000000 + 
         (1447789904*lm^2)/35 - (93670118847473965401529329289*Pi^2)/
          44838928134000 + (1594737653455597593835970289833*Pi^3)/
          (18029367591875534414520*Sqrt[3]) + (28844255351*Pi^4)/14175 + 
         lm*(1174649228218180807/7042990500 - (19023136*Pi^2)/315) - 
         (1967334758155626596225169819408891353*Im[PolyLog[2, (-1)^(1/3)]])/
          (1579147233953398370531770500*Sqrt[3]) + 
         (24172715344*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 + 
         (3189475306911195187671940579666*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(973808434746363741525*Sqrt[3]) + 
         (1594737653455597593835970289833*Pi*Log[3]^2)/
          (23371402433912729796600*Sqrt[3]) - 
         (10730301395461281440689319387358847661*PolyGamma[2, 1])/
          9928760124896491854150 + (728953131921468322273520796933034260872*
           Zeta[3])/709906348930099167571725) + 
       CF*Log[x]*((-170507641305632680022777955501184964707*NM*NC)/
          9524193651547601276250 - (188344412704624*lm*NM*NC)/1289925 - 
         25302528*lm^2*NM*NC - (2148591144458728446427*NC*NL)/
          3834908327250 - (188344412704624*lm*NC*NL)/1289925 - 
         25302528*lm^2*NC*NL - 
         (6573579249124096348500938823478423055243089093*NC*NH)/
          616968364424272972236561703633616250 - (188344412704624*lm*NC*NH)/
          1289925 - 25302528*lm^2*NC*NH - (281264867821575040*NM*NC*Pi^2)/
          189 - (132799260128*NC*NL*Pi^2)/2835 + 
         (2113942527441014872969266176*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (116740271897665983*Sqrt[3]) + 
         CF*NC*(3381876153675829446848417778609764202976342928808994429/
            99419206595454783825801239092066200000 - (595625560904896*lm)/
            143325 - 910891008*lm^2 + (135717514959581252762828*Pi^2)/
            42567525 + (6378950613822390375343881159332*
             Im[PolyLog[2, (-1)^(1/3)]])/(2921425304239091224575*Sqrt[3]) - 
           151815168*Zeta[3]) + CA*NC*
          (-392539191400494099840416203749137639239056842995031371/
            23079458673944860530989573360658225000 + (1264362813888232*lm)/
            1289925 + 139163904*lm^2 - (45239170807566235865429*Pi^2)/
            28378350 - (3189475306911195187671940579666*
             Im[PolyLog[2, (-1)^(1/3)]])/(2921425304239091224575*Sqrt[3]) + 
           75907584*Zeta[3])), 
      (38258852230766679535345462981767918469525865549550315748968601201*CF^2*
         NC)/2737610676926076755799061115073561395546688000000 + 
       (9018106065885903671*CF^2*lm*NC)/13527013500 + 
       (2075706528*CF^2*lm^2*NC)/5 + 
       (7811791877281936735156640486274538311618014707*CF*NM*NC)/
        137711889570156152978727000000 + (15803649370573651271*CF*lm*NM*NC)/
        486972486000 + (172975544*CF*lm^2*NM*NC)/15 - 
       (517803646528773964210312631*CF*NC*NL)/1579368645494640000 + 
       (15803649370573651271*CF*lm*NC*NL)/486972486000 + 
       (172975544*CF*lm^2*NC*NL)/15 - 
       (78905596201559316663944286628184570187609697948052527721426869*CF*NC*
         NH)/4435460027350766670700031522149607282682861069000000 + 
       (15803649370573651271*CF*lm*NC*NH)/486972486000 + 
       (172975544*CF*lm^2*NC*NH)/15 - (27000002227460110183920327236707*CF^2*
         NC*Pi^2)/4341262318192800 - (3338528*CF^2*lm*NC*Pi^2)/5 - 
       (456248810491246690858223*CF*NM*NC*Pi^2)/12162150 - 
       (834632*CF*lm*NM*NC*Pi^2)/45 + (5553188390914*CF*NC*NL*Pi^2)/
        225225 - (834632*CF*lm*NC*NL*Pi^2)/45 - (834632*CF*lm*NC*NH*Pi^2)/
        45 + (4320038856974136010307663985041*CF^2*NC*Pi^3)/
        (15453743650179029498160*Sqrt[3]) + (3484340549155146199849764280*CF*
         NC*NH*Pi^3)/(1350851717672992089*Sqrt[3]) + 
       (3039251381*CF^2*NC*Pi^4)/450 - 
       (10325469932061093077260825960198746529*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2707109543920111492340178000*Sqrt[3]) - 
       (336853579605246368326754708880986*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(33805064234766627027225*Sqrt[3]) + 
       731217736*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (4320038856974136010307663985041*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(417346472034155889225*
         Sqrt[3]) + (1592841393899495405645606528*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) + 
       (4320038856974136010307663985041*CF^2*NC*Pi*Log[3]^2)/
        (20032630657639482682800*Sqrt[3]) + (99552587118718462852850408*CF*NC*
         NH*Pi*Log[3]^2)/(50031545098999707*Sqrt[3]) + 
       (CF*NC*(-899*CA*(-1417499904972759771140971292850149 + 
            81900124405911049796157600*lm) + 
          77*(899*CF*(-36818172007101555287912347810841 + 
              6961994046311210844537600*lm) + 
            10920*(268801*(-68016168626828404771942631 + 59229398210348520*
                 lm)*NM + 1850886808914*(11310528121 + 8601780180*lm)*NL + 
              5*(715308700851580604191 + 3184184293667978504904*lm)*NH)))*
         Log[x]^2)/34149454710484113000 - 
       (CF*NC*(-29513716222166126144867*CA + 28*(2108118620987326330811*CF + 
            4004*(2974398293227667061*NM + 6615178567*NL)))*Log[x]^3)/
        2837835 - (55707388990238292887710198135545804248*CF^2*NC*
         PolyGamma[2, 1])/14893140187344737781225 - 
       (288339764732465979419*CF*NM*NC*PolyGamma[2, 1])/14175 + 
       (1724538840723458347716503614313*CF*NC*NH*PolyGamma[2, 1])/
        2127591455334962540175 + CA*CF*NC*
        (-124341265619997127774384635850761183047916604221760132244124113197/
          17794469400019498912693897247978149071053472000000 - 
         (951365492*lm^2)/15 + (254408419206756884970663315139*Pi^2)/
          81811377648000 - (4320038856974136010307663985041*Pi^3)/
          (30907487300358058996320*Sqrt[3]) - (3052605493*Pi^4)/900 + 
         lm*(-22950804700903065671/88540452000 + (4590476*Pi^2)/45) + 
         (10325469932061093077260825960198746529*Im[PolyLog[2, (-1)^(1/3)]])/
          (5414219087840222984680356000*Sqrt[3]) - 
         365608868*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (4320038856974136010307663985041*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(834692944068311778450*Sqrt[3]) - 
         (4320038856974136010307663985041*Pi*Log[3]^2)/
          (40065261315278965365600*Sqrt[3]) + 
         (27853694495119146443855099067772902124*PolyGamma[2, 1])/
          14893140187344737781225 - 
         (12433882750969342977911273186505838419749*Zeta[3])/
          8518876187161190010860700) + 
       (6216939925007876158432545204680335402693*CF^2*NC*Zeta[3])/
        2129719046790297502715175 + (256151945307583186922*CF*NM*NC*Zeta[3])/
        14175 + (63768306008*CF*NC*NL*Zeta[3])/135 - 
       (11583464443420031770963374837614*CF*NC*NH*Zeta[3])/
        2127591455334962540175 + CF*Log[x]*
        ((-1944435296515039052097432582376778501*NM*NC)/
          6858722586405690000 + (22981121889494*lm*NM*NC)/96525 + 
         40062336*lm^2*NM*NC + (589803207778178209693*NC*NL)/626107482000 + 
         (22981121889494*lm*NC*NL)/96525 + 40062336*lm^2*NC*NL + 
         (59831248972725213665588367072367322240927212256779*NC*NH)/
          3194435549548892860169482662421693410000 + 
         (22981121889494*lm*NC*NH)/96525 + 40062336*lm^2*NC*NH - 
         29376773341896320*NM*NC*Pi^2 + (31869129628*NC*NL*Pi^2)/405 - 
         (1592841393899495405645606528*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CA*NC*(28985855467493415383959335050010077686584983686757915129/
            1550939622889094627682499329836232720000 - (13951389933547*lm)/
            8775 - 220342848*lm^2 + (98379037971704639632991*Pi^2)/37837800 + 
           (4320038856974136010307663985041*Im[PolyLog[2, (-1)^(1/3)]])/
            (2504078832204935335350*Sqrt[3]) - 120187008*Zeta[3]) + 
         CF*NC*(-169013737563756464293427186172206399598766923310338241/
            4521689862650421655051018454333040000 + (73233905476376*lm)/
            10725 + 1442244096*lm^2 - (104104804290424538357*Pi^2)/20020 - 
           (4320038856974136010307663985041*Im[PolyLog[2, (-1)^(1/3)]])/
            (1252039416102467667675*Sqrt[3]) + 240374016*Zeta[3])), 
      (-363441070049539172483637415988409742958759791155869101458617276935240\
42237*CF^2*NC)/486068031900724626059494435178651767017193904040960000000 - 
       (6415071155474708614691*CF^2*lm*NC)/9090153072000 - 
       (15923656458*CF^2*lm^2*NC)/35 + 
       (41479651379033556629622988136122686860785159646112729179*CF*NM*NC)/
        1302503614147622932440949585519488000000 - 
       (11412339923814802460291*CF*lm*NM*NC)/327245510592000 - 
       (884647581*CF*lm^2*NM*NC)/70 + (99780392515183706823858845969*CF*NC*
         NL)/265333932443099520000 - (11412339923814802460291*CF*lm*NC*NL)/
        327245510592000 - (884647581*CF*lm^2*NC*NL)/70 + 
       (7073830743960256493292848767251833452811635779195208831947614343479*
         CF*NC*NH)/
        361649668790072111262197770189990379400829760121984000000 - 
       (11412339923814802460291*CF*lm*NC*NH)/327245510592000 - 
       (884647581*CF*lm^2*NC*NH)/70 + (6177964367957074453220571346486463*
         CF^2*NC*Pi^2)/109673995406976000 + (65831599*CF^2*lm*NC*Pi^2)/105 - 
       (762138633141043240093531*CF*NM*NC*Pi^2)/26195400 + 
       (65831599*CF*lm*NM*NC*Pi^2)/3780 - (36739733063228621*CF*NC*NL*Pi^2)/
        1362160800 + (65831599*CF*lm*NC*NL*Pi^2)/3780 + 
       (65831599*CF*lm*NC*NH*Pi^2)/3780 - (287849130193080907816080139046143*
         CF^2*NC*Pi^3)/(865409644410025651896960*Sqrt[3]) - 
       (7442458780792698226332369185*CF*NC*NH*Pi^3)/(2701703435345984178*
         Sqrt[3]) - (1658435748323*CF^2*NC*Pi^4)/226800 + 
       (1378780636212212769934960553768497775017*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(303196268919052487142099936000*
         Sqrt[3]) + (8492308230216195595029095801691659*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(946541798573465556762300*Sqrt[3]) - 
       (85453361593*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - 
       (287849130193080907816080139046143*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23371402433912729796600*
         Sqrt[3]) - (11907934049268317162131790696*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(116740271897665983*
         Sqrt[3]) - (287849130193080907816080139046143*CF^2*NC*Pi*Log[3]^2)/
        (1121827316827811030236800*Sqrt[3]) - 
       (1488491756158539645266473837*CF*NC*NH*Pi*Log[3]^2)/
        (700441631385995898*Sqrt[3]) - 
       (CF*NC*(-93*CA*(-11914204067977821946944165402117540587 + 
            85198936492483014503740838400*lm) + 
          10*(93*CF*(-2382840758186711111199787242680075513 + 
              55766576613261609493357639680*lm) + 
            8008*(217*(65866016450378113634979041614379 + 
                82903074029038832437440*lm)*NM + 133263850241808*(
                177399158327 + 134995102060*lm)*NL + 
              (4133288796801694525925701 + 17989967064301426638924480*lm)*
               NH)))*Log[x]^2)/3278347652206474848000 + 
       (CF*NC*(-29523600791697059815446761*CA + 
          104*(567761411158227479951581*CF - 20020*(14294154125895016311*
               NM - 47915843918*NL)))*Log[x]^3)/340540200 + 
       (1170896354090370025480889832357665174749*CF^2*NC*PolyGamma[2, 1])/
        39715040499585967416600 - (16869348324529860438197*CF*NM*NC*
         PolyGamma[2, 1])/1190700 - (5701206373555587663750936446413*CF*NC*
         NH*PolyGamma[2, 1])/7943008099917193483320 - 
       (28635291075044177686280122114689051830333*CF^2*NC*Zeta[3])/
        1032591052989235152831600 + (9146014422838372625593*CF*NM*NC*
         Zeta[3])/595350 - (1501952052019*CF*NC*NL*Zeta[3])/2835 + 
       (25647711331735586266656835653611*CF*NC*NH*Zeta[3])/
        3971504049958596741660 + CA*CF*NC*(3003645187680698424887520255792071\
03099490554066724604003506338048373997/
          8034182345466522744785031986423996149044527339520000000 + 
         (9731123391*lm^2)/140 - (110602942587092873560097466985807*Pi^2)/
          3926946127104000 + (287849130193080907816080139046143*Pi^3)/
          (1730819288820051303793920*Sqrt[3]) + (1664755581827*Pi^4)/453600 + 
         lm*(16675920820875214786691/59499183744000 - (724147589*Pi^2)/
            7560) - (1378780636212212769934960553768497775017*
           Im[PolyLog[2, (-1)^(1/3)]])/(606392537838104974284199872000*
           Sqrt[3]) + (85453361593*Im[PolyLog[2, (-1)^(1/3)]]^2)/210 + 
         (287849130193080907816080139046143*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(46742804867825459593200*Sqrt[3]) + 
         (287849130193080907816080139046143*Pi*Log[3]^2)/
          (2243654633655622060473600*Sqrt[3]) - 
         (1170896354090370025480889832357665174749*PolyGamma[2, 1])/
          79430080999171934833200 + 
         (28635291793880188326732542990859397615913*Zeta[3])/
          2065182105978470305663200) + CF*Log[x]*
        ((-758148407304652398791715813016472036242475081*NM*NC)/
          3075781194605388546557280000 - (59336004615832799*lm*NM*NC)/
          227026800 - 45070128*lm^2*NM*NC - (48117387602248849601089*NC*NL)/
          46018899927000 - (59336004615832799*lm*NC*NL)/227026800 - 
         45070128*lm^2*NC*NL - 
         (50104701736755696541463746269180510435527657055354991*NC*NH)/
          2504437470846332002372874407338607633440000 - 
         (59336004615832799*lm*NC*NH)/227026800 - 45070128*lm^2*NC*NH - 
         (12388266858559090231*NM*NC*Pi^2)/567 - (750679783814*NC*NL*Pi^2)/
          8505 + (11907934049268317162131790696*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(350220815692997949*Sqrt[3]) + 
         CF*NC*(91270579752939231478315834256586371888449636932765301268329/
            203803159820270090918903427561292455862500 - 
           (46972184568854399*lm)/6306300 - 1622524608*lm^2 + 
           (5367927310209497599302677*Pi^2)/123832800 + 
           (287849130193080907816080139046143*Im[PolyLog[2, (-1)^(1/3)]])/
            (70114207301738189389800*Sqrt[3]) - 270420768*Zeta[3]) + 
         CA*NC*(-359465667291723311840839453001735429051052138398539474773409\
1/16053418127381274853919777678674113446400000 + (72358711624562399*lm)/
            41277600 + 247885704*lm^2 - (5367927296378788436636437*Pi^2)/
            247665600 - (287849130193080907816080139046143*
             Im[PolyLog[2, (-1)^(1/3)]])/(140228414603476378779600*Sqrt[3]) + 
           135210384*Zeta[3])), (17320159815965119211601046440494826489150269\
52809888159081511612757101431221*CF^2*NC)/
        10936530717766304086338624791519664757886862840921600000000 + 
       (1909160822867025865*CF^2*lm*NC)/1731457728 + 
       (3433426692*CF^2*lm^2*NC)/5 + 
       (17055276388958265055449552444283270990324926629257743643*CF*NM*NC)/
        22742126596228336915635627683673600000 + 
       (16729144206091854221*CF*lm*NM*NC)/311662391040 + 
       (286118891*CF*lm^2*NM*NC)/15 - (6495017333680084582555621*CF*NC*NL)/
        10314244215475200 + (16729144206091854221*CF*lm*NC*NL)/
        311662391040 + (286118891*CF*lm^2*NC*NL)/15 - 
       (7624573170693000558979006798184571678201547911942500529601225791877*
         CF*NC*NH)/
        232489072793617785811412852264993815329104845792704000000 + 
       (16729144206091854221*CF*lm*NC*NH)/311662391040 + 
       (286118891*CF*lm^2*NC*NH)/15 - (483960088213820897262793258657159*
         CF^2*NC*Pi^2)/7366990600569600 - 1043290*CF^2*lm*NC*Pi^2 - 
       (4627945197232894593167407*CF*NM*NC*Pi^2)/9729720 - 
       (521645*CF*lm*NM*NC*Pi^2)/18 + (279634295663381*CF*NC*NL*Pi^2)/
        6486480 - (521645*CF*lm*NC*NL*Pi^2)/18 - (521645*CF*lm*NC*NH*Pi^2)/
        18 + (62828625369326794839570213311899*CF^2*NC*Pi^3)/
        (121698231245159857298010*Sqrt[3]) + (57699670100157306352264570990*
         CF*NC*NH*Pi^3)/(12157665459056928801*Sqrt[3]) + 
       (18808308088*CF^2*NC*Pi^4)/1575 - 
       (2336091479561127428787835647276278083613*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(341095802533934048034862428000*
         Sqrt[3]) - (225256167653898528747682356155279*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(12169823124515985729801*Sqrt[3]) + 
       (44491911488*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
       (502629002954614358716561706495192*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(26292827738151821021175*
         Sqrt[3]) + (26376992045786197189606661024*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) + (62828625369326794839570213311899*CF^2*NC*Pi*Log[3]^2)/
        (157756966428910926127050*Sqrt[3]) + (1648562002861637324350416314*CF*
         NC*NH*Pi*Log[3]^2)/(450283905890997363*Sqrt[3]) + 
       CF*((-310144939192697944384789686403937057*CF*NC)/393426897586222500 + 
         CA*(17368117208813911809048435919268636377/44063812529656920000 - 
           (108738868612*lm)/27)*NC + (79082813536*CF*lm*NC)/3 - 
         (11964589689833776424160861469643*NM*NC)/2096180606520 + 
         (19770703384*lm*NM*NC)/27 + (2728570350998*NC*NL)/2835 + 
         (19770703384*lm*NC*NL)/27 + (55825295285945102079091*NC*NH)/
          324907994010600 + (19770703384*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-6335802237020003771016633*CA + 
          16*(791975004724300264299961*CF + 350350*(15177982619964766161*
               NM + 4942675846*NL)))*Log[x]^3)/56756700 - 
       (43403537709723204877346363051229328260931*CF^2*NC*PolyGamma[2, 1])/
        1072306093488821120248200 - (1472487790929378710033*CF*NM*NC*
         PolyGamma[2, 1])/5670 + (56563798608620357522956270113511*CF*NC*NH*
         PolyGamma[2, 1])/38296646196029325723150 + 
       CA*CF*NC*(-17320159719156825945043821584931284524154363646009940725982\
76858886206165221/
          21873061435532608172677249583039329515773725681843200000000 - 
         (3147307801*lm^2)/30 + (7491642226073261313402591869309*Pi^2)/
          228080204352000 - (62828625369326794839570213311899*Pi^3)/
          (243396462490319714596020*Sqrt[3]) - (9440669194*Pi^4)/1575 + 
         lm*(-4859059105061793769/11333177856 + (5738095*Pi^2)/36) + 
         (2336091479561127428787835647276278083613*
           Im[PolyLog[2, (-1)^(1/3)]])/(682191605067868096069724856000*
           Sqrt[3]) - (22245955744*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
         (251314501477307179358280853247596*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(26292827738151821021175*Sqrt[3]) - 
         (62828625369326794839570213311899*Pi*Log[3]^2)/
          (315513932857821852254100*Sqrt[3]) + 
         (43403537709723204877346363051229328260931*PolyGamma[2, 1])/
          2144612186977642240496400 - 
         (90462445550944872617036904732849549100463*Zeta[3])/
          5897683514188516161365100) + 
       (18092488374454591200348676687819345131787*CF^2*NC*Zeta[3])/
        589768351418851616136510 + (652429758019194667357*CF*NM*NC*Zeta[3])/
        2835 + (23565983746*CF*NC*NL*Zeta[3])/27 - 
       (189759608152651772329708342840589*CF*NC*NH*Zeta[3])/
        19148323098014662861575 + CF*Log[x]*
        ((-17227457771539338287734991697000145706294507*NM*NC)/
          4882192372389505629456000 + (30161409542899*lm*NM*NC)/72072 + 
         70109088*lm^2*NM*NC + (3023094189524647588417*NC*NL)/
          1753100949600 + (30161409542899*lm*NC*NL)/72072 + 
         70109088*lm^2*NC*NL + 
         (55484568118186446924075088992236319447582012148216133*NC*NH)/
          1609995516972642001525419261860533478640000 + 
         (30161409542899*lm*NC*NH)/72072 + 70109088*lm^2*NC*NH - 
         (3372885028047586622*NM*NC*Pi^2)/9 + (11778297068*NC*NL*Pi^2)/81 - 
         (26376992045786197189606661024*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CA*NC*
          (217249714254915977509425987173268196665653338191736370939918501/
            1173906200564755723692883742753044545768000000 - 
           (36592375966963*lm)/13104 - 385599984*lm^2 + 
           (69624198417618247056589*Pi^2)/2494800 + 
           (251314501477307179358280853247596*Im[PolyLog[2, (-1)^(1/3)]])/
            (78878483214455463063525*Sqrt[3]) - 210327264*Zeta[3]) + 
         CF*NC*
          (-124142694285570167387824712841134656111959504091912626334657397/
            335401771589930206769395355072298441648000000 + 
           (24055819396243*lm)/2002 + 2523927168*lm^2 - 
           (487369390690097653516159*Pi^2)/8731800 - 
           (502629002954614358716561706495192*Im[PolyLog[2, (-1)^(1/3)]])/
            (78878483214455463063525*Sqrt[3]) + 420654528*Zeta[3])), 
      (-873113027645344475936869693560100126786188966176451795045060172804704\
4191088838701*CF^2*NC)/
        8308159758630887108420906264686139486456292037794332332800000000 - 
       (2523391859727677707583*CF^2*lm*NC)/2189211864840 - 
       (26004550032*CF^2*lm^2*NC)/35 + 
       (4457477843956722281044727016082148108795961340625489179395107*CF*NM*
         NC)/8892327851245628803829825419256702856000000 - 
       (4488814019997337527311*CF*lm*NM*NC)/78811627134240 - 
       (722348612*CF*lm^2*NM*NC)/35 + (708109866795717010801115402*CF*NC*
         NL)/998457115573642725 - (4488814019997337527311*CF*lm*NC*NL)/
        78811627134240 - (722348612*CF*lm^2*NC*NL)/35 + 
       (1667865612336224864248898497422968557754403524419989490522954799327*
         CF*NC*NH)/
        46944908929480514442689133630431443479915401554296000000 - 
       (4488814019997337527311*CF*lm*NC*NH)/78811627134240 - 
       (722348612*CF*lm^2*NC*NH)/35 + (1153220495167957929247554213632426881*
         CF^2*NC*Pi^2)/1549830647594829600 + (6786800*CF^2*lm*NC*Pi^2)/7 - 
       (11677134518933123370072920*CF*NM*NC*Pi^2)/28945917 + 
       (1696700*CF*lm*NM*NC*Pi^2)/63 - (13459375351190987*CF*NC*NL*Pi^2)/
        289459170 + (1696700*CF*lm*NC*NL*Pi^2)/63 + 
       (1696700*CF*lm*NC*NH*Pi^2)/63 - (4282394612318818802626112348195857*
         CF^2*NC*Pi^3)/(7093268335432174539655440*Sqrt[3]) - 
       (182374049476956156600462631000*CF*NC*NH*Pi^3)/(36472996377170786403*
         Sqrt[3]) - (361828820033*CF^2*NC*Pi^4)/28350 + 
       (339872149391959434853552968533678093764811*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(42247151542417259949460817868000*
         Sqrt[3]) + (21187183873028091912859853540741332*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1277831428074178501629105*Sqrt[3]) - 
       (20919384104*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (4282394612318818802626112348195857*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(191562030663677553154275*
         Sqrt[3]) - (583596958326259701121480419200*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3151987341236981541*
         Sqrt[3]) - (4282394612318818802626112348195857*CF^2*NC*Pi*Log[3]^2)/
        (9194977471856522551405200*Sqrt[3]) - 
       (36474809895391231320092526200*CF*NC*NH*Pi*Log[3]^2)/
        (9455962023710944623*Sqrt[3]) - 
       (CF*NC*(CA*(155511783383191986280019200045923442396117 - 
            154841711679304129012874140800000*lm) + 
          2*(CF*(-155511782878296520514161761203949503479807 + 
              506754692768631694951224460800000*lm) + 
            20420400*(7*(589823241558042563089775321763949 + 
                98476588142761318776000*lm)*NM + 111053208534840*(
                8153281811 + 6207259800*lm)*NL + (165121119651174030510553 + 
                689336116999329231432000*lm)*NH)))*Log[x]^2)/
        34832443804693795260000 + (2*CF*NC*(-417609817928950180945810847*CA + 
          51*(16376855003611874805594069*CF - 4004000*
             (2177957110439729841*NM - 954735674*NL)))*Log[x]^3)/
        723647925 + (633612732134566890917182290290041681642109*CF^2*NC*
         PolyGamma[2, 1])/1608459140233231680372300 - 
       (40311730139931750231539*CF*NM*NC*PolyGamma[2, 1])/198450 - 
       (2079653040372189212683040463769379*CF*NC*NH*PolyGamma[2, 1])/
        1608459140233231680372300 - 
       (51157372109630472261327067648536249085960646*CF^2*NC*Zeta[3])/
        139648720353820936249466475 + (20671069644670022880061*CF*NM*NC*
         Zeta[3])/99225 - (182215117232*CF*NC*NL*Zeta[3])/189 + 
       (9312499990344299767622130664539421*CF*NC*NH*Zeta[3])/
        804229570116615840186150 + CA*CF*NC*(87311302689562627603064915261266\
59968681197237179226915495897781064436459241462701/
          16616319517261774216841812529372278972912584075588664665600000000 + 
         (3972917366*lm^2)/35 - (356824312349909873890124372909447*Pi^2)/
          959083293168000 + (4282394612318818802626112348195857*Pi^3)/
          (14186536670864349079310880*Sqrt[3]) + (363050444033*Pi^4)/56700 + 
         lm*(6558976546174784860943/14329386751680 - (9331850*Pi^2)/63) - 
         (339872149391959434853552968533678093764811*
           Im[PolyLog[2, (-1)^(1/3)]])/(84494303084834519898921635736000*
           Sqrt[3]) + (10459692052*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (4282394612318818802626112348195857*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(383124061327355106308550*
           Sqrt[3]) + (4282394612318818802626112348195857*Pi*Log[3]^2)/
          (18389954943713045102810400*Sqrt[3]) - 
         (633612732134566890917182290290041681642109*PolyGamma[2, 1])/
          3216918280466463360744600 + 
         (716203211990161118402860863814159073792737087*Zeta[3])/
          3910164169906986214985061300) + CF*Log[x]*
        ((-202677572773335381026917198613304521466588792853*NM*NC)/
          61579702666995383192532210000 - (21852423001336717*lm*NM*NC)/
          48243195 - 77768064*lm^2*NM*NC - (24595899359099372818957*NC*NL)/
          13038688312650 - (21852423001336717*lm*NC*NL)/48243195 - 
         77768064*lm^2*NC*NL - 
         (153473823391481724910449101511712215762540246910565779*NC*NH)/
          4226238232053185254004225562383900381430000 - 
         (21852423001336717*lm*NC*NH)/48243195 - 77768064*lm^2*NC*NH - 
         (58078856244671947184*NM*NC*Pi^2)/189 - (91077018016*NC*NL*Pi^2)/
          567 + (583596958326259701121480419200*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(9455962023710944623*Sqrt[3]) + 
         CF*NC*(3327793563384804090073708877635244224593857613732330653155931\
98464179/57534316795879242773911925116069466232635448000000 - 
           (69276089269778548*lm)/5360355 - 2799650304*lm^2 + 
           (13257454500908376747322247*Pi^2)/22972950 + 
           (4282394612318818802626112348195857*Im[PolyLog[2, (-1)^(1/3)]])/
            (574686091991032659462825*Sqrt[3]) - 466608384*Zeta[3]) + 
         CA*NC*(-332779356252293248252024524977696427380134870784483012584967\
548463279/115068633591758485547823850232138932465270896000000 + 
           (26627415571204237*lm)/8771490 + 427724352*lm^2 - 
           (417609816632208306701011751*Pi^2)/1447295850 - 
           (4282394612318818802626112348195857*Im[PolyLog[2, (-1)^(1/3)]])/
            (1149372183982065318925650*Sqrt[3]) + 233304192*Zeta[3])), 
      (5871922546932461378626567125358075834891204108296788593813831887833491\
62246340223*CF^2*NC)/
        339108561576770902384526786313719979039032328073238054400000000 + 
       (3357577538553078831*CF^2*lm*NC)/1891123520 + 
       (5529010032*CF^2*lm^2*NC)/5 + 
       (6944868353777063705056284390156639864176426495648081264309*CF*NM*NC)/
        714221688201811495945288830196416000000 + 
       (1961484697576313573*CF*lm*NM*NC)/22693482240 + 
       (153583612*CF*lm^2*NM*NC)/5 - (45000265024438403334751627*CF*NC*NL)/
        38640214903530240 + (1961484697576313573*CF*lm*NC*NL)/22693482240 + 
       (153583612*CF*lm^2*NC*NL)/5 - 
       (8168335807012338208615484337147281315855517699298536149981487626437*
         CF*NC*NH)/
        139493443676170671486847711358996289197462907475622400000 + 
       (1961484697576313573*CF*lm*NC*NH)/22693482240 + 
       (153583612*CF*lm^2*NC*NH)/5 - (224000731257039020879761046469213029*
         CF^2*NC*Pi^2)/337378100156697600 - 1592010*CF^2*lm*NC*Pi^2 - 
       (109225815990515583620799113*CF*NM*NC*Pi^2)/18378360 - 
       (88445*CF*lm*NM*NC*Pi^2)/2 + (384211534853489*CF*NC*NL*Pi^2)/
        5250960 - (88445*CF*lm*NC*NL*Pi^2)/2 - (88445*CF*lm*NC*NH*Pi^2)/2 + 
       (52332486758230679632282734993561281*CF^2*NC*Pi^3)/
        (56746146683457396317243520*Sqrt[3]) + 
       (617132621790159430295427943765*CF*NC*NH*Pi^3)/(72945992754341572806*
         Sqrt[3]) + (221083026269*CF^2*NC*Pi^4)/10800 - 
       (576533215582620473104700310551504556273889*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(48282458905619725656526648992000*
         Sqrt[3]) - (6080701277966429477446377149595638*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(182547346867739785947015*Sqrt[3]) + 
       (10731962983*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (7476069536890097090326104999080183*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(218928035044202917890600*
         Sqrt[3]) + (141058884980607869781812101432*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) + (7476069536890097090326104999080183*CF^2*NC*Pi*Log[3]^2)/
        (10508545682121740058748800*Sqrt[3]) + 
       (17632360622575983722726512679*CF*NC*NH*Pi*Log[3]^2)/
        (2701703435345984178*Sqrt[3]) + 
       CF*((-52861371985466819123076713426519516937211*CF*NC)/
          6634751200894056240000 + 
         CA*(52861372320122737729817237624338961331691/
            13269502401788112480000 - 7272927046*lm)*NC + 
         47604613392*CF*lm*NC - (83053125957975180442523507187617*NM*NC)/
          1164544781400 + 1322350372*lm*NM*NC + (15638046938*NC*NL)/9 + 
         1322350372*lm*NC*NL + (776597323772794714111*NC*NH)/
          2406725881560 + 1322350372*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-158517838550109493906163371*CA + 
          32*(9907364272328752221388316*CF + 11486475*
             (7064330181329259516*NM + 330587593*NL)))*Log[x]^3)/
        137837700 - (180706028692458775757948421741186424535177*CF^2*NC*
         PolyGamma[2, 1])/428922437395528448099280 - 
       (30887471899701903871627*CF*NM*NC*PolyGamma[2, 1])/9450 + 
       (42817289329877365095409435271137*CF*NC*NH*PolyGamma[2, 1])/
        16412848369726853881350 + CA*CF*NC*
        (-4110345778990063470012670569674821807337472148774952925683578995633\
255001915696811/
          4747519862074792633383375008392079706546452593025332761600000000 - 
         (844709866*lm^2)/5 + (412632925941043584241537291958085077*Pi^2)/
          1242971947945728000 - (52332486758230679632282734993561281*Pi^3)/
          (113492293366914792634487040*Sqrt[3]) - (221847191069*Pi^4)/21600 + 
         lm*(-2848663926628653797/4126087680 + (972895*Pi^2)/4) + 
         (576533215582620473104700310551504556273889*
           Im[PolyLog[2, (-1)^(1/3)]])/(96564917811239451313053297984000*
           Sqrt[3]) - (10731962983*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
         (7476069536890097090326104999080183*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(437856070088405835781200*
           Sqrt[3]) - (7476069536890097090326104999080183*Pi*Log[3]^2)/
          (21017091364243480117497600*Sqrt[3]) + 
         (180706028692458775757948421741186424535177*PolyGamma[2, 1])/
          857844874791056896198560 - 
         (1602791104518681308762087047339918399525649371*Zeta[3])/
          10427104453085296573293496800) + 
       (1602791092973169931919370596534003892781898143*CF^2*NC*Zeta[3])/
        5213552226542648286646748400 + (13617808188520700322623*CF*NM*NC*
         Zeta[3])/4725 + 1561045738*CF*NC*NL*Zeta[3] - 
       (143466157680780426912760500324263*CF*NC*NH*Zeta[3])/
        8206424184863426940675 + CF*Log[x]*
        ((-3642447133984443659495713620319171566639323537*NM*NC)/
          84082201968930374729520000 + (624558607325281*lm*NM*NC)/875160 + 
         119082348*lm^2*NM*NC + (38576828520918310717*NC*NL)/12614906304 + 
         (624558607325281*lm*NC*NL)/875160 + 119082348*lm^2*NC*NL + 
         (59343608160332352583026997728075343127945097042849743*NC*NH)/
          965997310183585200915251557116320087184000 + 
         (624558607325281*lm*NC*NH)/875160 + 119082348*lm^2*NC*NH - 
         4709553454520207716*NM*NC*Pi^2 + (780257534*NC*NL*Pi^2)/3 - 
         (141058884980607869781812101432*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1350851717672992089*Sqrt[3]) + CA*NC*(1130652614484460982076727251\
44877556484577046409862096168262064435063/
            65753504909576277455899342989793675694440512000000 - 
           (757197289821601*lm)/159120 - 654952914*lm^2 + 
           (211357117005611700176219429*Pi^2)/735134400 + 
           (7476069536890097090326104999080183*Im[PolyLog[2, (-1)^(1/3)]])/
            (1313568210265217507343600*Sqrt[3]) - 357247044*Zeta[3]) + 
         CF*NC*(-113065261524126609828178074323092067253561638834102045341973\
617746113/32876752454788138727949671494896837847220256000000 + 
           (498630810550501*lm)/24310 + 4286964528*lm^2 - 
           (634071351414053434753411471*Pi^2)/1102701600 - 
           (7476069536890097090326104999080183*Im[PolyLog[2, (-1)^(1/3)]])/
            (656784105132608753671800*Sqrt[3]) + 714494088*Zeta[3])), 
      (-383667494546647179869548577583478481479369512510532087839132418306301\
94739420167293*CF^2*NC)/
        2670479922417070856278148442220544834932379583576749678400000000 - 
       (21863495928051764071*CF^2*lm*NC)/11914078176 - 
       (5913817716*CF^2*lm^2*NC)/5 + 
       (8341949219098949437029169034957103901592332786640893251634273*CF*NM*
         NC)/1129184489047063975089501640540533696000000 - 
       (194453850932929454291*CF*lm*NM*NC)/2144534071680 - 
       (492818143*CF*lm^2*NM*NC)/15 + (246396719826596303354861699*CF*NC*
         NL)/190928120699796480 - (194453850932929454291*CF*lm*NC*NL)/
        2144534071680 - (492818143*CF*lm^2*NC*NL)/15 + 
       (92996013061591192637435430837836411053864289364852799919227484603*CF*
         NC*NH)/1485728985900042654889502251160907222221498422817280000 - 
       (194453850932929454291*CF*lm*NC*NH)/2144534071680 - 
       (492818143*CF*lm^2*NC*NH)/15 + (3597048347930721542466808392396528913*
         CF^2*NC*Pi^2)/372891584383718400 + 1465660*CF^2*lm*NC*Pi^2 - 
       (179364140052508163507876263*CF*NM*NC*Pi^2)/33081048 + 
       (366415*CF*lm*NM*NC*Pi^2)/9 - (4546367998655*CF*NC*NL*Pi^2)/58344 + 
       (366415*CF*lm*NC*NL*Pi^2)/9 + (366415*CF*lm*NC*NH*Pi^2)/9 - 
       (49300915273163347177116792256653029*CF^2*NC*Pi^3)/
        (46428665468283324259562880*Sqrt[3]) - 
       (11560686427841156575886985180035*CF*NC*NH*Pi^3)/
        (1313027869578148310508*Sqrt[3]) - (700618293817*CF^2*NC*Pi^4)/
        32400 + (3826611748176737059320796270432479284963347*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(276526810095822065123743535136000*
         Sqrt[3]) + (1072371494581553241427397439152581*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(36108266413399078538970*Sqrt[3]) - 
       (34866686459*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (7042987896166192453873827465236147*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(179122937763438751001400*
         Sqrt[3]) - (1321221306038989322958512592004*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) - (7042987896166192453873827465236147*CF^2*NC*Pi*Log[3]^2)/
        (8597901012645060048067200*Sqrt[3]) - 
       (330305326509747330739628148001*CF*NC*NH*Pi*Log[3]^2)/
        (48630661836227715204*Sqrt[3]) + 
       CF*((329149193477326012220416279080578285041889*CF*NC)/
          2843464800383166960000 - 51818135472*CF*lm*NC + 
         CA*(-2304044355371482244999354591579844864609563/
            39808507205364337440000 + 7916659586*lm)*NC - 
         (7046553415839126550676129753734507*NM*NC)/108302664670200 - 
         1439392652*lm*NM*NC - (357202032658*NC*NL)/189 - 
         1439392652*lm*NC*NL - (54225178019438457809*NC*NH)/151472258280 - 
         1439392652*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-3116026490160851145714360869*CA + 
          4*(1558013236842197080572294097*CF - 137837700*
             (6267676024718017310*NM - 359848163*NL)))*Log[x]^3)/
        206756550 + (149483189722724596373529921084296378253730877*CF^2*NC*
         PolyGamma[2, 1])/28952264524198170246701400 - 
       (2222296885004372424553709*CF*NM*NC*PolyGamma[2, 1])/793800 - 
       (65430871577237306091753736868268107*CF*NC*NH*PolyGamma[2, 1])/
        28952264524198170246701400 - 
       (667907490573100235513526565674346711215451772353*CF^2*NC*Zeta[3])/
        140765910116651503739462206800 + (1094557272246986104867291*CF*NM*NC*
         Zeta[3])/396900 - (5102184760*CF*NC*NL*Zeta[3])/3 + 
       (291717795086909774464268784466929493*CF*NC*NH*Zeta[3])/
        14476132262099085123350700 + CA*CF*NC*(153466997801209716124676131780\
158125685410053920882588831478580459754099451375576547/
          21363839379336566850225187537764358679459036668613997427200000000 + 
         (5420999573*lm^2)/30 - (5995080579827751311360118519432536327*Pi^2)/
          1242971947945728000 + (49300915273163347177116792256653029*Pi^3)/
          (92857330936566648519125760*Sqrt[3]) + (702728844217*Pi^4)/64800 + 
         lm*(56825454045104594935/77983057152 - (4030565*Pi^2)/18) - 
         (3826611748176737059320796270432479284963347*
           Im[PolyLog[2, (-1)^(1/3)]])/(553053620191644130247487070272000*
           Sqrt[3]) + (34866686459*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (7042987896166192453873827465236147*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(358245875526877502002800*
           Sqrt[3]) + (7042987896166192453873827465236147*Pi*Log[3]^2)/
          (17195802025290120096134400*Sqrt[3]) - 
         (149483189722724596373529921084296378253730877*PolyGamma[2, 1])/
          57904529048396340493402800 + 
         (667907490882636578941725077763951780061846925029*Zeta[3])/
          281531820233303007478924413600) + CF*Log[x]*
        ((-167502464244065902590165984952789808921264171971*NM*NC)/
          3909822391555262424922680000 - (21025185979945799*lm*NM*NC)/
          27567540 - 130423524*lm^2*NM*NC - (17149458269304992999*NC*NL)/
          5194373184 - (21025185979945799*lm*NC*NL)/27567540 - 
         130423524*lm^2*NC*NL - 
         (4276282774674370042259699130875794498494263972887007*NC*NH)/
          66876736858863590832594338569591390651200 - 
         (21025185979945799*lm*NC*NH)/27567540 - 130423524*lm^2*NC*NH - 
         (12535352048412371069*NM*NC*Pi^2)/3 - (850119850*NC*NL*Pi^2)/3 + 
         (1321221306038989322958512592004*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (12157665459056928801*Sqrt[3]) + 
         CF*NC*(2172097923355827972768672420350395060329974512267284415486964\
3518916377/295890772093093248551547043454071540624982304000000 - 
           (16680676991215889*lm)/765765 - 4695246864*lm^2 + 
           (24928211911879785879443331623*Pi^2)/3308104800 + 
           (7042987896166192453873827465236147*Im[PolyLog[2, (-1)^(1/3)]])/
            (537368813290316253004200*Sqrt[3]) - 782541144*Zeta[3]) + 
         CA*NC*(-217209792327731101317128365772699801526161121845741415422012\
36251417177/591781544186186497103094086908143081249964608000000 + 
           (25601220526068839*lm)/5012280 + 717329382*lm^2 - 
           (24928211910703836642572479751*Pi^2)/6616209600 - 
           (7042987896166192453873827465236147*Im[PolyLog[2, (-1)^(1/3)]])/
            (1074737626580632506008400*Sqrt[3]) + 391270572*Zeta[3])), 
      (7218913628083857502480801553132516385054614731435706916913734287825882\
41347838171*CF^2*NC)/
        39636065638843352226762871127577659887679103281287564800000000 + 
       (10599001410126970733*CF^2*lm*NC)/3797876160 + 
       (8691776632*CF^2*lm^2*NC)/5 + 
       (139864508159588363126342948084660870198272168699932710498987399*CF*
         NM*NC)/1129184489047063975089501640540533696000000 + 
       (18576488464317128237*CF*lm*NM*NC)/136723541760 + 
       (2172944158*CF*lm^2*NM*NC)/45 - (1477625742502910196220448241967*CF*
         NC*NL)/709434345628815206400 + (18576488464317128237*CF*lm*NC*NL)/
        136723541760 + (2172944158*CF*lm^2*NC*NL)/45 - 
       (323015447684794487125243958106875408899053056975788340853521187094294\
38119*CF*NC*NH)/
        317959263113808286027048370556025756652358989356321564224000000 + 
       (18576488464317128237*CF*lm*NC*NH)/136723541760 + 
       (2172944158*CF*lm^2*NC*NH)/45 - (15231708683233957380438913459751039*
         CF^2*NC*Pi^2)/2400318499138560 - (21403690*CF^2*lm*NC*Pi^2)/9 - 
       (2019436094845128663750712829*CF*NM*NC*Pi^2)/27567540 - 
       (10701845*CF*lm*NM*NC*Pi^2)/162 + (519486962165479*CF*NC*NL*Pi^2)/
        4296240 - (10701845*CF*lm*NC*NL*Pi^2)/162 - 
       (10701845*CF*lm*NC*NH*Pi^2)/162 + 
       (24746245964835992262644010666130763*CF^2*NC*Pi^3)/
        (15476221822761108086520960*Sqrt[3]) + 
       (19244867989766650630956752367655*CF*NC*NH*Pi^3)/
        (1313027869578148310508*Sqrt[3]) + (1105817180237*CF^2*NC*Pi^4)/
        32400 - (800837406038445188368593119021701342535681*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(39503830013688866446249076448000*
         Sqrt[3]) - (250324705400841481971680898493040561*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4296883703194490346137430*Sqrt[3]) + 
       (158863920677*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
       (3535177994976570323234858666590109*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59707645921146250333800*
         Sqrt[3]) + (2199413484544760072109343127732*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) + (3535177994976570323234858666590109*CF^2*NC*Pi*Log[3]^2)/
        (2865967004215020016022400*Sqrt[3]) + 
       (549853371136190018027335781933*CF*NC*NH*Pi*Log[3]^2)/
        (48630661836227715204*Sqrt[3]) + 
       CF*((-10599145570457289447727749688586344173061*CF*NC)/
          139190584634141040000 + 
         CA*(137788892576170179386034537687120377287633/
            3618955200487667040000 - (344034291601*lm)/27)*NC + 
         (250206757528*CF*lm*NC)/3 - (31734468900906905987431928341998647*NM*
           NC)/36100888223400 + (62551689382*lm*NM*NC)/27 + 
         (246521413465*NC*NL)/81 + (62551689382*lm*NC*NL)/27 + 
         (2347072645397165136730243*NC*NH)/4007198592797400 + 
         (62551689382*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-423623818081157926945010583*CA + 847247625897954884688732536*
           CF + 1856400*(4727226712718237292018*NM + 31275844691*NL))*
         Log[x]^3)/37592100 - (48467247144088331379581801010803288258044019*
         CF^2*NC*PolyGamma[2, 1])/11580905809679268098680560 - 
       (191752981462243906982783*CF*NM*NC*PolyGamma[2, 1])/4725 + 
       (36766585813172519069037439876922*CF*NC*NH*PolyGamma[2, 1])/
        8206424184863426940675 + CA*CF*NC*
        (-3537267677198758091010298889421160395373080068200628296644968223479\
5578709577185129/
          3884334432606648518222761370502610668992552121566181350400000000 - 
         (11951192869*lm^2)/45 + (3226717234131792037209053601504308893*Pi^2)/
          1016977048319232000 - (24746245964835992262644010666130763*Pi^3)/
          (30952443645522216173041920*Sqrt[3]) - (369747256879*Pi^4)/21600 + 
         lm*(-296770188631898511343/273447083520 + (117720295*Pi^2)/324) + 
         (800837406038445188368593119021701342535681*
           Im[PolyLog[2, (-1)^(1/3)]])/(79007660027377732892498152896000*
           Sqrt[3]) - (158863920677*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
         (3535177994976570323234858666590109*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(119415291842292500667600*
           Sqrt[3]) - (3535177994976570323234858666590109*Pi*Log[3]^2)/
          (5731934008430040032044800*Sqrt[3]) + 
         (48467247144088331379581801010803288258044019*PolyGamma[2, 1])/
          23161811619358536197361120 - 
         (37095130378256909777877800215862777448154978997*Zeta[3])/
          25593801839391182498084037600) + 
       (37095130329352592006637261887381464181399744441*CF^2*NC*Zeta[3])/
        12796900919695591249042018800 + (168003820130417775325034*CF*NM*NC*
         Zeta[3])/4725 + (73206446264*CF*NC*NL*Zeta[3])/27 - 
       (246058971464391252897215941282556*CF*NC*NH*Zeta[3])/
        8206424184863426940675 + CF*Log[x]*
        ((-256631815556548639831492548591864538165773029381*NM*NC)/
          488727798944407803115335000 + (848043297434927*lm*NM*NC)/716040 + 
         196913948*lm^2*NM*NC + (305164762580342310564361*NC*NL)/
          57902419935360 + (848043297434927*lm*NC*NL)/716040 + 
         196913948*lm^2*NC*NL + 
         (186279970337370766249736717809627280444307226129400367797*NC*NH)/
          1750301890995875479481884475769144087381480000 + 
         (848043297434927*lm*NC*NH)/716040 + 196913948*lm^2*NC*NH - 
         (1575742237587925925593*NM*NC*Pi^2)/27 + (36592521287*NC*NL*Pi^2)/
          81 - (2199413484544760072109343127732*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12157665459056928801*Sqrt[3]) + 
         CA*NC*(2603142481432328135438604334238966183604273824551951690892429\
61773069/17932774066248075669790729906307366098483776000000 - 
           (11302451958347077*lm)/1432080 - 1083026714*lm^2 + 
           (1694495270800231124981369261*Pi^2)/601473600 + 
           (3535177994976570323234858666590109*Im[PolyLog[2, (-1)^(1/3)]])/
            (358245875526877502002800*Sqrt[3]) - 590741844*Zeta[3]) + 
         CF*NC*(-260314248179566386116435185706381005481067337108306736661284\
696946719/8966387033124037834895364953153683049241888000000 + 
           (677670395916107*lm)/19890 + 7088902128*lm^2 - 
           (564831756995880076060264031*Pi^2)/100245600 - 
           (3535177994976570323234858666590109*Im[PolyLog[2, (-1)^(1/3)]])/
            (179122937763438751001400*Sqrt[3]) + 1181483688*Zeta[3])), 
      (-353643377878060451801201520346401049340773442484168767847601126037028\
9444476828228383*CF^2*NC)/
        18450588554881580461558116509887400677714622577439361414400000000 - 
       (10275488905173036700829*CF^2*lm*NC)/3598962396120 - 
       (9200250576*CF^2*lm^2*NC)/5 + 
       (4256365427620363265528722340003091912764231578910063816947427*CF*NM*
         NC)/40978469360578934579860946632519368000000 - 
       (18277399904166834490733*CF*lm*NM*NC)/129562646260320 - 
       (255562516*CF*lm^2*NM*NC)/5 + (1529330517880650613216887680370103*CF*
         NC*NL)/672277721776506009964800 - (18277399904166834490733*CF*lm*NC*
         NL)/129562646260320 - (255562516*CF*lm^2*NC*NL)/5 + 
       (426383632154619872498937111999809408531786814166332410319114861314888\
5631*CF*NC*NH)/
        39744907889226035753381046319503219581544873669540195528000000 - 
       (18277399904166834490733*CF*lm*NC*NH)/129562646260320 - 
       (255562516*CF*lm^2*NC*NH)/5 + 
       (1128186098841821995202219002633500233593*CF^2*NC*Pi^2)/
        9178217861081068800 + (58612400*CF^2*lm*NC*Pi^2)/27 - 
       (83688749985920411862121689857*CF*NM*NC*Pi^2)/1178512335 + 
       (14653100*CF*lm*NM*NC*Pi^2)/243 - (3896697413304509*CF*NC*NL*Pi^2)/
        30610710 + (14653100*CF*lm*NC*NL*Pi^2)/243 + 
       (14653100*CF*lm*NC*NH*Pi^2)/243 - 
       (30800064339480100902681447948965273*CF^2*NC*Pi^3)/
        (16964320074949676171763360*Sqrt[3]) - 
       (4951501269549407022672485059930*CF*NC*NH*Pi^3)/
        (328256967394537077627*Sqrt[3]) - (866847826889*CF^2*NC*Pi^4)/24300 + 
       (4049969453430866994197177031181811692619771*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(174521290987048541100824154168000*
         Sqrt[3]) + (1444390837263175635392948146846158032*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(27929744070764187249893295*Sqrt[3]) - 
       (170031130412*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (30800064339480100902681447948965273*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(458141360048795266984350*
         Sqrt[3]) - (2263543437508300353221707455968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) - (30800064339480100902681447948965273*CF^2*NC*Pi*Log[3]^2)/
        (21990785282342172815248800*Sqrt[3]) - 
       (141471464844268772076356715998*CF*NC*NH*Pi*Log[3]^2)/
        (12157665459056928801*Sqrt[3]) + 
       CF*((38033973853123539345629630350179105041453879*CF*NC)/
          25785055803474627660000 - (806818681280*CF*lm*NC)/9 + 
         CA*(-38033973855437688668521540527242088532698899/
            51570111606949255320000 + (1109375686760*lm)/81)*NC - 
         (478460539209535721308615910633899*NM*NC)/561476948175 - 
         (201704670320*lm*NM*NC)/81 - (1323827301584*NC*NL)/405 - 
         (201704670320*lm*NC*NL)/81 - (320966846774927331801247*NC*NH)/
          500899824099675 - (201704670320*lm*NC*NH)/81)*Log[x]^2 + 
       (2*CF*NC*(-17260612684828467797928977609*CA + 
          19*(1816906597038972288616968217*CF - 618800*
             (1678664235219872112732*NM - 12606541895*NL)))*Log[x]^3)/
        178562475 + (2886998468689142422256683672604919592539128183*CF^2*NC*
         PolyGamma[2, 1])/43428396786297255370052100 - 
       (14844419106123604368108817*CF*NM*NC*PolyGamma[2, 1])/396900 - 
       (83476901182014021063438306186142081*CF*NC*NH*PolyGamma[2, 1])/
        21714198393148627685026050 - 
       (11009577639988136814795006963789765415994379855259*CF^2*NC*Zeta[3])/
        182355838105662175298848767900 + (7090126905079121106059183*CF*NM*NC*
         Zeta[3])/198450 - (236301693088*CF*NC*NL*Zeta[3])/81 + 
       (370645945072481979974297660582217119*CF*NC*NH*Zeta[3])/
        10857099196574313842513025 + CA*CF*NC*(353643377872771270847050141729\
3447390449973903753911079955467536214585876393632492883/
          36901177109763160923116233019774801355429245154878722828800000000 + 
         (1405593838*lm^2)/5 - (5640930494202244937171130432937645012217*
           Pi^2)/91782178610810688000 + (30800064339480100902681447948965273*
           Pi^3)/(33928640149899352343526720*Sqrt[3]) + (869192322889*Pi^4)/
          48600 + lm*(293763195347970215860399/259125292520640 - 
           (80592050*Pi^2)/243) - 
         (4049969453430866994197177031181811692619771*
           Im[PolyLog[2, (-1)^(1/3)]])/(349042581974097082201648308336000*
           Sqrt[3]) + (85015565206*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (30800064339480100902681447948965273*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(916282720097590533968700*
           Sqrt[3]) + (30800064339480100902681447948965273*Pi*Log[3]^2)/
          (43981570564684345630497600*Sqrt[3]) - 
         (2886998468689142422256683672604919592539128183*PolyGamma[2, 1])/
          86856793572594510740104200 + 
         (11009577640671535281365483011014559753128369340057*Zeta[3])/
          364711676211324350597697535800) + CF*Log[x]*
        ((-38711715540291083845298106674840000100866171527*NM*NC)/
          70944357911285003678032500 - (6383499172402451*lm*NM*NC)/5101785 - 
         213200064*lm^2*NM*NC - (81186020942786891063199893*NC*NL)/
          14439415971380400 - (6383499172402451*lm*NC*NL)/5101785 - 
         213200064*lm^2*NC*NL - 
         (203720411740512063712966019770325258892489052181996670613*NC*NH)/
          1859695759183117696949502255504715592842822500 - 
         (6383499172402451*lm*NC*NH)/5101785 - 213200064*lm^2*NC*NH - 
         (4476437960535493630856*NM*NC*Pi^2)/81 - (118121540344*NC*NL*Pi^2)/
          243 + (2263543437508300353221707455968*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12157665459056928801*Sqrt[3]) + 
         CF*NC*(1046035567464558800867544938799304236826986735813679356790834\
133931911/1140812635910870885243383487343214137961579500000 - 
           (20276775728457644*lm)/566865 - 7675202304*lm^2 + 
           (138084901471573437060643340563*Pi^2)/1428499800 + 
           (30800064339480100902681447948965273*Im[PolyLog[2, (-1)^(1/3)]])/
            (1374424080146385800953050*Sqrt[3]) - 1279200384*Zeta[3]) + 
         CA*NC*(-585779917777232037847277035133377687775351215654496829565547\
87659472791/127771015222017539147258950582439983451696904000000 + 
           (85446303335626321*lm)/10203570 + 1172600352*lm^2 - 
           (19726414495815061328877623893*Pi^2)/408142800 - 
           (30800064339480100902681447948965273*Im[PolyLog[2, (-1)^(1/3)]])/
            (2748848160292771601906100*Sqrt[3]) + 639600192*Zeta[3]))}, 0, 
     39, 1]
 
CbarSeries["v", 2, 4, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-7*CA*(821720709728416982 + 4704891332198400*lm + 
           1765791498240000*lm^2 - 682953956555155425*Zeta[3]) + 
         18*CF*(-5930826120063236726 + 824359727923200*lm + 
           4494741995520000*lm^2 + 4934211211084691025*Zeta[3]) + 
         35*(2097152*(105634889 + 42612255*lm + 30618000*lm^2)*NL + 
           63*NM*(-7810628892506 + 1418482155520*lm + 1019215872000*lm^2 + 
             5900562966375*Zeta[3]) + 63*NH*(-7810628892506 + 
             1418482155520*lm + 1019215872000*lm^2 + 5900562966375*
              Zeta[3]))))/18689137217372160000, 
      -(CF*NC*(-28*CA*(822896932561466582 + 5587787081318400*lm + 
            1765791498240000*lm^2 - 682953956555155425*Zeta[3]) + 
          72*CF*(-5930620030131255926 + 3071730725683200*lm + 
            4494741995520000*lm^2 + 4934211211084691025*Zeta[3]) + 
          35*(2097152*(465151811 + 231685020*lm + 122472000*lm^2)*NL + 
            315*NM*(-3531864340554 + 1542472073216*lm + 815372697600*lm^2 + 
              3139070093775*Zeta[3]) + 63*NH*(-41988745126238 + 
              7712360366080*lm + 4076863488000*lm^2 + 31509153262125*Zeta[
                3]))))/18689137217372160000, 
      (CF*NC*(-121*CA*(694675260168379887471254 + 1408241393216992051200*lm + 
           392471881564815360000*lm^2 - 577312020354903441386625*Zeta[3]) + 
         154*CF*(-15419751956787098421295234 + 2234545039954516377600*lm + 
           2018426819476193280000*lm^2 + 12828263614007031047347875*
            Zeta[3]) + 5*(33554432*(219292103698259 + 119162189763540*lm + 
             51464923587000*lm^2)*NL + 3465*NH*(-6936615046088900546 + 
             1153945048597921792*lm + 498376992463257600*lm^2 + 
             5273094353965913475*Zeta[3]) + 3465*NM*
            (1153945048597921792*lm + 498376992463257600*lm^2 + 
             605*(-1321436906896282 + 2122365242583495*Zeta[3])))))/
       8231443596019394150400000, 
      -(CF*NC*(-121*CA*(568767741536851810210934 + 483007928816841523200*lm + 
            122517677313884160000*lm^2 - 472902019476751280012625*Zeta[3]) + 
          154*CF*(-13587979143342714884928034 + 920747037020494233600*lm + 
            630090911899975680000*lm^2 + 11304184455127191683545875*
             Zeta[3]) + 5*(8388608*(309026162283743 + 171558367471260*lm + 
              64263079188000*lm^2)*NL + 231*NM*(494187913953447446 + 
              6230025514443079680*lm + 2333670044073984000*lm^2 + 
              5156425652464461375*Zeta[3]) + 693*NH*(-14502783498233498358 + 
              2076675171481026560*lm + 777890014691328000*lm^2 + 
              11221100619236132625*Zeta[3]))))/1646288719203878830080000, 
      (CF*NC*(-3872*CA*(3399202314004648115183234798 + 
           1082629089862153666560000*lm + 255952579523782901760000*lm^2 - 
           2827122724215524818182133125*Zeta[3]) + 
         7*(2496*CF*(-26962718999713109795399784802 + 
             649259011733685534720000*lm + 371271873594937835520000*lm^2 + 
             22430692363283798829478117875*Zeta[3]) + 
           25*(268435456*(20802409424729773 + 11342707872596100*lm + 
               3835784877724800*lm^2)*NL + 1287*NH*(2365800279763111116800*
                lm + 800047135019394662400*lm^2 + 429*
                (-46494052033110299606 + 36605205731267798625*Zeta[3])) + 
             429*NM*(7097400839289333350400*lm + 2400141405058183987200*
                lm^2 + 143*(7691445992269474426 + 55476954166068059625*
                  Zeta[3]))))))/89031293934545767130726400000, 
      -(CF*NC*(-495616*CA*(160785491039129465961013622 + 
            18193517603703816192000*lm + 4090649801289891840000*lm^2 - 
            133745065413833005463228625*Zeta[3]) + 745472*CF*
           (-4333632676344102257896248014 + 35006258695597719552000*lm + 
            17801069464953815040000*lm^2 + 3605193657715525443546103125*
             Zeta[3]) + 25*(1073741824*(83757005568948641 + 43597288947352140*
               lm + 13732039738216800*lm^2)*NL + 3003*NM*
             (-13066614689740204759898 + 15588489029565410181120*lm + 
              4909978486764365414400*lm^2 + 36370720648789254102375*Zeta[
                3]) + 9009*NH*(-54845485605474542883762 + 
              5196163009855136727040*lm + 1636659495588121804800*lm^2 + 
              43851948361621830304875*Zeta[3]))))/
       178062587869091534261452800000, 
      (CF*NC*(-11*CA*(5350920718185188160385080076073626 + 
           196113502095399095132749824000*lm + 42808283232996971658608640000*
            lm^2 - 4451304881200868656047621214050375*Zeta[3]) + 
         14*CF*(-192023620902310949947215953555631374 + 
           462361150043617104129687552000*lm + 220156885198270139958558720000*
            lm^2 + 159746044916654788625896495310803125*Zeta[3]) + 
         25*(8589934592*(2733344274511951213 + 1319034327996244860*lm + 
             398683205554233600*lm^2)*NL + 15015*NM*
            (-3419851355158802628994306 + 754606633505855329271808*lm + 
             228082761148169013166080*lm^2 + 4454406165064402812139875*
              Zeta[3]) + 3003*NH*(-52553438779784163460350826 + 
             3773033167529276646359040*lm + 1140413805740845065830400*lm^2 + 
             42586632401143382374197375*Zeta[3]))))/
       48433023900392897319115161600000, 
      -(CF*NC*(-11*CA*(1903402525910578755836527196840602 + 
            19240692910065214942504550400*lm + 4202973177025171417989120000*
             lm^2 - 1583436323090044935467219827938375*Zeta[3]) + 
          10*(3003*NM*(-16979768994306185484858698 + 
              925171782958647198351360*lm + 279918293508169924608000*lm^2 + 
              16862620495662188703831375*Zeta[3]) + 
            9*CF*(-11850801390254962601350240614149162 + 
              7050289385774937775873720320*lm + 3362378541620137134391296000*
               lm^2 + 9858771702273531982881682034063775*Zeta[3]) + 
            4*(1073741824*(1524195763089689189 + 646871250175129980*lm + 
                195716190013344000*lm^2)*NL + 429*NH*(
                -33075932806898879844637834 + 1619050620177632597114880*lm + 
                489857013639297368064000*lm^2 + 27127441054302913880931375*
                 Zeta[3])))))/6919003414341842474159308800000, 
      (CF*NC*(-44*CA*(1188899296081239366396911134437567310994 + 
           2149390962953114338294593748992000*lm + 
           519447003769004056433834065920000*lm^2 - 
           989051676601431576459875607184798546875*Zeta[3]) + 
         49*(5304*CF*(-11347109059691215873248123565524780854 + 
             953674169321957573290622976000*lm + 
             575617697407706037233909760000*lm^2 + 
             9439743864464857088069115353169632625*Zeta[3]) + 
           25*(17179869184*(1872295106653293335099 + 565741057040069650740*
                lm + 197458253439365318400*lm^2)*NL + 51051*NH*
              (-8237533857525472018351415726 + 190385249103176800571228160*
                lm + 66449373438119023057305600*lm^2 + 
               6839680031030456703385417125*Zeta[3]) + 7293*NM*
              (1332696743722237603998597120*lm + 465145614066833161401139200*
                lm^2 + 17*(-8318017564882646239781537306 + 
                 7363020996306560155894698375*Zeta[3]))))))/
       7446480558637607177019317865676800000, 
      (CF*NC*(7*(25*(137438953472*(-89090250193082206381 + 
               124124845950751185540*lm + 9992329175282454000*lm^2)*NL + 
             2431*NM*(3170950568824513495939470543802 + 
               7017519098043792592711188480*lm + 564926065240046617755648000*
                lm^2 - 2679046070134645969199283216375*Zeta[3]) + 
             21879*NH*(42762746790184116104196901542 + 
               779724344227088065856798720*lm + 62769562804449624195072000*
                lm^2 - 36158506294470722881847753625*Zeta[3])) + 
           2448*CF*(207148334396293132674930087180839118122 + 
             5661816966649953868320866304000*lm + 
             504902670808291664619110400000*lm^2 - 
             172328221338753811317468374842920345375*Zeta[3])) - 
         88*CA*(-651050251562268681964503427671866592286 + 
           205706705019343981558622060544000*lm + 
           15020854456546677022418534400000*lm^2 + 
           541613629265422016431123106100042178125*Zeta[3])))/
       3723240279318803588509658932838400000, 
      -(CF*NC*(175*(274877906944*(3342924727360696638859121 + 
              2428001155551479056468920*lm + 498142254177693344419200*lm^2)*
             NL + 46189*NM*(4007257131217876985922503980774382 + 
              14449411671514947911529340600320*lm + 
              2964521859939171369110156083200*lm^2 - 
              3333134025070280835048919105957125*Zeta[3]) + 
            415701*NH*(5919493507586426735842825815358 + 
              1605490185723883101281037844480*lm + 
              329391317771019041012239564800*lm^2 - 
              5550517862370256553442427888125*Zeta[3])) + 
          1368*CF*(68283668699264634519218215470033768186645242 + 
            2311606529017247578226873270796288000*lm + 
            630590856132310989851844075847680000*lm^2 - 
            56805685895520616759266370368559686564252375*Zeta[3]) - 
          308*CA*(-4481031069519583269401828682533199486601226 + 
            2630238305481212678719182339047424000*lm + 
            427900938089782457399465622896640000*lm^2 + 
            3727805387274265487588873428828205487531375*Zeta[3])))/
       43010871706690819054463579992149196800000, 
      (CF*NC*(1976*CF*(102682933074871617842373918723452627552613122 + 
           2222041081264660750703376168124416000*lm + 
           686559576469666491993783659397120000*lm^2 - 
           85422687737609715079389548948415804535819875*Zeta[3]) - 
         44*CA*(-62700017835115448044545369367272534256405622 + 
           26932859417745264271788725011218432000*lm + 
           4710561538555767320068460107530240000*lm^2 + 
           52160636352623372884060375447939904215052625*Zeta[3]) + 
         1225*(1374389534720*(178048156360678575194623 + 
             99488055436915645668168*lm + 22382919897818402482560*lm^2)*NL + 
           46189*NM*(1179184359091874936000807729919386 + 
             2960344285915262520551685488640*lm + 
             666021149278782050511146188800*lm^2 - 
             977645888032414444374639591858375*Zeta[3]) + 
           415701*NH*(328927142879473613394631720960*lm + 
             74002349919864672279016243200*lm^2 + 
             46189*(-51009653997795490503443614 + 40153679903952630364474125*
                Zeta[3])))))/43010871706690819054463579992149196800000, 
      -(CF*NC*(-256*CA*(-63025411018806006466422470733083672820095991386 + 
            15746203860945415094412675429191752089600*lm + 
            2869331086023585962686307019490590720000*lm^2 + 
            52431322193092587117337274232534571478326182375*Zeta[3]) + 
          5*(512*CF*(501388109510860680472251208756725313655688223214 + 
              5646907333745803585203508798860212305920*lm + 
              1878107619942710811940128230939295744000*lm^2 - 
              417108461740131147751053540089377065111091832325*Zeta[3]) + 
            231*(2199023255552*(452493155458822677371497447 + 
                221639524381450772146269720*lm + 52583093554894001203104000*
                 lm^2)*NL + 12597*NM*(
                28540602191862138461219833665523219394 + 
                38690995353202727319672477733355520*lm + 
                9179284399148876347378356977664000*lm^2 - 
                23676118184016946179737741842855423875*Zeta[3]) + 
              4199*NH*(116072986059608181959017433200066560*lm + 
                27537853197446629042135070932992000*lm^2 + 
                4199*(-415654515618119625451489345040662 + 
                  337994836288082208097181913218625*Zeta[3]))))))/
       130581006501513326649351428856164961484800000, 
      (CF*NC*(32*CF*(80564159289708828874453778460142787457431772168694 + 
           419282868134793318578102088311865606144000*lm + 
           150868062433345449685460004843332567040000*lm^2 - 
           67021917876633591595201409451179556637994961332625*Zeta[3]) - 
         208*CA*(-144617425411064663029169616885061427356125235634 + 
           18652889786451807839084335335355711488000*lm + 
           3546044202493162278931752250591150080000*lm^2 + 
           120308324707477443687594292601981347864526656875*Zeta[3]) + 
         75075*(1099511627776*(14642342779501506135760627 + 
             6478090073261267319298440*lm + 1624611873458393906486400*lm^2)*
            NL + 969*NM*(11637069749388196288222712837938866358 + 
             7350604088060932015659958413557760*lm + 
             1843425846739376279392632805785600*lm^2 - 
             9664620566921085754169087483792840625*Zeta[3]) + 
           4199*NH*(-40086793072986063845235869587903906 + 
             1696293251090984311306144249282560*lm + 
             425405964632163756782915262873600*lm^2 + 
             32918550623057579172339379475617875*Zeta[3]))))/
       130581006501513326649351428856164961484800000, 
      -(CF*NC*(92*CF*(65861379521141023193381058699606353000349709590798322 + 
            143794487007255169393677413744075631230976000*lm + 
            57557430065795970156601205980900330831872000*lm^2 - 
            54790567136530842636554156411514503379268849887580875*Zeta[3]) - 
          2*CA*(-32927440903178845662046954358018481466822133635621186 + 
            2014146769732951017323618546708669811130368000*lm + 
            404500827962399456933891808699105102790656000*lm^2 + 
            27392583311147318008651931622326534983471335606439875*Zeta[3]) + 
          5775*(61572651155456*(3814894509809255228328259823 + 
              1533288860995828097284592040*lm + 413663192100483550366901760*
               lm^2)*NL + 66861*NM*
             (5366139435771528850155333677551544813546 + 
              1412013881913859934267595250561187840*lm + 
              380944637726858045335171996015656960*lm^2 - 
              4460303337217043565689189989961456109375*Zeta[3]) + 
            7429*NH*(12708124937224739408408357255050690560*lm + 
              3428501739541722408016547964140912640*lm^2 + 
              7429*(-60001505048793017872305856898084846 + 
                49522614084526746040638524964325125*Zeta[3])))))/
       157891091289829828108587213405511462001049600000, 
      (CF*NC*(-5*CA*(-7390227867732221030634893101496415222233259825578998 + 
           198491468287868708838185909380306310686310400*lm + 
           43086549993050952158977459989609640781414400*lm^2 + 
           6147985291099914806770179396940968876496088237665425*Zeta[3]) + 
         7*(46*CF*(11300132122370293722484603565661873731509184728372466 + 
             9309092468000474360588846998308563976192000*lm + 
             4379208920806985538461853640954113687552000*lm^2 - 
             9400663221667061127727942582812092713083530008588875*Zeta[3]) + 
           525*(21990232555520*(4461725369937953087979617041 + 
               1615987497830375430829956888*lm + 484687556417492133278436864*
                lm^2)*NL + 74290*NM*
              (4847565632445977590327334916204535426954 + 
               478340838391477011250247191435935744*lm + 
               143470077835339510163049900599672832*lm^2 - 
               4031156346341059403194147734965404928175*Zeta[3]) + 
             22287*NH*(1594469461304923370834157304786452480*lm + 
               478233592784465033876833001998909440*lm^2 + 7429*
                (-11289954749845261514989756875556874 + 
                 9347446303815049345094828180907375*Zeta[3]))))))/
       50238074501309490761823204265390010636697600000}, 0, 16, 1]

CbarTable["v", 2, -1] = {{0., 0.000038580246913580246*CF*NC*
       (-3.*CA*(5160.430157209292 + 198.04533104651125*lm + 7140.*lm^2 + 
          1320.*lm^3) + 2.*(CF*(-135.93938964079425 + 116.1865557539944*lm + 
            5670.*lm^2 - 3240.*lm^3) - 
          15.*((-288.8434648794611 - 83.04316479128514*lm - 84.*lm^2 - 
              24.*lm^3)*NM + (-288.8434648794611 - 83.04316479128514*lm - 
              84.*lm^2 - 24.*lm^3)*NL - 1.*(-114.9438057198067 + 
              83.04316479128514*lm + 84.*lm^2 + 24.*lm^3)*NH)))}, 
     {0.005, CF*NC*(CF*(0.01558513398902728 + 0.022629959009972937*lm + 
          0.4368839555486113*lm^2 - 0.24750625*lm^3) + 
        CA*(-0.5664774200036408 - 0.003356097763197313*lm - 
          0.8158552042480709*lm^2 - 0.15125381944444444*lm^3) + 
        0.32733325531830904*NM + 0.09217020295303943*lm*NM + 
        0.09583598410570986*lm^2*NM + 0.027500694444444446*lm^3*NM + 
        0.32735256979168037*NL + 0.09217020295303943*lm*NL + 
        0.09583598410570986*lm^2*NL + 0.027500694444444446*lm^3*NL - 
        0.12972238143883777*NH + 0.09217020295303943*lm*NH + 
        0.09583598410570986*lm^2*NH + 0.027500694444444446*lm^3*NH)}, 
     {0.01, CF*NC*(CF*(0.040455436970460626 + 0.03602049392769377*lm + 
          0.436280002192214*lm^2 - 0.245025*lm^3) + 
        CA*(-0.536329482279015 + 0.01601206510541221*lm - 
          0.8053688181047581*lm^2 - 0.1497375*lm^3) + 0.32043677262231235*
         NM + 0.08826478246883106*lm*NM + 0.09445569420086511*lm^2*NM + 
        0.027225*lm^3*NM + 0.32050850824036714*NL + 0.08826478246883106*lm*
         NL + 0.09445569420086511*lm^2*NL + 0.027225*lm^3*NL - 
        0.1264272935503567*NH + 0.08826478246883106*lm*NH + 
        0.09445569420086511*lm^2*NH + 0.027225*lm^3*NH)}, 
     {0.015, CF*NC*(CF*(0.06390161331279477 + 0.04906233220384228*lm + 
          0.4356812249033566*lm^2 - 0.24255625*lm^3) + 
        CA*(-0.5070050486652662 + 0.035117010335685525*lm - 
          0.7949339563090598*lm^2 - 0.14822881944444444*lm^3) + 
        0.3136522436280296*NM + 0.08440945562952411*lm*NM + 
        0.0930821208440715*lm^2*NM + 0.026950694444444444*lm^3*NM + 
        0.3138034831347268*NL + 0.08440945562952411*lm*NL + 
        0.0930821208440715*lm^2*NL + 0.026950694444444444*lm^3*NL - 
        0.12315443904339582*NH + 0.08440945562952411*lm*NH + 
        0.0930821208440715*lm^2*NH + 0.026950694444444444*lm^3*NH)}, 
     {0.02, CF*NC*(CF*(0.08585765307317896 + 0.06171090391018802*lm + 
          0.4350820131386465*lm^2 - 0.2401*lm^3) + 
        CA*(-0.4785911992835258 + 0.05391513666436514*lm - 
          0.7845540475263827*lm^2 - 0.1467277777777778*lm^3) + 
        0.30699626988511974*NM + 0.08061135652735234*lm*NM + 
        0.09171588742903929*lm^2*NM + 0.02667777777777778*lm^3*NM + 
        0.3072496161471598*NL + 0.08061135652735234*lm*NL + 
        0.09171588742903929*lm^2*NL + 0.02667777777777778*lm^3*NL - 
        0.11990617926838798*NH + 0.08061135652735234*lm*NH + 
        0.09171588742903929*lm^2*NH + 0.02667777777777778*lm^3*NH)}, 
     {0.025, CF*NC*(CF*(0.10631672581015288 + 0.07393681308401141*lm + 
          0.4344775759399185*lm^2 - 0.23765625*lm^3) + 
        CA*(-0.4511351562853828 + 0.07237450626402925*lm - 
          0.7742320195644943*lm^2 - 0.145234375*lm^3) + 
        0.30047850872667237*NM + 0.07687561453079332*lm*NM + 
        0.0903575262844535*lm^2*NM + 0.02640625*lm^3*NM + 
        0.30085299440123664*NL + 0.07687561453079332*lm*NL + 
        0.0903575262844535*lm^2*NL + 0.02640625*lm^3*NL - 
        0.11668453955459814*NH + 0.07687561453079332*lm*NH + 
        0.0903575262844535*lm^2*NH + 0.02640625*lm^3*NH)}, 
     {0.03, CF*NC*(CF*(0.12530182127743314 + 0.0857202927030997*lm + 
          0.43386372725769423*lm^2 - 0.235225*lm^3) + 
        CA*(-0.4246612208801571 + 0.09047082997679144*lm - 
          0.7639704305647425*lm^2 - 0.14374861111111112*lm^3) + 
        0.2941045942353024*NM + 0.07320605388377893*lm*NM + 
        0.08900750252692285*lm^2*NM + 0.02613611111111111*lm^3*NM + 
        0.29461631365179725*NL + 0.07320605388377893*lm*NL + 
        0.08900750252692285*lm^2*NL + 0.02613611111111111*lm^3*NL - 
        0.11349129462703932*NH + 0.07320605388377893*lm*NH + 
        0.08900750252692285*lm^2*NH + 0.02613611111111111*lm^3*NH)}, 
     {0.035, CF*NC*(CF*(0.14285245941517885 + 0.09704828418118791*lm + 
          0.43323676056402455*lm^2 - 0.23280625*lm^3) + 
        CA*(-0.39917902682384926 + 0.1081853168489714*lm - 
          0.7537715456275406*lm^2 - 0.14227048611111112*lm^3) + 
        0.2878775659545826*NM + 0.06960556696787441*lm*NM + 
        0.08766622799288616*lm^2*NM + 0.025867361111111112*lm^3*NM + 
        0.288540147133707*NL + 0.06960556696787441*lm*NL + 
        0.08766622799288616*lm^2*NL + 0.025867361111111112*lm^3*NL - 
        0.11032801851072618*NH + 0.06960556696787441*lm*NH + 
        0.08766622799288616*lm^2*NH + 0.025867361111111112*lm^3*NH)}, 
     {0.04, CF*NC*(CF*(0.1590176297729148 + 0.10791266186875846*lm + 
          0.4325933657099287*lm^2 - 0.2304*lm^3) + 
        CA*(-0.37468824454810407 + 0.1255033466046701*lm - 
          0.7436373876217103*lm^2 - 0.1408*lm^3) + 0.28179868631989946*NM + 
        0.06607634391318533*lm*NM + 0.08633407047667459*lm^2*NM + 
        0.0256*lm^3*NM + 0.28262365896205577*NL + 0.06607634391318533*lm*
         NL + 0.08633407047667459*lm^2*NL + 0.0256*lm^3*NL - 
        0.1071961176723827*NH + 0.06607634391318533*lm*NH + 
        0.08633407047667459*lm^2*NH + 0.0256*lm^3*NH)}, 
     {0.045, CF*NC*(CF*(0.17385167624358244 + 0.11830905649380934*lm + 
          0.4319305693912572*lm^2 - 0.22800625*lm^3) + 
        CA*(-0.35118152462745983 + 0.142413576996117*lm - 
          0.7335697735664539*lm^2 - 0.13933715277777778*lm^3) + 
        0.2758679541011062*NM + 0.0626200264793256*lm*NM + 
        0.08501136034541587*lm^2*NM + 0.025334027777777778*lm^3*NM + 
        0.2768650447312624*NL + 0.0626200264793256*lm*NL + 
        0.08501136034541587*lm^2*NL + 0.025334027777777778*lm^3*NL - 
        0.10409685481440628*NH + 0.0626200264793256*lm*NH + 
        0.08501136034541587*lm^2*NH + 0.025334027777777778*lm^3*NH)}, 
     {0.05, CF*NC*(CF*(0.1874117516226072 + 0.12823602878192605*lm + 
          0.431245690238077*lm^2 - 0.225625*lm^3) + 
        CA*(-0.3286464585453007 + 0.15890730780442103*lm - 
          0.7235703420767308*lm^2 - 0.13788194444444443*lm^3) + 
        0.27008444771580076*NM + 0.05923781734064855*lm*NM + 
        0.08369839552910255*lm^2*NM + 0.025069444444444443*lm^3*NM + 
        0.27126182126175474*NL + 0.05923781734064855*lm*NL + 
        0.08369839552910255*lm^2*NL + 0.025069444444444443*lm^3*NL - 
        0.10103136688938583*NH + 0.05923781734064855*lm*NH + 
        0.08369839552910255*lm^2*NH + 0.025069444444444443*lm^3*NH)}, 
     {0.055, CF*NC*(CF*(0.1997561797139207 + 0.13769446410983266*lm + 
          0.43053630362988254*lm^2 - 0.22325625*lm^3) + 
        CA*(-0.30706694478409013 + 0.17497800828332735*lm - 
          0.7136405748650718*lm^2 - 0.136434375*lm^3) + 
        0.2644465652986506*NM + 0.055930561029937056*lm*NM + 
        0.08239544543001305*lm^2*NM + 0.02480625*lm^3*NM + 
        0.2658110258720564*NL + 0.055930561029937056*lm*NL + 
        0.08239544543001305*lm^2*NL + 0.02480625*lm^3*NL - 
        0.09800067927656295*NH + 0.055930561029937056*lm*NH + 
        0.08239544543001305*lm^2*NH + 0.02480625*lm^3*NH)}, 
     {0.06, CF*NC*(CF*(0.21094337386820802 + 0.14668711475905377*lm + 
          0.42980021332785356*lm^2 - 0.2209*lm^3) + 
        CA*(-0.2864241730755986 + 0.19062095468609797*lm - 
          0.7037818140774228*lm^2 - 0.13499444444444444*lm^3) + 
        0.258952198287004*NM + 0.052698805831007306*lm*NM + 
        0.08110275407468294*lm^2*NM + 0.024544444444444445*lm^3*NM + 
        0.26050935806374714*NL + 0.052698805831007306*lm*NL + 
        0.08110275407468294*lm^2*NL + 0.024544444444444445*lm^3*NL - 
        0.09500571727100725*NH + 0.052698805831007306*lm*NH + 
        0.08110275407468294*lm^2*NH + 0.024544444444444445*lm^3*NH)}, 
     {0.065, CF*NC*(CF*(0.22103111209856155 + 0.1552182450939385*lm + 
          0.42903542808270156*lm^2 - 0.21855625*lm^3) + 
        CA*(-0.26669735207944173 + 0.20583294520274326*lm - 
          0.693995276588349*lm^2 - 0.13356215277777778*lm^3) + 
        0.2535988602048282*NM + 0.049542852300321655*lm*NM + 
        0.07982054271303315*lm^2*NM + 0.02428402777777778*lm^3*NM + 
        0.2553532828459744*NL + 0.049542852300321655*lm*NL + 
        0.07982054271303315*lm^2*NL + 0.02428402777777778*lm^3*NL - 
        0.09204731561261552*NH + 0.049542852300321655*lm*NH + 
        0.07982054271303315*lm^2*NH + 0.02428402777777778*lm^3*NH)}, 
     {0.07, CF*NC*(CF*(0.23007604861931208 + 0.16329335101953046*lm + 
          0.428240141992992*lm^2 - 0.216225*lm^3) + 
        CA*(-0.247864258357066 + 0.2206120712293837*lm - 0.6842820660042827*
           lm^2 - 0.1321375*lm^3) + 0.24838378415280538*NM + 
        0.04646279207676644*lm*NM + 0.07854901200077867*lm^2*NM + 
        0.024025*lm^3*NM + 0.25033910757258754*NL + 0.04646279207676644*lm*
         NL + 0.07854901200077867*lm^2*NL + 0.024025*lm^3*NL - 
        0.08912622653776106*NH + 0.04646279207676644*lm*NH + 
        0.07854901200077867*lm^2*NH + 0.024025*lm^3*NH)}, 
     {0.075, CF*NC*(CF*(0.2381333863662115 + 0.17091893456513746*lm + 
          0.42741271776577516*lm^2 - 0.21390625*lm^3) + 
        CA*(-0.22990165720343606 + 0.23495753079060422*lm - 
          0.6746431828931374*lm^2 - 0.13072048611111112*lm^3) + 
        0.24330399779610695*NM + 0.04345853943767679*lm*NM + 
        0.07728834385935832*lm^2*NM + 0.02376736111111111*lm^3*NM + 
        0.24546303995178287*NL + 0.04345853943767679*lm*NL + 
        0.07728834385935832*lm^2*NL + 0.02376736111111111*lm^3*NL - 
        0.08624312668725813*NH + 0.04345853943767679*lm*NH + 
        0.07728834385935832*lm^2*NH + 0.02376736111111111*lm^3*NH)}, 
     {0.08, CF*NC*(CF*(0.24525666143348415 + 0.17810232033637666*lm + 
          0.4265516722727947*lm^2 - 0.2116*lm^3) + 
        CA*(-0.21278562936306195 + 0.24886947424353426*lm - 
          0.6650795336110699*lm^2 - 0.1293111111111111*lm^3) + 
        0.23835638178027177*NM + 0.04052985731008381*lm*NM + 
        0.07603870308080059*lm^2*NM + 0.02351111111111111*lm^3*NM + 
        0.24072123235006884*NL + 0.04052985731008381*lm*NL + 
        0.07603870308080059*lm^2*NL + 0.02351111111111111*lm^3*NL - 
        0.08339862310892081*NH + 0.04052985731008381*lm*NH + 
        0.07603870308080059*lm^2*NH + 0.02351111111111111*lm^3*NH)}, 
     {0.085, CF*NC*(CF*(0.25149760657949416 + 0.18485150439180933*lm + 
          0.42565566395620386*lm^2 - 0.20930625*lm^3) + 
        CA*(-0.1964918272218588 + 0.2623488751913524*lm - 
          0.6555919379989865*lm^2 - 0.127909375*lm^3) + 
        0.2335377156967591*NM + 0.03767637895997669*lm*NM + 
        0.07480023872708846*lm^2*NM + 0.02325625*lm^3*NM + 
        0.23610981591890787*NL + 0.03767637895997669*lm*NL + 
        0.07480023872708846*lm^2*NL + 0.02325625*lm^3*NL - 
        0.08059325852962837*NH + 0.03767637895997669*lm*NH + 
        0.07480023872708846*lm^2*NH + 0.02325625*lm^3*NH)}, 
     {0.09, CF*NC*(CF*(0.2569060712715862 + 0.19117502865031452*lm + 
          0.42472348174811353*lm^2 - 0.207025*lm^3) + 
        CA*(-0.18099567724933588 + 0.27539742141425305*lm - 
          0.6461811361539306*lm^2 - 0.12651527777777777*lm^3) + 
        0.22884471453583094*NM + 0.03489762625610348*lm*NM + 
        0.07357308536132072*lm^2*NM + 0.023002777777777778*lm^3*NM + 
        0.23162492703674378*NL + 0.03489762625610348*lm*NL + 
        0.07357308536132072*lm^2*NL + 0.023002777777777778*lm^3*NL - 
        0.0778275160283409*NH + 0.03489762625610348*lm*NH + 
        0.07357308536132072*lm^2*NH + 0.023002777777777778*lm^3*NH)}, 
     {0.095, CF*NC*(CF*(0.26152998250114545 + 0.19708187569005242*lm + 
          0.4237540352462554*lm^2 - 0.20475625*lm^3) + 
        CA*(-0.16627254087916482 + 0.28801742192560664*lm - 
          0.6368477944328439*lm^2 - 0.12512881944444446*lm^3) + 
        0.22427405776631687*NM + 0.03219302517955077*lm*NM + 
        0.07235736413930495*lm^2*NM + 0.022750694444444445*lm^3*NM + 
        0.22726272786586588*NL + 0.03219302517955077*lm*NL + 
        0.07235736413930495*lm^2*NL + 0.022750694444444445*lm^3*NL - 
        0.07510182321086388*NH + 0.03219302517955077*lm*NH + 
        0.07235736413930495*lm^2*NH + 0.022750694444444445*lm^3*NH)}, 
     {0.1, CF*NC*(CF*(0.26541533514116844 + 0.202581380037457*lm + 
          0.4227463459444111*lm^2 - 0.2025*lm^3) + 
        CA*(-0.1522978428510928 + 0.30021172718176387*lm - 
          0.6275925108117488*lm^2 - 0.12375*lm^3) + 0.21982241262994107*NM + 
        0.0295619190909108*lm*NM + 0.07115318378395433*lm^2*NM + 
        0.0225*lm^3*NM + 0.22301942234756375*NL + 0.0295619190909108*lm*
         NL + 0.07115318378395433*lm^2*NL + 0.0225*lm^3*NL - 
        0.07241655596503856*NH + 0.0295619190909108*lm*NH + 
        0.07115318378395433*lm^2*NH + 0.0225*lm^3*NH)}, 
     {0.105, CF*NC*(CF*(0.26860620373568606 + 0.20768315293656417*lm + 
          0.42169953935787197*lm^2 - 0.20025625*lm^3) + 
        CA*(-0.13904717380410692 + 0.3119836601403465*lm - 
          0.6184158196979671*lm^2 - 0.12237881944444444*lm^3) + 
        0.2154864528477285*NM + 0.027003580151566255*lm*NM + 
        0.06996064146023645*lm^2*NM + 0.022250694444444444*lm^3*NM + 
        0.21889126862489044*NL + 0.027003580151566255*lm*NL + 
        0.06996064146023645*lm^2*NL + 0.022250694444444444*lm^3*NL - 
        0.06977204185873194*NH + 0.027003580151566255*lm*NH + 
        0.06996064146023645*lm^2*NH + 0.022250694444444444*lm^3*NH)}, 
     {0.11, CF*NC*(CF*(0.27114476979044194 + 0.21239701824399906*lm + 
          0.4206128379154708*lm^2 - 0.198025*lm^3) + 
        CA*(-0.12649637230434368 + 0.3233369563533877*lm - 
          0.609318196273879*lm^2 - 0.12101527777777778*lm^3) + 
        0.2112628736547526*NM + 0.02451721921067939*lm*NM + 
        0.06877982356494769*lm^2*NM + 0.022002777777777777*lm^3*NM + 
        0.2148745886431982*NL + 0.02451721921067939*lm*NL + 
        0.06877982356494769*lm^2*NL + 0.022002777777777777*lm^3*NL - 
        0.06716856323076441*NH + 0.02451721921067939*lm*NH + 
        0.06877982356494769*lm^2*NH + 0.022002777777777777*lm^3*NH)}, 
     {0.115, CF*NC*(CF*(0.273071360184207 + 0.21673295758416558*lm + 
          0.41948555451362424*lm^2 - 0.19580625*lm^3) + 
        CA*(-0.11462159031555462 + 0.3342757116503495*lm - 
          0.6003000604361185*lm^2 - 0.119659375*lm^3) + 
        0.20714840387321276*NM + 0.022101994405821078*lm*NM + 
        0.06761080644293063*lm^2*NM + 0.02175625*lm^3*NM + 
        0.2109657755044731*NL + 0.022101994405821078*lm*NL + 
        0.06761080644293063*lm^2*NL + 0.02175625*lm^3*NL - 
        0.06460636001557987*NH + 0.022101994405821078*lm*NH + 
        0.06761080644293063*lm^2*NH + 0.02175625*lm^3*NH)}, 
     {0.12, CF*NC*(CF*(0.2744244934381353 + 0.22070106327010267*lm + 
          0.41831708664634576*lm^2 - 0.1936*lm^3) + 
        CA*(-0.1033993452461863 + 0.3448043362467395*lm - 
          0.5913617803827886*lm^2 - 0.11831111111111112*lm^3) + 
        0.20313981558021224*NM + 0.01975701867675952*lm*NM + 
        0.06645365703929491*lm^2*NM + 0.021511111111111113*lm^3*NM + 
        0.2071612990227426*NL + 0.01975701867675952*lm*NL + 
        0.06645365703929491*lm^2*NL + 0.021511111111111113*lm^3*NL - 
        0.062085632335239664*NH + 0.01975701867675952*lm*NH + 
        0.06645365703929491*lm^2*NH + 0.021511111111111113*lm^3*NH)}, 
     {0.125, CF*NC*(CF*(0.2752409313973137 + 0.22431149778051185*lm + 
          0.4171069110397331*lm^2 - 0.19140625*lm^3) + 
        CA*(-0.09280656104877721 + 0.35492751433066005*lm - 
          0.5825036758923854*lm^2 - 0.1169704861111111*lm^3) + 
        0.19923393181061627*NM + 0.017481366354601024*lm*NM + 
        0.06530843349558521*lm^2*NM + 0.021267361111111112*lm^3*NM + 
        0.2034577098313187*NL + 0.017481366354601024*lm*NL + 
        0.06530843349558521*lm^2*NL + 0.021267361111111112*lm^3*NL - 
        0.059606542886656746*NH + 0.017481366354601024*lm*NH + 
        0.06530843349558521*lm^2*NH + 0.021267361111111112*lm^3*NH)}, 
     {0.13, CF*NC*(CF*(0.2755557344820353 + 0.22757445880519606*lm + 
          0.4158545787309884*lm^2 - 0.189225*lm^3) + 
        CA*(-0.08282060034512435 + 0.3646501683488308*lm - 
          0.5737260213310627*lm^2 - 0.1156375*lm^3) + 0.19542763264670127*
         NM + 0.015274078959344359*lm*NM + 0.06417518569655685*lm^2*NM + 
        0.021025*lm^3*NM + 0.19985164231940114*NL + 0.015274078959344359*lm*
         NL + 0.06417518569655685*lm^2*NL + 0.021025*lm^3*NL - 
        0.05716921914749226*NH + 0.015274078959344359*lm*NH + 
        0.06417518569655685*lm^2*NH + 0.021025*lm^3*NH)}, 
     {0.135, CF*NC*(CF*(0.27540231911648055 + 0.23050014904555396*lm + 
          0.4145597105413111*lm^2 - 0.18705625*lm^3) + 
        CA*(-0.0734192891631928 + 0.3739774273472712*lm - 
          0.5650290484191988*lm^2 - 0.11431215277777777*lm^3) + 
        0.19171785997775986*NM + 0.01313417031592327*lm*NM + 
        0.06305395577318766*lm^2*NM + 0.020784027777777776*lm^3*NM + 
        0.19633981661936195*NL + 0.01313417031592327*lm*NL + 
        0.06305395577318766*lm^2*NL + 0.020784027777777776*lm^3*NL - 
        0.054773755420530486*NH + 0.01313417031592327*lm*NH + 
        0.06305395577318766*lm^2*NH + 0.020784027777777776*lm^3*NH)}, 
     {0.14, CF*NC*(CF*(0.2748125162812491 + 0.2330987500953401*lm + 
          0.4132219928995258*lm^2 - 0.1849*lm^3) + 
        CA*(-0.06458093556973991 + 0.3829145988284588*lm - 
          0.5564129487836231*lm^2 - 0.11299444444444444*lm^3) + 
        0.18810162115929502*NM + 0.011060631080488773*lm*NM + 
        0.06194477856671935*lm^2*NM + 0.020544444444444445*lm^3*NM + 
        0.19291903982246467*NL + 0.011060631080488773*lm*NL + 
        0.06194477856671935*lm^2*NL + 0.020544444444444445*lm^3*NL - 
        0.05242021473342723*NH + 0.011060631080488773*lm*NH + 
        0.06194477856671935*lm^2*NH + 0.020544444444444445*lm^3*NH)}, 
     {0.145, CF*NC*(CF*(0.2738166303930401 + 0.23538039983801326*lm + 
          0.4118411739794691*lm^2 - 0.18275625*lm^3) + 
        CA*(-0.05628434324504894 + 0.39146714367264146*lm - 
          0.5478778763181023*lm^2 - 0.111684375*lm^3) + 
        0.18457599175924258*NM + 0.00905243275394236*lm*NM + 
        0.06084768205783676*lm^2*NM + 0.02030625*lm^3*NM + 
        0.1895862065666875*NL + 0.00905243275394236*lm*NL + 
        0.06084768205783676*lm^2*NL + 0.02030625*lm^3*NL - 
        0.05010863060833872*NH + 0.00905243275394236*lm*NH + 
        0.06084768205783676*lm^2*NH + 0.02030625*lm^3*NH)}, 
     {0.15, CF*NC*(CF*(0.27244349791080275 + 0.2373551728868515*lm + 
          0.41041706011923595*lm^2 - 0.180625*lm^3) + 
        CA*(-0.048508820857673614 + 0.39964065374071084*lm - 
          0.539423949371578*lm^2 - 0.11038194444444445*lm^3) + 
        0.18113811754512227*NM + 0.007108531247771733*lm*NM + 
        0.05976268776452934*lm^2*NM + 0.020069444444444445*lm^3*NM + 
        0.18633829911342875*NL + 0.007108531247771733*lm*NL + 
        0.05976268776452934*lm^2*NL + 0.020069444444444445*lm^3*NL - 
        0.04783900871396882*NH + 0.007108531247771733*lm*NH + 
        0.05976268776452934*lm^2*NH + 0.020069444444444445*lm^3*NH)}, 
     {0.155, CF*NC*(CF*(0.2707205452181081 + 0.23903306366724333*lm + 
          0.4089495124946133*lm^2 - 0.17850625*lm^3) + 
        CA*(-0.04123418794637645 + 0.407440831833116*lm - 
          0.5310512527810697*lm^2 - 0.10908715277777778*lm^3) + 
        0.17778521583914889*NM + 0.0052278700574610445*lm*NM + 
        0.05868981111170963*lm^2*NM + 0.019834027777777777*lm^3*NM + 
        0.18317238700849342*NL + 0.0052278700574610445*lm*NL + 
        0.05868981111170963*lm^2*NL + 0.019834027777777777*lm^3*NL - 
        0.045611328410936604*NH + 0.0052278700574610445*lm*NH + 
        0.05868981111170963*lm^2*NH + 0.019834027777777777*lm^3*NH)}, 
     {0.16, CF*NC*(CF*(0.2686738454474621 + 0.24042397180068262*lm + 
          0.40743844402256146*lm^2 - 0.1764*lm^3) + 
        CA*(-0.03444077789506032 + 0.4148734737263488*lm - 
          0.5227598397639902*lm^2 - 0.1078*lm^3) + 0.17451457634666007*NM + 
        0.0034093830906930687*lm*NM + 0.05762906177527095*lm^2*NM + 
        0.0196*lm^3*NM + 0.18008562640564507*NL + 0.0034093830906930687*lm*
         NL + 0.05762906177527095*lm^2*NL + 0.0196*lm^3*NL - 
        0.043425544199997175*NH + 0.0034093830906930687*lm*NH + 
        0.05762906177527095*lm^2*NH + 0.0196*lm^3*NH)}, 
     {0.165, CF*NC*(CF*(0.2663281740020086 + 0.24153768949967314*lm + 
          0.4058838164735863*lm^2 - 0.17430625*lm^3) + 
        CA*(-0.028109438488089444 + 0.42194445204758124*lm - 
          0.5145497336828084*lm^2 - 0.10652048611111112*lm^3) + 
        0.17132356154561412*NM + 0.001651997190881776*lm*NM + 
        0.056580444002934854*lm^2*NM + 0.01936736111111111*lm^3*NM + 
        0.17707525911721236*NL + 0.001651997190881776*lm*NL + 
        0.056580444002934854*lm^2*NL + 0.01936736111111111*lm^3*NL - 
        0.04128158708149468*NH + 0.001651997190881776*lm*NH + 
        0.056580444002934854*lm^2*NH + 0.01936736111111111*lm^3*NH)}, 
     {0.17, CF*NC*(CF*(0.26370706259968346 + 0.2423838907240576*lm + 
          0.40428563777437027*lm^2 - 0.172225*lm^3) + 
        CA*(-0.02222153045313405 + 0.4286597017806523*lm - 
          0.5064209296934404*lm^2 - 0.10524861111111111*lm^3) + 
        0.16820960671053162*NM - 0.00004536560899855568*lm*NM + 
        0.05554395691395886*lm^2*NM + 0.01913611111111111*lm^3*NM + 
        0.17413861144506146*NL - 0.00004536560899855568*lm*NL + 
        0.05554395691395886*lm^2*NL + 0.01913611111111111*lm^3*NL - 
        0.03917936583344875*NH - 0.00004536560899855568*lm*NH + 
        0.05554395691395886*lm^2*NH + 0.01913611111111111*lm^3*NH)}, 
     {0.175, CF*NC*(CF*(0.260832851718977 + 0.2429721218838329*lm + 
          0.4026439594841859*lm^2 - 0.17015625*lm^3) + 
        CA*(-0.016758924332839147 + 0.43502520722399374*lm - 
          0.4983733962874419*lm^2 - 0.103984375*lm^3) + 
        0.16517021963244105*NM - 0.0016837860719979795*lm*NM + 
        0.0545195947795349*lm^2*NM + 0.01890625*lm^3*NM + 
        0.1712730928361318*NL - 0.0016837860719979795*lm*NL + 
        0.0545195947795349*lm^2*NL + 0.01890625*lm^3*NL - 
        0.0371187682148408*NH - 0.0016837860719979795*lm*NH + 
        0.0545195947795349*lm^2*NH + 0.01890625*lm^3*NH)}, 
     {0.18, CF*NC*(CF*(0.2577267413675268 + 0.24331179390255903*lm + 
          0.40095887443046124*lm^2 - 0.1681*lm^3) + 
        CA*(-0.011703995972335996 + 0.44104699024422417*lm - 
          0.49040707673694034*lm^2 - 0.10272777777777778*lm^3) + 
        0.16220298008663464*NM - 0.003264345955845215*lm*NM + 
        0.053507347285504304*lm^2*NM + 0.01867777777777778*lm^3*NM + 
        0.16847619439926925*NL - 0.003264345955845215*lm*NL + 
        0.053507347285504304*lm^2*NL + 0.01867777777777778*lm^3*NL - 
        0.03509966209995171*NH - 0.003264345955845215*lm*NH + 
        0.053507347285504304*lm^2*NH + 0.01867777777777778*lm^3*NH)}, 
     {0.185, CF*NC*(CF*(0.2544088401274509 + 0.24341217548001517*lm + 
          0.39923051449045965*lm^2 - 0.16605625*lm^3) + 
        CA*(-0.007039620864643238 + 0.44673109968878205*lm - 
          0.48252189045027466*lm^2 - 0.10147881944444445*lm^3) + 
        0.15930553909194825*NM - 0.004788126401673651*lm*NM + 
        0.05250719977883782*lm^2*NM + 0.018450694444444443*lm^3*NM + 
        0.16574548731394903*NL - 0.004788126401673651*lm*NL + 
        0.05250719977883782*lm^2*NL + 0.018450694444444443*lm^3*NL - 
        0.033121896548984994*NH - 0.004788126401673651*lm*NH + 
        0.05250719977883782*lm^2*NH + 0.018450694444444443*lm^3*NH)}, 
     {0.19, CF*NC*(CF*(0.2508982124566835 + 0.24328238741359248*lm + 
          0.3974590485074115*lm^2 - 0.164025*lm^3) + 
        CA*(-0.002749167558578167 + 0.45208360183771756*lm - 
          0.47471773424547076*lm^2 - 0.1002375*lm^3) + 0.15647561799853685*
         NM - 0.0062562064926719434*lm*NM + 0.0515191334991765*lm^2*NM + 
        0.018225*lm^3*NM + 0.1630786211564038*NL - 0.0062562064926719434*lm*
         NL + 0.0515191334991765*lm^2*NL + 0.018225*lm^3*NL - 
        0.031185302819675742*NH - 0.0062562064926719434*lm*NH + 
        0.0515191334991765*lm^2*NH + 0.018225*lm^3*NH)}, 
     {0.195, CF*NC*(CF*(0.24721292424516328 + 0.2429313978556825*lm + 
          0.39564468033063593*lm^2 - 0.16200625*lm^3) + 
        CA*(0.0011835096974759476 + 0.4571105717891171*lm - 
          0.4669944835479447*lm^2 - 0.09900381944444445*lm^3) + 
        0.1537110074354754*NM - 0.007669661964952108*lm*NM + 
        0.05054312579659601*lm^2*NM + 0.018000694444444444*lm^3*NM + 
        0.16047332216446278*NL - 0.007669661964952108*lm*NL + 
        0.05054312579659601*lm^2*NL + 0.018000694444444444*lm^3*NL - 
        0.02928969532412023*NH - 0.007669661964952108*lm*NH + 
        0.05054312579659601*lm^2*NH + 0.018000694444444444*lm^3*NH)}, 
     {0.2, NC*(CF^2*(0.24337008663977497 + 0.24236801839953276*lm + 
          0.3937876469702327*lm^2 - 0.16*lm^3) + 
        CA*CF*(0.004774078928836474 + 0.46181808568497906*lm - 
          0.4593519935181911*lm^2 - 0.09777777777777778*lm^3) + 
        CF*((0.15100956614478192 - 0.009029564055024948*lm + 
            0.04957915033664081*lm^2 + 0.017777777777777778*lm^3)*NM + 
          (0.15792739145890128 - 0.009029564055024948*lm + 
            0.04957915033664081*lm^2 + 0.017777777777777778*lm^3)*NL + 
          (-0.027434872534654736 - 0.009029564055024948*lm + 
            0.04957915033664081*lm^2 + 0.017777777777777778*lm^3)*NH))}, 
     {0.205, NC*(CF^2*(0.239385898163414 + 0.2416009008991175*lm + 
          0.39188821685784453*lm^2 - 0.15800625*lm^3) + 
        CA*CF*(0.008037738899794521 + 0.46621221369502264*lm - 
          0.45179010011465054*lm^2 - 0.096559375*lm^3) + 
        CF*((0.1483692197244495 - 0.010336978470081916*lm + 
            0.048627177293572826*lm^2 + 0.01755625*lm^3)*NM + 
          (0.15543870323617234 - 0.010336978470081916*lm + 
            0.048627177293572826*lm^2 + 0.01755625*lm^3)*NL + 
          (-0.025620617842255267 - 0.010336978470081916*lm + 
            0.048627177293572826*lm^2 + 0.01755625*lm^3)*NH))}, 
     {0.21, NC*(CF^2*(0.23527568516215883 + 0.24063853493985043*lm + 
          0.38994668820579204*lm^2 - 0.156025*lm^3) + 
        CA*CF*(0.010989227964528482 + 0.47029901368515864*lm - 
          0.4443086210964604*lm^2 - 0.0953486111111111*lm^3) + 
        CF*((0.14578795929975227 - 0.011592964468849278*lm + 
            0.047687173532689774*lm^2 + 0.01733611111111111*lm^3)*NM + 
          (0.15300520294493894 - 0.011592964468849278*lm + 
            0.047687173532689774*lm^2 + 0.01733611111111111*lm^3)*NL + 
          (-0.02384670037061551 - 0.011592964468849278*lm + 
            0.047687173532689774*lm^2 + 0.01733611111111111*lm^3)*NH))}, 
     {0.215, NC*(CF^2*(0.23105394062094586 + 0.2394892458867311*lm + 
          0.3879633874575999*lm^2 - 0.15405625*lm^3) + 
        CA*CF*(0.013642833213079832 + 0.47408452550538893*lm - 
          0.4369073569703556*lm^2 - 0.0941454861111111*lm^3) + 
        CF*((0.14326384013913715 - 0.012798574042142106*lm + 
            0.0467591027824889*lm^2 + 0.01711736111111111*lm^3)*NM + 
          (0.15062490545676568 - 0.012798574042142106*lm + 0.0467591027824889*
             lm^2 + 0.01711736111111111*lm^3)*NL + 
          (-0.02211287574878222 - 0.012798574042142106*lm + 
            0.0467591027824889*lm^2 + 0.01711736111111111*lm^3)*NH))}, 
     {0.22, NC*(CF^2*(0.22673436139270897 + 0.23816119344499384*lm + 
          0.3859386678235585*lm^2 - 0.1521*lm^3) + 
        CA*CF*(0.01601239983525505 + 0.477574765838926*lm - 
          0.42958609188560315*lm^2 - 0.09295*lm^3) + 
        CF*((0.14079498022869846 - 0.013954851183432702*lm + 
            0.04584292579738239*lm^2 + 0.0169*lm^3)*NM + 
          (0.1482958932395934 - 0.013954851183432702*lm + 0.04584292579738239*
             lm^2 + 0.0169*lm^3)*NL + (-0.02041888684498057 - 
            0.013954851183432702*lm + 0.04584292579738239*lm^2 + 0.0169*lm^3)*
           NH))}, {0.225, NC*(CF^2*(0.22232988388916833 + 
          0.23666237067571358*lm + 0.3838729078955288*lm^2 - 
          0.15015625*lm^3) + CA*CF*(0.018111340636735557 + 
          0.48077572356046583*lm - 0.42234459448051015*lm^2 - 
          0.09176215277777777*lm^3) + 
        CF*((0.13837955881705827 - 0.015062831240786452*lm + 
            0.04493860051160791*lm^2 + 0.016684027777777777*lm^3)*NM + 
          (0.14601631454115785 - 0.015062831240786452*lm + 
            0.04493860051160791*lm^2 + 0.016684027777777777*lm^3)*NL + 
          (-0.018764464464042056 - 0.015062831240786452*lm + 
            0.04493860051160791*lm^2 + 0.016684027777777777*lm^3)*NH))}, 
     {0.23, NC*(CF^2*(0.2178527182835185 + 0.23500060341527265*lm + 
          0.38176651033569586*lm^2 - 0.148225*lm^3) + 
        CA*CF*(0.019952645651443748 + 0.4836933555569482*lm - 
          0.41518261868374146*lm^2 - 0.09058194444444445*lm^3) + 
        CF*((0.13601581494074796 - 0.016123540342428883*lm + 
            0.04404608218492268*lm^2 + 0.016469444444444443*lm^3)*NM + 
          (0.14378438158827528 - 0.016123540342428883*lm + 
            0.04404608218492268*lm^2 + 0.016469444444444443*lm^3)*NL + 
          (-0.017149328010651416 - 0.016123540342428883*lm + 
            0.04404608218492268*lm^2 + 0.016469444444444443*lm^3)*NH))}, 
     {0.235, NC*(CF^2*(0.21331438127643568 + 0.233183550053243*lm + 
          0.37961990063442186*lm^2 - 0.14630625*lm^3) + 
        CA*CF*(0.021548891802575836 + 0.48633358296889045*lm - 
          0.4080999044734089*lm^2 - 0.089409375*lm^3) + 
        CF*((0.13370204593873797 - 0.01713799488900888*lm + 
            0.04316532354061979*lm^2 + 0.01625625*lm^3)*NM + 
          (0.14159836880687193 - 0.01713799488900888*lm + 0.04316532354061979*
             lm^2 + 0.01625625*lm^3)*NL + (-0.01557318612045288 - 
            0.01713799488900888*lm + 0.04316532354061979*lm^2 + 
            0.01625625*lm^3)*NH))}, 
     {0.24, NC*(CF^2*(0.20872572747739068 + 0.23121870162819913*lm + 
          0.3774335259327513*lm^2 - 0.1444*lm^3) + 
        CA*CF*(0.02291225257183766 + 0.4887022878145788*lm - 
          0.401096178596652*lm^2 - 0.08824444444444444*lm^3) + 
        CF*((0.1314366059632816 - 0.01810720110632977*lm + 
            0.042296274896360966*lm^2 + 0.016044444444444445*lm^3)*NM + 
          (0.13945661106674534 - 0.01810720110632977*lm + 
            0.042296274896360966*lm^2 + 0.016044444444444445*lm^3)*NL + 
          (-0.014035737260898212 - 0.01810720110632977*lm + 
            0.042296274896360966*lm^2 + 0.016044444444444445*lm^3)*NH))}, 
     {0.245, NC*(CF^2*(0.20409697945313032 + 0.2291133822053428*lm + 
          0.37520785390547745*lm^2 - 0.14250625*lm^3) + 
        CA*CF*(0.024054507642606745 + 0.4908053099631168*lm - 
          0.39417115525220825*lm^2 - 0.08708715277777777*lm^3) + 
        CF*((0.12921790449336226 - 0.019032154652944683*lm + 
            0.041438884288280284*lm^2 + 0.015834027777777777*lm^3)*NM + 
          (0.137357501954293 - 0.019032154652944683*lm + 0.041438884288280284*
             lm^2 + 0.015834027777777777*lm^3)*NL + 
          (-0.012536670303576337 - 0.019032154652944683*lm + 
            0.041438884288280284*lm^2 + 0.015834027777777777*lm^3)*NH))}, 
     {0.25, NC*(CF^2*(0.1994377564947964 + 0.2268747495036744*lm + 
          0.3729433717010048*lm^2 - 0.140625*lm^3) + 
        CA*CF*(0.024987052487995015 + 0.49264844442562905*lm - 
          0.3873245367382748*lm^2 - 0.0859375*lm^3) + 
        CF*((0.1270444048558837 - 0.019913840277566534*lm + 
            0.040593097588777244*lm^2 + 0.015625*lm^3)*NM + 
          (0.1352994920758033 - 0.019913840277566534*lm + 
            0.040593097588777244*lm^2 + 0.015625*lm^3)*NL + 
          (-0.011075665069635775 - 0.019913840277566534*lm + 
            0.040593097588777244*lm^2 + 0.015625*lm^3)*NH))}, 
     {0.255, NC*(CF^2*(0.1947571021543336 + 0.22450979574385038*lm + 
          0.3706405849345333*lm^2 - 0.13875625*lm^3) + 
        CA*CF*(0.025720907879352745 + 0.49423743893684996*lm - 
          0.3805560140677852*lm^2 - 0.08479548611111111*lm^3) + 
        CF*((0.1249146227590132 - 0.020753231521734916*lm + 
            0.03975885861838519*lm^2 + 0.01541736111111111*lm^3)*NM + 
          (0.13328108739336067 - 0.020753231521734916*lm + 
            0.03975885861838519*lm^2 + 0.01541736111111111*lm^3)*NL + 
          (-0.009652392849794472 - 0.020753231521734916*lm + 
            0.03975885861838519*lm^2 + 0.01541736111111111*lm^3)*NH))}, 
     {0.26, NC*(CF^2*(0.19006351059981796 + 0.22202534869088475*lm + 
          0.368300016731354*lm^2 - 0.1369*lm^3) + 
        CA*CF*(0.026266729294670825 + 0.4955779918019425*lm - 
          0.37386526755306143*lm^2 - 0.08366111111111112*lm^3) + 
        CF*((0.12282712484135191 - 0.021551290463620126*lm + 
            0.03893610925207178*lm^2 + 0.015211111111111111*lm^3)*NM + 
          (0.1313008475949544 - 0.021551290463620126*lm + 0.03893610925207178*
             lm^2 + 0.015211111111111111*lm^3)*NL + 
          (-0.008266516900325819 - 0.021551290463620126*lm + 
            0.03893610925207178*lm^2 + 0.015211111111111111*lm^3)*NH))}, 
     {0.265, NC*(CF^2*(0.1853649518381301 + 0.21942807286852997*lm + 
          0.365922206817286*lm^2 - 0.13505625*lm^3) + 
        CA*CF*(0.026634816209719057 + 0.49667574998572767*lm - 
          0.36725196736165855*lm^2 - 0.082534375*lm^3) + 
        CF*((0.12078052723999377 - 0.0223089674992354*lm + 
            0.03812478952030156*lm^2 + 0.01500625*lm^3)*NM + 
          (0.12935738449998793 - 0.0223089674992354*lm + 0.03812478952030156*
             lm^2 + 0.01500625*lm^3)*NL + (-0.0069176929163132835 - 
            0.0223089674992354*lm + 0.03812478952030156*lm^2 + 
            0.01500625*lm^3)*NH))}, 
     {0.27, NC*(CF^2*(0.18066889585205992 + 0.21672447092455518*lm + 
          0.36350771065350146*lm^2 - 0.133225*lm^3) + 
        CA*CF*(0.026835121257674146 + 0.4975363074235944*lm - 
          0.3607157740450825*lm^2 - 0.08141527777777778*lm^3) + 
        CF*((0.11877349418000373 - 0.023027201157677618*lm + 
            0.03732483770516651*lm^2 + 0.014802777777777778*lm^3)*NM + 
          (0.12744936050105268 - 0.023027201157677618*lm + 
            0.03732483770516651*lm^2 + 0.014802777777777778*lm^3)*NL + 
          (-0.005605569483378322 - 0.023027201157677618*lm + 
            0.03732483770516651*lm^2 + 0.014802777777777778*lm^3)*NH))}, 
     {0.275, NC*(CF^2*(0.17598233569750318 + 0.21392088512826088*lm + 
          0.3610570986131844*lm^2 - 0.13140625*lm^3) + 
        CA*CF*(0.02687725924550858 + 0.49816520353523547*lm - 
          0.35425633904194287*lm^2 - 0.08030381944444444*lm^3) + 
        CF*((0.11680473658739601 - 0.023706917947329518*lm + 
            0.0365361904318684*lm^2 + 0.014600694444444444*lm^3)*NM + 
          (0.12557548704254637 - 0.023706917947329518*lm + 0.0365361904318684*
             lm^2 + 0.014600694444444444*lm^3)*NL + 
          (-0.004329788509005909 - 0.023706917947329518*lm + 
            0.0365361904318684*lm^2 + 0.014600694444444444*lm^3)*NH))}, 
     {0.28, NC*(CF^2*(0.17131180960493061 + 0.21102349898346237*lm + 
          0.35857095519764887*lm^2 - 0.1296*lm^3) + 
        CA*CF*(0.026770516017580903 + 0.4985679219240367*lm - 
          0.3478733051569924*lm^2 - 0.0792*lm^3) + 
        CF*((0.11487301072728973 - 0.024349032230237093*lm + 
            0.035758782755816794*lm^2 + 0.0144*lm^3)*NM + 
          (0.12373452313647723 - 0.024349032230237093*lm + 
            0.035758782755816794*lm^2 + 0.0144*lm^3)*NL + 
          (-0.0030899856345185774 - 0.024349032230237093*lm + 
            0.035758782755816794*lm^2 + 0.0144*lm^3)*NH))}, 
     {0.285, NC*(CF^2*(0.16666342212778737 + 0.20803833894186613*lm + 
          0.35604987828970674*lm^2 - 0.12780625*lm^3) + 
        CA*CF*(0.026523857158746292 + 0.4987498892464651*lm - 
          0.3415663070174014*lm^2 - 0.07810381944444444*lm^3) + 
        CF*((0.11297711686858503 - 0.024954446122127966*lm + 
            0.034992548245588145*lm^2 + 0.014200694444444445*lm^3)*NM + 
          (0.12192527391559202 - 0.024954446122127966*lm + 
            0.034992548245588145*lm^2 + 0.014200694444444445*lm^3)*NL + 
          (-0.0018857906286824009 - 0.024954446122127966*lm + 
            0.034992548245588145*lm^2 + 0.014200694444444445*lm^3)*NH))}, 
     {0.29, NC*(CF^2*(0.1620428643789296 + 0.20497127620327724*lm + 
          0.3534944784422288*lm^2 - 0.126025*lm^3) + 
        CA*CF*(0.026145936530934305 + 0.4987164742371633*lm - 
          0.33533497150752684*lm^2 - 0.07701527777777778*lm^3) + 
        CF*((0.11111589797620434 - 0.02552404941576355*lm + 
            0.034237419061974576*lm^2 + 0.014002777777777777*lm^3)*NM + 
          (0.12014658922379462 - 0.02552404941576355*lm + 
            0.034237419061974576*lm^2 + 0.014002777777777777*lm^3)*NL + 
          (-0.0007168277638663926 - 0.02552404941576355*lm + 
            0.034237419061974576*lm^2 + 0.014002777777777777*lm^3)*NH))}, 
     {0.295, NC*(CF^2*(0.15745543339460374 + 0.20182802859043242*lm + 
          0.35090537819997786*lm^2 - 0.12425625*lm^3) + 
        CA*CF*(0.025645104638573016 + 0.4984729868766953*lm - 
          0.3291789181833469*lm^2 - 0.075934375*lm^3) + 
        CF*((0.10928823843169355 - 0.02605871952552233*lm + 
            0.03349332603333579*lm^2 + 0.01380625*lm^3)*NM + 
          (0.11839736224367843 - 0.02605871952552233*lm + 0.03349332603333579*
             lm^2 + 0.01380625*lm^3)*NL + (0.000417283824380277 - 
            0.02605871952552233*lm + 0.03349332603333579*lm^2 + 
            0.01380625*lm^3)*NH))}, 
     {0.3, NC*(CF^2*(0.15290607552135457 + 0.19861416248747152*lm + 
          0.3482832114529223*lm^2 - 0.1225*lm^3) + 
        CA*CF*(0.02502940439074442 + 0.49802467768999875*lm - 
          0.3230977596676586*lm^2 - 0.07486111111111111*lm^3) + 
        CF*((0.1074930627827535 - 0.026559321451296455*lm + 
            0.032760198727453074*lm^2 + 0.01361111111111111*lm^3)*NM + 
          (0.11667652816087487 - 0.026559321451296455*lm + 
            0.032760198727453074*lm^2 + 0.01361111111111111*lm^3)*NL + 
          (0.001516929793521453 - 0.026559321451296455*lm + 
            0.032760198727453074*lm^2 + 0.01361111111111111*lm^3)*NH))}, 
     {0.305, NC*(CF^2*(0.14839929978210517 + 0.19533509483215342*lm + 
          0.34562862281935475*lm^2 - 0.12075625*lm^3) + 
        CA*CF*(0.024306631297817446 + 0.4973767371646131*lm - 
          0.317091102027061*lm^2 - 0.07379548611111111*lm^3) + 
        CF*((0.10572933452209023 - 0.02702670775995069*lm + 
            0.032037965520071696*lm^2 + 0.01341736111111111*lm^3)*NM + 
          (0.11498306286481971 - 0.02702670775995069*lm + 
            0.032037965520071696*lm^2 + 0.01341736111111111*lm^3)*NL + 
          (0.0025825002652343936 - 0.02702670775995069*lm + 
            0.032037965520071696*lm^2 + 0.01341736111111111*lm^3)*NH))}, 
     {0.31, NC*(CF^2*(0.14393935931576315 + 0.19199609515290686*lm + 
          0.3429422670572475*lm^2 - 0.119025*lm^3) + 
        CA*CF*(0.023484259071410912 + 0.4965342952786641*lm - 
          0.31115854513168206*lm^2 - 0.0727375*lm^3) + 
        CF*((0.10399605489580466 - 0.027461718582744148*lm + 
            0.03132655366030584*lm^2 + 0.013225*lm^3)*NM + 
          (0.1133159816854559 - 0.027461718582744148*lm + 0.03132655366030584*
             lm^2 + 0.013225*lm^3)*NL + (0.003614389510899198 - 
            0.027461718582744148*lm + 0.03132655366030584*lm^2 + 
            0.013225*lm^3)*NH))}, 
     {0.315, NC*(CF^2*(0.13953015210187447 + 0.18860228764269243*lm + 
          0.34022480850237685*lm^2 - 0.11730625*lm^3) + 
        CA*CF*(0.022569505038006876 + 0.4955024211294197*lm - 
          0.3052996829985475*lm^2 - 0.07168715277777778*lm^3) + 
        CF*((0.10229226174140707 - 0.027865181627252125*lm + 
            0.030625889333069235*lm^2 + 0.013034027777777778*lm^3)*NM + 
          (0.11167433816532274 - 0.027865181627252125*lm + 
            0.030625889333069235*lm^2 + 0.013034027777777778*lm^3)*NL + 
          (0.0046129956507007346 - 0.027865181627252125*lm + 
            0.030625889333069235*lm^2 + 0.013034027777777778*lm^3)*NH))}, 
     {0.32, NC*(CF^2*(0.13517526703269586 + 0.18515865326245068*lm + 
          0.33747692053183914*lm^2 - 0.1156*lm^3) + 
        CA*CF*(0.02156932235107296 + 0.49428612265398547*lm - 
          0.29951410411943163*lm^2 - 0.07064444444444444*lm^3) + 
        CF*((0.1006170283554204 - 0.028237912202449887*lm + 
            0.02993589771868454*lm^2 + 0.012844444444444445*lm^3)*NM + 
          (0.1100572228664259 - 0.028237912202449887*lm + 0.02993589771868454*
             lm^2 + 0.012844444444444445*lm^3)*NL + 
          (0.005578720365705223 - 0.028237912202449887*lm + 
            0.02993589771868454*lm^2 + 0.012844444444444445*lm^3)*NH))}, 
     {0.325, NC*(CF^2*(0.13087799877423129 + 0.18167003186763184*lm + 
          0.3346992850516663*lm^2 - 0.11390625*lm^3) + 
        CA*CF*(0.020490407296853995 + 0.4928903464343964*lm - 
          0.29380139177398173*lm^2 - 0.069609375*lm^3) + 
        CF*((0.09896946239043625 - 0.02858071325573323*lm + 
            0.029256503049814857*lm^2 + 0.01265625*lm^3)*NM + 
          (0.10846376221123738 - 0.02858071325573323*lm + 
            0.029256503049814857*lm^2 + 0.01265625*lm^3)*NL + 
          (0.006511968622309521 - 0.02858071325573323*lm + 
            0.029256503049814857*lm^2 + 0.01265625*lm^3)*NH))}, 
     {0.33, NC*(CF^2*(0.12664136198857462 + 0.17814112435195378*lm + 
          0.331892592007328*lm^2 - 0.112225*lm^3) + 
        CA*CF*(0.019339206423421604 + 0.49131997757998896*lm - 
          0.2881611243288551*lm^2 - 0.06858194444444445*lm^3) + 
        CF*((0.09734870478140022 - 0.028894375420753477*lm + 
            0.028587628665852443*lm^2 + 0.012469444444444444*lm^3)*NM + 
          (0.10689311735714006 - 0.028894375420753477*lm + 
            0.028587628665852443*lm^2 + 0.012469444444444444*lm^3)*NL + 
          (0.007413148408494618 - 0.028894375420753477*lm + 
            0.028587628665852443*lm^2 + 0.012469444444444444*lm^3)*NH))}, 
     {0.335, NC*(CF^2*(0.12246810494545946 + 0.1745764948031226*lm + 
          0.3290575389159793*lm^2 - 0.11055625*lm^3) + 
        CA*CF*(0.018121923494569602 + 0.48957983968050783*lm - 
          0.2825928755235682*lm^2 - 0.06756215277777777*lm^3) + 
        CF*((0.09575392870083033 - 0.02917967707503823*lm + 
            0.027929197064891192*lm^2 + 0.012284027777777777*lm^3)*NM + 
          (0.10534448310360325 - 0.02917967707503823*lm + 
            0.027929197064891192*lm^2 + 0.012284027777777777*lm^3)*NL + 
          (0.008282670481345945 - 0.02917967707503823*lm + 
            0.027929197064891192*lm^2 + 0.012284027777777777*lm^3)*NH))}, 
     {0.34, NC*(CF^2*(0.11836072254969186 + 0.1709805726657821*lm + 
          0.32619483041938013*lm^2 - 0.1089*lm^3) + 
        CA*CF*(0.01684452627049279 + 0.48767469482392434*lm - 
          0.27709621474371215*lm^2 - 0.06655*lm^3) + 
        CF*((0.09418433854261074 - 0.029437384406454607*lm + 
            0.02728112995340221*lm^2 + 0.0121*lm^3)*NM + 
          (0.10381708683135618 - 0.029437384406454607*lm + 
            0.02728112995340221*lm^2 + 0.0121*lm^3)*NL + 
          (0.00912094812533217 - 0.029437384406454607*lm + 
            0.02728112995340221*lm^2 + 0.0121*lm^3)*NH))}, 
     {0.345, NC*(CF^2*(0.1143214688099646 + 0.1673576549074409*lm + 
          0.3233051778564773*lm^2 - 0.10725625*lm^3) + 
        CA*CF*(0.015512753117481156 + 0.48560924367342156*lm - 
          0.27167070728215276*lm^2 - 0.0655454861111111*lm^3) + 
        CF*((0.09263916893395135 - 0.02966825148764949*lm + 
            0.026643348293724747*lm^2 + 0.011917361111111111*lm^3)*NM + 
          (0.10231018747281155 - 0.02966825148764949*lm + 
            0.026643348293724747*lm^2 + 0.011917361111111111*lm^3)*NL + 
          (0.009928396920861225 - 0.02966825148764949*lm + 
            0.026643348293724747*lm^2 + 0.011917361111111111*lm^3)*NH))}, 
     {0.35, NC*(CF^2*(0.11035236877341996 + 0.16371190818356074*lm + 
          0.32038929885469514*lm^2 - 0.105625*lm^3) + 
        CA*CF*(0.01413211944910753 + 0.4833881255984364*lm - 
          0.2663159145887974*lm^2 - 0.06454861111111111*lm^3) + 
        CF*((0.09111768377506127 - 0.029873020357672597*lm + 
            0.026015772349478314*lm^2 + 0.01173611111111111*lm^3)*NM + 
          (0.10082307451298216 - 0.029873020357672597*lm + 
            0.026015772349478314*lm^2 + 0.01173611111111111*lm^3)*NL + 
          (0.01070543452265769 - 0.029873020357672597*lm + 
            0.026015772349478314*lm^2 + 0.01173611111111111*lm^3)*NH))}, 
     {0.355, NC*(CF^2*(0.10645522994924354 + 0.16004737099838648*lm + 
          0.3174479169390389*lm^2 - 0.10400625*lm^3) + 
        CA*CF*(0.012707924001590003 + 0.48101591885504996*lm - 
          0.26103139450947627*lm^2 - 0.063559375*lm^3) + 
        CF*((0.08961917530604903 - 0.030052421110053098*lm + 
            0.02539832172899568*lm^2 + 0.01155625*lm^3)*NM + 
          (0.09935506702012889 - 0.030052421110053098*lm + 
            0.02539832172899568*lm^2 + 0.01155625*lm^3)*NL + 
          (0.01145248044752935 - 0.030052421110053098*lm + 
            0.02539832172899568*lm^2 + 0.01155625*lm^3)*NH))}, 
     {0.36, NC*(CF^2*(0.10263165324353102 + 0.1563679558584551*lm + 
          0.3144817611581615*lm^2 - 0.1024*lm^3) + 
        CA*CF*(0.011245254946177464 + 0.47849714081138406*lm - 
          0.25581670151445685*lm^2 - 0.06257777777777777*lm^3) + 
        CF*((0.08814296320053432 - 0.030207171986660196*lm + 
            0.024790915426870945*lm^2 + 0.011377777777777778*lm^3)*NM + 
          (0.09790551270537687 - 0.030207171986660196*lm + 
            0.024790915426870945*lm^2 + 0.011377777777777778*lm^3)*NL + 
          (0.012169955871112942 - 0.030207171986660196*lm + 
            0.024790915426870945*lm^2 + 0.011377777777777778*lm^3)*NH))}, 
     {0.365, NC*(CF^2*(0.09888304342667421 + 0.15267745141604755*lm + 
          0.311491565726596*lm^2 - 0.10080625*lm^3) + 
        CA*CF*(0.009748995841540486 + 0.4758362482139982*lm - 
          0.25067138691708024*lm^2 - 0.061603819444444444*lm^3) + 
        CF*((0.0866883936854329 - 0.030337979476732366*lm + 
            0.024193471863711555*lm^2 + 0.011200694444444444*lm^3)*NM + 
          (0.09647378701053912 - 0.030337979476732366*lm + 
            0.024193471863711555*lm^2 + 0.011200694444444444*lm^3)*NL + 
          (0.012858283433209971 - 0.030337979476732366*lm + 
            0.024193471863711555*lm^2 + 0.011200694444444444*lm^3)*NH))}, 
     {0.37, NC*(CF^2*(0.09521061915355912 + 0.14897952460014227*lm + 
          0.3084780696823955*lm^2 - 0.099225*lm^3) + 
        CA*CF*(0.008223831429256428 + 0.47303763749158984*lm - 
          0.24559499908298052*lm^2 - 0.0606375*lm^3) + 
        CF*((0.0852548386863604 - 0.030445538420510104*lm + 
            0.023605908924178277*lm^2 + 0.011025*lm^3)*NM + 
          (0.09505929222339102 - 0.030445538420510104*lm + 
            0.023605908924178277*lm^2 + 0.011025*lm^3)*NL + 
          (0.013517887051342985 - 0.030445538420510104*lm + 
            0.023605908924178277*lm^2 + 0.011025*lm^3)*NH))}, 
     {0.375, NC*(CF^2*(0.09161542255595861 + 0.14527772273269624*lm + 
          0.3054420165594677*lm^2 - 0.09765625*lm^3) + 
        CA*CF*(0.00667425327555831 + 0.4701056450925855*lm - 
          0.24058708363032533*lm^2 - 0.05967881944444445*lm^3) + 
        CF*((0.08384169499808508 - 0.030530532116952717*lm + 
            0.023028143993392484*lm^2 + 0.010850694444444444*lm^3)*NM + 
          (0.09366145661964662 - 0.030530532116952717*lm + 
            0.023028143993392484*lm^2 + 0.010850694444444444*lm^3)*NL + 
          (0.014149191742181072 - 0.030530532116952717*lm + 
            0.023028143993392484*lm^2 + 0.010850694444444444*lm^3)*NH))}, 
     {0.38, NC*(CF^2*(0.0880983284256294 + 0.14157547562832457*lm + 
          0.3023841540739265*lm^2 - 0.0961*lm^3) + 
        CA*CF*(0.005104565262578212 + 0.4670445478534714*lm - 
          0.23564718362148937*lm^2 - 0.058727777777777775*lm^3) + 
        CF*((0.08244838347945367 - 0.03059363243506177*lm + 
            0.02246009399178595*lm^2 + 0.010677777777777777*lm^3)*NM + 
          (0.09227973363089587 - 0.03059363243506177*lm + 0.02246009399178595*
             lm^2 + 0.010677777777777777*lm^3)*NL + 
          (0.014752623450500634 - 0.03059363243506177*lm + 
            0.02246009399178595*lm^2 + 0.010677777777777777*lm^3)*NH))}, 
     {0.385, NC*(CF^2*(0.08466005300579242 + 0.13787609767566927*lm + 
          0.2993052338238218*lm^2 - 0.09455625*lm^3) + 
        CA*CF*(0.0035188889323564602 + 0.4638585633949518*lm - 
          0.23077483974655336*lm^2 - 0.057784375*lm^3) + 
        CF*((0.0810743482722059 - 0.030635499928372428*lm + 
            0.021901675408464244*lm^2 + 0.01050625*lm^3)*NM + 
          (0.09091360103777286 - 0.030635499928372428*lm + 
            0.021901675408464244*lm^2 + 0.01050625*lm^3)*NL + 
          (0.015328608885363679 - 0.030635499928372428*lm + 
            0.021901675408464244*lm^2 + 0.01050625*lm^3)*NH))}, 
     {0.39, NC*(CF^2*(0.08130116240787984 + 0.13418278989894974*lm + 
          0.29620601100164007*lm^2 - 0.093025*lm^3) + 
        CA*CF*(0.0019211686869137564 + 0.46055185054324643*lm - 
          0.22596959049899773*lm^2 - 0.056848611111111114*lm^3) + 
        CF*((0.07971905604309175 - 0.03065678395220936*lm + 
            0.021352804333151103*lm^2 + 0.010336111111111112*lm^3)*NM + 
          (0.08956256018763663 - 0.03065678395220936*lm + 
            0.021352804333151103*lm^2 + 0.010336111111111112*lm^3)*NL + 
          (0.015877575363211216 - 0.03065678395220936*lm + 
            0.021352804333151103*lm^2 + 0.010336111111111112*lm^3)*NH))}, 
     {0.395, NC*(CF^2*(0.07802208066967367 + 0.13049864199837014*lm + 
          0.29308724411900194*lm^2 - 0.09150625*lm^3) + 
        CA*CF*(0.00031517684769425666 + 0.4571285097740401*lm - 
          0.22123097234394326*lm^2 - 0.05592048611111111*lm^3) + 
        CF*((0.07838199524870446 - 0.0306581227833366*lm + 
            0.02081339648677756*lm^2 + 0.010167361111111111*lm^3)*NM + 
          (0.0882261352360585 - 0.0306581227833366*lm + 0.02081339648677756*
             lm^2 + 0.010167361111111111*lm^3)*NL + 
          (0.016399950657583786 - 0.0306581227833366*lm + 0.02081339648677756*
             lm^2 + 0.010167361111111111*lm^3)*NH))}, 
     {0.4, NC*(CF^2*(0.07482309747023667 + 0.126826634368224*lm + 
          0.28994969474301163*lm^2 - 0.09*lm^3) + 
        CA*CF*(-0.0012954814223130752 + 0.45359258367678856*lm - 
          0.21655851987927066*lm^2 - 0.055*lm^3) + 
        CF*((0.07706267542244427 - 0.03064014374166063*lm + 
            0.020283367250776483*lm^2 + 0.01*lm^3)*NM + 
          (0.08690387241142433 - 0.03064014374166063*lm + 
            0.020283367250776483*lm^2 + 0.01*lm^3)*NL + 
          (0.016896162855194668 - 0.03064014374166063*lm + 
            0.020283367250776483*lm^2 + 0.01*lm^3)*NH))}, 
     {0.405, NC*(CF^2*(0.07170437551634494 + 0.12316964009168896*lm + 
          0.2867941272437415*lm^2 - 0.08850625*lm^3) + 
        CA*CF*(-0.002907363330479014 + 0.4499480574372556*lm - 
          0.21195176598993576*lm^2 - 0.05408715277777778*lm^3) + 
        CF*((0.07576062648303084 - 0.03060346331367376*lm + 
            0.019762631695139837*lm^2 + 0.009834027777777778*lm^3)*NM + 
          (0.0855953393019733 - 0.03060346331367376*lm + 0.019762631695139837*
             lm^2 + 0.009834027777777778*lm^3)*NL + 
          (0.01736664021809422 - 0.03060346331367376*lm + 
            0.019762631695139837*lm^2 + 0.009834027777777778*lm^3)*NH))}, 
     {0.41, NC*(CF^2*(0.06866595761447276 + 0.1195304269114396*lm + 
          0.2836213085523609*lm^2 - 0.087025*lm^3) + 
        CA*CF*(-0.0045171837971893485 + 0.4461988593363199*lm - 
          0.20741024199577945*lm^2 - 0.05318194444444444*lm^3) + 
        CF*((0.07447539806398788 - 0.030548687277350165*lm + 
            0.019251104605293237*lm^2 + 0.009669444444444444*lm^3)*NM + 
          (0.08430012416461063 - 0.030548687277350165*lm + 
            0.019251104605293237*lm^2 + 0.009669444444444444*lm^3)*NL + 
          (0.017811811051675976 - 0.030548687277350165*lm + 
            0.019251104605293237*lm^2 + 0.009669444444444444*lm^3)*NH))}, 
     {0.415, NC*(CF^2*(0.06570777344175094 + 0.11591165917533294*lm + 
          0.2804320079294439*lm^2 - 0.08555625*lm^3) + 
        CA*CF*(-0.0061218109260033834 + 0.4423488612632351*lm - 
          0.20293347779311763*lm^2 - 0.052284375*lm^3) + 
        CF*((0.07320655886352954 - 0.03047641082823053*lm + 
            0.01874870050783957*lm^2 + 0.00950625*lm^3)*NM + 
          (0.08301783525484618 - 0.03047641082823053*lm + 0.01874870050783957*
             lm^2 + 0.00950625*lm^3)*NL + (0.018232103578286418 - 
            0.03047641082823053*lm + 0.01874870050783957*lm^2 + 
            0.00950625*lm^3)*NH))}, 
     {0.42, NC*(CF^2*(0.06282964602872057 + 0.11231589975653306*lm + 
          0.2772269967430126*lm^2 - 0.0841*lm^3) + 
        CA*CF*(-0.007718261598103706 + 0.43840187924166574*lm - 
          0.1985210019903812*lm^2 - 0.051394444444444444*lm^3) + 
        CF*((0.07195369601428545 - 0.030387218706452786*lm + 
            0.018255333695220824*lm^2 + 0.009344444444444445*lm^3)*NM + 
          (0.08174810017722645 - 0.030387218706452786*lm + 
            0.018255333695220824*lm^2 + 0.009344444444444445*lm^3)*NL + 
          (0.018627945816211418 - 0.030387218706452786*lm + 
            0.018255333695220824*lm^2 + 0.009344444444444445*lm^3)*NH))}, 
     {0.425, NC*(CF^2*(0.06003129796613147 + 0.10874561194754485*lm + 
          0.27400704825589567*lm^2 - 0.08265625*lm^3) + 
        CA*CF*(-0.009303697187864762 + 0.4343616739669486*lm - 
          0.19417234203806377*lm^2 - 0.05051215277777778*lm^3) + 
        CF*((0.07071641447231056 - 0.030281685324506404*lm + 
            0.017770918249344927*lm^2 + 0.009184027777777777*lm^3)*NM + 
          (0.0804905652556433 - 0.030281685324506404*lm + 
            0.017770918249344927*lm^2 + 0.009184027777777777*lm^3)*NL + 
          (0.0189997654638224 - 0.030281685324506404*lm + 
            0.017770918249344927*lm^2 + 0.009184027777777777*lm^3)*NH))}, 
     {0.43, NC*(CF^2*(0.05731235734748936 + 0.10520316132772019*lm + 
          0.2707729374220019*lm^2 - 0.081225*lm^3) + 
        CA*CF*(-0.010875419396413417 + 0.43023195135314374*lm - 
          0.18988702435322105*lm^2 - 0.0496375*lm^3) + 
        CF*((0.06949433642483367 - 0.030160374895506124*lm + 
            0.01729536806422201*lm^2 + 0.009025*lm^3)*NM + 
          (0.07924489492291835 - 0.030160374895506124*lm + 
            0.01729536806422201*lm^2 + 0.009025*lm^3)*NL + 
          (0.019347989788675145 - 0.030160374895506124*lm + 
            0.01729536806422201*lm^2 + 0.009025*lm^3)*NH))}, 
     {0.435, NC*(CF^2*(0.054672363458536336 + 0.10169081760388422*lm + 
          0.2675254406911281*lm^2 - 0.07980625*lm^3) + 
        CA*CF*(-0.01243086620010393 + 0.4260163630885517*lm - 
          0.18566457443875503*lm^2 - 0.04877048611111111*lm^3) + 
        CF*((0.06828710071620991 - 0.030023841561797947*lm + 
            0.01682859686765243*lm^2 + 0.00886736111111111*lm^3)*NM + 
          (0.07801077112907756 - 0.030023841561797947*lm + 
            0.01682859686765243*lm^2 + 0.00886736111111111*lm^3)*NL + 
          (0.019673045521363237 - 0.030023841561797947*lm + 
            0.01682859686765243*lm^2 + 0.00886736111111111*lm^3)*NH))}, 
     {0.44, NC*(CF^2*(0.05211077222435194 + 0.0982107564238071*lm + 
          0.26426533582193895*lm^2 - 0.0784*lm^3) + 
        CA*CF*(-0.013967607910881254 + 0.4217185071984706*lm - 
          0.18150451699770395*lm^2 - 0.04791111111111111*lm^3) + 
        CF*((0.06709436229155182 - 0.029872629523725925*lm + 
            0.01637051824200678*lm^2 + 0.00871111111111111*lm^3)*NM + 
          (0.07678789276774636 - 0.029872629523725925*lm + 
            0.01637051824200678*lm^2 + 0.00871111111111111*lm^3)*NL + 
          (0.0199753587539371 - 0.029872629523725925*lm + 0.01637051824200678*
             lm^2 + 0.00871111111111111*lm^3)*NH))}, 
     {0.445, NC*(CF^2*(0.04962696142428917 + 0.0947650611623155*lm + 
          0.2609934017027738*lm^2 - 0.07700625*lm^3) + 
        CA*CF*(-0.015483343345561909 + 0.41734192861406205*lm - 
          0.17740637604274934*lm^2 - 0.047059375*lm^3) + 
        CF*((0.06591579165752481 - 0.02970727316840277*lm + 
            0.015921045644136243*lm^2 + 0.00855625*lm^3)*NM + 
          (0.07557597512011126 - 0.02970727316840277*lm + 
            0.015921045644136243*lm^2 + 0.00855625*lm^3)*NL + 
          (0.02025535484270747 - 0.02970727316840277*lm + 
            0.015921045644136243*lm^2 + 0.00855625*lm^3)*NH))}, 
     {0.45, NC*(CF^2*(0.04722023568450984 + 0.09135572467990176*lm + 
          0.25771041817995194*lm^2 - 0.075625*lm^3) + 
        CA*CF*(-0.016975896101118923 + 0.4128901197462805*lm - 
          0.17336967500114048*lm^2 - 0.04621527777777778*lm^3) + 
        CF*((0.06475107435980382 - 0.029528297198340683*lm + 
            0.015480092424449783*lm^2 + 0.008402777777777778*lm^3)*NM + 
          (0.07437474931590905 - 0.029528297198340683*lm + 
            0.015480092424449783*lm^2 + 0.008402777777777778*lm^3)*NL + 
          (0.020513458315260573 - 0.029528297198340683*lm + 
            0.015480092424449783*lm^2 + 0.008402777777777778*lm^3)*NH))}, 
     {0.455, NC*(CF^2*(0.044889831257453564 + 0.08798465105374566*lm + 
          0.25441716589326296*lm^2 - 0.07425625*lm^3) + 
        CA*CF*(-0.018443210933116218 + 0.40836652106389976*lm - 
          0.16939393681522819*lm^2 - 0.04537881944444445*lm^3) + 
        CF*((0.06359991047669956 - 0.02933621675981116*lm + 
            0.015047571845193003*lm^2 + 0.008250694444444444*lm^3)*NM + 
          (0.07318396181092045 - 0.02933621675981116*lm + 
            0.015047571845193003*lm^2 + 0.008250694444444444*lm^3)*NL + 
          (0.020750092781519153 - 0.02933621675981116*lm + 
            0.015047571845193003*lm^2 + 0.008250694444444444*lm^3)*NH))}, 
     {0.46, NC*(CF^2*(0.04263492059716125 + 0.0846536572811155*lm + 
          0.2511144261183439*lm^2 - 0.0729*lm^3) + 
        CA*CF*(-0.019883350234496215 + 0.4037745216747476*lm - 
          0.16547868403878982*lm^2 - 0.04455*lm^3) + 
        CF*((0.06246201412847353 - 0.02913153757081397*lm + 
            0.014623397097961788*lm^2 + 0.0081*lm^3)*NM + 
          (0.07200337388045931 - 0.02913153757081397*lm + 
            0.014623397097961788*lm^2 + 0.0081*lm^3)*NL + 
          (0.020965680848691066 - 0.02913153757081397*lm + 
            0.014623397097961788*lm^2 + 0.0081*lm^3)*NH))}, 
     {0.465, NC*(CF^2*(0.04045461673898781 + 0.08136447495516157*lm + 
          0.24780298061565842*lm^2 - 0.07155625*lm^3) + 
        CA*CF*(-0.021294490611987675 + 0.39911745990932357*lm - 
          0.16162343892931985*lm^2 - 0.04372881944444444*lm^3) + 
        CF*((0.06133711300187358 - 0.02891475604854612*lm + 
            0.014207481320482397*lm^2 + 0.007950694444444444*lm^3)*NM + 
          (0.070832761128364 - 0.02891475604854612*lm + 0.014207481320482397*
             lm^2 + 0.007950694444444444*lm^3)*NL + 
          (0.021160644039953606 - 0.02891475604854612*lm + 
            0.014207481320482397*lm^2 + 0.007950694444444444*lm^3)*NH))}, 
     {0.47, NC*(CF^2*(0.038347977491861765 + 0.07811875191315774*lm + 
          0.24448361148580625*lm^2 - 0.070225*lm^3) + 
        CA*CF*(-0.02267491955746042 + 0.3943986239060443*lm - 
          0.15782772353645175*lm^2 - 0.042915277777777774*lm^3) + 
        CF*((0.060224947889432806 - 0.028686359436271253*lm + 
            0.013799737612688196*lm^2 + 0.007802777777777777*lm^3)*NM + 
          (0.06967191301101161 - 0.028686359436271253*lm + 
            0.013799737612688196*lm^2 + 0.007802777777777777*lm^3)*NL + 
          (0.021335402716728367 - 0.028686359436271253*lm + 
            0.013799737612688196*lm^2 + 0.007802777777777777*lm^3)*NH))}, 
     {0.475, NC*(CF^2*(0.036314009450894365 + 0.07491805385728431*lm + 
          0.24115710103090396*lm^2 - 0.06890625*lm^3) + 
        CA*CF*(-0.024023032211615607 + 0.3896212521974156*lm - 
          0.1540910597866698*lm^2 - 0.042109375*lm^3) + 
        CF*((0.059125272243086176 - 0.02844682592949922*lm + 
            0.013400079052121781*lm^2 + 0.00765625*lm^3)*NM + 
          (0.06852063237589016 - 0.02844682592949922*lm + 
            0.013400079052121781*lm^2 + 0.00765625*lm^3)*NL + 
          (0.021490376004407206 - 0.02844682592949922*lm + 
            0.013400079052121781*lm^2 + 0.00765625*lm^3)*NH))}, 
     {0.48, NC*(CF^2*(0.03435167183780288 + 0.07176386594807951*lm + 
          0.23782423162178987*lm^2 - 0.0676*lm^3) + 
        CA*CF*(-0.025337328217463005 + 0.3847885342964891*lm - 
          0.15041296956446176*lm^2 - 0.04131111111111111*lm^3) + 
        CF*((0.05803785174167134 - 0.02819662480139357*lm + 
            0.013008418708690015*lm^2 + 0.007511111111111111*lm^3)*NM + 
          (0.0673787350142775 - 0.02819662480139357*lm + 0.013008418708690015*
             lm^2 + 0.007511111111111111*lm^3)*NL + 
          (0.021625981721396282 - 0.02819662480139357*lm + 
            0.013008418708690015*lm^2 + 0.007511111111111111*lm^3)*NH))}, 
     {0.485, NC*(CF^2*(0.03245988017628637 + 0.06865759437071786*lm + 
          0.23448578557081598*lm^2 - 0.06630625*lm^3) + 
        CA*CF*(-0.02661640866109691 + 0.37990361128300953*lm - 
          0.1467929747900569*lm^2 - 0.04052048611111111*lm^3) + 
        CF*((0.056962463871891335 - 0.027936216527332844*lm + 
            0.012624669658798222*lm^2 + 0.007367361111111111*lm^3)*NM + 
          (0.06624604922758971 - 0.027936216527332844*lm + 
            0.012624669658798222*lm^2 + 0.007367361111111111*lm^3)*NL + 
          (0.02174263631134995 - 0.027936216527332844*lm + 
            0.012624669658798222*lm^2 + 0.007367361111111111*lm^3)*NH))}, 
     {0.49, NC*(CF^2*(0.03063750980918522 + 0.0656005678743006*lm + 
          0.2311425450100025*lm^2 - 0.065025*lm^3) + 
        CA*CF*(-0.027858973097345068 + 0.3749695763887084*lm - 
          0.14323059749388736*lm^2 - 0.0397375*lm^3) + 
        CF*((0.05589889752232825 - 0.02766605290855834*lm + 
            0.012248744998888611*lm^2 + 0.007225*lm^3)*NM + 
          (0.06512241540697479 - 0.02766605290855834*lm + 
            0.012248744998888611*lm^2 + 0.007225*lm^3)*NL + 
          (0.021840754778472186 - 0.02766605290855834*lm + 
            0.012248744998888611*lm^2 + 0.007225*lm^3)*NH))}, 
     {0.495, NC*(CF^2*(0.02888339926395965 + 0.06259403928436817*lm + 
          0.22779529177433805*lm^2 - 0.06375625*lm^3) + 
        CA*CF*(-0.029063816657924874 + 0.3699894755812443*lm - 
          0.13972535988790452*lm^2 - 0.03896215277777778*lm^3) + 
        CF*((0.054846952590108494 - 0.02738657719484792*lm + 
            0.011880557858406884*lm^2 + 0.007084027777777778*lm^3)*NM + 
          (0.06400768562574034 - 0.02738657719484792*lm + 
            0.011880557858406884*lm^2 + 0.007084027777777778*lm^3)*NL + 
          (0.021920750625767878 - 0.02738657719484792*lm + 
            0.011880557858406884*lm^2 + 0.007084027777777778*lm^3)*NH))}, 
     {0.5, CF*NC*(CF*(0.027196353455763513 + 0.05963918696687057*lm + 
          0.22444480728852878*lm^2 - 0.0625*lm^3) + 
        CA*(-0.030229827274025785 + 0.36496630812853487*lm - 
          0.13627678443478797*lm^2 - 0.03819444444444445*lm^3) + 
        0.053806439606481786*NM - 0.02709822420313731*lm*NM + 
        0.011520021412385692*lm^2*NM + 0.006944444444444444*lm^3*NM + 
        0.06290172324884523*NL - 0.02709822420313731*lm*NL + 
        0.011520021412385692*lm^2*NL + 0.006944444444444444*lm^3*NL + 
        0.021983035795573053*NH - 0.02709822420313731*lm*NH + 
        0.011520021412385692*lm^2*NH + 0.006944444444444444*lm^3*NH)}, 
     {0.505, CF*NC*(CF*(0.02557514684001686 + 0.056737116381009096*lm + 
          0.22109187246630044*lm^2 - 0.06125625*lm^3) + 
        CA*(-0.031355982797648785 + 0.3599030272540145*lm - 
          0.13288439390948306*lm^2 - 0.037434375*lm^3) + 
        0.05277717933946292*NM - 0.026801420450897784*lm*NM + 
        0.011167048892633284*lm^2*NM + 0.00680625*lm^3*NM + 
        0.06180440253020548*NL - 0.026801420450897784*lm*NL + 
        0.011167048892633284*lm^2*NL + 0.00680625*lm^3*NL + 
        0.022028020615736478*NH - 0.026801420450897784*lm*NH + 
        0.011167048892633284*lm^2*NH + 0.00680625*lm^3*NH)}, 
     {0.51, CF*NC*(CF*(0.024018526244345362 + 0.053888861364150276*lm + 
          0.21773726759785134*lm^2 - 0.060025*lm^3) + 
        CA*(-0.032441348575134844 + 0.3548025405935966*lm - 
          0.12954771146797975*lm^2 - 0.03668194444444445*lm^3) + 
        0.05175900248114126*NM - 0.026496584255136058*lm*NM + 
        0.01082155360023874*lm^2*NM + 0.006669444444444445*lm^3*NM + 
        0.060715608272584966*NL - 0.026496584255136058*lm*NL + 
        0.01082155360023874*lm^2*NL + 0.006669444444444445*lm^3*NL + 
        0.022056113742288407*NH - 0.026496584255136058*lm*NH + 
        0.01082155360023874*lm^2*NH + 0.006669444444444445*lm^3*NH)}, 
     {0.515, CF*NC*(CF*(0.022525213769407967 + 0.051095385645918964*lm + 
          0.21438177225896546*lm^2 - 0.05880625*lm^3) + 
        CA*(-0.03348507469762582 + 0.34966771085586645*lm - 
          0.12626626070285443*lm^2 - 0.03593715277777778*lm^3) + 
        0.05075174926906153*NM - 0.026184125865282012*lm*NM + 
        0.010483448915670504*lm^2*NM + 0.0065340277777777775*lm^3*NM + 
        0.059635235445142105*NL - 0.026184125865282012*lm*NL + 
        0.010483448915670504*lm^2*NL + 0.0065340277777777775*lm^3*NL + 
        0.022067722111102875*NH - 0.026184125865282012*lm*NH + 
        0.010483448915670504*lm^2*NH + 0.0065340277777777775*lm^3*NH)}, 
     {0.52, CF*NC*(CF*(0.021093909462363322 + 0.048357584201952*lm + 
          0.21102616521518136*lm^2 - 0.0576*lm^3) + 
        CA*(-0.034486393533027807 + 0.3445013563698672*lm - 
          0.12303956570183362*lm^2 - 0.0352*lm^3) + 0.04975526915921894*NM - 
        0.02586444757633806*lm*NM + 0.010152648309424294*lm^2*NM + 
        0.0064*lm^3*NM + 0.058563188840334256*NL - 0.02586444757633806*lm*
         NL + 0.010152648309424294*lm^2*NL + 0.0064*lm^3*NL + 
        0.02206325088856747*NH - 0.02586444757633806*lm*NH + 
        0.010152648309424294*lm^2*NH + 0.0064*lm^3*NH)}, 
     {0.525, CF*NC*(CF*(0.01972329389462526 + 0.04567628461122089*lm + 
          0.20767122433194404*lm^2 - 0.05640625*lm^3) + 
        CA*(-0.03544461728284322 + 0.33930625165251826*lm - 
          0.11986715110270087*lm^2 - 0.03447048611111111*lm^3) + 
        0.048769420500853124*NM - 0.025537943844751873*lm*NM + 
        0.009829065352006219*lm^2*NM + 0.006267361111111111*lm^3*NM + 
        0.0574993827353989*NL - 0.025537943844751873*lm*NL + 
        0.009829065352006219*lm^2*NL + 0.006267361111111111*lm^3*NL + 
        0.022043103425319375*NH - 0.025537943844751873*lm*NH + 
        0.009829065352006219*lm^2*NH + 0.006267361111111111*lm^3*NH)}, 
     {0.53, CF*NC*(CF*(0.01841203062648205 + 0.04305224838852931*lm + 
          0.20431772648863522*lm^2 - 0.055225*lm^3) + 
        CA*(-0.03635913560659957 + 0.3340851279721742*lm - 
          0.11674854214583404*lm^2 - 0.03374861111111111*lm^3) + 
        0.04779407022139988*NM - 0.02520500140303898*lm*NM + 
        0.009512613723484976*lm^2*NM + 0.006136111111111111*lm^3*NM + 
        0.0564437405641273*NL - 0.02520500140303898*lm*NL + 
        0.009512613723484976*lm^2*NL + 0.006136111111111111*lm^3*NL + 
        0.02200768121223104*NH - 0.02520500140303898*lm*NH + 
        0.009512613723484976*lm^2*NH + 0.006136111111111111*lm^3*NH)}, 
     {0.535, CF*NC*(CF*(0.01715876856319097 + 0.040486172292511724*lm + 
          0.20096644749633055*lm^2 - 0.05405625*lm^3) + 
        CA*(-0.03722941331196703 + 0.3288406739080823*lm - 
          0.11368326472446466*lm^2 - 0.033034375*lm^3) + 
        0.04682909352128512*NM - 0.024865999373132622*lm*NM + 
        0.009203207222629937*lm^2*NM + 0.00600625*lm^3*NM + 
        0.05539619459861154*NL - 0.024865999373132622*lm*NL + 
        0.009203207222629937*lm^2*NL + 0.00600625*lm^3*NL + 
        0.021957383838560694*NH - 0.024865999373132622*lm*NH + 
        0.009203207222629937*lm^2*NH + 0.00600625*lm^3*NH)}, 
     {0.54, CF*NC*(CF*(0.015962144206965366 + 0.03797868960946681*lm + 
          0.19761816201913887*lm^2 - 0.0529*lm^3) + 
        CA*(-0.03805498810870966 + 0.3235755359055202*lm - 
          0.11067084543274847*lm^2 - 0.032327777777777775*lm^3) + 
        0.0458743735782547*NM - 0.024521309378441637*lm*NM + 
        0.008900759775651237*lm^2*NM + 0.005877777777777778*lm^3*NM + 
        0.05435668564065602*NL - 0.024521309378441637*lm*NL + 
        0.008900759775651237*lm^2*NL + 0.005877777777777778*lm^3*NL + 
        0.021892608952186334*NH - 0.024521309378441637*lm*NH + 
        0.008900759775651237*lm^2*NH + 0.005877777777777778*lm^3*NH)}, 
     {0.545, CF*NC*(CF*(0.014820783809085624 + 0.035530371413364965*lm + 
          0.1942736434989842*lm^2 - 0.05175625*lm^3) + 
        CA*(-0.03883546842466676 + 0.31829231882641495*lm - 
          0.10771081161173188*lm^2 - 0.03162881944444444*lm^3) + 
        0.04492980126094308*NM - 0.024171295654599873*lm*NM + 
        0.00860518544455731*lm^2*NM + 0.0057506944444444446*lm^3*NM + 
        0.05332516272255409*NL - 0.024171295654599873*lm*NL + 
        0.00860518544455731*lm^2*NL + 0.0057506944444444446*lm^3*NL + 
        0.02181375222184481*NH - 0.024171295654599873*lm*NH + 
        0.00860518544455731*lm^2*NH + 0.0057506944444444446*lm^3*NH)}, 
     {0.55, CF*NC*(CF*(0.013733305426187973 + 0.033141727802374094*lm + 
          0.190933664083698*lm^2 - 0.050625*lm^3) + 
        CA*(-0.0395705312820115 + 0.3129935864952664*lm - 
          0.10480269139329566*lm^2 - 0.0309375*lm^3) + 0.04399527485139313*
         NM - 0.02381631515889376*lm*NM + 0.008316398435144668*lm^2*NM + 
        0.005625*lm^3*NM + 0.05230158281694012*NL - 0.02381631515889376*lm*
         NL + 0.008316398435144668*lm^2*NL + 0.005625*lm^3*NL + 
        0.021721207301300866*NH - 0.02381631515889376*lm*NH + 
        0.008316398435144668*lm^2*NH + 0.005625*lm^3*NH)}, 
     {0.555, CF*NC*(CF*(0.012698320884615475 + 0.030813209112251716*lm + 
          0.18759899455829315*lm^2 - 0.04950625*lm^3) + 
        CA*(-0.040259920232083045 + 0.30768186224021404*lm - 
          0.10194601374215417*lm^2 - 0.030253819444444444*lm^3) + 
        0.043070699776247834*NM - 0.02345671767835694*lm*NM + 
        0.008034313104634093*lm^2*NM + 0.005500694444444444*lm^3*NM + 
        0.051285910555436645*NL - 0.02345671767835694*lm*NL + 
        0.008034313104634093*lm^2*NL + 0.005500694444444444*lm^3*NL + 
        0.02161536579537374*NH - 0.02345671767835694*lm*NH + 
        0.008034313104634093*lm^2*NH + 0.005500694444444444*lm^3*NH)}, 
     {0.56, CF*NC*(CF*(0.01171443765655351 + 0.02854520710695428*lm + 
          0.18427040427929814*lm^2 - 0.0484*lm^3) + 
        CA*(-0.040903443347136643 + 0.30235962942910594*lm - 
          0.09914030849598446*lm^2 - 0.02957777777777778*lm^3) + 
        0.04215598834634347*NM - 0.023092845936523408*lm*NM + 
        0.007758843968966872*lm^2*NM + 0.005377777777777778*lm^3*NM + 
        0.05027811795582485*NL - 0.023092845936523408*lm*NL + 
        0.007758843968966872*lm^2*NL + 0.005377777777777778*lm^3*NL + 
        0.02149661722775182*NH - 0.023092845936523408*lm*NH + 
        0.007758843968966872*lm^2*NH + 0.005377777777777778*lm^3*NH)}, 
     {0.565, CF*NC*(CF*(0.010780260651517144 + 0.026338056146816644*lm + 
          0.1809486611120333*lm^2 - 0.04730625*lm^3) + 
        CA*(-0.041500971267403104 + 0.2970293320004422*lm - 
          0.09638510640375741*lm^2 - 0.028909375*lm^3) + 
        0.04125105950444222*NM - 0.022725035698832732*lm*NM + 
        0.007489905709774076*lm^2*NM + 0.00525625*lm^3*NM + 
        0.049278184157475605*NL - 0.022725035698832732*lm*NL + 
        0.007489905709774076*lm^2*NL + 0.00525625*lm^3*NL + 
        0.021365349010528435*NH - 0.022725035698832732*lm*NH + 
        0.007489905709774076*lm^2*NH + 0.00525625*lm^3*NH)}, 
     {0.57, CF*NC*(CF*(0.009894393926609703 + 0.024192034334656203*lm + 
          0.17763453137071714*lm^2 - 0.046225*lm^3) + 
        CA*(-0.04205243530189482 + 0.2916933749890817*lm - 
          0.09367993916233953*lm^2 - 0.02824861111111111*lm^3) + 
        0.04035583858085011*NM - 0.022353615876682924*lm*NM + 
        0.00722741318103143*lm^2*NM + 0.005136111111111111*lm^3*NM + 
        0.04828609516478651*NL - 0.022353615876682924*lm*NL + 
        0.00722741318103143*lm^2*NL + 0.005136111111111111*lm^3*NL + 
        0.021221946415394474*NH - 0.022353615876682924*lm*NH + 
        0.00722741318103143*lm^2*NH + 0.005136111111111111*lm^3*NH)}, 
     {0.575, CF*NC*(CF*(0.009055442318830336 + 0.02210736464015659*lm + 
          0.17432877976129427*lm^2 - 0.04515625*lm^3) + 
        CA*(-0.042557825581440153 + 0.2863541250466142*lm - 
          0.09102433945143129*lm^2 - 0.027595486111111112*lm^3) + 
        0.03947025705667426*NM - 0.021978908630128413*lm*NM + 
        0.0069712814154117494*lm^2*NM + 0.005017361111111111*lm^3*NM + 
        0.047301843598378426*NL - 0.021978908630128413*lm*NL + 
        0.0069712814154117494*lm^2*NL + 0.005017361111111111*lm^3*NL + 
        0.021066792546425902*NH - 0.021978908630128413*lm*NH + 
        0.0069712814154117494*lm^2*NH + 0.005017361111111111*lm^3*NH)}, 
     {0.58, CF*NC*(CF*(0.00826201300257292 + 0.020084216002886207*lm + 
          0.17103216932688162*lm^2 - 0.0441*lm^3) + 
        CA*(-0.043017189262471334 + 0.28101391095631145*lm - 
          0.08841784096690568*lm^2 - 0.02695*lm^3) + 0.03859425233448102*
         NM - 0.021601229469222282*lm*NM + 0.006721425630346486*lm^2*NM + 
        0.0049*lm^3*NM + 0.04632542845381306*NL - 0.021601229469222282*lm*
         NL + 0.006721425630346486*lm^2*NL + 0.0049*lm^3*NL + 
        0.020900268314406698*NH - 0.021601229469222282*lm*NH + 
        0.006721425630346486*lm^2*NH + 0.0049*lm^3*NH)}, 
     {0.585, CF*NC*(CF*(0.007512716975329305 + 0.018122704414306162*lm + 
          0.16774546139573332*lm^2 - 0.04305625*lm^3) + 
        CA*(-0.0434306287801336 + 0.2756750241425852*lm - 
          0.08585997845260743*lm^2 - 0.026312152777777778*lm^3) + 
        0.037727767516123986*NM - 0.021220887354003456*lm*NM + 
        0.0064777612338074095*lm^2*NM + 0.004784027777777778*lm^3*NM + 
        0.045356854867600604*NL - 0.021220887354003456*lm*NL + 
        0.0064777612338074095*lm^2*NL + 0.004784027777777778*lm^3*NL + 
        0.020722752412629816*NH - 0.021220887354003456*lm*NH + 
        0.0064777612338074095*lm^2*NH + 0.004784027777777778*lm^3*NH)}, 
     {0.59, CF*NC*(CF*(0.006806170474485988 + 0.01622289397912126*lm + 
          0.16446941553162842*lm^2 - 0.042025*lm^3) + 
        CA*(-0.04379830014932421 + 0.2703397191748885*lm - 
          0.08335028773067152*lm^2 - 0.025681944444444445*lm^3) + 
        0.036870751187518265*NM - 0.02083818479313101*lm*NM + 
        0.006240203829819064*lm^2*NM + 0.004669444444444445*lm^3*NM + 
        0.04439613389027379*NL - 0.02083818479313101*lm*NL + 
        0.006240203829819064*lm^2*NL + 0.004669444444444445*lm^3*NL + 
        0.020534621294121102*NH - 0.02083818479313101*lm*NH + 
        0.006240203829819064*lm^2*NH + 0.004669444444444445*lm^3*NH)}, 
     {0.595, CF*NC*(CF*(0.006140996327984935 + 0.014384797956326306*lm + 
          0.1612047894865905*lm^2 - 0.04100625*lm^3) + 
        CA*(-0.044120411312310245 + 0.2650102142660091*lm - 
          0.08088830573041692*lm^2 - 0.025059375*lm^3) + 
        0.036023157210144166*NM - 0.020453417941169078*lm*NM + 
        0.006008669223712167*lm^2*NM + 0.00455625*lm^3*NM + 
        0.04344328226631196*NL - 0.020453417941169078*lm*NL + 
        0.006008669223712167*lm^2*NL + 0.00455625*lm^3*NL + 
        0.02033624915023303*NH - 0.020453417941169078*lm*NH + 
        0.006008669223712167*lm^2*NH + 0.00455625*lm^3*NH)}, 
     {0.6, CF*NC*(CF*(0.005515825241505926 + 0.012608379780298102*lm + 
          0.15795233915585016*lm^2 - 0.04*lm^3) + 
        CA*(-0.04439722053161314 + 0.2596886917647111*lm - 
          0.07847357051586934*lm^2 - 0.024444444444444446*lm^3) + 
        0.035184944519070546*NM - 0.020066876694527003*lm*NM + 
        0.005783073427127758*lm^2*NM + 0.0044444444444444444*lm^3*NM + 
        0.04249832222070556*NL - 0.020066876694527003*lm*NL + 
        0.005783073427127758*lm^2*NL + 0.0044444444444444444*lm^3*NL + 
        0.020128007890557183*NH - 0.020066876694527003*lm*NH + 
        0.005783073427127758*lm^2*NH + 0.0044444444444444444*lm^3*NH)}, 
     {0.605, CF*NC*(CF*(0.004929297024719392 + 0.010893554062281215*lm + 
          0.15471281853496674*lm^2 - 0.03900625*lm^3) + 
        CA*(-0.044629034826885565 + 0.25437729864269176*lm - 
          0.07610562131196477*lm^2 - 0.023837152777777777*lm^3) + 
        0.03435607692729451*NM - 0.019678844786060558*lm*NM + 
        0.005563332662781473*lm^2*NM + 0.004334027777777778*lm^3*NM + 
        0.041561281251958175*NL - 0.019678844786060558*lm*NL + 
        0.005563332662781473*lm^2*NL + 0.004334027777777778*lm^3*NL + 
        0.019910267124106238*NH - 0.019678844786060558*lm*NH + 
        0.005563332662781473*lm^2*NH + 0.004334027777777778*lm^3*NH)}, 
     {0.61, CF*NC*(CF*(0.00438006175905498 + 0.009240187572613197*lm + 
          0.15148697967902702*lm^2 - 0.038025*lm^3) + 
        CA*(-0.04481620845454362 + 0.2490781469758274*lm - 
          0.07378399852948347*lm^2 - 0.0232375*lm^3) + 0.03353652293620059*
         NM - 0.01928959987834103*lm*NM + 0.005349363368996996*lm^2*NM + 
        0.004225*lm^3*NM + 0.04063219193132959*NL - 0.01928959987834103*lm*
         NL + 0.005349363368996996*lm^2*NL + 0.004225*lm^3*NL + 
        0.019683394141718127*NH - 0.01928959987834103*lm*NH + 
        0.005349363368996996*lm^2*NH + 0.004225*lm^3*NH)}, 
     {0.615, CF*NC*(CF*(0.0038667809093317312 + 0.007648100204031941*lm + 
          0.14827557266384386*lm^2 - 0.03705625*lm^3) + 
        CA*(-0.04495914142895262 + 0.2437933144196896*lm - 
          0.07150824378876208*lm^2 - 0.022645486111111113*lm^3) + 
        0.032726255551948746*NM - 0.01889941365559982*lm*NM + 
        0.00514108220401735*lm^2*NM + 0.004117361111111111*lm^3*NM + 
        0.039711091708129885*NL - 0.01889941365559982*lm*NL + 
        0.00514108220401735*lm^2*NL + 0.004117361111111111*lm^3*NL + 
        0.019447753899636676*NH - 0.01889941365559982*lm*NH + 
        0.00514108220401735*lm^2*NH + 0.004117361111111111*lm^3*NH)}, 
     {0.62, CF*NC*(CF*(0.0033881283815007826 + 0.006117065916404854*lm + 
          0.14507934554907867*lm^2 - 0.0361*lm^3) + 
        CA*(-0.04505827808399998 + 0.23852484467932109*lm - 
          0.0692778999422297*lm^2 - 0.02206111111111111*lm^3) + 
        0.03192525210760666*NM - 0.018508551914357223*lm*NM + 
        0.0049384060501023695*lm^2*NM + 0.004011111111111111*lm^3*NM + 
        0.03879802272088022*NL - 0.018508551914357223*lm*NL + 
        0.0049384060501023695*lm^2*NL + 0.004011111111111111*lm^3*NL + 
        0.019203709004224828*NH - 0.018508551914357223*lm*NH + 
        0.0049384060501023695*lm^2*NH + 0.004011111111111111*lm^3*NH)}, 
     {0.625, CF*NC*(CF*(0.0029427915286604446 + 0.004646813663216103*lm + 
          0.1418990443432166*lm^2 - 0.03515625*lm^3) + 
        CA*(-0.04511410567392258 + 0.23327474797326597*lm - 
          0.06709251109581207*lm^2 - 0.021484375*lm^3) + 
        0.031133494090847497*NM - 0.018117274652744573*lm*NM + 
        0.004741252017420377*lm^2*NM + 0.00390625*lm^3*NM + 
        0.037893031614162076*NL - 0.018117274652744573*lm*NL + 
        0.004741252017420377*lm^2*NL + 0.00390625*lm^3*NL + 
        0.01895161969776808*NH - 0.018117274652744573*lm*NH + 
        0.004741252017420377*lm^2*NH + 0.00390625*lm^3*NH)}, 
     {0.63, CF*NC*(CF*(0.0025294721074164326 + 0.003237028300144686*lm + 
          0.13873541297032424*lm^2 - 0.034225*lm^3) + 
        CA*(-0.0451271530122885 + 0.2280450014918556*lm - 
          0.06495162262924631*lm^2 - 0.02091527777777778*lm^3) + 
        0.030350966977040036*NM - 0.01772583615852987*lm*NM + 
        0.004549537447741752*lm^2*NM + 0.0038027777777777778*lm^3*NM + 
        0.036996169360982475*NL - 0.01772583615852987*lm*NL + 
        0.004549537447741752*lm^2*NL + 0.0038027777777777778*lm^3*NL + 
        0.018691843845327346*NH - 0.01772583615852987*lm*NH + 
        0.004549537447741752*lm^2*NH + 0.0038027777777777778*lm^3*NH)}, 
     {0.635, CF*NC*(CF*(0.0021468871865765807 + 0.0018873514760623029*lm + 
          0.13558919323852367*lm^2 - 0.03330625*lm^3) + 
        CA*(-0.04509798914806546 + 0.22283754984975665*lm - 
          0.06285478121534666*lm^2 - 0.020353819444444445*lm^3) + 
        0.029577660067563547*NM - 0.017334485095857468*lm*NM + 
        0.0043631799179418155*lm^2*NM + 0.0037006944444444444*lm^3*NM + 
        0.03610749109048773*NL - 0.017334485095857468*lm*NL + 
        0.0043631799179418155*lm^2*NL + 0.0037006944444444444*lm^3*NL + 
        0.018424736922601968*NH - 0.017334485095857468*lm*NH + 
        0.0043631799179418155*lm^2*NH + 0.0037006944444444444*lm^3*NH)}, 
     {0.64, CF*NC*(CF*(0.0017937700100894827 + 0.0005973825067761259*lm + 
          0.13246112481011868*lm^2 - 0.0324*lm^3) + 
        CA*(-0.04502722207773898 + 0.21765430553279283*lm - 
          0.060801534838260805*lm^2 - 0.0198*lm^3) + 0.028813566333185152*
         NM - 0.016943464590712963*lm*NM + 0.004182097243320146*lm^2*NM + 
        0.0036*lm^3*NM + 0.03522705592086413*NL - 0.016943464590712963*lm*
         NL + 0.004182097243320146*lm^2*NL + 0.0036*lm^3*NL + 
        0.018150652004764976*NH - 0.016943464590712963*lm*NH + 
        0.004182097243320146*lm^2*NH + 0.0036*lm^3*NH)}, 
     {0.645, CF*NC*(CF*(0.0014688708160599847 - 0.0006333207681624964*lm + 
          0.12935194517331136*lm^2 - 0.03150625*lm^3) + 
        CA*(-0.04491549749247362 + 0.21249714933905708*lm - 
          0.05879143281075418*lm^2 - 0.019253819444444445*lm^3) + 
        0.02805868226234244*NM - 0.016553012315125078*lm*NM + 
        0.0040062074807431835*lm^2*NM + 0.0035006944444444443*lm^3*NM + 
        0.034354926797268696*NL - 0.016553012315125078*lm*NL + 
        0.0040062074807431835*lm^2*NL + 0.0035006944444444443*lm^3*NL + 
        0.017869939756234125*NH - 0.016553012315125078*lm*NH + 
        0.0040062074807431835*lm^2*NH + 0.0035006944444444443*lm^3*NH)}, 
     {0.65, CF*NC*(CF*(0.0011709576136011393 - 0.0018052411452665115*lm + 
          0.12626238961544967*lm^2 - 0.030625*lm^3) + 
        CA*(-0.04476349755933978 + 0.20736793081433433*lm - 
          0.05682402579055854*lm^2 - 0.01871527777777778*lm^3) + 
        0.027313007714179258*NM - 0.0161633605701166*lm*NM + 
        0.003835428931616705*lm^2*NM + 0.0034027777777777776*lm^3*NM + 
        0.033491170334638165*NL - 0.0161633605701166*lm*NL + 
        0.003835428931616705*lm^2*NL + 0.0034027777777777776*lm^3*NL + 
        0.017582948421343517*NH - 0.0161633605701166*lm*NH + 
        0.003835428931616705*lm^2*NH + 0.0034027777777777776*lm^3*NH)}, 
     {0.655, CF*NC*(CF*(0.0008988169192120182 - 0.0029189012332262003*lm + 
          0.12319319119774934*lm^2 - 0.02975625*lm^3) + 
        CA*(-0.04457193973565701 + 0.20226846868185966*lm - 
          0.054898865795819846*lm^2 - 0.018184375*lm^3) + 
        0.026576545776187226*NM - 0.015774736367416952*lm*NM + 
        0.003669680144694517*lm^2*NM + 0.00330625*lm^3*NM + 
        0.03263585666522934*NL - 0.015774736367416952*lm*NL + 
        0.003669680144694517*lm^2*NL + 0.00330625*lm^3*NL + 
        0.017290023815881905*NH - 0.015774736367416952*lm*NH + 
        0.003669680144694517*lm^2*NH + 0.00330625*lm^3*NH)}, 
     {0.66, CF*NC*(CF*(0.0006512544543034785 - 0.003974862645018518*lm + 
          0.12014508073143478*lm^2 - 0.0289*lm^3) + 
        CA*(-0.044341575615532425 + 0.19720055126644045*lm - 
          0.05301550621967875*lm^2 - 0.01766111111111111*lm^3) + 
        0.025849302626310407*NM - 0.015387361509949278*lm*NM + 
        0.00350887991872947*lm^2*NM + 0.003211111111111111*lm^3*NM + 
        0.0317890592907483*NL - 0.015387361509949278*lm*NL + 
        0.00350887991872947*lm^2*NL + 0.003211111111111111*lm^3*NL + 
        0.016991509319465026*NH - 0.015387361509949278*lm*NH + 
        0.00350887991872947*lm^2*NH + 0.003211111111111111*lm^3*NH)}, 
     {0.665, CF*NC*(CF*(0.0004270958054295018 - 0.004973725205708904*lm + 
          0.11711878675524612*lm^2 - 0.02805625*lm^3) + 
        CA*(-0.044073189807699385 + 0.1921659369129734*lm - 
          0.051173501844016256*lm^2 - 0.01714548611111111*lm^3) + 
        0.025131287399374924*NM - 0.015001452671105267*lm*NM + 
        0.003352947304972653*lm^2*NM + 0.003117361111111111*lm^3*NM + 
        0.03095085493893072*NL - 0.015001452671105267*lm*NL + 
        0.003352947304972653*lm^2*NL + 0.003117361111111111*lm^3*NL + 
        0.016687745868710385*NH - 0.015001452671105267*lm*NH + 
        0.003352947304972653*lm^2*NH + 0.003117361111111111*lm^3*NH)}, 
     {0.67, CF*NC*(CF*(0.00022518704871992847 - 0.005916126175646211*lm + 
          0.11411503551426211*lm^2 - 0.027225*lm^3) + 
        CA*(-0.043767598843787905 + 0.18716635439939147*lm - 
          0.04937240885239538*lm^2 - 0.0166375*lm^3) + 0.024422512057709768*
         NM - 0.014617221472821207*lm*NM + 0.003201801609526433*lm^2*NM + 
        0.003025*lm^3*NM + 0.030121323424439607*NL - 0.014617221472821207*
         lm*NL + 0.003201801609526433*lm^2*NL + 0.003025*lm^3*NL + 
        0.016379071951184185*NH - 0.014617221472821207*lm*NH + 
        0.003201801609526433*lm^2*NH + 0.003025*lm^3*NH)}, 
     {0.675, CF*NC*(CF*(0.00004439533995117041 - 0.0068027394887559475*lm + 
          0.11113455093998906*lm^2 - 0.02640625*lm^3) + 
        CA*(-0.043425650116183045 + 0.1822035033440782*lm - 
          0.04761178484222891*lm^2 - 0.016137152777777778*lm^3) + 
        0.023722991265829316*NM - 0.01423487456246896*lm*NM + 
        0.003055362395556771*lm^2*NM + 0.0029340277777777776*lm^3*NM + 
        0.029300547513951215*NL - 0.01423487456246896*lm*NL + 
        0.003055362395556771*lm^2*NL + 0.0029340277777777776*lm^3*NL + 
        0.016065823600091074*NH - 0.01423487456246896*lm*NH + 
        0.003055362395556771*lm^2*NH + 0.0029340277777777776*lm^3*NH)}, 
     {0.68, CF*NC*(CF*(-0.00011639052836529215 - 0.007634275005641573*lm + 
          0.10817805463166955*lm^2 - 0.0256*lm^3) + 
        CA*(-0.04304822084465243 + 0.17727905460778892*lm - 
          0.04589118883620195*lm^2 - 0.015644444444444443*lm^3) + 
        0.02303274226905209*NM - 0.013854613688575797*lm*NM + 
        0.0029135494853700507*lm^2*NM + 0.0028444444444444446*lm^3*NM + 
        0.028488612795303812*NL - 0.013854613688575797*lm*NL + 
        0.0029135494853700507*lm^2*NL + 0.0028444444444444446*lm^3*NL + 
        0.015748334389678424*NH - 0.013854613688575797*lm*NH + 
        0.0029135494853700507*lm^2*NH + 0.0028444444444444446*lm^3*NH)}, 
     {0.685, CF*NC*(CF*(-0.0002582596015512644 - 0.008411477781208208*lm + 
          0.10524626583876484*lm^2 - 0.02480625*lm^3) + 
        CA*(-0.042636217070947446 + 0.17239465069012147*lm - 
          0.04421018129297704*lm^2 - 0.015159375*lm^3) + 
        0.022351784775934375*NM - 0.013476635775387207*lm*NM + 
        0.002776282962359462*lm^2*NM + 0.00275625*lm^3*NM + 
        0.027685607550587858*NL - 0.013476635775387207*lm*NL + 
        0.002776282962359462*lm^2*NL + 0.00275625*lm^3*NL + 
        0.015426935431327969*NH - 0.013476635775387207*lm*NH + 
        0.002776282962359462*lm^2*NH + 0.00275625*lm^3*NH)}, 
     {0.69, CF*NC*(CF*(-0.00038227826771387326 - 0.0091351273465277*lm + 
          0.10233990144456781*lm^2 - 0.024025*lm^3) + 
        CA*(-0.04219057268060592 + 0.16755190612058052*lm - 
          0.04256832411720856*lm^2 - 0.014681944444444444*lm^3) + 
        0.021680140844401022*NM - 0.013101132996286869*lm*NM + 
        0.0026434831728257987*lm^2*NM + 0.0026694444444444443*lm^3*NM + 
        0.026891622633060098*NL - 0.013101132996286869*lm*NL + 
        0.0026434831728257987*lm^2*NL + 0.0026694444444444443*lm^3*NL + 
        0.015101955370308486*NH - 0.013101132996286869*lm*NH + 
        0.0026434831728257987*lm^2*NH + 0.0026694444444444443*lm^3*NH)}, 
     {0.695, CF*NC*(CF*(-0.0004894897918581711 - 0.009806037004668646*lm + 
          0.09945967595090394*lm^2 - 0.02325625*lm^3) + 
        CA*(-0.04171224845120638 + 0.1627524078442818*lm - 
          0.04096518066889204*lm^2 - 0.014212152777777778*lm^3) + 
        0.021017834771459652*NM - 0.012728292846088186*lm*NM + 
        0.0025150707276773406*lm^2*NM + 0.002584027777777778*lm^3*NM + 
        0.026106751347767593*NL - 0.012728292846088186*lm*NL + 
        0.0025150707276773406*lm^2*NL + 0.002584027777777778*lm^3*NL + 
        0.014773720383164154*NH - 0.012728292846088186*lm*NH + 
        0.0025150707276773406*lm^2*NH + 0.002584027777777778*lm^3*NH)}, 
     {0.7, CF*NC*(CF*(-0.0005809138779851976 - 0.010425053140219527*lm + 
          0.09660630146388009*lm^2 - 0.0225*lm^3) + 
        CA*(-0.041202231126345516 + 0.15799771560234416*lm - 
          0.03940031577207328*lm^2 - 0.01375*lm^3) + 0.020364892986387936*
         NM - 0.012358298212211781*lm*NM + 0.002390966504013323*lm^2*NM + 
        0.0025*lm^3*NM + 0.025331089335771384*NL - 0.012358298212211781*lm*
         NL + 0.002390966504013323*lm^2*NL + 0.0025*lm^3*NL + 
        0.014442554175714202*NH - 0.012358298212211781*lm*NH + 
        0.002390966504013323*lm^2*NH + 0.0025*lm^3*NH)}, 
     {0.705, CF*NC*(CF*(-0.0006575462580464324 - 0.010993054542237785*lm + 
          0.09378048768064198*lm^2 - 0.02175625*lm^3) + 
        CA*(-0.04066153251463184 + 0.15328936230701848*lm - 
          0.037873295722941014*lm^2 - 0.01329548611111111*lm^3) + 
        0.01972134394728715*NM - 0.011991327444763484*lm*NM + 
        0.0022710916465953353*lm^2*NM + 0.002417361111111111*lm^3*NM + 
        0.024564734461862782*NL - 0.011991327444763484*lm*NL + 
        0.0022710916465953353*lm^2*NL + 0.002417361111111111*lm^3*NL + 
        0.014108777981640197*NH - 0.011991327444763484*lm*NH + 
        0.0022710916465953353*lm^2*NH + 0.002417361111111111*lm^3*NH)}, 
     {0.71, CF*NC*(CF*(-0.0007203583066697376 - 0.01151095174036223*lm + 
          0.09098294187710257*lm^2 - 0.021025*lm^3) + 
        CA*(-0.04009118861300859 + 0.14862885441160503*lm - 
          0.0363836882973262*lm^2 - 0.012848611111111111*lm^3) + 
        0.01908721804089869*NM - 0.011627554425527363*lm*NM + 
        0.002155367569210825*lm^2*NM + 0.0023361111111111113*lm^3*NM + 
        0.023807786705668778*NL - 0.011627554425527363*lm*NL + 
        0.002155367569210825*lm^2*NL + 0.0023361111111111113*lm^3*NL + 
        0.013772710561638275*NH - 0.011627554425527363*lm*NH + 
        0.002155367569210825*lm^2*NH + 0.0023361111111111113*lm^3*NH)}, 
     {0.715, CF*NC*(CF*(-0.0007702966806142651 - 0.011979686353830732*lm + 
          0.08821436889660539*lm^2 - 0.02030625*lm^3) + 
        CA*(-0.03949225875373903 + 0.14401767227521034*lm - 
          0.03493106275763004*lm^2 - 0.012409375*lm^3) + 
        0.018462547485583253*NM - 0.011267148635888355*lm*NM + 
        0.0020437159559327346*lm^2*NM + 0.00225625*lm^3*NM + 
        0.023060348056046096*NL - 0.011267148635888355*lm*NL + 
        0.0020437159559327346*lm^2*NL + 0.00225625*lm^3*NL + 
        0.013434668203114312*NH - 0.011267148635888355*lm*NH + 
        0.0020437159559327346*lm^2*NH + 0.00225625*lm^3*NH)}, 
     {0.72, CF*NC*(CF*(-0.0008082829819524543 - 0.012400230453149745*lm + 
          0.08547547113948765*lm^2 - 0.0196*lm^3) + 
        CA*(-0.038865824774406234 + 0.13945727052239743*lm - 
          0.03351498985920199*lm^2 - 0.011977777777777778*lm^3) + 
        0.01784736623736586*NM - 0.01091027522369911*lm*NM + 
        0.00193605876227915*lm^2*NM + 0.0021777777777777776*lm^3*NM + 
        0.022322522408666647*NL - 0.01091027522369911*lm*NL + 
        0.00193605876227915*lm^2*NL + 0.0021777777777777776*lm^3*NL + 
        0.013094964720400906*NH - 0.01091027522369911*lm*NH + 
        0.00193605876227915*lm^2*NH + 0.0021777777777777776*lm^3*NH)}, 
     {0.725, CF*NC*(CF*(-0.0008352134440162588 - 0.012773585934166687*lm + 
          0.0827669485535097*lm^2 - 0.01890625*lm^3) + 
        CA*(-0.038212990210298343 + 0.1349490783977827*lm - 
          0.03213504185618852*lm^2 - 0.011553819444444445*lm^3) + 
        0.017241709898952653*NM - 0.010557095069105599*lm*NM + 
        0.0018323182162767004*lm^2*NM + 0.0021006944444444445*lm^3*NM + 
        0.0215944154667001*NL - 0.010557095069105599*lm*NL + 
        0.0018323182162767004*lm^2*NL + 0.0021006944444444445*lm^3*NL + 
        0.012753911455475683*NH - 0.010557095069105599*lm*NH + 
        0.0018323182162767004*lm^2*NH + 0.0021006944444444445*lm^3*NH)}, 
     {0.73, CF*NC*(CF*(-0.0008519586391821781 - 0.013100783904300708*lm + 
          0.08008949862511819*lm^2 - 0.018225*lm^3) + 
        CA*(-0.03753487950856814 + 0.13049450011563496*lm - 
          0.030790792506872222*lm^2 - 0.0111375*lm^3) + 
        0.01664561563162861*NM - 0.010207764849346063*lm*NM + 
        0.0017324168194313132*lm^2*NM + 0.002025*lm^3*NM + 
        0.020876134644502206*NL - 0.010207764849346063*lm*NL + 
        0.0017324168194313132*lm^2*NL + 0.002025*lm^3*NL + 
        0.012411817279161243*NH - 0.010207764849346063*lm*NH + 
        0.0017324168194313132*lm^2*NH + 0.002025*lm^3*NH)}, 
     {0.735, CF*NC*(CF*(-0.0008593632076055997 - 0.013382884080691835*lm + 
          0.07744381637151183*lm^2 - 0.01755625*lm^3) + 
        CA*(-0.036832637263573505 + 0.12609491520453167*lm - 
          0.02948181707852054*lm^2 - 0.010728819444444444*lm^3) + 
        0.016059122069947945*NM - 0.009862437102537782*lm*NM + 
        0.0016362773476097955*lm^2*NM + 0.0019506944444444444*lm^3*NM + 
        0.020167788974220325*NL - 0.009862437102537782*lm*NL + 
        0.0016362773476097955*lm^2*NL + 0.0019506944444444444*lm^3*NL + 
        0.012068988592787697*NH - 0.009862437102537782*lm*NH + 
        0.0016362773476097955*lm^2*NH + 0.0019506944444444444*lm^3*NH)}, 
     {0.74, CF*NC*(CF*(-0.0008582456060494468 - 0.013620974200032861*lm + 
          0.07483059433347966*lm^2 - 0.0169*lm^3) + 
        CA*(-0.036107427472822154 + 0.12175167884712841*lm - 
          0.028207692351762428*lm^2 - 0.010327777777777778*lm^3) + 
        0.015482269239132007*NM - 0.009521260290466165*lm*NM + 
        0.001543822851835593*lm^2*NM + 0.0018777777777777777*lm^3*NM + 
        0.019469489015230327*NL - 0.009521260290466165*lm*NL + 
        0.001543822851835593*lm^2*NL + 0.0018777777777777777*lm^3*NL + 
        0.011725729330299415*NH - 0.009521260290466165*lm*NH + 
        0.001543822851835593*lm^2*NH + 0.0018777777777777777*lm^3*NH)}, 
     {0.745, CF*NC*(CF*(-0.0008493978759852338 - 0.013816169439852758*lm + 
          0.07225052256898244*lm^2 - 0.01625625*lm^3) + 
        CA*(-0.035360432812960745 + 0.11746612221509868*lm - 
          0.026967996624510732*lm^2 - 0.009934375*lm^3) + 
        0.014915098475091863*NM - 0.009184378860390523*lm*NM + 
        0.0014549766590019513*lm^2*NM + 0.00180625*lm^3*NM + 
        0.018781346766321688*NL - 0.009184378860390523*lm*NL + 
        0.0014549766590019513*lm^2*NL + 0.00180625*lm^3*NL + 
        0.011382340960788297*NH - 0.009184378860390523*lm*NH + 
        0.0014549766590019513*lm^2*NH + 0.00180625*lm^3*NH)}, 
     {0.75, CF*NC*(CF*(-0.0008335854301764165 - 0.01396961185102464*lm + 
          0.06970428864744967*lm^2 - 0.015625*lm^3) + 
        CA*(-0.03459285393526427 + 0.1132395527993005*lm - 
          0.025762309715447428*lm^2 - 0.009548611111111112*lm^3) + 
        0.014357652346995615*NM - 0.008851933305880869*lm*NM + 
        0.001369662372505593*lm^2*NM + 0.001736111111111111*lm^3*NM + 
        0.01810347558055011*NL - 0.008851933305880869*lm*NL + 
        0.001369662372505593*lm^2*NL + 0.001736111111111111*lm^3*NL + 
        0.011039122491436413*NH - 0.008851933305880869*lm*NH + 
        0.001369662372505593*lm^2*NH + 0.001736111111111111*lm^3*NH)}, 
     {0.755, CF*NC*(CF*(-0.0008115468569844427 - 0.014082469801275643*lm + 
          0.0671925776447648*lm^2 - 0.01500625*lm^3) + 
        CA*(-0.033805908780097364 + 0.10907325473522736*lm - 
          0.02459021296708818*lm^2 - 0.009170486111111112*lm^3) + 
        0.013809974582302834*NM - 0.008524060226699975*lm*NM + 
        0.0012878038728039117*lm^2*NM + 0.0016673611111111112*lm^3*NM + 
        0.017435990082679546*NL - 0.008524060226699975*lm*NL + 
        0.0012878038728039117*lm^2*NL + 0.0016673611111111112*lm^3*NL + 
        0.010696370470851526*NH - 0.008524060226699975*lm*NH + 
        0.0012878038728039117*lm^2*NH + 0.0016673611111111112*lm^3*NH)}, 
     {0.76, CF*NC*(CF*(-0.0007839937416672129 - 0.014155937429480271*lm + 
          0.06471607213891283*lm^2 - 0.0144*lm^3) + 
        CA*(-0.03300083190983408 + 0.10496848912380109*lm - 
          0.02345128924844216*lm^2 - 0.0088*lm^3) + 0.013272109994191011*
         NM - 0.008200892387744843*lm*NM + 0.0012093253178985742*lm^2*NM + 
        0.0016*lm^3*NM + 0.016779006089137793*NL - 0.008200892387744843*lm*
         NL + 0.0012093253178985742*lm^2*NL + 0.0016*lm^3*NL + 
        0.01035437899277956*NH - 0.008200892387744843*lm*NH + 
        0.0012093253178985742*lm^2*NH + 0.0016*lm^3*NH)}, 
     {0.765, CF*NC*(CF*(-0.0007516105039678021 - 0.014191234110522895*lm + 
          0.06227545220626508*lm^2 - 0.01380625*lm^3) + 
        CA*(-0.03217887385973734 + 0.10092649434756422*lm - 
          0.02234512295728245*lm^2 - 0.008437152777777778*lm^3) + 
        0.012744104411301223*NM - 0.007882558777061606*lm*NM + 
        0.0011341511437483244*lm^2*NM + 0.0015340277777777778*lm^3*NM + 
        0.016132640530412225*NL - 0.007882558777061606*lm*NL + 
        0.0011341511437483244*lm^2*NL + 0.0015340277777777778*lm^3*NL + 
        0.010013439700178609*NH - 0.007882558777061606*lm*NH + 
        0.0011341511437483244*lm^2*NH + 0.0015340277777777778*lm^3*NH)}, 
     {0.77, CF*NC*(CF*(-0.0007150542513183239 - 0.014189603930519256*lm + 
          0.059871395418476914*lm^2 - 0.013225*lm^3) + 
        CA*(-0.03134130050631356 + 0.09694848638232977*lm - 
          0.021271300022041886*lm^2 - 0.008081944444444444*lm^3) + 
        0.01222600460973254*NM - 0.007569184662947825*lm*NM + 
        0.0010622060646136762*lm^2*NM + 0.0014694444444444444*lm^3*NM + 
        0.015497011375814393*NL - 0.007569184662947825*lm*NL + 
        0.0010622060646136762*lm^2*NL + 0.0014694444444444444*lm^3*NL + 
        0.009673841789639634*NH - 0.007569184662947825*lm*NH + 
        0.0010622060646136762*lm^2*NH + 0.0014694444444444444*lm^3*NH)}, 
     {0.775, CF*NC*(CF*(-0.000674954647009777 - 0.014152315172190823*lm + 
          0.05750457683997514*lm^2 - 0.01265625*lm^3) + 
        CA*(-0.030489392452671512 + 0.0930356591043461*lm - 
          0.020229407903348526*lm^2 - 0.007734375*lm^3) + 
        0.01171785824721682*NM - 0.007260891650155984*lm*NM + 
        0.0009934150733360955*lm^2*NM + 0.00140625*lm^3*NM + 
        0.014872237560544453*NL - 0.007260891650155984*lm*NL + 
        0.0009934150733360955*lm^2*NL + 0.00140625*lm^3*NL + 
        0.009335872016139548*NH - 0.007260891650155984*lm*NH + 
        0.0009934150733360955*lm^2*NH + 0.00140625*lm^3*NH)}, 
     {0.78, CF*NC*(CF*(-0.0006319137927036528 - 0.014080659810189902*lm + 
          0.05517566902601245*lm^2 - 0.0121*lm^3) + 
        CA*(-0.029624444430427957 + 0.08918918459303496*lm - 
          0.01921903559521461*lm^2 - 0.007394444444444445*lm^3) + 
        0.011219713799407782*NM - 0.006957797735211878*lm*NM + 
        0.0009277034415541716*lm^2*NM + 0.0013444444444444445*lm^3*NM + 
        0.014258438914988441*NL - 0.006957797735211878*lm*NL + 
        0.0009277034415541716*lm^2*NL + 0.0013444444444444445*lm^3*NL + 
        0.0089998146981128*NH - 0.006957797735211878*lm*NH + 
        0.0009277034415541716*lm^2*NH + 0.0013444444444444445*lm^3*NH)}, 
     {0.785, CF*NC*(CF*(-0.0005865061246850391 - 0.013975953016177262*lm + 
          0.052885342021267254*lm^2 - 0.01155625*lm^3) + 
        CA*(-0.028747764717715587 + 0.08541021342936009*lm - 
          0.018239773625892235*lm^2 - 0.0070621527777777774*lm^3) + 
        0.010731620498220185*NM - 0.006660017360861462*lm*NM + 
        0.0008649967198591941*lm^2*NM + 0.0012840277777777778*lm^3*NM + 
        0.013655736096183433*NL - 0.006660017360861462*lm*NL + 
        0.0008649967198591941*lm^2*NL + 0.0012840277777777778*lm^3*NL + 
        0.008665951722828118*NH - 0.006660017360861462*lm*NH + 
        0.0008649967198591941*lm^2*NH + 0.0012840277777777778*lm^3*NH)}, 
     {0.79, CF*NC*(CF*(-0.0005392783232799749 - 0.013839532673458*lm + 
          0.05063426335896779*lm^2 - 0.011025*lm^3) + 
        CA*(-0.027860674572861212 + 0.08169987498988414*lm - 
          0.017291214058408572*lm^2 - 0.0067375*lm^3) + 
        0.010253628272156997*NM - 0.006367661469659604*lm*NM + 
        0.0008052207378924674*lm^2*NM + 0.001225*lm^3*NM + 
        0.013064250521387627*NL - 0.006367661469659604*lm*NL + 
        0.0008052207378924674*lm^2*NL + 0.001225*lm^3*NL + 
        0.008334562552057516*NH - 0.006367661469659604*lm*NH + 
        0.0008052207378924674*lm^2*NH + 0.001225*lm^3*NH)}, 
     {0.795, CF*NC*(CF*(-0.000490749234881923 - 0.013672758900985108*lm + 
          0.048423098060520524*lm^2 - 0.01050625*lm^3) + 
        CA*(-0.02696450768331444 + 0.07805927773657129*lm - 
          0.01637295049079301*lm^2 - 0.006420486111111111*lm^3) + 
        0.009785787688564414*NM - 0.0060808375567140355*lm*NM + 
        0.0007483016043866084*lm^2*NM + 0.0011673611111111112*lm^3*NM + 
        0.012484104303694264*NL - 0.0060808375567140355*lm*NL + 
        0.0007483016043866084*lm^2*NL + 0.0011673611111111112*lm^3*NL + 
        0.008005924228025103*NH - 0.0060808375567140355*lm*NH + 
        0.0007483016043866084*lm^2*NH + 0.0011673611111111112*lm^3*NH)}, 
     {0.8, CF*NC*(CF*(-0.00044140980605348495 - 0.01347701358654405*lm + 
          0.046252508635623024*lm^2 - 0.01*lm^3) + 
        CA*(-0.026060609629418904 + 0.07448950950239282*lm - 
          0.015484578056008152*lm^2 - 0.006111111111111111*lm^3) + 
        0.009328149897756328*NM - 0.005799649721597651*lm*NM + 
        0.0006941657071529972*lm^2*NM + 0.0011111111111111111*lm^3*NM + 
        0.011915420189630141*NL - 0.005799649721597651*lm*NL + 
        0.0006941657071529972*lm^2*NL + 0.0011111111111111111*lm^3*NL + 
        0.007680311379623673*NH - 0.005799649721597651*lm*NH + 
        0.0006941657071529972*lm^2*NH + 0.0011111111111111111*lm^3*NH)}, 
     {0.805, CF*NC*(CF*(-0.0003917230291899006 - 0.013253699928935245*lm + 
          0.04412315508284272*lm^2 - 0.00950625*lm^3) + 
        CA*(-0.025150337362629567 + 0.07099163777279235*lm - 
          0.014625693421596114*lm^2 - 0.005809375*lm^3) + 
        0.008880766578951782*NM - 0.005524198719442182*lm*NM + 
        0.0006427397130174754*lm^2*NM + 0.00105625*lm^3*NM + 
        0.011358321498681259*NL - 0.005524198719442182*lm*NL + 
        0.0006427397130174754*lm^2*NL + 0.00105625*lm^3*NL + 
        0.007357996228887458*NH - 0.005524198719442182*lm*NH + 
        0.0006427397130174754*lm^2*NH + 0.00105625*lm^3*NH)}, 
     {0.81, CF*NC*(CF*(-0.00034212389925050983 - 0.013004241988975087*lm + 
          0.04203569489064322*lm^2 - 0.009025*lm^3) + 
        CA*(-0.024235058697790714 + 0.06756670996306761*lm - 
          0.013795894789051365*lm^2 - 0.005515277777777778*lm^3) + 
        0.008443689887970627*NM - 0.005254582011226098*lm*NM + 
        0.0005939505677063088*lm^2*NM + 0.0010027777777777778*lm^3*NM + 
        0.01081293206468988*NL - 0.005254582011226098*lm*NL + 
        0.0005939505677063088*lm^2*NL + 0.0010027777777777778*lm^3*NL + 
        0.00703924859770986*NH - 0.005254582011226098*lm*NH + 
        0.0005939505677063088*lm^2*NH + 0.0010027777777777778*lm^3*NH)}, 
     {0.815, CF*NC*(CF*(-0.0002930193810832153 - 0.012730084249139672*lm + 
          0.0399907830388407*lm^2 - 0.00855625*lm^3) + 
        CA*(-0.023316151819100153 + 0.06421575369172486*lm - 
          0.012994781892930681*lm^2 - 0.005228819444444445*lm^3) + 
        0.008016972406634293*NM - 0.004990893813269459*lm*NM + 
        0.0005477254956843662*lm^2*NM + 0.0009506944444444444*lm^3*NM + 
        0.01027937617906891*NL - 0.004990893813269459*lm*NL + 
        0.0005477254956843662*lm^2*NL + 0.0009506944444444444*lm^3*NL + 
        0.006724335914795313*NH - 0.004990893813269459*lm*NH + 
        0.0005477254956843662*lm^2*NH + 0.0009506944444444444*lm^3*NH)}, 
     {0.82, CF*NC*(CF*(-0.000244788386885126 - 0.012432691181678895*lm + 
          0.03798907200047346*lm^2 - 0.0081*lm^3) + 
        CA*(-0.022395004799395525 + 0.06093977704986192*lm - 
          0.012221955999710663*lm^2 - 0.00495*lm^3) + 0.007600667093820256*
         NM - 0.004733225145948278*lm*NM + 0.0005039919999473932*lm^2*NM + 
        0.0009*lm^3*NM + 0.009757778535781213*NL - 0.004733225145948278*lm*
         NL + 0.0005039919999473932*lm^2*NL + 0.0009*lm^3*NL + 
        0.006413523222834848*NH - 0.004733225145948278*lm*NH + 
        0.0005039919999473932*lm^2*NH + 0.0009*lm^3*NH)}, 
     {0.825, CF*NC*(CF*(-0.0001977817633599922 - 0.012113546825032077*lm + 
          0.03603121174406822*lm^2 - 0.00765625*lm^3) + 
        CA*(-0.0214730151324089 + 0.05773976886663552*lm - 
          0.011477019906402755*lm^2 - 0.004678819444444445*lm^3) + 
        0.007194827238120328*NM - 0.004481663881640802*lm*NM + 
        0.0004626778617701977*lm^2*NM + 0.0008506944444444444*lm^3*NM + 
        0.009248264178032886*NL - 0.004481663881640802*lm*NL + 
        0.0004626778617701977*lm^2*NL + 0.0008506944444444444*lm^3*NL + 
        0.00610707318589526*NH - 0.004481663881640802*lm*NH + 
        0.0004626778617701977*lm^2*NH + 0.0008506944444444444*lm^3*NH)}, 
     {0.83, CF*NC*(CF*(-0.0001523222881498071 - 0.011774154368379634*lm + 
          0.03411784973628751*lm^2 - 0.007225*lm^3) + 
        CA*(-0.020551589277645596 + 0.054616698970867766*lm - 
          0.010759577938935411*lm^2 - 0.0044152777777777775*lm^3) + 
        0.006799506412054483*NM - 0.004236294791917969*lm*NM + 
        0.0004237111404124991*lm^2*NM + 0.0008027777777777778*lm^3*NM + 
        0.008750958446631249*NL - 0.004236294791917969*lm*NL + 
        0.0004237111404124991*lm^2*NL + 0.0008027777777777778*lm^3*NL + 
        0.005805246097012149*NH - 0.004236294791917969*lm*NH + 
        0.0004237111404124991*lm^2*NH + 0.0008027777777777778*lm^3*NH)}, 
     {0.835, CF*NC*(CF*(-0.00010870467513406418 - 0.011416035744168681*lm + 
          0.03224963094494282*lm^2 - 0.00680625*lm^3) + 
        CA*(-0.01963214221755286 + 0.05157151844884674*lm - 
          0.01006923595031272*lm^2 - 0.004159375*lm^3) + 
        0.006414758427793356*NM - 0.003997199593990125*lm*NM + 
        0.0003870201727841308*lm^2*NM + 0.00075625*lm^3*NM + 
        0.008265986929959548*NL - 0.003997199593990125*lm*NL + 
        0.0003870201727841308*lm^2*NL + 0.00075625*lm^3*NL + 
        0.005508299885977424*NH - 0.003997199593990125*lm*NH + 
        0.0003870201727841308*lm^2*NH + 0.00075625*lm^3*NH)}, 
     {0.84, CF*NC*(CF*(-0.00006719558820565775 - 0.011040731228453692*lm + 
          0.03042719784235892*lm^2 - 0.0064*lm^3) + 
        CA*(-0.018716097026653285 + 0.048605159898375244*lm - 
          0.00940560131855844*lm^2 - 0.003911111111111111*lm^3) + 
        0.006040637294344045*NM - 0.0037644569964219565*lm*NM + 
        0.0003525335730712313*lm^2*NM + 0.0007111111111111111*lm^3*NM + 
        0.007793475415521981*NL - 0.0037644569964219565*lm*NL + 
        0.0003525335730712313*lm^2*NL + 0.0007111111111111111*lm^3*NL + 
        0.005216490127312189*NH - 0.0037644569964219565*lm*NH + 
        0.0003525335730712313*lm^2*NH + 0.0007111111111111111*lm^3*NH)}, 
     {0.845, CF*NC*(CF*(-0.00002803366314731443 - 0.010649799048896581*lm + 
          0.02865119040907503*lm^2 - 0.00600625*lm^3) + 
        CA*(-0.017804884452326843 + 0.04571853767912153*lm - 
          0.008768282944454147*lm^2 - 0.003670486111111111*lm^3) + 
        0.005677197176155213*NM - 0.003538142744127397*lm*NM + 
        0.0003201802323249966*lm^2*NM + 0.0006673611111111111*lm^3*NM + 
        0.0073335498430139095*NL - 0.003538142744127397*lm*NL + 
        0.0003201802323249966*lm^2*NL + 0.0006673611111111111*lm^3*NL + 
        0.004930070048416259*NH - 0.003538142744127397*lm*NH + 
        0.0003201802323249966*lm^2*NH + 0.0006673611111111111*lm^3*NH)}, 
     {0.85, CF*NC*(CF*(8.570462753225005*^-6 - 0.010244815000273725*lm + 
          0.026922246137869345*lm^2 - 0.005625*lm^3) + 
        CA*(-0.016899942506934267 + 0.04291254815932532*lm - 
          0.008156891249079845*lm^2 - 0.0034375*lm^3) + 
        0.005324492353098826*NM - 0.003318329662656143*lm*NM + 
        0.0002898893180145173*lm^2*NM + 0.000625*lm^3*NM + 
        0.006886336258873523*NL - 0.003318329662656143*lm*NL + 
        0.0002898893180145173*lm^2*NL + 0.000625*lm^3*NL + 
        0.004649290537885825*NH - 0.003318329662656143*lm*NH + 
        0.0002898893180145173*lm^2*NH + 0.000625*lm^3*NH)}, 
     {0.855, CF*NC*(CF*(0.00004243411369727138 - 0.009827372067340516*lm + 
          0.025241000038093486*lm^2 - 0.00525625*lm^3) + 
        CA*(-0.016002716070982918 + 0.04018806995891165*lm - 
          0.007571038171165092*lm^2 - 0.0032121527777777777*lm^3) + 
        0.004982577181787203*NM - 0.0031050877017832286*lm*NM + 
        0.0002615902735451682*lm^2*NM + 0.0005840277777777778*lm^3*NM + 
        0.006451960772272479*NL - 0.0031050877017832286*lm*NL + 
        0.0002615902735451682*lm^2*NL + 0.0005840277777777778*lm^3*NL + 
        0.004374400153991109*NH - 0.0031050877017832286*lm*NH + 
        0.0002615902735451682*lm^2*NH + 0.0005840277777777778*lm^3*NH)}, 
     {0.86, CF*NC*(CF*(0.00007340253131324148 - 0.009399080054907128*lm + 
          0.023608084640304294*lm^2 - 0.0049*lm^3) + 
        CA*(-0.015114656507044608 + 0.0375459641890651*lm - 
          0.007010337164258487*lm^2 - 0.0029944444444444445*lm^3) + 
        0.0046515060581852705*NM - 0.00289848397841296*lm*NM + 
        0.0002352128177439674*lm^2*NM + 0.0005444444444444444*lm^3*NM + 
        0.006030549512504318*NL - 0.00289848397841296*lm*NL + 
        0.0002352128177439674*lm^2*NL + 0.0005444444444444444*lm^3*NL + 
        0.004105645133306118*NH - 0.00289848397841296*lm*NH + 
        0.0002352128177439674*lm^2*NH + 0.0005444444444444444*lm^3*NH)}, 
     {0.865, CF*NC*(CF*(0.00010134882386069031 - 0.008961565224982088*lm + 
          0.022024130001180527*lm^2 - 0.00455625*lm^3) + 
        CA*(-0.01423722128414281 + 0.03498707468831572*lm - 
          0.006474403193723011*lm^2 - 0.002784375*lm^3) + 
        0.004331333381479184*NM - 0.002698582818808352*lm*NM + 
        0.00021068694431327465*lm^2*NM + 0.00050625*lm^3*NM + 
        0.0056222285877306575*NL - 0.002698582818808352*lm*NL + 
        0.00021068694431327465*lm^2*NL + 0.00050625*lm^3*NL + 
        0.0038432693994828755*NH - 0.002698582818808352*lm*NH + 
        0.00021068694431327465*lm^2*NH + 0.00050625*lm^3*NH)}, 
     {0.87, CF*NC*(CF*(0.00012617390901004412 - 0.00851646994084324*lm + 
          0.02048976370871265*lm^2 - 0.004225*lm^3) + 
        CA*(-0.013371873612334502 + 0.03251222825518811*lm - 
          0.005962852733564492*lm^2 - 0.0025819444444444444*lm^3) + 
        0.004022113519163626*NM - 0.0025054458001570455*lm*NM + 
        0.00018794292125415017*lm^2*NM + 0.0004694444444444444*lm^3*NM + 
        0.005227124045046332*NL - 0.0025054458001570455*lm*NL + 
        0.00018794292125415017*lm^2*NL + 0.0004694444444444444*lm^3*NL + 
        0.0035875145721627885*NH - 0.0025054458001570455*lm*NH + 
        0.00018794292125415017*lm^2*NH + 0.0004694444444444444*lm^3*NH)}, 
     {0.875, CF*NC*(CF*(0.00014780645049595573 - 0.00806545231789853*lm + 
          0.01900561088765416*lm^2 - 0.00390625*lm^3) + 
        CA*(-0.012520082087219442 + 0.03012223487746404*lm - 
          0.005475303763100236*lm^2 - 0.002387152777777778*lm^3) + 
        0.003723900773311259*NM - 0.002319131791484521*lm*NM + 
        0.0001669112902606489*lm^2*NM + 0.00043402777777777775*lm^3*NM + 
        0.004845361831825822*NL - 0.002319131791484521*lm*NL + 
        0.0001669112902606489*lm^2*NL + 0.00043402777777777775*lm^3*NL + 
        0.003338619976018037*NH - 0.002319131791484521*lm*NH + 
        0.0001669112902606489*lm^2*NH + 0.00043402777777777775*lm^3*NH)}, 
     {0.88, CF*NC*(CF*(0.00016620278893085088 - 0.0076101858812018*lm + 
          0.017572294205223448*lm^2 - 0.0036*lm^3) + 
        CA*(-0.011683320344116968 + 0.02781788795810867*lm - 
          0.005011375763474559*lm^2 - 0.0022*lm^3) + 0.0034367493479889183*
         NM - 0.002139696993925279*lm*NM + 0.0001475228660862834*lm^2*NM + 
        0.0004*lm^3*NM + 0.004477067758314377*NL - 0.002139696993925279*lm*
         NL + 0.0001475228660862834*lm^2*NL + 0.0004*lm^3*NL + 
        0.0030968226499161478*NH - 0.002139696993925279*lm*NH + 
        0.0001475228660862834*lm^2*NH + 0.0004*lm^3*NH)}, 
     {0.885, CF*NC*(CF*(0.00018134686705431009 - 0.007152359229491681*lm + 
          0.016190433877045406*lm^2 - 0.00330625*lm^3) + 
        CA*(-0.0108630667216576 + 0.025599964537909876*lm - 
          0.004570689714027807*lm^2 - 0.002020486111111111*lm^3) + 
        0.0031607133177861996*NM - 0.0019671949803624846*lm*NM + 
        0.00012970873588384366*lm^2*NM + 0.0003673611111111111*lm^3*NM + 
        0.0041223674614283305*NL - 0.0019671949803624846*lm*NL + 
        0.00012970873588384366*lm^2*NL + 0.0003673611111111111*lm^3*NL + 
        0.0028623573562011305*NH - 0.0019671949803624846*lm*NH + 
        0.00012970873588384366*lm^2*NH + 0.0003673611111111111*lm^3*NH)}, 
     {0.89, CF*NC*(CF*(0.00019325014968341972 - 0.006693675705624193*lm + 
          0.014860647673322494*lm^2 - 0.003025*lm^3) + 
        CA*(-0.010060803934543566 + 0.023469225514879493*lm - 
          0.004152868088525143*lm^2 - 0.0018486111111111112*lm^3) + 
        0.002895846597423138*NM - 0.0018016767344464267*lm*NM + 
        0.00011340025851972286*lm^2*NM + 0.00033611111111111114*lm^3*NM + 
        0.00378138636973015*NL - 0.0018016767344464267*lm*NL + 
        0.00011340025851972286*lm^2*NL + 0.00033611111111111114*lm^3*NL + 
        0.0026354565900847875*NH - 0.0018016767344464267*lm*NH + 
        0.00011340025851972286*lm^2*NH + 0.00033611111111111114*lm^3*NH)}, 
     {0.895, CF*NC*(CF*(0.0002019515386191118 - 0.0062358530732724675*lm + 
          0.01358355092522528*lm^2 - 0.00275625*lm^3) + 
        CA*(-0.009278018755239153 + 0.02142641586046477*lm - 
          0.003757534851251218*lm^2 - 0.001684375*lm^3) + 
        0.0026422029124046928*NM - 0.0016431906890019782*lm*NM + 
        0.00009852906386385776*lm^2*NM + 0.00030625*lm^3*NM + 
        0.00345424966954474*NL - 0.0016431906890019782*lm*NL + 
        0.00009852906386385776*lm^2*NL + 0.00030625*lm^3*NL + 
        0.002416350589142043*NH - 0.0016431906890019782*lm*NH + 
        0.00009852906386385776*lm^2*NH + 0.00030625*lm^3*NH)}, 
     {0.9, CF*NC*(CF*(0.00020751728275377856 - 0.00578062319976953*lm + 
          0.012359756531492808*lm^2 - 0.0025*lm^3) + 
        CA*(-0.008516201704358238 + 0.019472264832617735*lm - 
          0.0033843154529766173*lm^2 - 0.0015277777777777779*lm^3) + 
        0.002399835770690723*NM - 0.0014917827638350977*lm*NM + 
        0.00008502705205635464*lm^2*NM + 0.0002777777777777778*lm^3*NM + 
        0.00314108227218453*NL - 0.0014917827638350977*lm*NL + 
        0.00008502705205635464*lm^2*NL + 0.0002777777777777778*lm^3*NL + 
        0.0022052673429043324*NH - 0.0014917827638350977*lm*NH + 
        0.00008502705205635464*lm^2*NH + 0.0002777777777777778*lm^3*NH)}, 
     {0.905, CF*NC*(CF*(0.00021004088361608066 - 0.005329731744972637*lm + 
          0.011189874965233491*lm^2 - 0.00225625*lm^3) + 
        CA*(-0.007776846749522739 + 0.017607486185769596*lm - 
          0.0030328368268017557*lm^2 - 0.0013788194444444444*lm^3) + 
        0.0021687984353510764*NM - 0.0013474964029482504*lm*NM + 
        0.00007282639275183437*lm^2*NM + 0.00025069444444444445*lm^3*NM + 
        0.0028420087822517846*NL - 0.0013474964029482504*lm*NL + 
        0.00007282639275183437*lm^2*NL + 0.00025069444444444445*lm^3*NL + 
        0.002002432602545316*NH - 0.0013474964029482504*lm*NH + 
        0.00007282639275183437*lm^2*NH + 0.00025069444444444445*lm^3*NH)}, 
     {0.91, CF*NC*(CF*(0.0002096429965798528 - 0.004884937856030176*lm + 
          0.01007451428091754*lm^2 - 0.002025*lm^3) + 
        CA*(-0.00706145101247185 + 0.01583277837775669*lm - 
          0.0027027273838837245*lm^2 - 0.0012375*lm^3) + 
        0.0019491438981763499*NM - 0.0012103726111744766*lm*NM + 
        0.0000618595243424954*lm^2*NM + 0.000225*lm^3*NM + 
        0.0025571534669875185*NL - 0.0012103726111744766*lm*NL + 
        0.0000618595243424954*lm^2*NL + 0.000225*lm^3*NL + 
        0.0018080698906533731*NH - 0.0012103726111744766*lm*NH + 
        0.0000618595243424954*lm^2*NH + 0.000225*lm^3*NH)}, 
     {0.915, CF*NC*(CF*(0.00020647132795533304 - 0.004448013867934559*lm + 
          0.009014280121552276*lm^2 - 0.00180625*lm^3) + 
        CA*(-0.006371514484207873 + 0.014148824773743874*lm - 
          0.0023936170090513866*lm^2 - 0.0011038194444444444*lm^3) + 
        0.0017409248542157513*NM - 0.0010804499902396863*lm*NM + 
        0.00005205915316085821*lm^2*NM + 0.00020069444444444445*lm^3*NM + 
        0.002286640226637269*NL - 0.0010804499902396863*lm*NL + 
        0.00005205915316085821*lm^2*NL + 0.00020069444444444445*lm^3*NL + 
        0.001622400511085527*NH - 0.0010804499902396863*lm*NH + 
        0.00005205915316085821*lm^2*NH + 0.00020069444444444445*lm^3*NH)}, 
     {0.92, CF*NC*(CF*(0.0002007005281725901 - 0.004020745009746969*lm + 
          0.008009775726031896*lm^2 - 0.0016*lm^3) + 
        CA*(-0.005708539747970311 + 0.01255629384719074*lm - 
          0.002105137056313841*lm^2 - 0.0009777777777777777*lm^3) + 
        0.001544193677214356*NM - 0.0009577647742626045*lm*NM + 
        0.000043358252663122616*lm^2*NM + 0.00017777777777777779*lm^3*NM + 
        0.0020305925658048447*NL - 0.0009577647742626045*lm*NL + 
        0.000043358252663122616*lm^2*NL + 0.00017777777777777779*lm^3*NL + 
        0.0014456435588976388*NH - 0.0009577647742626045*lm*NH + 
        0.000043358252663122616*lm^2*NH + 0.00017777777777777779*lm^3*NH)}, 
     {0.925, CF*NC*(CF*(0.00019253208125898352 - 0.003604929116382127*lm + 
          0.007061601936653673*lm^2 - 0.00140625*lm^3) + 
        CA*(-0.005074031709835462 + 0.011055839377905332*lm - 
          0.0018369203442672*lm^2 - 0.000859375*lm^3) + 
        0.001359002395922889*NM - 0.000842350864701645*lm*NM + 
        0.00003569006259403635*lm^2*NM + 0.00015625*lm^3*NM + 
        0.0017891335657660094*NL - 0.000842350864701645*lm*NL + 
        0.00003569006259403635*lm^2*NL + 0.00015625*lm^3*NL + 
        0.0012780159303458943*NH - 0.000842350864701645*lm*NH + 
        0.00003569006259403635*lm^2*NH + 0.00015625*lm^3*NH)}, 
     {0.93, CF*NC*(CF*(0.0001821941908047513 - 0.0032023763458435897*lm + 
          0.006170357206792712*lm^2 - 0.001225*lm^3) + 
        CA*(-0.004469497336744265 + 0.009648100647229532*lm - 
          0.0015886011514044541*lm^2 - 0.0007486111111111111*lm^3) + 
        0.0011854026712539692*NM - 0.0007342398647578428*lm*NM + 
        0.00002898808813414317*lm^2*NM + 0.0001361111111111111*lm^3*NM + 
        0.001562385857714849*NL - 0.0007342398647578428*lm*NL + 
        0.00002898808813414317*lm^2*NL + 0.0001361111111111111*lm^3*NL + 
        0.00111973233295477*NH - 0.0007342398647578428*lm*NH + 
        0.00002898808813414317*lm^2*NH + 0.0001361111111111111*lm^3*NH)}, 
     {0.935, CF*NC*(CF*(0.00016994166260336994 - 0.0028149089018023026*lm + 
          0.0053366376087277635*lm^2 - 0.00105625*lm^3) + 
        CA*(-0.0038964454017664453 + 0.008333702630399675*lm - 
          0.0013598152113330334*lm^2 - 0.0006454861111111111*lm^3) + 
        0.0010234457742595222*NM - 0.0006334611132428295*lm*NM + 
        0.000023186099030248504*lm^2*NM + 0.0001173611111111111*lm^3*NM + 
        0.0013504715969163833*NL - 0.0006334611132428295*lm*NL + 
        0.000023186099030248504*lm^2*NL + 0.0001173611111111111*lm^3*NL + 
        0.0009710052956468486*NH - 0.0006334611132428295*lm*NH + 
        0.000023186099030248504*lm^2*NH + 0.0001173611111111111*lm^3*NH)}, 
     {0.94, CF*NC*(CF*(0.0001560557841461579 - 0.002444360761413369*lm + 
          0.0045610368416107916*lm^2 - 0.0009*lm^3) + 
        CA*(-0.003356386236414165 + 0.007113256186125317*lm - 
          0.0011501997079045162*lm^2 - 0.00055*lm^3) + 0.000873182564904849*
         NM - 0.0005400417179206901*lm*NM + 0.000018218128709912022*lm^2*
         NM + 0.0001*lm^3*NM + 0.0011535124377397164*NL - 
        0.0005400417179206901*lm*NL + 0.000018218128709912022*lm^2*NL + 
        0.0001*lm^3*NL + 0.0008320451789300054*NH - 0.0005400417179206901*
         lm*NH + 0.000018218128709912022*lm^2*NH + 0.0001*lm^3*NH)}, 
     {0.945, CF*NC*(CF*(0.00014084420114368818 - 0.0020925774082681467*lm + 
          0.0038441462395732637*lm^2 - 0.00075625*lm^3) + 
        CA*(-0.002850831489823415 + 0.005987358243428513*lm - 
          0.0009593932702607833*lm^2 - 0.0004621527777777778*lm^3) + 
        0.0007346634716155458*NM - 0.00045400658833240023*lm*NM + 
        0.00001401847338074848*lm^2*NM + 0.00008402777777777778*lm^3*NM + 
        0.000971629509546773*NL - 0.00045400658833240023*lm*NL + 
        0.00001401847338074848*lm^2*NL + 0.00008402777777777778*lm^3*NL + 
        0.0007030601851376519*NH - 0.00045400658833240023*lm*NH + 
        0.00001401847338074848*lm^2*NH + 0.00008402777777777778*lm^3*NH)}, 
     {0.95, CF*NC*(CF*(0.00012464079123992544 - 0.0017614155703808978*lm + 
          0.0031865547799623767*lm^2 - 0.000625*lm^3) + 
        CA*(-0.0023812938946262407 + 0.004956591985785433*lm - 
          0.0007870359678007699*lm^2 - 0.00038194444444444446*lm^3) + 
        0.0006079384715741992*NM - 0.00037537846811139616*lm*NM + 
        0.000010521691115291498*lm^2*NM + 0.00006944444444444444*lm^3*NM + 
        0.0008049433934123814*NL - 0.00037537846811139616*lm*NL + 
        0.000010521691115291498*lm^2*NL + 0.00006944444444444444*lm^3*NL + 
        0.0005842563687178743*NH - 0.00037537846811139616*lm*NH + 
        0.000010521691115291498*lm^2*NH + 0.00006944444444444444*lm^3*NH)}, 
     {0.955, CF*NC*(CF*(0.00010780553507860102 - 0.0014527429631112961*lm + 
          0.002588849091700661*lm^2 - 0.00050625*lm^3) + 
        CA*(-0.0019492870393416366 + 0.004021527032611432*lm - 
          0.0006327693050718184*lm^2 - 0.000309375*lm^3) + 
        0.000493057071744463*NM - 0.0003041779667986982*lm*NM + 
        7.662600922148807*^-6*lm^2*NM + 0.00005625*lm^3*NM + 
        0.00065357409965215*NL - 0.0003041779667986982*lm*NL + 
        7.662600922148807*^-6*lm^2*NL + 0.00005625*lm^3*NL + 
        0.0004758376465674497*NH - 0.0003041779667986982*lm*NH + 
        7.662600922148807*^-6*lm^2*NH + 0.00005625*lm^3*NH)}, 
     {0.96, CF*NC*(CF*(0.00009072438487517442 - 0.0011684380369261285*lm + 
          0.0020516134637626276*lm^2 - 0.0004*lm^3) + 
        CA*(-0.0015563251471175429 + 0.003182719618130244*lm - 
          0.0004962362165895053*lm^2 - 0.00024444444444444443*lm^3) + 
        0.00039006829060078853*NM - 0.00024042359116586235*lm*NM + 
        5.3762818041524805*^-6*lm^2*NM + 0.000044444444444444447*lm^3*NM + 
        0.0005176410461352668*NL - 0.00024042359116586235*lm*NL + 
        5.3762818041524805*^-6*lm^2*NL + 0.000044444444444444447*lm^3*NL + 
        0.0003780058084068682*NH - 0.00024042359116586235*lm*NH + 
        5.3762818041524805*^-6*lm^2*NH + 0.000044444444444444447*lm^3*NH)}, 
     {0.965, CF*NC*(CF*(0.00007380913064179222 - 0.0009103897299055098*lm + 
          0.0015754298537623498*lm^2 - 0.00030625*lm^3) + 
        CA*(-0.0012039228606608443 + 0.0024407127676672876*lm - 
          0.0003770810615896751*lm^2 - 0.00018715277777777778*lm^3) + 
        0.0002990206405427322*NM - 0.00018413177605390395*lm*NM + 
        3.5980718041833556*^-6*lm^2*NM + 0.000034027777777777775*lm^3*NM + 
        0.0003972630373599959*NL - 0.00018413177605390395*lm*NL + 
        3.5980718041833556*^-6*lm^2*NL + 0.000034027777777777775*lm^3*NL + 
        0.00029096052719262717*NH - 0.00018413177605390395*lm*NH + 
        3.5980718041833556*^-6*lm^2*NH + 0.000034027777777777775*lm^3*NH)}, 
     {0.97, CF*NC*(CF*(0.000057497264206939166 - 0.0006804972249008818*lm + 
          0.0011608778966460708*lm^2 - 0.000225*lm^3) + 
        CA*(-0.00089359503319661 + 0.001796036471406559*lm - 
          0.0002749496187162901*lm^2 - 0.0001375*lm^3) + 
        0.0002199621109733873*NM - 0.000135316914736202*lm*NM + 
        2.26356703932547*^-6*lm^2*NM + 0.000025*lm^3*NM + 
        0.00029255824427028266*NL - 0.000135316914736202*lm*NL + 
        2.26356703932547*^-6*lm^2*NL + 0.000025*lm^3*NL + 
        0.00021489936956319486*NH - 0.000135316914736202*lm*NH + 
        2.26356703932547*^-6*lm^2*NH + 0.000025*lm^3*NH)}, 
     {0.975, CF*NC*(CF*(0.00004225184116597031 - 0.0004806697112539734*lm + 
          0.000808534913484147*lm^2 - 0.00015625*lm^3) + 
        CA*(-0.0006268565253020459 + 0.0012492078556499853*lm - 
          0.00018948908064857686*lm^2 - 0.00009548611111111112*lm^3) + 
        0.00015294015202209555*NM - 0.00009399138881325858*lm*NM + 
        1.3086207239836701*^-6*lm^2*NM + 0.00001736111111111111*lm^3*NM + 
        0.00020364418479249059*NL - 0.00009399138881325858*lm*NL + 
        1.3086207239836701*^-6*lm^2*NL + 0.00001736111111111111*lm^3*NL + 
        0.0001500178063151735*NH - 0.00009399138881325858*lm*NH + 
        1.3086207239836701*^-6*lm^2*NH + 0.00001736111111111111*lm^3*NH)}, 
     {0.98, CF*NC*(CF*(0.00002856134089341047 - 0.0003128261509877627*lm + 
          0.0005189759203568189*lm^2 - 0.0001*lm^3) + 
        CA*(-0.0004052220074647153 + 0.0008007313516175595*lm - 
          0.00012034804867083286*lm^2 - 0.00006111111111111111*lm^3) + 
        0.00009800165889218257*NM - 0.00006016559764705854*lm*NM + 
        6.693421825756725*^-7*lm^2*NM + 0.000011111111111111112*lm^3*NM + 
        0.00013063770507189124*NL - 0.00006016559764705854*lm*NL + 
        6.693421825756725*^-7*lm^2*NL + 0.000011111111111111112*lm^3*NL + 
        0.0000965092229063129*NH - 0.00006016559764705854*lm*NH + 
        6.693421825756725*^-7*lm^2*NH + 0.000011111111111111112*lm^3*NH)}, 
     {0.985, CF*NC*(CF*(0.000016939524742801062 - 0.0001788950493823142*lm + 
          0.0002927736373285015*lm^2 - 0.00005625*lm^3) + 
        CA*(-0.00023020576821858375 + 0.0004510988618260075*lm - 
          0.00006717652718813796*lm^2 - 0.000034375*lm^3) + 
        0.00005519295681503255*NM - 0.000033847987342644915*lm*NM + 
        2.8209585238871915*^-7*lm^2*NM + 6.25*^-6*lm^3*NM + 
        0.00007365496138910313*NL - 0.000033847987342644915*lm*NL + 
        2.8209585238871915*^-7*lm^2*NL + 6.25*^-6*lm^3*NL + 
        0.00005456492998214964*NH - 0.000033847987342644915*lm*NH + 
        2.8209585238871915*^-7*lm^2*NH + 6.25*^-6*lm^3*NH)}, 
     {0.99, CF*NC*(CF*(7.925292554955746*^-6 - 0.00008081422985014879*lm + 
          0.00013049849750546523*lm^2 - 0.000025*lm^3) + 
        CA*(-0.00010332152771530674 + 0.00020078992408318916*lm - 
          0.00002962591819110457*lm^2 - 0.000015277777777777777*lm^3) + 
        0.00002455978659236999*NM - 0.000015045079284398375*lm*NM + 
        8.35002771705283*^-8*lm^2*NM + 2.777777777777778*^-6*lm^3*NM + 
        0.00003281140273723926*NL - 0.000015045079284398375*lm*NL + 
        8.35002771705283*^-8*lm^2*NL + 2.777777777777778*^-6*lm^3*NL + 
        0.00002437417392316149*NH - 0.000015045079284398375*lm*NH + 
        8.35002771705283*^-8*lm^2*NH + 2.777777777777778*^-6*lm^3*NH)}, 
     {0.995, CF*NC*(CF*(2.082537590749136*^-6 - 0.000020530613027559642*lm + 
          0.00003271865617195955*lm^2 - 6.25*^-6*lm^3) + 
        CA*(-0.000026082256591951654 + 0.000050271873134874955*lm - 
          7.3490156726913885*^-6*lm^2 - 3.819444444444444*^-6*lm^3) + 
        6.147290709152704*^-6*NM - 3.761498234383358*^-6*lm*NM + 
        1.0427092004494872*^-8*lm^2*NM + 6.944444444444445*^-7*lm^3*NM + 
        8.221754041065459*^-6*NL - 3.761498234383358*^-6*lm*NL + 
        1.0427092004494872*^-8*lm^2*NL + 6.944444444444445*^-7*lm^3*NL + 
        6.124147409440892*^-6*NH - 3.761498234383358*^-6*lm*NH + 
        1.0427092004494872*^-8*lm^2*NH + 6.944444444444445*^-7*lm^3*NH)}, 
     {1., 0.}}
 
CbarTable["v", 2, 0] = {{0., 4.2866941015089165*^-6*CF*NC*
       (4.*CA*(-4566.775197079015 - 38047.87780943795*lm - 8910.*lm^2) - 
        3.*(CF*(-22820.768994014612 - 29160.*lm) - 
          80.*((74.38940068102023 + 51.47841760435743*lm + 27.*lm^2)*NM + 
            (74.38940068102023 + 51.47841760435743*lm + 27.*lm^2)*NL + 
            (-42.00116934067009 + 51.47841760435743*lm + 27.*lm^2)*NH)))}, 
     {0.005, CF*NC*(CF*(0.3003357603493021 + 0.375*lm) + 
        CA*(-0.06017821263859934 - 0.6438612431976769*lm - 
          0.1527777777777778*lm^2) + 0.07461493809117715*NM + 
        0.05140911492483014*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0746213603308773*NL + 0.05140911492483014*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.042287729227380055*NH + 
        0.05140911492483014*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.01, CF*NC*(CF*(0.30628176785359257 + 0.375*lm) + 
        CA*(-0.04267135031317881 - 0.6354780584652389*lm - 
          0.1527777777777778*lm^2) + 0.07278184119917311*NM + 
        0.049884899518932324*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.07280394284112271*NL + 0.049884899518932324*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.04137144396202136*NH + 
        0.049884899518932324*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.015, CF*NC*(CF*(0.31120463840017115 + 0.375*lm) + 
        CA*(-0.025921138719631413 - 0.6272875664558054*lm - 
          0.1527777777777778*lm^2) + 0.07105486157158444*NM + 
        0.04839571915358079*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.07109871243410577*NL + 0.04839571915358079*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.040463400222383324*NH + 
        0.04839571915358079*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.02, CF*NC*(CF*(0.31510699167797884 + 0.375*lm) + 
        CA*(-0.009980639425565615 - 0.6193109641454908*lm - 
          0.1527777777777778*lm^2) + 0.06944186294302555*NM + 
        0.046945427824432666*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.06951176543763427*NL + 0.046945427824432666*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.0395644739229127*NH + 
        0.046945427824432666*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.025, CF*NC*(CF*(0.3180288072910161 + 0.375*lm) + 
        CA*(0.00513232884160267 - 0.6115607085278228*lm - 
          0.1527777777777778*lm^2) + 0.06794486301144789*NM + 
        0.045536290439402126*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.06804411625803179*NL + 0.045536290439402126*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.03867535262979953*NH + 
        0.045536290439402126*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.03, CF*NC*(CF*(0.32002552766892667 + 0.375*lm) + 
        CA*(0.01941914286762802 - 0.6040438469124016*lm - 
          0.1527777777777778*lm^2) + 0.06656275179127315*NM + 
        0.04416958832750737*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.06669412979956567*NL + 0.04416958832750737*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.037796586023710096*NH + 
        0.04416958832750737*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.035, CF*NC*(CF*(0.32115878274019144 + 0.375*lm) + 
        CA*(0.0328926741785136 - 0.596763767640836*lm - 0.1527777777777778*
           lm^2) + 0.06529259287997395*NM + 0.042845937550859074*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.06545866130076833*NL + 
        0.042845937550859074*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.036928615815037355*NH + 0.042845937550859074*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.04, CF*NC*(CF*(0.3214918356284286 + 0.375*lm) + 
        CA*(0.04557298115344171 - 0.5897212598873792*lm - 
          0.1527777777777778*lm^2) + 0.06413034837111957*NM + 
        0.04156548159568511*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.06433367935004158*NL + 0.04156548159568511*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.03607179585808313*NH + 
        0.04156548159568511*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.045, CF*NC*(CF*(0.32108717782480145 + 0.375*lm) + 
        CA*(0.05748467391225576 - 0.5829152112456256*lm - 
          0.1527777777777778*lm^2) + 0.06307131946870803*NM + 
        0.04032801820627536*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.063314637974354*NL + 0.04032801820627536*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.03522640673681845*NH + 
        0.04032801820627536*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.05, CF*NC*(CF*(0.32000522265252734 + 0.375*lm) + 
        CA*(0.06865520612541677 - 0.5763430931969462*lm - 
          0.1527777777777778*lm^2) + 0.062110429554775706*NM + 
        0.039133087651970024*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.06239671175724095*NL + 0.039133087651970024*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.0343926668905938*NH + 
        0.039133087651970024*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.055, CF*NC*(CF*(0.31830360345919095 + 0.375*lm) + 
        CA*(0.07911372290051766 - 0.5700013125761383*lm - 
          0.1527777777777778*lm^2) + 0.06124241280349979*NM + 
        0.03798003663000494*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.06157495002102328*NL + 0.03798003663000494*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.033570741412573886*NH + 
        0.03798003663000494*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.06, CF*NC*(CF*(0.3160368218320347 + 0.375*lm) + 
        CA*(0.08889026203037154 - 0.5638854735606363*lm - 
          0.1527777777777778*lm^2) + 0.06046194286985039*NM + 
        0.03686806589991369*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.060844380372212*NL + 0.03686806589991369*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.03276074919729564*NH + 
        0.03686806589991369*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.065, CF*NC*(CF*(0.3132561050923077 + 0.375*lm) + 
        CA*(0.09801518975563517 - 0.5579905773363188*lm - 
          0.1527777777777778*lm^2) + 0.05976372191630292*NM + 
        0.035796266586401414*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0602000791819083*NL + 0.035796266586401414*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.03196276886819762*NH + 
        0.035796266586401414*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.07, CF*NC*(CF*(0.31000939121110627 + 0.375*lm) + 
        CA*(0.10651879749913017 - 0.5523111768872044*lm - 
          0.1527777777777778*lm^2) + 0.0591425425260824*NM + 
        0.034763648322926055*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05963721975601284*NL + 0.034763648322926055*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.03117684377375485*NH + 
        0.034763648322926055*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.075, CF*NC*(CF*(0.3063413916463623 + 0.375*lm) + 
        CA*(0.11443101206845609 - 0.5468414985978397*lm - 
          0.1527777777777778*lm^2) + 0.05859333061124389*NM + 
        0.03376916136122338*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.059151105064683976*NL + 0.03376916136122338*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.030402986253593296*NH + 
        0.03376916136122338*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.08, CF*NC*(CF*(0.30229370126721233 + 0.375*lm) + 
        CA*(0.1217811875549031 - 0.5415755387709994*lm - 0.1527777777777778*
           lm^2) + 0.058111174737915175*NM + 0.03281171411997969*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.05873718957287803*NL + 
        0.03281171411997969*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.02964118131986093*NH + 0.03281171411997969*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.085, CF*NC*(CF*(0.29790493573143106 + 0.375*lm) + 
        CA*(0.12859795705782592 - 0.5365071408390207*lm - 
          0.1527777777777778*lm^2) + 0.057691345598423066*NM + 
        0.0318901872232563*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05839109326124868*NL + 0.0318901872232563*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.02889138986164798*NH + 
        0.0318901872232563*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.09, CF*NC*(CF*(0.2932108836193426 + 0.375*lm) + 
        CA*(0.13490912881236994 - 0.531630057489352*lm - 0.1527777777777778*
           lm^2) + 0.057329308256410305*NM + 0.03100344479604379*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.058108609988754854*NL + 
        0.03100344479604379*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.028153551454373822*NH + 0.03100344479604379*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.095, CF*NC*(CF*(0.288244665039361 + 0.375*lm) + 
        CA*(0.14074161562232815 - 0.526938000850704*lm - 0.1527777777777778*
           lm^2) + 0.057020729050420896*NM + 0.030150343589016883*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.057885711724968744*NL + 
        0.030150343589016883*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.027427586837690643*NH + 0.030150343589016883*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.1, CF*NC*(CF*(0.28303689128640597 + 0.375*lm) + 
        CA*(0.1461213894722138 - 0.522424683127044*lm - 0.1527777777777778*
           lm^2) + 0.05676147853200156*NM + 0.02932974036653325*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.05771854975543106*NL + 
        0.02932974036653325*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.02671340011209728*NH + 0.02932974036653325*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.105, CF*NC*(CF*(0.27761582202880664 + 0.375*lm) + 
        CA*(0.15107345528038912 - 0.5180838495185716*lm - 
          0.1527777777777778*lm^2) + 0.0565476314564443*NM + 
        0.028540497892265544*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05760345366789942*NL + 0.028540497892265544*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.026010880694535617*NH + 
        0.028540497892265544*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.11, CF*NC*(CF*(0.27200751776847976 + 0.375*lm) + 
        CA*(0.15562183924939135 - 0.5139093048656151*lm - 
          0.1527777777777778*lm^2) + 0.056375464588146976*NM + 
        0.0277814897735462*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05753692871786412*NL + 0.0277814897735462*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.025319905065732885*NH + 
        0.0277814897735462*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.115, CF*NC*(CF*(0.2662359861780563 + 0.375*lm) + 
        CA*(0.15978958835694382 - 0.5098949351498173*lm - 
          0.1527777777777778*lm^2) + 0.05624145289628825*NM + 
        0.027051604370673867*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05751565202080224*NL + 0.027051604370673867*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.024640338336274645*NH + 
        0.027051604370673867*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.12, CF*NC*(CF*(0.26032332150369314 + 0.375*lm) + 
        CA*(0.16359877833397735 - 0.5060347247580781*lm - 
          0.1527777777777778*lm^2) + 0.05614226457912913*NM + 
        0.026349747935812184*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05753646790838245*NL + 0.026349747935812184*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.02397203565387865*NH + 
        0.026349747935812184*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.125, CF*NC*(CF*(0.25428983662195853 + 0.375*lm) + 
        CA*(0.16707052807644893 - 0.5023227702386824*lm - 
          0.1527777777777778*lm^2) + 0.05607475525267426*NM + 
        0.02567484711410387*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.057596382704266195*NL + 0.02567484711410387*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.02331484347076491*NH + 
        0.02567484711410387*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.13, CF*NC*(CF*(0.24815418761178754 + 0.375*lm) + 
        CA*(0.17022501889202374 - 0.49875329114203626*lm - 
          0.1527777777777778*lm^2) + 0.05603596156200504*NM + 
        0.025025850914713665*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.057692559114149174*NL + 0.025025850914713665*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.022668600687151815*NH + 
        0.025025850914713665*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.135, CF*NC*(CF*(0.24193349088718147 + 0.375*lm) + 
        CA*(0.17308151732988467 - 0.4953206384306763*lm - 
          0.1527777777777778*lm^2) + 0.056023094414607545*NM + 
        0.024401732239920947*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05782231037862809*NL + 0.024401732239920947*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.02203313968458497*NH + 
        0.024401732239920947*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.14, CF*NC*(CF*(0.2356434330596912 + 0.375*lm) + 
        CA*(0.17565840060971186 - 0.4920193008576348*lm - 
          0.1527777777777778*lm^2) + 0.05603353198970089*NM + 
        0.023801489044822488*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05798309430241015*NL + 0.023801489044822488*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.021408287260903443*NH + 
        0.023801489044822488*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.145, CF*NC*(CF*(0.22929837378007945 + 0.375*lm) + 
        CA*(0.17797318387406924 - 0.48884390964368013*lm - 
          0.1527777777777778*lm^2) + 0.05606481264250701*NM + 
        0.02322414518773982*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05817250724649074*NL + 0.02322414518773982*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.020793865477075575*NH + 
        0.02322414518773982*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.15, CF*NC*(CF*(0.22291144185865763 + 0.375*lm) + 
        CA*(0.18004254865146746 - 0.4857892417285832*lm - 
          0.1527777777777778*lm^2) + 0.0561146277951041*NM + 
        0.022668751021358558*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05838827814917358*NL + 0.022668751021358558*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.020189692424825722*NH + 
        0.022668751021358558*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.155, CF*NC*(CF*(0.21649462499258287 + 0.375*lm) + 
        CA*(0.18188237204585006 - 0.4828502218265224*lm - 
          0.1527777777777778*lm^2) + 0.05618081488414161*NM + 
        0.02213438376643841*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05862826262571235*NL + 0.02213438376643841*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.019595582922871835*NH + 
        0.02213438376643841*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.16, CF*NC*(CF*(0.21005885344221592 + 0.375*lm) + 
        CA*(0.18350775627006016 - 0.4800219234788609*lm - 
          0.1527777777777778*lm^2) + 0.05626135041890295*NM + 
        0.02162014770322724*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.058890437183815*NL + 0.02162014770322724*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.01901134914866153*NH + 
        0.02162014770322724*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.165, CF*NC*(CF*(0.2036140780019991 + 0.375*lm) + 
        CA*(0.18493305822191602 - 0.477299569267151*lm - 0.1527777777777778*
           lm^2) + 0.05635434318995855*NM + 0.021125174210189068*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.05917289358245247*NL + 
        0.021125174210189068*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.018436801211699855*NH + 0.021125174210189068*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.17, CF*NC*(CF*(0.1971693426074426 + 0.375*lm) + 
        CA*(0.18617191886634898 - 0.4746785303240515*lm - 
          0.1527777777777778*lm^2) + 0.05645802765818006*NM + 
        0.020648621675080067*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05947383335373752*NL + 0.020648621675080067*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.017871747673880885*NH + 
        0.020648621675080067*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.175, CF*NC*(CF*(0.19073285191103143 + 0.375*lm) + 
        CA*(0.18723729223907506 - 0.47215432525889406*lm - 
          0.1527777777777778*lm^2) + 0.05657075754559281*NM + 
        0.0201896752995969*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.05979156250161658*NL + 0.0201896752995969*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.01731599602164801*NH + 
        0.0201896752995969*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.18, CF*NC*(CF*(0.18431203414785857 + 0.375*lm) + 
        CA*(0.18814147392913042 - 0.4697226185971041*lm - 
          0.1527777777777778*lm^2) + 0.05669099964296982*NM + 
        0.019747546815635095*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.06012448638639208*NL + 0.019747546815635095*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.016769353094298514*NH + 
        0.019747546815635095*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.185, CF*NC*(CF*(0.17791359959775363 + 0.375*lm) + 
        CA*(0.1888961289313611 - 0.46737921881796035*lm - 
          0.1527777777777778*lm^2) + 0.0568173278438617*NM + 
        0.01932147412851804*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.06047110480038745*NL + 0.01932147412851804*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.016231625472304594*NH + 
        0.01932147412851804*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.19, CF*NC*(CF*(0.1715435949354784 + 0.375*lm) + 
        CA*(0.1895123187872283 - 0.46512007606275807*lm - 
          0.1527777777777778*lm^2) + 0.05694841741063526*NM + 
        0.01891072090029945*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.06083000723716842*NL + 0.01891072090029945*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.01570261982913465*NH + 
        0.01891072090029945*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.195, CF*NC*(CF*(0.16520745374482065 + 0.375*lm) + 
        CA*(0.19000052795433606 - 0.46294127957493353*lm - 
          0.1527777777777778*lm^2) + 0.05708303947484025*NM + 
        0.018514576084331352*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0611998683544762*NL + 0.018514576084331352*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.015182143249717558*NH + 
        0.018514576084331352*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.2, NC*(CF^2*(0.15891004345637066 + 0.375*lm) + 
        CA*CF*(0.19037068936301751 - 0.4608390549247794*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05722005577208994 + 0.01813235342066696*lm + 
            0.027777777777777776*lm^2)*NM + (0.061579443629278016 + 
            0.01813235342066696*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.014670003518391492 + 0.01813235342066696*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.205, NC*(CF^2*(0.1526557089542686 + 0.375*lm) + 
        CA*CF*(0.19063220913214857 - 0.45880976106378235*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05735841360724179 + 0.01776339090048568*lm + 
            0.027777777777777776*lm^2)*NM + (0.06196756520199736 + 
            0.01776339090048568*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.014166009378912275 + 0.01776339090048568*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.21, NC*(CF^2*(0.1464483130790515 + 0.375*lm) + 
        CA*CF*(0.19079399042944775 - 0.4568498872471213*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05749714105030609 + 0.017407050206547304*lm + 
            0.027777777777777776*lm^2)*NM + (0.0623631379059666 + 
            0.017407050206547304*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.013669970768859258 + 0.017407050206547304*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.215, NC*(CF^2*(0.1402912742433747 + 0.375*lm) + 
        CA*CF*(0.19086445646871564 - 0.4549560498573059*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05763534235327179 + 0.01706271613567178*lm + 
            0.027777777777777776*lm^2)*NM + (0.06276513547738409 + 
            0.01706271613567178*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.013181699030565468 + 0.01706271613567178*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.22, NC*(CF^2*(0.1341876013594583 + 0.375*lm) + 
        CA*CF*(0.1908515726459154 - 0.4531249891571677*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05777219358526312 + 0.01672979600837392*lm + 
            0.027777777777777776*lm^2)*NM + (0.06317259694050488 + 
            0.01672979600837392*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.01270100710050991 + 0.01672979600837392*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.225, NC*(CF^2*(0.12813992626596504 + 0.375*lm) + 
        CA*CF*(0.19076286782088278 - 0.45135356599631293*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.057906938478380326 + 0.0164077190700367*lm + 
            0.027777777777777776*lm^2)*NM + (0.06358462316240655 + 
            0.0164077190700367*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.012227709678940579 + 0.0164077190700367*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.23, NC*(CF^2*(0.12215053382878022 + 0.375*lm) + 
        CA*CF*(0.19060545475649962 - 0.44963875849161694*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.058038884477442654 + 0.016095935887364694*lm + 
            0.027777777777777776*lm^2)*NM + (0.06400037357141657 + 
            0.016095935887364694*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.011761623381344198 + 0.016095935887364694*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.235, NC*(CF^2*(0.11622138987809975 + 0.375*lm) + 
        CA*CF*(0.19038604973096754 - 0.4479776586992893*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05816739898648951 + 0.01579391774330513*lm + 
            0.027777777777777776*lm^2)*NM + (0.06441906303313752 + 
            0.01579391774330513*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.011302566873242263 + 0.01579391774330513*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.24, NC*(CF^2*(0.11035416713371972 + 0.375*lm) + 
        CA*CF*(0.1901109913413593 - 0.44636746929341*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05829190580446908 + 0.015501156033145246*lm + 
            0.027777777777777776*lm^2)*NM + (0.06483995887794057 + 
            0.015501156033145246*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.010850360989668031 + 0.015501156033145246*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.245, NC*(CF^2*(0.10455026925915553 + 0.375*lm) + 
        CA*CF*(0.1897862585192035 - 0.44480550026355564*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0584118817427766 + 0.015217161664080821*lm + 
            0.027777777777777776*lm^2)*NM + (0.06526237807379737 + 
            0.015217161664080821*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.010404828840567851 + 0.015217161664080821*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.25, NC*(CF^2*(0.09881085317610652 + 0.375*lm) + 
        CA*CF*(0.1894174877801269 - 0.44328916564216775*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0585268534170509 + 0.014941464460192112*lm + 
            0.027777777777777776*lm^2)*NM + (0.0656856845383724 + 
            0.014941464460192112*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.009965795903268104 + 0.014941464460192112*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.255, NC*(CF^2*(0.09313684976133037 + 0.375*lm) + 
        CA*CF*(0.18900998973087377 - 0.44181598027060226*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.058636394205826906 + 0.014673612574452936*lm + 
            0.027777777777777776*lm^2)*NM + (0.06610928658439004 + 
            0.014673612574452936*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.009533090103056764 + 0.014673612574452936*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.26, NC*(CF^2*(0.08752898303958859 + 0.375*lm) + 
        CA*CF*(0.188568764857716 - 0.4403835566113226*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05874012136871443 + 0.014413171909129366*lm + 
            0.027777777777777776*lm^2)*NM + (0.0665326344924137 + 
            0.014413171909129366*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.009106541882844528 + 0.014413171909129366*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.265, NC*(CF^2*(0.08198778797840496 + 0.375*lm) + 
        CA*CF*(0.18809851862069832 - 0.43898960161241113*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05883769331693083 + 0.01415972554569091*lm + 
            0.027777777777777776*lm^2)*NM + (0.06695521820532094 + 
            0.01415972554569091*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.008685984262793848 + 0.01415972554569091*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.27, NC*(CF^2*(0.0765136269830685 + 0.375*lm) + 
        CA*CF*(0.18760367587830554 - 0.4376319136294611*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05892880702917694 + 0.01391287318515454*lm + 
            0.027777777777777776*lm^2)*NM + (0.06737656513892273 + 
            0.01391287318515454*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.00827125289073427 + 0.01391287318515454*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.275, NC*(CF^2*(0.0711067051834519 + 0.375*lm) + 
        CA*CF*(0.18708839466710836 - 0.43630837940894496*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05901319560607079 + 0.013672230599606159*lm + 
            0.027777777777777776*lm^2)*NM + (0.06779623810335063 + 
            0.013672230599606159*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.007862186084118483 + 0.013672230599606159*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.28, NC*(CF^2*(0.06576708459796932 + 0.375*lm) + 
        CA*CF*(0.18655657936067863 - 0.43501697113631616*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0590906259565382 + 0.013437429095491827*lm + 
            0.027777777777777776*lm^2)*NM + (0.06821383333002061 + 
            0.013437429095491827*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.007458624864215061 + 0.013437429095491827*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.285, NC*(CF^2*(0.06049469725408447 + 0.375*lm) + 
        CA*CF*(0.18601189323172446 - 0.43375574355137536*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05916089660980826 + 0.013208114989138958*lm + 
            0.027777777777777776*lm^2)*NM + (0.06862897859917161 + 
            0.013208114989138958*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.007060412983180195 + 0.013208114989138958*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.29, NC*(CF^2*(0.0552893573393238 + 0.375*lm) + 
        CA*CF*(0.1854577704409297 - 0.43252283113280476*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.059223835646876534 + 0.01298394909485339*lm + 
            0.027777777777777776*lm^2)*NM + (0.06904133146316854 + 
            0.01298394909485339*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.006667396944601416 + 0.01298394909485339*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.295, NC*(CF^2*(0.05015077245148658 + 0.375*lm) + 
        CA*CF*(0.18489742747553334 - 0.43131644535322783*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.059279298745547555 + 0.012764606225839407*lm + 
            0.027777777777777776*lm^2)*NM + (0.0694505775609524 + 
            0.012764606225839407*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.006279426018061358 + 0.012764606225839407*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.3, NC*(CF^2*(0.04507863177264418 + 0.375*lm) + 
        CA*CF*(0.18433383517977014 - 0.4301348720056849*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05932716733338877 + 0.012549774708104323*lm + 
            0.027777777777777776*lm^2)*NM + (0.06985642901921024 + 
            0.012549774708104323*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.00589635224822772 + 0.012549774708104323*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.305, NC*(CF^2*(0.04007228961312544 + 0.375*lm) + 
        CA*CF*(0.18376989220565149 - 0.42897646860200744*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.059367346843182726 + 0.0123391559074357*lm + 
            0.027777777777777776*lm^2)*NM + (0.07025862293602718 + 
            0.0123391559074357*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.005518030458937634 + 0.0123391559074357*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.31, NC*(CF^2*(0.03513128755671442 + 0.375*lm) + 
        CA*CF*(0.18320817831733038 - 0.4278396618432287*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.059399765065673155 + 0.012132463769475924*lm + 
            0.027777777777777776*lm^2)*NM + (0.07065691994296629 + 
            0.012132463769475924*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.005144318252709226 + 0.012132463769475924*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.315, NC*(CF^2*(0.030255002762603254 + 0.375*lm) + 
        CA*CF*(0.18265114381754163 - 0.42672294516186643*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05942437059465351 + 0.011929424372864601*lm + 
            0.027777777777777776*lm^2)*NM + (0.07105110284170352 + 
            0.011929424372864601*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0047750760060807475 + 0.011929424372864601*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.32, NC*(CF^2*(0.025442750555995736 + 0.375*lm) + 
        CA*CF*(0.18210107107395507 - 0.4256248763356618*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05944113135964683 + 0.011729775495372853*lm + 
            0.027777777777777776*lm^2)*NM + (0.07144097531151973 + 
            0.011729775495372853*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0044101668611477235 + 0.011729775495372853*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.325, NC*(CF^2*(0.020693791429561684 + 0.375*lm) + 
        CA*CF*(0.18156008312577257 - 0.4245440751721386*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05945003324165783 + 0.011533266192914086*lm + 
            0.027777777777777776*lm^2)*NM + (0.07182636068412211 + 
            0.011533266192914086*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.004049456713640784 + 0.011533266192914086*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.33, NC*(CF^2*(0.01600733750404679 + 0.375*lm) + 
        CA*CF*(0.18103015188560564 - 0.42347922126316434*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.059451078767682686 + 0.011339656391282408*lm + 
            0.027777777777777776*lm^2)*NM + (0.07220710078243149 + 
            0.011339656391282408*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.003692814197861431 + 0.011339656391282408*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.335, NC*(CF^2*(0.011382558486145212 + 0.375*lm) + 
        CA*CF*(0.18051310595464146 - 0.4224290518085406*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05944428587986792 + 0.011148716490441728*lm + 
            0.027777777777777776*lm^2)*NM + (0.07258305482013089 + 
            0.011148716490441728*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0033401106687692655 + 0.011148716490441728*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.34, NC*(CF^2*(0.006818587159099232 + 0.375*lm) + 
        CA*CF*(0.1800106380684074 - 0.4213923595075191*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.059429686775406235 + 0.010960226981165085*lm + 
            0.027777777777777776*lm^2)*NM + (0.07295409835892261 + 
            0.010960226981165085*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.002991220181492141 + 0.010960226981165085*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.345, NC*(CF^2*(0.0023145244390372194 + 0.375*lm) + 
        CA*CF*(0.17952431218975481 - 0.42036799051703494*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05940732681344121 + 0.010773978073804332*lm + 
            0.027777777777777776*lm^2)*NM + (0.07332012232058838 + 
            0.010773978073804332*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0026460194685111902 + 0.010773978073804332*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.35, NC*(CF^2*(-0.0021305559722346597 + 0.375*lm) + 
        CA*CF*(0.17905557026501717 - 0.41935484247536053*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.059377263485442755 + 0.010589769338954443*lm + 
            0.027777777777777776*lm^2)*NM + (0.07368103205108686 + 
            0.010589769338954443*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.002304387914752776 + 0.010589769338954443*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.355, NC*(CF^2*(-0.006517603309393051 + 0.375*lm) + 
        CA*CF*(0.17860573865863866 - 0.4183518625898127*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.059339565445690655 + 0.010407409359763932*lm + 
            0.027777777777777776*lm^2)*NM + (0.07403674643405832 + 
            0.010407409359763932*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0019662075308033017 + 0.010407409359763932*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.36, NC*(CF^2*(-0.01084758581408804 + 0.375*lm) + 
        CA*CF*(0.1781760342809296 - 0.4173580457870918*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05929431159866307 + 0.010226715395632847*lm + 
            0.027777777777777776*lm^2)*NM + (0.07438719705123403 + 
            0.010226715395632847*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0016313629244455868 + 0.010226715395632847*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.365, NC*(CF^2*(-0.015121487128979268 + 0.375*lm) + 
        CA*CF*(0.17776757042298358 - 0.41637243292478765*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05924159024028226 + 0.0100475130570321*lm + 
            0.027777777777777776*lm^2)*NM + (0.07473232738737218 + 
            0.0100475130570321*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.001299741270701703 + 0.0100475130570321*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.37, NC*(CF^2*(-0.019340302992263653 + 0.375*lm) + 
        CA*CF*(0.17738136231220192 - 0.4153941090625589*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05918149825015953 + 0.009869635991172332*lm + 
            0.027777777777777776*lm^2)*NM + (0.07507209207745869 + 
            0.009869635991172332*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0009712322805521535 + 0.009869635991172332*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.375, NC*(CF^2*(-0.02350503821119333 + 0.375*lm) + 
        CA*CF*(0.17701833240126943 - 0.4144222017914675*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05911414033205935 + 0.009692925578246612*lm + 
            0.027777777777777776*lm^2)*NM + (0.07540645619402431 + 
            0.009692925578246612*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0006457281684894744 + 0.009692925578246612*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.38, NC*(CF^2*(-0.027616703894606902 + 0.375*lm) + 
        CA*CF*(0.1766793154028882 - 0.4134558796199413*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05903962830002061 + 0.009517230637969129*lm + 
            0.027777777777777776*lm^2)*NM + (0.07573539457253564 + 
            0.009517230637969129*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.00032312361905180225 + 0.009517230637969129*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.385, NC*(CF^2*(-0.031676314925842525 + 0.375*lm) + 
        CA*CF*(0.17636506308201752 - 0.4124943504148316*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05895808040764655 + 0.009342407146130998*lm + 
            0.027777777777777776*lm^2)*NM + (0.07605889117292024 + 
            0.009342407146130998*lm + 0.027777777777777776*lm^2)*NL + 
          (-3.3157524709457274*^-6 + 0.009342407146130998*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.39, NC*(CF^2*(-0.03568488765869982 + 0.375*lm) + 
        CA*CF*(0.176076248816857 - 0.411536859896032*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.058869620718231194 + 0.009168317960894703*lm + 
            0.027777777777777776*lm^2)*NM + (0.07637693847538282 + 
            0.009168317960894703*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0003137959104404661 + 0.009168317960894703*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.395, NC*(CF^2*(-0.039643437820306875 + 0.375*lm) + 
        CA*CF*(0.17581347193930535 - 0.4105826901831352*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05877437851350041 + 0.008994832558549829*lm + 
            0.027777777777777776*lm^2)*NM + (0.07668953690876196 + 
            0.008994832558549829*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0006283094840482276 + 0.008994832558549829*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.4, NC*(CF^2*(-0.04355297860586162 + 0.375*lm) + 
        CA*CF*(0.17557726186514874 - 0.4096311583926135*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0586724877388661 + 0.008821826778454982*lm + 
            0.027777777777777776*lm^2)*NM + (0.07699669430976479 + 
            0.008821826778454982*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0009403207541961306 + 0.008821826778454982*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.405, NC*(CF^2*(-0.047414518951251046 + 0.375*lm) + 
        CA*CF*(0.17536808202376855 - 0.40868161528402575*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05856408648319636 + 0.008649182576893571*lm + 
            0.027777777777777776*lm^2)*NM + (0.07729842541150092 + 
            0.008649182576893571*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0012499232149479381 + 0.008649182576893571*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.41, NC*(CF^2*(-0.05122906197051643 + 0.375*lm) + 
        CA*CF*(0.17518633359671767 - 0.40773344395377176*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05844931649121202 + 0.008476787789574667*lm + 
            0.027777777777777776*lm^2)*NM + (0.07759475135981615 + 
            0.008476787789574667*lm + 0.027777777777777776*lm^2)*NL + 
          (0.001557208105682622 + 0.008476787789574667*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.415, NC*(CF^2*(-0.05499760354602984 + 0.375*lm) + 
        CA*CF*(0.1750323590740882 - 0.4067860585749389*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05832832270671761 + 0.008304535902514136*lm + 
            0.027777777777777776*lm^2)*NM + (0.07788569925600257 + 
            0.008304535902514136*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0018622644484587096 + 0.008304535902514136*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.42, NC*(CF^2*(-0.058721131060083545 + 0.375*lm) + 
        CA*CF*(0.1749064456371877 - 0.40583890318180754*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05820125284496553 + 0.008132325831035712*lm + 
            0.027777777777777776*lm^2)*NM + (0.07817130172453317 + 
            0.008132325831035712*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0021651790855727396 + 0.008132325831035712*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.425, NC*(CF^2*(-0.062400622257373514 + 0.375*lm) + 
        CA*CF*(0.1748088283756519 - 0.4048914504976117*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05806825699255256 + 0.007960061706636476*lm + 
            0.027777777777777776*lm^2)*NM + (0.07845159650453769 + 
            0.007960061706636476*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0024660367172409854 + 0.007960061706636476*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.43, NC*(CF^2*(-0.06603704422858298 + 0.375*lm) + 
        CA*CF*(0.17473969334674805 - 0.4039432008041759*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.057929487233310435 + 0.007787652671466322*lm + 
            0.027777777777777776*lm^2)*NM + (0.07872662606380142 + 
            0.007787652671466322*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0027649199393403683 + 0.007787652671466322*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.435, NC*(CF^2*(-0.06963135250594762 + 0.375*lm) + 
        CA*CF*(0.17469918048426822 - 0.402993680852081*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05778509729876125 + 0.007615012680176338*lm + 
            0.027777777777777776*lm^2)*NM + (0.07899643723412979 + 
            0.007615012680176338*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0030619092811490995 + 0.007615012680176338*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.44, NC*(CF^2*(-0.07318449026231687 + 0.375*lm) + 
        CA*CF*(0.1746873863640701 - 0.4020424428100423*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05763524224175914 + 0.007442060308896579*lm + 
            0.027777777777777776*lm^2)*NM + (0.07926108086698117 + 
            0.007442060308896579*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0033570832430345637 + 0.007442060308896579*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.445, NC*(CF^2*(-0.07669738760580841 + 0.375*lm) + 
        CA*CF*(0.17470436683299723 - 0.40108906325221244*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05748007813202828 + 0.007268718571109334*lm + 
            0.027777777777777776*lm^2)*NM + (0.07952061150832478 + 
            0.007268718571109334*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0036505183340360616 + 0.007268718571109334*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.45, NC*(CF^2*(-0.080170960962705 + 0.375*lm) + 
        CA*CF*(0.17475013950760043 - 0.4001331421821551*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0573197617723658 + 0.0070949147401898225*lm + 
            0.027777777777777776*lm^2)*NM + (0.07977508709173434 + 
            0.0070949147401898225*lm + 0.027777777777777776*lm^2)*NL + 
          (0.003942289109300378 + 0.0070949147401898225*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.455, NC*(CF^2*(-0.08360611254174699 + 0.375*lm) + 
        CA*CF*(0.17482468614878274 - 0.3991743020922674*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.057154450434355755 + 0.006920580178392052*lm + 
            0.027777777777777776*lm^2)*NM + (0.08002456864877776 + 
            0.006920580178392052*lm + 0.027777777777777776*lm^2)*NL + 
          (0.004232468207326911 + 0.006920580178392052*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.46, NC*(CF^2*(-0.0870037298734565 + 0.375*lm) + 
        CA*CF*(0.1749279549182098 - 0.3982121870574601*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05698430161248176 + 0.006745650172063451*lm + 
            0.027777777777777776*lm^2)*NM + (0.08026912003581094 + 
            0.006745650172063451*lm + 0.027777777777777776*lm^2)*NL + 
          (0.004521126386985674 + 0.006745650172063451*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.465, NC*(CF^2*(-0.09036468541856452 + 0.375*lm) + 
        CA*CF*(0.17505986252205244 - 0.39724646186193896*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0568094727956089 + 0.006570063772877796*lm + 
            0.027777777777777776*lm^2)*NM + (0.08050880767632908 + 
            0.006570063772877796*lm + 0.027777777777777776*lm^2)*NL + 
          (0.004808332564273874 + 0.006570063772877796*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.47, NC*(CF^2*(-0.09368983624003087 + 0.375*lm) + 
        CA*CF*(0.17522029624737337 - 0.39627681115796093*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05663012125484148 + 0.006393763644881789*lm + 
            0.027777777777777776*lm^2)*NM + (0.0807437003180714 + 
            0.006393763644881789*lm + 0.027777777777777776*lm^2)*NL + 
          (0.0050941538487808274 + 0.006393763644881789*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.475, NC*(CF^2*(-0.0969800237335294 + 0.375*lm) + 
        CA*CF*(0.17540911589622019 - 0.39530293865547195*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05644640384682536 + 0.006216695917156516*lm + 
            0.027777777777777776*lm^2)*NM + (0.08097386880411647 + 
            0.006216695917156516*lm + 0.027777777777777776*lm^2)*NL + 
          (0.005378655579831434 + 0.006216695917156516*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.48, NC*(CF^2*(-0.10023607341163067 + 0.375*lm) + 
        CA*CF*(0.17562615562225328 - 0.3943245663415653*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.056258476831611205 + 0.0060388100419007705*lm + 
            0.027777777777777776*lm^2)*NM + (0.08119938585724364 + 
            0.0060388100419007705*lm + 0.027777777777777776*lm^2)*NL + 
          (0.005661901362286328 + 0.0060388100419007705*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.485, NC*(CF^2*(-0.10345879473724809 + 0.375*lm) + 
        CA*CF*(0.17587122567451105 - 0.3933414337287304*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.056066495704242415 + 0.00586005865774897*lm + 
            0.027777777777777776*lm^2)*NM + (0.08142032587687281 + 
            0.00586005865774897*lm + 0.027777777777777776*lm^2)*NL + 
          (0.005943953101972696 + 0.00586005865774897*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.49, NC*(CF^2*(-0.10664898100222688 + 0.375*lm) + 
        CA*CF*(0.17614411405270142 - 0.3923532971308924*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05587061503927554 + 0.005680397458142057*lm + 
            0.027777777777777776*lm^2)*NM + (0.08163676474792979 + 
            0.005680397458142057*lm + 0.027777777777777776*lm^2)*NL + 
          (0.006224871040728116 + 0.005680397458142057*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.495, NC*(CF^2*(-0.10980740924724472 + 0.375*lm) + 
        CA*CF*(0.1764445880782036 - 0.39135992896627514*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.055670988347484664 + 0.005499785064575277*lm + 
            0.027777777777777776*lm^2)*NM + (0.08184877966101735 + 
            0.005499785064575277*lm + 0.027777777777777776*lm^2)*NL + 
          (0.006504713791037966 + 0.005499785064575277*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.5, CF*NC*(CF*(-0.11293483995028156 + 0.375*lm) + 
        CA*(0.17677239577785075 - 0.39036111716358013*lm - 
          0.1527777777777778*lm^2) + 0.05546776795796492*NM + 
        0.005318182918630726*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08205644895046801*NL + 0.005318182918630726*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.006783538367780161*NH + 
        0.005318182918630726*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.505, CF*NC*(CF*(-0.11603201815411807 + 0.375*lm) + 
        CA*(0.17712726774945614 - 0.3893566641889251*lm - 
          0.1527777777777778*lm^2) + 0.05526110483830811*NM + 
        0.00513555510505709*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08225985190512465*NL + 0.00513555510505709*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.007061400232431384*NH + 
        0.00513555510505709*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.51, CF*NC*(CF*(-0.1190996716863314 + 0.375*lm) + 
        CA*(0.17750891778560898 - 0.38834638694307466*lm - 
          0.1527777777777778*lm^2) + 0.05505114857730907*NM + 
        0.004951868333084285*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08245906866718164*NL + 0.004951868333084285*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.007338353309829969*NH + 
        0.004951868333084285*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.515, CF*NC*(CF*(-0.12213851249132328 + 0.375*lm) + 
        CA*(0.17791704465542424 - 0.38733011579355453*lm - 
          0.1527777777777778*lm^2) + 0.054838047217164246*NM + 
        0.004767091760444257*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0826541800577227*NL + 0.004767091760444257*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.007614450032815213*NH + 
        0.004767091760444257*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.52, CF*NC*(CF*(-0.12514923636493874 + 0.375*lm) + 
        CA*(0.1783513331734231 - 0.3863076940971777*lm - 0.1527777777777778*
           lm^2) + 0.05462194717907647*NM + 0.004581196906557564*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08284526745438348*NL + 
        0.004581196906557564*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.00788974137147483*NH + 0.004581196906557564*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.525, CF*NC*(CF*(-0.12813252305586595 + 0.375*lm) + 
        CA*(0.1788114553423921 - 0.3852789776451224*lm - 0.1527777777777778*
           lm^2) + 0.05440299317943543*NM + 0.004394157551638418*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08303241266798951*NL + 
        0.004394157551638418*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.008164276865075353*NH + 0.004394157551638418*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.53, CF*NC*(CF*(-0.13108903638816718 + 0.375*lm) + 
        CA*(0.17929707143625034 - 0.3842438341288677*lm - 
          0.1527777777777778*lm^2) + 0.05418132815395462*NM + 
        0.0042059496395921055*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08321569782695704*NL + 0.0042059496395921055*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.008438104653510352*NH + 
        0.0042059496395921055*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.535, CF*NC*(CF*(-0.13401942440283388 + 0.375*lm) + 
        CA*(0.1798078310257824 - 0.3832021426262412*lm - 0.1527777777777778*
           lm^2) + 0.05395709318928393*NM + 0.004016551184569103*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08339520526904766*NL + 
        0.004016551184569103*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.008711271508261254*NH + 0.004016551184569103*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.54, CF*NC*(CF*(-0.1369243195164127 + 0.375*lm) + 
        CA*(0.18034337394995914 - 0.38215379310685776*lm - 
          0.1527777777777778*lm^2) + 0.05373042746164302*NM + 
        0.0038259421810448472*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08357101744008855*NL + 0.0038259421810448472*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.008983822862866689*NH + 
        0.0038259421810448472*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.545, CF*NC*(CF*(-0.13980433869489378 + 0.375*lm) + 
        CA*(0.1809033312354429 - 0.38109868595625274*lm - 
          0.1527777777777778*lm^2) + 0.053501468182045604*NM + 
        0.0036341045172984753*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08374321679928924*NL + 0.0036341045172984753*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.009255802842897247*NH + 
        0.0036341045172984753*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.55, CF*NC*(CF*(-0.1426600836411865 + 0.375*lm) + 
        CA*(0.18148732596675174 - 0.38003673151803646*lm - 
          0.1527777777777778*lm^2) + 0.053270350547708054*NM + 
        0.003441021892168242*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08391188573080516*NL + 0.003441021892168242*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.009527254295433536*NH + 
        0.003441021892168242*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.555, CF*NC*(CF*(-0.1454921409946333 + 0.375*lm) + 
        CA*(0.18209497410944173 - 0.37896784965342106*lm - 
          0.1527777777777778*lm^2) + 0.05303720769925807*NM + 
        0.003246679734965443*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08407710646121527*NL + 0.003246679734965443*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.009798218818046222*NH + 
        0.003246679734965443*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.56, CF*NC*(CF*(-0.14830108254112817 + 0.375*lm) + 
        CA*(0.18272588528855635 - 0.37789196931749136*lm - 
          0.1527777777777778*lm^2) + 0.052802170683380056*NM + 
        0.0030510651284327756*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08423896098259848*NL + 0.0030510651284327756*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.010068736787277594*NH + 
        0.0030510651284327756*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.565, CF*NC*(CF*(-0.151087465432516 + 0.375*lm) + 
        CA*(0.18337966352448712 - 0.37680902815161454*lm - 
          0.1527777777777778*lm^2) + 0.05256536842055389*NM + 
        0.002854166734636986*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08439753098090921*NL + 0.002854166734636986*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.01033884738662486*NH + 
        0.002854166734636986*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.57, CF*NC*(CF*(-0.15385183241404984 + 0.375*lm) + 
        CA*(0.1840559079282894 - 0.3757189720914032*lm - 0.1527777777777778*
           lm^2) + 0.05232692767756259*NM + 0.002655974723689475*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08455289776936765*NL + 
        0.002655974723689475*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.010608588634026117*NH + 0.002655974723689475*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.575, CF*NC*(CF*(-0.1565947120587771 + 0.375*lm) + 
        CA*(0.18475421335840192 - 0.37462175498966843*lm - 
          0.1527777777777778*lm^2) + 0.05208697304446216*NM + 
        0.0024564807051922406*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08470514222659478*NL + 0.0024564807051922406*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.010877997408850487*NH + 
        0.0024564807051922406*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.58, CF*NC*(CF*(-0.15931661900781466 + 0.375*lm) + 
        CA*(0.18547417104062774 - 0.37351733825381667*lm - 
          0.1527777777777778*lm^2) + 0.051845626915724016*NM + 
        0.002255677662310102*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08485434473923575*NL + 0.002255677662310102*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.01114710947839454*NH + 
        0.002255677662310102*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.585, CF*NC*(CF*(-0.16201805421555396 + 0.375*lm) + 
        CA*(0.18621536915314796 - 0.37240569049716615*lm - 
          0.1527777777777778*lm^2) + 0.05160300947527623*NM + 
        0.00205355988837364*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08500058514882837*NL + 0.00205355988837364*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.011415959523887569*NH + 
        0.00205355988837364*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.59, CF*NC*(CF*(-0.16469950519891377 + 0.375*lm) + 
        CA*(0.1869773933782561 - 0.3712867872036746*lm - 0.1527777777777778*
           lm^2) + 0.05135923868518506*NM + 0.0018501229259206351*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08514394270268563*NL + 
        0.0018501229259206351*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.011684581166008807*NH + 0.0018501229259206351*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.595, CF*NC*(CF*(-0.1673614462898294 + 0.375*lm) + 
        CA*(0.1877598274224236 - 0.3701606104055898*lm - 0.1527777777777778*
           lm^2) + 0.051114430277732666*NM + 0.0016453635080870275*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08528449600857291*NL + 
        0.0016453635080870275*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.01195300698992008*NH + 0.0016453635080870275*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.6, CF*NC*(CF*(-0.17000433889023317 + 0.375*lm) + 
        CA*(0.1885622535062301 - 0.36902714837354983*lm - 
          0.1527777777777778*lm^2) + 0.050868697750660385*NM + 
        0.001439279502261589*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0854223229929718*NL + 0.001439279502261589*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.012221268569817758*NH + 
        0.001439279502261589*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.605, CF*NC*(CF*(-0.1726286317288426 + 0.375*lm) + 
        CA*(0.18938425282562285 - 0.36788639531867945*lm - 
          0.1527777777777778*lm^2) + 0.05062215236536006*NM + 
        0.0012318698559215125*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08555750086273284*NL + 0.0012318698559215125*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.01248939649300826*NH + 
        0.0012318698559215125*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.61, CF*NC*(CF*(-0.17523476111912997 + 0.375*lm) + 
        CA*(0.19022540598589888 - 0.36673835110624103*lm - 
          0.1527777777777778*lm^2) + 0.05037490314780774*NM + 
        0.0010231345445690788*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08569010606992955*NL + 0.0010231345445690788*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.012757420383511643*NH + 
        0.0010231345445690788*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.615, CF*NC*(CF*(-0.17782315121790054 + 0.375*lm) + 
        CA*(0.1910852934097406 - 0.3655830209804193*lm - 0.1527777777777778*
           lm^2) + 0.05012705689204608*NM + 0.0008130745216923988*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08582021427973575*NL + 
        0.0008130745216923988*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.013025368925198098*NH + 0.0008130745216923988*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.62, CF*NC*(CF*(-0.18039421428395533 + 0.375*lm) + 
        CA*(0.19196349572057253 - 0.36442041529982894*lm - 
          0.1527777777777778*lm^2) + 0.049878718166032315*NM + 
        0.0006016916706759708*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08594790034115722*NL + 0.0006016916706759708*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.013293269884462474*NH + 
        0.0006016916706759708*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.625, CF*NC*(CF*(-0.18294835093636203 + 0.375*lm) + 
        CA*(0.19285959410244746 - 0.3632505492833531*lm - 
          0.1527777777777778*lm^2) + 0.04962998931967922*NM + 
        0.00038898875858944896*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08607323826045707*NL + 0.00038898875858944896*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.01356115013244209*NH + 
        0.00038898875858944896*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.63, CF*NC*(CF*(-0.18548595041189878 + 0.375*lm) + 
        CA*(0.193773170637615 - 0.3620734427659318*lm - 0.1527777777777778*
           lm^2) + 0.04938097049492637*NM + 0.0001749693917855818*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08619630117712278*NL + 
        0.0001749693917855818*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.013829035666783401*NH + 0.0001749693917855818*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.635, CF*NC*(CF*(-0.18800739082127646 + 0.375*lm) + 
        CA*(0.1947038086228708 - 0.36088911996393525*lm - 
          0.1527777777777778*lm^2) + 0.04913175963768801*NM - 
        0.00004036202675924867*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08631716134223034*NL - 0.00004036202675924867*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.014096951632963161*NH - 
        0.00004036202675924867*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.64, CF*NC*(CF*(-0.19051303940378167 + 0.375*lm) + 
        CA*(0.19565109286573365 - 0.35969760924976774*lm - 
          0.1527777777777778*lm^2) + 0.04888245251153298*NM - 
        0.0002570003384260635*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08643589009906837*NL - 0.0002570003384260635*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.014364922345169971*NH - 
        0.0002570003384260635*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.645, CF*NC*(CF*(-0.19300325278001693 + 0.375*lm) + 
        CA*(0.19661460996144967 - 0.3584989429353634*lm - 
          0.1527777777777778*lm^2) + 0.04863314271296015*NM - 
        0.0004749396683177695*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08655255786589199*NL - 0.0004749396683177695*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.014632971306752165*NH - 
        0.0004749396683177695*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.65, CF*NC*(CF*(-0.19547837720244654 + 0.375*lm) + 
        CA*(0.19759394855177467 - 0.3572931570642441*lm - 
          0.1527777777777778*lm^2) + 0.04838392168814095*NM - 
        0.0006941734630667314*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08666723412068326*NL - 0.0006941734630667314*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.014901121230238144*NH - 
        0.0006941734630667314*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.655, CF*NC*(CF*(-0.19793874880348616 + 0.375*lm) + 
        CA*(0.19858869956644282 - 0.356080291211825*lm - 0.1527777777777778*
           lm^2) + 0.04813487875100781*NM - 0.0009146945271429255*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08677998738780075*NL - 
        0.0009146945271429255*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.01516939405693535*NH - 0.0009146945271429255*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.66, CF*NC*(CF*(-0.20038469384090116 + 0.375*lm) + 
        CA*(0.19959845644818638 - 0.3548603882936616*lm - 
          0.1527777777777778*lm^2) + 0.047886101102574685*NM - 
        0.0011364950577180933*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08689088522640713*NL - 0.0011364950577180933*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.015437810976114165*NH - 
        0.0011364950577180933*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.665, CF*NC*(CF*(-0.20281652894030486 + 0.375*lm) + 
        CA*(0.20062281536213164 - 0.3536334943813449*lm - 
          0.1527777777777778*lm^2) + 0.04763767385138207*NM - 
        0.0013595666781393123*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08699999422056953*NL - 0.0013595666781393123*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.015706392443783062*NH - 
        0.0013595666781393123*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.67, CF*NC*(CF*(-0.2052345613345706 + 0.375*lm) + 
        CA*(0.20166137539035683 - 0.35239965852576205*lm - 
          0.1527777777777778*lm^2) + 0.04738968003496578*NM - 
        0.001583900470063465*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08710737997093246*NL - 0.001583900470063465*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.015975158201061428*NH - 
        0.001583900470063465*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.675, CF*NC*(CF*(-0.20763908909999396 + 0.375*lm) + 
        CA*(0.20271373871236165 - 0.35115893258744885*lm - 
          0.1527777777777778*lm^2) + 0.04714220064225427*NM - 
        0.0018094870043022316*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08721310708786854*NL - 0.0018094870043022316*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.016244127292156484*NH - 
        0.0018094870043022316*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.68, CF*NC*(CF*(-0.21003040138906073 + 0.375*lm) + 
        CA*(0.20377951077216308 - 0.3499113710737713*lm - 
          0.1527777777777778*lm^2) + 0.04689531463680526*NM - 
        0.0020363163704254245*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0873172391860169*NL - 0.0020363163704254245*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.01651331808195076*NH - 
        0.0020363163704254245*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.685, CF*NC*(CF*(-0.21240877865969623 + 0.375*lm) + 
        CA*(0.20485830043269806 - 0.34865703098268297*lm - 
          0.1527777777777778*lm^2) + 0.04664909898079755*NM - 
        0.002264378205168758*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08741983888012413*NL - 0.002264378205168758*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.01678274827320663*NH - 
        0.002264378205168758*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.69, CF*NC*(CF*(-0.21477449290088704 + 0.375*lm) + 
        CA*(0.2059497201181824 - 0.34739597165281355*lm - 
          0.1527777777777778*lm^2) + 0.046403628659699214*NM - 
        0.0024936617196904664*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08752096778210672*NL - 0.0024936617196904664*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.017052434923394363*NH - 
        0.0024936617196904664*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.695, CF*NC*(CF*(-0.2171278078545837 + 0.375*lm) + 
        CA*(0.20705338594504458 - 0.3461282546196534*lm - 
          0.1527777777777778*lm^2) + 0.04615897670753801*NM - 
        0.002724155725719577*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08762068649925836*NL - 0.002724155725719577*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.01732239446115021*NH - 
        0.002724155725719577*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.7, CF*NC*(CF*(-0.21946897923380618 + 0.375*lm) + 
        CA*(0.20816891784202413 - 0.3448539434776071*lm - 
          0.1527777777777778*lm^2) + 0.045915214232704345*NM - 
        0.002955848660637088*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08771905463352923*NL - 0.002955848660637088*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.017592642702370997*NH - 
        0.002955848660637088*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.705, CF*NC*(CF*(-0.22179825493688893 + 0.375*lm) + 
        CA*(0.20929593965999677 - 0.34357310374769723*lm - 
          0.1527777777777778*lm^2) + 0.04567241044422154*NM - 
        0.003188728611529792*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08781613078180867*NL - 0.003188728611529792*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.017863194865951622*NH - 
        0.003188728611529792*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.71, CF*NC*(CF*(-0.2241158752578129 + 0.375*lm) + 
        CA*(0.21043407927206162 - 0.34228580275070825*lm - 
          0.1527777777777778*lm^2) + 0.0454306326784222*NM - 
        0.003422783338255064*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0879119725371454*NL - 0.003422783338255064*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.018134065589172008*NH - 
        0.003422783338255064*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.715, CF*NC*(CF*(-0.22642207309258497 + 0.375*lm) + 
        CA*(0.2115829686644015 - 0.34099210948556685*lm - 
          0.1527777777777778*lm^2) + 0.045189946425973196*NM - 
        0.0036580002955535064*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08800663649084403*NL - 0.0036580002955535064*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.018405268942739753*NH - 
        0.0036580002955535064*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.72, CF*NC*(CF*(-0.22871707414163506 + 0.375*lm) + 
        CA*(0.21274224401840225 - 0.33969209451276344*lm - 
          0.1527777777777778*lm^2) + 0.044950415359195584*NM - 
        0.0038943666542450277*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08810017823537847*NL - 0.0038943666542450277*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.01867681844549498*NH - 
        0.0038943666542450277*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.725, CF*NC*(CF*(-0.2310010971082104 + 0.375*lm) + 
        CA*(0.21391154578449514 - 0.3383858298426267*lm - 
          0.1527777777777778*lm^2) + 0.04471210135962899*NM - 
        0.004131869321542622*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08819265236806732*NL - 0.004131869321542622*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.0189487270787836*NH - 
        0.004131869321542622*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.73, CF*NC*(CF*(-0.23327435389275614 + 0.375*lm) + 
        CA*(0.2150905187481636 - 0.33707338882826837*lm - 
          0.1527777777777778*lm^2) + 0.04447506454579353*NM - 
        0.004370494960516865*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08828411249545828*NL - 0.004370494960516865*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.019221007300505296*NH - 
        0.004370494960516865*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.735, CF*NC*(CF*(-0.23553704978327875 + 0.375*lm) + 
        CA*(0.21627881208853567 - 0.33575484606302486*lm - 
          0.1527777777777778*lm^2) + 0.04423936330110513*NM - 
        0.004610230008742953*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08837461123837172*NL - 0.004610230008742953*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.01949367105884243*NH - 
        0.004610230008742953*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.74, CF*NC*(CF*(-0.23778938364169655 + 0.375*lm) + 
        CA*(0.21747607942996275 - 0.33443027728222596*lm - 
          0.1527777777777778*lm^2) + 0.044005054301903164*NM - 
        0.0048510606961609335*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0884642002375564*NL - 0.0048510606961609335*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.019766729805676023*NH - 
        0.0048510606961609335*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.745, CF*NC*(CF*(-0.2400315480861881 + 0.375*lm) + 
        CA*(0.2186819788869669 - 0.33309975926912844*lm - 
          0.1527777777777778*lm^2) + 0.04377219254555194*NM - 
        0.005092973062178668*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08855293015991257*NL - 0.005092973062178668*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02004019450969487*NH - 
        0.005092973062178668*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.75, CF*NC*(CF*(-0.2422637296695557 + 0.375*lm) + 
        CA*(0.21989617310292062 - 0.33176336976485815*lm - 
          0.1527777777777778*lm^2) + 0.04354083137858044*NM - 
        0.005335952972045991*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08864085070524018*NL - 0.005335952972045991*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.020314075669203898*NH - 
        0.005335952972045991*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.755, CF*NC*(CF*(-0.2444861090536259 + 0.375*lm) + 
        CA*(0.22111832928280556 - 0.33042118738221*lm - 0.1527777777777778*
           lm^2) + 0.04331102252482672*NM - 0.005579986132527481*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08872801061347221*NL - 
        0.005579986132527481*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.02058838332463761*NH - 0.005579986132527481*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.76, CF*NC*(CF*(-0.2466988611797154 + 0.375*lm) + 
        CA*(0.22234811922038078 - 0.3290732915231597*lm - 
          0.1527777777777778*lm^2) + 0.04308281611355607*NM - 
        0.005825058106900263*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08881445767235531*NL - 0.005825058106900263*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.020863127070784568*NH - 
        0.005825058106900263*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.765, CF*NC*(CF*(-0.24890215543519376 + 0.375*lm) + 
        CA*(0.22358521932007439 - 0.32771976229994837*lm - 
          0.1527777777777778*lm^2) + 0.04285626070752408*NM - 
        0.006071154329302312*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0889002387255419*NL - 0.006071154329302312*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02113831606872874*NH - 
        0.006071154329302312*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.77, CF*NC*(CF*(-0.25109615581617933 + 0.375*lm) + 
        CA*(0.22482931061389883 - 0.3263606804596045*lm - 
          0.1527777777777778*lm^2) + 0.04263140333095773*NM - 
        0.006318260118455755*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08898539968105999*NL - 0.006318260118455755*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.021413959057513372*NH - 
        0.006318260118455755*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.775, CF*NC*(CF*(-0.25328102108640826 + 0.375*lm) + 
        CA*(0.2260800787736743 - 0.3249961273117725*lm - 0.1527777777777778*
           lm^2) + 0.04240828949742971*NM - 0.00656636069078883*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08906998552012874*NL - 
        0.00656636069078883*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.02169006436553317*NH - 0.00656636069078883*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.78, CF*NC*(CF*(-0.2554569049323198 + 0.375*lm) + 
        CA*(0.22733721411883234 - 0.32362618465972526*lm - 
          0.1527777777777778*lm^2) + 0.04218696323760296*NM - 
        0.006815441172979243*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08915404030628932*NL - 0.006815441172979243*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.021966639921660203*NH - 
        0.006815441172979243*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.785, CF*NC*(CF*(-0.25762395611440364 + 0.375*lm) + 
        CA*(0.22860041162005756 - 0.3222509347344363*lm - 
          0.1527777777777778*lm^2) + 0.04196746712682405*NM - 
        0.0070654866139408775*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08923760719482295*NL - 0.0070654866139408775*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.022243693266109206*NH - 
        0.0070654866139408775*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.79, CF*NC*(CF*(-0.25978231861485823 + 0.375*lm) + 
        CA*(0.2298693708990143 - 0.3208704601315988*lm - 0.1527777777777778*
           lm^2) + 0.04174984231254589*NM - 0.0073164819962749615*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08932072844242868*NL - 
        0.0073164819962749615*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.022521231561047562*NH - 0.0073164819962749615*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.795, CF*NC*(CF*(-0.26193213178161073 + 0.375*lm) + 
        CA*(0.23114379622439166 - 0.3194848437514777*lm - 
          0.1527777777777778*lm^2) + 0.04153412854156146*NM - 
        0.0075684122472060794*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08940344541713585*NL - 0.0075684122472060794*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.022799261600955408*NH - 
        0.0075684122472060794*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.8, CF*NC*(CF*(-0.2640735304687521 + 0.375*lm) + 
        CA*(0.23242339650449068 - 0.3180941687414867*lm - 
          0.1527777777777778*lm^2) + 0.04132036418703212*NM - 
        0.007821262249022617*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08948579860842704*NL - 0.007821262249022617*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02307778982274103*NH - 
        0.007821262249022617*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.805, CF*NC*(CF*(-0.2662066451734406 + 0.375*lm) + 
        CA*(0.2337078852765648 - 0.3166985184413881*lm - 0.1527777777777778*
           lm^2) + 0.04110858627529502*NM - 0.008075016849040547*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08956782763754877*NL - 
        0.008075016849040547*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.02335682231561679*NH - 0.008075016849040547*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.81, CF*NC*(CF*(-0.26833160216933205 + 0.375*lm) + 
        CA*(0.2349969806931165 - 0.3152979763310129*lm - 0.1527777777777778*
           lm^2) + 0.04089883051243564*NM - 0.008329660869108762*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08964957126798889*NL - 
        0.008329660869108762*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.02363636483074063*NH - 0.008329660869108762*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.815, CF*NC*(CF*(-0.2704485236365913 + 0.375*lm) + 
        CA*(0.23629040550534108 - 0.313892625980407*lm - 0.1527777777777778*
           lm^2) + 0.04069113131061281*NM - 0.00858517911467347*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.08973106741610021*NL - 
        0.00858517911467347*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.02391642279062821*NH - 0.00858517911467347*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.82, CF*NC*(CF*(-0.2725575277885466 + 0.375*lm) + 
        CA*(0.23758788704390124 - 0.3124825510023088*lm - 
          0.1527777777777778*lm^2) + 0.04048552181412433*NM - 
        0.008841556383418596*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08981235316185152*NL - 0.008841556383418596*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02419700129834051*NH - 
        0.008841556383418596*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.825, CF*NC*(CF*(-0.2746587289950431 + 0.375*lm) + 
        CA*(0.23888915719720527 - 0.3110678350068699*lm - 
          0.1527777777777778*lm^2) + 0.040282033925202784*NM - 
        0.009098777473498396*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08989346475968824*NL - 0.009098777473498396*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.024478105146451868*NH - 
        0.009098777473498396*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.83, CF*NC*(CF*(-0.2767522379025582 + 0.375*lm) + 
        CA*(0.24019395238735466 - 0.30964856155853193*lm - 
          0.1527777777777778*lm^2) + 0.04008069832953202*NM - 
        0.009356827191378033*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08997443764948578*NL - 0.009356827191378033*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02475973882580305*NH - 
        0.009356827191378033*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.835, CF*NC*(CF*(-0.27883816155113655 + 0.375*lm) + 
        CA*(0.24150201354391773 - 0.30822481413497665*lm - 
          0.1527777777777778*lm^2) + 0.03988154452147547*NM - 
        0.009615690359297175*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09005530646757978*NL - 0.009615690359297175*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.025041906534044173*NH - 
        0.009615690359297175*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.84, CF*NC*(CF*(-0.28091660348820796 + 0.375*lm) + 
        CA*(0.24281308607567892 - 0.3067966760880696*lm - 
          0.1527777777777778*lm^2) + 0.03968460082900889*NM - 
        0.009875351822371183*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09013610505785855*NL - 0.009875351822371183*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.025324612183971962*NH - 
        0.009875351822371183*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.845, CF*NC*(CF*(-0.28298766387934804 + 0.375*lm) + 
        CA*(0.24412691984050516 - 0.3053642306067196*lm - 
          0.1527777777777778*lm^2) + 0.03948989443835043*NM - 
        0.010135796455343911*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09021686648290335*NL - 0.010135796455343911*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02560785941166591*NH - 
        0.010135796455343911*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.85, CF*NC*(CF*(-0.28505143961604273 + 0.375*lm) + 
        CA*(0.2454432691134646 - 0.3039275606815802*lm - 0.1527777777777778*
           lm^2) + 0.039297451418282066*NM - 0.010397009169005614*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09029762303516398*NL - 
        0.010397009169005614*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.025891651584427706*NH - 0.010397009169005614*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.855, CF*NC*(CF*(-0.2871080244205185 + 0.375*lm) + 
        CA*(0.24676189255332534 - 0.3024867490715218*lm - 
          0.1527777777777778*lm^2) + 0.03910729674415705*NM - 
        0.01065897491628897*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09037840624815684*NL - 0.01065897491628897*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02617599180852834*NH - 
        0.01065897491628897*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.86, CF*NC*(CF*(-0.2891575089476992 + 0.375*lm) + 
        CA*(0.24808255316755612 - 0.30104187827180434*lm - 
          0.1527777777777778*lm^2) + 0.038919454321588706*NM - 
        0.010921678698055772*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09045924690767423*NL - 0.010921678698055772*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.026460882936767082*NH - 
        0.010921678698055772*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.865, CF*NC*(CF*(-0.2911999808843496 + 0.375*lm) + 
        CA*(0.24940501827594408 - 0.29959303048388636*lm - 
          0.1527777777777778*lm^2) + 0.03873394700981666*NM - 
        0.011185105568586321*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09054017506299401*NL - 0.011185105568586321*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.026746327575846544*NH - 
        0.011185105568586321*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.87, CF*NC*(CF*(-0.2932355250454678 + 0.375*lm) + 
        CA*(0.2507290594729396 - 0.29814028758680355*lm - 
          0.1527777777777778*lm^2) + 0.038550796644747046*NM - 
        0.01144924064078319*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09062122003807939*NL - 0.01144924064078319*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02703232809356793*NH - 
        0.01144924064078319*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.875, CF*NC*(CF*(-0.295264223467985 + 0.375*lm) + 
        CA*(0.25205445258883225 - 0.2966837311100582*lm - 
          0.1527777777777778*lm^2) + 0.03837002406166395*NM - 
        0.011714069091100527*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09070241044275969*NL - 0.011714069091100527*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02731888662585047*NH - 
        0.011714069091100527*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.88, CF*NC*(CF*(-0.2972861555018337 + 0.375*lm) + 
        CA*(0.2533809776498559 - 0.29522344220795765*lm - 
          0.1527777777777778*lm^2) + 0.03819164911760987*NM - 
        0.011979576164209717*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09078377418388288*NL - 0.011979576164209717*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.027606005083579004*NH - 
        0.011979576164209717*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.885, CF*NC*(CF*(-0.2993013978984429 + 0.375*lm) + 
        CA*(0.25470841883731793 - 0.2937595016353464*lm - 
          0.1527777777777778*lm^2) + 0.03801569071343332*NM - 
        0.01224574717741176*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09086533847643187*NL - 0.01224574717741176*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02789368515928357*NH - 
        0.01224574717741176*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.89, CF*NC*(CF*(-0.3013100248967194 + 0.375*lm) + 
        CA*(0.2560365644458402 - 0.29229198972467585*lm - 
          0.1527777777777778*lm^2) + 0.037842166815502454*NM - 
        0.012512567524806414*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09094712985459688*NL - 0.012512567524806414*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.02818192833365478*NH - 
        0.012512567524806414*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.895, CF*NC*(CF*(-0.30331210830657246 + 0.375*lm) + 
        CA*(0.25736520684079633 - 0.29082098636435866*lm - 
          0.1527777777777778*lm^2) + 0.03767109447708373*NM - 
        0.012780022681227722*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0910291741827965*NL - 0.012780022681227722*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.028470735881898693*NH - 
        0.012780022681227722*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.9, CF*NC*(CF*(-0.3053077175900408 + 0.375*lm) + 
        CA*(0.25869414241502536 - 0.2893465709783574*lm - 
          0.1527777777777778*lm^2) + 0.0375024898593852*NM - 
        0.013048098205955212*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09111149666664113*NL - 0.013048098205955212*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.028760108879934854*NH - 
        0.013048098205955212*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.905, CF*NC*(CF*(-0.30729691994007674 + 0.375*lm) + 
        CA*(0.2600231715448973 - 0.2878688225069576*lm - 0.1527777777777778*
           lm^2) + 0.03733636825226452*NM - 0.013316779746209728*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09119412186383223*NL - 
        0.013316779746209728*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.029050048210441024*NH - 0.013316779746209728*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.91, CF*NC*(CF*(-0.3092797803570449 + 0.375*lm) + 
        CA*(0.26135209854580144 - 0.2863878193886774*lm - 
          0.1527777777777778*lm^2) + 0.0371727440946017*NM - 
        0.013586053040442496*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09127707369499208*NL - 0.013586053040442496*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.029340554568748102*NH - 
        0.013586053040442496*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.915, CF*NC*(CF*(-0.31125636172299004 + 0.375*lm) + 
        CA*(0.2626807316271265 - 0.28490363954326964*lm - 
          0.1527777777777778*lm^2) + 0.03701163099433759*NM - 
        0.013855903921425727*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09136037545441829*NL - 0.013855903921425727*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.029631628468588706*NH - 
        0.013855903921425727*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.92, CF*NC*(CF*(-0.31322672487372827 + 0.375*lm) + 
        CA*(0.26400888284679586 - 0.2834163603557709*lm - 
          0.1527777777777778*lm^2) + 0.036853041748178654*NM - 
        0.014126318319152764*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09144404982075852*NL - 0.014126318319152764*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.029923270247702673*NH - 
        0.014126318319152764*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.925, CF*NC*(CF*(-0.3151909286688154 + 0.375*lm) + 
        CA*(0.26533636806541794 - 0.28192605866155623*lm - 
          0.1527777777777778*lm^2) + 0.036696988360969615*NM - 
        0.014397282263555435*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0915281188676007*NL - 0.014397282263555435*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.030215480073302856*NH - 
        0.014397282263555435*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.93, CF*NC*(CF*(-0.31714903005944545 + 0.375*lm) + 
        CA*(0.26666300690011124 - 0.2804328107323577*lm - 
          0.1527777777777778*lm^2) + 0.03654348206473521*NM - 
        0.014668781887046074*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09161260407397476*NL - 0.014668781887046074*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.030508257947404357*NH - 
        0.014668781887046074*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.935, CF*NC*(CF*(-0.3191010841543303 + 0.375*lm) + 
        CA*(0.2679886226780556 - 0.27893669226320894*lm - 
          0.1527777777777778*lm^2) + 0.03639253333739292*NM - 
        0.0149408034268913*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09169752633476162*NL - 0.0149408034268913*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.03080160371202038*NH - 
        0.0149408034268913*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.94, CF*NC*(CF*(-0.3210471442836124 + 0.375*lm) + 
        CA*(0.26931304238982284 - 0.2774377783602765*lm - 
          0.1527777777777778*lm^2) + 0.03624415192113859*NM - 
        0.015213333227424472*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09178290597100675*NL - 0.015213333227424472*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.03109551705422779*NH - 
        0.015213333227424472*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.945, CF*NC*(CF*(-0.3229872620608595 + 0.375*lm) + 
        CA*(0.27063609664253396 - 0.2759361435295424*lm - 
          0.1527777777777778*lm^2) + 0.03609834684050719*NM - 
        0.015486357742103411*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09186876274013415*NL - 0.015486357742103411*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.031389997511105314*NH - 
        0.015486357742103411*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.95, CF*NC*(CF*(-0.3249214874431917 + 0.375*lm) + 
        CA*(0.27195761961288956 - 0.27443186166630235*lm - 
          0.1527777777777778*lm^2) + 0.0359551264201109*NM - 
        0.01575986353541978*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09195511584605874*NL - 0.01575986353541978*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.031685044474547494*NH - 
        0.01575986353541978*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.955, CF*NC*(CF*(-0.32684986878958844 + 0.375*lm) + 
        CA*(0.273277449000115 - 0.27292500604544667*lm - 0.1527777777777778*
           lm^2) + 0.03581449830205729*NM - 0.01603383728466626*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09204198394919381*NL - 
        0.01603383728466626*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.031980657195957066*NH - 0.01603383728466626*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.96, CF*NC*(CF*(-0.32877245291742224 + 0.375*lm) + 
        CA*(0.2745954259788626 - 0.2714156493124902*lm - 0.1527777777777778*
           lm^2) + 0.03567646946305016*NM - 0.016308265781567445*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.0921293851763517*NL - 
        0.016308265781567445*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.0322768347908188*NH - 0.016308265781567445*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.965, CF*NC*(CF*(-0.330689285157267 + 0.375*lm) + 
        CA*(0.27591139515210744 - 0.26990386347532064*lm - 
          0.1527777777777778*lm^2) + 0.035541046231175905*NM - 
        0.016583135933780087*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0922173371305353*NL - 0.016583135933780087*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.03257357624315738*NH - 
        0.016583135933780087*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.97, CF*NC*(CF*(-0.33260040940602464 + 0.375*lm) + 
        CA*(0.2772252045040735 - 0.2683897198966355*lm - 0.1527777777777778*
           lm^2) + 0.035408234302378404*NM - 0.016858434766268294*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09230585690061854*NL - 
        0.016858434766268294*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.03287088040988224*NH - 0.016858434766268294*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.975, CF*NC*(CF*(-0.3345058681784164 + 0.375*lm) + 
        CA*(0.2785367053532244 - 0.2668732892870375*lm - 0.1527777777777778*
           lm^2) + 0.035278038756625614*NM - 0.017134149422558836*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09239496107091423*NL - 
        0.017134149422558836*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.03316874602502168*NH - 0.017134149422558836*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.98, CF*NC*(CF*(-0.33640570265688047 + 0.375*lm) + 
        CA*(0.2798457523053488 - 0.26535464169876183*lm - 
          0.1527777777777778*lm^2) + 0.03515046407377094*NM - 
        0.017410267165881687*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09248466573062777*NL - 0.017410267165881687*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.033467171703849295*NH - 
        0.017410267165881687*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.985, CF*NC*(CF*(-0.3382999527399208 + 0.375*lm) + 
        CA*(0.28115220320677237 - 0.2638338465200071*lm - 
          0.1527777777777778*lm^2) + 0.035025514149112875*NM - 
        0.017686775380200737*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09257498648319544*NL - 0.017686775380200737*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.03376615594690477*NH - 
        0.017686775380200737*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.99, CF*NC*(CF*(-0.34018865708894697 + 0.375*lm) + 
        CA*(0.2824559190977224 - 0.26231097246984497*lm - 
          0.1527777777777778*lm^2) + 0.03490319230865616*NM - 
        0.0179636615711393*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09266593845550611*NL - 0.0179636615711393*lm*NL + 
        0.027777777777777776*lm^2*NL + 0.03406569714391191*NH - 
        0.0179636615711393*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.995, CF*NC*(CF*(-0.3420718531736476 + 0.375*lm) + 
        CA*(0.2837567641658727 - 0.2607860875936835*lm - 0.1527777777777778*
           lm^2) + 0.03478350132407812*NM - 0.018240913366805025*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09275753630700569*NL - 
        0.018240913366805025*lm*NL + 0.027777777777777776*lm^2*NL + 
        0.03436579357759608*NH - 0.018240913366805025*lm*NH + 
        0.027777777777777776*lm^2*NH)}, {1., 0.0001286008230452675*CF*NC*
       (18.*CF*(-148.58621740048437 + 162.*lm) - 
        1.*CA*(-2216.584613923917 + 2016.*lm + 1188.*lm^2) + 
        269.56626409149*NM - 144.*lm*NM + 216.*lm^2*NM + 722.*NL - 
        144.*lm*NL + 216.*lm^2*NL + 269.56626409149*NH - 144.*lm*NH + 
        216.*lm^2*NH)}}
 
CbarTable["v", 2, 1] = {{0., -2.679183813443073*^-7*CF*NC*
       (CA*(592964.8250444641 + 865592.7977204673*lm + 427680.*lm^2) + 
        2.*(CF*(-138025.3669776792 - 321179.5617712915*lm - 349920.*lm^2) + 
          60.*((-2627.0212293857026 - 486.77696624313234*lm - 648.*lm^2)*
             NM + (-2627.0212293857026 - 486.77696624313234*lm - 648.*lm^2)*
             NL + 3.*(-43.17331277252964 - 162.2589887477108*lm - 216.*lm^2)*
             NH)))}, {0.005, 
      CF*NC*(CA*(-0.14850224247732124 - 0.2307115806427786*lm - 
          0.11533768879492802*lm^2) + CF*(0.0777179664303011 + 
          0.1687763563733961*lm + 0.18873439984624585*lm^2) + 
        0.0835305614611142*NM + 0.015257847007298717*lm*NM + 
        0.020970488871805096*lm^2*NM + 0.08353507413299442*NL + 
        0.015257847007298717*lm*NL + 0.020970488871805096*lm^2*NL + 
        0.004224034512172956*NH + 0.015257847007298717*lm*NH + 
        0.020970488871805096*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.13870460817144323 - 0.22957592351688577*lm - 
          0.11607052595083431*lm^2) + CF*(0.08081323045709778 + 
          0.16559163366207164*lm + 0.18993358791954706*lm^2) + 
        0.08266919112415465*NM + 0.014881781741720052*lm*NM + 
        0.021103731991060783*lm^2*NM + 0.0826845950407122*NL + 
        0.014881781741720052*lm*NL + 0.021103731991060783*lm^2*NL + 
        0.004283534848505097*NH + 0.014881781741720052*lm*NH + 
        0.021103731991060783*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.1295714991851351 - 0.22852065119512519*lm - 
          0.11677930035369691*lm^2) + CF*(0.08321160880956562 + 
          0.16258200131549722*lm + 0.19109340057877675*lm^2) + 
        0.08188891005352195*NM + 0.01452590013544827*lm*NM + 
        0.021232600064308528*lm^2*NM + 0.08191970971325495*NL + 
        0.01452590013544827*lm*NL + 0.021232600064308528*lm^2*NL + 
        0.004342299783383587*NH + 0.01452590013544827*lm*NH + 
        0.021232600064308528*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.12112576625458897 - 0.22755233027511088*lm - 
          0.11746227657152623*lm^2) + CF*(0.08495665796617705 + 
          0.15976134566370004*lm + 0.19221099802613384*lm^2) + 
        0.08119132278965145*NM + 0.01419179770289012*lm*NM + 
        0.021356777558459317*lm^2*NM + 0.08124141264828619*NL + 
        0.01419179770289012*lm*NL + 0.021356777558459317*lm^2*NL + 
        0.004400144478033609*NH + 0.01419179770289012*lm*NH + 
        0.021356777558459317*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.11336047022805214 - 0.2266717838660108*lm - 
          0.11811821618887054*lm^2) + CF*(0.08611079752488494 + 
          0.15713325504221065*lm + 0.19328435376360634*lm^2) + 
        0.08057347287718143*NM + 0.013879910675734398*lm*NM + 
        0.021476039307067374*lm^2*NM + 0.0806467374490041*NL + 
        0.013879910675734398*lm*NL + 0.021476039307067374*lm^2*NL + 
        0.004456950416807158*NH + 0.013879910675734398*lm*NH + 
        0.021476039307067374*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.1062538073635974 - 0.22587668177887077*lm - 
          0.11874623602652298*lm^2) + CF*(0.08674023124331648 + 
          0.1546955148959329*lm + 0.19431202258885577*lm^2) + 
        0.08003029199262553*NM + 0.013590019755310028*lm*NM + 
        0.021590224732095088*lm^2*NM + 0.08013092429662226*NL + 
        0.013590019755310028*lm*NL + 0.021590224732095088*lm^2*NL + 
        0.004512645745496009*NH + 0.013590019755310028*lm*NH + 
        0.021590224732095088*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.09977608908328528 - 0.22516284569563771*lm - 
          0.1193457237524884*lm^2) + CF*(0.08690933760236902 + 
          0.15244239624744882*lm + 0.19529300250407194*lm^2) + 
        0.07955572555400164*NM + 0.013321506944085574*lm*NM + 
        0.021699222500452437*lm^2*NM + 0.07968839364194398*NL + 
        0.013321506944085574*lm*NL + 0.021699222500452437*lm^2*NL + 
        0.004567193428129195*NH + 0.013321506944085574*lm*NH + 
        0.021699222500452437*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.09389352187525844 - 0.2245250029582281*lm - 
          0.11991628117248802*lm^2) + CF*(0.08667839469043517 + 
          0.15036599180953958*lm + 0.19622664191861677*lm^2) + 
        0.07914332771622289*NM + 0.01307350572108557*lm*NM + 
        0.02180296021317964*lm^2*NM + 0.07931325109803843*NL + 
        0.01307350572108557*lm*NL + 0.02180296021317964*lm^2*NL + 
        0.004620583205778084*NH + 0.01307350572108557*lm*NH + 
        0.02180296021317964*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.08857042708495194 - 0.22395725681436446*lm - 
          0.1204576832852879*lm^2) + CF*(0.08610271766980847 + 
          0.1484570595848439*lm + 0.19711257264865295*lm^2) + 
        0.07878659922172486*NM + 0.012844996015933528*lm*NM + 
        0.02190139696096144*lm^2*NM + 0.07899956938026735*NL + 
        0.012844996015933528*lm*NL + 0.02190139696096144*lm^2*NL + 
        0.004672825744147784*NH + 0.012844996015933528*lm*NH + 
        0.02190139696096144*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.08377060803429884 - 0.22345339404206158*lm - 
          0.12096984728481427*lm^2) + CF*(0.08523245459095395 + 
          0.1467055823549906*lm + 0.19795065919333243*lm^2) + 
        0.07847918590592903*NM + 0.012634867313640948*lm*NM + 
        0.02199451768814805*lm^2*NM + 0.07874155151296484*NL + 
        0.012634867313640948*lm*NL + 0.02199451768814805*lm^2*NL + 
        0.004723948179579036*NH + 0.012634867313640948*lm*NH + 
        0.02199451768814805*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.07945821424157755 - 0.223007092206314*lm - 
          0.12145280829493932*lm^2) + CF*(0.08411270242653766 + 
          0.14510115074593768*lm + 0.19874095902808253*lm^2) + 
        0.07821499598673368*NM + 0.012441961952732289*lm*NM + 
        0.02208232878089806*lm^2*NM + 0.0785336259397739*NL + 
        0.012441961952732289*lm*NL + 0.02208232878089806*lm^2*NL + 
        0.004773990624539043*NH + 0.012441961952732289*lm*NH + 
        0.02208232878089806*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.07559829267908587 - 0.22261206164471325*lm - 
          0.12190669990126592*lm^2) + CF*(0.08278377813743112 + 
          0.14363323080393378*lm + 0.19948369074752606*lm^2) + 
        0.07798826761560937*NM + 0.012265105445853271*lm*NM + 
        0.022164854527502893*lm^2*NM + 0.07837050054831061*NL + 
        0.012265105445853271*lm*NL + 0.022164854527502893*lm^2*NL + 
        0.004823003366369726*NH + 0.012265105445853271*lm*NH + 
        0.022164854527502893*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.07215713654734046 - 0.22226214333702687*lm - 
          0.1223317382367472*lm^2) + CF*(0.08128155940686525 + 
          0.14229135294945194*lm + 0.20017920802376815*lm^2) + 
        0.07779360492523181*NM + 0.01210312795690636*lm*NM + 
        0.02224213422486313*lm^2*NM + 0.07824719102974988*NL + 
        0.01210312795690636*lm*NL + 0.02224213422486313*lm^2*NL + 
        0.004871044586767357*NH + 0.01210312795690636*lm*NH + 
        0.02224213422486313*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.06910249928260122 - 0.22195137608089632*lm - 
          0.1227282087818472*lm^2) + CF*(0.07963784941421104 + 
          0.14106524579167715*lm + 0.20082797800665905*lm^2) + 
        0.07762599368682026*NM + 0.011954879569322294*lm*NM + 
        0.022314219778517674*lm^2*NM + 0.07815903283993206*NL + 
        0.011954879569322294*lm*NL + 0.022314219778517674*lm^2*NL + 
        0.004918178484271954*NH + 0.011954879569322294*lm*NH + 
        0.022314219778517674*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.0664037170403248 - 0.221674041840463*lm - 
          0.12309645528951564*lm^2) + CF*(0.07788074093307648 + 
          0.13994493038022934*lm + 0.2014305632010256*lm^2) + 
        0.07748080361887578*NM + 0.011819241094080562*lm*NM + 
        0.02238117368900284*lm^2*NM + 0.07810168255474864*NL + 
        0.011819241094080562*lm*NL + 0.02238117368900284*lm^2*NL + 
        0.004964473716049031*NH + 0.011819241094080562*lm*NH + 
        0.02238117368900284*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.06403176818360548 - 0.22142469531847425*lm - 
          0.12343687040684401*lm^2) + CF*(0.07603496650613195 + 
          0.13892078556990964*lm + 0.20198760612029018*lm^2) + 
        0.07735378194560263*NM + 0.011695131616651252*lm*NM + 
        0.02244306734669891*lm^2*NM + 0.07807111235385021*NL + 
        0.011695131616651252*lm*NL + 0.02244306734669891*lm^2*NL + 
        0.005010002097382887*NH + 0.011695131616651252*lm*NH + 
        0.02244306734669891*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.061959289097950045 - 0.22119818199106717*lm - 
          0.12374988767401962*lm^2) + CF*(0.07412222792256079 + 
          0.13798359201339672*lm + 0.2024998161938503*lm^2) + 
        0.07724104127819932*NM + 0.011581513627528335*lm*NM + 
        0.022499979577094476*lm^2*NM + 0.07806360009757123*NL + 
        0.011581513627528335*lm*NL + 0.022499979577094476*lm^2*NL + 
        0.00505483751229902*NH + 0.011581513627528335*lm*NH + 
        0.022499979577094476*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.0601605596967386 - 0.22098964764038406*lm - 
          0.12403597465679524*lm^2) + CF*(0.07216150194518978 + 
          0.13712456018973457*lm + 0.2029679585293013*lm^2) + 
        0.0771390439091578*NM + 0.011477396344613077*lm*NM + 
        0.02255199539214459*lm^2*NM + 0.0780757166537924*NL + 
        0.011477396344613077*lm*NL + 0.02255199539214459*lm^2*NL + 
        0.005099054999244671*NH + 0.011477396344613077*lm*NH + 
        0.02255199539214459*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.05861146801885351 - 0.22079454159727516*lm - 
          0.12429562702272495*lm^2) + CF*(0.0701693213881822 + 
          0.13633534643209683*lm + 0.20339284421900447*lm^2) + 
        0.0770445839589845*NM + 0.011381837673584751*lm*NM + 
        0.022599204913222717*lm^2*NM + 0.07810431160282541*NL + 
        0.011381837673584751*lm*NL + 0.022599204913222717*lm^2*NL + 
        0.005142729983339905*NH + 0.011381837673584751*lm*NH + 
        0.022599204913222717*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.05728946062081349 - 0.2206086153304716*lm - 
          0.12452936341096908*lm^2) + CF*(0.06816003188447364 + 
          0.13560805990438965*lm + 0.20377532194522213*lm^2) + 
        0.0769547683744213*NM + 0.01129394513853918*lm*NM + 
        0.022641702438358016*lm^2*NM + 0.07814649809481011*NL + 
        0.01129394513853918*lm*NL + 0.022641702438358016*lm^2*NL + 
        0.005185937632321866*NH + 0.01129394513853918*lm*NH + 
        0.022641702438358016*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.05617348359015248 - 0.22042791760734745*lm - 
          0.12473772097503301*lm^2) + CF*(0.06614602537546536 + 
          0.13493526274977327*lm + 0.20411627068641766*lm^2) + 
        0.07686699747379738*NM + 0.011212876033559667*lm*NM + 
        0.022679585631824185*lm^2*NM + 0.07819963739317619*NL + 
        0.011212876033559667*lm*NL + 0.022679585631824185*lm^2*NL + 
        0.005228752317547138*NH + 0.011212876033559667*lm*NH + 
        0.022679585631824185*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.05524391768103474 - 0.22024878715249574*lm - 
          0.12492125150030782*lm^2) + CF*(0.06413795172039743 + 
          0.13430996510435325*lm + 0.20441659336414006*lm^2) + 
        0.07677894552288328*NM + 0.011137836986332951*lm*NM + 
        0.022712954818237787*lm^2*NM + 0.07826132347102012*NL + 
        0.011137836986332951*lm*NL + 0.022712954818237787*lm^2*NL + 
        0.0052712471646873624*NH + 0.011137836986332951*lm*NH + 
        0.022712954818237787*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.05448251012229497 - 0.22006784350979722*lm - 
          0.12508051801569034*lm^2) + CF*(0.062144909988718584 + 
          0.13372561627688984*lm + 0.20467721129840236*lm^2) + 
        0.07668854167434462*NM + 0.011068083080795122*lm*NM + 
        0.02274191236648915*lm^2*NM + 0.07832936791047708*NL + 
        0.011068083080795122*lm*NL + 0.02274191236648915*lm^2*NL + 
        0.005313493681317245*NH + 0.011068083080795122*lm*NH + 
        0.02274191236648915*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.05387230495774878 - 0.2198819766487752*lm - 
          0.12521609183222443*lm^2) + CF*(0.06017462104441154 + 
          0.13317609310082926*lm + 0.2048990593618218*lm^2) + 
        0.07659395149650162*NM + 0.011002916652650995*lm*NM + 
        0.022766562151313532*lm^2*NM + 0.07840178527257405*NL + 
        0.011002916652650995*lm*NL + 0.022766562151313532*lm^2*NL + 
        0.005355561450634607*NH + 0.011002916652650995*lm*NH + 
        0.022766562151313532*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.05339757327217544 - 0.21968833573134036*lm - 
          0.12532854995256912*lm^2) + CF*(0.0582335830052316 + 
          0.1326556862412624*lm + 0.20508308174056766*lm^2) + 
        0.07649355923982826*NM + 0.010941685846426052*lm*NM + 
        0.022787009082285294*lm^2*NM + 0.07847677904621767*NL + 
        0.010941685846426052*lm*NL + 0.022787009082285294*lm^2*NL + 
        0.005397517882197893*NH + 0.010941685846426052*lm*NH + 
        0.022787009082285294*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.053043744281656376 - 0.21948431735980628*lm - 
          0.12541847280383644*lm^2) + CF*(0.05632721109246201 + 
          0.13215908506778068*lm + 0.20523022822445963*lm^2) + 
        0.07638595093378442*NM + 0.010883783003374526*lm*NM + 
        0.022803358691606625*lm^2*NM + 0.07855272824287231*NL + 
        0.010883783003374526*lm*NL + 0.022803358691606625*lm^2*NL + 
        0.005439428011909429*NH + 0.010883783003374526*lm*NH + 
        0.022803358691606625*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.05279733798779141 - 0.21926755355371158*lm - 
          0.1254864422534434*lm^2) + CF*(0.05445996329706162 + 
          0.1316813615713288*lm + 0.20534145096018014*lm^2) + 
        0.07626989836615518*NM + 0.010828642934588753*lm*NM + 
        0.02281571677335335*lm^2*NM + 0.07862817467331011*NL + 
        0.010828642934588753*lm*NL + 0.02281571677335335*lm^2*NL + 
        0.005481354344580258*NH + 0.010828642934588753*lm*NH + 
        0.02281571677335335*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.052645899886251166 - 0.21903589964608092*lm - 
          0.1255330398734481*lm^2) + CF*(0.05263545318786265 + 
          0.13121795369949493*lm + 0.2054177016110969*lm^2) + 
        0.07614434396785515*NM + 0.010775741121960605*lm*NM + 
        0.022824189067899656*lm^2*NM + 0.07870181092121725*NL + 
        0.010775741121960605*lm*NL + 0.022824189067899656*lm^2*NL + 
        0.0055233567333340654*NH + 0.010775741121960605*lm*NH + 
        0.022824189067899656*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.052577938062993025 - 0.21878742224533856*lm - 
          0.1255588454236602*lm^2) + CF*(0.05085655108416446 + 
          0.1307646484032682*lm + 0.20545992887508033*lm^2) + 
        0.07600838660513978*NM + 0.010724591880454238*lm*NM + 
        0.022828880986120036*lm^2*NM + 0.07877246901306391*NL + 
        0.010724591880454238*lm*NL + 0.022828880986120036*lm^2*NL + 
        0.005565492290881318*NH + 0.010724591880454238*lm*NH + 
        0.022828880986120036*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.05258286289314148 - 0.2185203873742376*lm - 
          0.12556443552783653*lm^2) + CF*(0.049125474713184944 + 
          0.13031756462399044*lm + 0.20546907631827796*lm^2) + 
        0.07586126826619244*NM + 0.010674746507882681*lm*NM + 
        0.02282989736869755*lm^2*NM + 0.07883910977280716*NL + 
        0.010674746507882681*lm*NL + 0.02282989736869755*lm^2*NL + 
        0.0056078153283487695*NH + 0.010674746507882681*lm*NH + 
        0.02282989736869755*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.05265092946842231 - 0.2182332488697144*lm - 
          0.12555038252064762*lm^2) + CF*(0.04744387037505469 + 
          0.12987313639819523*lm + 0.2054460804883325*lm^2) + 
        0.07570236161855347*NM + 0.010625791442608128*lm*NM + 
        0.022827342276481387*lm^2*NM + 0.07890081284248723*NL + 
        0.010625791442608128*lm*NL + 0.022827342276481387*lm^2*NL + 
        0.005650377317906024*NH + 0.010625791442608128*lm*NH + 
        0.022827342276481387*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.052773182812063585 - 0.2179246371058858*lm - 
          0.12551725344595496*lm^2) + CF*(0.04581288554586364 + 
          0.1294280962173657*lm + 0.20539186927519903*lm^2) + 
        0.07553115840667815*NM + 0.010577346444981393*lm*NM + 
        0.02282131880835545*lm^2*NM + 0.0789567673447189*NL + 
        0.010577346444981393*lm*NL + 0.02282131880835545*lm^2*NL + 
        0.005693226875907315*NH + 0.010577346444981393*lm*NH + 
        0.02282131880835545*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.05294140588996249 - 0.2175933480852297*lm - 
          0.1254656091893646*lm^2) + CF*(0.0442332337634285 + 
          0.12897945874714573*lm + 0.20530736049168755*lm^2) + 
        0.07534725865419767*NM + 0.010529062814651609*lm*NM + 
        0.022811928943520837*lm^2*NM + 0.07900626315982527*NL + 
        0.010529062814651609*lm*NL + 0.022811928943520837*lm^2*NL + 
        0.005736409763676532*NH + 0.010529062814651609*lm*NH + 
        0.022811928943520837*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.05314807038970443 - 0.21723833292937744*lm - 
          0.12539600373009732*lm^2) + CF*(0.04270525256119067 + 
          0.1285245049845076*lm + 0.20519346064925018*lm^2) + 
        0.07515036063258254*NM + 0.010480621652922139*lm*NM + 
        0.02279927340547224*lm^2*NM + 0.07904868278843792*NL + 
        0.010480621652922139*lm*NL + 0.02279927340547224*lm^2*NL + 
        0.005779968903417931*NH + 0.010480621652922139*lm*NH + 
        0.02279927340547224*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.05338629021171379 - 0.21685868779015588*lm - 
          0.1253089834989969*lm^2) + CF*(0.04122895514292655 + 
          0.12806076691050036*lm + 0.20505106390744948*lm^2) + 
        0.07494025155639068*NM + 0.01043173217695468*lm*NM + 
        0.022783451545272164*lm^2*NM + 0.07908349376943986*NL + 
        0.01043173217695468*lm*NL + 0.022783451545272164*lm^2*NL + 
        0.005823944407042479*NH + 0.01043173217695468*lm*NH + 
        0.022783451545272164*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.053649777597131375 - 0.21645364419297858*lm - 
          0.12520508683103637*lm^2) + CF*(0.03980407642451826 + 
          0.12758601267944458*lm + 0.20488105117805952*lm^2) + 
        0.07471679896476657*NM + 0.010382130090714965*lm*NM + 
        0.022764561242006612*lm^2*NM + 0.07911024162289465*NL + 
        0.010382130090714965*lm*NL + 0.022764561242006612*lm^2*NL + 
        0.0058683736159677825*NH + 0.010382130090714965*lm*NH + 
        0.022764561242006612*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.0539328018032045 - 0.21602255981794427*lm - 
          0.12508484350201507*lm^2) + CF*(0.038430114008554436 + 
          0.12709823237199724*lm + 0.20468428936693372*lm^2) + 
        0.07447994274906566*NM + 0.010331576016019441*lm*NM + 
        0.022742698818548193*lm^2*NM + 0.07912854328788871*NL + 
        0.010331576016019441*lm*NL + 0.022742698818548193*lm^2*NL + 
        0.005913291150183661*NH + 0.010331576016019441*lm*NH + 
        0.022742698818548193*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.054230150227697255 - 0.2155649097187026*lm - 
          0.12494877434029876*lm^2) + CF*(0.037106364602615384 + 
          0.1265956243287412*lm + 0.2044616307386707*lm^2) + 
        0.07422968778719576*NM + 0.010279853985810675*lm*NM + 
        0.02271795897096341*lm^2*NM + 0.07913808102586602*NL + 
        0.010279853985810675*lm*NL + 0.02271795897096341*lm^2*NL + 
        0.005958728965080719*NH + 0.010279853985810675*lm*NH + 
        0.02271795897096341*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.05453709187804328 - 0.2150802779750105*lm - 
          0.1247973909054683*lm^2) + CF*(0.035831956342338545 + 
          0.12607658207235142*lm + 0.2042139123907663*lm^2) + 
        0.0739660971463162*NM + 0.010226770000802635*lm*NM + 
        0.022690434710085146*lm^2*NM + 0.07913859676094445*NL + 
        0.010226770000802635*lm*NL + 0.022690434710085146*lm^2*NL + 
        0.006004716414719602*NH + 0.010226770000802635*lm*NH + 
        0.022690434710085146*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.05484934307330865 - 0.21456834977170045*lm - 
          0.1246311952266288*lm^2) + CF^2*(0.03460587742623309 + 
          0.12553968181954528*lm + 0.20394195582539257*lm^2) + 
        CF*((0.07368928583871565 + 0.010172150649849615*lm + 
            0.02266021731393251*lm^2)*NM + (0.07912988682978683 + 
            0.010172150649849615*lm + 0.02266021731393251*lm^2)*NL + 
          (0.006051280320377449 + 0.010172150649849615*lm + 
            0.02266021731393251*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.05516303529175651 - 0.21402890389433477*lm - 
          0.12445067959391165*lm^2) + CF^2*(0.033427001480070814 + 
          0.12498367057860856*lm + 0.20364656660821906*lm^2) + 
        CF*((0.07339941499216993 + 0.010115841793767264*lm + 
            0.022627396289802117*lm^2)*NM + (0.07911179711479424 + 
            0.010115841793767264*lm + 0.022627396289802117*lm^2)*NL + 
          (0.0060984450433482105 + 0.010115841793767264*lm + 
            0.022627396289802117*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.0554746850110514 - 0.21346180562998526*lm - 
          0.12425632639738828*lm^2) + CF^2*(0.032294109899412844 + 
          0.12440745482404174*lm + 0.2033285341048172*lm^2) + 
        CF*((0.0730966866197173 + 0.010057707311841356*lm + 
            0.022592059344979685*lm^2)*NM + (0.07908421853564812 + 
            0.010057707311841356*lm + 0.022592059344979685*lm^2)*NL + 
          (0.006146232561097356 + 0.010057707311841356*lm + 
            0.022592059344979685*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.0557811654866 - 0.21286700006023118*lm - 
          0.12404860800822168*lm^2) + CF^2*(0.03120591157922815 + 
          0.12381008973657212*lm + 0.20298863128618092*lm^2) + 
        CF*((0.0727813387034599 + 0.009997627909875033*lm + 
            0.022554292365131214*lm^2)*NM + (0.07904708287551407 + 
            0.009997627909875033*lm + 0.022554292365131214*lm^2)*NL + 
          (0.0061946625459811605 + 0.009997627909875033*lm + 
            0.022554292365131214*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.05607968032951836 - 0.2122445057325252*lm - 
          0.12382798669741947*lm^2) + CF^2*(0.030161060236539246 + 
          0.12319076899425724*lm + 0.20262761459577733*lm^2) + 
        CF*((0.07245364073110093 + 0.009935499988329*lm + 
            0.022514179399530813*lm^2)*NM + (0.07900035891951074 + 
            0.009935499988329*lm + 0.022514179399530813*lm^2)*NL + 
          (0.006243752445837959 + 0.009935499988329*lm + 0.022514179399530813*
             lm^2)*NH))}, {0.225, 
      NC*(CA*CF*(-0.056367738795778555 - 0.21159440869545013*lm - 
          0.12359491458802947*lm^2) + CF^2*(0.0291581695988249 + 
          0.12254881509851794*lm + 0.20224622387132096*lm^2) + 
        CF*((0.07211388959602676 + 0.009871234568884939*lm + 
            0.022471802652368995*lm^2)*NM + (0.07894404888431938 + 
            0.009871234568884939*lm + 0.022471802652368995*lm^2)*NL + 
          (0.006293517565844742 + 0.009871234568884939*lm + 
            0.022471802652368995*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.0566431326873291 - 0.2109168568830229*lm - 
          0.12334983363704327*lm^2) + CF^2*(0.02819582667783348 + 
          0.12188367021757071*lm + 0.20184518231516171*lm^2) + 
        CF*((0.07176240584344518 + 0.009804756277597455*lm + 
            0.022427242479462414*lm^2)*NM + (0.07887818511905341 + 
            0.009804756277597455*lm + 0.022427242479462414*lm^2)*NL + 
          (0.006343971151109793 + 0.009804756277597455*lm + 
            0.022427242479462414*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.05690391477165209 - 0.21021205483304123*lm - 
          0.12309317564365167*lm^2) + CF^2*(0.027272603330041372 + 
          0.12119488752878056*lm + 0.20142519650779364*lm^2) + 
        CF*((0.07139953023763132 + 0.009736002382683143*lm + 
            0.02238057738975485*lm^2)*NM + (0.07880282705870932 + 
            0.009736002382683143*lm + 0.02238057738975485*lm^2)*NL + 
          (0.0063951244695385715 + 0.009736002382683143*lm + 
            0.02238057738975485*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.05714837863035133 - 0.20948025872447298*lm - 
          0.12282536228083377*lm^2) + CF^2*(0.026387066285296894 + 
          0.12048212304085174*lm + 0.20098695645954615*lm^2) + 
        CF*((0.07102562062661673 + 0.009664921884917856*lm + 
            0.022331884051060683*lm^2)*NM + (0.0787180584126775 + 
            0.009664921884917856*lm + 0.022331884051060683*lm^2)*NL + 
          (0.006446986894572401 + 0.009664921884917856*lm + 
            0.022331884051060683*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.05737503985132344 - 0.20872177171902237*lm - 
          0.1225468051475635*lm^2) + CF^2*(0.02553778580691267 + 
          0.11974512787644648*lm + 0.200531135696013*lm^2) + 
        CF*((0.0706410490825445 + 0.009591474658567887*lm + 
            0.022281237299557*lm^2)*NM + (0.07862398457189665 + 
            0.009591474658567887*lm + 0.022281237299557*lm^2)*NL + 
          (0.006499565987451832 + 0.009591474658567887*lm + 
            0.022281237299557*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.05758261848331632 - 0.2079369395922441*lm - 
          0.12225790583918816*lm^2) + CF^2*(0.02472334313049326 + 
          0.11898374099572002*lm + 0.200058391373217*lm^2) + 
        CF*((0.07024619929705057 + 0.009515630640761169*lm + 
            0.022228710152579666*lm^2)*NM + (0.07852073021928865 + 
            0.009515630640761169*lm + 0.022228710152579666*lm^2)*NL + 
          (0.006552867578705057 + 0.009515630640761169*lm + 
            0.022228710152579666*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.05777002267572601 - 0.20712614663989284*lm - 
          0.12195905603377605*lm^2) + CF^2*(0.02394233681403744 + 
          0.11819788234133742*lm + 0.19956936441890624*lm^2) + 
        CF*((0.06984146421255198 + 0.009437369067205893*lm + 
            0.022174373824322916*lm^2)*NM + (0.07840843712910907 + 
            0.009437369067205893*lm + 0.022174373824322916*lm^2)*NL + 
          (0.006606895848604161 + 0.009437369067205893*lm + 
            0.022174373824322916*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.05793633343054192 - 0.20628981184557163*lm - 
          0.1216506375924486*lm^2) + CF^2*(0.023193388118700232 + 
          0.11738754638575985*lm + 0.19906467969673408*lm^2) + 
        CF*((0.06942724387157505 + 0.009356677752181946*lm + 
            0.022118297744081562*lm^2)*NM + (0.07828726214179302 + 
            0.009356677752181946*lm + 0.022118297744081562*lm^2)*NL + 
          (0.006661653406369825 + 0.009356677752181946*lm + 
            0.022118297744081562*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.058080790397302136 - 0.20542838529616433*lm - 
          0.12133302267190844*lm^2) + CF^2*(0.022475145527714444 + 
          0.11655279606192219*lm + 0.19854494619039564*lm^2) + 
        CF*((0.06900394346748594 + 0.009273552410761806*lm + 
            0.022060549576710626*lm^2)*NM + (0.0781573753017678 + 
            0.009273552410761806*lm + 0.022060549576710626*lm^2)*NL + 
          (0.006717141367938738 + 0.009273552410761806*lm + 
            0.022060549576710626*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.05820277864576885 - 0.20454234483199057*lm - 
          0.12100657384755106*lm^2) + CF^2*(0.021786288500282507 + 
          0.11569375705884673*lm + 0.19801075720508354*lm^2) + 
        CF*((0.06857197158112249 + 0.0091879960212592*lm + 
            0.022001195245009285*lm^2)*NM + (0.07801895814654194 + 
            0.0091879960212592*lm + 0.022001195245009285*lm^2)*NL + 
          (0.0067733594321378555 + 0.0091879960212592*lm + 
            0.022001195245009285*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.05830181635474722 - 0.20363219291909843*lm - 
          0.12067164424570714*lm^2) + CF^2*(0.021125530547607484 + 
          0.11481061246422833*lm + 0.1974626905838844*lm^2) + 
        CF*((0.06813173858893566 + 0.009100018225953436*lm + 
            0.021940298953764936*lm^2)*NM + (0.07787220213617012 + 
            0.009100018225953436*lm + 0.021940298953764936*lm^2)*NL + 
          (0.006830305955136241 + 0.009100018225953436*lm + 
            0.021940298953764936*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.05837754335907228 - 0.20269845373159756*lm - 
          0.12032857768370622*lm^2) + CF^2*(0.020491621709603593 + 
          0.11390359773656737*lm + 0.19690130893697383*lm^2) + 
        CF*((0.06768365522923121 + 0.009009634768193156*lm + 
            0.021877923215219315*lm^2)*NM + (0.0777173072129328 + 
            0.009009634768193156*lm + 0.021877923215219315*lm^2)*NL + 
          (0.006887978023068715 + 0.009009634768193156*lm + 
            0.021877923215219315*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.05842971050022442 - 0.20174167043243346*lm - 
          0.11997770881658161*lm^2) + CF^2*(0.019883350503022125 + 
          0.11297299599000374*lm + 0.196327159881679*lm^2) + 
        CF*((0.0672281313140797 + 0.008916866964043396*lm + 
            0.021814128875742113*lm^2)*NM + (0.07755448048176405 + 
            0.008916866964043396*lm + 0.021814128875742113*lm^2)*NL + 
          (0.006946371522746415 + 0.008916866964043396*lm + 
            0.021814128875742113*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.058458169729316174 - 0.20076240264149972*lm - 
          0.11961936328935366*lm^2) + CF^2*(0.019299545404697388 + 
          0.11201913357560739*lm + 0.19574077629166964*lm^2) + 
        CF*((0.06676557457533203 + 0.008821741206703235*lm + 
            0.021748975143518846*lm^2)*NM + (0.07738393500261057 + 
            0.008821741206703235*lm + 0.021748975143518846*lm^2)*NL + 
          (0.007005481210388044 + 0.008821741206703235*lm + 
            0.021748975143518846*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.05846286491424976 - 0.1997612240804798*lm - 
          0.11925385789393478*lm^2) + CF^2*(0.018739075927138936 + 
          0.11104237594349824*lm + 0.19514267655371145*lm^2) + 
        CF*((0.06629638963402806 + 0.00872428850198663*lm + 
            0.02168251961707905*lm^2)*NM + (0.07720588868651282 + 
            0.00872428850198663*lm + 0.02168251961707905*lm^2)*NL + 
          (0.007065300778321473 + 0.00872428850198663*lm + 
            0.02168251961707905*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.05844386166419927 - 0.1987387203842977*lm - 
          0.11888150072979473*lm^2) + CF^2*(0.018200930054751093 + 
          0.1100431237707926*lm + 0.19453336483057318*lm^2) + 
        CF*((0.06582097708323749 + 0.0086245440332256*lm + 
            0.021614818314508132*lm^2)*NM + (0.07702056328776781 + 
            0.0086245440332256*lm + 0.021614818314508132*lm^2)*NL + 
          (0.007125822919620396 + 0.0086245440332256*lm + 
            0.021614818314508132*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.05840117896638249 - 0.1976954870695354*lm - 
          0.11850259136761207*lm^2) + CF^2*(0.01768389376179621 + 
          0.10902180934099974*lm + 0.19391333132881977*lm^2) + 
        CF*((0.06533973267512821 + 0.008522546754021827*lm + 
            0.021545925703202195*lm^2)*NM + (0.07682818348506362 + 
            0.008522546754021827*lm + 0.021545925703202195*lm^2)*NL + 
          (0.007187039390652859 + 0.008522546754021827*lm + 
            0.021545925703202195*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.05833503362893754 - 0.19663212765064156*lm - 
          0.11811742101521598*lm^2) + CF^2*(0.017187054720941022 + 
          0.10797889316111348*lm + 0.19328305257035341*lm^2) + 
        CF*((0.06485304660369502 + 0.008418339007339397*lm + 
            0.021475894730039267*lm^2)*NM + (0.07662897604497186 + 
            0.008418339007339397*lm + 0.021475894730039267*lm^2)*NL + 
          (0.007248941071530026 + 0.008418339007339397*lm + 
            0.021475894730039267*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.05824565747853126 - 0.19554925189521036*lm - 
          0.11772627268519363*lm^2) + CF^2*(0.016709450211619098 + 
          0.10691486080325825*lm + 0.19264299166668047*lm^2) + 
        CF*((0.06436130287525062 + 0.008311966169497574*lm + 
            0.021404776851853387*lm^2)*NM + (0.07642316906164635 + 
            0.008311966169497574*lm + 0.021404776851853387*lm^2)*NL + 
          (0.007311518024453164 + 0.008311966169497574*lm + 
            0.021404776851853387*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.058133337314660784 - 0.19444747421004885*lm - 
          0.11732942136360362*lm^2) + CF^2*(0.016250159335576313 + 
          0.10583021995835108*lm + 0.19199359859498774*lm^2) + 
        CF*((0.06386487875932878 + 0.008203476317687385*lm + 
            0.02133262206610975*lm^2)*NM + (0.07621099126700827 + 
            0.008203476317687385*lm + 0.02133262206610975*lm^2)*NL + 
          (0.007374759549965303 + 0.008203476317687385*lm + 
            0.02133262206610975*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.057998409059771695 - 0.19332741215017543*lm - 
          0.11692713417929364*lm^2) + CF^2*(0.015808302513398518 + 
          0.10472549768983*lm + 0.19133531047520777*lm^2) + 
        CF*((0.06336414431322071 + 0.008092919919699485*lm + 
            0.021259478941689752*lm^2)*NM + (0.07599267140609971 + 
            0.008092919919699485*lm + 0.021259478941689752*lm^2)*NL + 
          (0.007438654241121656 + 0.008092919919699485*lm + 
            0.021259478941689752*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.05784125234646045 - 0.19218968504330178*lm - 
          0.11651967057337434*lm^2) + CF^2*(0.015383040832812424 + 
          0.10360123787607249*lm + 0.19066855184733983*lm^2) + 
        CF*((0.06285946197386001 + 0.007980349544612873*lm + 
            0.021185394649704425*lm^2)*NM + (0.07576843767266331 + 
            0.007980349544612873*lm + 0.021185394649704425*lm^2)*NL + 
          (0.007503190035599054 + 0.007980349544612873*lm + 
            0.021185394649704425*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.0576622855125776 - 0.1910349127227427*lm - 
          0.1161072824684494*lm^2) + CF^2*(0.014973575271903758 + 
          0.10245799883068295*lm + 0.18999373494837174*lm^2) + 
        CF*((0.06235118621124786 + 0.007865819593254183*lm + 
            0.021110414994263527*lm^2)*NM + (0.0755385172003541 + 
            0.007865819593254183*lm + 0.021110414994263527*lm^2)*NL + 
          (0.007568354265770331 + 0.007865819593254183*lm + 
            0.021110414994263527*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.057461960976891734 - 0.1898637143620756*lm - 
          0.11569021443724525*lm^2) + CF^2*(0.014579145817848329 + 
          0.1012963510903658*lm + 0.1893112599882195*lm^2) + 
        CF*((0.06183966323805376 + 0.00774938604729584*lm + 
            0.0210345844431355*lm^2)*NM + (0.07530313560531603 + 
            0.00774938604729584*lm + 0.0210345844431355*lm^2)*NL + 
          (0.0076341337067748405 + 0.00774938604729584*lm + 
            0.0210345844431355*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.05724076096972034 - 0.18867670740523235*lm - 
          0.11526870387032438*lm^2) + CF^2*(0.014199030499481237 + 
          0.10011687536061954*lm + 0.18862151542416716*lm^2) + 
        CF*((0.06132523077040388 + 0.007631106235917594*lm + 
            0.020957946158240797*lm^2)*NM + (0.07506251657615828 + 
            0.007631106235917594*lm + 0.020957946158240797*lm^2)*NL + 
          (0.007700514622618668 + 0.007631106235917594*lm + 
            0.020957946158240797*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.0569991935945474 - 0.1874745065860499*lm - 
          0.11484298114260122*lm^2) + CF^2*(0.013832544349930188 + 
          0.0989201606099852*lm + 0.18792487823334744*lm^2) + 
        CF*((0.06080821783529211 + 0.0075110386190104395*lm + 
            0.020880542025927495*lm^2)*NM + (0.07481688150764887 + 
            0.0075110386190104395*lm + 0.020880542025927495*lm^2)*NL + 
          (0.007767482810344141 + 0.0075110386190104395*lm + 
            0.020880542025927495*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.05673778919819955 - 0.18625772303163693*lm - 
          0.11441326977841318*lm^2) + CF^2*(0.01347903831371934 + 
          0.09770680230406303*lm + 0.18722171418285793*lm^2) + 
        CF*((0.06028894462037206 + 0.007389242585954079*lm + 
            0.020802412686984215*lm^2)*NM + (0.07456644917470581 + 
            0.007389242585954079*lm + 0.020802412686984215*lm^2)*NL + 
          (0.00783502364230824 + 0.007389242585954079*lm + 
            0.020802412686984215*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.056457097028575175 - 0.18502696344422606*lm - 
          0.1139797866149287*lm^2) + CF^2*(0.013137898111045756 + 
          0.09647740077097001*lm + 0.18651237809715607*lm^2) + 
        CF*((0.059767722362223975 + 0.007265778269049334*lm + 
            0.020723597566350675*lm^2)*NM + (0.07431143544351111 + 
            0.007265778269049334*lm + 0.020723597566350675*lm^2)*NL + 
          (0.007903122106614428 + 0.007265778269049334*lm + 
            0.020723597566350675*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.056157682160288214 - 0.18378282935648*lm - 
          0.11354274196370116*lm^2) + CF^2*(0.01280854307045935 + 
          0.09523255969035113*lm + 0.18579721412242006*lm^2) + 
        CF*((0.05924485326945007 + 0.0071407063707349385*lm + 
            0.020644134902491118*lm^2)*NM + (0.07405205301679975 + 
            0.0071407063707349385*lm + 0.020644134902491118*lm^2)*NL + 
          (0.007971762845741746 + 0.0071407063707349385*lm + 
            0.020644134902491118*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.055840122669831446 - 0.18252591645550553*lm - 
          0.11310233977020195*lm^2) + CF^2*(0.012490424939777336 + 
          0.09397288469847824*lm + 0.1850765559876032*lm^2) + 
        CF*((0.05872063047736208 + 0.00701408800376419*lm + 
            0.020564061776400355*lm^2)*NM + (0.07378851121058862 + 
            0.00701408800376419*lm + 0.020564061776400355*lm^2)*NL + 
          (0.008040930193419197 + 0.00701408800376419*lm + 
            0.020564061776400355*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.05550500704308695 - 0.1812568139710974*lm - 
          0.11265877777118846*lm^2) + CF^2*(0.012183026683917686 + 
          0.09269898210237204*lm + 0.18435072726194476*lm^2) + 
        CF*((0.058195338031060743 + 0.006885984543560879*lm + 
            0.020483414140216084*lm^2)*NM + (0.07352101575980693 + 
            0.006885984543560879*lm + 0.020483414140216084*lm^2)*NL + 
          (0.008110608209792142 + 0.006885984543560879*lm + 
            0.020483414140216084*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.05515293179908827 - 0.1799761041239922*lm - 
          0.11221224764978222*lm^2) + CF^2*(0.011885861277170564 + 
          0.0914114576962657*lm + 0.18362004160873455*lm^2) + 
        CF*((0.05766925089420306 + 0.00675645749201592*lm + 
            0.02040222684541495*lm^2)*NM + (0.07324976865047324 + 
            0.00675645749201592*lm + 0.02040222684541495*lm^2)*NL + 
          (0.008180780714929678 + 0.00675645749201592*lm + 
            0.02040222684541495*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.05478449931501178 - 0.17868436163015455*lm - 
          0.11176293518815142*lm^2) + CF^2*(0.011598470496504292 + 
          0.09011091567409453*lm + 0.18288480303515686*lm^2) + 
        CF*((0.05714263498078267 + 0.0066255683520261175*lm + 
            0.020320533670572984*lm^2)*NM + (0.07297496797623498 + 
            0.0066255683520261175*lm + 0.020320533670572984*lm^2)*NL + 
          (0.008251431320722306 + 0.0066255683520261175*lm + 
            0.020320533670572984*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.05440031583833987 - 0.17738215325734988*lm - 
          0.11131102041770798*lm^2) + CF^2*(0.0113204237215974 + 
          0.08879795763204322*lm + 0.1821453061380676*lm^2) + 
        CF*((0.05661574720755253 + 0.006493378512114662*lm + 
            0.020238367348674176*lm^2)*NM + (0.07269680781724504 + 
            0.006493378512114662*lm + 0.020238367348674176*lm^2)*NL + 
          (0.008322543461218745 + 0.006493378512114662*lm + 
            0.020238367348674176*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.054000989673060606 - 0.17607003743047536*lm - 
          0.11085667776674434*lm^2) + CF^2*(0.011051316746512108 + 
          0.08747318165551332*lm + 0.18140183634558163*lm^2) + 
        CF*((0.056088835564875275 + 0.0063599491405092285*lm + 
            0.020155759593953517*lm^2)*NM + (0.07241547813949764 + 
            0.0063599491405092285*lm + 0.020155759593953517*lm^2)*NL + 
          (0.008394100421452015 + 0.0063599491405092285*lm + 
            0.020155759593953517*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.05358712952762593 - 0.17474856388232876*lm - 
          0.110400076205449*lm^2) + CF^2*(0.010790770607216952 + 
          0.08613718148518813*lm + 0.18065467015437112*lm^2) + 
        CF*((0.055562139203984603 + 0.006225341088088105*lm + 
            0.020072741128263457*lm^2)*NM + (0.07213116471288308 + 
            0.006225341088088105*lm + 0.020072741128263457*lm^2)*NL + 
          (0.008466085364803737 + 0.006225341088088105*lm + 
            0.020072741128263457*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.05315934301319709 - 0.1734182733466907*lm - 
          0.10994137938825164*lm^2) + CF^2*(0.010538430428542038 + 
          0.08479054575717063*lm + 0.17990407536259362*lm^2) + 
        CF*((0.055035888538786985 + 0.006089614799637596*lm + 
            0.019989341706954846*lm^2)*NM + (0.07184404904634863 + 
            0.006089614799637596*lm + 0.019989341706954846*lm^2)*NL + 
          (0.008538481358955022 + 0.006089614799637596*lm + 
            0.019989341706954846*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.05271823528145855 - 0.17207969729078101*lm - 
          0.10948074579345979*lm^2) + CF^2*(0.01029396429358634 + 
          0.08343385731245409*lm + 0.17915031129838874*lm^2) + 
        CF*((0.0545103053604995 + 0.005952830232895108*lm + 
            0.019905590144265416*lm^2)*NM + (0.0715543083386718 + 
            0.005952830232895108*lm + 0.019905590144265416*lm^2)*NL + 
          (0.008611271400474796 + 0.005952830232895108*lm + 
            0.019905590144265416*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.05226440779198825 - 0.1707333576843259*lm - 
          0.10901832886015908*lm^2) + CF^2*(0.010057062138097964 + 
          0.08206769257125365*lm + 0.1783936290438967*lm^2) + 
        CF*((0.0539856029635556 + 0.005815046784881949*lm + 
            0.019821514338210743*lm^2)*NM + (0.0712621154434623 + 
            0.005815046784881949*lm + 0.019821514338210743*lm^2)*NL + 
          (0.008684438438090249 + 0.005815046784881949*lm + 
            0.019821514338210743*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.051798457199833656 - 0.16937976680263797*lm - 
          0.10855427712235806*lm^2) + CF^2*(0.00982743467190509 + 
          0.08069262096798265*lm + 0.17763427165476775*lm^2) + 
        CF*((0.053461986281329955 + 0.0056763232250579285*lm + 
            0.019737141294974194*lm^2)*NM + (0.07096763884711209 + 
            0.0056763232250579285*lm + 0.019737141294974194*lm^2)*NL + 
          (0.008757965394690072 + 0.0056763232250579285*lm + 
            0.019737141294974194*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.05132097435455828 - 0.16801942706126763*lm - 
          0.10808873434036621*lm^2) + CF^2*(0.009604812329072288 + 
          0.07930920444289909*lm + 0.17687247437514472*lm^2) + 
        CF*((0.05293965203039828 + 0.005536717634856477*lm + 
            0.01965249715279386*lm^2)*NM + (0.07067104265850807 + 
            0.005536717634856477*lm + 0.01965249715279386*lm^2)*NL + 
          (0.008831835188105082 + 0.005536717634856477*lm + 
            0.01965249715279386*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.05083254340260892 - 0.1666528308799338*lm - 
          0.10762183962940164*lm^2) + CF^2*(0.009388944248119771 + 
          0.07791799698667715*lm + 0.17610846484811177*lm^2) + 
        CF*((0.05241878886207178 + 0.005396287353184279*lm + 
            0.01956760720534575*lm^2)*NM + (0.07037248660941096 + 
            0.005396287353184279*lm + 0.01956760720534575*lm^2)*NL + 
          (0.008906030750712746 + 0.005396287353184279*lm + 
            0.01956760720534575*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.05033374098538912 - 0.16528046057357948*lm - 
          0.10715372758543082*lm^2) + CF^2*(0.0091795972833183 + 
          0.07651954423437508*lm + 0.17534246332161407*lm^2) + 
        CF*((0.05189957752016538 + 0.005255088927493268*lm + 
            0.019482495924623786*lm^2)*NM + (0.07007212606448616 + 
            0.005255088927493268*lm + 0.019482495924623786*lm^2)*NL + 
          (0.008980535047909273 + 0.005255088927493268*lm + 
            0.019482495924623786*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.049825135525935545 - 0.16390278826853152*lm - 
          0.1066845284082491*lm^2) + CF^2*(0.008976555047807366 + 
          0.07511438310547679*lm + 0.17457468284986216*lm^2) + 
        CF*((0.05138219100394989 + 0.005113178070055528*lm + 
            0.019397186983318018*lm^2)*NM + (0.06977011204004921 + 
            0.005113178070055528*lm + 0.019397186983318018*lm^2)*NL + 
          (0.009055331095497653 + 0.005113178070055528*lm + 
            0.019397186983318018*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.0493072865975679 - 0.16252027584186773*lm - 
          0.10621436802181526*lm^2) + CF^2*(0.008779616989040173 + 
          0.07370304148687824*lm + 0.17380532949024316*lm^2) + 
        CF*((0.05086679473539406 + 0.00497060961909308*lm + 
            0.019311703276693685*lm^2)*NM + (0.06946659123065971 + 
            0.00497060961909308*lm + 0.019311703276693685*lm^2)*NL + 
          (0.00913040197602632 + 0.00497060961909308*lm + 
            0.019311703276693685*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.048780744368326544 - 0.16113337488221127*lm - 
          0.10574336819185852*lm^2) + CF^2*(0.008588597496846753 + 
          0.07228603795587452*lm + 0.1730346024957685*lm^2) + 
        CF*((0.050353546729841006 + 0.004827437504434789*lm + 
            0.019226066943974277*lm^2)*NM + (0.06916170604276377 + 
            0.004827437504434789*lm + 0.019226066943974277*lm^2)*NL + 
          (0.00920573085412922 + 0.004827437504434789*lm + 
            0.019226066943974277*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.0482460491154283 - 0.1597425266702846*lm - 
          0.10527164664078019*lm^2) + CF^2*(0.008403325044221753 + 
          0.07086388154037593*lm + 0.17226269450309487*lm^2) + 
        CF*((0.04984259776939442 + 0.004683714717391866*lm + 
            0.019140299389232764*lm^2)*NM + (0.06885559463464642 + 
            0.004683714717391866*lm + 0.019140299389232764*lm^2)*NL + 
          (0.009281300990902267 + 0.004683714717391866*lm + 
            0.019140299389232764*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.04770373080435864 - 0.158348162177658*lm - 
          0.1047993171598759*lm^2) + CF^2*(0.008223641360780475 + 
          0.0694370715137476*lm + 0.17148979171616055*lm^2) + 
        CF*((0.04933409157826807 + 0.004539493284561575*lm + 
            0.019054421301795618*lm^2)*NM + (0.06854839096201282 + 
            0.004539493284561575*lm + 0.019054421301795618*lm^2)*NL + 
          (0.009357095757358215 + 0.004539493284561575*lm + 
            0.019054421301795618*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.04715430872758319 - 0.1569507020822273*lm - 
          0.10432648971890734*lm^2) + CF^2*(0.008049400638687507 + 
          0.06800609722182063*lm + 0.17071607408548475*lm^2) + 
        CF*((0.04882816499952714 + 0.004394824245285909*lm + 
            0.01896845267616497*lm^2)*NM + (0.06824022482856988 + 
            0.004394824245285909*lm + 0.01896845267616497*lm^2)*NL + 
          (0.00943309864699786 + 0.004394824245285909*lm + 
            0.01896845267616497*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.04659829119820093 - 0.15555055679904786*lm - 
          0.10385327057305557*lm^2) + CF^2*(0.007880468770740709 + 
          0.06657143793977113*lm + 0.16994171548318185*lm^2) + 
        CF*((0.04832494817262102 + 0.004249757632508239*lm + 
            0.018882412831464652*lm^2)*NM + (0.06793122194102964 + 
            0.004249757632508239*lm + 0.018882412831464652*lm^2)*NL + 
          (0.009509293287537066 + 0.004249757632508239*lm + 
            0.018882412831464652*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.04603617529417982 - 0.15414812652523896*lm - 
          0.1033797623672899*lm^2) + CF^2*(0.007716722620188511 + 
          0.06513356275670103*lm + 0.16916688387374712*lm^2) + 
        CF*((0.047824564711204325 + 0.004104342456786278*lm + 
            0.018796320430416347*lm^2)*NM + (0.06762150396800104 + 
            0.004104342456786278*lm + 0.018796320430416347*lm^2)*NL + 
          (0.009585663451820079 + 0.004104342456786278*lm + 
            0.018796320430416347*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.04546844664911288 - 0.15274380129775555*lm - 
          0.10290606423818895*lm^2) + CF^2*(0.007558049321770391 + 
          0.06369293048588612*lm + 0.16839174148067282*lm^2) + 
        CF*((0.04732713188078443 + 0.003958626693234146*lm + 
            0.018710193497852537*lm^2)*NM + (0.06731118860227954 + 
            0.003958626693234146*lm + 0.018710193497852537*lm^2)*NL + 
          (0.009662193067964637 + 0.003958626693234146*lm + 
            0.018710193497852537*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.044895579285711244 - 0.15133796106290182*lm - 
          0.10243227191325185*lm^2) + CF^2*(0.007404345613394933 + 
          0.06224998959878019*lm + 0.16761644494895758*lm^2) + 
        CF*((0.04683276077577937 + 0.0038126572711800664*lm + 
            0.018624049438773063*lm^2)*NM + (0.06700038962608348 + 
            0.0038126572711800664*lm + 0.018624049438773063*lm^2)*NL + 
          (0.009738866228762223 + 0.0038126572711800664*lm + 
            0.018624049438773063*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.04431803548851065 - 0.1499309757565335*lm - 
          0.10195847780773962*lm^2) + CF^2*(0.007255517197807426 + 
          0.060805178180980614*lm + 0.16684114550357393*lm^2) + 
        CF*((0.04634155649561088 + 0.0036664800663390694*lm + 
            0.01853790505595266*lm^2)*NM + (0.06668921697882266 + 
            0.0036664800663390694*lm + 0.01853790505595266*lm^2)*NL + 
          (0.009815667200374651 + 0.0036664800663390694*lm + 
            0.01853790505595266*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.04373626571251114 - 0.1485232053939652*lm - 
          0.10148477111908724*lm^2) + CF^2*(0.00711147813354668 + 
          0.05935892390847114*lm + 0.16606598910396095*lm^2) + 
        CF*((0.04585361831950066 + 0.003520139895312331*lm + 
            0.01845177656710677*lm^2)*NM + (0.06637777682701836 + 
            0.003520139895312331*lm + 0.01845177656710677*lm^2)*NL + 
          (0.009892580430354203 + 0.003520139895312331*lm + 
            0.01845177656710677*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.043150707491984304 - 0.14711500017211113*lm - 
          0.10101123786379157*lm^2) + CF*(0.00697215478232787 + 
          0.05791164414799708*lm + 0.16529111650438622*lm^2) + 
        0.04536903948970809*NM + 0.0033736805256221526*lm*NM + 
        0.01836567961159847*lm^2*NM + 0.06606617137715808*NL + 
        0.0033736805256221526*lm*NL + 0.01836567961159847*lm^2*NL + 
        0.00996959054032332*NH + 0.0033736805256221526*lm*NH + 
        0.01836567961159847*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.042561789750638526 - 0.1457067005608818*lm - 
          0.10053796119887214*lm^2) + CF*(0.006837466222987251 + 
          0.0564637455248066*lm + 0.1645166637799726*lm^2) + 
        0.04488790902157984*NM + 0.003227144617941981*lm*NM + 
        0.018279629308885843*lm^2*NM + 0.06575450003672871*NL + 
        0.003227144617941981*lm*NL + 0.018279629308885843*lm^2*NL + 
        0.010046682394512757*NH + 0.003227144617941981*lm*NH + 
        0.018279629308885843*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.04196992594072313 - 0.14429863744236*lm - 
          0.10006502114252772*lm^2) + CF*(0.006707353839785817 + 
          0.05501562465598103*lm + 0.1637427618695908*lm^2) + 
        0.04441030928107806*NM + 0.0030805738160425075*lm*NM + 
        0.01819364020773231*lm^2*NM + 0.06544285776811629*NL + 
        0.0030805738160425075*lm*NL + 0.01819364020773231*lm^2*NL + 
        0.010123841008209775*NH + 0.0030805738160425075*lm*NH + 
        0.01819364020773231*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.04137551890919996 - 0.14289113221182562*lm - 
          0.09959249491834062*lm^2) + CF*(0.006581759548740596 + 
          0.05356766769276758*lm + 0.1629695371391028*lm^2) + 
        0.04393631798180704*NM + 0.0029340086855093087*lm*NM + 
        0.018107726348789203*lm^2*NM + 0.06513133637882967*NL + 
        0.0029340086855093087*lm*NL + 0.018107726348789203*lm^2*NL + 
        0.0102010516224121*NH + 0.0029340086855093087*lm*NH + 
        0.018107726348789203*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.040778959654642344 - 0.1414844969090375*lm - 
          0.0991204569691156*lm^2) + CF*(0.006460630995075786 + 
          0.05212025051035629*lm + 0.16219711140400733*lm^2) + 
        0.04346600786186714*NM + 0.002787488734409822*lm*NM + 
        0.018021901267111926*lm^2*NM + 0.06482002427378117*NL + 
        0.002787488734409822*lm*NL + 0.018021901267111926*lm^2*NL + 
        0.010278299690516073*NH + 0.002787488734409822*lm*NH + 
        0.018021901267111926*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.040180627394566314 - 0.14007903434906563*lm - 
          0.0986489790376396*lm^2) + CF*(0.006343921102298105 + 
          0.05067373877580102*lm + 0.16142560206159207*lm^2) + 
        0.04299944684578431*NM + 0.0026410524183928526*lm*NM + 
        0.01793617800684356*lm^2*NM + 0.06450900653179993*NL + 
        0.0026410524183928526*lm*NL + 0.01793617800684356*lm^2*NL + 
        0.010355570882905745*NH + 0.0026410524183928526*lm*NH + 
        0.01793617800684356*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.03958088965129421 - 0.1386750382575529*lm - 
          0.09817813024531706*lm^2) + CF*(0.0062315876450865886 + 
          0.04922848802703337*lm + 0.16065512221960976*lm^2) + 
        0.042536698203655375*NM + 0.0024947371470850086*lm*NM + 
        0.017850569135512195*lm^2*NM + 0.06419836498238883*NL + 
        0.0024947371470850086*lm*NL + 0.017850569135512195*lm^2*NL + 
        0.01043285109106169*NH + 0.0024947371470850086*lm*NH + 
        0.017850569135512195*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.038980102354529256 - 0.13727279340984389*lm - 
          0.09770797716872646*lm^2) + CF*(0.006123592845122678 + 
          0.047784843761966865*lm + 0.15988578082155241*lm^2) + 
        0.042077820707396685*NM + 0.002348579291671274*lm*NM + 
        0.017765086757950268*lm^2*NM + 0.06388817828254198*NL + 
        0.002348579291671274*lm*NL + 0.017765086757950268*lm^2*NL + 
        0.010510126431213523*NH + 0.002348579291671274*lm*NH + 
        0.017765086757950268*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.03837860995895093 - 0.13587257577345674*lm - 
          0.09723858391414279*lm^2) + CF*(0.006019902988995374 + 
          0.046343141536753424*lm + 0.1591176827685973*lm^2) + 
        0.041622868784001336*NM + 0.002202614193554134*lm*NM + 
        0.017679742529844146*lm^2*NM + 0.06357852199345773*NL + 
        0.002202614193554134*lm*NL + 0.017679742529844146*lm^2*NL + 
        0.010587383247559274*NH + 0.002202614193554134*lm*NH + 
        0.017679742529844146*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.037776745575263705 - 0.13447465265341296*lm - 
          0.09677001219007121*lm^2) + CF*(0.005920488067327634 + 
          0.04490370707231548*lm + 0.15835092903829834*lm^2) + 
        0.04117189266572652*NM + 0.0020568761739924914*lm*NM + 
        0.01759454767092204*lm^2*NM + 0.06326946865699697*NL + 
        0.0020568761739924914*lm*NL + 0.01759454767092204*lm^2*NL + 
        0.010664608115073798*NH + 0.0020568761739924914*lm*NH + 
        0.01759454767092204*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.037174831113246404 - 0.1330792828399729*lm - 
          0.09630232137783633*lm^2) + CF*(0.005825321434283519 + 
          0.04346685636833452*lm + 0.1575856168000958*lm^2) + 
        0.040724938537147246*NM + 0.0019113985446279872*lm*NM + 
        0.01750951297778842*lm^2*NM + 0.06296108787175135*NL + 
        0.0019113985446279872*lm*NL + 0.01750951297778842*lm^2*NL + 
        0.01074178784192758*NH + 0.0019113985446279872*lm*NH + 
        0.01750951297778842*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.036573177435456315 - 0.1316867167583591*lm - 
          0.09583556860027141*lm^2) + CF*(0.005734379486630754 + 
          0.04203289582393109*lm + 0.15682183952771686*lm^2) + 
        0.04028204867902636*NM + 0.0017662136188124015*lm*NM + 
        0.017424648836412985*lm^2*NM + 0.06265344636859968*NL + 
        0.0017662136188124015*lm*NL + 0.017424648836412985*lm^2*NL + 
        0.0108189094715364*NH + 0.0017662136188124015*lm*NH + 
        0.017424648836412985*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.03597208452034244 - 0.13029719662007952*lm - 
          0.0953698087885514*lm^2) + CF*(0.005647641361549932 + 
          0.04060212236432222*lm + 0.15605968710853865*lm^2) + 
        0.039843261608962746*NM + 0.0016213527236554571*lm*NM + 
        0.017339965234282072*lm^2*NM + 0.062346608085642546*NL + 
        0.0016213527236554571*lm*NL + 0.017339965234282072*lm^2*NL + 
        0.010895960284261517*NH + 0.0016213527236554571*lm*NH + 
        0.017339965234282072*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.03537184163361532 - 0.12891095657549123*lm - 
          0.09490509474721298*lm^2) + CF*(0.005565088652399445 + 
          0.03917482357279025*lm + 0.15529924594998487*lm^2) + 
        0.03940861221879123*NM + 0.0014768462127177156*lm*NM + 
        0.017255471772220542*lm^2*NM + 0.062040634242417354*NL + 
        0.0014768462127177156*lm*NL + 0.017255471772220542*lm^2*NL + 
        0.010972927798779241*NH + 0.0014768462127177156*lm*NH + 
        0.017255471772220542*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.03477272750680846 - 0.1275282228672729*lm - 
          0.09444147721740476*lm^2) + CF*(0.005486705141664062 + 
          0.03775127782734207*lm + 0.15454059908302598*lm^2) + 
        0.038978131908717385*NM + 0.0013327234792782677*lm*NM + 
        0.017171177675891772*lm^2*NM + 0.06173558341330613*NL + 
        0.0013327234792782677*lm*NL + 0.017171177675891772*lm^2*NL + 
        0.01104979977313798*NH + 0.0013327234792782677*lm*NH + 
        0.017171177675891772*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.034175010522047154 - 0.1261492139844993*lm - 
          0.09397900493840977*lm^2) + CF*(0.005412476550334717 + 
          0.036331754441480346*lm + 0.15378382626285234*lm^2) + 
        0.03855184871817996*NM + 0.0011890129701116617*lm*NM + 
        0.017087091806983593*lm^2*NM + 0.06143151160005836*NL + 
        0.0011890129701116617*lm*NL + 0.017087091806983593*lm^2*NL + 
        0.011126564205520061*NH + 0.0011890129701116617*lm*NH + 
        0.017087091806983593*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.033578948902117045 - 0.12477414081703476*lm - 
          0.09351772470748203*lm^2) + CF*(0.005342390302987432 + 
          0.03491651380854809*lm + 0.15302900406678877*lm^2) + 
        0.038129787453441845*NM + 0.001045742199712959*lm*NM + 
        0.017003222674087642*lm^2*NM + 0.06112847230336021*NL + 
        0.001045742199712959*lm*NL + 0.017003222674087642*lm^2*NL + 
        0.011203209334725003*NH + 0.001045742199712959*lm*NH + 
        0.017003222674087642*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.032984790904994996 - 0.12340320680998483*lm - 
          0.09305768143803832*lm^2) + CF*(0.005276435307850058 + 
          0.033505807549145485*lm + 0.15227620598951724*lm^2) + 
        0.03771196981191787*NM + 0.0009029377649139938*lm*NM + 
        0.016919578443279695*lm^2*NM + 0.06082651659338975*NL + 
        0.0009029377649139938*lm*NL + 0.016919578443279695*lm^2*NL + 
        0.011279723640390074*NH + 0.0009029377649139938*lm*NH + 
        0.016919578443279695*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.03239277502207134 - 0.12203660811796638*lm - 
          0.0925989182162457*lm^2) + CF*(0.005214601751166708 + 
          0.03209987866115315*lm + 0.1515255025356748*lm^2) + 
        0.03729841450325472*NM + 0.0007606253598378543*lm*NM + 
        0.01683616694840831*lm^2*NM + 0.060525693179305354*NL + 
        0.0007606253598378543*lm*NL + 0.01683616694840831*lm^2*NL + 
        0.011356095842963428*NH + 0.0007606253598378543*lm*NH + 
        0.01683616694840831*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.031803130179353906 - 0.12067453375897572*lm - 
          0.09214147635604457*lm^2) + CF*(0.005156880905191106 + 
          0.030698961671929186*lm + 0.1507769613098911*lm^2) + 
        0.03688913736718404*NM + 0.0006188297911422967*lm*NM + 
        0.016752995701099012*lm^2*NM + 0.06022604847762179*NL + 
        0.0006188297911422967*lm*NL + 0.016752995701099012*lm^2*NL + 
        0.011432314903444351*NH + 0.0006188297911422967*lm*NH + 
        0.016752995701099012*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.031216075941001557 - 0.11931716576765262*lm - 
          0.0916853954526463*lm^2) + CF*(0.005103264949161606 + 
          0.029303282792278354*lm + 0.1500306471043303*lm^2) + 
        0.03648415148817538*NM + 0.00047757499350629284*lm*NM + 
        0.016670071900481146*lm^2*NM + 0.05992762667943465*NL + 
        0.00047757499350629284*lm*NL + 0.016670071900481146*lm^2*NL + 
        0.011508370022904606*NH + 0.00047757499350629284*lm*NH + 
        0.016670071900481146*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.030631822714588915 - 0.11796467934775538*lm - 
          0.09123071343454431*lm^2) + CF*(0.005053746802632133 + 
          0.027913060071821177*lm + 0.14928662198379977*lm^2) + 
        0.036083467306920386*NM + 0.000336884045317172*lm*NM + 
        0.01658740244264442*lm^2*NM + 0.05963046981646017*NL + 
        0.000336884045317172*lm*NL + 0.01658740244264442*lm^2*NL + 
        0.011584250641804171*NH + 0.000336884045317172*lm*NH + 
        0.01658740244264442*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.030050571957553073 - 0.11661724302367765*lm - 
          0.09077746661407578*lm^2) + CF*(0.00500831997055475 + 
          0.02652850355541802*lm + 0.14854494536848764*lm^2) + 
        0.03568709272868391*NM + 0.00019677918451889786*lm*NM + 
        0.01650499392983196*lm^2*NM + 0.059334617825862364*NL + 
        0.00019677918451889786*lm*NL + 0.01650499392983196*lm^2*NL + 
        0.01165994643911415*NH + 0.00019677918451889786*lm*NH + 
        0.01650499392983196*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.029472516384320215 - 0.1152750187908535*lm - 
          0.09032568973657157*lm^2) + CF*(0.004966978399530866 + 
          0.025149815440329085*lm + 0.14780567411438983*lm^2) + 
        0.03529503322856154*NM + 0.00005728182458490142*lm*NM + 
        0.016422852679376647*lm^2*NM + 0.05904010861384514*NL + 
        0.00005728182458490142*lm*NL + 0.016422852679376647*lm^2*NL + 
        0.011735447331259027*NH + 0.00005728182458490142*lm*NH + 
        0.016422852679376647*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.028897840173652798 - 0.11393816226491014*lm - 
          0.08987541602813032*lm^2) + CF*(0.0049297163446691975 + 
          0.023777190233815443*lm + 0.147068862591486*lm^2) + 
        0.0349072919536863*NM - 0.00008158742941839483*lm*NM + 
        0.01634098473238733*lm^2*NM + 0.05874697811799105*NL - 
        0.00008158742941839483*lm*NL + 0.01634098473238733*lm^2*NL + 
        0.011810743470889893*NH - 0.00008158742941839483*lm*NH + 
        0.01634098473238733*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.028326719175798355 - 0.11260682282944194*lm - 
          0.08942667724205262*lm^2) + CF*(0.004896528246509426 + 
          0.022410814910908915*lm + 0.14633456275972248*lm^2) + 
        0.03452386982243019*NM - 0.0002198087647086849*lm*NM + 
        0.016259395862191387*lm^2*NM + 0.05845526036833284*NL - 
        0.0002198087647086849*lm*NL + 0.016259395862191387*lm^2*NL + 
        0.011885825245499776*NH - 0.0002198087647086849*lm*NH + 
        0.016259395862191387*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.027759321119058395 - 0.1112811437822903*lm - 
          0.08897950370396984*lm^2) + CF*(0.004867408617491015 + 
          0.02105086907209988*lm + 0.14560282424285975*lm^2) + 
        0.03414476562064888*NM - 0.00035736314463445293*lm*NM + 
        0.01617809158253997*lm^2*NM + 0.058164987547147794*NL - 
        0.00035736314463445293*lm*NL + 0.01617809158253997*lm^2*NL + 
        0.011960683275891653*NH - 0.00035736314463445293*lm*NH + 
        0.01617809158253997*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.027195805815430584 - 0.10996126248022686*lm - 
          0.08853392435570205*lm^2) + CF*(0.004842351937466798 + 
          0.019697525100712134*lm + 0.14487369440023973*lm^2) + 
        0.03376997609501967*NM - 0.0004942322925179059*lm*NM + 
        0.01609707715558219*lm^2*NM + 0.05787619004746835*NL - 
        0.0004942322925179059*lm*NL + 0.01609707715558219*lm^2*NL + 
        0.012035308414509284*NH - 0.0004942322925179059*lm*NH + 
        0.01609707715558219*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.02663632536500984 - 0.1086473104819465*lm - 
          0.0880899667978783*lm^2) + CF*(0.004821352557780733 + 
          0.01835094831975255*lm + 0.1441472183965281*lm^2) + 
        0.03339949604352519*NM - 0.000630398675518756*lm*NM + 
        0.016016357599614235*lm^2*NM + 0.05758889653030549*NL - 
        0.000630398675518756*lm*NL + 0.016016357599614235*lm^2*NL + 
        0.0121096917436405*NH - 0.000630398675518756*lm*NH + 
        0.016016357599614235*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.026081024358863898 - 0.10733941368928801*lm - 
          0.08764765733135195*lm^2) + CF*(0.004804404613448553 + 
          0.0170112971480409*lm + 0.143423439269485*lm^2) + 
        0.03303331840313634*NM - 0.0007658454885414741*lm*NM + 
        0.015935937696609444*lm^2*NM + 0.05730313398058464*NL - 
        0.0007658454885414741*lm*NL + 0.015935937696609444*lm^2*NL + 
        0.012183824573502153*NH - 0.0007658454885414741*lm*NH + 
        0.015935937696609444*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.025530040080126944 - 0.10603769248660853*lm - 
          0.08720702099744317*lm^2) + CF*(0.004791501942998928 + 
          0.01567872325544162*lm + 0.14270239799581608*lm^2) + 
        0.032671434334749554*NM - 0.0009005566382067846*lm*NM + 
        0.01585582199953512*lm^2*NM + 0.0570189277617962*NL - 
        0.0009005566382067846*lm*NL + 0.01585582199953512*lm^2*NL + 
        0.012257698440215476*NH - 0.0009005566382067846*lm*NH + 
        0.01585582199953512*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.02498350270308073 - 0.1047422618782469*lm - 
          0.08676808161703968*lm^2) + CF*(0.004782638015551205 + 
          0.014353371717034658*lm + 0.14198413355515585*lm^2) + 
        0.03231383330543434*NM - 0.0010345167269064427*lm*NM + 
        0.015776014839461762*lm^2*NM + 0.056736301669365226*NL - 
        0.0010345167269064427*lm*NL + 0.015776014839461762*lm^2*NL + 
        0.012331305103680227*NH - 0.0010345167269064427*lm*NH + 
        0.015776014839461762*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.024441535490016642 - 0.103453231624019*lm - 
          0.08633086182858651*lm^2) + CF*(0.004777805864723709 + 
          0.013035381166076991*lm + 0.14126868299223247*lm^2) + 
        0.03196050316804795*NM - 0.0011677110369587133*lm*NM + 
        0.015696520332470276*lm^2*NM + 0.05645527798274713*NL - 
        0.0011677110369587133*lm*NL + 0.015696520332470276*lm^2*NL + 
        0.012404636545355533*NH - 0.0011677110369587133*lm*NH + 
        0.015696520332470276*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.023904254985694505 - 0.10217070637269574*lm - 
          0.0858953831249943*lm^2) + CF*(0.004776998028984071 + 
          0.011724883945619852*lm + 0.1405560814772634*lm^2) + 
        0.031611430238274535*NM - 0.00130012551488045*lm*NM + 
        0.015617342386362601*lm^2*NM + 0.056175877516257945*NL - 
        0.00130012551488045*lm*NL + 0.015617342386362601*lm^2*NL + 
        0.012477684965955025*NH - 0.00130012551488045*lm*NH + 
        0.015617342386362601*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.02337177120923451 - 0.1008947857934209*lm - 
          0.0854616658894957*lm^2) + CF*(0.004780206498069952 + 
          0.01042200625865932*lm + 0.13984636236462933*lm^2) + 
        0.031266599369146435*NM - 0.0014317467557902483*lm*NM + 
        0.015538484707181038*lm^2*NM + 0.05589811966864966*NL - 
        0.0014317467557902483*lm*NL + 0.015538484707181038*lm^2*NL + 
        0.012550442783063434*NH - 0.0014317467557902483*lm*NH + 
        0.015538484707181038*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.022844187843297857 - 0.09962556470503309*lm - 
          0.08502972943047797*lm^2) + CF*(0.004787422665125006 + 
          0.00912686831670973*lm + 0.13913955724987304*lm^2) + 
        0.03092599402310586*NM - 0.0015625619879558272*lm*NM + 
        0.01545995080554145*lm^2*NM + 0.05562202247144261*NL - 
        0.0015625619879558272*lm*NL + 0.01545995080554145*lm^2*NL + 
        0.012622902628681501*NH - 0.0015625619879558272*lm*NH + 
        0.01545995080554145*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.022321602420429305 - 0.0983631332032614*lm - 
          0.08459959201531972*lm^2) + CF*(0.004798637284210817 + 
          0.00783958448670032*lm + 0.13843569602506864*lm^2) + 
        0.030589596341664815*NM - 0.0016925590574975314*lm*NM + 
        0.015381744002785403*lm^2*NM + 0.05534760263602825*NL - 
        0.0016925590574975314*lm*NL + 0.015381744002785403*lm^2*NL + 
        0.012695057346705707*NH - 0.0016925590574975314*lm*NH + 
        0.015381744002785403*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.021804106506451287 - 0.09710757678577032*lm - 
          0.08417127090325893*lm^2) + CF*(0.004813840432870985 + 
          0.006560263436105929*lm + 0.13773480693260554*lm^2) + 
        0.030257387212721386*NM - 0.0018217264132587027*lm*NM + 
        0.01530386743695617*lm^2*NM + 0.05507487559955699*NL - 
        0.0018217264132587027*lm*NL + 0.01530386743695617*lm^2*NL + 
        0.012766899990348971*NH - 0.0018217264132587027*lm*NH + 
        0.01530386743695617*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.02129178588081432 - 0.09585897647503455*lm - 
          0.0837447823773186*lm^2) + CF*(0.004833021479438386 + 
          0.005289008276231987*lm + 0.13703691661743042*lm^2) + 
        0.029929346335590214*NM - 0.0019500530918525648*lm*NM + 
        0.015226324068603381*lm^2*NM + 0.05480385556962682*NL - 
        0.0019500530918525648*lm*NL + 0.015226324068603381*lm^2*NL + 
        0.012838423819508216*NH - 0.0019500530918525648*lm*NH + 
        0.015226324068603381*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.020784720713822445 - 0.09461740893902891*lm - 
          0.08332014177531578*lm^2) + CF*(0.004856169054791066 + 
          0.004025916703583196*lm + 0.13634205017778947*lm^2) + 
        0.02960545228380468*NM - 0.002077528702894265*lm*NM + 
        0.015149116686421053*lm^2*NM + 0.05453455556778932*NL - 
        0.002077528702894265*lm*NL + 0.015149116686421053*lm^2*NL + 
        0.01290962229808433*NH - 0.002077528702894265*lm*NH + 
        0.015149116686421053*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.020282985740665244 - 0.09338294660972304*lm - 
          0.08289736351997941*lm^2) + CF*(0.004883271028276092 + 
          0.0027710811392534862*lm + 0.13565023121451178*lm^2) + 
        0.029285682565747904*NM - 0.0022041434144257563*lm*NM + 
        0.015072247912723529*lm^2*NM + 0.05426698747189063*NL - 
        0.0022041434144257563*lm*NL + 0.015072247912723529*lm^2*NL + 
        0.012980489091259808*NH - 0.0022041434144257563*lm*NH + 
        0.015072247912723529*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.019786650432200004 - 0.09215565779937492*lm - 
          0.08247646114820102*lm^2) + CF*(0.004914314487534046 + 
          0.0015245888662827175*lm + 0.1349614818788744*lm^2) + 
        0.02897001368316925*NM - 0.002329887938540335*lm*NM + 
        0.014995720208763823*lm^2*NM + 0.05400116205726574*NL - 
        0.002329887938540335*lm*NL + 0.014995720208763823*lm^2*NL + 
        0.013051018062739093*NH - 0.002329887938540335*lm*NH + 
        0.014995720208763823*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.019295779162438343 - 0.09093560681462029*lm - 
          0.08205744733944269*lm^2) + CF*(0.004949285721969789 + 
          0.0002865221649327867*lm + 0.13427582291908804*lm^2) + 
        0.028658421187642367*NM - 0.002454753517212802*lm*NM + 
        0.01491953587989867*lm^2*NM + 0.0537370890368047*NL - 
        0.002454753517212802*lm*NL + 0.01491953587989867*lm^2*NL + 
        0.013121203271956322*NH - 0.002454753517212802*lm*NH + 
        0.01491953587989867*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.018810431372701854 - 0.08972285406835942*lm - 
          0.08164033394332518*lm^2) + CF*(0.004988170209627486 - 
          0.0009430415541574281*lm + 0.13359327372544122*lm^2) + 
        0.028350879735020183*NM - 0.0025787319083404774*lm*NM + 
        0.01484369708060458*lm^2*NM + 0.05347477709991049*NL - 
        0.0025787319083404774*lm*NL + 0.01484369708060458*lm^2*NL + 
        0.013191038971254988*NH - 0.0025787319083404774*lm*NH + 
        0.01484369708060458*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.0183306617324204 - 0.08851745618944502*lm - 
          0.08122513200641918*lm^2) + CF*(0.005030952607239854 - 
          0.002164029618972598*lm + 0.13291385237414047*lm^2) + 
        0.028047363137941622*NM - 0.0027018153719995564*lm*NM + 
        0.01476820581934894*lm^2*NM + 0.053214233950368096*NL - 
        0.0027018153719995564*lm*NL + 0.01476820581934894*lm^2*NL + 
        0.013260519603043749*NH - 0.0027018153719995564*lm*NH + 
        0.01476820581934894*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.017856520296555305 - 0.0873194661301784*lm - 
          0.08081185179826154*lm^2) + CF*(0.005077616743233055 - 
          0.0033763739673054335*lm + 0.13223757566988253*lm^2) + 
        0.02774784441644397*NM - 0.0028239966569206507*lm*NM + 
        0.01469306396332028*lm^2*NM + 0.05295546634314524*NL - 
        0.0028239966569206507*lm*NL + 0.01469306396332028*lm^2*NL + 
        0.013329639796932382*NH - 0.0028239966569206507*lm*NH + 
        0.01469306396332028*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.017388052659637332 - 0.08612893327162374*lm - 
          0.08040050283661843*lm^2) + CF*(0.005128145613479672 - 
          0.004580011020148216*lm + 0.13156445918719378*lm^2) + 
        0.02745229584673405*NM - 0.002945268987186724*lm*NM + 
        0.014618273243021531*lm^2*NM + 0.05269848012014512*NL - 
        0.002945268987186724*lm*NL + 0.014618273243021531*lm^2*NL + 
        0.013398394366851711*NH - 0.002945268987186724*lm*NH + 
        0.014618273243021531*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.01692530010641654 - 0.08494590352675259*lm - 
          0.07999109391201578*lm^2) + CF*(0.005182521379602809 - 
          0.005774881557309435*lm + 0.13089451731057128*lm^2) + 
        0.02716068900817051*NM - 0.0030656260491560717*lm*NM + 
        0.014543835256730142*lm^2*NM + 0.0524432802449319*NL - 
        0.0030656260491560717*lm*NL + 0.014543835256730142*lm^2*NL + 
        0.01346677830816106*NH - 0.0030656260491560717*lm*NH + 
        0.014543835256730142*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.016468299759127503 - 0.08377041944143276*lm - 
          0.07958363311155814*lm^2) + CF*(0.005240725369644474 - 
          0.006960930595268957*lm + 0.13022776327345875*lm^2) + 
        0.026872994828508696*NM - 0.003185061978612454*lm*NM + 
        0.014469751474828752*lm^2*NM + 0.05218987083644996*NL - 
        0.003185061978612454*lm*NL + 0.014469751474828752*lm^2*NL + 
        0.013534786794746591*NH - 0.003185061978612454*lm*NH + 
        0.014469751474828752*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.016017084721379374 - 0.08260252029327836*lm - 
          0.07917812784205523*lm^2) + CF*(0.0053027380809211625 - 
          0.008138107267280852*lm + 0.12956420919609038*lm^2) + 
        0.02658918362745852*NM - 0.0033035713481439906*lm*NM + 
        0.014396023244010044*lm^2*NM + 0.05193825520175765*NL - 
        0.0033035713481439906*lm*NL + 0.014396023244010044*lm^2*NL + 
        0.013602415176113776*NH - 0.0033035713481439906*lm*NH + 
        0.014396023244010044*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.01557168421868556 - 0.081442242188379*lm - 
          0.07877458485247604*lm^2) + CF*(0.005368539184898858 - 
          0.009306364705729023*lm + 0.12890386612223353*lm^2) + 
        0.026309225158604996*NM - 0.003421149154751994*lm*NM + 
        0.014322651791359282*lm^2*NM + 0.0516884358677969*NL - 
        0.003421149154751994*lm*NL + 0.014322651791359282*lm^2*NL + 
        0.013669658974476934*NH - 0.003421149154751994*lm*NH + 
        0.014322651791359282*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.015132123735652741 - 0.08028961815592835*lm - 
          0.07837301025574889*lm^2) + CF*(0.005438107533928611 - 
          0.01046565992673714*lm + 0.1282467440548618*lm^2) + 
        0.026033088649739963*NM - 0.0035377908076904565*lm*NM + 
        0.01424963822831798*lm^2*NM + 0.05144041461221945*NL - 
        0.0035377908076904565*lm*NL + 0.01424963822831798*lm^2*NL + 
        0.013736513881848692*NH - 0.0035377908076904565*lm*NH + 
        0.01424963822831798*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.014698425149853327 - 0.07914467824077308*lm - 
          0.07797340954992611*lm^2) + CF*(0.005511421169692395 - 
          0.01161595371703097*lm + 0.12759285199078818*lm^2) + 
        0.02576074284165271*NM - 0.0036534921165365555*lm*NM + 
        0.01417698355453202*lm^2*NM + 0.05119419249329089*NL - 
        0.0036534921165365555*lm*NL + 0.01417698355453202*lm^2*NL + 
        0.01380297575713202*NH - 0.0036534921165365555*lm*NH + 
        0.01417698355453202*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.014270606862409435 - 0.07800744959390556*lm - 
          0.07757578763873114*lm^2) + CF*(0.005588457333217113 - 
          0.012757210523048096*lm + 0.12694219795428732*lm^2) + 
        0.025492156025426062*NM - 0.003768249279492146*lm*NM + 
        0.01410468866158748*lm^2*NM + 0.05094976987889337*NL - 
        0.003768249279492146*lm*NL + 0.01410468866158748*lm^2*NL + 
        0.013869040623217347*NH - 0.003768249279492146*lm*NH + 
        0.01410468866158748*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.013848683925320097 - 0.07687795656092376*lm - 
          0.07718014885150527*lm^2) + CF*(0.00566919247632243 - 
          0.01388939834228717*lm + 0.1262947890297359*lm^2) + 
        0.02522729607828362*NM - 0.0038820588719159057*lm*NM + 
        0.014032754336637322*lm^2*NM + 0.050707146474647906*NL - 
        0.0038820588719159057*lm*NL + 0.014032754336637322*lm^2*NL + 
        0.013934704664087054*NH - 0.0038820588719159057*lm*NH + 
        0.014032754336637322*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.013432668165566581 - 0.07575622076848401*lm - 
          0.07678649696257106*lm^2) + CF*(0.005753602274375604 - 
          0.015012488616886185*lm + 0.1256506313932981*lm^2) + 
        0.024966130498032788*NM - 0.0039949178350854675*lm*NM + 
        0.013961181265922011*lm^2*NM + 0.05046632135117687*NL - 
        0.0039949178350854675*lm*NL + 0.013961181265922011*lm^2*NL + 
        0.013999964221929612*NH - 0.0039949178350854675*lm*NH + 
        0.013961181265922011*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.01302256830603362 - 0.07464226120877217*lm - 
          0.07639483521002892*lm^2) + CF*(0.005841661640233586 - 
          0.0161264561294169*lm + 0.12500973034368368*lm^2) + 
        0.02470862643614719*NM - 0.004106823465188613*lm*NM + 
        0.013889970038187077*lm^2*NM + 0.05022729297052719*NL - 
        0.004106823465188613*lm*NL + 0.013889970038187077*lm^2*NL + 
        0.014064815794265353*NH - 0.004106823465188613*lm*NH + 
        0.013889970038187077*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.012618390083286876 - 0.07353609432202053*lm - 
          0.07600516631400264*lm^2) + CF*(0.005933344739259499 - 
          0.017231278900880286*lm + 0.12437209033200433*lm^2) + 
        0.024454750729531106*NM - 0.004217773402542335*lm*NM + 
        0.013819121148000482*lm^2*NM + 0.04999005921177479*NL - 
        0.004217773402542335*lm*NL + 0.013819121148000482*lm^2*NL + 
        0.014129256031085825*NH - 0.004217773402542335*lm*NH + 
        0.013819121148000482*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.012220136362249247 - 0.072437734077098*lm - 
          0.07561749249434978*lm^2) + CF*(0.006028625005307061 - 
          0.018326938090885918*lm + 0.12373771499075417*lm^2) + 
        0.02420446993100757*NM - 0.0043277656210383274*lm*NM + 
        0.013748634998972687*lm^2*NM + 0.049754617395830064*NL - 
        0.0043277656210383274*lm*NL + 0.013748634998972687*lm^2*NL + 
        0.014193281732008543*NH - 0.0043277656210383274*lm*NH + 
        0.013748634998972687*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.01182780724782059 - 0.0713471920502017*lm - 
          0.07523181548785161*lm^2) + CF*(0.006127475157572769 - 
          0.01941341789999641*lm + 0.123106607161939*lm^2) + 
        0.023957750338570658*NM - 0.004436798417813286*lm*NM + 
        0.01367851190688211*lm^2*NM + 0.04952096430946463*NL - 
        0.004436798417813286*lm*NL + 0.01367851190688211*lm^2*NL + 
        0.014256889843448766*NH - 0.004436798417813286*lm*NH + 
        0.01367851190688211*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.011441400193487198 - 0.07026447750167905*lm - 
          0.07484813656489783*lm^2) + CF*(0.006229867218221526 - 
          0.020490705474216293*lm + 0.12247876892437826*lm^2) + 
        0.023714558023441683*NM - 0.0045448704031421485*lm*NM + 
        0.013608752102708696*lm^2*NM + 0.04928909622857869*NL - 
        0.0045448704031421485*lm*NL + 0.013608752102708696*lm^2*NL + 
        0.01432007745580991*NH - 0.0045448704031421485*lm*NH + 
        0.013608752102708696*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.01106091010696885 - 0.06918959745100964*lm - 
          0.07446645654567993*lm^2) + CF*(0.006335772530697021 - 
          0.02155879081160328*lm + 0.12185420162020352*lm^2) + 
        0.023474858856967786*NM - 0.004651980490552281*lm*NM + 
        0.013539355735578169*lm^2*NM + 0.04905900894072859*NL - 
        0.004651980490552281*lm*NL + 0.013539355735578169*lm^2*NL + 
        0.014382841800694008*NH - 0.004651980490552281*lm*NH + 
        0.013539355735578169*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.010686329452952547 - 0.06812255674997639*lm - 
          0.07408677581590742*lm^2) + CF*(0.006445161778633569 - 
          0.02261766667097853*lm + 0.12123290588057578*lm^2) + 
        0.023238618536400676*NM - 0.004758127887156426*lm*NM + 
        0.013470322875619532*lm^2*NM + 0.04883069776693354*NL - 
        0.004758127887156426*lm*NL + 0.013470322875619532*lm^2*NL + 
        0.014445180248133583*NH - 0.004758127887156426*lm*NH + 
        0.013470322875619532*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.010317648352963112 - 0.06706335815405631*lm - 
          0.07370909434206034*lm^2) + CF*(0.006558005005291179 - 
          0.023667328482711286*lm + 0.1206148816506442*lm^2) + 
        0.023005802609592087*NM - 0.004863312084202072*lm*NM + 
        0.013401653516738244*lm^2*NM + 0.04860415758278031*NL - 
        0.004863312084202072*lm*NL + 0.013401653516738244*lm^2*NL + 
        0.014507090303846162*NH - 0.004863312084202072*lm*NH + 
        0.013401653516738244*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.009954854682421802 - 0.06601200239206093*lm - 
          0.07333341168619122*lm^2) + CF*(0.006674271633440504 - 
          0.02470777426155217*lm + 0.12000012821376745*lm^2) + 
        0.02277637649864171*NM - 0.004967532847834823*lm*NM + 
        0.013333347579307493*lm^2*NM + 0.04837938283884449*NL - 
        0.004967532847834823*lm*NL + 0.013333347579307493*lm^2*NL + 
        0.014568569606512614*NH - 0.004967532847834823*lm*NH + 
        0.013333347579307493*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.009597934164944703 - 0.06496848823405682*lm - 
          0.07295972702028934*lm^2) + CF*(0.00679393048562892 - 
          0.025739004521488557*lm + 0.11938864421501894*lm^2) + 
        0.022550305522532284*NM - 0.005070790210073153*lm*NM + 
        0.013265404912779881*lm^2*NM + 0.04815636758044632*NL - 
        0.005070790210073153*lm*NL + 0.013265404912779881*lm^2*NL + 
        0.014629615925080332*NH - 0.005070790210073153*lm*NH + 
        0.013265404912779881*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.00924687046393336 - 0.06393281255759697*lm - 
          0.07258803914021976*lm^2) + CF*(0.006916949804763412 - 
          0.026761022192594446*lm + 0.11878042768399598*lm^2) + 
        0.02232755491878576*NM - 0.005173084459991901*lm*NM + 
        0.013197825298221775*lm^2*NM + 0.04793510546675908*NL - 
        0.005173084459991901*lm*NL + 0.013197825298221775*lm^2*NL + 
        0.014690227156092266*NH - 0.005173084459991901*lm*NH + 
        0.013197825298221775*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.008901645271510468 - 0.06290497041229338*lm - 
          0.07221834647924905*lm^2) + CF*(0.007043297274950062 - 
          0.027773832539846707*lm + 0.118175476056953*lm^2) + 
        0.02210808986417329*NM - 0.005274416135111727*lm*NM + 
        0.013130608450772555*lm^2*NM + 0.04771558978928762*NL - 
        0.005274416135111727*lm*NL + 0.013130608450772555*lm^2*NL + 
        0.014750401321042689*NH - 0.005274416135111727*lm*NH + 
        0.013130608450772555*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.00856223839485377 - 0.061884955082761824*lm - 
          0.07185064712116972*lm^2) + CF*(0.007172940042533959 - 
          0.028777443083878723*lm + 0.11757378619827771*lm^2) + 
        0.021891875494511163*NM - 0.005374786012991668*lm*NM + 
        0.013063754022030857*lm^2*NM + 0.047497813489734024*NL - 
        0.005374786012991668*lm*NL + 0.013063754022030857*lm^2*NL + 
        0.014810136563760514*NH - 0.005374786012991668*lm*NH + 
        0.013063754022030857*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.008228627839981469 - 0.06087275814996909*lm - 
          0.0714849388130346*lm^2) + CF*(0.0073058447372870575 - 
          0.029771863523642115*lm + 0.11697535442132934*lm^2) + 
        0.02167887692357364*NM - 0.005474195103021889*lm*NM + 
        0.012997261602369926*lm^2*NM + 0.04728176917726753*NL - 
        0.005474195103021889*lm*NL + 0.012997261602369926*lm^2*NL + 
        0.014869431147820909*NH - 0.005474195103021889*lm*NH + 
        0.012997261602369926*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.00790078989304259 - 0.05986836955101353*lm - 
          0.0711212189775124*lm^2) + CF*(0.007441977493695133 - 
          0.030757105660946592*lm + 0.11638017650865667*lm^2) + 
        0.02146905926115304*NM - 0.005572644638413634*lm*NM + 
        0.012931130723184074*lm^2*NM + 0.04706744914521511*NL - 
        0.005572644638413634*lm*NL + 0.012931130723184074*lm^2*NL + 
        0.014928283453985886*NH - 0.005572644638413634*lm*NH + 
        0.012931130723184074*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.007578699199165588 - 0.05887177763736923*lm - 
          0.07075948472487524*lm^2) + CF*(0.007581303972298331 - 
          0.0317331833268477*lm + 0.11578824773161403*lm^2) + 
        0.021262387630296288*NM - 0.005670136068383337*lm*NM + 
        0.012865360859068226*lm^2*NM + 0.046854845387188884*NL - 
        0.005670136068383337*lm*NL + 0.012865360859068226*lm^2*NL + 
        0.01498669197767446*NH - 0.005670136068383337*lm*NH + 
        0.012865360859068226*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.0072623288389185095 - 0.057882969231624046*lm - 
          0.07039973286462847*lm^2) + CF*(0.007723789381043042 - 
          0.03270011230985185*lm + 0.11519956286939204*lm^2) + 
        0.021058827183746548*NM - 0.005766671050527836*lm*NM + 
        0.01279995142993245*lm^2*NM + 0.04664394961266635*NL - 
        0.005766671050527836*lm*NL + 0.01279995142993245*lm^2*NL + 
        0.015044655326462946*NH - 0.005766671050527836*lm*NH + 
        0.01279995142993245*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.006951650402433678 - 0.05690192968274183*lm - 
          0.07004195991679331*lm^2) + CF*(0.007869398496605864 - 
          0.03365791028590787*lm + 0.11461411622747997*lm^2) + 
        0.020858343119617553*NM - 0.005862251443387541*lm*NM + 
        0.012734901803053329*lm^2*NM + 0.04643475326203883*NL - 
        0.005862251443387541*lm*NL + 0.012734901803053329*lm^2*NL + 
        0.015102172217615856*NH - 0.005862251443387541*lm*NH + 
        0.012734901803053329*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.006646634061249684 - 0.05592864291987857*lm - 
          0.069686162122852*lm^2) + CF*(0.00801809568565332 - 
          0.03460659675015398*lm + 0.114031901655576*lm^2) + 
        0.020660900696327502*NM - 0.005956879299194442*lm*NM + 
        0.012670211295064*lm^2*NM + 0.046227247521143405*NL - 
        0.005956879299194442*lm*NL + 0.012670211295064*lm^2*NL + 
        0.015159241475647855*NH - 0.005956879299194442*lm*NH + 
        0.012670211295064*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.006347248637923066 - 0.05496309150478224*lm - 
          0.06933233545636514*lm^2) + CF*(0.008169844926003702 - 
          0.0355461929503891*lm + 0.11345291256496112*lm^2) + 
        0.02046646524681865*NM - 0.006050556856801772*lm*NM + 
        0.01260587917388457*lm^2*NM + 0.04602142333529311*NL - 
        0.006050556856801772*lm*NL + 0.01260587917388457*lm^2*NL + 
        0.015215862029917118*NH - 0.006050556856801772*lm*NH + 
        0.01260587917388457*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.006053461673461635 - 0.05400525668280577*lm - 
          0.06898047563327059*lm^2) + CF*(0.008324609827659998 - 
          0.036476721822237324*lm + 0.11287714194535187*lm^2) + 
        0.02027500219208782*NM - 0.006143286534792144*lm*NM + 
        0.012541904660594651*lm^2*NM + 0.04581727142282001*NL - 
        0.006143286534792144*lm*NL + 0.012541904660594651*lm^2*NL + 
        0.015272032912250452*NH - 0.006143286534792144*lm*NH + 
        0.012541904660594651*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.005765239492630986 - 0.0530551184325623*lm - 
          0.06863057812187316*lm^2) + CF*(0.008482353653685337 - 
          0.03739820792597427*lm + 0.11230458238124699*lm^2) + 
        0.02008647705405247*NM - 0.006235070924760975*lm*NM + 
        0.012478286931249666*lm^2*NM + 0.04561478228814516*NL - 
        0.006235070924760975*lm*NL + 0.012478286931249666*lm^2*NL + 
        0.015327753254600444*NH - 0.006235070924760975*lm*NH + 
        0.012478286931249666*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.005482547267185126 - 0.05211265551425153*lm - 
          0.06828263815253373*lm^2) + CF*(0.008643039340894644 - 
          0.038310677384984164*lm + 0.11173522606778247*lm^2) + 
        0.019900855467775962*NM - 0.006325912784771989*lm*NM + 
        0.012415025118642497*lm^2*NM + 0.0454139462343895*NL - 
        0.006325912784771989*lm*NL + 0.012415025118642497*lm^2*NL + 
        0.01538302228673486*NH - 0.006325912784771989*lm*NH + 
        0.012415025118642497*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.0052053490770716795 - 0.05117784551668578*lm - 
          0.06793665072706652*lm^2) + CF*(0.008806629520338428 - 
          0.039214157825816394*lm + 0.11116906482610886*lm^2) + 
        0.019718103193075313*NM - 0.006415815032981616*lm*NM + 
        0.012352118314012095*lm^2*NM + 0.045214753375539055*NL - 
        0.006415815032981616*lm*NL + 0.012352118314012095*lm^2*NL + 
        0.015437839333958503*NH - 0.006415815032981616*lm*NH + 
        0.012352118314012095*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.004933607969661422 - 0.050250664903043876*lm - 
          0.06759261062785293*lm^2) + CF*(0.008973086537556655 - 
          0.040108678319810784*lm + 0.1106060901183048*lm^2) + 
        0.01953818612553362*NM - 0.006504780741429065*lm*NM + 
        0.012289565568700533*lm^2*NM + 0.045017193648177675*NL - 
        0.006504780741429065*lm*NL + 0.012289565568700533*lm^2*NL + 
        0.015492203814867688*NH - 0.006504780741429065*lm*NH + 
        0.012289565568700533*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.0046672860170513366 - 0.04933108905538079*lm - 
          0.0672505124266799*lm^2) + CF*(0.009142372472582603 - 
          0.04099426932626033*lm + 0.11004629306183983*lm^2) + 
        0.019361070306938913*NM - 0.006592813129988923*lm*NM + 
        0.01222736589575998*lm^2*NM + 0.04482125682280023*NL - 
        0.006592813129988923*lm*NL + 0.01222736589575998*lm^2*NL + 
        0.01554611523913743*NH - 0.006592813129988923*lm*NH + 
        0.01222736589575998*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.004406344371489649 - 0.048419092317920506*lm - 
          0.0669103504933108*lm^2) + CF*(0.009314449159678455 - 
          0.04187096263708103*lm + 0.10948966444359949*lm^2) + 
        0.019186721935170452*NM - 0.006679915560483069*lm*NM + 
        0.012165518271511055*lm^2*NM + 0.04462693251471871*NL - 
        0.006679915560483069*lm*NL + 0.012165518271511055*lm^2*NL + 
        0.015599573205341423*NH - 0.006679915560483069*lm*NH + 
        0.012165518271511055*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.004150743318970622 - 0.04751464803915921*lm - 
          0.06657211900379656*lm^2) + CF*(0.009489278206786118 - 
          0.04273879132295805*lm + 0.10893619473348529*lm^2) + 
        0.019015107373552782*NM - 0.00676609153094877*lm*NM + 
        0.01210402163705392*lm^2*NM + 0.04443421019457365*NL - 
        0.00676609153094877*lm*NL + 0.01210402163705392*lm^2*NL + 
        0.015652577398804882*NH - 0.00676609153094877*lm*NH + 
        0.01210402163705392*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.0039004423310461406 - 0.046617728612805574*lm - 
          0.0662358119485343*lm^2) + CF*(0.009666821014678308 - 
          0.043597789680938095*lm + 0.10838587409760159*lm^2) + 
        0.018846193159697294*NM - 0.006851344670059817*lm*NM + 
        0.01204287489973351*lm^2*NM + 0.044243079198462605*NL - 
        0.006851344670059817*lm*NL + 0.01204287489973351*lm^2*NL + 
        0.015705127589490237*NH - 0.006851344670059817*lm*NH + 
        0.01204287489973351*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.003655400114900406 - 0.045728305517584514*lm - 
          0.06590142314008092*lm^2) + CF*(0.009847038795796603 - 
          0.04444799318343791*lm + 0.1078386924110415*lm^2) + 
        0.018679946013850316*NM - 0.006935678731697573*lm*NM + 
        0.011982076934560167*lm^2*NM + 0.044053528737697446*NL - 
        0.006935678731697573*lm*NL + 0.011982076934560167*lm^2*NL + 
        0.01575722362991565*NH - 0.006935678731697573*lm*NH + 
        0.011982076934560167*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.003415574661733235 - 0.04484634935593033*lm - 
          0.06556894622072851*lm^2) + CF*(0.010029892592764498 - 
          0.04528943842863915*lm + 0.10729463927028302*lm^2) + 
        0.01851633284676631*NM - 0.007019097589668851*lm*NM + 
        0.011921626585587002*lm^2*NM + 0.043865547908201755*NL - 
        0.007019097589668851*lm*NL + 0.011921626585587002*lm^2*NL + 
        0.015808865453106367*NH - 0.007019097589668851*lm*NH + 
        0.011921626585587002*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.003180923293496729 - 0.04397182989159476*lm - 
          0.06523837466984855*lm^2) + CF*(0.010215343296564903 - 
          0.04612216309224026*lm + 0.10675370400520673*lm^2) + 
        0.018355320767123977*NM - 0.007101605232567561*lm*NM + 
        0.011861522667245192*lm^2*NM + 0.04367912569955941*NL - 
        0.007101605232567561*lm*NL + 0.011861522667245192*lm^2*NL + 
        0.01586005307057876*NH - 0.007101605232567561*lm*NH + 
        0.011861522667245192*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.0029514027080292512 - 0.04310471608619521*lm - 
          0.06490970181101148*lm^2) + CF*(0.010403351664372805 - 
          0.046946205880536045*lm + 0.10621587569074604*lm^2) + 
        0.018196877088502636*NM - 0.00718320575877708*lm*NM + 
        0.01180176396563845*lm^2*NM + 0.04349425100372501*NL - 
        0.00718320575877708*lm*NL + 0.01180176396563845*lm^2*NL + 
        0.015910786570357036*NH - 0.00718320575877708*lm*NH + 
        0.01180176396563845*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.002726969022629861 - 0.042244976134727746*lm - 
          0.06458292081888795*lm^2) + CF*(0.010593878337034974 - 
          0.04776160648479642*lm + 0.10568114315818028*lm^2) + 
        0.018040969335935617*NM - 0.007263903371610349*lm*NM + 
        0.01174234923979781*lm^2*NM + 0.04331091262340668*NL - 
        0.007263903371610349*lm*NL + 0.01174234923979781*lm^2*NL + 
        0.01596106611502242*NH - 0.007263903371610349*lm*NH + 
        0.01174234923979781*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.002507577816115535 - 0.041392577500069264*lm - 
          0.06425802472593839*lm^2) + CF*(0.010786883856189764 - 
          0.04856840553691565*lm + 0.105149495006081*lm^2) + 
        0.017887565252056883*NM - 0.007343702374584721*lm*NM + 
        0.01168327722289789*lm^2*NM + 0.043129099280131436*NL - 
        0.007343702374584721*lm*NL + 0.01168327722289789*lm^2*NL + 
        0.01601089193979477*NH - 0.007343702374584721*lm*NH + 
        0.01168327722289789*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.0022931841694026896 - 0.040547486946492704*lm - 
          0.06393500642889657*lm^2) + CF*(0.010982328681021059 - 
          0.049366644566304095*lm + 0.10462091961092167*lm^2) + 
        0.01773663280285657*NM - 0.007422607166828634*lm*NM + 
        0.011624546623435742*lm^2*NM + 0.04294879962200299*NL - 
        0.007422607166828634*lm*NL + 0.011624546623435742*lm^2*NL + 
        0.016060264350646333*NH - 0.007422607166828634*lm*NH + 
        0.011624546623435742*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.002083742704653707 - 0.03970967057221878*lm - 
          0.06361385869505334*lm^2) + CF*(0.011180173204641444 - 
          0.050156365957994734*lm + 0.10409540513736001*lm^2) + 
        0.01758814018306062*NM - 0.007500622238617193*lm*NM + 
        0.011566156126373335*lm^2*NM + 0.04277000223116164*NL - 
        0.007500622238617193*lm*NL + 0.011566156126373335*lm^2*NL + 
        0.01610918372244763*NH - 0.007500622238617193*lm*NH + 
        0.011566156126373335*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.0018792076230283242 - 0.03887909384102732*lm - 
          0.06329457416834616*lm^2) + CF*(0.011380377770100597 - 
          0.0509376129119372*lm + 0.10357293954820282*lm^2) + 
        0.017442055821149147*NM - 0.007577752167033815*lm*NM + 
        0.011508104394244758*lm^2*NM + 0.0425926956309557*NL - 
        0.007577752167033815*lm*NL + 0.011508104394244758*lm^2*NL + 
        0.016157650497145088*NH - 0.007577752167033815*lm*NH + 
        0.011508104394244758*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.0016795327410789455 - 0.03805572161295079*lm - 
          0.06297714537526017*lm^2) + CF*(0.01158290268601569 - 
          0.05171042940345224*lm + 0.1030535106140621*lm^2) + 
        0.01729834838402777*NM - 0.007654001611755102*lm*NM + 
        0.011450390068229122*lm^2*NM + 0.04241686829283347*NL - 
        0.007654001611755102*lm*NL + 0.011450390068229122*lm^2*NL + 
        0.016205665181970384*NH - 0.007654001611755102*lm*NH + 
        0.011450390068229122*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.0014846715258280989 - 0.03723951817407227*lm - 
          0.06266156473054593*lm^2) + CF*(0.011787708241821527 - 
          0.05247486014482025*lm + 0.10253710592271154*lm^2) + 
        0.0171569867813656*NM - 0.007729375310956167*lm*NM + 
        0.01139301176919017*lm^2*NM + 0.0422425086429647*NL - 
        0.007729375310956167*lm*NL + 0.01139301176919017*lm^2*NL + 
        0.01625322834768113*NH - 0.007729375310956167*lm*NH + 
        0.01139301176919017*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.0012945771285654505 - 0.03643044726544976*lm - 
          0.06234782454275954*lm^2) + CF*(0.011994754722638739 - 
          0.05323095054797759*lm + 0.10202371288815199*lm^2) + 
        0.017017940169613128*NM - 0.007803878077333658*lm*NM + 
        0.011335968098683553*lm^2*NM + 0.04206960506860021*NL - 
        0.007803878077333658*lm*NL + 0.011335968098683553*lm^2*NL + 
        0.016300340626832763*NH - 0.007803878077333658*lm*NH + 
        0.011335968098683553*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.001109202417400966 - 0.03562847211118796*lm - 
          0.06203591701962976*lm^2) + CF*(0.012204002423759188 - 
          0.053978746688295054*lm + 0.10151331875939415*lm^2) + 
        0.016881177955712857*NM - 0.007877514794243786*lm*NM + 
        0.011279257639932684*lm^2*NM + 0.04189814592417791*NL - 
        0.007877514794243786*lm*NL + 0.011279257639932684*lm^2*NL + 
        0.01634700271208131*NH - 0.007877514794243786*lm*NH + 
        0.011279257639932684*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.0009285000086100051 - 0.03483355544567881*lm - 
          0.061725834273257514*lm^2) + CF*(0.012415411664748282 - 
          0.05471829526941315*lm + 0.10100591062896684*lm^2) + 
        0.01674666980051503*NM - 0.007950290411952698*lm*NM + 
        0.011222878958774093*lm^2*NM + 0.04172811953718351*NL - 
        0.007950290411952698*lm*NL + 0.011222878958774093*lm^2*NL + 
        0.016393215354516828*NH - 0.007950290411952698*lm*NH + 
        0.011222878958774093*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.0007524222968053285 - 0.034045659540031054*lm - 
          0.06141756832515243*lm^2) + CF*(0.012628942803164584 - 
          0.055449643589109365*lm + 0.10050147544115852*lm^2) + 
        0.016614385621910446*NM - 0.008022209943996569*lm*NM + 
        0.011166830604573168*lm^2*NM + 0.04155951421377379*NL - 
        0.008022209943996569*lm*NL + 0.011166830604573168*lm^2*NL + 
        0.01643897936202717*NH - 0.008022209943996569*lm*NH + 
        0.011166830604573168*lm^2*NH)}, {1., 1.7861225422953818*^-7*CF*NC*
       (-3.*CA*(1084.1389102445376 + 62080.*lm + 114048.*lm^2) + 
        2.*(9.*CF*(3995.170775346067 - 17472.*lm + 31104.*lm^2) + 
          4.*((11536.369431088682 - 5664.*lm + 7776.*lm^2)*NM + 
            24.*(1207. - 236.*lm + 324.*lm^2)*NL + 
            (11536.369431088682 - 5664.*lm + 7776.*lm^2)*NH)))}}
 
CbarTable["v", 2, 2] = {{0., -8.573388203017833*^-8*CF*NC*
       (CF*(-817920.1586039913 - 2.5609985392376385*^6*lm - 2.3328*^6*lm^2) + 
        CA*(1.180946508732078*^6 + 2.2243273314337227*^6*lm + 712800.*lm^2) + 
        60.*((-9100.57495786913 - 3991.294943738554*lm - 2160.*lm^2)*NM + 
          (-9100.57495786913 - 3991.294943738554*lm - 2160.*lm^2)*NL - 
          2.*(-898.9399877902611 + 1995.647471869277*lm + 1080.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.09549815379252861 - 0.19147356955293707*lm - 
          0.06186103557638051*lm^2) + CF*(0.07151117544121913 + 
          0.21713094253125864*lm + 0.20245429824997258*lm^2) + 
        0.04644991702148939*NM + 0.020498425901041003*lm*NM + 
        0.011247461013887365*lm^2*NM + 0.04645334880525537*NL + 
        0.020498425901041003*lm*NL + 0.011247461013887365*lm^2*NL - 
        0.00932339918273324*NH + 0.020498425901041003*lm*NH + 
        0.011247461013887365*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.09023580947228943 - 0.1922415935227016*lm - 
          0.06257869011608388*lm^2) + CF*(0.07242555425781168 + 
          0.2148937210909639*lm + 0.20480298583445636*lm^2) + 
        0.046136796394007626*NM + 0.020471997803711454*lm*NM + 
        0.011377943657469797*lm^2*NM + 0.046148483782917867*NL + 
        0.020471997803711454*lm*NL + 0.011377943657469797*lm^2*NL - 
        0.009395235652251494*NH + 0.020471997803711454*lm*NH + 
        0.011377943657469797*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.08552580457727212 - 0.19300943310530133*lm - 
          0.06325983790722516*lm^2) + CF*(0.0728848894437793 + 
          0.21289756484307418*lm + 0.20703219678728232*lm^2) + 
        0.04588152681932775*NM + 0.02045398402408533*lm*NM + 
        0.011501788710404574*lm^2*NM + 0.04590521810732613*NL + 
        0.02045398402408533*lm*NL + 0.011501788710404574*lm^2*NL - 
        0.009463586326705454*NH + 0.02045398402408533*lm*NH + 
        0.011501788710404574*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.0813668699650191 - 0.19377407841114433*lm - 
          0.06390185247386185*lm^2) + CF*(0.07295306781763763 + 
          0.21115001007644477*lm + 0.20913333536900242*lm^2) + 
        0.04568116101110721*NM + 0.020444445089066475*lm*NM + 
        0.011618518631611245*lm^2*NM + 0.04572062766447736*NL + 
        0.020444445089066475*lm*NL + 0.011618518631611245*lm^2*NL - 
        0.009528251912168096*NH + 0.020444445089066475*lm*NH + 
        0.011618518631611245*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.0777337311447854 - 0.1945297342065859*lm - 
          0.0645030783097513*lm^2) + CF*(0.07269782847466676 + 
          0.20964304974956385*lm + 0.21110098355918605*lm^2) + 
        0.04552952762810354*NM + 0.020442710412164077*lm*NM + 
        0.01172783241995478*lm^2*NM + 0.04558900277740112*NL + 
        0.020442710412164077*lm*NL + 0.01172783241995478*lm^2*NL - 
        0.009589082265254295*NH + 0.020442710412164077*lm*NH + 
        0.01172783241995478*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.07459074250010458 - 0.19526961024972692*lm - 
          0.06506253773202726*lm^2) + CF*(0.07218187581592066 + 
          0.20836093335155392*lm + 0.21293194166845286*lm^2) + 
        0.04541936377255953*NM + 0.0204477716446052*lm*NM + 
        0.011829552314914046*lm^2*NM + 0.04550371349304524*NL + 
        0.0204477716446052*lm*NL + 0.011829552314914046*lm^2*NL - 
        0.009645963668679619*NH + 0.0204477716446052*lm*NH + 
        0.011829552314914046*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.07189801805474953 - 0.19598673623198612*lm - 
          0.06557975578397082*lm^2) + CF*(0.07146055473452718 + 
          0.20728399309839568*lm + 0.21462465529299543*lm^2) + 
        0.045343230483479366*NM + 0.020458471364896792*lm*NM + 
        0.011923591960721968*lm^2*NM + 0.045457990936350556*NL + 
        0.020458471364896792*lm*NL + 0.011923591960721968*lm^2*NL - 
        0.009698811324223077*NH + 0.020458471364896792*lm*NH + 
        0.011923591960721968*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.06961458331169271 - 0.19667437566380075*lm - 
          0.0660546426417899*lm^2) + CF*(0.07058157637862529 + 
          0.2063907769156314*lm + 0.21617883046403963*lm^2) + 
        0.04529395204925026*NM + 0.020473605542425617*lm*NM + 
        0.01200993502577998*lm^2*NM + 0.045445294795843943*NL + 
        0.020473605542425617*lm*NL + 0.01200993502577998*lm^2*NL - 
        0.009747564316369407*NH + 0.020473605542425617*lm*NH + 
        0.01200993502577998*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.06770010073442369 - 0.19732624311797145*lm - 
          0.06648740906438173*lm^2) + CF*(0.06958547209704508 + 
          0.2056593191251812*lm + 0.21759515693797657*lm^2) + 
        0.04526483179295298*NM + 0.020491982601592424*lm*NM + 
        0.012088619829887588*lm^2*NM + 0.04545949071108799*NL + 
        0.020491982601592424*lm*NL + 0.012088619829887588*lm^2*NL - 
        0.009792181954104147*NH + 0.020491982601592424*lm*NH + 
        0.012088619829887588*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.06611583357668101 - 0.1979366148570397*lm - 
          0.066878502848545*lm^2) + CF*(0.06850629671546106 + 
          0.20506792315457173*lm + 0.2188751002316018*lm^2) + 
        0.04524975174836096*NM + 0.02051245824045962*lm*NM + 
        0.012159727790644545*lm^2*NM + 0.045494930833210004*NL + 
        0.02051245824045962*lm*NL + 0.012159727790644545*lm^2*NL - 
        0.009832640963689734*NH + 0.02051245824045962*lm*NH + 
        0.012159727790644545*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.0648251736774555 - 0.19850037798787612*lm - 
          0.06722855958647389*lm^2) + CF*(0.06737238816597889 + 
          0.20459564838374675*lm + 0.22002074046482364*lm^2) + 
        0.045243208371692094*NM + 0.020533955762909138*lm*NM + 
        0.01222337447026798*lm^2*NM + 0.04554648198525191*NL + 
        0.020533955762909138*lm*NL + 0.01222337447026798*lm^2*NL - 
        0.009868933245717899*NH + 0.020533955762909138*lm*NH + 
        0.01222337447026798*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.06379390802436531 - 0.19901304285886684*lm - 
          0.06753836365626774*lm^2) + CF*(0.06620710250773298 + 
          0.20422260895405622*lm + 0.22103464469323988*lm^2) + 
        0.0452403119414533*NM + 0.020555477359665897*lm*NM + 
        0.012279702482957771*lm^2*NM + 0.04560952455831757*NL + 
        0.020555477359665897*lm*NL + 0.012279702482957771*lm^2*NL - 
        0.009901064027048026*NH + 0.020555477359665897*lm*NH + 
        0.012279702482957771*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.06299032431733878 - 0.19947073310565305*lm - 
          0.06780881681156017*lm^2) + CF*(0.06502949145811476 + 
          0.20393014912213975*lm + 0.22191976411056058*lm^2) + 
        0.04523676524195107*NM + 0.02057610956694779*lm*NM + 
        0.012328875783920033*lm^2*NM + 0.04567993496865012*NL + 
        0.02057610956694779*lm*NL + 0.012328875783920033*lm^2*NL - 
        0.00992905030122595*NH + 0.02057610956694779*lm*NH + 
        0.012328875783920033*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.06238521588568621 - 0.19987016213497988*lm - 
          0.06804091257882225*lm^2) + CF*(0.06385491134882162 + 
          0.2037009357835984*lm + 0.22267935025796373*lm^2) + 
        0.04522883071549888*NM + 0.020595024915392845*lm*NM + 
        0.01237107501433132*lm^2*NM + 0.045754059106290317*NL + 
        0.020595024915392845*lm*NL + 0.01237107501433132*lm^2*NL - 
        0.009952919487284065*NH + 0.020595024915392845*lm*NH + 
        0.01237107501433132*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.06195182365979479 - 0.2002086015913949*lm - 
          0.06823571519493843*lm^2) + CF*(0.06269556252171112 + 
          0.20351899470286527*lm + 0.22331688609252576*lm^2) + 
        0.04521329165477619*NM + 0.02061148107068109*lm*NM + 
        0.012406493671806988*lm^2*NM + 0.04582868121298337*NL + 
        0.02061148107068109*lm*NL + 0.012406493671806988*lm^2*NL - 
        0.009972708258933503*NH + 0.02061148107068109*lm*NH + 
        0.012406493671806988*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.06166573940490503 - 0.20048384538825115*lm - 
          0.06839434215928752*lm^2) + CF*(0.06156096278330197 + 
          0.20336970829882767*lm + 0.22383602888494097*lm^2) + 
        0.045187410875787724*NM + 0.020624818331251855*lm*NM + 
        0.012435334938052277*lm^2*NM + 0.04590099088911902*NL + 
        0.020624818331251855*lm*NL + 0.012435334938052277*lm^2*NL - 
        0.009988461510225349*NH + 0.020624818331251855*lm*NH + 
        0.012435334938052277*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.06150478607325855 - 0.2006941716520048*lm - 
          0.0685179497060624*lm^2) + CF*(0.06045836046236364 + 
          0.20323978726973477*lm + 0.22424056267438605*lm^2) + 
        0.04514888901029844*NM + 0.02063445607086246*lm*NM + 
        0.012457809037465892*lm^2*NM + 0.04596854988391468*NL + 
        0.02063445607086246*lm*NL + 0.012457809037465892*lm^2*NL - 
        0.0100002314330314*NH + 0.02063445607086246*lm*NH + 
        0.012457809037465892*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.06144888580010098 - 0.2008383041319169*lm - 
          0.06860772066460777*lm^2) + CF*(0.059393093213299705 + 
          0.20311722466023363*lm + 0.22453435853871634*lm^2) + 
        0.04509582373984066*NM + 0.020639888531348384*lm*NM + 
        0.012474131029928686*lm^2*NM + 0.046029259676452695*NL + 
        0.020639888531348384*lm*NL + 0.012474131029928686*lm^2*NL - 
        0.010008076687993061*NH + 0.020639888531348384*lm*NH + 
        0.012474131029928686*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.06147992257965232 - 0.20091537409971005*lm - 
          0.06866485429215458*lm^2) + CF*(0.05836889865213368 + 
          0.2029912384749535*lm + 0.22472134131977858*lm^2) + 
        0.0450266707703277*NM + 0.020640680248043747*lm*NM + 
        0.012484518962209921*lm^2*NM + 0.04608133044694581*NL + 
        0.020640680248043747*lm*NL + 0.012484518962209921*lm^2*NL - 
        0.010012061654972832*NH + 0.020640680248043747*lm*NH + 
        0.012484518962209921*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.061581604326288404 - 0.20092488340790948*lm - 
          0.06869055774923866*lm^2) + CF*(0.05738818254650221 + 
          0.20285220720985117*lm + 0.22480546172478105*lm^2) + 
        0.044940207006541055*NM + 0.020636461305746496*lm*NM + 
        0.012489192318043392*lm^2*NM + 0.04612325177607545*NL + 
        0.020636461305746496*lm*NL + 0.012489192318043392*lm^2*NL - 
        0.010012255752164414*NH + 0.020636461305746496*lm*NH + 
        0.012489192318043392*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.0617393274438172 - 0.20086666913217682*lm - 
          0.06868603895269931*lm^2) + CF*(0.05645224978527583 + 
          0.20269160144818074*lm + 0.22479067293610683*lm^2) + 
        0.044835496163201864*NM + 0.02062692256390338*lm*NM + 
        0.012488370718672603*lm^2*NM + 0.046153765241262724*NL + 
        0.02062692256390338*lm*NL + 0.012488370718672603*lm^2*NL - 
        0.010008732815281482*NH + 0.02062692256390338*lm*NH + 
        0.012488370718672603*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.0619400459380604 - 0.20074087005472696*lm - 
          0.06865250059061934*lm^2) + CF*(0.05556150282044779 + 
          0.20250191378996518*lm + 0.2246809110238451*lm^2) + 
        0.044711856903242704*NM + 0.02061181094765828*lm*NM + 
        0.012482272834658062*lm^2*NM + 0.04617183896931594*NL + 
        0.02061181094765828*lm*NL + 0.012482272834658062*lm^2*NL - 
        0.010001570529915915*NH + 0.02061181094765828*lm*NH + 
        0.012482272834658062*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.06217214635357933 - 0.20054789512896265*lm - 
          0.06859113512203942*lm^2) + CF*(0.05471561175132264 + 
          0.20227658874641016*lm + 0.22448007858121993*lm^2) + 
        0.04456883349848468*NM + 0.020590924871240285*lm*NM + 
        0.012471115476734441*lm^2*NM + 0.04617664413445272*NL + 
        0.020590924871240285*lm*NL + 0.012471115476734441*lm^2*NL - 
        0.009990849911408079*NH + 0.020590924871240285*lm*NH + 
        0.012471115476734441*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.062425329289286034 - 0.20028839398400278*lm - 
          0.06850312061461698*lm^2) + CF*(0.05391365973181333 + 
          0.2020099537632801*lm + 0.22419203110238287*lm^2) + 
        0.044406168946530614*NM + 0.02056410983833707*lm*NM + 
        0.01245511283902127*lm^2*NM + 0.046167533346066915*NL + 
        0.02056410983833707*lm*NL + 0.01245511283902127*lm^2*NL - 
        0.009976654827523692*NH + 0.02056410983833707*lm*NH + 
        0.01245511283902127*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.06269049788009558 - 0.19996322947121906*lm - 
          0.06838961729761703*lm^2) + CF*(0.05315426693555443 + 
          0.2016971521918306*lm + 0.2238205657012921*lm^2) + 
        0.0442237804393246*NM + 0.020531254248211093*lm*NM + 
        0.012434475872294007*lm^2*NM + 0.04614402084324294*NL + 
        0.020531254248211093*lm*NL + 0.012434475872294007*lm^2*NL - 
        0.009959071559965359*NH + 0.020531254248211093*lm*NH + 
        0.012434475872294007*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.0629596533755319 - 0.19957345221598444*lm - 
          0.06825176472716635*lm^2) + CF*(0.05243569591317633 + 
          0.20133407876917012*lm + 0.22336941183436262*lm^2) + 
        0.04402173705614997*NM + 0.020492285424719002*lm*NM + 
        0.0124094117685757*lm^2*NM + 0.04610576439725362*NL + 
        0.020492285424719002*lm*NL + 0.0124094117685757*lm^2*NL - 
        0.009938188401319766*NH + 0.020492285424719002*lm*NH + 
        0.0124094117685757*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.06322579776889307 - 0.19912027711153932*lm - 
          0.06809067947662772*lm^2) + CF*(0.05175594082035098 + 
          0.20091731797843607*lm + 0.22284222374169074*lm^2) + 
        0.043800239541852685*NM + 0.020447165876928006*lm*NM + 
        0.01238012354120504*lm^2*NM + 0.0460525488153182*NL + 
        0.020447165876928006*lm*NL + 0.01238012354120504*lm^2*NL - 
        0.009914095284494774*NH + 0.020447165876928006*lm*NH + 
        0.01238012354120504*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.06348284330964188 - 0.1986050616746521*lm - 
          0.0679074532780406*lm^2) + CF*(0.05111280268117652 + 
          0.20044408551612983*lm + 0.22224257436449651*lm^2) + 
        0.04355960202636159*NM + 0.020395889793861234*lm*NM + 
        0.012346809686916474*lm^2*NM + 0.04598427093617484*NL + 
        0.020395889793861234*lm*NL + 0.012346809686916474*lm^2*NL - 
        0.009886883442063553*NH + 0.020395889793861234*lm*NH + 
        0.012346809686916474*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.06372552865120487 - 0.19802928617206014*lm - 
          0.06770315155141754*lm^2) + CF*(0.050503952575395056 + 
          0.19991217298719308*lm + 0.22157395053191198*lm^2) + 
        0.04330023554176189*NM + 0.020338479771451503*lm*NM + 
        0.012309663918439554*lm^2*NM + 0.04590092600877607*NL + 
        0.020338479771451503*lm*NL + 0.012309663918439554*lm^2*NL - 
        0.009856645093227461*NH + 0.020338479771451503*lm*NH + 
        0.012309663918439554*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.06394934133500185 - 0.19739453542071006*lm - 
          0.06747881226772977*lm^2) + CF*(0.04992698439591375 + 
          0.19931989586900536*lm + 0.22083974923984287*lm^2) + 
        0.04302263319661062*NM + 0.020274983766604863*lm*NM + 
        0.012268874957769047*lm^2*NM + 0.045802595348437204*NL + 
        0.020274983766604863*lm*NL + 0.012268874957769047*lm^2*NL - 
        0.009823473156351143*NH + 0.020274983766604863*lm*NH + 
        0.012268874957769047*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.06415044628113958 - 0.19670248216224798*lm - 
          0.06723544509900639*lm^2) + CF*(0.049379458611302156 + 
          0.19866604472682708*lm + 0.22004327486947545*lm^2) + 
        0.042727356872706956*NM + 0.02020547227105187*lm*NM + 
        0.012224626381637524*lm^2*NM + 0.04568943516921764*NL + 
        0.02020547227105187*lm*NL + 0.012224626381637524*lm^2*NL - 
        0.009787460985224426*NH + 0.02020547227105187*lm*NH + 
        0.012224626381637524*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.06432561994088834 - 0.1959548719120776*lm - 
          0.06697403081537973*lm^2) + CF*(0.048858938282806214 + 
          0.1979498396203601*lm + 0.21918773721397003*lm^2) + 
        0.04241502531633099*NM + 0.020130035696157646*lm*NM + 
        0.012177096511887224*lm^2*NM + 0.045561666496614785*NL + 
        0.020130035696157646*lm*NL + 0.012177096511887224*lm^2*NL - 
        0.0097487021273749*NH + 0.020130035696157646*lm*NH + 
        0.012177096511887224*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.06447218976151489 - 0.195153509184897*lm - 
          0.06669552089434479*lm^2) + CF*(0.048363018423707715 + 
          0.19717088761032261*lm + 0.21827625019967387*lm^2) + 
        0.04208630350346768*NM + 0.020048781958893223*lm*NM + 
        0.012126458344426326*lm^2*NM + 0.04541956607039803*NL + 
        0.020048781958893223*lm*NL + 0.012126458344426326*lm^2*NL - 
        0.00970729010289918*NH + 0.020048781958893223*lm*NH + 
        0.012126458344426326*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.06458797861712416 - 0.19430024500141538*lm - 
          0.06640083731213443*lm^2) + CF*(0.04788934964766975 + 
          0.1963291432524034*lm + 0.21731183120334907*lm^2) + 
        0.04174189316632496*NM + 0.019961834258606398*lm*NM + 
        0.01207287951129717*lm^2*NM + 0.04526345815333066*NL + 
        0.019961834258606398*lm*NL + 0.01207287951129717*lm^2*NL - 
        0.009663318202405178*NH + 0.019961834258606398*lm*NH + 
        0.01207287951129717*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.06467125386755351 - 0.1933969655845578*lm - 
          0.06609087249107659*lm^2) + CF*(0.04743565692947775 + 
          0.19542487195150854*lm + 0.21629740087988705*lm^2) + 
        0.041382524376225124*NM + 0.01986932903396799*lm*NM + 
        0.012016522271104836*lm^2*NM + 0.04509370716743312*NL + 
        0.01986932903396799*lm*NL + 0.012016522271104836*lm^2*NL - 
        0.00961687930276593*NH + 0.01986932903396799*lm*NH + 
        0.012016522271104836*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.06472068071937677 - 0.19244558215759214*lm - 
          0.06576648938020573*lm^2) + CF*(0.04699975419407266 + 
          0.19445861604017928*lm + 0.21523578342612784*lm^2) + 
        0.04100894808543349*NM + 0.019771414089431952*lm*NM + 
        0.011957543523673769*lm^2*NM + 0.044910711085206084*NL + 
        0.019771414089431952*lm*NL + 0.011957543523673769*lm^2*NL - 
        0.009568065699480896*NH + 0.019771414089431952*lm*NH + 
        0.011957543523673769*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.06473527957748078 - 0.1914480217610541*lm - 
          0.06542852164933649*lm^2) + CF*(0.04657955535604125 + 
          0.19343116344015612*lm + 0.21412970721601032*lm^2) + 
        0.040621929537409306*NM + 0.019668246880675772*lm*NM + 
        0.011896094845333908*lm^2*NM + 0.044714895508774964*NL + 
        0.019668246880675772*lm*NL + 0.011896094845333908*lm^2*NL - 
        0.009516968954525397*NH + 0.019668246880675772*lm*NH + 
        0.011896094845333908*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.0647143870916052 - 0.19040621900993923*lm - 
          0.06507777397934554*lm^2) + CF*(0.04617308235014852 + 
          0.1923435187642989*lm + 0.2129818057505854*lm^2) + 
        0.0402222424609429*NM + 0.01955999294873544*lm*NM + 
        0.011832322541699188*lm^2*NM + 0.044506708375189254*NL + 
        0.01955999294873544*lm*NL + 0.011832322541699188*lm^2*NL - 
        0.009463679758644934*NH + 0.01955999294873544*lm*NH + 
        0.011832322541699188*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.06465762061911 - 0.18932210871726401*lm - 
          0.06471502243360759*lm^2) + CF*(0.045778470622750055 + 
          0.19119687671666832*lm + 0.21179461887362483*lm^2) + 
        0.039810663968085885*NM + 0.019446824492882608*lm*NM + 
        0.01176636771520138*lm^2*NM + 0.04428661523108133*NL + 
        0.019446824492882608*lm*NL + 0.01176636771520138*lm^2*NL - 
        0.009408287807119851*NH + 0.019446824492882608*lm*NH + 
        0.01176636771520138*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.0645648457401165 - 0.188197619314686*lm - 
          0.06434101489744416*lm^2) + CF^2*(0.045393972287795334 + 
          0.18999259765093293*lm + 0.21057059420981725*lm^2) + 
        CF*((0.03938797070648231 + 0.019328919072683103*lm + 
            0.011698366344989847*lm^2)*NM + (0.044055095024548276 + 
            0.019328919072683103*lm + 0.011698366344989847*lm^2)*NL + 
          (-0.009350881688088569 + 0.019328919072683103*lm + 
            0.011698366344989847*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.06443614706162355 - 0.18703466700535712*lm - 
          0.06395647157410889*lm^2) + CF^2*(0.045017958264313936 + 
          0.18873218515091078*lm + 0.2093120887879927*lm^2) + 
        CF*((0.03895493322434204 + 0.01920645843010585*lm + 
            0.011628449377110706*lm^2)*NM + (0.04381263636646415 + 
            0.01920645843010585*lm + 0.011628449377110706*lm^2)*NL + 
          (-0.009291548782574944 + 0.01920645843010585*lm + 
            0.011628449377110706*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.06427180106220601 - 0.1858351505885198*lm - 
          0.06356208552728722*lm^2) + CF^2*(0.04464891766221622 + 
          0.1874172655016263*lm + 0.20802137081657632*lm^2) + 
        CF*((0.03851231479256459 + 0.019079627423003252*lm + 
            0.01155674282314313*lm^2)*NM + (0.04355973421746488 + 
            0.019079627423003252*lm + 0.01155674282314313*lm^2)*NL + 
          (-0.00923037517541838 + 0.019079627423003252*lm + 
            0.01155674282314313*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.06407225194376907 - 0.18460094689951903*lm - 
          0.06315852326135905*lm^2) + CF^2*(0.04428545704003135 + 
          0.1860495689244705*lm + 0.20670062158262964*lm^2) + 
        CF*((0.03806086730792462 + 0.01894861306174682*lm + 
            0.011483367865701647*lm^2)*NM + (0.04329688696058328 + 
            0.01894861306174682*lm + 0.011483367865701647*lm^2)*NL + 
          (-0.0091674455763543 + 0.01894861306174682*lm + 
            0.011483367865701647*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.06383808950560509 - 0.18333390681287204*lm - 
          0.06274642533178632*lm^2) + CF^2*(0.043926298189409047 + 
          0.1846309124556735*lm + 0.20535193744948246*lm^2) + 
        CF*((0.03760132910938527 + 0.018813603641265855*lm + 
            0.011408440969415692*lm^2)*NM + (0.043024593822961366 + 
            0.018813603641265855*lm + 0.011408440969415692*lm^2)*NL + 
          (-0.009102843250538223 + 0.018813603641265855*lm + 
            0.011408440969415692*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.06357002913857751 - 0.18203585175980402*lm - 
          0.06232640697896315*lm^2) + CF^2*(0.04357027520610538 + 
          0.1831631843531646*lm + 0.2039773319311521*lm^2) + 
        CF*((0.037134422904954396 + 0.018674787961196038*lm + 
            0.011332073996175118*lm^2)*NM + (0.04274335261324608 + 
            0.018674787961196038*lm + 0.011332073996175118*lm^2)*NL + 
          (-0.009036649957849646 + 0.018674787961196038*lm + 
            0.011332073996175118*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.06326889372519814 - 0.1807085707152171*lm - 
          0.061899058779724264*lm^2) + CF^2*(0.04321633092836941 + 
          0.18164832992286634*lm + 0.20257873782455216*lm^2) + 
        CF*((0.03666085403637547 + 0.018532354627293357*lm + 
            0.01125437432358623*lm^2)*NM + (0.04245365774419901 + 
            0.018532354627293357*lm + 0.01125437432358623*lm^2)*NL + 
          (-0.008968945900350429 + 0.018532354627293357*lm + 
            0.01125437432358623*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.06293559728699405 - 0.17935381761241123*lm - 
          0.061464947311459614*lm^2) + CF^2*(0.04286351288533015 + 
          0.18008833866145202*lm + 0.20115800938295872*lm^2) + 
        CF*((0.0361813090456585 + 0.018386491427703947*lm + 
            0.011175444965719929*lm^2)*NM + (0.04215599851273732 + 
            0.018386491427703947*lm + 0.011175444965719929*lm^2)*NL + 
          (-0.008899809677312638 + 0.018386491427703947*lm + 
            0.011175444965719929*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.06257113023261049 - 0.1779733091470226*lm - 
          0.06102461582444694*lm^2) + CF^2*(0.042510968877163186 + 
          0.17848523261850374*lm + 0.1997169245163718*lm^2) + 
        CF*((0.035696454510649143 + 0.018237384778099032*lm + 
            0.01109538469535399*lm^2)*NM + (0.041850857612088135 + 
            0.018237384778099032*lm + 0.01109538469535399*lm^2)*NL + 
          (-0.008829318247262321 + 0.018237384778099032*lm + 
            0.01109538469535399*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.062176546071258006 - 0.17656872293459175*lm - 
          0.06057858491859733*lm^2) + CF^2*(0.042157942290467765 + 
          0.17684105588679233*lm + 0.19825718700631853*lm^2) + 
        CF*((0.035206936120095365 + 0.01808521923008507*lm + 
            0.011014288167017697*lm^2)*NM + (0.04153870985299798 + 
            0.01808521923008507*lm + 0.011014288167017697*lm^2)*NL + 
          (-0.008757546896521745 + 0.01808521923008507*lm + 
            0.011014288167017697*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.06175294946665535 - 0.17514169598892906*lm - 
          0.06012735322132284*lm^2) + CF^2*(0.04180376723656303 + 
          0.17515786513501086*lm + 0.1967804287243293*lm^2) + 
        CF*((0.03471337796131108 + 0.017930177037680992*lm + 
            0.010932246040240517*lm^2)*NM + (0.0412200210730082 + 
            0.017930177037680992*lm + 0.010932246040240517*lm^2)*NL + 
          (-0.008684569213762388 + 0.017930177037680992*lm + 
            0.010932246040240517*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.06130148551636812 - 0.173693823491015*lm - 
          0.05967139806368874*lm^2) + CF^2*(0.041447863586610574 + 
          0.1734377211027046*lm + 0.19528821184479953*lm^2) + 
        CF*((0.03421638199617252 + 0.017772437777016904*lm + 
            0.010849345102488863*lm^2)*NM + (0.04089524721470092 + 
            0.017772437777016904*lm + 0.010849345102488863*lm^2)*NL + 
          (-0.008610457070110827 + 0.017772437777016904*lm + 
            0.010849345102488863*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.06082333015054886 - 0.1722266578205663*lm - 
          0.05921117615241233*lm^2) + CF^2*(0.041089731965570364 + 
          0.1716826809823304*lm + 0.19378203104425853*lm^2) + 
        CF*((0.03371652770349352 + 0.01761217801475135*lm + 
            0.010765668391347696*lm^2)*NM + (0.04056483355555189 + 
            0.01761217801475135*lm + 0.010765668391347696*lm^2)*NL + 
          (-0.008535280604377393 + 0.01761217801475135*lm + 
            0.010765668391347696*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.06031968155254394 - 0.1707417078246264*lm - 
          0.058747124235622714*lm^2) + CF^2*(0.0407289487566957 + 
          0.1698947916183327*lm + 0.1922633156802198*lm^2) + 
        CF*((0.03321437186795779 + 0.017449571021027642*lm + 
            0.010681295315567767*lm^2)*NM + (0.04022921407360943 + 
            0.017449571021027642*lm + 0.010681295315567767*lm^2)*NL + 
          (-0.008459108213003818 + 0.017449571021027642*lm + 
            0.010681295315567767*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.05979175251169702 - 0.16924043829960705*lm - 
          0.05827965976060673*lm^2) + CF^2*(0.04036516115939976 + 
          0.1680760834578381*lm + 0.19073343194380382*lm^2) + 
        CF*((0.0327104484977053 + 0.017284786523093943*lm + 
            0.010596301774655769*lm^2)*NM + (0.03988881093466511 + 
            0.017284786523093943*lm + 0.010596301774655769*lm^2)*NL + 
          (-0.008382006544350853 + 0.017284786523093943*lm + 
            0.010596301774655769*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.05924076362597802 - 0.16772426966512805*lm - 
          0.05780918152203993*lm^2) + CF^2*(0.03999808233569725 + 
          0.16622856519203896*lm + 0.1891936849812216*lm^2) + 
        CF*((0.03220526885446475 + 0.01711799049599751*lm + 
            0.010510760276734534*lm^2)*NM + (0.03954403408790207 + 
            0.01711799049599751*lm + 0.010510760276734534*lm^2)*NL + 
          (-0.00830404049697034 + 0.01711799049599751*lm + 
            0.010510760276734534*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.058667937278858655 - 0.16619457780978175*lm - 
          0.057336070299443466*lm^2) + CF^2*(0.03962748667392866 + 
          0.16435421903156494*lm + 0.1876453209799968*lm^2) + 
        CF*((0.031699321581689574 + 0.016949344987031253*lm + 
            0.010424740054444267*lm^2)*NM + (0.03919528095821269 + 
            0.016949344987031253*lm + 0.010424740054444267*lm^2)*NL + 
          (-0.008225273221528365 + 0.016949344987031253*lm + 
            0.010424740054444267*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.05807449232114495 - 0.16465269409059863*lm - 
          0.05686068948281996*lm^2) + CF^2*(0.03925320519291969 + 
          0.16245499656312626*lm + 0.18608952921650168*lm^2) + 
        CF*((0.031193072917645472 + 0.01677900797086125*lm + 
            0.010338307178694538*lm^2)*NM + (0.03884293622447707 + 
            0.01677900797086125*lm + 0.010338307178694538*lm^2)*NL + 
          (-0.008145766126067296 + 0.01677900797086125*lm + 
            0.010338307178694538*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.057461639394299165 - 0.16309990546951458*lm - 
          0.05638338568560931*lm^2) + CF^2*(0.038875121104996906 + 
          0.16053281513846876*lm + 0.1845274440619941*lm^2) + 
        CF*((0.030686966981693584 + 0.01660713323249802*lm + 
            0.010251524670110783*lm^2)*NM + (0.03848737167409735 + 
            0.01660713323249802*lm + 0.010251524670110783*lm^2)*NL + 
          (-0.008065578884313753 + 0.01660713323249802*lm + 
            0.010251524670110783*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.05683057683709376 - 0.16153745477155357*lm - 
          0.055904489344269864*lm^2) + CF^2*(0.03849316555211885 + 
          0.15858955475020703*lm + 0.1829601469448832*lm^2) + 
        CF*((0.03018142612324974 + 0.016433870275492746*lm + 
            0.010164452608049067*lm^2)*NM + (0.03812894612499767 + 
            0.016433870275492746*lm + 0.010164452608049067*lm^2)*NL + 
          (-0.007984769446759368 + 0.016433870275492746*lm + 
            0.010164452608049067*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.056182535528193814 - 0.15996654105074232*lm - 
          0.055424315303935365*lm^2) + CF^2*(0.03810741033754574 + 
          0.156627055352411*lm + 0.18138866826742484*lm^2) + 
        CF*((0.029676851323940674 + 0.016259364252943314*lm + 
            0.010077148237079158*lm^2)*NM + (0.03776800540713391 + 
            0.016259364252943314*lm + 0.010077148237079158*lm^2)*NL + 
          (-0.00790339405425754 + 0.016259364252943314*lm + 
            0.010077148237079158*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.05551857385809236 - 0.15838832005097878*lm - 
          0.0549431633897252*lm^2) + CF^2*(0.03771766014508594 + 
          0.15464711458692326*lm + 0.1798139892754643*lm^2) + 
        CF*((0.02917362264453819 + 0.016083755919084525*lm + 
            0.009989666070859127*lm^2)*NM + (0.03740488239631721 + 
            0.016083755919084525*lm + 0.009989666070859127*lm^2)*NL + 
          (-0.00782150725389731 + 0.016083755919084525*lm + 
            0.009989666070859127*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.05483989105188903 - 0.15680390475018757*lm - 
          0.05446131896339698*lm^2) + CF^2*(0.03732408078322468 + 
          0.15265148587928348*lm + 0.1782370438802083*lm^2) + 
        CF*((0.028672099709065882 + 0.015907181599413317*lm + 
            0.009902057993344907*lm^2)*NM + (0.03703989709384799 + 
            0.015907181599413317*lm + 0.009902057993344907*lm^2)*NL + 
          (-0.007739161916930524 + 0.015907181599413317*lm + 
            0.009902057993344907*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.05414760478452037 - 0.15521436597712157*lm - 
          0.05397905346512791*lm^2) + CF^2*(0.03692675542187652 + 
          0.1506418768708487*lm + 0.1766587204313277*lm^2) + 
        CF*((0.02817262221938232 + 0.01572977317746358*lm + 
            0.009814373357295982*lm^2)*NM + (0.036673356746087814 + 
            0.01572977317746358*lm + 0.009814373357295982*lm^2)*NL + 
          (-0.00765640925854357 + 0.01572977317746358*lm + 
            0.009814373357295982*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.05344280691081749 - 0.15362073309111376*lm - 
          0.05349662494029642*lm^2) + CF^2*(0.03652579654219832 + 
          0.14861994815622825*lm + 0.1750798634409701*lm^2) + 
        CF*((0.02767551049417812 + 0.015551658096497547*lm + 
            0.009726659080053894*lm^2)*NM + (0.036305555998670865 + 
            0.015551658096497547*lm + 0.009726659080053894*lm^2)*NL + 
          (-0.007573298859279294 + 0.015551658096497547*lm + 
            0.009726659080053894*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.05272656186479451 - 0.15202399471595504*lm - 
          0.05301427855120999*lm^2) + CF^2*(0.03612134277598665 + 
          0.14658731229751232*lm + 0.17350127525850545*lm^2) + 
        CF*((0.027181066027081355 + 0.015372959374521744*lm + 
            0.009638959736583635*lm^2)*NM + (0.03593677708057928 + 
            0.015372959374521744*lm + 0.009638959736583635*lm^2)*NL + 
          (-0.007489878687927418 + 0.015372959374521744*lm + 
            0.009638959736583635*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.051999905346300154 - 0.15042509951987562*lm - 
          0.052532247073788986*lm^2) + CF^2*(0.035713555931456885 + 
          0.14454553308897328*lm + 0.17192371769603668*lm^2) + 
        CF*((0.026689572059412688 + 0.015193795631166709*lm + 
            0.009551317649779815*lm^2)*NM + (0.03556729001378268 + 
            0.015193795631166709*lm + 0.009551317649779815*lm^2)*NL + 
          (-0.007406195125714913 + 0.015193795631166709*lm + 
            0.009551317649779815*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.05126384326704884 - 0.14882495703434603*lm - 
          0.052050751379272314*lm^2) + CF^2*(0.03530261820349551 + 
          0.14249612504796622*lm + 0.1703479136048912*lm^2) + 
        CF*((0.026201294161236222 + 0.015014281125090812*lm + 
            0.009463772978049512*lm^2)*NM + (0.03519735284457436 + 
            0.015014281125090812*lm + 0.009463772978049512*lm^2)*NL + 
          (-0.007322292991639302 + 0.015014281125090812*lm + 
            0.009463772978049512*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.0505193509263905 - 0.14722443850509337*lm - 
          0.05157000090105881*lm^2) + CF^2*(0.034888729557330626 + 
          0.14044055310966003*lm + 0.1687745484034652*lm^2) + 
        CF*((0.02571648082368856 + 0.014834525800681052*lm + 
            0.009376363800192512*lm^2)*NM + (0.03482721189313068 + 
            0.014834525800681052*lm + 0.009376363800192512*lm^2)*NL + 
          (-0.007238215568797742 + 0.014834525800681052*lm + 
            0.009376363800192512*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.049767372398269914 - 0.14562437776935183*lm - 
          0.051090194086839014*lm^2) + CF^2*(0.0344721052914957 + 
          0.13838023250500225*lm + 0.16720427155692769*lm^2) + 
        CF*((0.025235364047459134 + 0.014654635342927666*lm + 
            0.009289126197607094*lm^2)*NM + (0.034457102018177234 + 
            0.014654635342927666*lm + 0.009289126197607094*lm^2)*NL + 
          (-0.0071540046315790315 + 0.014654635342927666*lm + 
            0.009289126197607094*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.04900882010071102 - 0.1440255721539421*lm - 
          0.050611518836207535*lm^2) + CF^2*(0.03405297376100152 + 
          0.13631652880296563*lm + 0.16563769800940648*lm^2) + 
        CF*((0.024758159938139193 + 0.014474711239445583*lm + 
            0.009202094333855914*lm^2)*NM + (0.034087246893970774 + 
            0.014474711239445583*lm + 0.009202094333855914*lm^2)*NL + 
          (-0.007069700473589492 + 0.014474711239445583*lm + 
            0.009202094333855914*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.048244574533166974 - 0.14242878338929954*lm - 
          0.05013415292397573*lm^2) + CF^2*(0.033631574265386 + 
          0.13425075809965337*lm + 0.1640754095693751*lm^2) + 
        CF*((0.02428506929513101 + 0.014294850848704705*lm + 
            0.009115300531631952*lm^2)*NM + (0.033717859297100805 + 
            0.014294850848704705*lm + 0.009115300531631952*lm^2)*NL + 
          (-0.00698534193619939 + 0.014294850848704705*lm + 
            0.009115300531631952*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.0474754841600247 - 0.14083473853505543*lm - 
          0.04965826440942944*lm^2) + CF^2*(0.033208155088377656 + 
          0.13218418733825593*lm + 0.1625179562490418*lm^2) + 
        CF*((0.023816278198316738 + 0.014115147473613183*lm + 
            0.009028775347168989*lm^2)*NM + (0.03334914140088269 + 
            0.014115147473613183*lm + 0.009028775347168989*lm^2)*NL + 
          (-0.006900966437599308 + 0.014115147473613183*lm + 
            0.009028775347168989*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.04670236542511066 - 0.13924413091322*lm - 
          0.0491840120317973*lm^2) + CF^2*(0.032782971685582196 + 
          0.13011803474516928*lm + 0.16096585755860934*lm^2) + 
        CF*((0.023351958587715972 + 0.013935690439673682*lm + 
            0.008942547642144964*lm^2)*NM + (0.032981285075357414 + 
            0.013935690439673682*lm + 0.008942547642144964*lm^2)*NL + 
          (-0.006816610002270019 + 0.013935690439673682*lm + 
            0.008942547642144964*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.04592600288151812 - 0.1376576210454214*lm - 
          0.048711545592212205*lm^2) + CF^2*(0.032356285012453155 + 
          0.1280534703688008*lm + 0.15941960375633085*lm^2) + 
        CF*((0.022892268835584442 + 0.013756565177002718*lm + 
            0.008856644653129492*lm^2)*NM + (0.03261447219113349 + 
            0.013756565177002718*lm + 0.008856644653129492*lm^2)*NL + 
          (-0.006732307290770702 + 0.013756565177002718*lm + 
            0.008856644653129492*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.04514714942304692 - 0.13607583759102862*lm - 
          0.04824100632246223*lm^2) + CF^2*(0.03192835998596959 + 
          0.1259916167087197*lm + 0.15787965705533094*lm^2) + 
        CF*((0.02243735430907632 + 0.01357785330556766*lm + 
            0.008771092058629498*lm^2)*NM + (0.032248874925506425 + 
            0.01357785330556766*lm + 0.008771092058629498*lm^2)*NL + 
          (-0.00664809162976326 + 0.01357785330556766*lm + 
            0.008771092058629498*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.04436652660466137 - 0.13449937828332717*lm - 
          0.047772527240838206*lm^2) + CF^2*(0.03149946407317691 + 
          0.12393354942385258*lm + 0.15634645278819775*lm^2) + 
        CF*((0.021987347922653565 + 0.013399632723055605*lm + 
            0.008685914043788764*lm^2)*NM + (0.03188465606947229 + 
            0.013399632723055605*lm + 0.008685914043788764*lm^2)*NL + 
          (-0.006563995042193975 + 0.013399632723055605*lm + 
            0.008685914043788764*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.043584825040596464 - 0.13292881086122862*lm - 
          0.04730623349539323*lm^2) + CF^2*(0.031069865999956266 + 
          0.12188029810939308*lm + 0.15482040053037785*lm^2) + 
        CF*((0.021542370679052972 + 0.013221977694843135*lm + 
            0.008601133362798769*lm^2)*NM + (0.03152196933441584 + 
            0.013221977694843135*lm + 0.008601133362798769*lm^2)*NL + 
          (-0.006480048277560272 + 0.013221977694843135*lm + 
            0.008601133362798769*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.04280270486977193 - 0.1313646739942806*lm - 
          0.046842242694935816*lm^2) + CF^2*(0.030639834573439183 + 
          0.11983284713298778*lm + 0.1533018851834263*lm^2) + 
        CF*((0.0211025321980705 + 0.013044958945586528*lm + 
            0.00851677139907924*lm^2)*NM + (0.03116095965740189 + 
            0.013044958945586528*lm + 0.00851677139907924*lm^2)*NL + 
          (-0.006396280842198318 + 0.013044958945586528*lm + 
            0.00851677139907924*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.04202079627915664 - 0.12980747819900484*lm - 
          0.04638066522808198*lm^2) + CF^2*(0.030209637611650356 + 
          0.1177921365215888*lm + 0.1517912680191774*lm^2) + 
        CF*((0.02066793123246986 + 0.012868643751998437*lm + 
            0.008432848223287633*lm^2)*NM + (0.030801763504132794 + 
            0.012868643751998437*lm + 0.008432848223287633*lm^2)*NL + 
          (-0.006312721029529697 + 0.012868643751998437*lm + 
            0.008432848223287633*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.04123970007661193 - 0.12825770674482903*lm - 
          0.045921604570694156*lm^2) + CF^2*(0.029779540974123418 + 
          0.11575906289112622*lm + 0.15028888768590815*lm^2) + 
        CF*((0.020238656170516064 + 0.012693096036419852*lm + 
            0.008349382649217118*lm^2)*NM + (0.030444509168756007 + 
            0.012693096036419852*lm + 0.008349382649217118*lm^2)*NL + 
          (-0.006229395950213106 + 0.012693096036419852*lm + 
            0.008349382649217118*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.0404599883055607 - 0.12671581654809488*lm - 
          0.04546515758203561*lm^2) + CF^2*(0.029349807687430084 + 
          0.11373448041185992*lm + 0.1487950611775711*lm^2) + 
        CF*((0.01981478552469806 + 0.012518376460835458*lm + 
            0.00826639228764284*lm^2)*NM + (0.030089317069814814 + 
            0.012518376460835458*lm + 0.00826639228764284*lm^2)*NL + 
          (-0.006146331562152966 + 0.012518376460835458*lm + 
            0.00826639228764284*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.039682204894572096 - 0.12518223905282377*lm - 
          0.04501141478996848*lm^2) + CF^2*(0.02892069715976174 + 
          0.11171920180292115*lm + 0.14731008476716956*lm^2) + 
        CF*((0.01939638840635338 + 0.012344542521016574*lm + 
            0.008183893598176088*lm^2)*NM + (0.029736300041734182 + 
            0.012344542521016574*lm + 0.008183893598176088*lm^2)*NL + 
          (-0.006063552700313387 + 0.012344542521016574*lm + 
            0.008183893598176088*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.038906866335634484 - 0.12365738109710014*lm - 
          0.04456046066552173*lm^2) + CF^2*(0.028492464478919014 + 
          0.10971399935015497*lm + 0.14583423490534383*lm^2) + 
        CF*((0.018983524985985576 + 0.012171648640509047*lm + 
            0.008101901939185769*lm^2)*NM + (0.02938556362132211 + 
            0.012171648640509047*lm + 0.008101901939185769*lm^2)*NL + 
          (-0.005981083106305263 + 0.012171648640509047*lm + 
            0.008101901939185769*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.03813446238551408 - 0.12214162576409847*lm - 
          0.044112373887153125*lm^2) + CF^2*(0.028065359788289664 + 
          0.10771960594192843*lm + 0.14436776908522841*lm^2) + 
        CF*((0.018576246939113278 + 0.011999746264213875*lm + 
            0.008020431615846021*lm^2)*NM + (0.029037206328846953 + 
            0.011999746264213875*lm + 0.008020431615846021*lm^2)*NL + 
          (-0.0058989454577004635 + 0.011999746264213875*lm + 
            0.008020431615846021*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.03736545678516024 - 0.12063533321692657*lm - 
          0.04366722759502528*lm^2) + CF^2*(0.027639627735609653 + 
          0.10573671611807992*lm + 0.1429109266746282*lm^2) + 
        CF*((0.01817459787769944 + 0.011828883951336171*lm + 
            0.007939495926368233*lm^2)*NM + (0.02869131994332282 + 
            0.011828883951336171*lm + 0.007939495926368233*lm^2)*NL + 
          (-0.005817161397044867 + 0.011828883951336171*lm + 
            0.007939495926368233*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.03660028799264857 - 0.11913884151659465*lm - 
          0.04322508963561207*lm^2) + CF^2*(0.027215506989551604 + 
          0.10376598712765465*lm + 0.1414639297165486*lm^2) + 
        CF*((0.017778613766996194 + 0.011659107467503673*lm + 
            0.007859107206474921*lm^2)*NM + (0.028347989771699524 + 
            0.011659107467503673*lm + 0.007859107206474921*lm^2)*NL + 
          (-0.005735751560538189 + 0.011659107467503673*lm + 
            0.007859107206474921*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.035839369925617315 - 0.11765246742254092*lm - 
          0.042786022796946495*lm^2) + CF^2*(0.026793229819392472 + 
          0.1018080399915046*lm + 0.14002698369909763*lm^2) + 
        CF*((0.017388323328065867 + 0.011490459875879324*lm + 
            0.0077792768721720905*lm^2)*NM + (0.028007294911711337 + 
            0.011490459875879324*lm + 0.0077792768721720905*lm^2)*NL + 
          (-0.005654735606357322 + 0.011490459875879324*lm + 
            0.0077792768721720905*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.03508309270959149 - 0.11617650717525585*lm - 
          0.042350085034816146*lm^2) + CF^2*(0.02637302173325214 + 
          0.09986346056622798*lm + 0.13860027829576194*lm^2) + 
        CF*((0.017003748425951 + 0.011322981627113857*lm + 
            0.0077000154608756624*lm^2)*NM + (0.02766930850819027 + 
            0.011322981627113857*lm + 0.0077000154608756624*lm^2)*NL + 
          (-0.005574132242586031 + 0.011322981627113857*lm + 
            0.0077000154608756624*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.03433182342898277 - 0.11471123726064705*lm - 
          0.04191732969020614*lm^2) + CF^2*(0.025955101170616605 + 
          0.09793280060629023*lm + 0.13718398807703827*lm^2) + 
        CF*((0.016624904443727915 + 0.01115671064800383*lm + 
            0.007621332670946571*lm^2)*NM + (0.027334098002695793 + 
            0.01115671064800383*lm + 0.007621332670946571*lm^2)*NL + 
          (-0.005493959254754148 + 0.01115671064800383*lm + 
            0.007621332670946571*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.03358590687791185 - 0.11325691515587676*lm - 
          0.041487805698283725*lm^2) + CF^2*(0.025539679245078103 + 
          0.09601657882150354*lm + 0.1357782731943831*lm^2) + 
        CF*((0.016251800642570497 + 0.01099168242873838*lm + 
            0.007543237399687951*lm^2)*NM + (0.02700172537635384 + 
            0.01099168242873838*lm + 0.007543237399687951*lm^2)*NL + 
          (-0.005414233532941539 + 0.01099168242873838*lm + 
            0.007543237399687951*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.03284566630832996 - 0.11181378005648554*lm - 
          0.041061557789212*lm^2) + CF^2*(0.025126959533445053 + 
          0.09411528192735094*lm + 0.1343832800374211*lm^2) + 
        CF*((0.015884440508175165 + 0.010827930108634264*lm + 
            0.007465737779856727*lm^2)*NM + (0.026672247385834527 + 
            0.010827930108634264*lm + 0.007465737779856727*lm^2)*NL + 
          (-0.005334971098447803 + 0.010827930108634264*lm + 
            0.007465737779856727*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.03211140417320989 - 0.1103820535846887*lm - 
          0.040638626681073646*lm^2) + CF^2*(0.02471713790757638 + 
          0.0922293656859234*lm + 0.13299914186533193*lm^2) + 
        CF*((0.015522822083600459 + 0.010665484560273464*lm + 
            0.007388841214740663*lm^2)*NM + (0.026345715792430325 + 
            0.010665484560273464*lm + 0.007388841214740663*lm^2)*NL + 
          (-0.005256187130007097 + 0.010665484560273464*lm + 
            0.007388841214740663*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.03138340286285286 - 0.10896194047879677*lm - 
          0.040219049265178844*lm^2) + CF^2*(0.024310402405508646 + 
          0.09035925593549805*lm + 0.13162597941331258*lm^2) + 
        CF*((0.015166938288990005 + 0.010504374471971249*lm + 
            0.007312554411850699*lm^2)*NM + (0.02602217758422504 + 
            0.010504374471971249*lm + 0.007312554411850699*lm^2)*NL + 
          (-0.005177895989538216 + 0.010504374471971249*lm + 
            0.007312554411850699*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.030661925432600583 - 0.10755362926377102*lm - 
          0.03980285878402441*lm^2) + CF^2*(0.02390693313863507 + 
          0.08850534960702289*lm + 0.13026390147498898*lm^2) + 
        CF*((0.01481677722835302 + 0.010344626428514702*lm + 
            0.0072368834152771655*lm^2)*NM + (0.025701675191369247 + 
            0.010344626428514702*lm + 0.0072368834152771655*lm^2)*NL + 
          (-0.005100111247413748 + 0.010344626428514702*lm + 
            0.0072368834152771655*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.029947216320465587 - 0.1061572929029758*lm - 
          0.03939008500216428*lm^2) + CF^2*(0.023506902231887315 + 
          0.08666801572599032*lm + 0.12891300546162857*lm^2) + 
        CF*((0.014472322483741017 + 0.010186264990122875*lm + 
            0.007161833636757142*lm^2)*NM + (0.025384246694499856 + 
            0.010186264990122875*lm + 0.007161833636757142*lm^2)*NL + 
          (-0.005022845707259292 + 0.010186264990122875*lm + 
            0.007161833636757142*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.02923950205339645 - 0.10477308943123698*lm - 
          0.038980754370244355*lm^2) + CF^2*(0.023110473794054755 + 
          0.08484759639838113*lm + 0.12757337793898152*lm^2) + 
        CF*((0.014133553397140598 + 0.010029312769589849*lm + 
            0.007087409885498973*lm^2)*NM + (0.025069926026361045 + 
            0.010029312769589849*lm + 0.007087409885498973*lm^2)*NL + 
          (-0.004946111430242982 + 0.010029312769589849*lm + 
            0.007087409885498973*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.02853899194107715 - 0.10340116256935601*lm - 
          0.03857489018244757*lm^2) + CF^2*(0.022717803915550856 + 
          0.08304440777954113*lm + 0.1262450951425557*lm^2) + 
        CF*((0.013800445340407953 + 0.009873790507580993*lm + 
            0.00701361639680865*lm^2)*NM + (0.024758743166700427 + 
            0.009873790507580993*lm + 0.00701361639680865*lm^2)*NL + 
          (-0.0048699197588856265 + 0.009873790507580993*lm + 
            0.00701361639680865*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.027845878756326232 - 0.10204164232026591*lm - 
          0.03817251272758811*lm^2) + CF^2*(0.022329040691104796 + 
          0.08125874102501839*lm + 0.12492822347210654*lm^2) + 
        CF*((0.013472969973570992 + 0.009719717146061017*lm + 
            0.006940456859561474*lm^2)*NM + (0.0244507243305292 + 
            0.009719717146061017*lm + 0.006940456859561474*lm^2)*NL + 
          (-0.0047942813403611065 + 0.009719717146061017*lm + 
            0.006940456859561474*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.027160339401311198 - 0.10069464554704671*lm - 
          0.03777363943408633*lm^2) + CF^2*(0.021944324265016996 + 
          0.07949086322254009*lm + 0.12362281996610071*lm^2) + 
        CF*((0.013151095491842785 + 0.009567109899839757*lm + 
            0.00686793444256115*lm^2)*NM + (0.024145892149847335 + 
            0.009567109899839757*lm + 0.00686793444256115*lm^2)*NL + 
          (-0.0047192061493005096 + 0.009567109899839757*lm + 
            0.00686793444256115*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.02648251267767413 - 0.09936027023476664*lm - 
          0.03737828427741079*lm^2) + CF*(0.021563800815183984 + 
          0.0777410025352194*lm + 0.12232893036243532*lm^2) + 
        0.012834781265824723*NM + 0.009415983350391437*lm*NM + 
        0.006796051686801962*lm^2*NM + 0.02384426189347238*NL + 
        0.009415983350391437*lm*NL + 0.006796051686801962*lm^2*NL - 
        0.004644703476759653*NH + 0.009415983350391437*lm*NH + 
        0.006796051686801962*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.025812595727133462 - 0.09803862240147963*lm - 
          0.03698646097771316*lm^2) + CF*(0.02118756429150943 + 
          0.07600941510609663*lm + 0.1210465995634249*lm^2) + 
        0.012524001500323035*NM + 0.009266353598814739*lm*NM + 
        0.006724811086856938*lm^2*NM + 0.023545858199315494*NL + 
        0.009266353598814739*lm*NL + 0.006724811086856938*lm^2*NL - 
        0.00457078209142673*NH + 0.009266353598814739*lm*NH + 
        0.006724811086856938*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.02515069375544299 - 0.09672977509659691*lm - 
          0.03659817829995728*lm^2) + CF*(0.020815748537218685 + 
          0.07429628198336029*lm + 0.11977585625440565*lm^2) + 
        0.012218708535060081*NM + 0.009118231898564696*lm*NM + 
        0.006654214236355869*lm^2*NM + 0.023250689146487227*NL + 
        0.009118231898564696*lm*NL + 0.006654214236355869*lm^2*NL - 
        0.004497450041606738*NH + 0.009118231898564696*lm*NH + 
        0.006654214236355869*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.02449692667341229 - 0.09543379808655238*lm - 
          0.03621344357042251*lm^2) + CF*(0.020448462636079454 + 
          0.07260178299476289*lm + 0.11851672441229186*lm^2) + 
        0.011918858995173533*NM + 0.008971629239110098*lm*NM + 
        0.0065842624673495475*lm^2*NM + 0.02295876474876234*NL + 
        0.008971629239110098*lm*NL + 0.0065842624673495475*lm^2*NL - 
        0.004424714829898564*NH + 0.008971629239110098*lm*NH + 
        0.0065842624673495475*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.023851401598781727 - 0.09415075061927583*lm - 
          0.035832261894982044*lm^2) + CF*(0.020085808229045717 + 
          0.07092607824258357*lm + 0.11726922074721396*lm^2) + 
        0.011624407113172558*NM + 0.008826555211277447*lm*NM + 
        0.006514956708178554*lm^2*NM + 0.02267009224786122*NL + 
        0.008826555211277447*lm*NL + 0.006514956708178554*lm^2*NL - 
        0.004352583392802278*NH + 0.008826555211277447*lm*NH + 
        0.006514956708178554*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.023214213431042588 - 0.09288068190020035*lm - 
          0.03545463627196028*lm^2) + CF*(0.019727879650887906 + 
          0.06926930891437322*lm + 0.11603335507187*lm^2) + 
        0.011335304916226334*NM + 0.008683018067681984*lm*NM + 
        0.006446297503992778*lm^2*NM + 0.02238467625919421*NL + 
        0.008683018067681984*lm*NL + 0.006446297503992778*lm^2*NL - 
        0.004281062120520682*NH + 0.008683018067681984*lm*NH + 
        0.006446297503992778*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.02258544540917151 - 0.09162363155210568*lm - 
          0.035080567700284795*lm^2) + CF*(0.019374764077151756 + 
          0.06763159807194817*lm + 0.11480913065547751*lm^2) + 
        0.011051502404392401*NM + 0.008541024781308684*lm*NM + 
        0.006378285036415418*lm^2*NM + 0.02210251891190465*NL + 
        0.008541024781308684*lm*NL + 0.006378285036415418*lm^2*NL - 
        0.004210156876268412*NH + 0.008541024781308684*lm*NH + 
        0.006378285036415418*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.02196516965233628 - 0.09037963005917164*lm - 
          0.03471005528311416*lm^2) + CF*(0.019026541680055385 + 
          0.06601305141865728*lm + 0.11359654456291907*lm^2) + 
        0.010772947720127523*NM + 0.008400581102269255*lm*NM + 
        0.006310919142384392*lm^2*NM + 0.021823619983372865*NL + 
        0.008400581102269255*lm*NL + 0.006310919142384392*lm^2*NL - 
        0.004139873015093087*NH + 0.008400581102269255*lm*NH + 
        0.006310919142384392*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.021353447683675596 - 0.08914869919561934*lm - 
          0.034343096327116254*lm^2) + CF*(0.018683285792042745 + 
          0.06441375804500117*lm + 0.1123955879796532*lm^2) + 
        0.010499587309415229*NM + 0.008261691612763392*lm*NM + 
        0.006244199332202955*lm^2*NM + 0.021547977028342893*NL + 
        0.008261691612763392*lm*NL + 0.006244199332202955*lm^2*NL - 
        0.00407021540221355*NH + 0.008261691612763392*lm*NH + 
        0.006244199332202955*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.020750330937295534 - 0.08793085243931971*lm - 
          0.033979686437565666*lm^2) + CF*(0.018345063075813167 + 
          0.06283379115273147*lm + 0.11120624652294218*lm^2) + 
        0.01023136607483569*NM + 0.00812435978027434*lm*NM + 
        0.006178124806830122*lm^2*NM + 0.02127558550283285*NL + 
        0.00812435978027434*lm*NL + 0.006178124806830122*lm^2*NL - 
        0.004001188430880671*NH + 0.00812435978027434*lm*NH + 
        0.006178124806830122*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.020155861248661193 - 0.0867260953707505*lm - 
          0.03361981960942262*lm^2) + CF*(0.018011933699741637 + 
          0.061273208757600665*lm + 0.11002850053992858*lm^2) + 
        0.0099682275208949*NM + 0.007988588009030394*lm*NM + 
        0.006112694474440477*lm^2*NM + 0.021006438882988518*NL + 
        0.007988588009030394*lm*NL + 0.006112694474440477*lm^2*NL - 
        0.003932796039766658*NH + 0.007988588009030394*lm*NH + 
        0.006112694474440477*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.019570071328593217 - 0.08553442605768231*lm - 
          0.033263488314549935*lm^2) + CF*(0.017683951517693267 + 
          0.059732054370972704*lm + 0.10886232539307251*lm^2) + 
        0.009710113891921333*NM + 0.007854377689765393*lm*NM + 
        0.006047906966281806*lm^2*NM + 0.020740528779038186*NL + 
        0.007854377689765393*lm*NL + 0.006047906966281806*lm^2*NL - 
        0.0038650417298891782*NH + 0.007854377689765393*lm*NH + 
        0.006047906966281806*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.018992985221106234 - 0.08435583542597351*lm - 
          0.03291068358521903*lm^2) + CF*(0.017361164252318255 + 
          0.05821035766053775*lm + 0.1077076917334441*lm^2) + 
        0.009456966302829502*NM + 0.007721729247812268*lm*NM + 
        0.005983760651858005*lm^2*NM + 0.020477845044504835*NL + 
        0.007721729247812268*lm*NL + 0.005983760651858005*lm^2*NL - 
        0.003797928581076917*NH + 0.007721729247812268*lm*NH + 
        0.005983760651858005*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.018424618745350004 - 0.08319030761685195*lm - 
          0.0325613950940503*lm^2) + CF*(0.01704361368099121 + 
          0.056708135090405634*lm + 0.10656456576234644*lm^2) + 
        0.009208724863041001*NM + 0.007590642189564748*lm*NM + 
        0.0059202536534636915*lm^2*NM + 0.020218375880829524*NL + 
        0.007590642189564748*lm*NL + 0.0059202536534636915*lm^2*NL - 
        0.0037314592679835263*NH + 0.007590642189564748*lm*NH + 
        0.0059202536534636915*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.01786497992193449 - 0.08203782033105847*lm - 
          0.03221561123052793*lm^2) + CF*(0.016731335823630795 + 
          0.05522539054087837*lm + 0.10543290948172777*lm^2) + 
        0.008965328793844858*NM + 0.007461115147343011*lm*NM + 
        0.005857383860095987*lm^2*NM + 0.01996210793755749*NL + 
        0.007461115147343011*lm*NL + 0.005857383860095987*lm^2*NL - 
        0.0036656360756571324*NH + 0.007461115147343011*lm*NH + 
        0.005857383860095987*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.01731406938393743 - 0.08089834516022422*lm - 
          0.03187331917422411*lm^2) + CF*(0.016424361131703067 + 
          0.053762115908225404*lm + 0.10431268093382437*lm^2) + 
        0.008726716539470268*NM + 0.007333145922699649*lm*NM + 
        0.005795148940768021*lm^2*NM + 0.019709026408235818*NL + 
        0.007333145922699649*lm*NL + 0.005795148940768021*lm^2*NL - 
        0.0036004609146728203*NH + 0.007333145922699649*lm*NH + 
        0.005795148940768021*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.016771880772907703 - 0.07977184790584933*lm - 
          0.031534504964862556*lm^2) + CF*(0.016122714677774694 + 
          0.05231829168480519*lm + 0.10320383443045926*lm^2) + 
        0.008492825872136128*NM + 0.007206731528202758*lm*NM + 
        0.005733546357247737*lm^2*NM + 0.019459115122168778*NL + 
        0.007206731528202758*lm*NL + 0.005733546357247737*lm^2*NL - 
        0.0035359353358356896*NH + 0.007206731528202758*lm*NH + 
        0.005733546357247737*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.016238401120189958 - 0.07865828888624647*lm - 
          0.0311991535693464*lm^2) + CF*(0.01582641634504067 + 
          0.05089388751989369*lm + 0.1021063207724064*lm^2) + 
        0.00826359399133322*NM + 0.00708186822773325*lm*NM + 
        0.0056725733762448*lm^2*NM + 0.019212356632173952*NL + 
        0.00708186822773325*lm*NL + 0.0056725733762448*lm^2*NL - 
        0.0034720605444622313*NH + 0.00708186822773325*lm*NH + 
        0.0056725733762448*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.015713611213905784 - 0.07755762323180725*lm - 
          0.030867248945871048*lm^2) + CF*(0.015535481016305471 + 
          0.0494888627615947*lm + 0.10102008745921434*lm^2) + 
        0.008038957617586377*NM + 0.006958551575333636*lm*NM + 
        0.0056122270810674635*lm^2*NM + 0.018968732298479295*NL + 
        0.006958551575333636*lm*NL + 0.0056122270810674635*lm^2*NL - 
        0.003408837414247912*NH + 0.006958551575333636*lm*NH + 
        0.0056122270810674635*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.015197485951934634 - 0.07646980116894425*lm - 
          0.030538774105237733*lm^2) + CF*(0.015249918761947336 + 
          0.048103166980218985*lm + 0.09994507888986895*lm^2) + 
        0.007818853080935691*NM + 0.006836776452645594*lm*NM + 
        0.0055525043827704965*lm^2*NM + 0.018728222368898102*NL + 
        0.006836776452645594*lm*NL + 0.0055525043827704965*lm^2*NL - 
        0.0033462665007289506*NH + 0.006836776452645594*lm*NH + 
        0.0055525043827704965*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.014689994681243611 - 0.07539476829305596*lm - 
          0.030213711169479584*lm^2) + CF*(0.014969735026442214 + 
          0.04673674047352903*lm + 0.09888123655466045*lm^2) + 
        0.007603216404367539*NM + 0.0067165371049735766*lm*NM + 
        0.00549340203081447*lm^2*NM + 0.018490806055415594*NL + 
        0.0067165371049735766*lm*NL + 0.00549340203081447*lm^2*NL - 
        0.003284348054346346*NH + 0.0067165371049735766*lm*NH + 
        0.00549340203081447*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.014191101523919607 - 0.074332465830855*lm - 
          0.029892041427907454*lm^2) + CF*(0.014694930813067657 + 
          0.04538951475425376*lm + 0.09782849921860622*lm^2) + 
        0.0073919833824181765*NM + 0.006597827176011579*lm*NM + 
        0.005434916623255901*lm^2*NM + 0.018256461607317625*NL + 
        0.006597827176011579*lm*NL + 0.005434916623255901*lm^2*NL - 
        0.003223082033120295*NH + 0.006597827176011579*lm*NH + 
        0.005434916623255901*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.013700765690259924 - 0.07328283089239433*lm - 
          0.02957374539067891*lm^2) + CF*(0.014425502866447391 + 
          0.044061413020283886*lm + 0.09678680309676735*lm^2) + 
        0.00718508965516472*NM + 0.006480639741269966*lm*NM + 
        0.005377044616487075*lm^2*NM + 0.018025166380988635*NL + 
        0.006480639741269966*lm*NL + 0.005377044616487075*lm^2*NL - 
        0.0031624681149431465*NH + 0.006480639741269966*lm*NH + 
        0.005377044616487075*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.013218941779279072 - 0.07224579671311944*lm - 
          0.029258802839989814*lm^2) + CF*(0.014161443852634839 + 
          0.04275235060796246*lm + 0.09575608202178484*lm^2) + 
        0.006982470777810613*NM + 0.00636496734023895*lm*NM + 
        0.005319782334543602*lm^2*NM + 0.01779689690650265*NL + 
        0.00636496734023895*lm*NL + 0.005319782334543602*lm^2*NL - 
        0.0031025057094990816*NH + 0.00636496734023895*lm*NH + 
        0.005319782334543602*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.012745580066989505 - 0.07122129288626708*lm - 
          0.02894719287898411*lm^2) + CF*(0.013902742536468617 + 
          0.041462235428888355*lm + 0.094736267603948*lm^2) + 
        0.006784062286065074*NM + 0.006250802007324964*lm*NM + 
        0.005263125977997111*lm^2*NM + 0.017571628951127766*NL + 
        0.006250802007324964*lm*NL + 0.005263125977997111*lm^2*NL - 
        0.0030431939698187063*NH + 0.006250802007324964*lm*NH + 
        0.005263125977997111*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.012280626782813229 - 0.07020924558592521*lm - 
          0.028638893978473846*lm^2) + CF*(0.013649383955965171 + 
          0.040190968390651546*lm + 0.09372728938409622*lm^2) + 
        0.00658979975750864*NM + 0.006138135301595762*lm*NM + 
        0.00520707163244979*lm^2*NM + 0.017349337579861124*NL + 
        0.006138135301595762*lm*NL + 0.00520707163244979*lm^2*NL - 
        0.0029845318034767187*NH + 0.006138135301595762*lm*NH + 
        0.00520707163244979*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.011824024374479325 - 0.0692095777810609*lm - 
          0.028333884021557884*lm^2) + CF*(0.013401349593543452 + 
          0.03893844380191946*lm + 0.09272907497964399*lm^2) + 
        0.00639961886912971*NM + 0.00602695833536958*lm*NM + 
        0.005151615276646889*lm^2*NM + 0.017129997213108126*NL + 
        0.00602695833536958*lm*NL + 0.005151615276646889*lm^2*NL - 
        0.0029265178834408058*NH + 0.00602695833536958*lm*NH + 
        0.005151615276646889*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.011375711761759673 - 0.06822220944081614*lm - 
          0.02803214034622444*lm^2) + CF*(0.013158617543903952 + 
          0.03770454976229271*lm + 0.09174155022400726*lm^2) + 
        0.006213455451209948*NM + 0.00591726180168323*lm*NM + 
        0.005096752790222626*lm^2*NM + 0.01691358168161622*NL + 
        0.00591726180168323*lm*NL + 0.005096752790222626*lm^2*NL - 
        0.0028691506585798677*NH + 0.00591726180168323*lm*NH + 
        0.005096752790222626*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.010935624579391703 - 0.06724705773136443*lm - 
          0.027733639786019185*lm^2) + CF*(0.012921162678409703 + 
          0.036489168537346656*lm + 0.09076463929969915*lm^2) + 
        0.006031245537729584*NM + 0.00580903600067339*lm*NM + 
        0.0050424799610943975*lm^2*NM + 0.01670006427877022*NL + 
        0.00580903600067339*lm*NL + 0.0050424799610943975*lm^2*NL - 
        0.0028124283638396265*NH + 0.00580903600067339*lm*NH + 
        0.0050424799610943975*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.010503695409532804 - 0.06628403720461355*lm - 
          0.027438358708857677*lm^2) + CF*(0.012688956805840174 + 
          0.03529217691927245*lm + 0.0897982648653524*lm^2) + 
        0.0058529254134569685*NM + 0.005702270864904819*lm*NM + 
        0.004988792492519578*lm^2*NM + 0.016489417810353*NL + 
        0.005702270864904819*lm*NL + 0.004988792492519578*lm^2*NL - 
        0.0027563490300936064*NH + 0.005702270864904819*lm*NH + 
        0.004988792492519578*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.01007985400408629 - 0.06533305997903296*lm - 
          0.02714627305405768*lm^2) + CF*(0.012461968829410378 + 
          0.03411344657352769*lm + 0.08884234817691605*lm^2) + 
        0.005678431657880301*NM + 0.005596955983678596*lm*NM + 
        0.004935686009828669*lm^2*NM + 0.01628161464187192*NL + 
        0.005596955983678596*lm*NL + 0.004935686009828669*lm^2*NL - 
        0.002700910493677416*NH + 0.005596955983678596*lm*NH + 
        0.004935686009828669*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.009664027497233536 - 0.06439403591287665*lm - 
          0.026857358367664095*lm^2) + CF*(0.012240164899967255 + 
          0.03295284437190261*lm + 0.08789680920326431*lm^2) + 
        0.005507701186133163*NM + 0.005493080626352825*lm*NM + 
        0.004883156066848017*lm^2*NM + 0.016076626743548372*NL + 
        0.005493080626352825*lm*NL + 0.004883156066848017*lm^2*NL - 
        0.0026461104056141604*NH + 0.005493080626352825*lm*NH + 
        0.004883156066848017*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.009256140608501235 - 0.06346687277006559*lm - 
          0.026571589836136382*lm^2) + CF*(0.012023508565293363 + 
          0.031810232712402735*lm + 0.08696156673644634*lm^2) + 
        0.005340671287059411*NM + 0.005390633764707638*lm*NM + 
        0.0048311981520247965*lm^2*NM + 0.015874425733064475*NL + 
        0.005390633764707638*lm*NL + 0.0048311981520247965*lm^2*NL - 
        0.0025919462405387425*NH + 0.005390633764707638*lm*NH + 
        0.0048311981520247965*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.00885611583668662 - 0.06255147637898624*lm - 
          0.02628894231846563*lm^2) + CF*(0.01181196091546451 + 
          0.030685469826343646*lm + 0.08603653849679661*lm^2) + 
        0.005177279658557066*NM + 0.005289604094385616*lm*NM + 
        0.004779807694266478*lm^2*NM + 0.015674982916157997*NL + 
        0.005289604094385616*lm*NL + 0.004779807694266478*lm^2*NL - 
        0.002538415305328713*NH + 0.005289604094385616*lm*NH + 
        0.004779807694266478*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.008463873644957135 - 0.061647750784455065*lm - 
          0.02600939037678584*lm^2) + CF*(0.011605480724223044 + 
          0.02957841007304751*lm + 0.08512164123311729*lm^2) + 
        0.005017464440335171*NM + 0.005189980055438082*lm*NM + 
        0.004728980068506516*lm^2*NM + 0.015478269325153421*NL + 
        0.005189980055438082*lm*NL + 0.004728980068506516*lm^2*NL - 
        0.0024855147474492213*NH + 0.005189980055438082*lm*NH + 
        0.004728980068506516*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.008079332637434352 - 0.06075559839309129*lm - 
          0.025732908305541386*lm^2) + CF*(0.011404024586342284 + 
          0.02848890422252481*lm + 0.08421679081813545*lm^2) + 
        0.0048611642442120025*NM + 0.005091749852007022*lm*NM + 
        0.004678710601007525*lm^2*NM + 0.015284255755514198*NL + 
        0.005091749852007022*lm*NL + 0.004678710601007525*lm^2*NL - 
        0.002433241563019525*NH + 0.005091749852007022*lm*NH + 
        0.004678710601007525*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.007702409727565125 - 0.05987492011233388*lm - 
          0.025459470159270334*lm^2) + CF*(0.011207547050970169 + 
          0.027416799726518018*lm + 0.0833219023394302*lm^2) + 
        0.004708318182077747*NM + 0.004994901471171704*lm*NM + 
        0.004628994574412788*lm^2*NM + 0.01509291280049819*NL + 
        0.004994901471171704*lm*NL + 0.004628994574412788*lm^2*NL - 
        0.002381592604608391*NH + 0.004994901471171704*lm*NH + 
        0.004628994574412788*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.007333020298575859 - 0.05900561548333136*lm - 
          0.025189049779060807*lm^2) + CF*(0.01101600075095155 + 
          0.02636194097827695*lm + 0.08243689018601719*lm^2) + 
        0.004558865891639522*NM + 0.004899422700988324*lm*NM + 
        0.00457982723255651*lm^2*NM + 0.014904210883995548*NL + 
        0.004899422700988324*lm*NL + 0.00457982723255651*lm^2*NL - 
        0.0023305645887656216*NH + 0.004899422700988324*lm*NH + 
        0.00457982723255651*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.006971078356298688 - 0.058147582807926576*lm - 
          0.024921620817735433*lm^2) + CF*(0.010829336528138956 + 
          0.025324169561428456*lm + 0.08156166813077051*lm^2) + 
        0.004412747560061693*NM + 0.004805301147750352*lm*NM + 
        0.004531203785042806*lm^2*NM + 0.01471812029162543*NL + 
        0.004805301147750352*lm*NL + 0.004531203785042806*lm^2*NL - 
        0.002280154103296806*NH + 0.004805301147750352*lm*NH + 
        0.004531203785042806*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.006616496674651011 - 0.05730071926995192*lm - 
          0.024657156763816728*lm^2) + CF*(0.010647503554710934 + 
          0.024303324488295572*lm + 0.08069614940885474*lm^2) + 
        0.004269903945609583*NM + 0.0047125242524964795*lm*NM + 
        0.004483119411603041*lm^2*NM + 0.014534611200165252*NL + 
        0.0047125242524964795*lm*NL + 0.004483119411603041*lm^2*NL - 
        0.0022303576142882918*NH + 0.0047125242524964795*lm*NH + 
        0.004483119411603041*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.0062691869340425815 - 0.05646492105104373*lm - 
          0.024395630964324174*lm^2) + CF*(0.010470449450525521 + 
          0.023299242428013667*lm + 0.07984024679233366*lm^2) + 
        0.004130276397400055*NM + 0.00462107930679244*lm*NM + 
        0.004435569266240759*lm^2*NM + 0.014353653705383511*NL + 
        0.00462107930679244*lm*NL + 0.004435569266240759*lm^2*NL - 
        0.0021811714728892273*NH + 0.00462107930679244*lm*NH + 
        0.004435569266240759*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.005929059852976929 - 0.05564008344117844*lm - 
          0.02413701664645175*lm^2) + CF*(0.010298120396543974 + 
          0.022311757924783557*lm + 0.07899387266111482*lm^2) + 
        0.003993806873357954*NM + 0.004530953467812204*lm*NM + 
        0.004388548481173046*lm^2*NM + 0.01417521784834464*NL + 
        0.004530953467812204*lm*NL + 0.004388548481173046*lm^2*NL - 
        0.002132591921857422*NH + 0.004530953467812204*lm*NH + 
        0.004388548481173046*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.005596025313106558 - 0.054826100944126675*lm - 
          0.023881286938172718*lm^2) + CF*(0.010130461244366602 + 
          0.021340703606593507*lm + 0.07815693907038344*lm^2) + 
        0.0038604379564730843*NM + 0.004442133772743394*lm*NM + 
        0.004342052170576858*lm^2*NM + 0.013999273640251842*NL + 
        0.004442133772743394*lm*NL + 0.004342052170576858*lm^2*NL - 
        0.0020846151018756244*NH + 0.004442133772743394*lm*NH + 
        0.004342052170576858*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.005269992477993979 - 0.054022867378015225*lm - 
          0.023628414887816692*lm^2) + CF*(0.009967415621928632 + 
          0.020385910384734373*lm + 0.07732935781467282*lm^2) + 
        0.0037301128694482567*NM + 0.004354607152541054*lm*NM + 
        0.00429607543414849*lm^2*NM + 0.013825791085891407*NL + 
        0.004354607152541054*lm*NL + 0.00429607543414849*lm^2*NL - 
        0.0020372370576446997*NH + 0.004354607152541054*lm*NH + 
        0.00429607543414849*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.004950869905823339 - 0.05323027597118101*lm - 
          0.023378373482662133*lm^2) + CF*(0.009808926035409334 + 
          0.019447207644424053*lm + 0.07651104048871243*lm^2) + 
        0.0036027754878249106*NM + 0.004268360445053244*lm*NM + 
        0.004250613360484024*lm^2*NM + 0.013654740205739622*NL + 
        0.004268360445053244*lm*NL + 0.004250613360484024*lm^2*NL - 
        0.00199045374376006*NH + 0.004268360445053244*lm*NH + 
        0.004250613360484024*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.004638565656300121 - 0.05244821945349497*lm - 
          0.023131135666585777*lm^2) + CF*(0.009654933967412382 + 
          0.018524423426849578*lm + 0.07570189854518981*lm^2) + 
        0.0034783703516689927*NM + 0.004183380407541219*lm*NM + 
        0.004205661030288323*lm^2*NM + 0.013486091056791123*NL + 
        0.004183380407541219*lm*NL + 0.004205661030288323*lm^2*NL - 
        0.0019442610303775584*NH + 0.004183380407541219*lm*NH + 
        0.004205661030288323*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.004332987391969182 - 0.05167659014332835*lm - 
          0.02288667435680879*lm^2) + CF*(0.009505379971479518 + 
          0.017617384602927166*lm + 0.07490184334955603*lm^2) + 
        0.0033568426758960584*NM + 0.004099653728616344*lm*NM + 
        0.00416121351941978*lm^2*NM + 0.01331981375216526*NL + 
        0.004099653728616344*lm*NL + 0.00416121351941978*lm^2*NL - 
        0.0018986547086749415*NH + 0.004099653728616344*lm*NH + 
        0.00416121351941978*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.0040340424741742995 - 0.05091528003032804*lm - 
          0.02264496245977791*lm^2) + CF*(0.00936020376300323 + 
          0.016725917039072696*lm + 0.07411078623200044*lm^2) + 
        0.0032381383593109987*NM + 0.004017167039615168*lm*NM + 
        0.004117265901777802*lm^2*NM + 0.013155878479544917*NL + 
        0.004017167039615168*lm*NL + 0.004117265901777802*lm^2*NL - 
        0.0018536304961148126*NH + 0.004017167039615168*lm*NH + 
        0.004117265901777802*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.003741638053875354 - 0.05016418085416208*lm - 
          0.022405972886218296*lm^2) + CF*(0.009219344306607175 + 
          0.01584984575526716*lm + 0.07332863853671442*lm^2) + 
        0.003122203992434377*NM + 0.003935906925433498*lm*NM + 
        0.00407381325203969*lm^2*NM + 0.012994255518500076*NL + 
        0.003935906925433498*lm*NL + 0.00407381325203969*lm^2*NL - 
        0.001809184041514934*NH + 0.003935906925433498*lm*NH + 
        0.00407381325203969*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0034556811575323482 - 0.0494231841793913*lm - 
          0.022169678565393265*lm^2) + CF*(0.009082739900065806 + 
          0.014988995075693809*lm + 0.07255531166855977*lm^2) + 
        0.003008986864184072*NM + 0.0038558599348396468*lm*NM + 
        0.004030850648253321*lm^2*NM + 0.012834915256746448*NL + 
        0.0038558599348396468*lm*NL + 0.004030850648253321*lm^2*NL - 
        0.0017653109299315625*NH + 0.0038558599348396468*lm*NH + 
        0.004030850648253321*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.003176078768258687 - 0.04869218146661775*lm - 
          0.021936052458604846*lm^2) + CF*(0.008950328254836772 + 
          0.014143188772216101*lm + 0.07179071713725223*lm^2) + 
        0.002898434967477764*NM + 0.003777012590286404*lm*NM + 
        0.00398837317429179*lm^2*NM + 0.012677828205387497*NL + 
        0.003777012590286404*lm*NL + 0.00398837317429179*lm^2*NL - 
        0.001722006687361385*NH + 0.003777012590286404*lm*NH + 
        0.00398837317429179*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.002902737902439432 - 0.04797106414005528*lm - 
          0.02170506757196755*lm^2) + CF*(0.008822046573281573 + 
          0.013312250200957707*lm + 0.07103476659916654*lm^2) + 
        0.0027904970038187646*NM + 0.0036993513972407004*lm*NM + 
        0.003946375922175918*lm^2*NM + 0.012522965013186239*NL + 
        0.0036993513972407004*lm*NL + 0.003946375922175918*lm^2*NL - 
        0.0016792667852674906*NH + 0.0036993513972407004*lm*NH + 
        0.003946375922175918*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.002635565682003709 - 0.0472597236516631*lm - 
          0.021476696968486565*lm^2) + CF*(0.008697831622651373 + 
          0.012496002432238418*lm + 0.07028737189686513*lm^2) + 
        0.0026851223869247876*NM + 0.0036228628530492924*lm*NM + 
        0.003904853994270285*lm^2*NM + 0.012370296479911452*NL + 
        0.0036228628530492924*lm*NL + 0.003904853994270285*lm^2*NL - 
        0.0016370866449346895*NH + 0.0036228628530492924*lm*NH + 
        0.003904853994270285*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.0023744694025340167 - 0.04655805154197799*lm - 
          0.02125091377947028*lm^2) + CF*(0.008577619805916033 + 
          0.011694268374112332*lm + 0.06954844509644818*lm^2) + 
        0.0025822612454564652*NM + 0.0035475334553582484*lm*NM + 
        0.0038638025053582326*lm^2*NM + 0.012219793568801053*NL + 
        0.0035475334553582484*lm*NL + 0.0038638025053582326*lm^2*NL - 
        0.001595461641659359*NH + 0.0035475334553582484*lm*NH + 
        0.0038638025053582326*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.002119356597388919 - 0.04586593949777634*lm - 
          0.021027691215305882*lm^2) + CF*(0.008461347229515291 + 
          0.010906870889747271*lm + 0.06881789852281925*lm^2) + 
        0.0024818644248997307*NM + 0.0034733497101034285*lm*NM + 
        0.0038232165846010698*lm^2*NM + 0.012071427418183758*NL + 
        0.0034733497101034285*lm*NL + 0.0038232165846010698*lm^2*NL - 
        0.001554387108778873*NH + 0.0034733497101034285*lm*NH + 
        0.0038232165846010698*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.0018701350980094543 - 0.045183279406692506*lm - 
          0.020807002575625573*lm^2) + CF*(0.008348949768111538 + 
          0.010133632908877265*lm + 0.06809564479295642*lm^2) + 
        0.0023838834886536274*NM + 0.003400298139088588*lm*NM + 
        0.0037830913773864677*lm^2*NM + 0.01192516935229845*NL + 
        0.003400298139088588*lm*NL + 0.0037830913773864677*lm^2*NL - 
        0.0015138583415455521*NH + 0.003400298139088588*lm*NH + 
        0.0037830913773864677*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.001626713090573617 - 0.04450996340891574*lm - 
          0.020588821258889823*lm^2) + CF*(0.008240363126424044 + 
          0.009374377533552773*lm + 0.06738159684727578*lm^2) + 
        0.0022882707183726394*NM + 0.0033283652871672004*lm*NM + 
        0.003743422047070877*lm^2*NM + 0.011780990891349083*NL + 
        0.0033283652871672004*lm*NL + 0.003743422047070877*lm^2*NL - 
        0.0014738706008499383*NH + 0.0033283652871672004*lm*NH + 
        0.003743422047070877*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.001388999169157413 - 0.04384588394608352*lm - 
          0.02037312077141311*lm^2) + CF*(0.00813552289822452 + 
          0.008628928138406404*lm + 0.06667566797917017*lm^2) + 
        0.0021949791136102845*NM + 0.0032575377290435573*lm*NM + 
        0.003704203776620565*lm^2*NM + 0.011638863760831392*NL + 
        0.0032575377290435573*lm*NL + 0.003704203776620565*lm^2*NL - 
        0.0014344191167980852*NH + 0.0032575377290435573*lm*NH + 
        0.003704203776620565*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0011569023855553054 - 0.04319093380748497*lm - 
          0.020159874735856426*lm^2) + CF*(0.008034364622573837 + 
          0.00789710846564506*lm + 0.06597777186280285*lm^2) + 
        0.0021039623908084503*NM + 0.0031878020757081776*lm*NM + 
        0.0036654317701557133*lm^2*NM + 0.011498759900166234*NL + 
        0.0031878020757081776*lm*NL + 0.0036654317701557133*lm^2*NL - 
        0.0013954990921474359*NH + 0.0031878020757081776*lm*NH + 
        0.0036654317701557133*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0009303322959073216 - 0.04254500617368409*lm - 
          0.019949056899209987*lm^2) + CF*(0.007936823837379425 + 
          0.007178742714972733*lm + 0.06528782257923268*lm^2) + 
        0.0020151749816747873*NM + 0.0031191449805220693*lm*NM + 
        0.0036271012544018158*lm^2*NM + 0.011360651470672917*NL + 
        0.0031191449805220693*lm*NL + 0.0036271012544018158*lm^2*NL - 
        0.0013571057056057363*NH + 0.0031191449805220693*lm*NH + 
        0.0036271012544018158*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0007091990042746995 - 0.041907994657668535*lm - 
          0.019740641140288513*lm^2) + CF*(0.007842836130352424 + 
          0.006473655628641664*lm + 0.06460573464094423*lm^2) + 
        0.001928572030988411*NM + 0.0030515531449638793*lm*NM + 
        0.0035892074800524566*lm^2*NM + 0.01122451086291447*NL + 
        0.0030515531449638793*lm*NL + 0.0035892074800524566*lm^2*NL - 
        0.0013192341149973223*NH + 0.0030515531449638793*lm*NH + 
        0.0035892074800524566*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0004934132033007055 - 0.041279793343625866*lm - 
          0.019534601476760595*lm^2) + CF*(0.007752337187443044 + 
          0.005781672571823188*lm + 0.06393142301485286*lm^2) + 
        0.0018441093938721695*NM + 0.0029850133240534905*lm*NM + 
        0.003551745723047381*lm^2*NM + 0.011090310703445537*NL + 
        0.0029850133240534905*lm*NL + 0.003551745723047381*lm^2*NL - 
        0.0012818794603010023*NH + 0.0029850133240534905*lm*NH + 
        0.003551745723047381*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.00028288621208816776 - 0.040660296823445685*lm - 
          0.019330912071732844*lm^2) + CF*(0.007665262838831866 + 
          0.005102619608483334*lm + 0.06326480314385295*lm^2) + 
        0.0017617436325678547*NM + 0.002919512331465169*lm*NM + 
        0.0035147112857696083*lm^2*NM + 0.010958023860992237*NL + 
        0.002919512331465169*lm*NL + 0.0035147112857696083*lm^2*NL - 
        0.0012450368665636448*NH + 0.002919512331465169*lm*NH + 
        0.0035147112857696083*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.00007753001142031905 - 0.040049400231042254*lm - 
          0.01912954723990853*lm^2) + CF*(0.007581549102553943 + 
          0.004436323572942147*lm + 0.06260579096697337*lm^2) + 
        0.0016814320127489003*NM + 0.0028550370443428986*lm*NM + 
        0.0034780994981651876*lm^2*NM + 0.010827623452092127*NL + 
        0.0028550370443428986*lm*NL + 0.0034780994981651876*lm^2*NL - 
        0.0012087014466934715*NH + 0.0028550370443428986*lm*NH + 
        0.0034780994981651876*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(0.0001227427235532519 - 0.03944699927458893*lm - 
          0.018930481453339768*lm^2) + CF*(0.007501132225831592 + 
          0.0037826121372897606*lm + 0.06195430293820288*lm^2) + 
        0.0016031324994033916*NM + 0.0027915744078301067*lm*NM + 
        0.003441905718789049*lm^2*NM + 0.010699082846221208*NL + 
        0.0027915744078301067*lm*NL + 0.003441905718789049*lm^2*NL - 
        0.0011728683041369481*NH + 0.0027915744078301067*lm*NH + 
        0.003441905718789049*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(0.00031801859304839716 - 0.03885299026675238*lm - 
          0.018733689346791437*lm^2) + CF*(0.00742394872419073 + 
          0.003141313874826471*lm + 0.0613102560440447*lm^2) + 
        0.0015268037523185447*NM + 0.0027291114393255553*lm*NM + 
        0.003406125335780261*lm^2*NM + 0.01057237567043376*NL + 
        0.0027291114393255553*lm*NL + 0.003406125335780261*lm^2*NL - 
        0.0011375325354430594*NH + 0.0027291114393255553*lm*NH + 
        0.003406125335780261*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(0.0005083834446833176 - 0.03826727015301128*lm - 
          0.018539145722734303*lm^2) + CF*(0.007349935418434412 + 
          0.0025122583196883594*lm + 0.06067356781985772*lm^2) + 
        0.0014524051211962249*NM + 0.0026676352324767586*lm*NM + 
        0.0033707537677698735*lm^2*NM + 0.010447475813539718*NL + 
        0.0026676352324767586*lm*NL + 0.0033707537677698735*lm^2*NL - 
        0.0011026892327186475*NH + 0.0026676352324767586*lm*NH + 
        0.0033707537677698735*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(0.0006939223477123157 - 0.037689736538141026*lm - 
          0.018346825555984124*lm^2) + CF*(0.007279029469546076 + 
          0.001895276022814566*lm + 0.06004415636503895*lm^2) + 
        0.0013798966404275667*NM + 0.0026071329609218766*lm*NM + 
        0.003335786464724386*lm^2*NM + 0.010324357429843195*NL + 
        0.0026071329609218766*lm*NL + 0.003335786464724386*lm^2*NL - 
        0.0010683334859783989*NH + 0.0026071329609218766*lm*NH + 
        0.003335786464724386*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(0.0008747195693523545 - 0.03712028771094305*lm - 
          0.018156703998002757*lm^2) + CF*(0.007211168411593646 + 
          0.0012901986044069314*lm + 0.05942194035709993*lm^2) + 
        0.0013092390235533023*NM + 0.00254759188179066*lm*NM + 
        0.003301218908727774*lm^2*NM + 0.010202994942464813*NL + 
        0.00254759188179066*lm*NL + 0.003301218908727774*lm^2*NL - 
        0.001034460385392955*NH + 0.00254759188179066*lm*NH + 
        0.003301218908727774*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(0.0010508585531024753 - 0.036558822667294454*lm - 
          0.017968756380876746*lm^2) + CF*(0.007146290182704383 + 
          0.0006968588030275171*lm + 0.05880683906468753*lm^2) + 
        0.0012403936574350227*NM + 0.0024889993389746205*lm*NM + 
        0.003267046614704863*lm^2*NM + 0.010083363046269434*NL + 
        0.0024889993389746205*lm*NL + 0.003267046614704863*lm^2*NL - 
        0.001001065023438534*NH + 0.0024889993389746205*lm*NH + 
        0.003267046614704863*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(0.0012224218989600889 - 0.036005241131590614*lm - 
          0.017782958220988104*lm^2) + CF*(0.0070843331541789265 + 
          0.00011509052147446055*lm + 0.05819877235959744*lm^2) + 
        0.0011733225961612801*NM + 0.002431342766176252*lm*NM + 
        0.0032332651310887466*lm^2*NM + 0.009965436710420024*NL + 
        0.002431342766176252*lm*NL + 0.0032332651310887466*lm^2*NL - 
        0.0009681424969513454*NH + 0.002431342766176252*lm*NH + 
        0.0032332651310887466*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(0.001389491345441975 - 0.035459443576650915*lm - 
          0.017599285222391497*lm^2) + CF*(0.007025236157811591 - 
          0.00045527113042831234*lm + 0.05759766072782671*lm^2) + 
        0.001107988554711172*NM + 0.0023746096897467625*lm*NM + 
        0.0031998700404348174*lm^2*NM + 0.009849191180577416*NL + 
        0.0023746096897467625*lm*NL + 0.0031998700404348174*lm^2*NL - 
        0.0009356879090899955*NH + 0.0023746096897467625*lm*NH + 
        0.0031998700404348174*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(0.0015521477533215337 - 0.034921331242155074*lm - 
          0.017417713279911384*lm^2) + CF*(0.006968938511482518 - 
          0.0010143897959967666*lm + 0.05700342527970998*lm^2) + 
        0.001044354902396848*NM + 0.002318787731321429*lm*NM + 
        0.003166856959983888*lm^2*NM + 0.009734601980764927*NL + 
        0.002318787731321429*lm*NL + 0.003166856959983888*lm^2*NL - 
        0.0009036963712089835*NH + 0.002318787731321429*lm*NH + 
        0.003166856959983888*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(0.001710471090997392 - 0.03439080615167484*lm - 
          0.017238218481972194*lm^2) + CF*(0.006915380043085799 - 
          0.0015624278346817282*lm + 0.056415987759181725*lm^2) + 
        0.0009823856561052297*NM + 0.002263864610261365*lm*NM + 
        0.0031342215421767627*lm^2*NM + 0.009621644914915897*NL + 
        0.002263864610261365*lm*NL + 0.0031342215421767627*lm^2*NL - 
        0.0008721630046463005*NH + 0.002263864610261365*lm*NH + 
        0.0031342215421767627*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(0.001864540421411935 - 0.03386777112836358*lm - 
          0.017060777113173952*lm^2) + CF*(0.006864501112856215 - 
          0.002099546287771542*lm + 0.055835270552205656*lm^2) + 
        0.000922045473358137*NM + 0.00220982814591015*lm*NM + 
        0.0031019594751225364*lm^2*NM + 0.009510296068121456*NL + 
        0.00220982814591015*lm*NL + 0.0031019594751225364*lm^2*NL - 
        0.0008410829424280561*NH + 0.00220982814591015*lm*NH + 
        0.0031019594751225364*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(0.002014433890441644 - 0.033352129809363654*lm - 
          0.016885365656625365*lm^2) + CF*(0.00681624263415568 - 
          0.002625904846685199*lm + 0.055261196694410285*lm^2) + 
        0.00086329964520897*NM + 0.002156666259673473*lm*NM + 
        0.0030700664830227934*lm^2*NM + 0.009400531807595027*NL + 
        0.002156666259673473*lm*NL + 0.0030700664830227934*lm^2*NL - 
        0.0008104513308929731*NH + 0.002156666259673473*lm*NH + 
        0.0030700664830227934*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(0.002160228716684355 - 0.03284378665898949*lm - 
          0.016711960796045856*lm^2) + CF*(0.006770546092779034 - 
          0.0031416618237429346*lm + 0.05469368987796826*lm^2) + 
        0.0008061140889930966*NM + 0.0021043669769296256*lm*NM + 
        0.003038538326553792*lm^2*NM + 0.00929232878336936*NL + 
        0.0021043669769296256*lm*NL + 0.003038538326553792*lm^2*NL - 
        0.0007802633312395059*NH + 0.0021043669769296256*lm*NH + 
        0.003038538326553792*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(0.002302001182571639 - 0.03234264698074165*lm - 
          0.016540539417647503*lm^2) + CF*(0.006727353564837221 - 
          0.003646974125305433*lm + 0.05413267445775547*lm^2) + 
        0.0007504553409481475*NM + 0.002052918428778398*lm*NM + 
        0.0030073708032086373*lm^2*NM + 0.009185663928741178*NL + 
        0.002052918428778398*lm*NL + 0.0030073708032086373*lm^2*NL - 
        0.0007505141209982575*NH + 0.002052918428778398*lm*NH + 
        0.0030073708032086373*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(0.0024398266267374995 - 0.03184861692820551*lm - 
          0.01637107861180745*lm^2) + CF*(0.006686607733274434 - 
          0.004141997227176739*lm + 0.05357807545682438*lm^2) + 
        0.0006962905487195091*NM + 0.0020023088536356413*lm*NM + 
        0.0029765597476013542*lm^2*NM + 0.009080514460477813*NL + 
        0.0020023088536356413*lm*NL + 0.0029765597476013542*lm^2*NL - 
        0.00072119889543229*NH + 0.0020023088536356413*lm*NH + 
        0.0029765597476013542*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(0.0025737794375774695 - 0.031361603514885567*lm - 
          0.01620355567454087*lm^2) + CF*(0.006648251903074251 - 
          0.004626885152169843*lm + 0.05302981857122466*lm^2) + 
        0.0006435874637654476*NM + 0.0019525265986804806*lm*NM + 
        0.002946101031734703*lm^2*NM + 0.008976857878799588*NL + 
        0.0019525265986804806*lm*NL + 0.002946101031734703*lm^2*NL - 
        0.0006923128688678474*NH + 0.0019525265986804806*lm*NH + 
        0.002946101031734703*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(0.002703933047934955 - 0.030881514623024946*lm - 
          0.01603794810878419*lm^2) + CF*(0.006612230015208287 - 
          0.005101790449737654*lm + 0.0524878301742028*lm^2) + 
        0.0005923144336754674*NM + 0.0019035601211619135*lm*NM + 
        0.0029159905652334887*lm^2*NM + 0.008874671967151068*NL + 
        0.0019035601211619135*lm*NL + 0.0029159905652334887*lm^2*NL - 
        0.0006638512759579319*NH + 0.0019035601211619135*lm*NH + 
        0.0029159905652334887*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(0.0028303599308543677 - 0.030408259011457318*lm - 
          0.01587423362549782*lm^2) + CF*(0.0065784866593793815 - 
          0.005566864177575674*lm + 0.05195203731981105*lm^2) + 
        0.0005424403944147285*NM + 0.0018553979895712565*lm*NM + 
        0.0028862242955450586*lm^2*NM + 0.00877393479177369*NL + 
        0.0018553979895712565*lm*NL + 0.0028862242955450586*lm^2*NL - 
        0.0006358093728811035*NH + 0.0018553979895712565*lm*NH + 
        0.0028862242955450586*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(0.0029531315963431458 - 0.029941746322536822*lm - 
          0.015712390144597292*lm^2) + CF*(0.006546967085609834 - 
          0.006022255885106206*lm + 0.05142236774595478*lm^2) + 
        0.0004939348625065962*NM + 0.00180802888468666*lm*NM + 
        0.0028567982081085987*lm^2*NM + 0.00867462470109172*NL + 
        0.00180802888468666*lm*NL + 0.0028567982081085987*lm^2*NL - 
        0.0006081824384777994*NH + 0.00180802888468666*lm*NH + 
        0.0028567982081085987*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(0.0030723185890872604 - 0.029481887088189697*lm - 
          0.015552395795721295*lm^2) + CF*(0.006517617214723756 - 
          0.006468113598757328*lm + 0.050898749876906055*lm^2) + 
        0.00044676792716469125*NM + 0.0017614416004956787*lm*NM + 
        0.002827708326494781*lm^2*NM + 0.00857672032492292*NL + 
        0.0017614416004956787*lm*NL + 0.002827708326494781*lm^2*NL - 
        0.0005809657753263993*NH + 0.0017614416004956787*lm*NH + 
        0.002827708326494781*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(0.0031879904870671864 - 0.02902859273512968*lm - 
          0.015394228918844795*lm^2) + CF*(0.006490383647771107 - 
          0.006904583808953107*lm + 0.050381112825310236*lm^2) + 
        0.000400910242385123*NM + 0.0017156250450016427*lm*NM + 
        0.0027989507125172355*lm^2*NM + 0.008480200573524818*NL + 
        0.0017156250450016427*lm*NL + 0.0027989507125172355*lm^2*NL - 
        0.0005541547107611976*NH + 0.0017156250450016427*lm*NH + 
        0.0027989507125172355*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(0.0033002159010236155 - 0.02858177558927745*lm - 
          0.015237868064745037*lm^2) + CF*(0.0064652136744395685 - 
          0.007331811458734754*lm + 0.04986938639371103*lm^2) + 
        0.00035633301900895393*NM + 0.0016705682409193622*lm*NM + 
        0.0027705214663172797*lm^2*NM + 0.008385044636486899*NL + 
        0.0016705682409193622*lm*NL + 0.0027705214663172797*lm^2*NL - 
        0.0005277445978343718*NH + 0.0016705682409193622*lm*NH + 
        0.0027705214663172797*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(0.0034090624747244083 - 0.02814134887942289*lm - 
          0.015083291995327904*lm^2) + CF*(0.0064420552804989786 - 
          0.007749939933935429*lm + 0.04936350107561859*lm^2) + 
        0.00031300801676432336*NM + 0.0016262603262654732*lm*NM + 
        0.0027424167264232554*lm^2*NM + 0.00829123198147862*NL + 
        0.0016262603262654732*lm*NL + 0.0027424167264232554*lm^2*NL - 
        0.0005017308162239785*NH + 0.0016262603262654732*lm*NH + 
        0.0027424167264232554*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(0.003514596885986401 - 0.027707226740167394*lm - 
          0.01493047968382179*lm^2) + CF*(0.0064208571543216434 - 
          0.00815911105483443*lm + 0.04886338805614404*lm^2) + 
        0.0002709075362970791*NM + 0.0015826905548485333*lm*NM + 
        0.00271463266978578*lm^2*NM + 0.008198742352862644*NL + 
        0.0015826905548485333*lm*NL + 0.00271463266978578*lm^2*NL - 
        0.00047610877308993933*NH + 0.0015826905548485333*lm*NH + 
        0.00271463266978578*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(0.0036168848484077363 - 0.02727932421418185*lm - 
          0.01477941031484588*lm^2) + CF*(0.006401568692520475 - 
          0.008559465069219315*lm + 0.04836897921222288*lm^2) + 
        0.00023000441119821048*NM + 0.0015398482966637692*lm*NM + 
        0.0026871655117901598*lm^2*NM + 0.008107555770182245*NL + 
        0.0015398482966637692*lm*NL + 0.0026871655117901598*lm^2*NL - 
        0.0004508739038799217*NH + 0.0015398482966637692*lm*NH + 
        0.0026871655117901598*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(0.003715991113768356 - 0.026857557253814612*lm - 
          0.014630063284359363*lm^2) + CF*(0.006384140004745539 - 
          0.008951140646787295*lm + 0.04788020711244882*lm^2) + 
        0.00019027200003584894*NM + 0.0014977230381971846*lm*NM + 
        0.002660011506247157*lm^2*NM + 0.008017652526531456*NL + 
        0.0014977230381971846*lm*NL + 0.002660011506247157*lm^2*NL - 
        0.00042602167308695835*NH + 0.0014977230381971846*lm*NH + 
        0.002660011506247157*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(0.0038119794750581725 - 0.026441842722082363*lm - 
          0.014482418199497915*lm^2) + CF*(0.006368521917678285 - 
          0.00933427487481995*lm + 0.04739700501653863*lm^2) + 
        0.000151684178399102*NM + 0.0014563043826435569*lm*NM + 
        0.0026331669453632574*lm^2*NM + 0.007929013186816025*NL + 
        0.0014563043826435569*lm*NL + 0.0026331669453632574*lm^2*NL - 
        0.0004015475749605924*NH + 0.0014563043826435569*lm*NH + 
        0.0026331669453632574*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(0.003904912770094277 - 0.026032098393075347*lm - 
          0.014336454878303422*lm^2) + CF*(0.006354665978261412 - 
          0.009709003255067796*lm + 0.046919306874447564*lm^2) + 
        0.00011421533096050949*NM + 0.0014155820500426598*lm*NM + 
        0.002606628159691531*lm^2*NM + 0.007841618585912985*NL + 
        0.0014155820500426598*lm*NL + 0.002606628159691531*lm^2*NL - 
        0.000377447134173277*NH + 0.0014155820500426598*lm*NH + 
        0.002606628159691531*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(0.003994852885690261 - 0.025628242951807326*lm - 
          0.014192153349352747*lm^2) + CF*(0.006342524456201048 - 
          0.010075459701783874*lm + 0.04644704732515444*lm^2) + 
        0.00007784034356346056*NM + 0.0013755458773378867*lm*NM + 
        0.002580391518064136*lm^2*NM + 0.0077554498267361415*NL + 
        0.0013755458773378867*lm*NL + 0.002580391518064136*lm^2*NL - 
        0.0003537159064437055*NH + 0.0013755458773378867*lm*NH + 
        0.002580391518064136*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(0.004081860762342429 - 0.025230195993539237*lm - 
          0.014049493851291039*lm^2) + CF*(0.0063320503457766925 - 
          0.01043377654084781*lm + 0.04598016169513431*lm^2) + 
        0.0000425345953404783*NM + 0.0013361858183612734*lm*NM + 
        0.0025544534275074617*lm^2*NM + 0.0076704882782145135*NL + 
        0.0013361858183612734*lm*NL + 0.0025544534275074617*lm^2*NL - 
        0.00033034947911869396*NH + 0.0013361858183612734*lm*NH + 
        0.0025544534275074617*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(0.004165996399399277 - 0.024837878022604377*lm - 
          0.013908456832274855*lm^2) + CF*(0.006323197366993124 - 
          0.010784084509924173*lm + 0.04551858599653589*lm^2) + 
        8.273950867873382*^-6*NM + 0.0012974919437487634*lm*NM + 
        0.0025288103331408828*lm^2*NM + 0.007586715573190369*NL + 
        0.0012974919437487634*lm*NL + 0.0025288103331408828*lm^2*NL - 
        0.0003073434717151854*NH + 0.0012974919437487634*lm*NH + 
        0.0025288103331408828*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(0.004247318860682165 - 0.024451210450761887*lm - 
          0.01376902294933016*lm^2) + CF*(0.006315919966107289 - 
          0.01112651275960125*lm + 0.04506225692508053*lm^2) - 
        0.000024965247638120228*NM + 0.0012594544407893969*lm*NM + 
        0.002503458718060029*lm^2*NM + 0.0075041136062432*NL + 
        0.0012594544407893969*lm*NL + 0.002503458718060029*lm^2*NL - 
        0.0002846935364238961*NH + 0.0012594544407893969*lm*NH + 
        0.002503458718060029*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(0.0043258862805265995 - 0.02407011559510403*lm - 
          0.01363117306763004*lm^2) + CF*(0.00631017331556204 - 
          0.0114611888554584*lm + 0.04461111185769832*lm^2) - 
        0.00005720618807898081*NM + 0.0012220636132119632*lm*NM + 
        0.002478395103205462*lm^2*NM + 0.0074226645314456425*NL + 
        0.0012220636132119632*lm*NL + 0.002478395103205462*lm^2*NL - 
        0.00026239535857607536*NH + 0.0012220636132119632*lm*NH + 
        0.002478395103205462*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(0.00440175587021495 - 0.023694516675541857*lm - 
          0.013494888259696719*lm^2) + CF*(0.006305913313357422 - 
          0.011788238781012369*lm + 0.04416508884991653*lm^2) - 
        0.00008847159618090736*NM + 0.0011853098809125019*lm*NM + 
        0.0024536160472175854*lm^2*NM + 0.007342350760057066*NL + 
        0.0011853098809125019*lm*NL + 0.0024536160472175854*lm^2*NL - 
        0.00024044465707480055*NH + 0.0011853098809125019*lm*NH + 
        0.0024536160472175854*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(0.00447498392477282 - 0.023324337811892738*lm - 
          0.013360149804532338*lm^2) + CF*(0.006303096581889128 - 
          0.012107786941494874*lm + 0.04372412663301493*lm^2) - 
        0.00011878374314713272*NM + 0.0011491837796259068*lm*NM + 
        0.002429118146278607*lm^2*NM + 0.007263154958160257*NL + 
        0.0011491837796259068*lm*NL + 0.002429118146278607*lm^2*NL - 
        0.00021883718479218624*NH + 0.0011491837796259068*lm*NH + 
        0.002429118146278607*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(0.00454562583010259 - 0.022959504020592297*lm - 
          0.013226939186682714*lm^2) + CF*(0.006301680466282641 - 
          0.012419956168415739*lm + 0.04328816461096161*lm^2) - 
        0.00014816445325178593*NM + 0.0011136759605447483*lm*NM + 
        0.002404898033942312*lm^2*NM + 0.007185060044246348*NL + 
        0.0011136759605447483*lm*NL + 0.002404898033942312*lm^2*NL - 
        0.0001975687289338387*NH + 0.0011136759605447483*lm*NH + 
        0.002404898033942312*lm^2*NH)}, {1., 7.973761349532954*^-12*CF*NC*
       (20.*CF*(3.951474565149632*^7 - 7.9792128*^7*lm + 2.6873856*^8*lm^2) - 
        2.*CA*(-2.893073838169943*^8 + 1.41714432*^9*lm + 8.211456*^8*lm^2) + 
        3.*(15.*(-492267.64196824474 + 3.006464*^6*lm + 6.63552*^6*lm^2)*
           NM + 1024.*(290179. + 44040.*lm + 97200.*lm^2)*NL + 
          15.*(-492267.64196824474 + 3.006464*^6*lm + 6.63552*^6*lm^2)*NH))}}
 
CbarTable["v", 2, 3] = {{0., -2.2680921172004848*^-10*CF*NC*
       (CF*(-3.4006959039835095*^8 - 1.078594304894892*^9*lm - 
          8.26686*^8*lm^2) + 7.*CA*(5.6525331823675215*^7 + 
          8.739916495725876*^7*lm + 2.4057*^7*lm^2) + 
        70.*(45.*(-47454.35801988715 - 22941.884831215662*lm - 9720.*lm^2)*
           NM + 45.*(-47454.35801988715 - 22941.884831215662*lm - 
            9720.*lm^2)*NL + (456462.5279541789 - 1.0323848174047048*^6*lm - 
            437400.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.08647469256467132 - 0.14016851614703565*lm - 
          0.03886516765725508*lm^2) + CF*(0.07754642571698094 + 
          0.24388075802773065*lm + 0.19079264122652492*lm^2) + 
        0.03383210384468604*NM + 0.016491592238278036*lm*NM + 
        0.007066394119500923*lm^2*NM + 0.03383484785278748*NL + 
        0.016491592238278036*lm*NL + 0.007066394119500923*lm^2*NL - 
        0.007348924413720166*NH + 0.016491592238278036*lm*NH + 
        0.007066394119500923*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.08361553464422851 - 0.14152143859436142*lm - 
          0.03949647911775794*lm^2) + CF*(0.07763088068176507 + 
          0.24330664384455739*lm + 0.19389180657808444*lm^2) + 
        0.03379583915575191*NM + 0.016591489535361395*lm*NM + 
        0.007181178021410535*lm^2*NM + 0.03380521374860005*NL + 
        0.016591489535361395*lm*NL + 0.007181178021410535*lm^2*NL - 
        0.007445222136466929*NH + 0.016591489535361395*lm*NH + 
        0.007181178021410535*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.0812040926310018 - 0.1428137604194512*lm - 
          0.04008300802816011*lm^2) + CF*(0.07743359097421215 + 
          0.24294688914221968*lm + 0.19677113032005875*lm^2) + 
        0.03379688756128882*NM + 0.01669073144164829*lm*NM + 
        0.007287819641483657*lm^2*NM + 0.033816241646117275*NL + 
        0.01669073144164829*lm*NL + 0.007287819641483657*lm^2*NL - 
        0.0075353176055621375*NH + 0.01669073144164829*lm*NH + 
        0.007287819641483657*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.07922040417290786 - 0.14403641897215289*lm - 
          0.0406217747314828*lm^2) + CF*(0.07702345817772015 + 
          0.2427910612877529*lm + 0.199415985045461*lm^2) + 
        0.03382905017203927*NM + 0.016788359709965662*lm*NM + 
        0.007385777223905963*lm^2*NM + 0.033862127748591896*NL + 
        0.016788359709965662*lm*NL + 0.007385777223905963*lm^2*NL - 
        0.007618801995742893*NH + 0.016788359709965662*lm*NH + 
        0.007385777223905963*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.07762637978319259 - 0.14518040623740175*lm - 
          0.04111120960190853*lm^2) + CF*(0.07646188294477396 + 
          0.24281287955022424*lm + 0.20181866531846007*lm^2) + 
        0.03388423289219905*NM + 0.016883099738590077*lm*NM + 
        0.007474765382165188*lm^2*NM + 0.0339354599079145*NL + 
        0.016883099738590077*lm*NL + 0.007474765382165188*lm^2*NL - 
        0.007695424036505519*NH + 0.016883099738590077*lm*NH + 
        0.007474765382165188*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.07637799502285234 - 0.14623770357179566*lm - 
          0.041550700575552504*lm^2) + CF*(0.07579935583156919 + 
          0.2429799754186571*lm + 0.2039761664618032*lm^2) + 
        0.03395422298218602*NM + 0.01697363522697549*lm*NM + 
        0.0075546728319186365*lm^2*NM + 0.034028749637860976*NL + 
        0.01697363522697549*lm*NL + 0.0075546728319186365*lm^2*NL - 
        0.007765042948387032*NH + 0.01697363522697549*lm*NH + 
        0.0075546728319186365*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.07543046199572914 - 0.147201569047364*lm - 
          0.041940322969996724*lm^2) + CF*(0.0750759471206288 + 
          0.24325839129445248*lm + 0.20588885821634756*lm^2) + 
        0.034031367605148195*NM + 0.01705872294117438*lm*NM + 
        0.007625513267272132*lm^2*NM + 0.03413500022936956*NL + 
        0.01705872294117438*lm*NL + 0.007625513267272132*lm^2*NL - 
        0.007827600307840063*NH + 0.01705872294117438*lm*NH + 
        0.007625513267272132*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.07474067199589826 - 0.14806658681177154*lm - 
          0.04228065892640972*lm^2) + CF*(0.07432267368780611 + 
          0.24361488653692268*lm + 0.20755959836601137*lm^2) + 
        0.034108839296411085*NM + 0.017137243470409104*lm*NM + 
        0.007687392532074495*lm^2*NM + 0.03424792263123955*NL + 
        0.017137243470409104*lm*NL + 0.007687392532074495*lm^2*NL - 
        0.007883101117154075*NH + 0.017137243470409104*lm*NH + 
        0.007687392532074495*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.0742683678668648 - 0.14882861607567482*lm - 
          0.04257266872965776*lm^2) + CF*(0.07356297190920055 + 
          0.24401815781681124*lm + 0.20899310103650173*lm^2) + 
        0.03418071794315116*NM + 0.017208221729210157*lm*NM + 
        0.0077404852235741384*lm^2*NM + 0.03436199889092321*NL + 
        0.017208221729210157*lm*NL + 0.0077404852235741384*lm^2*NL - 
        0.00793160015291272*NH + 0.017208221729210157*lm*NH + 
        0.0077404852235741384*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.07397666330219242 - 0.14948469658149532*lm - 
          0.04281759527789442*lm^2) + CF*(0.07281405221992893 + 
          0.24443946694281188*lm + 0.21019546772784534*lm^2) + 
        0.03424198476772259*NM + 0.01727083187613102*lm*NM + 
        0.0077850173232535316*lm^2*NM + 0.03447247425725147*NL + 
        0.01727083187613102*lm*NL + 0.0077850173232535316*lm^2*NL - 
        0.007973191663559257*NH + 0.01727083187613102*lm*NH + 
        0.0077850173232535316*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.07383220698940225 - 0.15003293694427464*lm - 
          0.0430168911874505*lm^2) + CF*(0.07208807706059277 + 
          0.24485292588971153*lm + 0.2111738294656661*lm^2) + 
        0.03428847333799578*NM + 0.01732439388037544*lm*NM + 
        0.007821252943172818*lm^2*NM + 0.03457531530295866*NL + 
        0.01732439388037544*lm*NL + 0.007821252943172818*lm^2*NL - 
        0.008008001344127411*NH + 0.01732439388037544*lm*NH + 
        0.007821252943172818*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.07380514847902542 - 0.1504723989615111*lm - 
          0.043172162100895264*lm^2) + CF*(0.07139315964297645 + 
          0.24523557683966485*lm + 0.21193606849530403*lm^2) + 
        0.03431680056008028*NM + 0.017368365606017993*lm*NM + 
        0.007849484018344594*lm^2*NM + 0.034667152691948665*NL + 
        0.017368365606017993*lm*NL + 0.007849484018344594*lm^2*NL - 
        0.008036179939291873*NH + 0.017368365606017993*lm*NH + 
        0.007849484018344594*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.07386899352705746 - 0.15080298458966152*lm - 
          0.04328512200579102*lm^2) + CF*(0.07073419951139645 + 
          0.24556734803512364*lm + 0.21249059893751956*lm^2) + 
        0.03432428992692928*NM + 0.017402332601738884*lm*NM + 
        0.007870022182871096*lm^2*NM + 0.034745218333719324*NL + 
        0.017402332601738884*lm*NL + 0.007870022182871096*lm^2*NL - 
        0.008057898056137231*NH + 0.017402332601738884*lm*NH + 
        0.007870022182871096*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.07400040007828713 - 0.15102532898608012*lm - 
          0.04335755769538235*lm^2) + CF*(0.07011357585437619 + 
          0.24583093491750257*lm + 0.21284619232278607*lm^2) + 
        0.03430889373831283*NM + 0.017425996877876507*lm*NM + 
        0.007883192308251335*lm^2*NM + 0.034807282138728836*NL + 
        0.017425996877876507*lm*NL + 0.007883192308251335*lm^2*NL - 
        0.008073341902891912*NH + 0.017425996877876507*lm*NH + 
        0.007883192308251335*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.07417894555335736 - 0.1511407012319301*lm - 
          0.04339130033171827*lm^2) + CF*(0.06953171941525883 + 
          0.2460116377933894*lm + 0.21301183799207152*lm^2) + 
        0.034269117961062114*NM + 0.01743916543648224*lm*NM + 
        0.007889327333039686*lm^2*NM + 0.03485159115552493*NL + 
        0.01743916543648224*lm*NL + 0.007889327333039686*lm^2*NL - 
        0.008082709753520765*NH + 0.01743916543648224*lm*NH + 
        0.007889327333039686*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.07438688408906709 - 0.15115091335808334*lm - 
          0.04338820261610532*lm^2) + CF*(0.06898758193515049 + 
          0.246097176170478*lm + 0.21299663102451705*lm^2) + 
        0.034203951665906604*NM + 0.017441739013445326*lm*NM + 
        0.007888764112019149*lm^2*NM + 0.034876812514150084*NL + 
        0.017441739013445326*lm*NL + 0.007888764112019149*lm^2*NL - 
        0.008086208992416846*NH + 0.017441739013445326*lm*NH + 
        0.007888764112019149*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.07460890509944744 - 0.1510582377347128*lm - 
          0.043350120443188034*lm^2) + CF*(0.06847901964896763 + 
          0.24607749290487896*lm + 0.21280968217565033*lm^2) + 
        0.0341128019679713*NM + 0.01743370130375551*lm*NM + 
        0.007881840080579641*lm^2*NM + 0.03488198082596895*NL + 
        0.01743370130375551*lm*NL + 0.007881840080579641*lm^2*NL - 
        0.008084053630118831*NH + 0.01743370130375551*lm*NH + 
        0.007881840080579641*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.07483189999601579 - 0.15086533256963344*lm - 
          0.04327889817658002*lm^2) + CF*(0.06800310496901943 + 
          0.2459445567615876*lm + 0.21246004559412007*lm^2) + 
        0.03399543480304709*NM + 0.017415108823038802*lm*NM + 
        0.007868890577560003*lm^2*NM + 0.034866450242985535*NL + 
        0.017415108823038802*lm*NL + 0.007868890577560003*lm^2*NL - 
        0.008076462206553607*NH + 0.017415108823038802*lm*NH + 
        0.007868890577560003*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.07504474103572278 - 0.15057517508842577*lm - 
          0.043176356873316314*lm^2) + CF*(0.0675563783251115 + 
          0.24569216898122687*lm + 0.2119566610144619*lm^2) + 
        0.03385192152150203*NM + 0.017386081483409175*lm*NM + 
        0.00785024670423933*lm^2*NM + 0.03482985112245489*NL + 
        0.017386081483409175*lm*NL + 0.00785024670423933*lm^2*NL - 
        0.008063656016625663*NH + 0.017386081483409175*lm*NH + 
        0.00785024670423933*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.07523807442462774 - 0.15019100188298265*lm - 
          0.04304428492462457*lm^2) + CF*(0.06713505024074015 + 
          0.24531577741930505*lm + 0.21130830781179336*lm^2) + 
        0.03368259107936453*NM + 0.017346793913521737*lm*NM + 
        0.007826233622659013*lm^2*NM + 0.03477205109797038*NL + 
        0.017346793913521737*lm*NL + 0.007826233622659013*lm^2*NL - 
        0.00804585760641728*NH + 0.017346793913521737*lm*NH + 
        0.007826233622659013*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.07540412861874646 - 0.1497162558803185*lm - 
          0.04288443068643059*lm^2) + CF*(0.06673516210861656 + 
          0.24481230044277436*lm + 0.2105235688242956*lm^2) + 
        0.03348798749461288*NM + 0.017297467521875626*lm*NM + 
        0.0077971692157146515*lm^2*NM + 0.0346931202814791*NL + 
        0.017297467521875626*lm*NL + 0.0077971692157146515*lm^2*NL - 
        0.008023289498332043*NH + 0.017297467521875626*lm*NH + 
        0.0077971692157146515*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.07553653800021687 - 0.14915453937978793*lm - 
          0.042698496754389734*lm^2) + CF*(0.06635271276027332 + 
          0.24417996182043822*lm + 0.20961080224882234*lm^2) + 
        0.033268832181499196*NM + 0.01723836328291258*lm*NM + 
        0.0077633630462526785*lm^2*NM + 0.034593300285205915*NL + 
        0.01723836328291258*lm*NL + 0.0077633630462526785*lm^2*NL - 
        0.007996173111194832*NH + 0.01723836328291258*lm*NH + 
        0.0077633630462526785*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.0756301816217247 - 0.14850957262169165*lm - 
          0.042488135601685864*lm^2) + CF*(0.06598375677208557 + 
          0.2434181371913494*lm + 0.20857812022645789*lm^2) + 
        0.03302599075545032*NM + 0.01716977521347117*lm*NM + 
        0.007725115563942885*lm^2*NM + 0.03447297674205265*NL + 
        0.01716977521347117*lm*NL + 0.007725115563942885*lm^2*NL - 
        0.007964727847276316*NH + 0.01716977521347117*lm*NH + 
        0.007725115563942885*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.07568103641162129 - 0.14778515737575582*lm - 
          0.04225494634795034*lm^2) + CF*(0.06562447948213478 + 
          0.2425272122477987*lm + 0.2074333729808471*lm^2) + 
        0.032760443902280806*NM + 0.0170920245001985*lm*NM + 
        0.007682717517809152*lm^2*NM + 0.03433265500766525*NL + 
        0.0170920245001985*lm*NL + 0.007682717517809152*lm^2*NL - 
        0.007929170322894393*NH + 0.0170920245001985*lm*NH + 
        0.007682717517809152*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.07568604405515916 - 0.1469851450692126*lm - 
          0.04200047246767703*lm^2) + CF*(0.06527125288031002 + 
          0.24150845246541275*lm + 0.20618413756859635*lm^2) + 
        0.03247326191956159*NM + 0.017005454234939835*lm*NM + 
        0.007636449539577642*lm^2*NM + 0.03417293874076036*NL + 
        0.017005454234939835*lm*NL + 0.007636449539577642*lm^2*NL - 
        0.007889713722978222*NH + 0.017005454234939835*lm*NH + 
        0.007636449539577642*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.0756429906730738 - 0.14611340900806108*lm - 
          0.04172620027879005*lm^2) + CF*(0.06492067585293165 + 
          0.24036388401009615*lm + 0.20483771045951482*lm^2) + 
        0.03216558255951595*NM + 0.016910424713811753*lm*NM + 
        0.007586581868870919*lm^2*NM + 0.03399451107652179*NL + 
        0.016910424713811753*lm*NL + 0.007586581868870919*lm^2*NL - 
        0.00784656726299104*NH + 0.016910424713811753*lm*NH + 
        0.007586581868870919*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.07555039837993875 - 0.14517382027957879*lm - 
          0.04143355807828193*lm^2) + CF*(0.06456960169175666 + 
          0.2390961853207098*lm + 0.20340110329338404*lm^2) + 
        0.03183859182822083*NM + 0.016807309255858174*lm*NM + 
        0.00753337419605126*lm^2*NM + 0.03379811812842064*NL + 
        0.016807309255858174*lm*NL + 0.00753337419605126*lm^2*NL - 
        0.007799935744061584*NH + 0.016807309255858174*lm*NH + 
        0.00753337419605126*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.07540742780267001 - 0.14417022695805598*lm - 
          0.04112391581336724*lm^2) + CF*(0.06421515529759932 + 
          0.2377085887867633*lm + 0.20188104126562098*lm^2) + 
        0.031493507422902044*NM + 0.016696490498371477*lm*NM + 
        0.0074770756024304065*lm^2*NM + 0.033584554575113855*NL + 
        0.016696490498371477*lm*NL + 0.0074770756024304065*lm^2*NL - 
        0.0077500191891931285*NH + 0.016696490498371477*lm*NH + 
        0.0074770756024304065*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.0752137906614713 - 0.14310643626829703*lm - 
          0.04079858519436002*lm^2) + CF*(0.06385474210601842 + 
          0.23620479189726062*lm + 0.20028396368140372*lm^2) + 
        0.03113156451627599*NM + 0.01657835712777235*lm*NM + 
        0.007417924580792731*lm^2*NM + 0.03335465111016021*NL + 
        0.01657835712777235*lm*NL + 0.007417924580792731*lm^2*NL - 
        0.007697012550095587*NH + 0.01657835712777235*lm*NH + 
        0.007417924580792731*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.07496967155259406 - 0.14198619939224544*lm - 
          0.040458820170228255*lm^2) + CF*(0.0634860504241077 + 
          0.23458887721957117*lm + 0.19861602629021144*lm^2) + 
        0.030754003623298873*NM + 0.0164533010071323*lm*NM + 
        0.007356149121859683*lm^2*NM + 0.03310926355257729*NL + 
        0.0164533010071323*lm*NL + 0.007356149121859683*lm^2*NL - 
        0.007641105475589033*NH + 0.0164533010071323*lm*NH + 
        0.007356149121859683*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.07467565811846165 - 0.14081319863292022*lm - 
          0.040105817700080815*lm^2) + CF*(0.06310704858298771 + 
          0.2328652405681227*lm + 0.196883105073124*lm^2) + 
        0.030362060310770794*NM + 0.016321714663818033*lm*NM + 
        0.007291966854560149*lm^2*NM + 0.032849263435411384*NL + 
        0.016321714663818033*lm*NL + 0.007291966854560149*lm^2*NL - 
        0.007582482133709743*NH + 0.016321714663818033*lm*NH + 
        0.007291966854560149*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.07433267884179506 - 0.13959103667661735*lm - 
          0.03974071876415341*lm^2) + CF*(0.06271597807148284 + 
          0.23103852673625241*lm + 0.19509080120584402*lm^2) + 
        0.029956956533645298*NM + 0.016183989103217243*lm*NM + 
        0.007225585229846075*lm^2*NM + 0.03257552990733393*NL + 
        0.016183989103217243*lm*NL + 0.007225585229846075*lm^2*NL - 
        0.00752132108065353*NH + 0.016183989103217243*lm*NH + 
        0.007225585229846075*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.07394194775352503 - 0.13832322771902794*lm - 
          0.03936460956653706*lm^2) + CF*(0.062311343615479346 + 
          0.22911357218662678*lm + 0.1932444469630001*lm^2) + 
        0.02953989340332695*NM + 0.01604051191698824*lm*NM + 
        0.007157201739370375*lm^2*NM + 0.032288942798746494*NL + 
        0.01604051191698824*lm*NL + 0.007157201739370375*lm^2*NL - 
        0.007457795170548143*NH + 0.01604051191698824*lm*NH + 
        0.007157201739370375*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.07350491539757101 - 0.13701319024361466*lm - 
          0.03897852288921973*lm^2) + CF*(0.06189190099863823 + 
          0.22709535412327453*lm + 0.1913491123652605*lm^2) + 
        0.029112045212343108*NM + 0.015891665656705536*lm*NM + 
        0.007087004161676315*lm^2*NM + 0.03199037671897212*NL + 
        0.015891665656705536*lm*NL + 0.007087004161676315*lm^2*NL - 
        0.007392071500782214*NH + 0.015891665656705536*lm*NH + 
        0.007087004161676315*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.07302322544779573 - 0.1356642412613566*lm - 
          0.03858343956321828*lm^2) + CF*(0.06145664327858542 + 
          0.224988945399297*lm + 0.18940961240125337*lm^2) + 
        0.02867455455590308*NM + 0.0157378264461135*lm*NM + 
        0.007015170829676051*lm^2*NM + 0.03168069606487621*NL + 
        0.0157378264461135*lm*NL + 0.007015170829676051*lm^2*NL - 
        0.007324311388253081*NH + 0.0157378264461135*lm*NH + 
        0.007015170829676051*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.07249867642293265 - 0.13427959183993057*lm - 
          0.038180290027848854*lm^2) + CF*(0.061004785934523666 + 
          0.2227994747471388*lm + 0.18743051468216712*lm^2) + 
        0.028228528402711544*NM + 0.015579362807427312*lm*NM + 
        0.0069418709141543375*lm^2*NM + 0.031360750833762205*NL + 
        0.015579362807427312*lm*NL + 0.0069418709141543375*lm^2*NL - 
        0.007254670372446104*NH + 0.015579362807427312*lm*NH + 
        0.0069418709141543375*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.07193318799383712 - 0.13286234376766243*lm - 
          0.037769955953670525*lm^2) + CF*(0.06053575138448988 + 
          0.22053209185177808*lm + 0.18541614740892803*lm^2) + 
        0.027775034972437312*NM + 0.015416634679221478*lm*NM + 
        0.006867264718849186*lm^2*NM + 0.031031373144706127*NL + 
        0.015416634679221478*lm*NL + 0.006867264718849186*lm^2*NL - 
        0.007183298241737079*NH + 0.015416634679221478*lm*NH + 
        0.006867264718849186*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.07132877142433074 - 0.13141548721327664*lm - 
          0.03735327190846342*lm^2) + CF*(0.06004915323140337 + 
          0.21819193682050758*lm + 0.18337060755063864*lm^2) + 
        0.027315101270703315*NM + 0.015249992605414138*lm*NM + 
        0.006791503983356986*lm^2*NM + 0.030693374382716517*NL + 
        0.015249992605414138*lm*NL + 0.006791503983356986*lm^2*NL - 
        0.007110339079727838*NH + 0.015249992605414138*lm*NH + 
        0.006791503983356986*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.07068750373305244 - 0.12994189925671754*lm - 
          0.03693102704887117*lm^2) + CF*(0.05954478053607934 + 
          0.2157841136355487*lm + 0.18129776914900392*lm^2) + 
        0.026849711106019986*NM + 0.0150797770766892*lm*NM + 
        0.006714732190703849*lm^2*NM + 0.030347542889320244*NL + 
        0.0150797770766892*lm*NL + 0.006714732190703849*lm^2*NL - 
        0.007035931328792019*NH + 0.0150797770766892*lm*NH + 
        0.006714732190703849*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.07001150385764844 - 0.12844434317922682*lm - 
          0.036503966823132894*lm^2) + CF^2*(0.05902257966752834 + 
          0.21331366720717299*lm + 0.17920129167719784*lm^2) + 
        CF*((0.026379815162410742 + 0.014906318007398915*lm + 
            0.006637084876933254*lm^2)*NM + (0.0299946421314655 + 
            0.014906318007398915*lm + 0.006637084876933254*lm^2)*NL + 
          (-0.00696020786833064 + 0.014906318007398915*lm + 
            0.006637084876933254*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.06930291689354348 - 0.12692546841255312*lm - 
          0.03607279467272366*lm^2) + CF^2*(0.05848264674265781 + 
          0.21078556367503906*lm + 0.1770846283933707*lm^2) + 
        CF*((0.02590629676112462 + 0.014729934332561206*lm + 
            0.006558689940495212*lm^2)*NM + (0.029635409288084405 + 
            0.014729934332561206*lm + 0.006558689940495212*lm^2)*NL + 
          (-0.006883296105521589 + 0.014729934332561206*lm + 
            0.006558689940495212*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.06856389250672627 - 0.125387811057742*lm - 
          0.0356381737227724*lm^2) + CF^2*(0.057925203615789046 + 
          0.20820467363392162*lm + 0.1749510346390645*lm^2) + 
        CF*((0.0254300126518735 + 0.014550933711014022*lm + 
            0.006479667949594981*lm^2)*NM + (0.02927055420034571 + 
            0.014550933711014022*lm + 0.006479667949594981*lm^2)*NL + 
          (-0.006805318076598707 + 0.014550933711014022*lm + 
            0.006479667949594981*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.06779657302016218 - 0.12383379489351025*lm - 
          0.03520072845288412*lm^2) + CF^2*(0.05735058908506267 + 
          0.2055757579868293*lm + 0.17280357604143115*lm^2) + 
        CF*((0.024951769786227644 + 0.014369612322119587*lm + 
            0.006400132445978931*lm^2)*NM + (0.02890075863762586 + 
            0.014369612322119587*lm + 0.006400132445978931*lm^2)*NL + 
          (-0.006726390556918952 + 0.014369612322119587*lm + 
            0.006400132445978931*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.06700308039900317 - 0.12226573280283581*lm - 
          0.034761046341499464*lm^2) + CF^2*(0.056759244351211095 + 
          0.20290345615364228*lm + 0.1706451365855428*lm^2) + 
        CF*((0.024472330752066594 + 0.014186254744631428*lm + 
            0.006320190243908993*lm^2)*NM + (0.028526675836600922 + 
            0.014186254744631428*lm + 0.006320190243908993*lm^2)*NL + 
          (-0.006646625178273867 + 0.014186254744631428*lm + 
            0.006320190243908993*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.06618550569197168 - 0.12068582855417813*lm - 
          0.03431967947821569*lm^2) + CF^2*(0.05615170035562077 + 
          0.20019227638685552*lm + 0.16847842652942246*lm^2) + 
        CF*((0.023992414368022515 + 0.014001133907453552*lm + 
            0.006239941723311943*lm^2)*NM + (0.028148930275673535 + 
            0.014001133907453552*lm + 0.006239941723311943*lm^2)*NL + 
          (-0.006566128552078189 + 0.014001133907453552*lm + 
            0.006239941723311943*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.06534590014380608 - 0.11909617888076213*lm - 
          0.03387714613959931*lm^2) + CF^2*(0.05552856587529081 + 
          0.19744658796782527*lm + 0.16630599013985115*lm^2) + 
        CF*((0.023512696479533277 + 0.013814511103041207*lm + 
            0.006159481116290783*lm^2)*NM + (0.027768117651254344 + 
            0.013814511103041207*lm + 0.006159481116290783*lm^2)*NL + 
          (-0.00648500239722267 + 0.013814511103041207*lm + 
            0.006159481116290783*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.06448626778970862 - 0.1174987758076808*lm - 
          0.033433932324966935*lm^2) + CF^2*(0.0548905163876981 + 
          0.19467061507713326*lm + 0.16413021323165586*lm^2) + 
        CF*((0.023033810920785224 + 0.01362663605512317*lm + 
            0.006078896786357625*lm^2)*NM + (0.027384805026267126 + 
            0.01362663605512317*lm + 0.006078896786357625*lm^2)*NL + 
          (-0.006403343671522976 + 0.01362663605512317*lm + 
            0.006078896786357625*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.063608559361633 - 0.11589550918226472*lm - 
          0.03299049324942028*lm^2) + CF^2*(0.05423828370642658 + 
          0.1918684321513802*lm + 0.1619533304971541*lm^2) + 
        CF*((0.022556350611029737 + 0.013437747033273191*lm + 
            0.0059982714998945965*lm^2)*NM + (0.026999531124687032 + 
            0.013437747033273191*lm + 0.0059982714998945965*lm^2)*NL + 
          (-0.006321244705814826 + 0.013437747033273191*lm + 
            0.0059982714998945965*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.0627146673533835 - 0.114288169368287*lm - 
          0.03254725479211196*lm^2) + CF^2*(0.05357264637871619 + 
          0.18904396055596395*lm + 0.15977743261582233*lm^2) + 
        CF*((0.02208086875808886 + 0.01324807100762958*lm + 
            0.005917682689474901*lm^2)*NM + (0.026612806748994005 + 
            0.01324807100762958*lm + 0.005917682689474901*lm^2)*NL + 
          (-0.006238793339862234 + 0.01324807100762958*lm + 
            0.005917682689474901*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.06180642210706043 - 0.11267845006917737*lm - 
          0.03210461489830726*lm^2) + CF^2*(0.052894420828521124 + 
          0.18620096641927625*lm + 0.1576044731371447*lm^2) + 
        CF*((0.021607880145119898 + 0.013057823837762801*lm + 
            0.005837202708783138*lm^2)*NM + (0.026225115300166028 + 
            0.013057823837762801*lm + 0.005837202708783138*lm^2)*NL + 
          (-0.006156073059342905 + 0.013057823837762801*lm + 
            0.005837202708783138*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.06088558879747841 - 0.11106795124955553*lm - 
          0.031662944934306936*lm^2) + CF^2*(0.05220445322282578 + 
          0.18334305948834287*lm + 0.15543627513205224*lm^2) + 
        CF*((0.021137862479985548 + 0.012867210490327498*lm + 
            0.005756899078964898*lm^2)*NM + (0.025836913382283635 + 
            0.012867210490327498*lm + 0.005756899078964898*lm^2)*NL + 
          (-0.006073163133264798 + 0.012867210490327498*lm + 
            0.005756899078964898*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.059953865203958 - 0.10945818212810689*lm - 
          0.031222590994719957*lm^2) + CF^2*(0.05150361203460805 + 
          0.18047369287932055*lm + 0.15327453761044343*lm^2) + 
        CF*((0.02067125778932174 + 0.012676425280712335*lm + 
            0.0056768347263127196*lm^2)*NM + (0.02544863147599841 + 
            0.012676425280712335*lm + 0.0056768347263127196*lm^2)*NL + 
          (-0.005990138751247564 + 0.012676425280712335*lm + 
            0.0056768347263127196*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.05901288017046249 - 0.1078505642181559*lm - 
          0.030783875161932393*lm^2) + CF^2*(0.050792781272717503 + 
          0.17759616360852987*lm + 0.15112084170403173*lm^2) + 
        CF*((0.020208473841868396 + 0.012485652134424157*lm + 
            0.005597068211260435*lm^2)*NM + (0.02506067466706191 + 
            0.012485652134424157*lm + 0.005597068211260435*lm^2)*NL + 
          (-0.005907071160174432 + 0.012485652134424157*lm + 
            0.005597068211260435*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.05806419266554121 - 0.10624643439527728*lm - 
          0.030347096717919422*lm^2) + CF^2*(0.050072854346859534 + 
          0.17471361380092681*lm + 0.1489766566152408*lm^2) + 
        CF*((0.01974988558776574 + 0.012295064864416168*lm + 
            0.005517653948712622*lm^2)*NM + (0.024673423417842094 + 
            0.012295064864416168*lm + 0.005517653948712622*lm^2)*NL + 
          (-0.0058240277997839715 + 0.012295064864416168*lm + 
            0.005517653948712622*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.05710929136305172 - 0.10464704797395907*lm - 
          0.029912533308798134*lm^2) + CF^2*(0.04934472853467885 + 
          0.1718290324831725*lm + 0.14684334533409993*lm^2) + 
        CF*((0.01929583660251944 + 0.01210482746099795*lm + 
            0.005438642419781478*lm^2)*NM + (0.02428723437129439 + 
            0.01210482746099795*lm + 0.005438642419781478*lm^2)*NL + 
          (-0.005741072436828691 + 0.01210482746099795*lm + 
            0.005438642419781478*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.05614959467327598 - 0.10305358177772439*lm - 
          0.029480442062727326*lm^2) + CF^2*(0.048609300017501675 + 
          0.16894525787782144*lm + 0.14472217012611596*lm^2) + 
        CF*((0.018846640525943762 + 0.01191509439135183*lm + 
            0.005360080375041332*lm^2)*NM + (0.02390244117822372 + 
            0.01191509439135183*lm + 0.005360080375041332*lm^2)*NL + 
          (-0.005658265297478928 + 0.01191509439135183*lm + 
            0.005360080375041332*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.05518645116188891 - 0.10146713718925555*lm - 
          0.029051060661931877*lm^2) + CF^2*(0.047867459451468405 + 
          0.16606498012368603*lm + 0.1426142977949383*lm^2) + 
        CF*((0.018402582487971064 + 0.01172601090602917*lm + 
            0.005282011029442159*lm^2)*NM + (0.023519355339890583 + 
            0.01172601090602917*lm + 0.005282011029442159*lm^2)*NL + 
          (-0.005575663197696708 + 0.01172601090602917*lm + 
            0.005282011029442159*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.054221140301351875 - 0.09988874316897406*lm - 
          0.02862460836976885*lm^2) + CF^2*(0.047120088041446954 + 
          0.1631907443552088*lm + 0.1405208047243198*lm^2) + 
        CF*((0.01796392051444047 + 0.011537713350114887*lm + 
            0.005204474249048882*lm^2)*NM + (0.02313826705909393 + 
            0.011537713350114887*lm + 0.005204474249048882*lm^2)*NL + 
          (-0.005493319671344651 + 0.011537713350114887*lm + 
            0.005204474249048882*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.05325487350565166 - 0.09831935923223137*lm - 
          0.02820128701386463*lm^2) + CF^2*(0.04636805408595691 + 
          0.16032495408074918*lm + 0.13844268170442636*lm^2) + 
        CF*((0.01753088690728608 + 0.01135032947703207*lm + 
            0.005127506729793569*lm^2)*NM + (0.02275944609382169 + 
            0.01135032947703207*lm + 0.005127506729793569*lm^2)*NL + 
          (-0.005411285095833753 + 0.01135032947703207*lm + 
            0.005127506729793569*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.05228886336072855 - 0.09675987837678186*lm - 
          0.027781281926440877*lm^2) + CF^2*(0.045612345873834254 + 
          0.15746987480612137*lm + 0.1363808385479825*lm^2) + 
        CF*((0.01710368959429415 + 0.011163978763213688*lm + 
            0.005051142168443796*lm^2)*NM + (0.022383142608407992 + 
            0.011163978763213688*lm + 0.005051142168443796*lm^2)*NL + 
          (-0.00532960681514436 + 0.011163978763213688*lm + 
            0.005051142168443796*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.05132404240001339 - 0.09521112995355718*lm - 
          0.027364762843015228*lm^2) + CF^2*(0.04485350367850211 + 
          0.15462763785556122*lm + 0.13433610850207475*lm^2) + 
        CF*((0.01668251344485269 + 0.010978772722097782*lm + 
            0.0049754114260027685*lm^2)*NM + (0.022009588017887355 + 
            0.010978772722097782*lm + 0.0049754114260027685*lm^2)*NL + 
          (-0.005248329260086395 + 0.010978772722097782*lm + 
            0.0049754114260027685*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.050361505619815373 - 0.09367388247495896*lm - 
          0.026951884760713272*lm^2) + CF^2*(0.044092499278509716 + 
          0.15180024434759642*lm + 0.13230925246168335*lm^2) + 
        CF*((0.01626752154841871 + 0.010794815216108476*lm + 
            0.004900342683766049*lm^2)*NM + (0.021638995821899674 + 
            0.010794815216108476*lm + 0.004900342683766049*lm^2)*NL + 
          (-0.005167494065689714 + 0.010794815216108476*lm + 
            0.004900342683766049*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.04940220621998971 - 0.09214884635594771*lm - 
          0.026542788757464242*lm^2) + CF^2*(0.04333012200756018 + 
          0.14898956928809828*lm + 0.1303009629911881*lm^2) + 
        CF*((0.01585885645386259 + 0.010612202765469841*lm + 
            0.004825961592266226*lm^2)*NM + (0.021271562425085884 + 
            0.010612202765469841*lm + 0.004825961592266226*lm^2)*NL + 
          (-0.005087140185639309 + 0.010612202765469841*lm + 
            0.004825961592266226*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.048447037257384605 - 0.0906366765841456*lm - 
          0.02613760277337565*lm^2) + CF^2*(0.042567136735476185 + 
          0.1461973657471402*lm + 0.12831186816020773*lm^2) + 
        CF*((0.015456641367183433 + 0.010431024852865166*lm + 
            0.004752291413341028*lm^2)*NM + (0.020907467941430443 + 
            0.010431024852865166*lm + 0.004752291413341028*lm^2)*NL + 
          (-0.005007304003691457 + 0.010431024852865166*lm + 
            0.004752291413341028*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.047496833571339846 - 0.08913797531599978*lm - 
          0.025736442355594337*lm^2) + CF^2*(0.04180428251998268 + 
          0.1434252690902223*lm + 0.1263425352001904*lm^2) + 
        CF*((0.015060981307995908 + 0.010251364223102095*lm + 
            0.004679353155562607*lm^2)*NM + (0.0205468769804614 + 
            0.010251364223102095*lm + 0.004679353155562607*lm^2)*NL + 
          (-0.004928019442024224 + 0.010251364223102095*lm + 
            0.004679353155562607*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.04655237338818626 - 0.08765329439678371*lm - 
          0.02533941136796427*lm^2) + CF^2*(0.041042270760122505 + 
          0.1406748012379747*lm + 0.12439347398818823*lm^2) + 
        CF*((0.014671965020039804 + 0.010073297177076381*lm + 
            0.004607165703266231*lm^2)*NM + (0.02018993941361776 + 
            0.010073297177076381*lm + 0.004607165703266231*lm^2)*NL + 
          (-0.0048493180664935485 + 0.010073297177076381*lm + 
            0.004607165703266231*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.045614382252163785 - 0.08618313780285687*lm - 
          0.024946602666786576*lm^2) + CF^2*(0.04028178815925384 + 
          0.13794737493166234*lm + 0.12246514036422501*lm^2) + 
        CF*((0.014289662031639033 + 0.00989689385944485*lm + 
            0.004535745939415741*lm^2)*NM + (0.019836791119443888 + 
            0.00989689385944485*lm + 0.004535745939415741*lm^2)*NL + 
          (-0.0047712291887799674 + 0.00989689385944485*lm + 
            0.004535745939415741*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.0446835312125672 - 0.084727964005165*lm - 
          0.02455809874397598*lm^2) + CF^2*(0.03952348836709497 + 
          0.13524429798470441*lm + 0.12055793928860935*lm^2) + 
        CF*((0.01391413178691539 + 0.009722218539523162*lm + 
            0.004465108862541087*lm^2)*NM + (0.019487554706576673 + 
            0.009722218539523162*lm + 0.004465108862541087*lm^2)*NL + 
          (-0.004693779965421172 + 0.009722218539523162*lm + 
            0.004465108862541087*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.043760442916408675 - 0.08328818825345569*lm - 
          0.024173972338890876*lm^2) + CF^2*(0.0387679996064466 + 
          0.13256677750302975*lm + 0.1186722278454643*lm^2) + 
        CF*((0.013545416203335508 + 0.009549329885017195*lm + 
            0.004395267697980159*lm^2)*NM + (0.019142340213758016 + 
            0.009549329885017195*lm + 0.004395267697980159*lm^2)*NL + 
          (-0.0046169954937454105 + 0.009549329885017195*lm + 
            0.004395267697980159*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.042845691329242916 - 0.08186418478111135*lm - 
          0.02379428702009323*lm^2) + CF^2*(0.038015919734553094 + 
          0.12991592405943142*lm + 0.11680831809863948*lm^2) + 
        CF*((0.013183545404230971 + 0.009378281228279663*lm + 
            0.004326234003653315*lm^2)*NM + (0.018801245786337618 + 
            0.009378281228279663*lm + 0.004326234003653315*lm^2)*NL + 
          (-0.004540898904717042 + 0.009378281228279663*lm + 
            0.004326234003653315*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.041939804584595106 - 0.08045628893087278*lm - 
          0.023419097738269303*lm^2) + CF^2*(0.037267817742629834 + 
          0.12729275580918994*lm + 0.11496647980604931*lm^2) + 
        CF*((0.012828537037752389 + 0.0092091208248567*lm + 
            0.004258017770594419*lm^2)*NM + (0.01846435832893211 + 
            0.0092091208248567*lm + 0.004258017770594419*lm^2)*NL + 
          (-0.004465511452728788 + 0.0092091208248567*lm + 
            0.004258017770594419*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.0410432667973708 - 0.07906479920204636*lm - 
          0.02304845135151454*lm^2) + CF^2*(0.03652423336525516 + 
          0.12469820253612335*lm + 0.1131469429983441*lm^2) + 
        CF*((0.012480397514148305 + 0.009041892104153824*lm + 
            0.004190627518457189*lm^2)*NM + (0.018131754134080733 + 
            0.009041892104153824*lm + 0.004190627518457189*lm^2)*NL + 
          (-0.0043908526023690615 + 0.009041892104153824*lm + 
            0.004190627518457189*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.04015652009998238 - 0.07768997922006188*lm - 
          0.02268238712415552*lm^2) + CF^2*(0.03578567731660246 + 
          0.12213310961991466*lm + 0.11134990042767255*lm^2) + 
        CF*((0.012139122742497213 + 0.008876633912107496*lm + 
            0.004124070386210095*lm^2)*NM + (0.017803499486887128 + 
            0.008876633912107496*lm + 0.004124070386210095*lm^2)*NL + 
          (-0.004316940112213073 + 0.008876633912107496*lm + 
            0.004124070386210095*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.03927996660215192 - 0.07633205962948242*lm - 
          0.02232093720025003*lm^2) + CF^2*(0.03505263155374552 + 
          0.11959824191708074*lm + 0.1095755098921365*lm^2) + 
        CF*((0.011804698903520114 + 0.00871338074579845*lm + 
            0.004058352218227278*lm^2)*NM + (0.017479651245764914 + 
            0.00871338074579845*lm + 0.004058352218227278*lm^2)*NL + 
          (-0.004243790115676965 + 0.00871338074579845*lm + 
            0.004058352218227278*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.03841397031074713 - 0.07499123991176426*lm - 
          0.021964127052872772*lm^2) + CF^2*(0.034325549637076895 + 
          0.1170942875492969*lm + 0.10782389644137542*lm^2) + 
        CF*((0.011477103182741618 + 0.008552162979986578*lm + 
            0.003993477645976868*lm^2)*NM + (0.017160257399513667 + 
            0.008552162979986578*lm + 0.003993477645976868*lm^2)*NL + 
          (-0.004171417198992398 + 0.008552162979986578*lm + 
            0.003993477645976868*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.03755885900477722 - 0.073667690129231*lm - 
          0.02161197591025996*lm^2) + CF^2*(0.03360485717461441 + 
          0.11462186159399743*lm + 0.10609515446854889*lm^2) + 
        CF*((0.011156304466693193 + 0.00839300708558515*lm + 
            0.00392945016550181*lm^2)*NM + (0.016845357601043803 + 
            0.00839300708558515*lm + 0.00392945016550181*lm^2)*NL + 
          (-0.004099834476355305 + 0.00839300708558515*lm + 
            0.00392945016550181*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.036714926062397055 - 0.07236155259686224*lm - 
          0.021264497159851025*lm^2) + CF^2*(0.03289095233976412 + 
          0.11218150967324131*lm + 0.10438934969381412*lm^2) + 
        CF*((0.010842264002318889 + 0.008235935840125127*lm + 
            0.0038662722108820046*lm^2)*NM + (0.016534983678146136 + 
            0.008235935840125127*lm + 0.0038662722108820046*lm^2)*NL + 
          (-0.0040290536623061105 + 0.008235935840125127*lm + 
            0.0038662722108820046*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.035882432237001216 - 0.07107294348360872*lm - 
          0.02092169873123043*lm^2) + CF^2*(0.0321842064520599 + 
          0.10977371143778428*lm + 0.10270652104422211*lm^2) + 
        CF*((0.010534936021158342 + 0.00808096853028876*lm + 
            0.003803945223860078*lm^2)*NM + (0.016229160121765736 + 
            0.00808096853028876*lm + 0.003803945223860078*lm^2)*NL + 
          (-0.003959085141406564 + 0.00808096853028876*lm + 
            0.003803945223860078*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.03506160738025526 - 0.06980195434503485*lm - 
          0.020583583458937047*lm^2) + CF^2*(0.03148496461153287 + 
          0.10739888394413855*lm + 0.10104668243478188*lm^2) + 
        CF*((0.010234268329469654 + 0.007928121146615945*lm + 
            0.003742469719806736*lm^2)*NM + (0.01592790455229216 + 
            0.007928121146615945*lm + 0.003742469719806736*lm^2)*NL + 
          (-0.003889938035272792 + 0.007928121146615945*lm + 
            0.003742469719806736*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.03425265211045293 - 0.06854865358915832*lm - 
          0.02025014942607344*lm^2) + CF^2*(0.03079354637814849 + 
          0.10505738492314445*lm + 0.09940982445526961*lm^2) + 
        CF*((0.009940202865647826 + 0.00777740657050766*lm + 
            0.0036818453501951706*lm^2)*NM + (0.015631228164420318 + 
            0.00777740657050766*lm + 0.0036818453501951706*lm^2)*NL + 
          (-0.003821620267032157 + 0.00777740657050766*lm + 
            0.0036818453501951706*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.03345573942508357 - 0.06731308787740875*lm - 
          0.01992139028961223*lm^2) + CF^2*(0.030110246488527056 + 
          0.10274951593923208*lm + 0.09779591596718733*lm^2) + 
        CF*((0.009652676226144205 + 0.007628834753668183*lm + 
            0.0036220709617476787*lm^2)*NM + (0.015339136151169582 + 
            0.007628834753668183*lm + 0.0036220709617476787*lm^2)*NL + 
          (-0.0037541386232759124 + 0.007628834753668183*lm + 
            0.0036220709617476787*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.032671016256919504 - 0.06609528346266283*lm - 
          0.019597295588262335*lm^2) + CF^2*(0.029435335602874646 + 
          0.10047552544012325*lm + 0.09620490561510602*lm^2) + 
        CF*((0.009371620161205272 + 0.0074824128901424545*lm + 
            0.0035631446524113336*lm^2)*NM + (0.015051628107674166 + 
            0.0074824128901424545*lm + 0.0035631446524113336*lm^2)*NL + 
          (-0.0036874988135592026 + 0.0074824128901424545*lm + 
            0.0035631446524113336*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.0318986049733072 - 0.06489524746633692*lm - 
          0.019277851033723648*lm^2) + CF^2*(0.028769061075721414 + 
          0.09823561169722578*lm + 0.09463672325646155*lm^2) + 
        CF*((0.009096962041695494 + 0.007338145581116941*lm + 
            0.0035050638243133907*lm^2)*NM + (0.014768698415376588 + 
            0.007338145581116941*lm + 0.0035050638243133907*lm^2)*NL + 
          (-0.003621705527540645 + 0.007338145581116941*lm + 
            0.0035050638243133907*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.03113860481866993 - 0.0637129690965286*lm - 
          0.01896303878612564*lm^2) + CF^2*(0.02811164774468679 + 
          0.09602992563740688*lm + 0.09309128131370768*lm^2) + 
        CF*((0.008828625298149168 + 0.007196034992662078*lm + 
            0.0034478252338410254*lm^2)*NM + (0.014490336607268735 + 
            0.007196034992662078*lm + 0.0034478252338410254*lm^2)*NL + 
          (-0.003556762489806554 + 0.007196034992662078*lm + 
            0.0034478252338410254*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.03039109330050405 - 0.06254842080920005*lm - 
          0.01865283771441251*lm^2) + CF^2*(0.02746329873205801 + 
          0.09385857356720935*lm + 0.0915684760525705*lm^2) + 
        CF*((0.008566529833576956 + 0.0070560810066020736*lm + 
            0.0033914250389840924*lm^2)*NM + (0.014216527714832713 + 
            0.0070560810066020736*lm + 0.0033914250389840924*lm^2)*NL + 
          (-0.003492672512462585 + 0.0070560810066020736*lm + 
            0.0033914250389840924*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.029656127519394636 - 0.06140155941438726*lm - 
          0.018347223642405867*lm^2) + CF^2*(0.026824196254510733 + 
          0.09172161979089849*lm + 0.09006818878999244*lm^2) + 
        CF*((0.008310592410710013 + 0.006918281364703764*lm + 
            0.0033358588440737945*lm^2)*NM + (0.013947252597336821 + 
            0.006918281364703764*lm + 0.0033358588440737945*lm^2)*NL + 
          (-0.003429437545555793 + 0.006918281364703764*lm + 
            0.0033358588440737945*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.02893374544377956 - 0.06027232712940436*lm - 
          0.018046169581244886*lm^2) + CF^2*(0.026194502436792833 + 
          0.08961908912400424*lm + 0.08859028703520216*lm^2) + 
        CF*((0.008060727015432204 + 0.006782631806380488*lm + 
            0.003281121742044525*lm^2)*NM + (0.013682488254141438 + 
            0.006782631806380488*lm + 0.003281121742044525*lm^2)*NL + 
          (-0.0033670587254056696 + 0.006782631806380488*lm + 
            0.003281121742044525*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.028223967130355847 - 0.05916065258098925*lm - 
          0.01774964594887379*lm^2) + CF^2*(0.025574360125631735 + 
          0.08755096930425753*lm + 0.0871346255671986*lm^2) + 
        CF*((0.00781684519711523 + 0.006649126200109896*lm + 
            0.0032272083543406892*lm^2)*NM + (0.013422208120665647 + 
            0.006649126200109896*lm + 0.0032272083543406892*lm^2)*NL + 
          (-0.003305536420872562 + 0.006649126200109896*lm + 
            0.0032272083543406892*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.02752679589117668 - 0.05806645175830926*lm - 
          0.01745762077721746*lm^2) + CF^2*(0.024963893700565166 + 
          0.08551721330201616*lm + 0.0857010474517948*lm^2) + 
        CF*((0.007578856387201971 + 0.006517756668766239*lm + 
            0.0031741128685849928*lm^2)*NM + (0.01316638234865881 + 
            0.006517756668766239*lm + 0.0031741128685849928*lm^2)*NL + 
          (-0.0032448702777009655 + 0.006517756668766239*lm + 
            0.0031741128685849928*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.026842219408595533 - 0.05698962891871294*lm - 
          0.0171700599076576*lm^2) + CF^2*(0.024363209878757203 + 
          0.08351774153243821*lm + 0.08428938500122822*lm^2) + 
        CF*((0.0073466681969007975 + 0.006388513709068362*lm + 
            0.003121829074119564*lm^2)*NM + (0.012914978071412269 + 
            0.006388513709068362*lm + 0.003121829074119564*lm^2)*NL + 
          (-0.0031850592609267005 + 0.006388513709068362*lm + 
            0.003121829074119564*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.026170210799328904 - 0.05593007744807731*lm - 
          0.016886927175394726*lm^2) + CF^2*(0.023772398511249942 + 
          0.08155244397179354*lm + 0.08289946067921047*lm^2) + 
        CF*((0.007120186695442811 + 0.006261386305344203*lm + 
            0.003070350395526314*lm^2)*NM + (0.012667959654535413 + 
            0.006261386305344203*lm + 0.003070350395526314*lm^2)*NL + 
          (-0.00312610169546265 + 0.006261386305344203*lm + 
            0.003070350395526314*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.025510729628957077 - 0.05488768067756046*lm - 
          0.016608184583254842*lm^2) + CF^2*(0.023191533368364308 + 
          0.0796211821804088*lm + 0.08153108795416013*lm^2) + 
        CF*((0.006899316669262287 + 0.006136362037811525*lm + 
            0.003019669924228153*lm^2)*NM + (0.012425288932907664 + 
            0.006136362037811525*lm + 0.003019669924228153*lm^2)*NL + 
          (-0.0030679953049069083 + 0.006136362037811525*lm + 
            0.003019669924228153*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.024863722878279274 - 0.05386231265852638*lm - 
          0.01633379246547432*lm^2) + CF^2*(0.02262067291233165 + 
          0.0777237912348239*lm + 0.08018407210323755*lm^2) + 
        CF*((0.006683961863709151 + 0.006013427185572724*lm + 
            0.0029697804482680576*lm^2)*NM + (0.012186925434404122 + 
            0.006013427185572724*lm + 0.0029697804482680576*lm^2)*NL + 
          (-0.003010737248641713 + 0.006013427185572724*lm + 
            0.0029697804482680576*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.024229125862958403 - 0.05285383889736492*lm - 
          0.016063709641972*lm^2) + CF^2*(0.02205986105545375 + 
          0.07586008157179744*lm + 0.07885821096968071*lm^2) + 
        CF*((0.006474025207845678 + 0.00589256682451911*lm + 
            0.002920674480358545*lm^2)*NM + (0.011952826590977473 + 
            0.00589256682451911*lm + 0.002920674480358545*lm^2)*NL + 
          (-0.002954324157263825 + 0.00589256682451911*lm + 
            0.002920674480358545*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.023606863107934476 - 0.05186211705188283*lm - 
          0.01579789356359409*lm^2) + CF^2*(0.021509127902357525 + 
          0.07402984074684114*lm + 0.07755329567582553*lm^2) + 
        CF*((0.00626940902332792 + 0.005773764920337089*lm + 
            0.002872344284289834*lm^2)*NM + (0.011722947937663037 + 
            0.005773764920337089*lm + 0.002872344284289834*lm^2)*NL + 
          (-0.0028987521664688054 + 0.005773764920337089*lm + 
            0.002872344284289834*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.022996849178106023 - 0.05088699759089501*lm - 
          0.015536300448794726*lm^2) + CF^2*(0.020968490475132728 + 
          0.07223283510998785*lm + 0.0762691112940832*lm^2) + 
        CF*((0.006070015218241907 + 0.005657004416805272*lm + 
            0.0028247818997808594*lm^2)*NM + (0.011497243300057206 + 
            0.005657004416805272*lm + 0.0028247818997808594*lm^2)*NL + 
          (-0.002844016949338941 + 0.005657004416805272*lm + 
            0.0028247818997808594*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.022398989466788973 - 0.049928324418596175*lm - 
          0.01527888541219344*lm^2) + CF^2*(0.020437953420342447 + 
          0.07046881140150908*lm + 0.07500543747804053*lm^2) + 
        CF*((0.0058757454667149635 + 0.005542267319567765*lm + 
            0.002777979165853353*lm^2)*NM + (0.011275664970802722 + 
            0.005542267319567765*lm + 0.002777979165853353*lm^2)*NL + 
          (-0.0027901137472077365 + 0.005542267319567765*lm + 
            0.002777979165853353*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.021813180943464787 - 0.04898593546524467*lm - 
          0.015025602585429875*lm^2) + CF^2*(0.01991750969708032 + 
          0.06873749827029599*lm + 0.07376204905574667*lm^2) + 
        CF*((0.005686501375065894 + 0.005429534775564844*lm + 
            0.002731927742805432*lm^2)*NM + (0.011058163875596806 + 
            0.005429534775564844*lm + 0.002731927742805432*lm^2)*NL + 
          (-0.002737037399068265 + 0.005429534775564844*lm + 
            0.002731927742805432*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.02123931286232524 - 0.04805966324564079*lm - 
          0.014776405230716196*lm^2) + CF^2*(0.019407141245416048 + 
          0.06703860771760438*lm + 0.07253871658715223*lm^2) + 
        CF*((0.005502184635267809 + 0.005318787148297883*lm + 
            0.00268661913285749*lm^2)*NM + (0.010844689729220803 + 
            0.005318787148297883*lm + 0.00268661913285749*lm^2)*NL + 
          (-0.0026847823696326068 + 0.005318787148297883*lm + 
            0.00268661913285749*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.02067714840268117 - 0.04714929771291784*lm - 
          0.014531245818279056*lm^2) + CF*(0.018906622806670142 + 
          0.0653716518577956*lm + 0.071335206744279*lm^2) + 
        0.005322684589450623*NM + 0.00520999724605272*lm*NM + 
        0.0026420446942325556*lm^2*NM + 0.010635177020662055*NL + 
        0.00520999724605272*lm*NL + 0.0026420446942325556*lm^2*NL - 
        0.002633341597202731*NH + 0.00520999724605272*lm*NH + 
        0.0026420446942325556*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.0201268220376455 - 0.046254743982730634*lm - 
          0.014290076266263661*lm^2) + CF*(0.01841634326218842 + 
          0.06373671445867235*lm + 0.0701512834889307*lm^2) + 
        0.005147930906244815*NM + 0.005103158943509847*lm*NM + 
        0.002598195684775211*lm^2*NM + 0.010429604272716924*NL + 
        0.005103158943509847*lm*NL + 0.002598195684775211*lm^2*NL - 
        0.002582711436596382*NH + 0.005103158943509847*lm*NH + 
        0.002598195684775211*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.01958806068945897 - 0.045375776083300456*lm - 
          0.014052847783020682*lm^2) + CF*(0.017936019657329882 + 
          0.062133243880684884*lm + 0.06898670729846516*lm^2) + 
        0.004977811140823083*NM + 0.004998242445520918*lm*NM + 
        0.0025550632332764873*lm^2*NM + 0.010227901357015397*NL + 
        0.004998242445520918*lm*NL + 0.0025550632332764873*lm^2*NL - 
        0.0025328839711081684*NH + 0.004998242445520918*lm*NH + 
        0.0025550632332764873*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.019060729649421716 - 0.04451221003039293*lm - 
          0.013819511157254473*lm^2) + CF*(0.017465596971317547 + 
          0.060560899401408796*lm + 0.06784123659015832*lm^2) + 
        0.0048122286962575455*NM + 0.004895225688144787*lm*NM + 
        0.002512638392228086*lm^2*NM + 0.01003001458889873*NL + 
        0.004895225688144787*lm*NL + 0.002512638392228086*lm^2*NL - 
        0.002483852428505136*NH + 0.004895225688144787*lm*NH + 
        0.002512638392228086*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.018544689417003254 - 0.0436638587557558*lm - 
          0.013590016778813616*lm^2) + CF*(0.017005012075885496 + 
          0.05901932971751829*lm + 0.06671462782326684*lm^2) + 
        0.004651087652415111*NM + 0.004794086139006995*lm*NM + 
        0.0024709121416024754*lm^2*NM + 0.009835889709154505*NL + 
        0.004794086139006995*lm*NL + 0.0024709121416024754*lm^2*NL - 
        0.00243560978302475*NH + 0.004794086139006995*lm*NH + 
        0.0024709121416024754*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.01803979621584179 - 0.042830532504589354*lm - 
          0.013364314715893296*lm^2) + CF*(0.016554194296775182 + 
          0.0575081740136004*lm + 0.06560663587802164*lm^2) + 
        0.0044942928588036744*NM + 0.004694800851702095*lm*NM + 
        0.0024298754028896905*lm^2*NM + 0.009645471991194721*NL + 
        0.004694800851702095*lm*NL + 0.0024298754028896905*lm^2*NL - 
        0.002388148776378573*NH + 0.004694800851702095*lm*NH + 
        0.0024298754028896905*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.017545902478849133 - 0.042012039209306996*lm - 
          0.013142354787233164*lm^2) + CF*(0.016113065952202736 + 
          0.05602706297177593*lm + 0.06451701441005371*lm^2) + 
        0.004341750018898701*NM + 0.004597346517043184*lm*NM + 
        0.0023895190522242116*lm^2*NM + 0.009458706341047349*NL + 
        0.004597346517043184*lm*NL + 0.0023895190522242116*lm^2*NL - 
        0.0023414619377083753*NH + 0.004597346517043184*lm*NH + 
        0.0023895190522242116*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.017062857303939152 - 0.04120818484075885*lm - 
          0.012924086629581364*lm^2) + CF*(0.015681542868754776 + 
          0.054575619724791156*lm + 0.06344551618158124*lm^2) + 
        0.004193365766491157*NM + 0.004501699511309227*lm*NM + 
        0.002349833932651157*lm^2*NM + 0.009275537390553125*NL + 
        0.004501699511309227*lm*NL + 0.002349833932651157*lm^2*NL - 
        0.002295541602538693*NH + 0.004501699511309227*lm*NH + 
        0.002349833932651157*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.01659050688183351 - 0.04041877373803937*lm - 
          0.01270945976068186*lm^2) + CF*(0.015259534875197198 + 
          0.05315346075514356*lm + 0.062391893370620045*lm^2) + 
        0.004049047734567817*NM + 0.004407835941634496*lm*NM + 
        0.0023108108655785203*lm^2*NM + 0.009095909584140159*NL + 
        0.004407835941634496*lm*NL + 0.0023108108655785203*lm^2*NL - 
        0.0022503799307682093*NH + 0.004407835941634496*lm*NH + 
        0.0023108108655785203*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.016128694897336295 - 0.03964360891794924*lm - 
          0.012498423638029069*lm^2) + CF*(0.014846946274704285 + 
          0.05176019674270783*lm + 0.06135589785941543*lm^2) + 
        0.003908704617206637*NM + 0.004315731688678259*lm*NM + 
        0.0022724406614598306*lm^2*NM + 0.008919767259530541*NL + 
        0.004315731688678259*lm*NL + 0.0022724406614598306*lm^2*NL - 
        0.002205968923740775*NH + 0.004315731688678259*lm*NH + 
        0.0022724406614598306*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.015677262905409505 - 0.038882492365134254*lm - 
          0.012290927713621507*lm^2) + CF*(0.014443676296034283 + 
          0.05039543336323307*lm + 0.06033728150323286*lm^2) + 
        0.003772246224942867*NM + 0.004225362446707036*lm*NM + 
        0.002234714129749365*lm^2*NM + 0.00874705472271559*NL + 
        0.004225362446707036*lm*NL + 0.002234714129749365*lm^2*NL - 
        0.002162300440435346*NH + 0.004225362446707036*lm*NH + 
        0.002234714129749365*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.015236050683323617 - 0.038135225303877245*lm - 
          0.012086921484934371*lm^2) + CF*(0.014049619524192942 + 
          0.049058772039990484*lm + 0.05933579638058691*lm^2) + 
        0.0036395835340360667*NM + 0.004136703761216008*lm*NM + 
        0.0021976220881698857*lm^2*NM + 0.00857771631751965*NL + 
        0.004136703761216008*lm*NL + 0.0021976220881698857*lm^2*NL - 
        0.0021193662128126604*NH + 0.004136703761216008*lm*NH + 
        0.0021976220881698857*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.014804896560101788 - 0.03740160845247523*lm - 
          0.011886354542319713*lm^2) + CF*(0.01366466631113852 + 
          0.04774981065076133*lm + 0.05835119502593314*lm^2) + 
        0.0035106287300438834*NM + 0.004049731064210769*lm*NM + 
        0.0021611553713308572*lm^2*NM + 0.008411696490056372*NL + 
        0.004049731064210769*lm*NL + 0.0021611553713308572*lm^2*NL - 
        0.0020771578603550277*NH + 0.004049731064210769*lm*NH + 
        0.0021611553713308572*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.014383637724422787 - 0.03668144226109124*lm - 
          0.011689176613032322*lm^2) + CF*(0.01328870316709087 + 
          0.04646814419226856*lm + 0.057383230645795036*lm^2) + 
        0.003385295246085457*NM + 0.003964419707265308*lm*NM + 
        0.0021253048387331495*lm^2*NM + 0.008248939848366145*NL + 
        0.003964419707265308*lm*NL + 0.0021253048387331495*lm^2*NL - 
        0.002035666903834236*NH + 0.003964419707265308*lm*NH + 
        0.0021253048387331495*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.0139721105120961 - 0.035974527133929755*lm - 
          0.011495337602069153*lm^2) + CF*(0.012921613133013548 + 
          0.045213365404071365*lm + 0.05643165731924857*lm^2) + 
        0.0032634977961554837*NM + 0.0038807449924670935*lm*NM + 
        0.0020900613821943914*lm^2*NM + 0.008089391217508811*NL + 
        0.0038807449924670935*lm*NL + 0.0020900613821943914*lm^2*NL - 
        0.001994884778341228*NH + 0.0038807449924670935*lm*NH + 
        0.0020900613821943914*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.013570150674172944 - 0.035280663636545556*lm - 
          0.011304787630000642*lm^2) + CF*(0.012563276134841848 + 
          0.043985065353860944*lm + 0.055496230183639514*lm^2) + 
        0.0031451524038292773*NM + 0.003798682201355242*lm*NM + 
        0.0020554159327273894*lm^2*NM + 0.007932995690371938*NL + 
        0.003798682201355242*lm*NL + 0.0020554159327273894*lm^2*NL - 
        0.0019548028456099257*NH + 0.003798682201355242*lm*NH + 
        0.0020554159327273894*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.0131775936267092 - 0.03459965268905862*lm - 
          0.01111747706796296*lm^2) + CF*(0.012213569320031302 + 
          0.042782833986016885*lm + 0.05457670560636362*lm^2) + 
        0.0030301764266795566*NM + 0.0037182066219531127*lm*NM + 
        0.0020213594669023565*lm^2*NM + 0.007779698674441674*NL + 
        0.0037182066219531127*lm*NL + 0.0020213594669023565*lm^2*NL - 
        0.0019154124056663037*NH + 0.0037182066219531127*lm*NH + 
        0.0020213594669023565*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.012794274683150215 - 0.033931295746011586*lm - 
          0.01093335656997164*lm^2) + CF*(0.011872367377000965 + 
          0.04160626063520748*lm + 0.05367284134349714*lm^2) + 
        0.002918488576707089*NM + 0.0036392935739921408*lm*NM + 
        0.001987883012722116*lm^2*NM + 0.0076294459347706*NL + 
        0.0036392935739921408*lm*NL + 0.001987883012722116*lm^2*NL - 
        0.0018767047078326231*NH + 0.0036392935739921408*lm*NH + 
        0.001987883012722116*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.012420029270263274 - 0.033275394963572485*lm - 
          0.010752377102708637*lm^2) + CF*(0.011539542838043619 + 
          0.04045493450674391*lm + 0.05278439668602422*lm^2) + 
        0.0028100089370697214*NM + 0.0035619184324194456*lm*NM + 
        0.001954977655037934*lm^2*NM + 0.007482183633364994*NL + 
        0.0035619184324194456*lm*NL + 0.001954977655037934*lm^2*NL - 
        0.0018386709611155582*NH + 0.0035619184324194456*lm*NH + 
        0.001954977655037934*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.012054693128501014 - 0.03263175335475203*lm - 
          0.0105744899729271*lm^2) + CF*(0.011214966366271392 + 
          0.03932844512532668*lm + 0.0519111325943694*lm^2) + 
        0.0027046589753776285*NM + 0.0034860566492775696*lm*NM + 
        0.0019226345405322*lm^2*NM + 0.00733785836520244*NL + 
        0.0034860566492775696*lm*NL + 0.0019226345405322*lm^2*NL - 
        0.0018013023440058191*NH + 0.0034860566492775696*lm*NH + 
        0.0019226345405322*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.011698102497638207 - 0.032000174933273846*lm - 
          0.01039964685261054*lm^2) + CF*(0.01089850702716009 + 
          0.038226382753754444*lm + 0.05105281182190628*lm^2) + 
        0.0026023615538068303*NM + 0.0034116837740407395*lm*NM + 
        0.0018908448822928254*lm^2*NM + 0.007196417191079813*NL + 
        0.0034116837740407395*lm*NL + 0.0018908448822928254*lm^2*NL - 
        0.0017645900137157847*NH + 0.0034116837740407395*lm*NH + 
        0.0018908448822928254*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.011350094288485203 - 0.03138046484670564*lm - 
          0.010227799802016064*lm^2) + CF*(0.010590032545249144 + 
          0.03714833878309863*lm + 0.05020919902807886*lm^2) + 
        0.0025030409362680533*NM + 0.0033387754724882174*lm*NM + 
        0.0018595999640029206*lm^2*NM + 0.007057807667481268*NL + 
        0.0033387754724882174*lm*NL + 0.0018595999640029206*lm^2*NL - 
        0.0017285251148806047*NH + 0.0033387754724882174*lm*NH + 
        0.0018595999640029206*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.011010506241443589 - 0.030772429499430612*lm - 
          0.010058901290724512*lm^2) + CF*(0.010289409546546521 + 
          0.036093906095783335*lm + 0.04938006088173851*lm^2) + 
        0.002406622792853863*NM + 0.0032673075441916294*lm*NM + 
        0.001828891143768093*lm^2*NM + 0.006921977873645982*NL + 
        0.0032673075441916294*lm*NL + 0.001828891143768093*lm^2*NL - 
        0.0016930987877472115*NH + 0.0032673075441916294*lm*NH + 
        0.001828891143768093*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.010679177072633574 - 0.030175876666010813*lm - 
          0.009892904216813934*lm^2) + CF*(0.009996503787179397 + 
          0.03506267940294836*lm + 0.0485651661552684*lm^2) + 
        0.0023130342017735933*NM + 0.0031972559386896507*lm*NM + 
        0.0017987098576025334*lm^2*NM + 0.006788876436005915*NL + 
        0.0031972559386896507*lm*NL + 0.0017987098576025334*lm^2*NL - 
        0.0016583021758747047*NH + 0.0031972559386896507*lm*NH + 
        0.0017987098576025334*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.01035594660828792 - 0.02959061559546787*lm - 
          0.009729761924266741*lm^2) + CF*(0.00971118036882202 + 
          0.0340542555574133*lm + 0.047764285810036736*lm^2) + 
        0.00222220364897292*NM + 0.003128596770420036*lm*NM + 
        0.0017690476225939531*lm^2*NM + 0.006658452550154948*NL + 
        0.003128596770420036*lm*NL + 0.0017690476225939531*lm^2*NL - 
        0.0016241264333686205*NH + 0.003128596770420036*lm*NH + 
        0.0017690476225939531*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.010040655908074021 - 0.029016457106981253*lm - 
          0.009569428218715063*lm^2) + CF*(0.009433303941422005 + 
          0.033068233843503575*lm + 0.04697719307369213*lm^2) + 
        0.0021340610256229383*NM + 0.0030613063324757507*lm*NM + 
        0.0017398960397663752*lm^2*NM + 0.006530656000502165*NL + 
        0.0030613063324757507*lm*NL + 0.0017398960397663752*lm^2*NL - 
        0.0015905627316706876*NH + 0.0030613063324757507*lm*NH + 
        0.0017398960397663752*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.009733147377973893 - 0.028453213677480164*lm - 
          0.009411857381623307*lm^2) + CF*(0.009162738893735565 + 
          0.03210421624494367*lm + 0.04620366350978714*lm^2) + 
        0.002048537623652268*NM + 0.0029953611092488515*lm*NM + 
        0.001711246796658783*lm^2*NM + 0.006405437177753933*NL + 
        0.0029953611092488515*lm*NL + 0.001711246796658783*lm^2*NL - 
        0.0015576022659247858*NH + 0.0029953611092488515*lm*NH + 
        0.001711246796658783*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.009433264873321313 - 0.02790069952158207*lm - 
          0.009257004183001738*lm^2) + CF*(0.008899349532170829 + 
          0.031161807691969787*lm + 0.04544347508019035*lm^2) + 
        0.001965566129484985*NM + 0.002930737788022784*lm*NM + 
        0.0016830916696366797*lm^2*NM + 0.006282747094361697*NL + 
        0.002930737788022784*lm*NL + 0.0016830916696366797*lm^2*NL - 
        0.0015252362609389856*NH + 0.002930737788022784*lm*NH + 
        0.0016830916696366797*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.009140853792566102 - 0.02735873066430894*lm - 
          0.009104823892739864*lm^2) + CF*(0.008643000248426654 + 
          0.030240616288762633*lm + 0.044696408200722966*lm^2) + 
        0.0018850806161370588*NM + 0.002867413269570913*lm*NM + 
        0.0016554225259527025*lm^2*NM + 0.006162537398065064*NL + 
        0.002867413269570913*lm*NL + 0.0016554225259527025*lm^2*NL - 
        0.0014934559767627127*NH + 0.002867413269570913*lm*NH + 
        0.0016554225259527025*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.008855761162307582 - 0.026827125006991158*lm - 
          0.008955272290643721*lm^2) + CF*(0.008393555676402183 + 
          0.02934025352225192*lm + 0.04396224579043281*lm^2) + 
        0.0018070165338143964*NM + 0.0028053646778163745*lm*NM + 
        0.0016282313255715855*lm^2*NM + 0.0060447603836527265*NL + 
        0.0028053646778163745*lm*NL + 0.0016282313255715855*lm^2*NL - 
        0.0014622527138973098*NH + 0.0028053646778163745*lm*NH + 
        0.0016282313255715855*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.008577835714112426 - 0.026305702386748953*lm - 
          0.008808305675256688*lm^2) + CF*(0.008150880838840014 + 
          0.02846033445329651*lm + 0.043240773314896466*lm^2) + 
        0.0017313106991465525*NM + 0.0027445693686057*lm*NM + 
        0.0016015101227739434*lm^2*NM + 0.005929369003057164*NL + 
        0.0027445693686057*lm*NL + 0.0016015101227739434*lm^2*NL - 
        0.0014316178181574962*NH + 0.0027445693686057*lm*NH + 
        0.0016015101227739434*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.008306927953606496 - 0.02579428462992205*lm - 
          0.00866388087153916*lm^2) + CF*(0.00791484128415315 + 
          0.027600477891198672*lm + 0.042531778823919515*lm^2) + 
        0.0016579012831816357*NM + 0.0026850049376461868*lm*NM + 
        0.0015752510675525746*lm^2*NM + 0.005816316873892693*NL + 
        0.0026850049376461868*lm*NL + 0.0015752510675525746*lm^2*NL - 
        0.0014015426852005037*NH + 0.0026850049376461868*lm*NH + 
        0.0015752510675525746*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.008042890222305739 - 0.02529269559979988*lm - 
          0.008521955237478401*lm^2) + CF*(0.00768530321387317 + 
          0.026760306552466927*lm + 0.041835052983984884*lm^2) + 
        0.0015867277982598688*NM + 0.0026266492276545627*lm*NM + 
        0.001549446406814255*lm^2*NM + 0.005705558286540466*NL + 
        0.0026266492276545627*lm*NL + 0.001549446406814255*lm^2*NL - 
        0.0013720187647389551*NH + 0.0026266492276545627*lm*NH + 
        0.001549446406814255*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.007785576752627779 - 0.024800761238987102*lm - 
          0.00838248666969606*lm^2) + CF*(0.007462133601144099 + 
          0.025939447204699897*lm + 0.04115038910578066*lm^2) + 
        0.0015177310838756664*NM + 0.002569480334762203*lm*NM + 
        0.0015240884853992835*lm^2*NM + 0.0055970482098783*NL + 
        0.002569480334762203*lm*NL + 0.0015240884853992835*lm^2*NL - 
        0.001343037564452884*NH + 0.002569480334762203*lm*NH + 
        0.0015240884853992835*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.007534843716503419 - 0.024318309606722613*lm - 
          0.008245433608117162*lm^2) + CF*(0.007245200300673531 + 
          0.02513753079642311*lm + 0.04047758316712062*lm^2) + 
        0.0014508532916309017*NM + 0.0025134766142199745*lm*NM + 
        0.0014991697469303933*lm^2*NM + 0.0054907422957477785*NL + 
        0.0025134766142199745*lm*NL + 0.0014991697469303933*lm^2*NL - 
        0.0013145906536156308*NH + 0.0025134766142199745*lm*NH + 
        0.0014991697469303933*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.007290549267985866 - 0.02384517091145412*lm - 
          0.008110755039760992*lm^2) + CF*(0.007034372150539628 + 
          0.02435419257367187*lm + 0.03981643383155396*lm^2) + 
        0.0013860378693752787*NM + 0.0024586166854436604*lm*NM + 
        0.0014746827345019984*lm^2*NM + 0.005386596882245935*NL + 
        0.0024586166854436604*lm*NL + 0.0014746827345019984*lm^2*NL - 
        0.0012866696664477356*NH + 0.0024586166854436604*lm*NH + 
        0.0014746827345019984*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.007052553580235036 - 0.02338117753895521*lm - 
          0.007978410501710918*lm^2) + CF*(0.0068295190662396605 + 
          0.023589072184075986*lm + 0.03916674246294451*lm^2) + 
        0.001323229544623327*NM + 0.0024048794364389166*lm*NM + 
        0.001450620091220167*lm^2*NM + 0.005284568995923936*NL + 
        0.0024048794364389166*lm*NL + 0.001450620091220167*lm^2*NL - 
        0.0012592663052123335*NH + 0.0024048794364389166*lm*NH + 
        0.001450620091220167*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.006820718877234781 - 0.022926164076257288*lm - 
          0.007848360083317197*lm^2) + CF*(0.006630512127352957 + 
          0.022841813769166476*lm + 0.03852831313628442*lm^2) + 
        0.0012623743073315295*NM + 0.0023522440276428*lm*NM + 
        0.0014269745606031268*lm^2*NM + 0.005184616352970531*NL + 
        0.0023522440276428*lm*NL + 0.0014269745606031268*lm^2*NL - 
        0.0012323723430649862*NH + 0.0023522440276428*lm*NH + 
        0.0014269745606031268*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.006594909460582203 - 0.022479967331654912*lm - 
          0.007720564427683754*lm^2) + CF*(0.006437223657178381 + 
          0.02211206604558997*lm + 0.03790095264499298*lm^2) + 
        0.001203419392113412*NM + 0.0023006898952170492*lm*NM + 
        0.0014037389868515916*lm^2*NM + 0.0050866973594536355*NL + 
        0.0023006898952170492*lm*NL + 0.0014037389868515916*lm^2*NL - 
        0.0012059796266703216*NH + 0.0023006898952170492*lm*NH + 
        0.0014037389868515916*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.006374991731670478 - 0.022042426351029827*lm - 
          0.007594984732487185*lm^2) + CF*(0.006249527295693868 + 
          0.0213994823758838*lm + 0.03728447050493709*lm^2) + 
        0.0011463132599650887*NM + 0.0022501967538265705*lm*NM + 
        0.00138090631499767*lm^2*NM + 0.00499077111068923*NL + 
        0.0022501967538265705*lm*NL + 0.00138090631499767*lm^2*NL - 
        0.0011800800785973186*NH + 0.0022501967538265705*lm*NH + 
        0.00138090631499767*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.006160834209569611 - 0.02161338243072636*lm - 
          0.007471582750173568*lm^2) + CF*(0.006067298066173148 + 
          0.02070372082943316*lm + 0.03667867895539752*lm^2) + 
        0.001091005579568717*NM + 0.002200744598934876*lm*NM + 
        0.0013584695909406488*lm^2*NM + 0.004896797389802795*NL + 
        0.002200744598934876*lm*NL + 0.0013584695909406488*lm^2*NL - 
        0.0011546656995045585*NH + 0.002200744598934876*lm*NH + 
        0.0013584695909406488*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.005952307544893382 - 0.02119267912719891*lm - 
          0.007350320787576118*lm^2) + CF*(0.0058904124357825076 + 
          0.020024444234201504*lm + 0.03608339295719185*lm^2) + 
        0.0010374472082365826*NM + 0.002152313708646651*lm*NM + 
        0.0013364219613774759*lm^2*NM + 0.004804736665544734*NL + 
        0.002152313708646651*lm*NL + 0.0013364219613774759*lm^2*NL - 
        0.0011297285701262706*NH + 0.002152313708646651*lm*NH + 
        0.0013364219613774759*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.00574928452992529 - 0.02078016226364073*lm - 
          0.007231161704994354*lm^2) + CF*(0.005718748370468458 + 
          0.019361320219796693*lm + 0.03549843018815411*lm^2) + 
        0.000985590172554075*NM + 0.0021048846451260667*lm*NM + 
        0.0013147566736353372*lm^2*NM + 0.0047145500894176795*NL + 
        0.0021048846451260667*lm*NL + 0.0013147566736353372*lm^2*NL - 
        0.001105260853069521*NH + 0.0021048846451260667*lm*NH + 
        0.0013147566736353372*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.00555164010526165 - 0.0203756799337923*lm - 
          0.0071140689147732*lm^2) + CF*(0.005552185384435336 + 
          0.01871402125240737*lm + 0.03492361103615935*lm^2) + 
        0.0009353876487756135*NM + 0.002058438255618025*lm*NM + 
        0.001293467075413309*lm^2*NM + 0.0046261994921701745*NL + 
        0.002058438255618025*lm*NL + 0.001293467075413309*lm^2*NL - 
        0.001081254794432441*NH + 0.002058438255618025*lm*NH + 
        0.001293467075413309*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.005359251363215928 - 0.019979082503117272*lm - 
          0.006999006379418215*lm^2) + CF*(0.005390604584500337 + 
          0.01808222466211793*lm + 0.03435875858987124*lm^2) + 
        0.0008867939430236497*NM + 0.0020129556730980993*lm*NM + 
        0.0012725466144396754*lm^2*NM + 0.004539647379708044*NL + 
        0.0020129556730980993*lm*NL + 0.0012725466144396754*lm^2*NL - 
        0.0010577027252529525*NH + 0.0020129556730980993*lm*NH + 
        0.0012725466144396754*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.005171997548215125 - 0.019590222607523883*lm - 
          0.006885938609281214*lm^2) + CF*(0.005233888709602122 + 
          0.017465612663084842*lm + 0.03380369862738051*lm^2) + 
        0.0008397644713371459*NM + 0.001968418316575631*lm*NM + 
        0.00125198883805113*lm^2*NM + 0.004454856928471712*NL + 
        0.001968418316575631*lm*NL + 0.00125198883805113*lm^2*NL - 
        0.0010345970627970186*NH + 0.001968418316575631*lm*NH + 
        0.00125198883805113*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.004989760054406273 - 0.019208955149800516*lm - 
          0.006774830659848525*lm^2) + CF*(0.005081922165728136 + 
          0.016863872367033038*lm + 0.033258259602892755*lm^2) + 
        0.000794255739612458*NM + 0.0019248078910731627*lm*NM + 
        0.0012317873926997317*lm^2*NM + 0.004371791980324851*NL + 
        0.0019248078910731627*lm*NL + 0.0012317873926997317*lm^2*NL - 
        0.001011930311695059*NH + 0.0019248078910731627*lm*NH + 
        0.0012317873926997317*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.004812422420679042 - 0.018835137293924966*lm - 
          0.006665648128662318*lm^2) + CF*(0.004934591056514971 + 
          0.0162766957905078*lm + 0.03272227263161502*lm^2) + 
        0.0007502253234762673*NM + 0.001882106387304168*lm*NM + 
        0.0012119360233931488*lm^2*NM + 0.004290417036997012*NL + 
        0.001882106387304168*lm*NL + 0.0012119360233931488*lm^2*NL - 
        0.0009896950649347681*NH + 0.001882106387304168*lm*NH + 
        0.0012119360233931488*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.00463987032329896 - 0.01846862845739839*lm - 
          0.006558357151903752*lm^2) + CF*(0.004791783209765607 + 
          0.0157037798562955*lm + 0.032195571472982056*lm^2) + 
        0.0007076318481271327*NM + 0.0018402960810699137*lm*NM + 
        0.0011924285730734094*lm^2*NM + 0.004210697254120335*NL + 
        0.0018402960810699137*lm*NL + 0.0011924285730734094*lm^2*NL - 
        0.000967884004718207*NH + 0.0018402960810699137*lm*NH + 
        0.0011924285730734094*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.004471991566334777 - 0.01810929030174692*lm - 
          0.0064529244006649444*lm^2) + CF*(0.004653388200117147 + 
          0.015144826389405395*lm + 0.03167799251235518*lm^2) + 
        0.0006664349681793458*NM + 0.0017993595323951555*lm*NM + 
        0.0011732589819390808*lm^2*NM + 0.0041325984348979505*NL + 
        0.0017993595323951555*lm*NL + 0.0011732589819390808*lm^2*NL - 
        0.0009464899031906856*NH + 0.0017993595323951555*lm*NH + 
        0.0011732589819390808*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0043086760700531525 - 0.017756986721326026*lm - 
          0.006349317076935323*lm^2) + CF*(0.004519297368082755 + 
          0.01459954210798437*lm + 0.031169374741318857*lm^2) + 
        0.0006265953475400677*NM + 0.0017592795844213517*lm*NM + 
        0.0011544212867155132*lm^2*NM + 0.004056087023439407*NL + 
        0.0017592795844213517*lm*NL + 0.0011544212867155132*lm^2*NL - 
        0.000925505623048605*NH + 0.0017592795844213517*lm*NH + 
        0.0011544212867155132*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.004149815857443906 - 0.017411583830555428*lm - 
          0.006247502909326334*lm^2) + CF*(0.004389403835681797 + 
          0.014067638609517394*lm + 0.03066955973669291*lm^2) + 
        0.0005880746393481779*NM + 0.0017200393620750586*lm*NM + 
        0.0011359096198775153*lm^2*NM + 0.003981130097796251*NL + 
        0.0017200393620750586*lm*NL + 0.0011359096198775153*lm^2*NL - 
        0.000904924118033105*NH + 0.0017200393620750586*lm*NH + 
        0.0011359096198775153*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0039953050390297 - 0.0170729499497053*lm - 
          0.006147450148557165*lm^2) + CF*(0.00426360251886292 + 
          0.013548832352647843*lm + 0.03017839163837154*lm^2) + 
        0.0005508354660008918*NM + 0.0016816222705282313*lm*NM + 
        0.0011177182088285755*lm^2*NM + 0.003907695362728828*NL + 
        0.0016816222705282313*lm*NL + 0.0011177182088285755*lm^2*NL - 
        0.0008847384333160451*NH + 0.0016816222705282313*lm*NH + 
        0.0011177182088285755*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.003845039796105094 - 0.016740955589347874*lm - 
          0.00604912756272276*lm^2) + CF*(0.004141790136915659 + 
          0.013042844634934382*lm + 0.029695717126093552*lm^2) + 
        0.0005148413992919668*NM + 0.0016440119934662478*lm*NM + 
        0.001099841375040502*lm^2*NM + 0.0038357511422333957*NL + 
        0.0016440119934662478*lm*NL + 0.001099841375040502*lm^2*NL - 
        0.0008649417057845456*NH + 0.0016440119934662478*lm*NH + 
        0.001099841375040502*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.003698918362541427 - 0.01641547343358218*lm - 
          0.00595250443236418*lm^2) + CF*(0.004023865219057432 + 
          0.01254940156684426*lm + 0.029221385395242338*lm^2) + 
        0.0004800569406832289*NM + 0.0016071924911786031*lm*NM + 
        0.0010822735331571236*lm^2*NM + 0.0037652663718568172*NL + 
        0.0016071924911786031*lm*NL + 0.0010822735331571236*lm^2*NL - 
        0.0008455271642300292*NH + 0.0016071924911786031*lm*NH + 
        0.0010822735331571236*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.003556841005285925 - 0.016096378322133623*lm - 
          0.005857550545360145*lm^2) + CF*(0.003909728108374293 + 
          0.012068234042266885*lm + 0.028755248131767983*lm^2) + 
        0.0004464475017291955*NM + 0.0015711479984864107*lm*NM + 
        0.0010650091900654807*lm^2*NM + 0.0036962105908243275*NL + 
        0.0015711479984864107*lm*NL + 0.0010650091900654807*lm^2*NL - 
        0.0008264881294474216*NH + 0.0015711479984864107*lm*NH + 
        0.0010650091900654807*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.003418710003675814 - 0.015783547231424413*lm - 
          0.0057642361916575065*lm^2) + CF*(0.0037992809632855797 + 
          0.011599077705816266*lm + 0.02829715948631867*lm^2) + 
        0.000413979384672741*NM + 0.0015358630225200565*lm*NM + 
        0.0010480429439377284*lm^2*NM + 0.0036285539340042217*NL + 
        0.0015358630225200565*lm*NL + 0.0010480429439377284*lm^2*NL - 
        0.0008078180142499093*NH + 0.0015358630225200565*lm*NH + 
        0.0010480429439377284*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.003284429627680932 - 0.01547685925470534*lm - 
          0.005672532157857289*lm^2) + CF*(0.003692427756694709 + 
          0.011141672917176368*lm + 0.027846976047663053*lm^2) + 
        0.00038261976322803714*NM + 0.0015013223403596144*lm*NM + 
        0.00103136948324678*lm^2*NM + 0.0035622671237317523*NL + 
        0.0015013223403596144*lm*NL + 0.00103136948324678*lm^2*NL - 
        0.0007895103234043948*NH + 0.0015013223403596144*lm*NH + 
        0.00103136948324678*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0031539061151814995 - 0.015176195581334309*lm - 
          0.005582409721671947*lm^2) + CF*(0.0035890742729807086 + 
          0.010695764712729561*lm + 0.027404556815480468*lm^2) + 
        0.0003523366635654055*NM + 0.0014675109965499198*lm*NM + 
        0.0010149835857585358*lm^2*NM + 0.0034973214615130455*NL + 
        0.0014675109965499198*lm*NL + 0.0010149835857585358*lm^2*NL - 
        0.0007715586534925477*NH + 0.0014675109965499198*lm*NH + 
        0.0010149835857585358*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0030270476483811462 - 0.014881439475282017*lm - 
          0.005493840646268554*lm^2) + CF*(0.003489128102977702 + 
          0.010261102764695103*lm + 0.026969763172591085*lm^2) + 
        0.0003230989455112221*NM + 0.0014344143005015277*lm*NM + 
        0.0009988801175033735*lm^2*NM + 0.003433688819628455*NL + 
        0.0014344143005015277*lm*NL + 0.0009988801175033735*lm^2*NL - 
        0.0007539566927021172*NH + 0.0014344143005015277*lm*NH + 
        0.0009988801175033735*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0029037643294491386 - 0.014592476252940566*lm - 
          0.005406797174511685*lm^2) + CF*(0.003392498637082477 + 
          0.00983744133799203*lm + 0.026542458856693728*lm^2) + 
        0.00029487628397462313*NM + 0.0014020178237881427*lm*NM + 
        0.0009830540317293972*lm^2*NM + 0.0033713416326534434*NL + 
        0.0014020178237881427*lm*NL + 0.0009830540317293972*lm^2*NL - 
        0.0007366982205529465*NH + 0.0014020178237881427*lm*NH + 
        0.0009830540317293972*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0027839681554798763 - 0.014309193260306372*lm - 
          0.00532125202311894*lm^2) + CF*(0.0032990970566234186 + 
          0.00942453924502885*lm + 0.026122509931674795*lm^2) + 
        0.00026763915061145865*NM + 0.0013703073973504948*lm*NM + 
        0.0009675003678398073*lm^2*NM + 0.0033102528889138675*NL + 
        0.0013703073973504948*lm*NL + 0.0009675003678398073*lm^2*NL - 
        0.0007197771075619193*NH + 0.0013703073973504948*lm*NH + 
        0.0009675003678398073*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0026675729928521894 - 0.014031479849604454*lm - 
          0.005237178376741227*lm^2) + CF*(0.0032088363236175157 + 
          0.00902215979861098*lm + 0.025709784758547842*lm^2) + 
        0.0002413587957347303*NM + 0.0013392691086160631*lm*NM + 
        0.0009522142503165867*lm^2*NM + 0.0032503961218913356*NL + 
        0.0013392691086160631*lm*NL + 0.0009522142503165867*lm^2*NL - 
        0.0007031873148508606*NH + 0.0013392691086160631*lm*NH + 
        0.0009522142503165867*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.0025544945510656974 - 0.01375922735541726*lm - 
          0.005154549881979161*lm^2) + CF*(0.0031216311690358276 + 
          0.008630070763146055*lm + 0.02530415396607952*lm^2) + 
        0.00021600723047962046*NM + 0.0013088892985434976*lm*NM + 
        0.0009371908876325748*lm^2*NM + 0.003191745401593233*NL + 
        0.0013088892985434976*lm*NL + 0.0009371908876325748*lm^2*NL - 
        0.0006869228937012192*NH + 0.0013088892985434976*lm*NH + 
        0.0009371908876325748*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.002444650356126528 - 0.013492329070377364*lm - 
          0.005073340641346213*lm^2) + CF*(0.0030373980796917126 + 
          0.008248044304316872*lm + 0.024905490421154138*lm^2) + 
        0.0001915572092301695*NM + 0.0012791545586000664*lm*NM + 
        0.0009224255711538569*lm^2*NM + 0.0031342753259009535*NL + 
        0.0012791545586000664*lm*NL + 0.0009224255711538569*lm^2*NL - 
        0.0006709779850591755*NH + 0.0012791545586000664*lm*NH + 
        0.0009224255711538569*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.0023379597235499757 - 0.013230680220479745*lm - 
          0.004993525207188546*lm^2) + CF*(0.0029560552838602885 + 
          0.0078758569373819*lm + 0.02451366919892559*lm^2) + 
        0.00016798221231368126*NM + 0.0012500517276799598*lm*NM + 
        0.0009079136740342811*lm^2*NM + 0.003077961011908895*NL + 
        0.0012500517276799598*lm*NL + 0.0009079136740342811*lm^2*NL - 
        0.0006553468189946332*NH + 0.0012500517276799598*lm*NH + 
        0.0009079136740342811*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.0022343437310432253 - 0.012974177940066027*lm - 
          0.004915078575570854*lm^2) + CF*(0.0028775227357319935 + 
          0.007513289474253966*lm + 0.02412856755280237*lm^2) + 
        0.00014525642896802957*NM + 0.0012215678889708158*lm*NM + 
        0.0008936506501037915*lm^2*NM + 0.003022778087265852*NL + 
        0.0012215678889708158*lm*NL + 0.0008936506501037915*lm^2*NL - 
        0.0006400237141173872*NH + 0.0012215678889708158*lm*NH + 
        0.0008936506501037915*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.0021337251909270545 - 0.012722721246529707*lm - 
          0.004837976180136871*lm^2) + CF*(0.0028017220987977395 + 
          0.007160126969498789*lm + 0.023750064884308274*lm^2) + 
        0.00012335474058619596*NM + 0.0011936903667753816*lm*NM + 
        0.0008796320327521584*lm^2*NM + 0.002968702681529574*NL + 
        0.0011936903667753816*lm*NL + 0.0008796320327521584*lm^2*NL - 
        0.000625003076953594*NH + 0.0011936903667753816*lm*NH + 
        0.0008796320327521584*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.0020360286223514426 - 0.012476211014788444*lm - 
          0.004762193885952676*lm^2) + CF*(0.002728576728257999 + 
          0.0068161586653866495*lm + 0.023378042712858593*lm^2) + 
        0.00010225270424158785*NM + 0.0011664067232948004*lm*NM + 
        0.0008658534338095775*lm^2*NM + 0.002915711417544426*NL + 
        0.0011664067232948004*lm*NL + 0.0008658534338095775*lm^2*NL - 
        0.0006102794012855153*NH + 0.0011664067232948004*lm*NH + 
        0.0008658534338095775*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0019411802233562374 - 0.012234549951566491*lm - 
          0.004687707983340336*lm^2) + CF*(0.002658011652543238 + 
          0.006481177936122405*lm + 0.023012384645488923*lm^2) + 
        0.00008192653649696281*NM + 0.0011397047553796148*lm*NM + 
        0.0008523105424255157*lm^2*NM + 0.0028637814028513284*NL + 
        0.0011397047553796148*lm*NL + 0.0008523105424255157*lm^2*NL - 
        0.0005958472674573535*NH + 0.0011397047553796148*lm*NH + 
        0.0008523105424255157*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0018491078428244977 - 0.011997642569527638*lm - 
          0.004614495181708946*lm^2) + CF*(0.0025899535540283617 + 
          0.006154982231371443*lm + 0.02265297634657119*lm^2) + 
        0.00006235309749911466*NM + 0.0011135724912541946*lm*NM + 
        0.0008389991239470811*lm^2*NM + 0.002812890221138414*NL + 
        0.0011135724912541946*lm*NL + 0.0008389991239470811*lm^2*NL - 
        0.0005817013416498588*NH + 0.0011135724912541946*lm*NH + 
        0.0008389991239470811*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0017597409523727341 - 0.011765395161296396*lm - 
          0.004542532603389611*lm^2) + CF*(0.002524330749019343 + 
          0.005837373019191961*lm + 0.022299705507549*lm^2) + 
        0.00004350987536085896*NM + 0.0010879981872199307*lm*NM + 
        0.0008259150187981112*lm^2*NM + 0.002763015923740169*NL + 
        0.0010879981872199307*lm*NL + 0.0008259150187981112*lm^2*NL - 
        0.0005678363751262462*NH + 0.0010879981872199307*lm*NH + 
        0.0008259150187981112*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.0016730106182191301 - 0.011537715773402728*lm - 
          0.004471797777480475*lm^2) + CF*(0.0024610731670858497 + 
          0.005528155728477049*lm + 0.02195246181672233*lm^2) + 
        0.000025374970831283343*NM + 0.0010629703243422042*lm*NM + 
        0.0008130541413600864*lm^2*NM + 0.0027141370211921723*NL + 
        0.0010629703243422042*lm*NL + 0.0008130541413600864*lm^2*NL - 
        0.0005542472034518355*NH + 0.0010629703243422042*lm*NH + 
        0.0008130541413600864*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.001588849473067807 - 0.011314514180183203*lm - 
          0.004402268633707445*lm^2) + CF*(0.002400112329809566 + 
          0.005227139691003523*lm + 0.021611136929109275*lm^2) + 
        7.927082254702431*^-6*NM + 0.0010384776051258018*lm*NM + 
        0.0008004124788558991*lm^2*NM + 0.0026662324748479506*NL + 
        0.0010384776051258018*lm*NL + 0.0008004124788558991*lm^2*NL - 
        0.0005409287456896955*NH + 0.0010384776051258018*lm*NH + 
        0.0008004124788558991*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.001507191688044384 - 0.011095701857669338*lm - 
          0.0043339234963058635*lm^2) + CF*(0.0023413813290139402 + 
          0.004934138083178322*lm + 0.021275624436410605*lm^2) - 
        8.85450918172827*^-6*NM + 0.0010145089501831508*lm*NM + 
        0.0007879860902374298*lm^2*NM + 0.0026192816885638954*NL + 
        0.0010145089501831508*lm*NL + 0.0007879860902374298*lm^2*NL - 
        0.0005278760035744624*NH + 0.0010145089501831508*lm*NH + 
        0.0007879860902374298*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.0014279729447154144 - 0.010881191957491704*lm - 
          0.004266741077928001*lm^2) + CF*(0.002284814804537312 + 
          0.0046489678675673335*lm + 0.020945819837101094*lm^2) - 
        0.00002498995391223*NM + 0.0009910534948994502*lm*NM + 
        0.0007757711050778184*lm^2*NM + 0.002573264500457663*NL + 
        0.0009910534948994502*lm*NL + 0.0007757711050778184*lm^2*NL - 
        0.0005150840606663819*NH + 0.0009910534948994502*lm*NH + 
        0.0007757711050778184*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0013511304072217688 - 0.010670899280826445*lm - 
          0.004200700473580839*lm^2) + CF*(0.0022303489216077776 + 
          0.004371449734286018*lm + 0.020621620506669575*lm^2) - 
        0.00004049884816934921*NM + 0.0009681005860984984*lm*NM + 
        0.0007637637224692435*lm^2*NM + 0.0025281611747449643*NL + 
        0.0009681005860984984*lm*NL + 0.0007637637224692435*lm^2*NL - 
        0.0005025480814875203*NH + 0.0009681005860984984*lm*NH + 
        0.0007637637224692435*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.0012766026945536686 - 0.01046474025240894*lm - 
          0.004135781154598323*lm^2) + CF*(0.0021779213478746954 + 
          0.004101408042325865*lm + 0.020302925668028132*lm^2) - 
        0.00005540024787491024*NM + 0.0009456397787127573*lm*NM + 
        0.0007519602099269678*lm^2*NM + 0.0024839523936591988*NL + 
        0.0009456397787127573*lm*NL + 0.0007519602099269678*lm^2*NL - 
        0.0004902633106419831*NH + 0.0009456397787127573*lm*NH + 
        0.0007519602099269678*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.0012043298529928464 - 0.010262632894637608*lm - 
          0.004071962962651889*lm^2) + CF*(0.0021274712301484543 + 
          0.0038386707608857656*lm + 0.01998963636210927*lm^2) - 
        0.00006971268224658719*NM + 0.0009236608324609464*lm*NM + 
        0.0007403569023003433*lm^2*NM + 0.002440619249457941*NL + 
        0.0009236608324609464*lm*NL + 0.0007403569023003433*lm^2*NL - 
        0.0004782250719218825*NH + 0.0009236608324609464*lm*NH + 
        0.0007403569023003433*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.001134253328745205 - 0.01006449680178913*lm - 
          0.00400922610380279*lm^2) + CF*(0.002078939170897009 + 
          0.003583069410772598*lm + 0.019681655418668245*lm^2) - 
        0.0000834541671220219*NM + 0.0009021537085362211*lm*NM + 
        0.0007289502006914165*lm^2*NM + 0.0023981432365198737*NL + 
        0.0009021537085362211*lm*NL + 0.0007289502006914165*lm^2*NL - 
        0.00046642876740070105*NH + 0.0009021537085362211*lm*NH + 
        0.0007289502006914165*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.0010663159407853816 - 0.009870253114364807*lm - 
          0.003947551142599463*lm^2) + CF*(0.0020322672045446884 + 
          0.0033344390059308897*lm + 0.019378887427306455*lm^2) - 
        0.00009664221800269802*NM + 0.000881108566307775*lm*NM + 
        0.0007177365713817205*lm^2*NM + 0.002356506243535377*NL + 
        0.000881108566307775*lm*NL + 0.0007177365713817205*lm^2*NL - 
        0.0004548698765156052*NH + 0.000881108566307775*lm*NH + 
        0.0007177365713817205*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.0010004618539327526 - 0.009679824493586252*lm - 
          0.0038869189962228647*lm^2) + CF*(0.0019873987736159547 + 
          0.0030926179951571205*lm + 0.019081238708730425*lm^2) - 
        0.00010929386282003796*NM + 0.0008605157600384903*lm*NM + 
        0.0007067125447677936*lm^2*NM + 0.002315690545793629*NL + 
        0.0008605157600384903*lm*NL + 0.0007067125447677936*lm^2*NL - 
        0.00044354395514018186*NH + 0.0008605157600384903*lm*NH + 
        0.0007067125447677936*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.0009366365521766831 - 0.00949313509605724*lm - 
          0.003827310928682516*lm^2) + CF*(0.0019442787047640746 + 
          0.002857448204050254*lm + 0.018788617286259624*lm^2) - 
        0.00012142565442642227*NM + 0.0008403658356210647*lm*NM + 
        0.000695874714305912*lm^2*NM + 0.0022756787975687256*NL + 
        0.0008403658356210647*lm*NL + 0.000695874714305912*lm^2*NL - 
        0.0004324466346489832*NH + 0.0008403658356210647*lm*NH + 
        0.000695874714305912*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.0008747868122671724 - 0.009310110548607137*lm - 
          0.0037687085450656844*lm^2) + CF*(0.0019028531847221069 + 
          0.002628774777246258*lm + 0.01850093285759518*lm^2) - 
        0.00013305368281403955*NM + 0.0008206495273348581*lm*NM + 
        0.0006852197354664881*lm^2*NM + 0.0022364540246070214*NL + 
        0.0008206495273348581*lm*NL + 0.0006852197354664881*lm^2*NL - 
        0.00042157362097519223*NH + 0.0008206495273348581*lm*NH + 
        0.0006852197354664881*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.0008148606775855086 - 0.009130677923330133*lm - 
          0.003711093785841955*lm^2) + CF*(0.0018630697362111432 + 
          0.0024064461209807857*lm + 0.018218096766860505*lm^2) - 
        0.00014419358706466314*NM + 0.0008013577546255222*lm*NM + 
        0.0006747443246985373*lm^2*NM + 0.002197999616717591*NL + 
        0.0008013577546255222*lm*NL + 0.0006747443246985373*lm^2*NL - 
        0.0004109206936626426*NH + 0.0008013577546255222*lm*NH + 
        0.0006747443246985373*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.0007568074323081042 - 0.00895476571283328*lm - 
          0.003654448921225201*lm^2) + CF*(0.0018248771938384277 + 
          0.0021903138460207905*lm + 0.017940021976923713*lm^2) - 
        0.00015486056703361802*NM + 0.0007824816189093102*lm*NM + 
        0.000664445258404582*lm^2*NM + 0.0021602993204674382*NL + 
        0.0007824816189093102*lm*NL + 0.000664445258404582*lm^2*NL - 
        0.0004004837049133575*NH + 0.0007824816189093102*lm*NH + 
        0.000664445258404582*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.0007005775758753185 - 0.00878230380570522*lm - 
          0.00359875654559478*lm^2) + CF*(0.001788225680015763 + 
          0.001980232711002643*lm + 0.017666623042010738*lm^2) - 
        0.00016506939477135097*NM + 0.0007640124004038098*lm*NM + 
        0.0006543193719263236*lm^2*NM + 0.0021233372319828287*NL + 
        0.0007640124004038098*lm*NL + 0.0006543193719263236*lm^2*NL - 
        0.00039025857863170444*NH + 0.0007640124004038098*lm*NH + 
        0.0006543193719263236*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.0006461227977758076 - 0.00861322346221643*lm - 
          0.003543999571977582*lm^2) + CF*(0.0017530665809265087 + 
          0.0017760605662112663*lm + 0.01739781608061722*lm^2) - 
        0.00017483442568614742*NM + 0.0007459415549866872*lm*NM + 
        0.0006443635585413785*lm^2*NM + 0.0020870977898578744*NL + 
        0.0007459415549866872*lm*NL + 0.0006443635585413785*lm^2*NL - 
        0.00038024130946619775*NH + 0.0007459415549866872*lm*NH + 
        0.0006443635585413785*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.0005933959526557467 - 0.008447457290260831*lm - 
          0.003490161226592384*lm^2) + CF*(0.0017193525225674888 + 
          0.00157765829783196*lm + 0.017133518748726248*lm^2) - 
        0.00018416960945165503*NM + 0.0007282607110838972*lm*NM + 
        0.0006345747684713425*lm^2*NM + 0.0020515657681712787*NL + 
        0.0007282607110838972*lm*NL + 0.0006345747684713425*lm^2*NL - 
        0.00037042796184991856*NH + 0.0007282607110838972*lm*NH + 
        0.0006345747684713425*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.0005423510357611547 - 0.008284939221547646*lm - 
          0.003437225043457797*lm^2) + CF*(0.0016870373468902274 + 
          0.0013848897727038684*lm + 0.016873650213338278*lm^2) - 
        0.00019308850066297292*NM + 0.0007109616665886767*lm*NM + 
        0.0006249500079014177*lm^2*NM + 0.0020167262696119508*NL + 
        0.0007109616665886767*lm*NL + 0.0006249500079014177*lm^2*NL - 
        0.00036081466904046527*NH + 0.0007109616665886767*lm*NH + 
        0.0006249500079014177*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.0004929431587205055 - 0.008125604488051507*lm - 
          0.003385174859064941*lm^2) + CF*(0.0016560760880641432 + 
          0.0011976217836015034*lm + 0.0166181311263188*lm^2) - 
        0.00020160426924515284*NM + 0.0006940363858125192*lm*NM + 
        0.0006154863380118075*lm^2*NM + 0.001982564718713991*NL + 
        0.0006940363858125192*lm*NL + 0.0006154863380118075*lm^2*NL - 
        0.00035139763216029024*NH + 0.0006940363858125192*lm*NH + 
        0.0006154863380118075*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.0004451285256738355 - 0.007969389598728038*lm - 
          0.003333994807115826*lm^2) + CF*(0.0016264249488826294 + 
          0.0010157239950683266*lm + 0.0163668835985686*lm^2) - 
        0.00020972971061803083*NM + 0.0006774769964692042*lm*NM + 
        0.0006061808740210592*lm^2*NM + 0.0019490668552013875*NL + 
        0.0006774769964692042*lm*NL + 0.0006061808740210592*lm^2*NL - 
        0.0003421731192382249*NH + 0.0006774769964692042*lm*NH + 
        0.0006061808740210592*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.0003988644097536422 - 0.007816232316501253*lm - 
          0.0032836693133282903*lm^2) + CF*(0.001598041277331332 + 
          0.0008390688898241242*lm + 0.016119831174520698*lm^2) - 
        0.00021747725562136955*NM + 0.0006612757866928549*lm*NM + 
        0.0005970307842415073*lm^2*NM + 0.0019162187274425833*NL + 
        0.0006612757866928549*lm*NL + 0.0005970307842415073*lm^2*NL - 
        0.0003331374642529477*NH + 0.0006612757866928549*lm*NH + 
        0.0005970307842415073*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.000354109129922019 - 0.007666071635528491*lm - 
          0.003234183090308217*lm^2) + CF*(0.0015708835433364185 + 
          0.0006675317157657811*lm + 0.01587689880696761*lm^2) - 
        0.0002248589802043411*NM + 0.000645425202090882*lm*NM + 
        0.0005880332891469485*lm^2*NM + 0.0018840066860149312*NL + 
        0.000645425202090882*lm*NL + 0.0005880332891469485*lm^2*NL - 
        0.0003242870661790973*NH + 0.000645425202090882*lm*NH + 
        0.0005880332891469485*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.0003108220281676748 - 0.00751884775874783*lm - 
          0.0031855211324896215*lm^2) + CF*(0.00154491131570918 + 
          0.0005009904335790446*lm + 0.015638012832221777*lm^2) - 
        0.0002318866148834201*NM + 0.0006299178428325855*lm*NM + 
        0.0005791856604526585*lm^2*NM + 0.0018524173773789043*NL + 
        0.0006299178428325855*lm*NL + 0.0005791856604526585*lm^2*NL - 
        0.000315618388036691*NH + 0.0006299178428325855*lm*NH + 
        0.0005791856604526585*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.000268963447065749 - 0.007374502075712324*lm - 
          0.0031376687111430994*lm^2) + CF*(0.001520085239301948 + 
          0.00033932566497697737*lm + 0.015403100945611578*lm^2) - 
        0.00023857155397278632*NM + 0.0006147464607740856*lm*NM + 
        0.0005704852202078363*lm^2*NM + 0.0018214377376618034*NL + 
        0.0006147464607740856*lm*NL + 0.0005704852202078363*lm^2*NL - 
        0.00030712795594446354*NH + 0.0006147464607740856*lm*NH + 
        0.0005704852202078363*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.00022849470770264105 - 0.007232977140714785*lm - 
          0.0030906113694530155*lm^2) + CF*(0.0014963670123890088 + 
          0.00018242064157902266*lm + 0.015172092177314803*lm^2) - 
        0.00024492486459135726*NM + 0.0005999039566201721*lm*NM + 
        0.0005619293399005483*lm^2*NM + 0.0017910549865505813*NL + 
        0.0005999039566201721*lm*NL + 0.0005619293399005483*lm^2*NL - 
        0.00029881235817769987*NH + 0.0005999039566201721*lm*NH + 
        0.0005619293399005483*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.00018937808796743328 - 0.007094216651206254*lm - 
          0.003044334917663717*lm^2) + CF*(0.001473719364284987 + 
          0.000030161154442930546*lm + 0.014944916868530974*lm^2) - 
        0.00025095729545058495*NM + 0.0005853833771235828*lm*NM + 
        0.0005535154395752212*lm^2*NM + 0.0017612566212932875*NL + 
        0.0005853833771235828*lm*NL + 0.0005535154395752212*lm^2*NL - 
        0.0002906682442310963*NH + 0.0005853833771235828*lm*NH + 
        0.0005535154395752212*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.0001515768012108905 - 0.006958165426510795*lm - 
          0.002998825428294957*lm^2) + CF*(0.0014521060332120077 - 
          0.00011756449573977656*lm + 0.014721506647993425*lm^2) - 
        0.00025667928542715544*NM + 0.000571177912322138*lm*NM + 
        0.0005452409869627195*lm^2*NM + 0.001732030410808545*NL + 
        0.000571177912322138*lm*NL + 0.0005452409869627195*lm^2*NL - 
        0.0002826923238871475*NH + 0.000571177912322138*lm*NH + 
        0.0005452409869627195*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.00011505497527246721 - 0.006824769386838715*lm - 
          0.00295406923142664*lm^2) + CF*(0.0014314917444258669 - 
          0.00026086554777559354*lm + 0.014501794408821688*lm^2) - 
        0.0002621009719247289*NM + 0.0005572808928140976*lm*NM + 
        0.0005371034966230255*lm^2*NM + 0.0017033643899023643*NL + 
        0.0005572808928140976*lm*NL + 0.0005371034966230255*lm^2*NL - 
        0.0002748813662905216*NH + 0.0005572808928140976*lm*NH + 
        0.0005371034966230255*lm^2*NH)}, 
     {1., 5.085306983120506*^-16*CF*NC*
       (-3.*CA*(5.229289804269676*^10 + 4.38778855424*^12*lm + 
          1.907490816*^12*lm^2) + 2.*(315.*CF*(4.406851650134771*^9 - 
            1.248067584*^9*lm + 4.45906944*^10*lm^2) + 
          32.*(35.*(-2.3459761475197878*^8 + 4.77290496*^8*lm + 
              4.644864*^8*lm^2)*NM + 6144.*(8.377809*^6 + 2.71894*^6*lm + 
              2.646*^6*lm^2)*NL + 35.*(-2.3459761475197878*^8 + 
              4.77290496*^8*lm + 4.644864*^8*lm^2)*NH)))}}
 
CbarTable["v", 2, 4] = {{0., -6.943139134287199*^-12*CF*NC*
       (3.*CF*(-4.076696129615126*^9 - 1.2069497103215195*^10*lm - 
          8.2301184*^9*lm^2) + 12.*CA*(9.284320385597681*^8 + 
          1.240896236581136*^9*lm + 3.143448*^8*lm^2) + 
        560.*(9.*(-746381.0908126297 - 363991.7907277644*lm - 136080.*lm^2)*
           NM + 9.*(-746381.0908126297 - 363991.7907277644*lm - 
            136080.*lm^2)*NL + (1.3743768926234106*^6 - 
            3.2759261165498802*^6*lm - 1.22472*^6*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.07551460082152234 - 0.1049958750493196*lm - 
          0.02678277506092036*lm^2) + CF*(0.08509606716159146 + 
          0.2523023144161373*lm + 0.17530543676238783*lm^2) + 
        0.026205224215527814*NM + 0.012892492143630257*lm*NM + 
        0.004869595465621884*lm^2*NM + 0.026207496279672757*NL + 
        0.012892492143630257*lm*NL + 0.004869595465621884*lm^2*NL - 
        0.005447438839115718*NH + 0.012892492143630257*lm*NH + 
        0.004869595465621884*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.07401330991700603 - 0.10650872011969796*lm - 
          0.027330350486719703*lm^2) + CF*(0.08504457366582961 + 
          0.2533121291603022*lm + 0.17888956682216534*lm^2) + 
        0.026313708389735145*NM + 0.013040843214919036*lm*NM + 
        0.004969154633949037*lm^2*NM + 0.02632153109807274*NL + 
        0.013040843214919036*lm*NL + 0.004969154633949037*lm^2*NL - 
        0.005543873707974211*NH + 0.013040843214919036*lm*NH + 
        0.004969154633949037*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.0728662456090438 - 0.1079135556181224*lm - 
          0.02782710450575218*lm^2) + CF*(0.08482490585762084 + 
          0.2544402950061975*lm + 0.18214104767401426*lm^2) + 
        0.02644158710194351*NM + 0.013181316507749022*lm*NM + 
        0.005059473546500396*lm^2*NM + 0.02645808184416599*NL + 
        0.013181316507749022*lm*NL + 0.005059473546500396*lm^2*NL - 
        0.005632159883969203*NH + 0.013181316507749022*lm*NH + 
        0.005059473546500396*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.07203931905647197 - 0.10919786907233885*lm - 
          0.028270081420579327*lm^2) + CF*(0.08450017053875004 + 
          0.2556529116847437*lm + 0.18504053293470105*lm^2) + 
        0.026580433331163*NM + 0.013312320990208541*lm*NM + 
        0.0051400148037416965*lm^2*NM + 0.026609335209115903*NL + 
        0.013312320990208541*lm*NL + 0.0051400148037416965*lm^2*NL - 
        0.005711795381993687*NH + 0.013312320990208541*lm*NH + 
        0.0051400148037416965*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.07148612881073943 - 0.11035186750298404*lm - 
          0.028658132101933506*lm^2) + CF*(0.08411831123388636 + 
          0.2569045411740828*lm + 0.1875805010308375*lm^2) + 
        0.02672120911409359*NM + 0.013432342034805873*lm*NM + 
        0.005210569473078819*lm^2*NM + 0.026767015500074338*NL + 
        0.013432342034805873*lm*NL + 0.005210569473078819*lm^2*NL - 
        0.005782535475862586*NH + 0.013432342034805873*lm*NH + 
        0.005210569473078819*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.07115857460588745 - 0.11136850876399255*lm - 
          0.028991296216382044*lm^2) + CF*(0.08371334841120683 + 
          0.25814844525530073*lm + 0.189761211598137*lm^2) + 
        0.02685565330651236*NM + 0.013540090072306934*lm*NM + 
        0.005271144766614917*lm^2*NM + 0.02692355691619487*NL + 
        0.013540090072306934*lm*NL + 0.005271144766614917*lm^2*NL - 
        0.005844309611530105*NH + 0.013540090072306934*lm*NH + 
        0.005271144766614917*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.0710109768895906 - 0.11224323408035979*lm - 
          0.029270434744817518*lm^2) + CF*(0.08330811890350467 + 
          0.25934080262874815*lm + 0.1915883001478965*lm^2) + 
        0.02697670307853694*NM + 0.013634536999281197*lm*NM + 
        0.005321897226330458*lm^2*NM + 0.027072442233147257*NL + 
        0.013634536999281197*lm*NL + 0.005321897226330458*lm^2*NL - 
        0.005897171756174717*NH + 0.013634536999281197*lm*NH + 
        0.005321897226330458*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.0710017488513423 - 0.11297363945213443*lm - 
          0.02949698655246683*lm^2) + CF*(0.08291684794097913 + 
          0.26044251132638974*lm + 0.1930711847070556*lm^2) + 
        0.027078574201434613*NM + 0.013714912764280053*lm*NM + 
        0.0053630884640848775*lm^2*NM + 0.027208257675050793*NL + 
        0.013714912764280053*lm*NL + 0.0053630884640848775*lm^2*NL - 
        0.00594126720167707*NH + 0.013714912764280053*lm*NH + 
        0.0053630884640848775*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.07109397763877796 - 0.11355915261997872*lm - 
          0.029672797147231374*lm^2) + CF*(0.08254728465385455 + 
          0.2614198552125082*lm + 0.19422194496369627*lm^2) + 
        0.02715670415267925*NM + 0.013780686260471514*lm*NM + 
        0.005395054026769341*lm^2*NM + 0.027326637770264058*NL + 
        0.013780686260471514*lm*NL + 0.005395054026769341*lm^2*NL - 
        0.00597680889780522*NH + 0.013780686260471514*lm*NH + 
        0.005395054026769341*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.07125547891535668 - 0.11400073651696185*lm - 
          0.029799993676646225*lm^2) + CF*(0.08220240831025742 + 
          0.2622445929489583*lm + 0.19505450406532074*lm^2) + 
        0.027207639870585523*NM + 0.013831540334107988*lm*NM + 
        0.005418180668481131*lm^2*NM + 0.027424167782803252*NL + 
        0.013831540334107988*lm*NL + 0.005418180668481131*lm^2*NL - 
        0.006004059877084847*NH + 0.013831540334107988*lm*NH + 
        0.005418180668481131*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.07145859072735417 - 0.11430062488247857*lm - 
          0.029880891482319406*lm^2) + CF*(0.08188176936413942 + 
          0.2628937449931025*lm + 0.19558401697518157*lm^2) + 
        0.02722890678709671*NM + 0.013867345338095746*lm*NM + 
        0.0054328893604217105*lm^2*NM + 0.027498273056857116*NL + 
        0.013867345338095746*lm*NL + 0.0054328893604217105*lm^2*NL - 
        0.006023319840893634*NH + 0.013867345338095746*lm*NH + 
        0.0054328893604217105*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.0716798423686468 - 0.11446209006927698*lm - 
          0.02991792316996476*lm^2) + CF*(0.08158253344031591 + 
          0.2633492256684844*lm + 0.1958264062034057*lm^2) + 
        0.02721887644035583*NM + 0.013888133328637028*lm*NM + 
        0.005439622394539047*lm^2*NM + 0.02754710868668435*NL + 
        0.013888133328637028*lm*NL + 0.005439622394539047*lm^2*NL - 
        0.006034914725924529*NH + 0.013888133328637028*lm*NH + 
        0.005439622394539047*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.07189957092962157 - 0.11448924094160122*lm - 
          0.029913584269547315*lm^2) + CF*(0.08130028771656565 + 
          0.26359740277758426*lm + 0.19579800612794604*lm^2) + 
        0.027176640890276594*NM + 0.013894073893949605*lm*NM + 
        0.005438833503554057*lm^2*NM + 0.027569455642742442*NL + 
        0.013894073893949605*lm*NL + 0.005438833503554057*lm^2*NL - 
        0.0060391884815258305*NH + 0.013894073893949605*lm*NH + 
        0.005438833503554057*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.0721015254638048 - 0.11438684803870783*lm - 
          0.02987039141525834*lm^2) + CF*(0.08102965859353226 + 
          0.26362863236094175*lm + 0.19551528926350914*lm^2) + 
        0.027101897625972607*NM + 0.013885452043176351*lm*NM + 
        0.005430980257319699*lm^2*NM + 0.027564625947440816*NL + 
        0.013885452043176351*lm*NL + 0.005430980257319699*lm^2*NL - 
        0.006036496531523763*NH + 0.013885452043176351*lm*NH + 
        0.005430980257319699*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.07227248076367784 - 0.11416019304896113*lm - 
          0.02979085014533024*lm^2) + CF*(0.08076477998945676 + 
          0.26343679635705197*lm + 0.19499465549670705*lm^2) + 
        0.026994846305248593*NM + 0.013862648289321471*lm*NM + 
        0.0054165182082418625*lm^2*NM + 0.027532377714838848*NL + 
        0.013862648289321471*lm*NL + 0.0054165182082418625*lm^2*NL - 
        0.006027200546358359*NH + 0.013862648289321471*lm*NH + 
        0.0054165182082418625*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.07240187253503408 - 0.11381493976325724*lm - 
          0.029677430194960205*lm^2) + CF*(0.08049964366142145 + 
          0.2630188591686193*lm + 0.19425227036701226*lm^2) + 
        0.02685609743378184*NM + 0.013826120903576641*lm*NM + 
        0.005395896399083674*lm^2*NM + 0.027472839965727733*NL + 
        0.013826120903576641*lm*NL + 0.005395896399083674*lm^2*NL - 
        0.006011664251232128*NH + 0.013826120903576641*lm*NH + 
        0.005395896399083674*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.0724814598128154 - 0.11335702390087354*lm - 
          0.02953254668619144*lm^2) + CF*(0.08022835656301254 + 
          0.2623744519927741*lm + 0.19330394194598033*lm^2) + 
        0.02668659245416118*NM + 0.013776390236412047*lm*NM + 
        0.005369553942943898*lm^2*NM + 0.02738644668218826*NL + 
        0.013776390236412047*lm*NL + 0.005369553942943898*lm^2*NL - 
        0.0059902500640493265*NH + 0.013776390236412047*lm*NH + 
        0.005369553942943898*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.07250501694987282 - 0.11279255945646904*lm - 
          0.029358545994192565*lm^2) + CF*(0.07994532515712378 + 
          0.26150548934657103*lm + 0.19216502832562407*lm^2) + 
        0.026487534404309232*NM + 0.013714024960371298*lm*NM + 
        0.005337917453489557*lm^2*NM + 0.02727387936194153*NL + 
        0.013714024960371298*lm*NL + 0.005337917453489557*lm^2*NL - 
        0.005963316404840147*NH + 0.013714024960371298*lm*NH + 
        0.005337917453489557*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.07246805543550354 - 0.11212775947184628*lm - 
          0.029157695342259794*lm^2) + CF*(0.07964538255952844 + 
          0.26041581945588227*lm + 0.19085036951297318*lm^2) + 
        0.026260328176627722*NM + 0.01363963007270532*lm*NM + 
        0.005301399153138145*lm^2*NM + 0.027136017261084434*NL + 
        0.01363963007270532*lm*NL + 0.005301399153138145*lm^2*NL - 
        0.005931215553015673*NH + 0.01363963007270532*lm*NH + 
        0.005301399153138145*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.0723675745939748 - 0.11136886937596545*lm - 
          0.028932175380513604*lm^2) + CF*(0.07932387117616349 + 
          0.2591109084550034*lm + 0.18937423885427085*lm^2) + 
        0.026006529383104448*NM + 0.013553836492701315*lm*NM + 
        0.005260395523729746*lm^2*NM + 0.02697389451346651*NL + 
        0.013553836492701315*lm*NL + 0.005260395523729746*lm^2*NL - 
        0.005894291954444871*NH + 0.013553836492701315*lm*NH + 
        0.005260395523729746*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.07220183953952802 - 0.11052211125592087*lm - 
          0.028684075156561167*lm^2) + CF*(0.07897669093884933 + 
          0.2575975572896417*lm + 0.18775031011567309*lm^2) + 
        0.025727800861705567*NM + 0.013457292092946667*lm*NM + 
        0.00521528639210203*lm^2*NM + 0.026788663352210914*NL + 
        0.013457292092946667*lm*NL + 0.00521528639210203*lm^2*NL - 
        0.005852880899707133*NH + 0.013457292092946667*lm*NH + 
        0.00521528639210203*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.07197018442096566 - 0.10959363761869595*lm - 
          0.028415389004204813*lm^2) + CF*(0.07860032120176408 + 
          0.2558836495929317*lm + 0.1859916371184315*lm^2) + 
        0.025425875918973665*NM + 0.013350654012343604*lm*NM + 
        0.005166434364400875*lm^2*NM + 0.026581562714568734*NL + 
        0.013350654012343604*lm*NL + 0.005166434364400875*lm^2*NL - 
        0.005807307509747477*NH + 0.013350654012343604*lm*NH + 
        0.005166434364400875*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.07167283885067285 - 0.10858949337907076*lm - 
          0.02812801496803604*lm^2) + CF*(0.07819182272615635 + 
          0.2539779284630845*lm + 0.184110643427145*lm^2) + 
        0.025102527477216904*NM + 0.013234582109376426*lm*NM + 
        0.005114184539642916*lm^2*NM + 0.026353891574519516*NL + 
        0.013234582109376426*lm*NL + 0.005114184539642916*lm^2*NL - 
        0.005757885976760366*NH + 0.013234582109376426*lm*NH + 
        0.005114184539642916*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.07131077540113342 - 0.10751558496453985*lm - 
          0.027823754454051157*lm^2) + CF*(0.07774882486913966 + 
          0.2518897999149176*lm + 0.1821191200628803*lm^2) + 
        0.02475954237283752*NM + 0.013109733425673092*lm*NM + 
        0.005058864446191119*lm^2*NM + 0.0261069864121148*NL + 
        0.013109733425673092*lm*NL + 0.005058864446191119*lm^2*NL - 
        0.005704919017293667*NH + 0.013109733425673092*lm*NH + 
        0.005058864446191119*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.07088557611658748 - 0.10637765556533443*lm - 
          0.027504312853951263*lm^2) + CF*(0.07726950203806321 + 
          0.24962916074157557*lm + 0.18002822958949918*lm^2) + 
        0.02439870012990383*NM + 0.01297675754154316*lm*NM + 
        0.005000784155263866*lm^2*NM + 0.02584220229108666*NL + 
        0.01297675754154316*lm*NL + 0.005000784155263866*lm^2*NL - 
        0.005648697501891276*NH + 0.01297675754154316*lm*NH + 
        0.005000784155263866*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.07039931609630856 - 0.10518126567852279*lm - 
          0.027171300936952778*lm^2) + CF*(0.07675254262322755 + 
          0.24720624856427967*lm + 0.1778485152236909*lm^2) + 
        0.024021755607048542*NM + 0.012836292716469615*lm*NM + 
        0.004940236533991414*lm^2*NM + 0.02556089707491422*NL + 
        0.012836292716469615*lm*NL + 0.004940236533991414*lm^2*NL - 
        0.005589500231510461*NH + 0.012836292716469615*lm*NH + 
        0.004940236533991414*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.06985446233835914 - 0.1039317782015016*lm - 
          0.026826236840249876*lm^2) + CF*(0.07619711293790411 + 
          0.24463151193800217*lm + 0.17558991386345374*lm^2) + 
        0.02363042498462253*NM + 0.012688962718231724*lm*NM + 
        0.004877497607318159*lm^2*NM + 0.02526441836552169*NL + 
        0.012688962718231724*lm*NL + 0.004877497607318159*lm^2*NL - 
        0.005527593835772363*NH + 0.012688962718231724*lm*NH + 
        0.004877497607318159*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.06925378617532013 - 0.10263434742367089*lm - 
          0.026470548519621512*lm^2) + CF*(0.07560281814351132 + 
          0.24191549849992627*lm + 0.17326177212843172*lm^2) + 
        0.023226374622041843*NM + 0.01253537425430874*lm*NM + 
        0.004812827003567548*lm^2*NM + 0.024954092797800344*NL + 
        0.01253537425430874*lm*NL + 0.004812827003567548*lm^2*NL - 
        0.005463232772065542*NH + 0.01253537425430874*lm*NH + 
        0.004812827003567548*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.0686002877779259 - 0.10129391134722357*lm - 
          0.02610557654649439*lm^2) + CF*(0.07496966169377685 + 
          0.2390687592821454*lm + 0.17087286466796328*lm^2) + 
        0.022811212372214982*NM + 0.012376114928405584*lm*NM + 
        0.00474646846299898*lm^2*NM + 0.02463121736725746*NL + 
        0.012376114928405584*lm*NL + 0.00474646846299898*lm^2*NL - 
        0.0053966594077995735*NH + 0.012376114928405584*lm*NH + 
        0.00474646846299898*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.06789713134350367 - 0.09991518684013792*lm - 
          0.025732577158159766*lm^2) + CF*(0.07429800447432303 + 
          0.23610176745128342*lm + 0.16843141412613666*lm^2) + 
        0.022386480990818743*NM + 0.012211751653343478*lm*NM + 
        0.004678650392392685*lm^2*NM + 0.024297052507532616*NL + 
        0.012211751653343478*lm*NL + 0.004678650392392685*lm^2*NL - 
        0.005328104170833757*NH + 0.012211751653343478*lm*NH + 
        0.004678650392392685*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.06714758972046592 - 0.0985026671878398*lm - 
          0.025352725484651503*lm^2) + CF*(0.0735885245269732 + 
          0.2330248498795779*lm + 0.16594511226317346*lm^2) + 
        0.021953653322948373*NM + 0.012042829459192014*lm*NM + 
        0.004609586451754819*lm^2*NM + 0.0239528166696137*NL + 
        0.012042829459192014*lm*NL + 0.004609586451754819*lm^2*NL - 
        0.005257785755389484*NH + 0.012042829459192014*lm*NH + 
        0.004609586451754819*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.06635499734611709 - 0.09706062166566364*lm - 
          0.024967118889696785*lm^2) + CF*(0.07284217801808196 + 
          0.2298481300905076*lm + 0.16342114182346987*lm^2) + 
        0.02151412898782835*NM + 0.011869870642422233*lm*NM + 
        0.0045394761617630515*lm^2*NM + 0.023599682185699224*NL + 
        0.011869870642422233*lm*NL + 0.0045394761617630515*lm^2*NL - 
        0.005185911372675497*NH + 0.011869870642422233*lm*NH + 
        0.0045394761617630515*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.06552271049198552 - 0.09559309680312195*lm - 
          0.024576780374680945*lm^2) + CF*(0.07206016192692216 + 
          0.22658148125474814*lm + 0.16086619881609346*lm^2) + 
        0.021069232312299496*NM + 0.011693374208079475*lm*NM + 
        0.004468505522669262*lm^2*NM + 0.023238772228165214*NL + 
        0.011693374208079475*lm*NL + 0.004468505522669262*lm^2*NL - 
        0.005112677037077712*NH + 0.011693374208079475*lm*NH + 
        0.004468505522669262*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.06465407391880801 - 0.09410391905391366*lm - 
          0.024182662004148526*lm^2) + CF*(0.0712438787855336 + 
          0.2232344880375848*lm + 0.1582865149362449*lm^2) + 
        0.02062021128189373*NM + 0.011513815562561501*lm*NM + 
        0.004396847637117914*lm^2*NM + 0.022871158698369438*NL + 
        0.011513815562561501*lm*NL + 0.004396847637117914*lm^2*NL - 
        0.005038267880140995*NH + 0.011513815562561501*lm*NH + 
        0.004396847637117914*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.0637523931428891 - 0.09259669862328192*lm - 
          0.023785648319335405*lm^2) + CF*(0.0703949036895848 + 
          0.2198164162160761*lm + 0.15568787990837718*lm^2) + 
        0.020168237276198826*NM + 0.011331646419593477*lm*NM + 
        0.004324663330788256*lm^2*NM + 0.022497860901406565*NL + 
        0.011331646419593477*lm*NL + 0.004324663330788256*lm^2*NL - 
        0.004962858485740565*NH + 0.011331646419593477*lm*NH + 
        0.004324663330788256*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.06282091160829507 - 0.09107483423740573*lm - 
          0.023386559712867804*lm^2) + CF*(0.0695149537171885 + 
          0.2163361890928934*lm + 0.15307566357513472*lm^2) + 
        0.01971440531637557*NM + 0.011147294886467995*lm*NM + 
        0.004252101765975964*lm^2*NM + 0.022119844881733266*NL + 
        0.011147294886467995*lm*NL + 0.004252101765975964*lm^2*NL - 
        0.004886613240839068*NH + 0.011147294886467995*lm*NH + 
        0.004252101765975964*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.06186279214760936 - 0.08954151866853138*lm - 
          0.022986155743298545*lm^2) + CF*(0.06860585983832226 + 
          0.2128023698338447*lm + 0.15045483759249959*lm^2) + 
        0.01925973444638737*NM + 0.010961165701614307*lm*NM + 
        0.004179301044236099*lm^2*NM + 0.021738023311102545*NL + 
        0.010961165701614307*lm*NL + 0.004179301044236099*lm^2*NL - 
        0.004809686697079159*NH + 0.010961165701614307*lm*NH + 
        0.004179301044236099*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.06088110220113505 - 0.08799974485500679*lm - 
          0.022585138372763013*lm^2) + CF*(0.06766954137328315 + 
          0.20922314894781868*lm + 0.14782999662172153*lm^2) + 
        0.01880516764265859*NM + 0.010773640598122192*lm*NM + 
        0.00410638879504782*lm^2*NM + 0.021353255834743522*NL + 
        0.010773640598122192*lm*NL + 0.00410638879504782*lm^2*NL - 
        0.004732223939193091*NH + 0.010773640598122192*lm*NH + 
        0.00410638879504782*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.05987880235418848 - 0.08645231247770266*lm - 
          0.022184155114878746*lm^2) + CF*(0.06670798306750554 + 
          0.20560633621160143*lm + 0.1452053789337518*lm^2) + 
        0.018351570215729068*NM + 0.01058507877101532*lm*NM + 
        0.0040334827481597725*lm^2*NM + 0.02096634979443249*NL + 
        0.01058507877101532*lm*NL + 0.0040334827481597725*lm^2*NL - 
        0.004654360956838843*NH + 0.01058507877101532*lm*NH + 
        0.0040334827481597725*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.05885872745497579 - 0.08490183487386484*lm - 
          0.021783802083208702*lm^2) + CF^2*(0.06572319410929275 + 
          0.20195935641814752*lm + 0.14258488636282057*lm^2) + 
        CF*((0.017899884822233342 + 0.010395817428885807*lm + 
            0.0039606912878561275*lm^2)*NM + (0.02057806125823306 + 
            0.010395817428885807*lm + 0.0039606912878561275*lm^2)*NL + 
          (-0.004576225017012149 + 0.010395817428885807*lm + 
            0.0039606912878561275*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.057823609952592094 - 0.08335074618657282*lm - 
          0.021384626933262506*lm^2) + CF^2*(0.06471724904548412 + 
          0.1982892483959078*lm + 0.13997210356317277*lm^2) + 
        CF*((0.017450674915562 + 0.01020617241300208*lm + 0.00388811398786591*
             lm^2)*NM + (0.020189096296425072 + 0.01020617241300208*lm + 
            0.00388811398786591*lm^2)*NL + (-0.004497935034648305 + 
            0.01020617241300208*lm + 0.00388811398786591*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.05677603869152703 - 0.08180130866297189*lm - 
          0.020987131693209767*lm^2) + CF^2*(0.06369219763612102 + 
          0.1946026668092276*lm + 0.13737031653737303*lm^2) + 
        CF*((0.017004691023681965 + 0.010016438869219074*lm + 
            0.0038158421260381394*lm^2)*NM + (0.019800112451659732 + 
            0.010016438869219074*lm + 0.0038158421260381394*lm^2)*NL + 
          (-0.004419601939427589 + 0.010016438869219074*lm + 
            0.0038158421260381394*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.0557184769417934 - 0.08025562002755457*lm - 
          0.02059177548029606*lm^2) + CF^2*(0.06265009168253859 + 
          0.19090588630612781*lm + 0.13478253041648328*lm^2) + 
        CF*((0.01656255340344971 + 0.009826891959982735*lm + 
            0.003743959178235647*lm^2)*NM + (0.019411720358819048 + 
            0.009826891959982735*lm + 0.003743959178235647*lm^2)*NL + 
          (-0.004341329037142707 + 0.009826891959982735*lm + 
            0.003743959178235647*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.05465325652483062 - 0.0787156208682192*lm - 
          0.02019897710144686*lm^2) + CF^2*(0.06159296294662364 + 
          0.18720480763046712*lm + 0.13221148648219766*lm^2) + 
        CF*((0.01612482490495262 + 0.00963778760545711*lm + 
            0.003672541291172157*lm^2)*NM + (0.01902448547655133 + 
            0.00963778760545711*lm + 0.003672541291172157*lm^2)*NL + 
          (-0.00426321236428323 + 0.00963778760545711*lm + 
            0.003672541291172157*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.05358257772713247 - 0.07718310198282517*lm - 
          0.01980911753776786*lm^2) + CF^2*(0.06052281187536318 + 
          0.1835049653610223*lm + 0.12965967842902598*lm^2) + 
        CF*((0.015692013896343143 + 0.009449363244335983*lm + 
            0.003601657734139611*lm^2)*NM + (0.01863892989811611 + 
            0.009449363244335983*lm + 0.003601657734139611*lm^2)*NL + 
          (-0.0041853410347489775 + 0.009449363244335983*lm + 
            0.003601657734139611*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.052508510251090525 - 0.0756597116426724*lm - 
          0.01942254231364447*lm^2) + CF^2*(0.05944159790259031 + 
          0.17981153698086916*lm + 0.12712936787112744*lm^2) + 
        CF*((0.015264577186672209 + 0.009261838606254114*lm + 
            0.0035313713297535397*lm^2)*NM + (0.0182555342141024 + 
            0.009261838606254114*lm + 0.0035313713297535397*lm^2)*NL + 
          (-0.004107797577819898 + 0.009261838606254114*lm + 
            0.0035313713297535397*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.05143299502677221 - 0.07414696273690993*lm - 
          0.019039563751945536*lm^2) + CF^2*(0.05835123119952849 + 
          0.17612935301702215*lm + 0.12462259910364351*lm^2) + 
        CF*((0.014842922922287791 + 0.009075416488905317*lm + 
            0.0034617388639900976*lm^2)*NM + (0.017874739403873494 + 
            0.009075416488905317*lm + 0.0034617388639900976*lm^2)*NL + 
          (-0.004030658266708264 + 0.009075416488905317*lm + 
            0.0034617388639900976*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.05035784673098218 - 0.07264623976846177*lm - 
          0.01866046311747593*lm^2) + CF^2*(0.05725356574957198 + 
          0.17246290802298775*lm + 0.12214121313256973*lm^2) + 
        CF*((0.014427413436290898 + 0.008890283534023413*lm + 
            0.003392811475904715*lm^2)*NM + (0.01749694873631774 + 
            0.008890283534023413*lm + 0.003392811475904715*lm^2)*NL + 
          (-0.00395399343717012 + 0.008890283534023413*lm + 
            0.003392811475904715*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.0492847568800644 - 0.07115880567776689*lm - 
          0.018285492651326358*lm^2) + CF^2*(0.05615039362784479 + 
          0.16881637220607512*lm + 0.11968686099049979*lm^2) + 
        CF*((0.014018368035261413 + 0.008706610997303584*lm + 
            0.003324635027513883*lm^2)*NM + (0.017122529663717388 + 
            0.008706610997303584*lm + 0.003324635027513883*lm^2)*NL + 
          (-0.003877867795801423 + 0.008706610997303584*lm + 
            0.003324635027513883*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.04821529738059608 - 0.06968580847556932*lm - 
          0.01791487749915772*lm^2) + CF^2*(0.055043440371769156 + 
          0.16519360352732215*lm + 0.11726101635812326*lm^2) + 
        CF*((0.01361606571017867 + 0.008524555508149661*lm + 
            0.003257250454392313*lm^2)*NM + (0.016751815695347783 + 
            0.008524555508149661*lm + 0.003257250454392313*lm^2)*NL + 
          (-0.0038023407177591494 + 0.008524555508149661*lm + 
            0.003257250454392313*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.04715092443781243 - 0.06822828767025918*lm - 
          0.017548817536750493*lm^2) + CF^2*(0.053934361335199694 + 
          0.16159816012504588*lm + 0.11486498751327595*lm^2) + 
        CF*((0.013220747761645913 + 0.008344259815840398*lm + 
            0.0031906940975909986*lm^2)*NM + (0.01638510823984029 + 
            0.008344259815840398*lm + 0.0031906940975909986*lm^2)*NL + 
          (-0.003727466533750564 + 0.008344259815840398*lm + 
            0.0031906940975909986*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.04609298273543189 - 0.06678718047893561*lm - 
          0.017187489096362165*lm^2) + CF^2*(0.05282473892527205 + 
          0.158033312933598*lm + 0.11249992863073417*lm^2) + 
        CF*((0.012832620331904682 + 0.008165853519325975*lm + 
            0.0031249980175203935*lm^2)*NM + (0.01602267840743174 + 
            0.008165853519325975*lm + 0.0031249980175203935*lm^2)*NL + 
          (-0.0036532948062200582 + 0.008165853519325975*lm + 
            0.0031249980175203935*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.04504270981277315 - 0.06536332781451303*lm - 
          0.01683104659758175*lm^2) + CF^2*(0.05171608062790024 + 
          0.15450205838715847*lm + 0.11016685045689874*lm^2) + 
        CF*((0.012451856838225502 + 0.007989453778404938*lm + 
            0.0030601902904694093*lm^2)*NM + (0.015664768765022295 + 
            0.007989453778404938*lm + 0.0030601902904694093*lm^2)*NL + 
          (-0.0035798705947366768 + 0.007989453778404938*lm + 
            0.0030601902904694093*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.04400124057586066 - 0.06395748004388511*lm - 
          0.016479624086460358*lm^2) + CF^2*(0.05060981773472677 + 
          0.15100713111456532*lm + 0.10786663038410417*lm^2) + 
        CF*((0.012078600303897557 + 0.007815166004500681*lm + 
            0.002996295288447338*lm^2)*NM + (0.015311595038508954 + 
            0.007815166004500681*lm + 0.002996295288447338*lm^2)*NL + 
          (-0.003507234710646867 + 0.007815166004500681*lm + 
            0.002996295288447338*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.042969611888783524 - 0.0625703025144549*lm - 
          0.016133336686740878*lm^2) + CF^2*(0.04950730469121596 + 
          0.14755101654547484*lm + 0.10560002194957666*lm^2) + 
        CF*((0.011712965584758215 + 0.007643084529663332*lm + 
            0.0029333339430437956*lm^2)*NM + (0.014963347758185653 + 
            0.007643084529663332*lm + 0.0029333339430437956*lm^2)*NL + 
          (-0.0034354239611087897 + 0.007643084529663332*lm + 
            0.0029333339430437956*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.04194876720007883 - 0.06120238084828171*lm - 
          0.015792281967016025*lm^2) + CF^2*(0.04840981899246938 + 
          0.14413596336076548*lm + 0.10336766378410489*lm^2) + 
        CF*((0.011355041490146421 + 0.0074732932527747835*lm + 
            0.0028713239940029137*lm^2)*NM + (0.014620193844130908 + 
            0.0074732932527747835*lm + 0.0028713239940029137*lm^2)*NL + 
          (-0.0033644713826677117 + 0.0074732932527747835*lm + 
            0.0028713239940029137*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.040939561166467485 - 0.05985422600473318*lm - 
          0.015456541227619166*lm^2) + CF^2*(0.04731856156014069 + 
          0.14076399573121506*lm + 0.10117008803532544*lm^2) + 
        CF*((0.011004892798518401 + 0.0073058662622379625*lm + 
            0.002810280223203485*lm^2)*NM + (0.014282278129465352 + 
            0.0073058662622379625*lm + 0.002810280223203485*lm^2)*NL + 
          (-0.003294406464567781 + 0.0073058662622379625*lm + 
            0.002810280223203485*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.03994276424307977 - 0.05852627911389993*lm - 
          0.015126180711002324*lm^2) + CF^2*(0.046234657540670465 + 
          0.13743692529825766*lm + 0.09900772829019704*lm^2) + 
        CF*((0.010662562168188873 + 0.007140868434692011*lm + 
            0.0027502146747276955*lm^2)*NM + (0.013949724820175785 + 
            0.007140868434692011*lm + 0.0027502146747276955*lm^2)*NL + 
          (-0.0032252553620226846 + 0.007140868434692011*lm + 
            0.0027502146747276955*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.0389590672149661 - 0.057218916084166745*lm - 
          0.014801252739285856*lm^2) + CF^2*(0.04515915747090537 + 
          0.13415636285920127*lm + 0.09688092702078015*lm^2) + 
        CF*((0.010328071945935227 + 0.006978356009517887*lm + 
            0.0026911368616883377*lm^2)*NM + (0.013622638890888694 + 
            0.006978356009517887*lm + 0.0026911368616883377*lm^2)*NL + 
          (-0.003157041099694581 + 0.006978356009517887*lm + 
            0.0026911368616883377*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.03798918845451329 - 0.055932451988267885*lm - 
          0.014481796782578143*lm^2) + CF^2*(0.0440932443724498 + 
          0.13092372972679434*lm + 0.09478994257687512*lm^2) + 
        CF*((0.010001425873642176 + 0.006818377139088475*lm + 
            0.0026330539604687534*lm^2)*NM + (0.013301107416551314 + 
            0.006818377139088475*lm + 0.0026330539604687534*lm^2)*NL + 
          (-0.0030897837656440196 + 0.006818377139088475*lm + 
            0.0026330539604687534*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.037033451884308004 - 0.05466714523291088*lm - 
          0.014167840461565407*lm^2) + CF^2*(0.04303738272250569 + 
          0.12774026873958177*lm + 0.09273495574842812*lm^2) + 
        CF*((0.009682610698467563 + 0.006660972414877752*lm + 
            0.0025759709930118922*lm^2)*NM + (0.01298520084045697 + 
            0.006660972414877752*lm + 0.0025759709930118922*lm^2)*NL + 
          (-0.003023500696032094 + 0.006660972414877752*lm + 
            0.0025759709930118922*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.0360924539182168 - 0.0534232015176574*lm - 
          0.013859400487763957*lm^2) + CF^2*(0.0419926458327618 + 
          0.12460705490519411*lm + 0.09071607591990953*lm^2) + 
        CF*((0.009371597682856692 + 0.006506175369678281*lm + 
            0.0025198909977752646*lm^2)*NM + (0.012674974179446357 + 
            0.006506175369678281*lm + 0.0025198909977752646*lm^2)*NL + 
          (-0.0029582066508634423 + 0.006506175369678281*lm + 
            0.0025198909977752646*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.035166609299823993 - 0.05220077758922159*lm - 
          0.013556483544712623*lm^2) + CF^2*(0.0409598014586449 + 
          0.12152500566366278*lm + 0.088733346838119*lm^2) + 
        CF*((0.009068344039589678 + 0.006354012956288608*lm + 
            0.0024648151899477498*lm^2)*NM + (0.012370468167439143 + 
            0.006354012956288608*lm + 0.0024648151899477498*lm^2)*NL + 
          (-0.0028939139810666772 + 0.006354012956288608*lm + 
            0.0024648151899477498*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.034256274016013895 - 0.05099998479770377*lm - 
          0.0132590871132638*lm^2) + CF^2*(0.0399395519770941 + 
          0.11849489076213239*lm + 0.08678675201409033*lm^2) + 
        CF*((0.008772794276075479 + 0.0062045060031247655*lm + 
            0.002410743111502509*lm^2)*NM + (0.012071710338710465 + 
            0.0062045060031247655*lm + 0.002410743111502509*lm^2)*NL + 
          (-0.0028306327872144135 + 0.0062045060031247655*lm + 
            0.002410743111502509*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.03336174877315307 - 0.049820892461536655*lm - 
          0.01296720024400921*lm^2) + CF^2*(0.03893253608937143 + 
          0.11551734173602424*lm + 0.08487621977896938*lm^2) + 
        CF*((0.008484882127636982 + 0.006057669647285525*lm + 
            0.002357672771638038*lm^2)*NM + (0.011778716052533325 + 
            0.006057669647285525*lm + 0.002357672771638038*lm^2)*NL + 
          (-0.0027683710701845977 + 0.006057669647285525*lm + 
            0.002357672771638038*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.032481922202314155 - 0.04866353104809642*lm - 
          0.012680804279752704*lm^2) + CF^2*(0.03793661036278656 + 
          0.11259286099486199*lm + 0.08300162801292679*lm^2) + 
        CF*((0.008207375941652476 + 0.005913513745661533*lm + 
            0.0023056007781368554*lm^2)*NM + (0.01149148946096816 + 
            0.005913513745661533*lm + 0.0023056007781368554*lm^2)*NL + 
          (-0.002707134874067948 + 0.005913513745661533*lm + 
            0.0023056007781368554*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.031621081492781804 - 0.04752789517703393*lm - 
          0.012399873530818277*lm^2) + CF^2*(0.036960465990514196 + 
          0.10972183051366084*lm + 0.08116280856535599*lm^2) + 
        CF*((0.007931647533106082 + 0.005772043264725907*lm + 
            0.0022545224601487777*lm^2)*NM + (0.011210024421701497 + 
            0.005772043264725907*lm + 0.0022545224601487777*lm^2)*NL + 
          (-0.002646928421623371 + 0.005772043264725907*lm + 
            0.0022545224601487777*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.03077526057731794 - 0.046413946453423505*lm - 
          0.01212437590585807*lm^2) + CF^2*(0.03599632099711194 + 
          0.10690452013306037*lm + 0.07935955138379829*lm^2) + 
        CF*((0.007666214344461317 + 0.005633258649680091*lm + 
            0.002204431982883286*lm^2)*NM + (0.010934305357922478 + 
            0.005633258649680091*lm + 0.002204431982883286*lm^2)*NL + 
          (-0.002587754242574218 + 0.005633258649680091*lm + 
            0.002204431982883286*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.029946049706883283 - 0.04532161613781665*lm - 
          0.01185427350070323*lm^2) + CF^2*(0.03504753554594691 + 
          0.10414109547329699*lm + 0.07759160836823933*lm^2) + 
        CF*((0.007407919657857889 + 0.005497156173655171*lm + 
            0.002155322454673315*lm^2)*NM + (0.010664308067284195 + 
            0.005497156173655171*lm + 0.002155322454673315*lm^2)*NL + 
          (-0.0025296132950530397 + 0.005497156173655171*lm + 
            0.002155322454673315*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.029133414637755234 - 0.044250807660235224*lm - 
          0.011589523147680712*lm^2) + CF^2*(0.03411424677554889 + 
          0.10143162546870826*lm + 0.07585869696663738*lm^2) + 
        CF*((0.007156861534875977 + 0.005363728267686901*lm + 
            0.0021071860268510384*lm^2)*NM + (0.010400000482030542 + 
            0.005363728267686901*lm + 0.0021071860268510384*lm^2)*NL + 
          (-0.002472505080467325 + 0.005363728267686901*lm + 
            0.0021071860268510384*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.02833743480275363 - 0.043201398985048746*lm - 
          0.011330076927702082*lm^2) + CF^2*(0.0331968418899034 + 
          0.098776089530777*lm + 0.07416050352677726*lm^2) + 
        CF*((0.006912857494678851 + 0.005232963832193505*lm + 
            0.002060013986854924*lm^2)*NM + (0.01014134338238259 + 
            0.005232963832193505*lm + 0.002060013986854924*lm^2)*NL + 
          (-0.002416427752085223 + 0.005232963832193505*lm + 
            0.002060013986854924*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.027558119860644683 - 0.042173244833561295*lm - 
          0.011075882647316402*lm^2) + CF^2*(0.032295588272966545 + 
          0.09617438434879187*lm + 0.07249668641879826*lm^2) + 
        CF*((0.006675788632137831 + 0.005104848530689994*lm + 
            0.002013796844966619*lm^2)*NM + (0.009888291065274602 + 
            0.005104848530689994*lm + 0.002013796844966619*lm^2)*NL + 
          (-0.002361378217602961 + 0.005104848530689994*lm + 
            0.002013796844966619*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.0267954492893586 - 0.0411661787709896*lm - 
          0.010826884282808648*lm^2) + CF^2*(0.03141070994144006 + 
          0.093626330338056*lm + 0.07086687894202023*lm^2) + 
        CF*((0.006445532049144693 + 0.004979365066472142*lm + 
            0.0019685244150561177*lm^2)*NM + (0.009640791970511663 + 
            0.004979365066472142*lm + 0.0019685244150561177*lm^2)*NL + 
          (-0.0023073522359801637 + 0.004979365066472142*lm + 
            0.0019685244150561177*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.026049374893761926 - 0.0401800151643503*lm - 
          0.010583022393318231*lm^2) + CF^2*(0.03054239006073513 + 
          0.09113167774624059*lm + 0.06927069202899207*lm^2) + 
        CF*((0.0062219613920453665 + 0.004856493442998315*lm + 
            0.0019241858896942238*lm^2)*NM + (0.009398789266390933 + 
            0.004856493442998315*lm + 0.0019241858896942238*lm^2)*NL + 
          (-0.002254344508787129 + 0.004856493442998315*lm + 
            0.0019241858896942238*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.025319823132599156 - 0.03921455101759511*lm - 
          0.01034423450484902*lm^2) + CF^2*(0.02969077331751728 + 
          0.08869011242898354*lm + 0.06770771675901176*lm^2) + 
        CF*((0.006004947423679436 + 0.004736211208688595*lm + 
            0.001880769909972549*lm^2)*NM + (0.009162221396789058 + 
            0.004736211208688595*lm + 0.001880769909972549*lm^2)*NL + 
          (-0.0022023487663314512 + 0.004736211208688595*lm + 
            0.001880769909972549*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.024606697296429253 - 0.0382695676901419*lm - 
          0.010110455466942976*lm^2) + CF^2*(0.028855968197385548 + 
          0.08630126130619366*lm + 0.06617752669271768*lm^2) + 
        CF*((0.005794358577261391 + 0.004618493686848912*lm + 
            0.0018382646303532685*lm^2)*NM + (0.008931022591670978 + 
            0.004618493686848912*lm + 0.0018382646303532685*lm^2)*NL + 
          (-0.0021513578488055927 + 0.004618493686848912*lm + 
            0.0018382646303532685*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.023909879564255488 - 0.037344832504749036*lm - 
          0.009881617783694306*lm^2) + CF^2*(0.02803804920873417 + 
          0.08396469751075973*lm + 0.06467968003872636*lm^2) + 
        CF*((0.005590061457951423 + 0.00450331419141354*lm + 
            0.00179665777885351*lm^2)*NM + (0.00870512334292206 + 
            0.00450331419141354*lm + 0.00179665777885351*lm^2)*NL + 
          (-0.0021013637826889997 + 0.00450331419141354*lm + 
            0.00179665777885351*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.023229232937818183 - 0.03644010025047484*lm - 
          0.009657651920689573*lm^2) + CF^2*(0.027237059037138692 + 
          0.08167994524149637*lm + 0.06321372166269539*lm^2) + 
        CF*((0.005391921304093298 + 0.004390644229182962*lm + 
            0.0017559367128526498*lm^2)*NM + (0.00848445084734741 + 
            0.004390644229182962*lm + 0.0017559367128526498*lm^2)*NL + 
          (-0.0020523578526428186 + 0.004390644229182962*lm + 
            0.0017559367128526498*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.022564603059153386 - 0.03555511458625293*lm - 
          0.009438486589372033*lm^2) + CF^2*(0.026453010628619728 + 
          0.0794464843322006*lm + 0.06177918494861694*lm^2) + 
        CF*((0.0051998024093677896 + 0.004280453689216095*lm + 
            0.0017160884707949152*lm^2)*NM + (0.008268929418620646 + 
            0.004280453689216095*lm + 0.0017160884707949152*lm^2)*NL + 
          (-0.0020043306691078064 + 0.004280453689216095*lm + 
            0.0017160884707949152*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.021915819916277026 - 0.03468960935040265*lm - 
          0.009224049010244827*lm^2) + CF^2*(0.02568588919938284 + 
          0.07726375454865957*lm + 0.06037559352160251*lm^2) + 
        CF*((0.005013568508580068 + 0.0041727110200165535*lm + 
            0.001677099820044514*lm^2)*NM + (0.008058480869900268 + 
            0.0041727110200165535*lm + 0.001677099820044514*lm^2)*NL + 
          (-0.001957272231823146 + 0.0041727110200165535*lm + 
            0.001677099820044514*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.021282699441871472 - 0.03384330978118054*lm - 
          0.009014265156248228*lm^2) + CF^2*(0.024935654170382564 + 
          0.07513115962534889*lm + 0.059002462840897496*lm^2) + 
        CF*((0.0048330831292553705 + 0.0040673833951324085*lm + 
            0.0016389573011360416*lm^2)*NM + (0.007853024868766103 + 
            0.0040673833951324085*lm + 0.0016389573011360416*lm^2)*NL + 
          (-0.0019111719894847315 + 0.0040673833951324085*lm + 
            0.0016389573011360416*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.020665045009806652 - 0.03301593365326734*lm - 
          0.008809059977570215*lm^2) + CF^2*(0.02420224102566272 + 
          0.07304807105340713*lm + 0.05765930167136867*lm^2) + 
        CF*((0.004658209911419977 + 0.003964436867767897*lm + 
            0.00160164726864913*lm^2)*NM + (0.007652479266061599 + 
            0.003964436867767897*lm + 0.00160164726864913*lm^2)*NL + 
          (-0.0018660188956966116 + 0.003964436867767897*lm + 
            0.00160164726864913*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.020062648834269843 - 0.03220719233487539*lm - 
          0.00860835760907757*lm^2) + CF^2*(0.0234855630939787 + 
          0.07101383163127173*lm + 0.05634561344123501*lm^2) + 
        CF*((0.004488812897716562 + 0.003863836514984186*lm + 
            0.0015651559289231946*lm^2)*NM + (0.007456760400160815 + 
            0.003863836514984186*lm + 0.0015651559289231946*lm^2)*NL + 
          (-0.001821801461467668 + 0.003863836514984186*lm + 
            0.0015651559289231946*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.019475293276195026 - 0.03141679176995471*lm - 
          0.00841208156148613*lm^2) + CF^2*(0.02278551325368488 + 
          0.06902775878912301*lm + 0.05506089749336376*lm^2) + 
        CF*((0.004324756795588726 + 0.0037655465720445617*lm + 
            0.00152946937481566*lm^2)*NM + (0.007265783378112226 + 
            0.0037655465720445617*lm + 0.00152946937481566*lm^2)*NL + 
          (-0.0017785078043717256 + 0.0037655465720445617*lm + 
            0.00152946937481566*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.01890275206158943 - 0.030644433389773764*lm - 
          0.008220154897323646*lm^2) + CF^2*(0.022101965561300067 + 
          0.06708914769801534*lm + 0.053804650237027504*lm^2) + 
        CF*((0.004165907214310914 + 0.0036695305574376918*lm + 
            0.0014945736176952085*lm^2)*NM + (0.007079462335045436 + 
            0.0036695305574376918*lm + 0.0014945736176952085*lm^2)*NL + 
          (-0.0017361256945819564 + 0.0036695305574376918*lm + 
            0.0014945736176952085*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.01834479141621554 - 0.0298898149579525*lm - 
          0.008032500392677064*lm^2) + CF^2*(0.021434776804473366 + 
          0.06519727417428058*lm + 0.0525763662066135*lm^2) + 
        CF*((0.004012130877182458 + 0.003575751389090886*lm + 
            0.0014604546168503752*lm^2)*NM + (0.00689771067316176 + 
            0.003575751389090886*lm + 0.0014604546168503752*lm^2)*NL + 
          (-0.0016946425979308924 + 0.003575751389090886*lm + 
            0.0014604546168503752*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.017801171121010054 - 0.029152631352832744*lm - 
          0.007849040685657362*lm^2) + CF^2*(0.02078378798047864 + 
          0.06335139738947781*lm + 0.05137553903339364*lm^2) + 
        CF*((0.00386329581226204 + 0.003484171492263754*lm + 
            0.0014270983064831567*lm^2)*NM + (0.0067204412815659535 + 
            0.003484171492263754*lm + 0.0014270983064831567*lm^2)*NL + 
          (-0.0016540457161857375 + 0.003484171492263754*lm + 
            0.0014270983064831567*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.017271645492420714 - 0.0284325752908833*lm - 
          0.007669698412459743*lm^2) + CF^2*(0.020148825701495666 + 
          0.06155076239583619*lm + 0.050201662336100135*lm^2) + 
        CF*((0.0037192715220081903 + 0.0033947528995914036*lm + 
            0.0013944906204472261*lm^2)*NM + (0.006547566738134034 + 
            0.0033947528995914036*lm + 0.0013944906204472261*lm^2)*NL + 
          (-0.0016143220245763326 + 0.0033947528995914036*lm + 
            0.0013944906204472261*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.016755964291758057 - 0.027729337994655583*lm - 
          0.0074943963318444*lm^2) + CF^2*(0.019529703528270166 + 
          0.059794602476801455*lm + 0.049054230535708794*lm^2) + 
        CF*((0.003579929134033686 + 0.0033074573437254515*lm + 
            0.0013626175148807999*lm^2)*NM + (0.006378999494551695 + 
            0.0033074573437254515*lm + 0.0013626175148807999*lm^2)*NL + 
          (-0.001575458306927989 + 0.0033074573437254515*lm + 
            0.0013626175148807999*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.016253873567462246 - 0.027042609808629853*lm - 
          0.00732305743881349*lm^2) + CF^2*(0.018926223233825805 + 
          0.0580821413319532*lm + 0.047932739599506474*lm^2) + 
        CF*((0.0034451415337368877 + 0.0032222463430006533*lm + 
            0.00133146498887518*lm^2)*NM + (0.006214652045599066 + 
            0.0032222463430006533*lm + 0.00133146498887518*lm^2)*NL + 
          (-0.0015374411883128747 + 0.0032222463430006533*lm + 
            0.00133146498887518*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.01576511643410877 - 0.02637208076612279*lm - 
          0.007155605068213005*lm^2) + CF^2*(0.018338175999194982 + 
          0.05641259510521234*lm + 0.0468366877192124*lm^2) + 
        CF*((0.003314783481449438 + 0.003139081280535018*lm + 
            0.0013010191033114556*lm^2)*NM + (0.006054437083700864 + 
            0.003139081280535018*lm + 0.0013010191033114556*lm^2)*NL + 
          (-0.0015002571654981831 + 0.003139081280535018*lm + 
            0.0013010191033114556*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.015289433791702629 - 0.025717441110263698*lm - 
          0.006991962988943877*lm^2) + CF^2*(0.0177653435430074 + 
          0.05478517426491017*lm + 0.045765575927632654*lm^2) + 
        CF*((0.0031887317133035696 + 0.003057923477151841*lm + 
            0.0012712659979897958*lm^2)*NM + (0.005898267639706272 + 
            0.003057923477151841*lm + 0.0012712659979897958*lm^2)*NL + 
          (-0.0014638926352588408 + 0.003057923477151841*lm + 
            0.0012712659979897958*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.0148265649888068 - 0.025078381771889872*lm - 
          0.006832055489424799*lm^2) + CF^2*(0.01720749918716212 + 
          0.053199085343942534*lm + 0.04471890865805323*lm^2) + 
        CF*((0.0030668650290314155 + 0.002978734258493246*lm + 
            0.0012421919071681454*lm^2)*NM + (0.005746057210810268 + 
            0.002978734258493246*lm + 0.0012421919071681454*lm^2)*NL + 
          (-0.001428333920692927 + 0.002978734258493246*lm + 
            0.0012421919071681454*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.014376248432786476 - 0.024454594807060845*lm - 
          0.00667580745490976*lm^2) + CF^2*(0.01666440886065025 + 
          0.05165353254788853*lm + 0.043696194250318426*lm^2) + 
        CF*((0.0029490643665915422 + 0.002901475016676573*lm + 
            0.0012137831736199563*lm^2)*NM + (0.005597719876477573 + 
            0.002901475016676573*lm + 0.0012137831736199563*lm^2)*NL + 
          (-0.0013935672955866264 + 0.002901475016676573*lm + 
            0.0012137831736199563*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.013938222150351804 - 0.02384577379674692*lm - 
          0.006523144437225965*lm^2) + CF^2*(0.01613583204374381 + 
          0.05014771923863255*lm + 0.04269694540729723*lm^2) + 
        CF*((0.002835212864977597 + 0.002826107266827316*lm + 
            0.001186026261313812*lm^2)*NM + (0.005453170403181984 + 
            0.002826107266827316*lm + 0.001186026261313812*lm^2)*NL + 
          (-0.001359579007143397 + 0.002826107266827316*lm + 
            0.001186026261313812*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.013512224301426772 - 0.023251614211109006*lm - 
          0.006373992717462735*lm^2) + CF^2*(0.015621522654779797 + 
          0.048680849300694704*lm + 0.04172067960521063*lm^2) + 
        CF*((0.0027251959162114467 + 0.002752592698805302*lm + 
            0.0011589077668114065*lm^2)*NM + (0.005312324338727536 + 
            0.002752592698805302*lm + 0.0011589077668114065*lm^2)*NL + 
          (-0.0013263552968232903 + 0.002752592698805302*lm + 
            0.0011589077668114065*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.013097993649227004 - 0.022671813740654693*lm - 
          0.006228279362108788*lm^2) + CF^2*(0.015121229881780737 + 
          0.047252128397146674*lm + 0.040766919461075704*lm^2) + 
        CF*((0.002618901207409172 + 0.0026808932244244393*lm + 
            0.0011324144294743252*lm^2)*NM + (0.005175098096873699 + 
            0.0026808932244244393*lm + 0.0011324144294743252*lm^2)*NL + 
          (-0.0012938824197730144 + 0.0026808932244244393*lm + 
            0.0011324144294743252*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.012695269989285536 - 0.022106072596429126*lm - 
          0.006085932273104172*lm^2) + CF^2*(0.014634698961146952 + 
          0.045860765121670824*lm + 0.039835193060318214*lm^2) + 
        CF*((0.0025162187536721067 + 0.002610971020450611*lm + 
            0.0011065331405643948*lm^2)*NM + (0.005041409032944588 + 
            0.002610971020450611*lm + 0.0011065331405643948*lm^2)*NL + 
          (-0.001262146662646118 + 0.002610971020450611*lm + 
            0.0011065331405643948*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.01230379454003371 - 0.02155409378127885*lm - 
          0.00594688023224366*lm^2) + CF^2*(0.014161671905654333 + 
          0.04450597205300874*lm + 0.03892503424741305*lm^2) + 
        CF*((0.00241704092264954 + 0.0025427885676472086*lm + 
            0.0010812509513170292*lm^2)*NM + (0.004911175511062023 + 
            0.0025427885676472086*lm + 0.0010812509513170292*lm^2)*NL + 
          (-0.0012311343600813136 + 0.0025427885676472086*lm + 
            0.0010812509513170292*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.011923657901625154 - 0.02101586220005547*lm - 
          0.005811130669859588*lm^2) + CF*(0.013701425818708379 + 
          0.043187529720411906*lm + 0.03803649165726276*lm^2) + 
        0.002321455947668215*NM + 0.0024763414020260483*lm*NM + 
        0.0010565692127017432*lm^2*NM + 0.004784432601880712*NL + 
        0.0024763414020260483*lm*NL + 0.0010565692127017432*lm^2*NL - 
        0.0012008390198876592*NH + 0.0024763414020260483*lm*NH + 
        0.0010565692127017432*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.011553858627149407 - 0.020490487466221237*lm - 
          0.005678446917691224*lm^2) + CF*(0.013254698723159895 + 
          0.04190345355358649*lm + 0.037168016188524375*lm^2) + 
        0.0022289445136355036*NM + 0.002411522401334818*lm*NM + 
        0.0010324448941256771*lm^2*NM + 0.004660852113749595*NL + 
        0.002411522401334818*lm*NL + 0.0010324448941256771*lm^2*NL - 
        0.0011712318374531713*NH + 0.002411522401334818*lm*NH + 
        0.0010324448941256771*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.011194550271208177 - 0.0199780091128848*lm - 
          0.005548851925943927*lm^2) + CF*(0.012820676871073383 + 
          0.04065362961094996*lm + 0.036319758060723885*lm^2) + 
        0.002139633307173253*NM + 0.0023483334426201295*lm*NM + 
        0.0010088821683534412*lm^2*NM + 0.004540491371770039*NL + 
        0.0023483334426201295*lm*NL + 0.0010088821683534412*lm^2*NL - 
        0.0011423076957527063*NH + 0.0023483334426201295*lm*NH + 
        0.0010088821683534412*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.010845482038556379 - 0.019478142707886524*lm - 
          0.005422278104622238*lm^2) + CF*(0.012399097506333456 + 
          0.03943729379391264*lm + 0.03549127486661829*lm^2) + 
        0.0020534236297973765*NM + 0.0022867384516039742*lm*NM + 
        0.0009858687462949525*lm^2*NM + 0.0044232729630096996*NL + 
        0.0022867384516039742*lm*NL + 0.0009858687462949525*lm^2*NL - 
        0.0011140532409406351*NH + 0.0022867384516039742*lm*NH + 
        0.0009858687462949525*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.010506406126181846 - 0.018990607697528424*lm - 
          0.005298658924856202*lm^2) + CF*(0.011989697349653904 + 
          0.03825369015785184*lm + 0.03468213114451332*lm^2) + 
        0.001970219231733779*NM + 0.0022267018136334846*lm*NM + 
        0.0009633925317920368*lm^2*NM + 0.004309120756357551*NL + 
        0.0022267018136334846*lm*NL + 0.0009633925317920368*lm^2*NL - 
        0.0010864552335528733*NH + 0.0022267018136334846*lm*NH + 
        0.0009633925317920368*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.010177077918759318 - 0.0185151275292809*lm - 
          0.005177928933439907*lm^2) + CF*(0.011592213102281283 + 
          0.037102071479182264*lm + 0.03389189847342485*lm^2) + 
        0.0018899262911994319*NM + 0.0021681883926269615*lm*NM + 
        0.0009414416242618013*lm^2*NM + 0.004197959925900875*NL + 
        0.0021681883926269615*lm*NL + 0.0009414416242618013*lm^2*NL - 
        0.001059500557854416*NH + 0.0021681883926269615*lm*NH + 
        0.0009414416242618013*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.00985725616157509 - 0.018051429758165857*lm - 
          0.005060023764509918*lm^2) + CF*(0.011206381909104605 + 
          0.035981699762027856*lm + 0.03312015554951946*lm^2) + 
        0.0018124533904869443*NM + 0.0021111635477138115*lm*NM + 
        0.0009200043208199851*lm^2*NM + 0.004089716969980609*NL + 
        0.0021111635477138115*lm*NL + 0.0009200043208199851*lm^2*NL - 
        0.0010331762303078284*NH + 0.0021111635477138115*lm*NH + 
        0.0009200043208199851*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.009546703112504976 - 0.017599246137957908*lm - 
          0.00494488014857599*lm^2) + CF*(0.010831941783604708 + 
          0.03489184668851936*lm + 0.03236648824522466*lm^2) + 
        0.0017377114891853204*NM + 0.0020555931477268283*lm*NM + 
        0.0008990691179229072*lm^2*NM + 0.0039843197262554135*NL + 
        0.0020555931477268283*lm*NL + 0.0008990691179229072*lm^2*NL - 
        0.0010074694072170188*NH + 0.0020555931477268283*lm*NH + 
        0.0008990691179229072*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.009245184674535497 - 0.01715831269827953*lm - 
          0.0048324359191037995*lm^2) + CF*(0.010468631996951609 + 
          0.03383179401651589*lm + 0.031630489652315776*lm^2) + 
        0.001665613894846633*NM + 0.002001443583696226*lm*NM + 
        0.0008786247125643271*lm^2*NM + 0.003881697383084693*NL + 
        0.002001443583696226*lm*NL + 0.0008786247125643271*lm^2*NL - 
        0.0009823673915977473*NH + 0.002001443583696226*lm*NH + 
        0.0008786247125643271*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.008952470510230265 - 0.01672836980860372*lm - 
          0.004722630016837477*lm^2) + CF*(0.010116193433438541 + 
          0.032800833928334744*lm + 0.03091176011020894*lm^2) + 
        0.0015960762313866653*NM + 0.0019486817794862187*lm*NM + 
        0.0008586600030613593*lm^2*NM + 0.0037817804875216452*NL + 
        0.0019486817794862187*lm*NL + 0.0008586600030613593*lm^2*NL - 
        0.0009578576393235791*NH + 0.0019486817794862187*lm*NH + 
        0.0008586600030613593*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.008668334139460112 - 0.016309162230118197*lm - 
          0.004615402492038356*lm^2) + CF*(0.009774368914327267 + 
          0.031798269333869776*lm + 0.030209907220614694*lm^2) + 
        0.00152901640548717*NM + 0.0018972752007068295*lm*NM + 
        0.0008391640894615192*lm^2*NM + 0.0036845009501894*NL + 
        0.0018972752007068295*lm*NL + 0.0008391640894615192*lm^2*NL - 
        0.0009339277645933906*NH + 0.0018972752007068295*lm*NH + 
        0.0008391640894615192*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.008392553021636532 - 0.015900439156349252*lm - 
          0.004510694504805633*lm^2) + CF*(0.009442903492070422 + 
          0.030823414131285427*lm + 0.02952454584963687*lm^2) + 
        0.001464354571248155*NM + 0.0018471918620258329*lm*NM + 
        0.0008201262736010242*lm^2*NM + 0.0035897920472961493*NL + 
        0.0018471918620258329*lm*NL + 0.0008201262736010242*lm^2*NL - 
        0.000910565544764046*NH + 0.0018471918620258329*lm*NH + 
        0.0008201262736010242*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.008124908623613113 - 0.015501954243389819*lm - 
          0.004408448323634438*lm^2) + CF*(0.009121544716772855 + 
          0.0298755934282898*lm + 0.028855298118334503*lm^2) + 
        0.0014020130933205227*NM + 0.0017984003329984443*lm*NM + 
        0.000801536058842625*lm^2*NM + 0.0034975884200290387*NL + 
        0.0017984003329984443*lm*NL + 0.000801536058842625*lm^2*NL - 
        0.0008877589245895036*NH + 0.0017984003329984443*lm*NH + 
        0.000801536058842625*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.007865186474348782 - 0.015113465630526022*lm - 
          0.004308607322357196*lm^2) + CF*(0.008810042876654942 + 
          0.02895414372681585*lm + 0.02820179338270165*lm^2) + 
        0.001341916508732334*NM + 0.0017508697425253799*lm*NM + 
        0.0007833831495194903*lm^2*NM + 0.0034078260715512763*NL + 
        0.0017508697425253799*lm*NL + 0.0007833831495194903*lm^2*NL - 
        0.0008654960199053634*NH + 0.0017508697425253799*lm*NH + 
        0.0007833831495194903*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.0076131762073595646 - 0.014734735952008415*lm - 
          0.004211115975605056*lm^2) + CF*(0.00850815121418659 + 
          0.028058413073774637*lm + 0.027563668203960362*lm^2) + 
        0.0012839914876059807*NM + 0.0017045697820433354*lm*NM + 
        0.00076565745011001*lm^2*NM + 0.003320442361812475*NL + 
        0.0017045697820433354*lm*NL + 0.00076565745011001*lm^2*NL - 
        0.0008437651207957246*NH + 0.0017045697820433354*lm*NH + 
        0.00076565745011001*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.007368671591922041 - 0.01436553234066895*lm - 
          0.004115919852917513*lm^2) + CF*(0.008215626119470736 + 
          0.027187761180387567*lm + 0.026940566310005538*lm^2) + 
        0.0012281667929484829*NM + 0.0016594707075456739*lm*NM + 
        0.0007483490641668204*lm^2*NM + 0.0032353760003685935*NL + 
        0.0016594707075456739*lm*NL + 0.0007483490641668204*lm^2*NL - 
        0.000822554694277194*NH + 0.0016594707075456739*lm*NH + 
        0.0007483490641668204*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.007131470553931669 - 0.014005626424041658*lm - 
          0.0040229656116202665*lm^2) + CF*(0.007932227302369541 + 
          0.026341559512455946*lm + 0.0263321385487872*lm^2) + 
        0.001174373239682999*NM + 0.0016155433405251984*lm*NM + 
        0.0007314482930218666*lm^2*NM + 0.0031525670373949567*NL + 
        0.0016155433405251984*lm*NL + 0.0007314482930218666*lm^2*NL - 
        0.0008018533865329483*NH + 0.0016155433405251984*lm*NH + 
        0.0007314482930218666*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.006901375187262269 - 0.013654794313604496*lm - 
          0.00393220098858358*lm^2) + CF*(0.007657717944785031 + 
          0.025519191353785345*lm + 0.02573804283436525*lm^2) + 
        0.0011225436530763752*NM + 0.0015727590679252784*lm*NM + 
        0.0007149456342879237*lm^2*NM + 0.003071956853063674*NL + 
        0.0015727590679252784*lm*NL + 0.0007149456342879237*lm^2*NL - 
        0.0007816500247279195*NH + 0.0015727590679252784*lm*NH + 
        0.0007149456342879237*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.006678191756419355 - 0.01331281658772128*lm - 
          0.003843574790966193*lm^2) + CF*(0.00739186483442824 + 
          0.024720051844848625*lm + 0.02515794408632417*lm^2) + 
        0.0010726128267051099*NM + 0.0015310898411802871*lm*NM + 
        0.0006988317801756715*lm^2*NM + 0.0029934881454452993*NL + 
        0.0015310898411802871*lm*NL + 0.0006988317801756715*lm^2*NL - 
        0.0007619336184344246*NH + 0.0015310898411802871*lm*NH + 
        0.0006988317801756715*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.006461730691229218 - 0.012979478268826332*lm - 
          0.0037570368860429543*lm^2) + CF*(0.0071344384813371116 + 
          0.023943547998645037*lm + 0.024591514163190244*lm^2) + 
        0.0010245174800904457*NM + 0.001490508174421294*lm*NM + 
        0.0006830976156441735*lm^2*NM + 0.0029171049170837603*NL + 
        0.001490508174421294*lm*NL + 0.0006830976156441735*lm^2*NL - 
        0.0007426933606959034*NH + 0.001490508174421294*lm*NH + 
        0.0006830976156441735*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.006251806574257767 - 0.012654568795360064*lm - 
          0.0036725381902078373*lm^2) + CF*(0.0068852132183331435 + 
          0.023189098695593137*lm + 0.0240384317904513*lm^2) + 
        0.0009781962161223786*NM + 0.0014509871419181978*lm*NM + 
        0.000667734216401425*lm^2*NM + 0.0028427524603833894*NL + 
        0.0014509871419181978*lm*NL + 0.000667734216401425*lm^2*NL - 
        0.0007239186287548544*NH + 0.0014509871419181978*lm*NH + 
        0.000667734216401425*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.00604823812160794 - 0.012337881988931198*lm - 
          0.003590030657237919*lm^2) + CF*(0.0066439672865399035 + 
          0.0224561346591818*lm + 0.023498382483739106*lm^2) + 
        0.0009335894783821421*NM + 0.0014125003748249967*lm*NM + 
        0.0006527328467705307*lm^2*NM + 0.0027703773419372733*NL + 
        0.0014125003748249967*lm*NL + 0.0006527328467705307*lm^2*NL - 
        0.0007055989844695611*NH + 0.0014125003748249967*lm*NH + 
        0.0006527328467705307*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.005850848157701751 - 0.012029216017150672*lm - 
          0.0035094672658981*lm^2) + CF*(0.006410482907023002 + 
          0.021744098413996413*lm + 0.022971058467696655*lm^2) + 
        0.0008906395084631517*NM + 0.0013750220572906445*lm*NM + 
        0.0006380849574360182*lm^2*NM + 0.002699927385917106*NL + 
        0.0013750220572906445*lm*NL + 0.0006380849574360182*lm^2*NL - 
        0.0006877241744427853*NH + 0.0013750220572906445*lm*NH + 
        0.0006380849574360182*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.00565946358461282 - 0.01172837335255326*lm - 
          0.0034308020069609316*lm^2) + CF*(0.006184546339550705 + 
          0.021052444227635955*lm + 0.022456158591017007*lm^2) + 
        0.0008492903033814616*NM + 0.0013385269219939307*lm*NM + 
        0.0006237821830838057*lm^2*NM + 0.0026313516566362043*NL + 
        0.0013385269219939307*lm*NL + 0.0006237821830838057*lm^2*NL - 
        0.000670284129884255*NH + 0.0013385269219939307*lm*NH + 
        0.0006237821830838057*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.005473915346477252 - 0.011435160727995537*lm - 
          0.0033539898697107686*lm^2) + CF*(0.005965947929416972 + 
          0.020380638037940543*lm + 0.021953388238106848*lm^2) + 
        0.0008094875731584218*NM + 0.0013029902451570275*lm*NM + 
        0.0006098163399474125*lm^2*NM + 0.0025646004403893376*NL + 
        0.0013029902451570275*lm*NL + 0.0006098163399474125*lm^2*NL - 
        0.0006532689662274988*NH + 0.0013029902451570275*lm*NH + 
        0.0006098163399474125*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.00529403838947493 - 0.011149389088893076*lm - 
          0.003278986827996651*lm^2) + CF*(0.005754482143214141 + 
          0.019728157366858654*lm + 0.02146245923779626*lm^2) + 
        0.0007711786986504335*NM + 0.0012683878410887724*lm*NM + 
        0.0005961794232721184*lm^2*NM + 0.002499625226665496*NL + 
        0.0012683878410887724*lm*NL + 0.0005961794232721184*lm^2*NL - 
        0.0006366689825203674*NH + 0.0012683878410887724*lm*NH + 
        0.0005961794232721184*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.005119671617839599 - 0.010870873542635261*lm - 
          0.0032057498258937687*lm^2) + CF*(0.005549947594390756 + 
          0.019094491222197276*lm + 0.02098308976948649*lm^2) + 
        0.0007343126896934309*NM + 0.0012346960563053735*lm*NM + 
        0.000582863604707958*lm^2*NM + 0.0024363786888226407*NL + 
        0.0012346960563053735*lm*NL + 0.000582863604707958*lm^2*NL - 
        0.0006204746606074342*NH + 0.0012346960563053735*lm*NH + 
        0.000582863604707958*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.004950657846324344 - 0.010599433305493264*lm - 
          0.0031342367630290795*lm^2) + CF*(0.005352147059380809 + 
          0.018479139988417555*lm + 0.02051500426709943*lm^2) + 
        0.0006988401436229428*NM + 0.001201891763273038*lm*NM + 
        0.0005698612296416508*lm^2*NM + 0.0023748146643068255*NL + 
        0.001201891763273038*lm*NL + 0.0005698612296416508*lm^2*NL - 
        0.000604676664121378*NH + 0.001201891763273038*lm*NH + 
        0.0005698612296416508*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.004786843749519197 - 0.010334891647314997*lm - 
          0.0030644064796226346*lm^2) + CF*(0.00516088748504408 + 
          0.017881615307561993*lm + 0.020057933321166333*lm^2) + 
        0.0006647132042242837*NM + 0.001169952353814018*lm*NM + 
        0.0005571648144768426*lm^2*NM + 0.002314888134491846*NL + 
        0.001169952353814018*lm*NL + 0.0005571648144768426*lm^2*NL - 
        0.0005892658372994226*NH + 0.001169952353814018*lm*NH + 
        0.0005571648144768426*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.004628079808389485 - 0.01007707583428045*lm - 
          0.002996218741292378*lm^2) + CF*(0.0049759799881129345 + 
          0.017301439951327224*lm + 0.01961161357936829*lm^2) + 
        0.0006318855211615643*NM + 0.0011388557322147383*lm*NM + 
        0.0005447670438713414*lm^2*NM + 0.0022565552042097033*NL + 
        0.0011388557322147383*lm*NL + 0.0005447670438713414*lm^2*NL - 
        0.0005742332036399288*NH + 0.0011388557322147383*lm*NH + 
        0.0005447670438713414*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.004474220254377084 - 0.009825817069971652*lm - 
          0.0029296342236666247*lm^2) + CF*(0.004797239847299028 + 
          0.016738147685228355*lm + 0.01917578764581791*lm^2) + 
        0.0006003122099287603*NM + 0.0011085803080719905*lm*NM + 
        0.0005326607679393864*lm^2*NM + 0.0021997730810366925*NL + 
        0.0011085803080719905*lm*NL + 0.0005326607679393864*lm^2*NL - 
        0.0005595699644133093*NH + 0.0011085803080719905*lm*NH + 
        0.0005326607679393864*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.004325123011381907 - 0.009580950434993378*lm - 
          0.002864614496845095*lm^2) + CF*(0.004624486488673523 + 
          0.016191283125736727*lm + 0.018750203979349712*lm^2) + 
        0.0005699498123610264*NM + 0.001079104988910675*lm*NM + 
        0.0005208389994263809*lm^2*NM + 0.002144500054394755*NL + 
        0.001079104988910675*lm*NL + 0.0005208389994263809*lm^2*NL - 
        0.0005452674970405655*NH + 0.001079104988910675*lm*NH + 
        0.0005208389994263809*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.004180649635917585 - 0.009342314825363704*lm - 
          0.0028011220097462286*lm^2) + CF*(0.004457543464896751 + 
          0.015660401591212507*lm + 0.018334616791066224*lm^2) + 
        0.0005407562577397554*NM + 0.0010504091726041905*lm*NM + 
        0.0005092949108629507*lm^2*NM + 0.0020906954745229323*NL + 
        0.0010504091726041905*lm*NL + 0.0005092949108629507*lm^2*NL - 
        0.0005313173533519106*NH + 0.0010504091726041905*lm*NH + 
        0.0005092949108629507*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.004040665255713381 - 0.009109752889877523*lm - 
          0.0027391200743755784*lm^2) + CF*(0.004296238428837501 + 
          0.015145068947396588*lm + 0.01792878594136742*lm^2) + 
        0.0005126908245205426*NM + 0.0010224727396263582*lm*NM + 
        0.0004980218317046506*lm^2*NM + 0.002038319731369229*NL + 
        0.0010224727396263582*lm*NL + 0.0004980218317046506*lm^2*NL - 
        0.0005177112577371663*NH + 0.0010224727396263582*lm*NH + 
        0.0004980218317046506*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.003905038507013793 - 0.008883110966631106*lm - 
          0.002678572850047307*lm^2) + CF*(0.004140403102088306 + 
          0.014644861448172548*lm + 0.017532476836673284*lm^2) + 
        0.0004857141027092005*NM + 0.000995276045161651*lm*NM + 
        0.0004870132454631467*lm^2*NM + 0.001987334233448971*NL + 
        0.000995276045161651*lm*NL + 0.0004870132454631467*lm^2*NL - 
        0.0005044411051988744*NH + 0.000995276045161651*lm*NH + 
        0.0004870132454631467*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.0037736414708080183 - 0.008662239018881584*lm - 
          0.0026194453275882336*lm^2) + CF*(0.003989873238851043 + 
          0.014159365572258973*lm + 0.017145460326032078*lm^2) + 
        0.0004597879569072638*NM + 0.0009687999110985481*lm*NM + 
        0.0004762627868342243*lm^2*NM + 0.0019377013867118039*NL + 
        0.0009687999110985481*lm*NL + 0.0004762627868342243*lm^2*NL - 
        0.0004914989593183661*NH + 0.0009687999110985481*lm*NH + 
        0.0004762627868342243*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.003646349608203307 - 0.008446990570402059*lm - 
          0.002561703313551447*lm^2) + CF*(0.0038444885856368963 + 
          0.01368817785644493*lm + 0.01676751259779129*lm^2) + 
        0.00043487549004499974*NM + 0.000943025617928965*lm*NM + 
        0.00046576423882753584*lm^2*NM + 0.0018893845734557655*NL + 
        0.000943025617928965*lm*NL + 0.00046576423882753584*lm^2*NL - 
        0.0004788770501443689*NH + 0.000943025617928965*lm*NH + 
        0.00046576423882753584*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.0035230416951393152 - 0.00823722264048049*lm - 
          0.0025053134144642345*lm^2) + CF*(0.0037040928371960234 + 
          0.013230904725936594*lm + 0.016398415076493172*lm^2) + 
        0.0004109410078167921*NM + 0.0009179348965749772*lm*NM + 
        0.00045551152990258814*lm^2*NM + 0.0018423481313234451*NL + 
        0.0009179348965749772*lm*NL + 0.00045551152990258814*lm^2*NL - 
        0.0004665677720131061*NH + 0.0009179348965749772*lm*NH + 
        0.00045551152990258814*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0034035997566246624 - 0.008032795678698901*lm - 
          0.0024502430211329556*lm^2) + CF*(0.0035685335890651786 + 
          0.012787162322341094*lm + 0.01603795432014298*lm^2) + 
        0.00038794998383086384*NM + 0.0008935099201624221*lm*NM + 
        0.0004454987311150828*lm^2*NM + 0.0017965573324120018*NL + 
        0.0008935099201624221*lm*NL + 0.0004454987311150828*lm^2*NL - 
        0.00045456368130825114*NH + 0.0008935099201624221*lm*NH + 
        0.0004454987311150828*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.003287909000662023 - 0.00783357349961838*lm - 
          0.0023964602930254923*lm^2) + CF*(0.003437662287095929 + 
          0.012356576329774084*lm + 0.01568592191798504*lm^2) + 
        0.0003658690254826448*NM + 0.0008697332957594262*lm*NM + 
        0.00043572005327736224*lm^2*NM + 0.0017519783625258305*NL + 
        0.0008697332957594262*lm*NL + 0.00043572005327736224*lm^2*NL - 
        0.0004428574941685435*NH + 0.0008697332957594262*lm*NH + 
        0.00043572005327736224*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.003175857752014191 - 0.007639423217485201*lm - 
          0.0023439341427500694*lm^2) + CF*(0.003311334174301875 + 
          0.011938781799540438*lm + 0.015342114388909546*lm^2) + 
        0.00034466584055864777*NM + 0.0008465880560964668*lm*NM + 
        0.00042616984413637626*lm^2*NM + 0.001708578300597863*NL + 
        0.0008465880560964668*lm*NL + 0.00042616984413637626*lm^2*NL - 
        0.00043144208415034395*NH + 0.0008465880560964668*lm*NH + 
        0.00042616984413637626*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.003067337385950539 - 0.007450215181063665*lm - 
          0.002292634220647479*lm^2) + CF*(0.0031894082353404437 + 
          0.0115334229738027*lm + 0.015006333080601682*lm^2) + 
        0.00032430920457548367*NM + 0.0008240576512832333*lm*NM + 
        0.00041684258557226896*lm^2*NM + 0.0016663250983028927*NL + 
        0.0008240576512832333*lm*NL + 0.00041684258557226896*lm^2*NL - 
        0.0004203104798519115*NH + 0.0008240576512832333*lm*NH + 
        0.00041684258557226896*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.002962242262101143 - 0.007265822908692298*lm - 
          0.002242530899512154*lm^2) + CF*(0.0030717471389232246 + 
          0.011140153108619159*lm + 0.014678384069534098*lm^2) + 
        0.00030476892885660623*NM + 0.0008021259405362832*lm*NM + 
        0.0004077328908203916*lm^2*NM + 0.0016251875598838846*NL + 
        0.0008021259405362832*lm*NL + 0.0004077328908203916*lm^2*NL - 
        0.0004094558625057146*NH + 0.0008021259405362832*lm*NH + 
        0.0004077328908203916*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.002860469658534512 - 0.007086123023651605*lm - 
          0.0021935952594559958*lm^2) + CF*(0.0029582171784284716 + 
          0.010758634296702804*lm + 0.01435807806189379*lm^2) + 
        0.00028601582934751756*NM + 0.0007807771839303093*lm*NM + 
        0.000398835501719272*lm^2*NM + 0.001585135322209992*NL + 
        0.0007807771839303093*lm*NL + 0.000398835501719272*lm^2*NL - 
        0.00039887156354464896*NH + 0.0007807771839303093*lm*NH + 
        0.000398835501719272*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.002761919706164268 - 0.0069109951899237*lm - 
          0.0021457990729274825*lm^2) + CF*(0.002848688210970169 + 
          0.010388537290223692*lm + 0.01404523029552534*lm^2) + 
        0.00026802169616847477*NM + 0.0007599960341847262*lm*NM + 
        0.000390145285986815*lm^2*NM + 0.001546138835082902*NL + 
        0.0007599960341847262*lm*NL + 0.000390145285986815*lm^2*NL - 
        0.0003885510621476152*NH + 0.0007599960341847262*lm*NH + 
        0.000390145285986815*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.0026664953235802404 - 0.006740322048416759*lm - 
          0.002099114789897246*lm^2) + CF*(0.0027430335951599723 + 
          0.010029541323950286*lm + 0.013739660442963793*lm^2) + 
        0.00025075926390220654*NM + 0.0007397675284962463*lm*NM + 
        0.000381657234526772*lm^2*NM + 0.0015081693418061955*NL + 
        0.0007397675284962463*lm*NL + 0.000381657234526772*lm^2*NL - 
        0.00037848798276952044*NH + 0.0007397675284962463*lm*NH + 
        0.000381657234526772*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.0025741021523902697 - 0.006573989153720372*lm - 
          0.002053515523220108*lm^2) + CF*(0.0026411301277812476 + 
          0.009681333939000185*lm + 0.013441192515622527*lm^2) + 
        0.00023420218261275977*NM + 0.0007200770804271501*lm*NM + 
        0.0003733664587672924*lm^2*NM + 0.0014711988600306146*NL + 
        0.0007200770804271501*lm*NL + 0.0003733664587672924*lm^2*NL - 
        0.00036867609266039516*NH + 0.0007200770804271501*lm*NH + 
        0.0003733664587672924*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.0024846484931504253 - 0.006411884911451433*lm - 
          0.0020089750341824157*lm^2) + CF*(0.0025428579795783906 + 
          0.009343610807447012*lm + 0.013149654769193992*lm^2) + 
        0.00021832498959034851*NM + 0.0007009104718580486*lm*NM + 
        0.00036526818803316643*lm^2*NM + 0.0014352001628864563*NL + 
        0.0007009104718580486*lm*NL + 0.00036526818803316643*lm^2*NL - 
        0.00035910929937797123*NH + 0.0007009104718580486*lm*NH + 
        0.00036526818803316643*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.0023980452419533876 - 0.006253900516244249*lm - 
          0.00196546771824247*lm^2) + CF*(0.0024481006303494488 + 
          0.009016075558008197*lm + 0.012864879610314349*lm^2) + 
        0.0002031030818159524*NM + 0.0006822538450130935*lm*NM + 
        0.00035735776695317636*lm^2*NM + 0.001400146760412779*NL + 
        0.0006822538450130935*lm*NL + 0.00035735776695317636*lm^2*NL - 
        0.00034978164829773854*NH + 0.0006822538450130935*lm*NH + 
        0.00035735776695317636*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.002314205827737331 - 0.006099929890432952*lm - 
          0.0019229685909708636*lm^2) + CF*(0.0023567448035158567 + 
          0.008698439603017775*lm + 0.012586703504536561*lm^2) + 
        0.00018851268913840848*NM + 0.0006640936945647996*lm*NM + 
        0.00034963065290379334*lm^2*NM + 0.0013660128812916798*NL + 
        0.0006640936945647996*lm*NL + 0.00034963065290379334*lm^2*NL - 
        0.0003406873201241896*NH + 0.0006640936945647996*lm*NH + 
        0.00034963065290379334*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0022330461503707764 - 0.005949869623469083*lm - 
          0.001881453274196621*lm^2) + CF*(0.002268680400329692 + 
          0.008390421966869033*lm + 0.01231496688565061*lm^2) + 
        0.00017453084815584287*NM + 0.0006464168598249126*lm*NM + 
        0.00034208241349029475*lm^2*NM + 0.0013327734548945899*NL + 
        0.0006464168598249126*lm*NL + 0.00034208241349029475*lm^2*NL - 
        0.0003318206284066725*NH + 0.0006464168598249126*lm*NH + 
        0.00034208241349029475*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.002154484519562477 - 0.0058036189121124316*lm - 
          0.0018408979823642175*lm^2) + CF*(0.002183800433866283 + 
          0.008091749116093871*lm + 0.01204951406638397*lm^2) + 
        0.0001611353767924953*NM + 0.0006292105170270694*lm*NM + 
        0.0003347087240662214*lm^2*NM + 0.00130040409364632*NL + 
        0.0006292105170270694*lm*NL + 0.0003347087240662214*lm^2*NL - 
        0.0003231760170630005*NH + 0.0006292105170270694*lm*NH + 
        0.0003347087240662214*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0020784415946395 - 0.005661079501428665*lm - 
          0.0018012795091057493*lm^2) + CF*(0.0021020009629381677 + 
          0.0078021547912289725*lm + 0.01179019315051036*lm^2) + 
        0.00014830484956128933*NM + 0.0006124621717063609*lm*NM + 
        0.0003275053652919544*lm^2*NM + 0.0012688810757114789*NL + 
        0.0006124621717063609*lm*NL + 0.0003275053652919544*lm^2*NL - 
        0.00031474805791371*NH + 0.0006124621717063609*lm*NH + 
        0.0003275053652919544*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.0020048403252311644 - 0.00552215562662314*lm - 
          0.0017625752140318235*lm^2) + CF*(0.002023181026055321 + 
          0.007521379840603253*lm + 0.011536855946390116*lm^2) + 
        0.0001360185735018864*NM + 0.0005961596511803142*lm*NM + 
        0.0003204682207330588*lm^2*NM + 0.0012381813280068514*NL + 
        0.0005961596511803142*lm*NL + 0.0003204682207330588*lm^2*NL - 
        0.0003065314482296201*NH + 0.0005961596511803142*lm*NH + 
        0.0003204682207330588*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.0019336058928914356 - 0.00538675395573639*lm - 
          0.001724763009744062*lm^2) + CF*(0.0019472425755461204 + 
          0.007249172056166444*lm + 0.011289357881961132*lm^2) + 
        0.0001242565647834307*NM + 0.0005802910971352633*lm*NM + 
        0.00031359327449892037*lm^2*NM + 0.0012082824095423967*NL + 
        0.0005802910971352633*lm*NL + 0.00031359327449892037*lm^2*NL - 
        0.0002985210082951202*NH + 0.0005802910971352633*lm*NH + 
        0.00031359327449892037*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.0018646656536876732 - 0.00525478353322323*lm - 
          0.0016878213490715067*lm^2) + CF*(0.0018740904119437889 + 
          0.006985286011465188*lm + 0.011047557921195316*lm^2) + 
        0.00011299952596073095*NM + 0.000564844958321561*lm*NM + 
        0.0003068766089220921*lm^2*NM + 0.001179162495092648*NL + 
        0.000564844958321561*lm*NL + 0.0003068766089220921*lm^2*NL - 
        0.00029071167898940206*NH + 0.000564844958321561*lm*NH + 
        0.0003068766089220921*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0017979490817792972 - 0.005126155724434004*lm - 
          0.001651729212532636*lm^2) + CF*(0.0018036321187338575 + 
          0.006729482901860345*lm + 0.0108113184820318*lm^2) + 
        0.00010222882387223592*NM + 0.000549809983360614*lm*NM + 
        0.0003003144022786611*lm^2*NM + 0.001150800359199514*NL + 
        0.000549809983360614*lm*NL + 0.0003003144022786611*lm^2*NL - 
        0.000283098519387654*NH + 0.000549809983360614*lm*NH + 
        0.0003003144022786611*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.0017333877140059484 - 0.005000784161013537*lm - 
          0.0016164660960241975*lm^2) + CF*(0.0017357779975496512 + 
          0.00648153038706755*lm + 0.010580505355794747*lm^2) + 
        0.00009192646816783187*NM + 0.0005351752136662834*lm*NM + 
        0.00029390292654985406*lm^2*NM + 0.0011231753605067658*NL + 
        0.0005351752136662834*lm*NL + 0.00029390292654985406*lm^2*NL - 
        0.0002756767043840488*NH + 0.0005351752136662834*lm*NH + 
        0.00029390292654985406*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0016709150955010288 - 0.0048785846872303855*lm - 
          0.0015820119987375665*lm^2) + CF*(0.0016704410038947436 + 
          0.006241202436092128*lm + 0.010354987628100436*lm^2) + 
        0.00008207509045422057*NM + 0.0005209299764827821*lm*NM + 
        0.0002876385452250121*lm^2*NM + 0.001096267426425818*NL + 
        0.0005209299764827821*lm*NL + 0.0002876385452250121*lm^2*NL - 
        0.0002684415223381841*NH + 0.0005209299764827821*lm*NH + 
        0.0002876385452250121*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0016104667263431263 - 0.00475947530724645*lm - 
          0.0015483474113029173*lm^2) + CF*(0.0016075366834638373 + 
          0.006008279174619469*lm + 0.010134637601255459*lm^2) + 
        0.00007265792404541971*NM + 0.0005070638780408282*lm*NM + 
        0.000281517711145985*lm^2*NM + 0.0010700570381318366*NL + 
        0.0005070638780408282*lm*NL + 0.000281517711145985*lm^2*NL - 
        0.0002613883727464708*NH + 0.0005070638780408282*lm*NH + 
        0.000281517711145985*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0015519800092547136 - 0.004643376133334511*lm - 
          0.0015154533041610776*lm^2) + CF*(0.0015469831091264933 + 
          0.005782546734912523*lm + 0.009919330718145235*lm^2) + 
        0.00006365878430575853*NM + 0.0004935667968334633*lm*NM + 
        0.0002755369643929232*lm^2*NM + 0.0010445252158886456*NL + 
        0.0004935667968334633*lm*NL + 0.0002755369643929232*lm^2*NL - 
        0.0002545127639398124*NH + 0.0004935667968334633*lm*NH + 
        0.0002755369643929232*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0014953941983546597 - 0.004530209335049073*lm - 
          0.001483311116162578*lm^2) + CF*(0.0014887008186315874 + 
          0.005563797108259506*lm + 0.009708945487609602*lm^2) + 
        0.000055062049572618406*NM + 0.00048042887701262336*lm*NM + 
        0.0002696929302113778*lm^2*NM + 0.0010196535047004246*NL + 
        0.00048042887701262336*lm*NL + 0.0002696929302113778*lm^2*NL - 
        0.00024781031080877607*NH + 0.00048042887701262336*lm*NH + 
        0.0002696929302113778*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0014406503489684788 - 0.004419899089353811*lm - 
          0.0014519027433930725*lm^2) + CF*(0.0014326127530842447 + 
          0.005351828000006869*lm + 0.009503363411300111*lm^2) + 
        0.00004685264264608384*NM + 0.00046764052190725473*lm*NM + 
        0.00026398231698055867*lm^2*NM + 0.0009954239602877374*NL + 
        0.00046764052190725473*lm*NL + 0.00026398231698055867*lm^2*NL - 
        0.00024127673255732438*NH + 0.00046764052190725473*lm*NH + 
        0.00026398231698055867*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.0013876912684978502 - 0.004312371531707043*lm - 
          0.0014212105282239952*lm^2) + CF*(0.0013786441962412989 + 
          0.005146442687205188*lm + 0.009302468912011605*lm^2) + 
        0.00003901601283262361*NM + 0.00045519238766349656*lm*NM + 
        0.0002584019142225446*lm^2*NM + 0.0009718191353850423*NL + 
        0.00045519238766349656*lm*NL + 0.0002584019142225446*lm^2*NL - 
        0.00023490785048604988*NH + 0.00045519238766349656*lm*NH + 
        0.0002584019142225446*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.0013364614683487681 - 0.004207554708104921*lm - 
          0.0013912172485870452*lm^2) + CF*(0.0013267227146660056 + 
          0.004947449878888873*lm + 0.00910614926347884*lm^2) + 
        0.00003153811852990835*NM + 0.00044307537700719827*lm*NM + 
        0.00025294859065219005*lm^2*NM + 0.0009488220663564689*NL + 
        0.00044307537700719827*lm*NL + 0.00025294859065219005*lm^2*NL - 
        0.00022869958580574196*NH + 0.00044307537700719827*lm*NH + 
        0.00025294859065219005*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.001286907116915692 - 0.004105378528080456*lm - 
          0.0013619061074708434*lm^2) + CF*(0.0012767780987777903 + 
          0.004754663579004243*lm + 0.008914294521627338*lm^2) + 
        0.00002440541033988863*NM + 0.00043128063312881324*lm*NM + 
        0.00024761929226742606*lm^2*NM + 0.0009264162601263322*NL + 
        0.00043128063312881324*lm*NL + 0.00024761929226742606*lm^2*NL - 
        0.00022264795748200498*NH + 0.00043128063312881324*lm*NH + 
        0.00024761929226742606*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.001238975993617265 - 0.004005774718655037*lm - 
          0.00133326072263787*lm^2) + CF*(0.0012287423048282016 + 
          0.004567902951994827*lm + 0.008726797457266058*lm^2) + 
        0.000017604814697302526*NM + 0.00041979953369049945*lm*NM + 
        0.00024241104047961274*lm^2*NM + 0.0009045856814205699*NL + 
        0.00041979953369049945*lm*NL + 0.00024241104047961274*lm^2*NL - 
        0.00021674908011154773*NH + 0.00041979953369049945*lm*NH + 
        0.00024241104047961274*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.0011926174439775426 - 0.0039086767792377965*lm - 
          0.0013052651165595937*lm^2) + CF*(0.001182549397829968 + 
          0.0043869921910473795*lm + 0.00854355349020825*lm^2) + 
        0.00001112371800085147*NM + 0.0004086236849550652*lm*NM + 
        0.0002373209302835625*lm^2*NM + 0.0008833147403150395*NL + 
        0.0004086236849550652*lm*NL + 0.0002373209302835625*lm^2*NL - 
        0.00021099916183066924*NH + 0.0004086236849550652*lm*NH + 
        0.0002373209302835625*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.0011477823357451873 - 0.0038140199374669783*lm - 
          0.0012779037065675186*lm^2) + CF*(0.0011381354954620802 + 
          0.004211760388997295*lm + 0.008364460624805576*lm^2) + 
        4.949951234375284*^-6*NM + 0.00039774491603622317*lm*NM + 
        0.00023234612846682157*lm^2*NM + 0.0008625882800863876*NL + 
        0.00039774491603622317*lm*NL + 0.00023234612846682157*lm^2*NL - 
        0.00020539450225638011*NH + 0.00039774491603622317*lm*NH + 
        0.00023234612846682157*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0011044230160417634 - 0.0037217411059863735*lm - 
          0.0012511612952177125*lm^2) + CF*(0.0010954387129701413 + 
          0.004042041411887626*lm + 0.008189419386879572*lm^2) - 
        9.282249345305942*^-7*NM + 0.00038715527326945673*lm*NM + 
        0.0002274838718577659*lm^2*NM + 0.0008423915653610199*NL + 
        0.00038715527326945673*lm*NL + 0.0002274838718577659*lm^2*NL - 
        0.00019993149046051702*NH + 0.00038715527326945673*lm*NH + 
        0.0002274838718577659*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0010624932695290745 - 0.0036317788401489105*lm - 
          0.0012250230608662285*lm^2) + CF*(0.0010543991090778138 + 
          0.003877673775171883*lm + 0.008018332762033497*lm^2) - 
        6.522134590882922*^-6*NM + 0.00037684701470265807*lm*NM + 
        0.00022273146561204156*lm^2*NM + 0.0008227102705575246*NL + 
        0.00037684701470265807*lm*NL + 0.00022273146561204156*lm^2*NL - 
        0.00019460660297713266*NH + 0.00037684701470265807*lm*NH + 
        0.00022273146561204156*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0010219482775844085 - 0.0035440732966386117*lm - 
          0.0011994745484527158*lm^2) + CF*(0.0010149586329220406 + 
          0.0037185005225470573*lm + 0.007851106135326868*lm^2) - 
        0.000011842700555944995*NM + 0.00036681260470556546*lm*NM + 
        0.00021808628153685742*lm^2*NM + 0.00080353046861777*NL + 
        0.00036681260470556546*lm*NL + 0.00021808628153685742*lm^2*NL - 
        0.00018941640184337488*NH + 0.00036681260470556546*lm*NH + 
        0.00021808628153685742*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.0009827445784716218 - 0.003458566193001317*lm - 
          0.0011745016604893866*lm^2) + CF*(0.0009770610720217982 + 
          0.0035643691073999877*lm + 0.007687647232294166*lm^2) - 
        0.000016900457930249456*NM + 0.00035704470869691034*lm*NM + 
        0.00021354575645261573*lm^2*NM + 0.0007848386200217703*NL + 
        0.00035704470869691034*lm*NL + 0.00021354575645261573*lm^2*NL - 
        0.00018435753267400255*NH + 0.00035704470869691034*lm*NH + 
        0.00021354575645261573*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.0009448400284951384 - 0.003375200768073876*lm - 
          0.0011500906482524219*lm^2) + CF*(0.0009406520012874558 + 
          0.0034151312768471117*lm + 0.0075278660612885795*lm^2) - 
        0.000021705567207959573*NM + 0.00034753618798807814*lm*NM + 
        0.00020910739059134943*lm^2*NM + 0.0007666215620813176*NL + 
        0.00034753618798807814*lm*NL + 0.00020910739059134943*lm^2*NL - 
        0.00017942672276962825*NH + 0.00034753618798807814*lm*NH + 
        0.00020910739059134943*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.0009081937641232075 - 0.0032939217433008827*lm - 
          0.0011262281031728068*lm^2) + CF*(0.0009056787330753333 + 
          0.0032706429583449063*lm + 0.007371674857131099*lm^2) - 
        0.000026267826974336552*NM + 0.0003382800947419903*lm*NM + 
        0.0002047687460314194*lm^2*NM + 0.0007488664985072968*NL + 
        0.0003382800947419903*lm*NL + 0.0002047687460314194*lm^2*NL - 
        0.00017462077925872038*NH + 0.0003382800947419903*lm*NH + 
        0.0002047687460314194*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.0008727661650661152 - 0.0032146752849274546*lm - 
          0.0011029009484235107*lm^2) + CF*(0.0008720902682897752 + 
          0.00313076414884583*lm + 0.007218988026044798*lm^2) - 
        0.00003059668619788853*NM + 0.00032926966704583223*lm*NM + 
        0.00020052744516791106*lm^2*NM + 0.0007315609892455375*NL + 
        0.00032926966704583223*lm*NL + 0.00020052744516791106*lm^2*NL - 
        0.00016993658727334845*NH + 0.00032926966704583223*lm*NH + 
        0.00020052744516791106*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0008385188182944796 - 0.0031374089670560762*lm - 
          0.0010800964306998762*lm^2) + CF*(0.0008398372485329652 + 
          0.0029953588064723607*lm + 0.007069722091853735*lm^2) - 
        0.00003470125612857738*NM + 0.00032049832409617476*lm*NM + 
        0.00019638116921815932*lm^2*NM + 0.0007146929405760079*NL + 
        0.00032049832409617476*lm*NL + 0.00019638116921815932*lm^2*NL - 
        0.00016537110815860738*NH + 0.00032049832409617476*lm*NH + 
        0.00019638116921815932*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.0008054144829822836 - 0.0030620717355550895*lm - 
          0.0010578021121900175*lm^2) + CF*(0.0008088719093007908 + 
          0.0028642947446797214*lm + 0.006923795643425569*lm^2) - 
        0.00003859032181325285*NM + 0.00031195966149497083*lm*NM + 
        0.00019232765676182136*lm^2*NM + 0.0006982505954701234*NL + 
        0.00031195966149497083*lm*NL + 0.00019232765676182136*lm^2*NL - 
        0.00016092137771561387*NH + 0.00031195966149497083*lm*NH + 
        0.00019232765676182136*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.0007734170563588835 - 0.0029886138728060494*lm - 
          0.0010360058627320002*lm^2) + CF*(0.0007791480342213113 + 
          0.0027374435288761204*lm + 0.006781129283336729*lm^2) - 
        0.00004227235323927199*NM + 0.0003036474466548519*lm*NM + 
        0.00018836470231490914*lm^2*NM + 0.0006822225242009237*NL + 
        0.0003036474466548519*lm*NL + 0.00018836470231490914*lm^2*NL - 
        0.00015658450447792827*NH + 0.0003036474466548519*lm*NH + 
        0.00018836470231490914*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.0007424915404538959 - 0.002916986963276842*lm - 
          0.0010146958521545335*lm^2) + CF*(0.0007506209103307885 + 
          0.002614680375467772*lm + 0.006641645577738765*lm^2) - 
        0.00004575551611704494*NM + 0.00029555561431209574*lm*NM + 
        0.0001844901549371879*lm^2*NM + 0.0006665976152008616*NL + 
        0.00029555561431209574*lm*NL + 0.0001844901549371879*lm^2*NL - 
        0.0001523576680212195*NH + 0.00029555561431209574*lm*NH + 
        0.0001844901549371879*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.0007126040097185838 - 0.0028471438599071814*lm - 
          0.0009938605427978855*lm^2) + CF*(0.0007232472843807787 + 
          0.0024958840532945696*lm + 0.006505269007404341*lm^2) - 
        0.000049047682312028464*NM + 0.0002876782621455967*lm*NM + 
        0.00018070191687234282*lm^2*NM + 0.0006513650661619524*NL + 
        0.0002876782621455967*lm*NL + 0.00018070191687234282*lm^2*NL - 
        0.00014823811730595689*NH + 0.0002876782621455967*lm*NH + 
        0.00018070191687234282*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.0006837215795071391 - 0.0027790386512929043*lm - 
          0.000973488682211719*lm^2) + CF*(0.0006969853201684655 + 
          0.002380936787421094*lm + 0.0063719259199312515*lm^2) - 
        0.000052156439936465614*NM + 0.0002800096465001303*lm*NM + 
        0.00017699794222031254*lm^2*NM + 0.0006365143753730438*NL + 
        0.0002800096465001303*lm*NL + 0.00017699794222031254*lm^2*NL - 
        0.00014422316905288307*NH + 0.0002800096465001303*lm*NH + 
        0.00017699794222031254*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.0006558123754010906 - 0.0027126266296552673*lm - 
          0.0009535692960265301*lm^2) + CF*(0.0006717945568812174 + 
          0.0022697241652466114*lm + 0.006241544483082743*lm^2) - 
        0.000055089103110945184*NM + 0.00027254417821217386*lm*NM + 
        0.0001733762356411873*lm^2*NM + 0.0006220353332889888*NL + 
        0.00027254417821217386*lm*NL + 0.0001733762356411873*lm^2*NL - 
        0.00014031020615099446*NH + 0.00027254417821217386*lm*NH + 
        0.0001733762356411873*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.000628845503359946 - 0.0026478642595813427*lm - 
          0.0009340916809953744*lm^2) + CF*(0.0006476358684452734 + 
          0.002162135044896799*lm + 0.0061140546392424505*lm^2) - 
        0.000057852721405628723*NM + 0.0002652764185365211*lm*NM + 
        0.00016983485109006808*lm^2*NM + 0.0006079180143265351*NL + 
        0.0002652764185365211*lm*NL + 0.00016983485109006808*lm^2*NL - 
        0.00013649667609773056*NH + 0.0002652764185365211*lm*NH + 
        0.00016983485109006808*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.0006027910206810939 - 0.0025847091475214726*lm - 
          0.0009150453982025652*lm^2) + CF*(0.0006244714238674906 + 
          0.002058061465859222*lm + 0.005989388060962245*lm^2) - 
        0.00006045408897076606*NM + 0.0002582010751719056*lm*NM + 
        0.00016637189058228458*lm^2*NM + 0.0005941527688817798*NL + 
        0.0002582010751719056*lm*NL + 0.00016637189058228458*lm^2*NL - 
        0.0001327800894710514*NH + 0.0002582010751719056*lm*NH + 
        0.00016637189058228458*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.0005776199077519584 - 0.002523120012029693*lm - 
          0.0008964202664360402*lm^2) + CF*(0.0006022646485582232 + 
          0.0019573985618239497*lm + 0.005867478107581354*lm^2) - 
        0.00006289975336589397*NM + 0.00025131299838383574*lm*NM + 
        0.00016298550298837096*lm^2*NM + 0.0005807302155640838*NL + 
        0.00025131299838383574*lm*NL + 0.00016298550298837096*lm^2*NL - 
        0.00012915801843306173*NH + 0.00025131299838383574*lm*NH + 
        0.00016298550298837096*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.0005533040405773954 - 0.002463056654732973*lm - 
          0.0008782063557201021*lm^2) + CF*(0.000580980186622623 + 
          0.0018600444756901988*lm + 0.005748259782895214*lm^2) - 
        0.00006519602409688613*NM + 0.000244607177222831*lm*NM + 
        0.00015967388285820038*lm^2*NM + 0.0005676412336413915*NL + 
        0.000244607177222831*lm*NL + 0.00015967388285820038*lm^2*NL - 
        0.00012562809526482223*NH + 0.000244607177222831*lm*NH + 
        0.00015967388285820038*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.000529816164065352 - 0.00240447993201512*lm - 
          0.0008603939810052585*lm^2) + CF*(0.0005605838641069745 + 
          0.0017659002766995243*lm + 0.005631669693852601*lm^2) - 
        0.00006734898086979766*NM + 0.00023807873583624306*lm*NM + 
        0.00015643526927368336*lm^2*NM + 0.0005548769556919515*NL + 
        0.00023807873583624306*lm*NL + 0.00015643526927368336*lm^2*NL - 
        0.00012218801093197206*NH + 0.00023807873583624306*lm*NH + 
        0.00015643526927368336*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.0005071298660538726 - 0.0023473517274011967*lm - 
          0.0008429736960119088*lm^2) + CF*(0.0005410426531860702 + 
          0.0016748698796557604*lm + 0.005517646010259766*lm^2) - 
        0.00006936448157022374*NM + 0.00023172292987184198*lm*NM + 
        0.00015326794472943797*lm^2*NM + 0.0005424287604575015*NL + 
        0.00023172292987184198*lm*NL + 0.00015326794472943797*lm^2*NL - 
        0.00011883551368077237*NH + 0.00023172292987184198*lm*NH + 
        0.00015326794472943797*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.00048521955206262413 - 0.0022916349246283334*lm - 
          0.0008259362872246505*lm^2) + CF*(0.0005223246372771084 + 
          0.0015868599661917494*lm + 0.00540612842547044*lm^2) - 
        0.00007124816997666961*NM + 0.00022553514297134807*lm*NM + 
        0.00015017023404084555*lm^2*NM + 0.0005302882658930377*NL + 
        0.00022553514297134807*lm*NL + 0.00015017023404084555*lm^2*NL - 
        0.00011556840766416786*NH + 0.00022553514297134807*lm*NH + 
        0.00015017023404084555*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.00046406042075222974 - 0.002237293381388879*lm - 
          0.0008092727680340034*lm^2) + CF*(0.0005043989770651406 + 
          0.001501779908042772*lm + 0.005297058118040749*lm^2) - 
        0.00007300548321620981*NM + 0.00021951088335209288*lm*NM + 
        0.0001471405032789097*lm^2*NM + 0.0005184473224083606*NL + 
        0.00021951088335209288*lm*NL + 0.0001471405032789097*lm^2*NL - 
        0.00011238455159745196*NH + 0.00021951088335209288*lm*NH + 
        0.0001471405032789097*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.00044362844007483335 - 0.002184291903731896*lm - 
          0.000792974373022385*lm^2) + CF*(0.000487235877424706 + 
          0.0014195416922865686*lm + 0.005190377714328338*lm^2) - 
        0.00007464165897049679*NM + 0.00021364578047499937*lm*NM + 
        0.00014417715873134274*lm^2*NM + 0.0005068980062966588*NL + 
        0.00021364578047499937*lm*NL + 0.00014417715873134274*lm^2*NL - 
        0.00010928185744311178*NH + 0.00021364578047499937*lm*NH + 
        0.00014417715873134274*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.00042390032409947605 - 0.0021325962211091068*lm - 
          0.0007770325523912044*lm^2) + CF*(0.00047080655522196334 + 
          0.001340059848509883*lm + 0.005086031252015156*lm^2) - 
        0.00007616174243996445*NM + 0.00020793558179707953*lm*NM + 
        0.0001412786458893099*lm^2*NM + 0.0004956326133454664*NL + 
        0.00020793558179707953*lm*NL + 0.0001412786458893099*lm^2*NL - 
        0.00010625828912442054*NH + 0.00020793558179707953*lm*NH + 
        0.0001412786458893099*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.0004048535104960396 - 0.002082172962051499*lm - 
          0.0007614389665259732*lm^2) + CF*(0.00045508320798135865 + 
          0.0012632513778615697*lm + 0.004983964144533643*lm^2) - 
        0.00007757059307386043*NM + 0.00020237614960665892*lm*NM + 
        0.00013844344845926785*lm^2*NM + 0.0004846436526254044*NL + 
        0.00020237614960665892*lm*NL + 0.00013844344845926785*lm^2*NL - 
        0.00010331186126733822*NH + 0.00020237614960665892*lm*NH + 
        0.00013844344845926785*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.0003864661386617028 - 0.0020329896304629217*lm - 
          0.0007461854806963791*lm^2) + CF*(0.00044003898340064674 + 
          0.0011890356839524712*lm + 0.0048841231463763*lm^2) - 
        0.00007887289107353206*NM + 0.00019696345793955092*lm*NM + 
        0.00013567008739934165*lm^2*NM + 0.00047392384045219656*NL + 
        0.00019696345793955092*lm*NL + 0.00013567008739934165*lm^2*NL - 
        0.00010044063797027506*NH + 0.00019696345793955092*lm*NH + 
        0.00013567008739934165*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.00036871702847405977 - 0.001985014582517133*lm - 
          0.0007312641598882988*lm^2) + CF*(0.0004256479496979153 + 
          0.0011173345055624975*lm + 0.0047864563192688645*lm^2) - 
        0.00008007314367618596*NM + 0.00019169358957441785*lm*NM + 
        0.0001329571199796907*lm^2*NM + 0.00046346609451752716*NL + 
        0.00019169358957441785*lm*NL + 0.0001329571199796907*lm^2*NL - 
        0.00009764273160126808*NH + 0.00019169358957441785*lm*NH + 
        0.0001329571199796907*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.0003515856596552676 - 0.0019382170041449156*lm - 
          0.0007166672637647758*lm^2) + CF*(0.0004118850667741305 + 
          0.0010480718511156097*lm + 0.0046909129991876235*lm^2) - 
        0.00008117569122613882*NM + 0.00018656273310557373*lm*NM + 
        0.00013030313886632286*lm^2*NM + 0.00045326352818439105*NL + 
        0.00018656273310557373*lm*NL + 0.00013030313886632286*lm^2*NL - 
        0.00009491630162211686*NH + 0.00018656273310557373*lm*NH + 
        0.00013030313886632286*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.0003350521517318182 - 0.0018925668890980212*lm - 
          0.0007023872417530289*lm^2) + CF*(0.0003987261581746404 + 
          0.0009811739348837276*lm + 0.0045974437642016435*lm^2) - 
        0.00008218471304037921*NM + 0.0001815671800915013*lm*NM + 
        0.00012770677122782344*lm^2*NM + 0.0004433094449426678*NL + 
        0.0001815671800915013*lm*NL + 0.00012770677122782344*lm^2*NL - 
        0.00009225955343902215*NH + 0.0001815671800915013*lm*NH + 
        0.00012770677122782344*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.0003190972445747659 - 0.0018480350175768732*lm - 
          0.0006884167282546004*lm^2) + CF*(0.0003861478838330202 + 
          0.0009165691148809407*lm + 0.0045060004031210205*lm^2) - 
        0.00008310423307506506*NM + 0.0001767033222773752*lm*NM + 
        0.0001251666778644728*lm^2*NM + 0.00043359733302073347*NL + 
        0.0001767033222773752*lm*NL + 0.0001251666778644728*lm^2*NL - 
        0.00008967073727926858*NH + 0.0001767033222773752*lm*NH + 
        0.0001251666778644728*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.0003037022795054882 - 0.0018045929354091365*lm - 
          0.0006747485379758023*lm^2) + CF*(0.0003741277135806329 + 
          0.0008541878324097885*lm + 0.004416535884932525*lm^2) - 
        0.0000839381253993912*NM + 0.00017196764888990524*lm*NM + 
        0.0001226815523592368*lm^2*NM + 0.000424120860149009*NL + 
        0.00017196764888990524*lm*NL + 0.0001226815523592368*lm^2*NL - 
        0.00008714814709349236*NH + 0.00017196764888990524*lm*NH + 
        0.0001226815523592368*lm^2*NH)}, 
     {1., 5.3507017920039*^-20*CF*NC*(-7.*CA*(7.711917111347545*^14 + 
          4.7048913321984*^15*lm + 1.76579149824*^15*lm^2) + 
        18.*CF*(3.7652786857815044*^14 + 8.243597279232*^14*lm + 
          4.49474199552*^15*lm^2) + 
        35.*(63.*(-7.178164462470782*^11 + 1.41848215552*^12*lm + 
            1.019215872*^12*lm^2)*NM + 2.097152*^6*(1.05634889*^8 + 
            4.2612255*^7*lm + 3.0618*^7*lm^2)*NL + 
          63.*(-7.178164462470782*^11 + 1.41848215552*^12*lm + 
            1.019215872*^12*lm^2)*NH))}}


(* axial  *)

CbarData["a", 0, -1] = (-2*NC*(1 + x)^2)/(3*ep) + 
     NC*((-1 - 4*x - x^2 - 2*lm*(1 + x)^2)/3 + (4*x^3*(2 + x)*HPL[{0}, x])/
        (3*(-1 + x^2)))
 
CbarData["a", 0, 0] = (4*NC)/(9*ep) + 
     NC*((2*(2 - 9*x - 16*x^2 - 9*x^3 + 2*x^4 + 6*lm*(-1 + x^2)^2))/
        (27*(-1 + x^2)^2) - (8*x^3*(-3 - 3*x + x^3)*HPL[{0}, x])/
        (9*(-1 + x^2)^3))
 
CbarData["a", 0, 1] = 
    NC*(-(-3 + 4*x + 21*x^2 + 40*x^3 + 21*x^4 + 4*x^5 - 3*x^6)/
       (18*(-1 + x^2)^4) + (4*x^3*(2 + 3*x + 2*x^2)*HPL[{0}, x])/
       (3*(-1 + x^2)^5))
 
CbarData["a", 0, 2] = 
    NC*(-(-2 + 5*x + 28*x^2 + 145*x^3 + 188*x^4 + 145*x^5 + 28*x^6 + 5*x^7 - 
         2*x^8)/(45*(-1 + x^2)^6) + (8*x^3*(1 + x + x^2)^2*HPL[{0}, x])/
       (3*(-1 + x^2)^7))
 
CbarData["a", 0, 3] = 
    NC*(-(-5 + 18*x + 115*x^2 + 1068*x^3 + 1990*x^4 + 2868*x^5 + 1990*x^6 + 
         1068*x^7 + 115*x^8 + 18*x^9 - 5*x^10)/(270*(-1 + x^2)^8) + 
      (4*x^3*(6 + 15*x + 36*x^2 + 40*x^3 + 36*x^4 + 15*x^5 + 6*x^6)*
        HPL[{0}, x])/(9*(-1 + x^2)^9))
 
CbarData["a", 0, 4] = 
    NC*(-(-3 + 14*x + 102*x^2 + 1428*x^3 + 3399*x^4 + 7378*x^5 + 8124*x^6 + 
         7378*x^7 + 3399*x^8 + 1428*x^9 + 102*x^10 + 14*x^11 - 3*x^12)/
       (315*(-1 + x^2)^10) + (8*x^3*(1 + 3*x + 10*x^2 + 15*x^3 + 20*x^4 + 
         15*x^5 + 10*x^6 + 3*x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11))
 
CbarData["a", 0, 5] = 
    NC*(-(-7 + 40*x + 329*x^2 + 6312*x^3 + 18165*x^4 + 53352*x^5 + 
         78533*x^6 + 102352*x^7 + 78533*x^8 + 53352*x^9 + 18165*x^10 + 
         6312*x^11 + 329*x^12 + 40*x^13 - 7*x^14)/(1260*(-1 + x^2)^12) + 
      (4*x^3*(2 + 7*x + 30*x^2 + 56*x^3 + 100*x^4 + 105*x^5 + 100*x^6 + 
         56*x^7 + 30*x^8 + 7*x^9 + 2*x^10)*HPL[{0}, x])/(3*(-1 + x^2)^13))
 
CbarData["a", 0, 6] = 
    NC*(-(-20 + 135*x + 1240*x^2 + 30699*x^3 + 103336*x^4 + 385263*x^5 + 
         703096*x^6 + 1205523*x^7 + 1267576*x^8 + 1205523*x^9 + 703096*x^10 + 
         385263*x^11 + 103336*x^12 + 30699*x^13 + 1240*x^14 + 135*x^15 - 
         20*x^16)/(5670*(-1 + x^2)^14) + 
      (8*x^3*(3 + 12*x + 63*x^2 + 140*x^3 + 315*x^4 + 420*x^5 + 525*x^6 + 
         420*x^7 + 315*x^8 + 140*x^9 + 63*x^10 + 12*x^11 + 3*x^12)*
        HPL[{0}, x])/(9*(-1 + x^2)^15))
 
CbarData["a", 0, 7] = 
    NC*(-(-9 + 70*x + 711*x^2 + 21796*x^3 + 83898*x^4 + 380644*x^5 + 
         825210*x^6 + 1763620*x^7 + 2333430*x^8 + 2874940*x^9 + 
         2333430*x^10 + 1763620*x^11 + 825210*x^12 + 380644*x^13 + 
         83898*x^14 + 21796*x^15 + 711*x^16 + 70*x^17 - 9*x^18)/
       (3780*(-1 + x^2)^16) + (4*x^3*(2 + 9*x + 56*x^2 + 144*x^3 + 392*x^4 + 
         630*x^5 + 980*x^6 + 1008*x^7 + 980*x^8 + 630*x^9 + 392*x^10 + 
         144*x^11 + 56*x^12 + 9*x^13 + 2*x^14)*HPL[{0}, x])/(3*(-1 + x^2)^17))
 
CbarData["a", 0, 8] = 
    NC*(-(-35 + 308*x + 3430*x^2 + 126346*x^3 + 546995*x^4 + 2931214*x^5 + 
         7341860*x^6 + 18853582*x^7 + 29919800*x^8 + 45475870*x^9 + 
         46898300*x^10 + 45475870*x^11 + 29919800*x^12 + 18853582*x^13 + 
         7341860*x^14 + 2931214*x^15 + 546995*x^16 + 126346*x^17 + 
         3430*x^18 + 308*x^19 - 35*x^20)/(20790*(-1 + x^2)^18) + 
      (8*x^3*(1 + 5*x + 36*x^2 + 105*x^3 + 336*x^4 + 630*x^5 + 1176*x^6 + 
         1470*x^7 + 1764*x^8 + 1470*x^9 + 1176*x^10 + 630*x^11 + 336*x^12 + 
         105*x^13 + 36*x^14 + 5*x^15 + x^16)*HPL[{0}, x])/(3*(-1 + x^2)^19))
 
CbarData["a", 0, 9] = 
    NC*(-(-77 + 756*x + 9163*x^2 + 396426*x^3 + 1905838*x^4 + 11798256*x^5 + 
         33477158*x^6 + 100595316*x^7 + 185670353*x^8 + 336603396*x^9 + 
         419117105*x^10 + 497967060*x^11 + 419117105*x^12 + 336603396*x^13 + 
         185670353*x^14 + 100595316*x^15 + 33477158*x^16 + 11798256*x^17 + 
         1905838*x^18 + 396426*x^19 + 9163*x^20 + 756*x^21 - 77*x^22)/
       (62370*(-1 + x^2)^20) + (4*x^3*(6 + 33*x + 270*x^2 + 880*x^3 + 
         3240*x^4 + 6930*x^5 + 15120*x^6 + 22176*x^7 + 31752*x^8 + 
         32340*x^9 + 31752*x^10 + 22176*x^11 + 15120*x^12 + 6930*x^13 + 
         3240*x^14 + 880*x^15 + 270*x^16 + 33*x^17 + 6*x^18)*HPL[{0}, x])/
       (9*(-1 + x^2)^21))
 
 
CbarLData["a", 0, -1] = (2*NC*(1 + x)^2)/(3*ep) + 
     NC*((1 + 4*x + x^2 + 2*lm*(1 + x)^2)/3 - (4*x^3*(2 + x)*HPL[{0}, x])/
        (3*(-1 + x^2)))
 
CbarLData["a", 0, 0] = (2*NC*(-1 - 3*x + 3*x^2 - 3*x^4 + 3*x^5 + x^6 - 
       12*x^3*HPL[{0}, x]))/(9*(-1 + x^2)^3)
 
CbarLData["a", 0, 1] = NC*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
       (18*(-1 + x^2)^4) + (4*x^3*(-2 + x - 2*x^2)*HPL[{0}, x])/
       (3*(-1 + x^2)^5))
 
CbarLData["a", 0, 2] = NC*((1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 
        14*x^6 + 5*x^7 + x^8)/(45*(-1 + x^2)^6) - 
      (8*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/(3*(-1 + x^2)^7))
 
CbarLData["a", 0, 3] = NC*((1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 956*x^5 - 
        398*x^6 + 356*x^7 - 23*x^8 + 6*x^9 + x^10)/(90*(-1 + x^2)^8) - 
      (4*x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*x^5 + 2*x^6)*HPL[{0}, x])/
       (3*(-1 + x^2)^9))
 
CbarLData["a", 0, 4] = 
    NC*((2*(1 + 7*x - 34*x^2 + 714*x^3 - 1133*x^4 + 3689*x^5 - 2708*x^6 + 
         3689*x^7 - 1133*x^8 + 714*x^9 - 34*x^10 + 7*x^11 + x^12))/
       (315*(-1 + x^2)^10) - (8*x^3*(1 - 2*x + 10*x^2 - 10*x^3 + 20*x^4 - 
         10*x^5 + 10*x^6 - 2*x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11))
 
CbarLData["a", 0, 5] = NC*((5 + 40*x - 235*x^2 + 6312*x^3 - 12975*x^4 + 
        53352*x^5 - 56095*x^6 + 102352*x^7 - 56095*x^8 + 53352*x^9 - 
        12975*x^10 + 6312*x^11 - 235*x^12 + 40*x^13 + 5*x^14)/
       (1260*(-1 + x^2)^12) - (4*x^3*(2 - 5*x + 30*x^2 - 40*x^3 + 100*x^4 - 
         75*x^5 + 100*x^6 - 40*x^7 + 30*x^8 - 5*x^9 + 2*x^10)*HPL[{0}, x])/
       (3*(-1 + x^2)^13))
 
CbarLData["a", 0, 6] = NC*((5 + 45*x - 310*x^2 + 10233*x^3 - 25834*x^4 + 
        128421*x^5 - 175774*x^6 + 401841*x^7 - 316894*x^8 + 401841*x^9 - 
        175774*x^10 + 128421*x^11 - 25834*x^12 + 10233*x^13 - 310*x^14 + 
        45*x^15 + 5*x^16)/(1890*(-1 + x^2)^14) - 
      (8*x^3*(1 - 3*x + 21*x^2 - 35*x^3 + 105*x^4 - 105*x^5 + 175*x^6 - 
         105*x^7 + 105*x^8 - 35*x^9 + 21*x^10 - 3*x^11 + x^12)*HPL[{0}, x])/
       (3*(-1 + x^2)^15))
 
CbarLData["a", 0, 7] = NC*((7 + 70*x - 553*x^2 + 21796*x^3 - 65254*x^4 + 
        380644*x^5 - 641830*x^6 + 1763620*x^7 - 1814890*x^8 + 2874940*x^9 - 
        1814890*x^10 + 1763620*x^11 - 641830*x^12 + 380644*x^13 - 
        65254*x^14 + 21796*x^15 - 553*x^16 + 70*x^17 + 7*x^18)/
       (3780*(-1 + x^2)^16) - (4*x^3*(2 - 7*x + 56*x^2 - 112*x^3 + 392*x^4 - 
         490*x^5 + 980*x^6 - 784*x^7 + 980*x^8 - 490*x^9 + 392*x^10 - 
         112*x^11 + 56*x^12 - 7*x^13 + 2*x^14)*HPL[{0}, x])/(3*(-1 + x^2)^17))
 
CbarLData["a", 0, 8] = NC*((14 + 154*x - 1372*x^2 + 63173*x^3 - 218798*x^4 + 
        1465607*x^5 - 2936744*x^6 + 9426791*x^7 - 11967920*x^8 + 
        22737935*x^9 - 18759320*x^10 + 22737935*x^11 - 11967920*x^12 + 
        9426791*x^13 - 2936744*x^14 + 1465607*x^15 - 218798*x^16 + 
        63173*x^17 - 1372*x^18 + 154*x^19 + 14*x^20)/(10395*(-1 + x^2)^18) - 
      (8*x^3*(1 - 4*x + 36*x^2 - 84*x^3 + 336*x^4 - 504*x^5 + 1176*x^6 - 
         1176*x^7 + 1764*x^8 - 1176*x^9 + 1176*x^10 - 504*x^11 + 336*x^12 - 
         84*x^13 + 36*x^14 - 4*x^15 + x^16)*HPL[{0}, x])/(3*(-1 + x^2)^19))
 
CbarLData["a", 0, 9] = NC*((21 + 252*x - 2499*x^2 + 132142*x^3 - 519774*x^4 + 
        3932752*x^5 - 9130134*x^6 + 33531772*x^7 - 50637369*x^8 + 
        112201132*x^9 - 114304665*x^10 + 165989020*x^11 - 114304665*x^12 + 
        112201132*x^13 - 50637369*x^14 + 33531772*x^15 - 9130134*x^16 + 
        3932752*x^17 - 519774*x^18 + 132142*x^19 - 2499*x^20 + 252*x^21 + 
        21*x^22)/(20790*(-1 + x^2)^20) - 
      (4*x^3*(2 - 9*x + 90*x^2 - 240*x^3 + 1080*x^4 - 1890*x^5 + 5040*x^6 - 
         6048*x^7 + 10584*x^8 - 8820*x^9 + 10584*x^10 - 6048*x^11 + 
         5040*x^12 - 1890*x^13 + 1080*x^14 - 240*x^15 + 90*x^16 - 9*x^17 + 
         2*x^18)*HPL[{0}, x])/(3*(-1 + x^2)^21))
 
CbarData["a", 1, -1] = (-5*CF*NC*(1 + x)^2)/(12*ep) + 
     (CF*NC*(1 + 2*x + x^2))/(2*ep^2) + CF*NC*(-(lm^2*(1 + x)^2)/2 + 
       (-4*Pi^2*(-1 + x^2) - 3*(13 + 66*x + 13*x^2))/72 + 
       (2*x^2*(1 + 5*x + x^2)*HPL[{0}, x])/(3*(-1 + x^2)) + 
       lm*((-1 - 5*x - x^2)/3 + (2*x^3*(2 + x)*HPL[{0}, x])/(-1 + x^2)) + 
       (2*(-1 + x^2)*HPL[{-1, 0}, x])/3 - (8*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*
         HPL[{0, 0}, x])/(3*(-1 + x^2)^2) - (2*(-1 + x^2)*HPL[{1, 0}, x])/3)
 
CbarData["a", 1, 0] = (CF*NC)/(6*ep) + 
     CF*NC*(-lm/3 + (4*Pi^2*(-2 - 9*x + 9*x^3 + 2*x^4) + 
         3*(19 - 84*x - 142*x^2 - 84*x^3 + 19*x^4))/(324*(-1 + x^2)^2) + 
       (2*x^2*(-4 - 48*x - 31*x^2 + 9*x^4)*HPL[{0}, x])/(27*(-1 + x^2)^3) + 
       ((8 + 36*x + 8*x^2)*HPL[{-1, 0}, x])/(27 - 27*x^2) + 
       (8*x^3*(54 + 54*x + 27*x^2 - 4*x^3 + 9*x^4 + 2*x^5)*HPL[{0, 0}, x])/
        (27*(-1 + x^2)^4) + (4*(2 + 9*x + 2*x^2)*HPL[{1, 0}, x])/
        (27*(-1 + x^2)))
 
CbarData["a", 1, 1] = 
    CF*NC*(-(4*Pi^2*(-9 + 12*x + 41*x^2 - 41*x^4 - 12*x^5 + 9*x^6) + 
         3*(69 + 168*x + 23*x^2 - 144*x^3 + 23*x^4 + 168*x^5 + 69*x^6))/
       (1296*(-1 + x^2)^4) + (x^2*(18 - 438*x - 691*x^2 - 762*x^3 - 198*x^4 - 
         36*x^5 + 27*x^6)*HPL[{0}, x])/(54*(-1 + x^2)^5) + 
      lm*((-3 + 4*x + 21*x^2 + 40*x^3 + 21*x^4 + 4*x^5 - 3*x^6)/
         (12*(-1 + x^2)^4) - (2*x^3*(2 + 3*x + 2*x^2)*HPL[{0}, x])/
         (-1 + x^2)^5) + ((9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*
        HPL[{-1, 0}, x])/(27*(-1 + x^2)^3) + 
      (2*x^3*(216 + 324*x + 648*x^2 + 516*x^3 + 408*x^4 + 59*x^5 + 12*x^6 - 
         9*x^7)*HPL[{0, 0}, x])/(27*(-1 + x^2)^6) + 
      ((-9 + 12*x + 32*x^2 + 12*x^3 - 9*x^4)*HPL[{1, 0}, x])/
       (27*(-1 + x^2)^3))
 
CbarData["a", 1, 2] = CF*NC*((-92 - 147*x + 74*x^2 + 3567*x^3 + 4908*x^4 + 
        3567*x^5 + 74*x^6 - 147*x^7 - 92*x^8 - 
        4*Pi^2*(-2 + 5*x + 14*x^2 + 15*x^3 - 15*x^5 - 14*x^6 - 5*x^7 + 
          2*x^8))/(1080*(-1 + x^2)^6) + 
      (2*x^2*(2 - 299*x - 568*x^2 - 1217*x^3 - 1048*x^4 - 719*x^5 - 88*x^6 - 
         15*x^7 + 6*x^8)*HPL[{0}, x])/(45*(-1 + x^2)^7) + 
      lm*((-2 + 5*x + 28*x^2 + 145*x^3 + 188*x^4 + 145*x^5 + 28*x^6 + 5*x^7 - 
          2*x^8)/(15*(-1 + x^2)^6) - (8*x^3*(1 + x + x^2)^2*HPL[{0}, x])/
         (-1 + x^2)^7) + (2*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 5*x^5 + 
         2*x^6)*HPL[{-1, 0}, x])/(45*(-1 + x^2)^5) + 
      (4*x^3*(180 + 360*x + 1260*x^2 + 1560*x^3 + 1940*x^4 + 1050*x^5 + 
         545*x^6 + 18*x^7 + 5*x^8 - 2*x^9)*HPL[{0, 0}, x])/
       (45*(-1 + x^2)^8) + ((-4 + 10*x + 24*x^2 + 40*x^3 + 24*x^4 + 10*x^5 - 
         4*x^6)*HPL[{1, 0}, x])/(45*(-1 + x^2)^5))
 
CbarData["a", 1, 3] = CF*NC*((-577 - 171*x + 3270*x^2 + 83664*x^3 + 
        149875*x^4 + 223542*x^5 + 149875*x^6 + 83664*x^7 + 3270*x^8 - 
        171*x^9 - 577*x^10 - 6*Pi^2*(-5 + 18*x + 47*x^2 + 144*x^3 + 144*x^4 - 
          144*x^6 - 144*x^7 - 47*x^8 - 18*x^9 + 5*x^10))/
       (9720*(-1 + x^2)^8) + (x^2*(10 - 5016*x - 11700*x^2 - 36954*x^3 - 
         46374*x^4 - 53154*x^5 - 28575*x^6 - 14466*x^7 - 1070*x^8 - 162*x^9 + 
         45*x^10)*HPL[{0}, x])/(270*(-1 + x^2)^9) + 
      lm*((-5 + 18*x + 115*x^2 + 1068*x^3 + 1990*x^4 + 2868*x^5 + 1990*x^6 + 
          1068*x^7 + 115*x^8 + 18*x^9 - 5*x^10)/(60*(-1 + x^2)^8) - 
        (2*x^3*(6 + 15*x + 36*x^2 + 40*x^3 + 36*x^4 + 15*x^5 + 6*x^6)*
          HPL[{0}, x])/(-1 + x^2)^9) - 
      ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 18*x^7 - 
         5*x^8)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^7) + 
      (2*x^3*(1080 + 2700*x + 13500*x^2 + 22000*x^3 + 39600*x^4 + 35115*x^5 + 
         29430*x^6 + 10845*x^7 + 4428*x^8 + 57*x^9 + 18*x^10 - 5*x^11)*
        HPL[{0, 0}, x])/(135*(-1 + x^2)^10) + 
      ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 18*x^7 - 
         5*x^8)*HPL[{1, 0}, x])/(135*(-1 + x^2)^7))
 
CbarData["a", 1, 4] = CF*NC*((-15129 + 14145*x + 192874*x^2 + 5402655*x^3 + 
        12004625*x^4 + 27166800*x^5 + 29023260*x^6 + 27166800*x^7 + 
        12004625*x^8 + 5402655*x^9 + 192874*x^10 + 14145*x^11 - 15129*x^12 - 
        60*Pi^2*(-9 + 42*x + 106*x^2 + 630*x^3 + 935*x^4 + 840*x^5 - 
          840*x^7 - 935*x^8 - 630*x^9 - 106*x^10 - 42*x^11 + 9*x^12))/
       (340200*(-1 + x^2)^10) + (x^2*(18 - 22584*x - 62924*x^2 - 263451*x^3 - 
         423882*x^4 - 687762*x^5 - 593982*x^6 - 477651*x^7 - 181616*x^8 - 
         73488*x^9 - 3762*x^10 - 504*x^11 + 108*x^12)*HPL[{0}, x])/
       (945*(-1 + x^2)^11) + 
      lm*((2*(-3 + 14*x + 102*x^2 + 1428*x^3 + 3399*x^4 + 7378*x^5 + 
           8124*x^6 + 7378*x^7 + 3399*x^8 + 1428*x^9 + 102*x^10 + 14*x^11 - 
           3*x^12))/(105*(-1 + x^2)^10) - 
        (16*x^3*(1 + 3*x + 10*x^2 + 15*x^3 + 20*x^4 + 15*x^5 + 10*x^6 + 
           3*x^7 + x^8)*HPL[{0}, x])/(-1 + x^2)^11) + 
      (2*(9 - 42*x - 97*x^2 - 672*x^3 - 1032*x^4 - 1512*x^5 - 1032*x^6 - 
         672*x^7 - 97*x^8 - 42*x^9 + 9*x^10)*HPL[{-1, 0}, x])/
       (945*(-1 + x^2)^9) + (4*x^3*(3780 + 11340*x + 73710*x^2 + 147840*x^3 + 
         353850*x^4 + 425215*x^5 + 503160*x^6 + 327516*x^7 + 209412*x^8 + 
         57414*x^9 + 19446*x^10 + 124*x^11 + 42*x^12 - 9*x^13)*
        HPL[{0, 0}, x])/(945*(-1 + x^2)^12) + 
      (2*(-9 + 42*x + 97*x^2 + 672*x^3 + 1032*x^4 + 1512*x^5 + 1032*x^6 + 
         672*x^7 + 97*x^8 + 42*x^9 - 9*x^10)*HPL[{1, 0}, x])/
       (945*(-1 + x^2)^9))
 
CbarData["a", 1, 5] = CF*NC*((-62917 + 131656*x + 1370025*x^2 + 
        44965824*x^3 + 119732847*x^4 + 366102840*x^5 + 518856445*x^6 + 
        691672960*x^7 + 518856445*x^8 + 366102840*x^9 + 119732847*x^10 + 
        44965824*x^11 + 1370025*x^12 + 131656*x^13 - 62917*x^14 - 
        240*Pi^2*(-7 + 40*x + 99*x^2 + 960*x^3 + 1773*x^4 + 3000*x^5 + 
          2215*x^6 - 2215*x^8 - 3000*x^9 - 1773*x^10 - 960*x^11 - 99*x^12 - 
          40*x^13 + 7*x^14))/(1814400*(-1 + x^2)^12) + 
      (x^2*(14 - 36830*x - 119635*x^2 - 624986*x^3 - 1218098*x^4 - 
         2572244*x^5 - 2972507*x^6 - 3307244*x^7 - 2123618*x^8 - 
         1330586*x^9 - 387175*x^10 - 130910*x^11 - 5026*x^12 - 600*x^13 + 
         105*x^14)*HPL[{0}, x])/(1260*(-1 + x^2)^13) + 
      lm*((-7 + 40*x + 329*x^2 + 6312*x^3 + 18165*x^4 + 53352*x^5 + 
          78533*x^6 + 102352*x^7 + 78533*x^8 + 53352*x^9 + 18165*x^10 + 
          6312*x^11 + 329*x^12 + 40*x^13 - 7*x^14)/(168*(-1 + x^2)^12) - 
        (10*x^3*(2 + 7*x + 30*x^2 + 56*x^3 + 100*x^4 + 105*x^5 + 100*x^6 + 
           56*x^7 + 30*x^8 + 7*x^9 + 2*x^10)*HPL[{0}, x])/(-1 + x^2)^13) - 
      ((-7 + 40*x + 92*x^2 + 1000*x^3 + 1865*x^4 + 4000*x^5 + 4080*x^6 + 
         4000*x^7 + 1865*x^8 + 1000*x^9 + 92*x^10 + 40*x^11 - 7*x^12)*
        HPL[{-1, 0}, x])/(630*(-1 + x^2)^11) + 
      (x^3*(5040 + 17640*x + 141120*x^2 + 335160*x^3 + 1007440*x^4 + 
         1512140*x^5 + 2336320*x^6 + 2124668*x^7 + 1884400*x^8 + 951328*x^9 + 
         495040*x^10 + 107408*x^11 + 31120*x^12 + 113*x^13 + 40*x^14 - 
         7*x^15)*HPL[{0, 0}, x])/(315*(-1 + x^2)^14) + 
      ((-7 + 40*x + 92*x^2 + 1000*x^3 + 1865*x^4 + 4000*x^5 + 4080*x^6 + 
         4000*x^7 + 1865*x^8 + 1000*x^9 + 92*x^10 + 40*x^11 - 7*x^12)*
        HPL[{1, 0}, x])/(630*(-1 + x^2)^11))
 
CbarData["a", 1, 6] = CF*NC*((-530052 + 1696401*x + 17328358*x^2 + 
        667762515*x^3 + 2075987732*x^4 + 8035738389*x^5 + 14055862562*x^6 + 
        24558727095*x^7 + 25221686000*x^8 + 24558727095*x^9 + 
        14055862562*x^10 + 8035738389*x^11 + 2075987732*x^12 + 
        667762515*x^13 + 17328358*x^14 + 1696401*x^15 - 530052*x^16 - 
        2800*Pi^2*(-4 + 27*x + 66*x^2 + 945*x^3 + 2044*x^4 + 5103*x^5 + 
          5894*x^6 + 4725*x^7 - 4725*x^9 - 5894*x^10 - 5103*x^11 - 
          2044*x^12 - 945*x^13 - 66*x^14 - 27*x^15 + 4*x^16))/
       (19051200*(-1 + x^2)^14) + (x^2*(60 - 293985*x - 1092243*x^2 - 
         6843879*x^3 - 15623255*x^4 - 40767381*x^5 - 58339291*x^6 - 
         83412999*x^7 - 73580251*x^8 - 62914401*x^9 - 31816775*x^10 - 
         16417107*x^11 - 3848835*x^12 - 1119213*x^13 - 33960*x^14 - 
         3645*x^15 + 540*x^16)*HPL[{0}, x])/(8505*(-1 + x^2)^15) + 
      lm*((-20 + 135*x + 1240*x^2 + 30699*x^3 + 103336*x^4 + 385263*x^5 + 
          703096*x^6 + 1205523*x^7 + 1267576*x^8 + 1205523*x^9 + 
          703096*x^10 + 385263*x^11 + 103336*x^12 + 30699*x^13 + 1240*x^14 + 
          135*x^15 - 20*x^16)/(630*(-1 + x^2)^14) - 
        (8*x^3*(3 + 12*x + 63*x^2 + 140*x^3 + 315*x^4 + 420*x^5 + 525*x^6 + 
           420*x^7 + 315*x^8 + 140*x^9 + 63*x^10 + 12*x^11 + 3*x^12)*
          HPL[{0}, x])/(-1 + x^2)^15) - 
      ((-4 + 27*x + 62*x^2 + 972*x^3 + 2106*x^4 + 6075*x^5 + 8000*x^6 + 
         10800*x^7 + 8000*x^8 + 6075*x^9 + 2106*x^10 + 972*x^11 + 62*x^12 + 
         27*x^13 - 4*x^14)*HPL[{-1, 0}, x])/(567*(-1 + x^2)^13) + 
      (2*x^3*(4536 + 18144*x + 172368*x^2 + 472416*x^3 + 1714608*x^4 + 
         3071712*x^5 + 5889996*x^6 + 6801480*x^7 + 7786044*x^8 + 
         5602128*x^9 + 3996216*x^10 + 1635504*x^11 + 719928*x^12 + 
         128916*x^13 + 32643*x^14 + 74*x^15 + 27*x^16 - 4*x^17)*
        HPL[{0, 0}, x])/(567*(-1 + x^2)^16) + 
      ((-4 + 27*x + 62*x^2 + 972*x^3 + 2106*x^4 + 6075*x^5 + 8000*x^6 + 
         10800*x^7 + 8000*x^8 + 6075*x^9 + 2106*x^10 + 972*x^11 + 62*x^12 + 
         27*x^13 - 4*x^14)*HPL[{1, 0}, x])/(567*(-1 + x^2)^13))
 
CbarData["a", 1, 7] = CF*NC*((-4348503 + 18592590*x + 197815541*x^2 + 
        8856087840*x^3 + 31512520240*x^4 + 148038444960*x^5 + 
        306957447664*x^6 + 667159553760*x^7 + 860209765058*x^8 + 
        1077841457700*x^9 + 860209765058*x^10 + 667159553760*x^11 + 
        306957447664*x^12 + 148038444960*x^13 + 31512520240*x^14 + 
        8856087840*x^15 + 197815541*x^16 + 18592590*x^17 - 4348503*x^18 - 
        2800*Pi^2*(-27 + 210*x + 509*x^2 + 10080*x^3 + 24760*x^4 + 
          82320*x^5 + 122136*x^6 + 164640*x^7 + 107072*x^8 - 107072*x^10 - 
          164640*x^11 - 122136*x^12 - 82320*x^13 - 24760*x^14 - 10080*x^15 - 
          509*x^16 - 210*x^17 + 27*x^18))/(190512000*(-1 + x^2)^16) + 
      (x^2*(162 - 1357524*x - 5682252*x^2 - 41533902*x^3 - 108549186*x^4 - 
         337877454*x^5 - 573477332*x^6 - 1005439650*x^7 - 1115698754*x^8 - 
         1215479130*x^9 - 858530912*x^10 - 599259918*x^11 - 248657154*x^12 - 
         109356174*x^13 - 21404595*x^14 - 5463738*x^15 - 135918*x^16 - 
         13230*x^17 + 1701*x^18)*HPL[{0}, x])/(34020*(-1 + x^2)^17) + 
      lm*((-9 + 70*x + 711*x^2 + 21796*x^3 + 83898*x^4 + 380644*x^5 + 
          825210*x^6 + 1763620*x^7 + 2333430*x^8 + 2874940*x^9 + 
          2333430*x^10 + 1763620*x^11 + 825210*x^12 + 380644*x^13 + 
          83898*x^14 + 21796*x^15 + 711*x^16 + 70*x^17 - 9*x^18)/
         (360*(-1 + x^2)^16) - (14*x^3*(2 + 9*x + 56*x^2 + 144*x^3 + 
           392*x^4 + 630*x^5 + 980*x^6 + 1008*x^7 + 980*x^8 + 630*x^9 + 
           392*x^10 + 144*x^11 + 56*x^12 + 9*x^13 + 2*x^14)*HPL[{0}, x])/
         (-1 + x^2)^17) - ((-27 + 210*x + 482*x^2 + 10290*x^3 + 25242*x^4 + 
         92610*x^5 + 147378*x^6 + 257250*x^7 + 254450*x^8 + 257250*x^9 + 
         147378*x^10 + 92610*x^11 + 25242*x^12 + 10290*x^13 + 482*x^14 + 
         210*x^15 - 27*x^16)*HPL[{-1, 0}, x])/(5670*(-1 + x^2)^15) + 
      (x^3*(45360 + 204120*x + 2245320*x^2 + 6970320*x^3 + 29695680*x^4 + 
         61668180*x^5 + 141666840*x^6 + 197215452*x^7 + 278011440*x^8 + 
         257027652*x^9 + 234770760*x^10 + 138713100*x^11 + 83049120*x^12 + 
         28476045*x^13 + 10880730*x^14 + 1656675*x^15 + 372540*x^16 + 
         563*x^17 + 210*x^18 - 27*x^19)*HPL[{0, 0}, x])/
       (2835*(-1 + x^2)^18) + ((-27 + 210*x + 482*x^2 + 10290*x^3 + 
         25242*x^4 + 92610*x^5 + 147378*x^6 + 257250*x^7 + 254450*x^8 + 
         257250*x^9 + 147378*x^10 + 92610*x^11 + 25242*x^12 + 10290*x^13 + 
         482*x^14 + 210*x^15 - 27*x^16)*HPL[{1, 0}, x])/(5670*(-1 + x^2)^15))
 
CbarData["a", 1, 8] = CF*NC*((-19978295 + 106458666*x + 1202188214*x^2 + 
        61750661238*x^3 + 247622461713*x^4 + 1370635589520*x^5 + 
        3281192772992*x^6 + 8558244275952*x^7 + 13213347969766*x^8 + 
        20354712918624*x^9 + 20625533267220*x^10 + 20354712918624*x^11 + 
        13213347969766*x^12 + 8558244275952*x^13 + 3281192772992*x^14 + 
        1370635589520*x^15 + 247622461713*x^16 + 61750661238*x^17 + 
        1202188214*x^18 + 106458666*x^19 - 19978295*x^20 - 
        58800*Pi^2*(-5 + 44*x + 106*x^2 + 2772*x^3 + 7587*x^4 + 31680*x^5 + 
          56208*x^6 + 103488*x^7 + 104664*x^8 + 77616*x^9 - 77616*x^11 - 
          104664*x^12 - 103488*x^13 - 56208*x^14 - 31680*x^15 - 7587*x^16 - 
          2772*x^17 - 106*x^18 - 44*x^19 + 5*x^20))/
       (1047816000*(-1 + x^2)^18) + (x^2*(210 - 2821728*x - 13145976*x^2 - 
         109809471*x^3 - 323122610*x^4 - 1169546426*x^5 - 2290024528*x^6 - 
         4765789042*x^7 - 6335944176*x^8 - 8416225146*x^9 - 7558396176*x^10 - 
         6682593778*x^11 - 3915636208*x^12 - 2315956922*x^13 - 
         812352890*x^14 - 311759967*x^15 - 52282656*x^16 - 11896464*x^17 - 
         249270*x^18 - 22176*x^19 + 2520*x^20)*HPL[{0}, x])/
       (62370*(-1 + x^2)^19) + 
      lm*((2*(-35 + 308*x + 3430*x^2 + 126346*x^3 + 546995*x^4 + 
           2931214*x^5 + 7341860*x^6 + 18853582*x^7 + 29919800*x^8 + 
           45475870*x^9 + 46898300*x^10 + 45475870*x^11 + 29919800*x^12 + 
           18853582*x^13 + 7341860*x^14 + 2931214*x^15 + 546995*x^16 + 
           126346*x^17 + 3430*x^18 + 308*x^19 - 35*x^20))/
         (3465*(-1 + x^2)^18) - (32*x^3*(1 + 5*x + 36*x^2 + 105*x^3 + 
           336*x^4 + 630*x^5 + 1176*x^6 + 1470*x^7 + 1764*x^8 + 1470*x^9 + 
           1176*x^10 + 630*x^11 + 336*x^12 + 105*x^13 + 36*x^14 + 5*x^15 + 
           x^16)*HPL[{0}, x])/(-1 + x^2)^19) - 
      ((-5 + 44*x + 101*x^2 + 2816*x^3 + 7688*x^4 + 34496*x^5 + 63896*x^6 + 
         137984*x^7 + 168560*x^8 + 215600*x^9 + 168560*x^10 + 137984*x^11 + 
         63896*x^12 + 34496*x^13 + 7688*x^14 + 2816*x^15 + 101*x^16 + 
         44*x^17 - 5*x^18)*HPL[{-1, 0}, x])/(1485*(-1 + x^2)^17) + 
      (2*x^3*(11880 + 59400*x + 742500*x^2 + 2574000*x^3 + 12602700*x^4 + 
         29721780*x^5 + 79718760*x^6 + 129484080*x^7 + 217493496*x^8 + 
         244299264*x^9 + 273247656*x^10 + 209164560*x^11 + 159454680*x^12 + 
         79617615*x^13 + 41157600*x^14 + 12119140*x^15 + 4095080*x^16 + 
         541970*x^17 + 109604*x^18 + 116*x^19 + 44*x^20 - 5*x^21)*
        HPL[{0, 0}, x])/(1485*(-1 + x^2)^20) + 
      ((-5 + 44*x + 101*x^2 + 2816*x^3 + 7688*x^4 + 34496*x^5 + 63896*x^6 + 
         137984*x^7 + 168560*x^8 + 215600*x^9 + 168560*x^10 + 137984*x^11 + 
         63896*x^12 + 34496*x^13 + 7688*x^14 + 2816*x^15 + 101*x^16 + 
         44*x^17 - 5*x^18)*HPL[{1, 0}, x])/(1485*(-1 + x^2)^17))
 
CbarData["a", 1, 9] = CF*NC*((-304927709 + 1941296292*x + 23403488661*x^2 + 
        1363066804800*x^3 + 6084175765955*x^4 + 38821309936380*x^5 + 
        105289881375525*x^6 + 321065661841920*x^7 + 575954268655320*x^8 + 
        1056250581775200*x^9 + 1290950998018248*x^10 + 
        1554142929042816*x^11 + 1290950998018248*x^12 + 
        1056250581775200*x^13 + 575954268655320*x^14 + 321065661841920*x^15 + 
        105289881375525*x^16 + 38821309936380*x^17 + 6084175765955*x^18 + 
        1363066804800*x^19 + 23403488661*x^20 + 1941296292*x^21 - 
        304927709*x^22 - 352800*Pi^2*(-11 + 108*x + 259*x^2 + 8640*x^3 + 
          26005*x^4 + 131220*x^5 + 268275*x^6 + 622080*x^7 + 805620*x^8 + 
          952560*x^9 + 579180*x^10 - 579180*x^12 - 952560*x^13 - 
          805620*x^14 - 622080*x^15 - 268275*x^16 - 131220*x^17 - 
          26005*x^18 - 8640*x^19 - 259*x^20 - 108*x^21 + 11*x^22))/
       (18860688000*(-1 + x^2)^20) + 
      (x^2*(1848 - 37855944*x - 194355030*x^2 - 1826173512*x^3 - 
         5972994772*x^4 - 24660507024*x^5 - 54629701971*x^6 - 
         131774311188*x^7 - 203480851350*x^8 - 319587253812*x^9 - 
         346393739110*x^10 - 371869080948*x^11 - 279117598998*x^12 - 
         208240929108*x^13 - 103940297151*x^14 - 53430754464*x^15 - 
         16202102452*x^16 - 5520366432*x^17 - 808877730*x^18 - 
         166053024*x^19 - 2991912*x^20 - 244944*x^21 + 24948*x^22)*
        HPL[{0}, x])/(748440*(-1 + x^2)^21) + 
      lm*((-77 + 756*x + 9163*x^2 + 396426*x^3 + 1905838*x^4 + 11798256*x^5 + 
          33477158*x^6 + 100595316*x^7 + 185670353*x^8 + 336603396*x^9 + 
          419117105*x^10 + 497967060*x^11 + 419117105*x^12 + 336603396*x^13 + 
          185670353*x^14 + 100595316*x^15 + 33477158*x^16 + 11798256*x^17 + 
          1905838*x^18 + 396426*x^19 + 9163*x^20 + 756*x^21 - 77*x^22)/
         (4620*(-1 + x^2)^20) - (6*x^3*(6 + 33*x + 270*x^2 + 880*x^3 + 
           3240*x^4 + 6930*x^5 + 15120*x^6 + 22176*x^7 + 31752*x^8 + 
           32340*x^9 + 31752*x^10 + 22176*x^11 + 15120*x^12 + 6930*x^13 + 
           3240*x^14 + 880*x^15 + 270*x^16 + 33*x^17 + 6*x^18)*HPL[{0}, x])/
         (-1 + x^2)^21) - ((-11 + 108*x + 248*x^2 + 8748*x^3 + 26253*x^4 + 
         139968*x^5 + 294528*x^6 + 762048*x^7 + 1100148*x^8 + 1714608*x^9 + 
         1679328*x^10 + 1714608*x^11 + 1100148*x^12 + 762048*x^13 + 
         294528*x^14 + 139968*x^15 + 26253*x^16 + 8748*x^17 + 248*x^18 + 
         108*x^19 - 11*x^20)*HPL[{-1, 0}, x])/(4455*(-1 + x^2)^19) + 
      (2*x^3*(35640 + 196020*x + 2744280*x^2 + 10505220*x^3 + 58152600*x^4 + 
         153387465*x^5 + 471036060*x^6 + 872756181*x^7 + 1704903552*x^8 + 
         2246471964*x^9 + 2981751696*x^10 + 2788907484*x^11 + 
         2592767232*x^12 + 1687043556*x^13 + 1105980480*x^14 + 
         477115540*x^15 + 217297080*x^16 + 56002364*x^17 + 16971768*x^18 + 
         1985676*x^19 + 364824*x^20 + 281*x^21 + 108*x^22 - 11*x^23)*
        HPL[{0, 0}, x])/(4455*(-1 + x^2)^22) + 
      ((-11 + 108*x + 248*x^2 + 8748*x^3 + 26253*x^4 + 139968*x^5 + 
         294528*x^6 + 762048*x^7 + 1100148*x^8 + 1714608*x^9 + 1679328*x^10 + 
         1714608*x^11 + 1100148*x^12 + 762048*x^13 + 294528*x^14 + 
         139968*x^15 + 26253*x^16 + 8748*x^17 + 248*x^18 + 108*x^19 - 
         11*x^20)*HPL[{1, 0}, x])/(4455*(-1 + x^2)^19))
 
 
CbarLData["a", 1, -1] = (5*CF*NC*(1 + x)^2)/(12*ep) - 
     (CF*NC*(1 + 2*x + x^2))/(2*ep^2) + CF*NC*((lm^2*(1 + x)^2)/2 + 
       (39 + 198*x + 39*x^2 + 4*Pi^2*(-1 + x^2))/72 - 
       (2*x^2*(1 + 5*x + x^2)*HPL[{0}, x])/(3*(-1 + x^2)) + 
       lm*((1 + 5*x + x^2)/3 - (2*x^3*(2 + x)*HPL[{0}, x])/(-1 + x^2)) - 
       (2*(-1 + x^2)*HPL[{-1, 0}, x])/3 + (8*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*
         HPL[{0, 0}, x])/(3*(-1 + x^2)^2) + (2*(-1 + x^2)*HPL[{1, 0}, x])/3)
 
CbarLData["a", 1, 0] = CF*NC*((-4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) + 
        3*(1 + 36*x - 22*x^2 + 36*x^3 + x^4))/(108*(-1 + x^2)^2) + 
      (4*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(9*(-1 + x^2)^3) + 
      (4*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(9*(-1 + x^2)) - 
      (8*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
       (9*(-1 + x^2)^4) - (4*(1 + 3*x + x^2)*HPL[{1, 0}, x])/(9*(-1 + x^2)))
 
CbarLData["a", 1, 1] = CF*NC*((-4*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 
        3*(3 + 72*x - 127*x^2 + 112*x^3 - 127*x^4 + 72*x^5 + 3*x^6))/
       (432*(-1 + x^2)^4) + (x^2*(2 + 122*x - 27*x^2 + 230*x^3 - 22*x^4 + 
         12*x^5 + 3*x^6)*HPL[{0}, x])/(18*(-1 + x^2)^5) + 
      lm*(-(1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
         (12*(-1 + x^2)^4) + (2*x^3*(2 - x + 2*x^2)*HPL[{0}, x])/
         (-1 + x^2)^5) + ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0}, x])/
       (9*(-1 + x^2)^3) - (2*x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 
         3*x^5 + 4*x^6 + x^7)*HPL[{0, 0}, x])/(9*(-1 + x^2)^6) - 
      ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/(9*(-1 + x^2)^3))
 
CbarLData["a", 1, 2] = 
    CF*NC*(-(11 - 219*x + 658*x^2 + 1479*x^3 + 1326*x^4 + 1479*x^5 + 
         658*x^6 - 219*x^7 + 11*x^8 + 4*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 
           15*x^5 - 2*x^6 + 5*x^7 + x^8))/(1080*(-1 + x^2)^6) + 
      (2*x^2*(1 + 263*x - 184*x^2 + 1109*x^3 - 424*x^4 + 683*x^5 - 44*x^6 + 
         15*x^7 + 3*x^8)*HPL[{0}, x])/(45*(-1 + x^2)^7) + 
      lm*(-(1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 5*x^7 + 
           x^8)/(15*(-1 + x^2)^6) + (8*x^3*(1 - x + 3*x^2 - x^3 + x^4)*
          HPL[{0}, x])/(-1 + x^2)^7) + 
      (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{-1, 0}, x])/
       (45*(-1 + x^2)^5) - (4*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 
         1940*x^4 - 535*x^5 + 545*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{0, 0}, x])/
       (45*(-1 + x^2)^8) - (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*
        HPL[{1, 0}, x])/(45*(-1 + x^2)^5))
 
CbarLData["a", 1, 3] = 
    CF*NC*(-(61 - 201*x + 978*x^2 + 19344*x^3 - 7591*x^4 + 51570*x^5 - 
         7591*x^6 + 19344*x^7 + 978*x^8 - 201*x^9 + 61*x^10 + 
         6*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*x^4 - 16*x^6 + 48*x^7 - 
           3*x^8 + 6*x^9 + x^10))/(3240*(-1 + x^2)^8) + 
      (x^2*(2 + 1512*x - 1780*x^2 + 11358*x^3 - 7758*x^4 + 16758*x^5 - 
         5155*x^6 + 4662*x^7 - 214*x^8 + 54*x^9 + 9*x^10)*HPL[{0}, x])/
       (90*(-1 + x^2)^9) + 
      lm*(-(1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 956*x^5 - 398*x^6 + 
           356*x^7 - 23*x^8 + 6*x^9 + x^10)/(20*(-1 + x^2)^8) + 
        (6*x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*x^5 + 2*x^6)*
          HPL[{0}, x])/(-1 + x^2)^9) + 
      ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
        HPL[{-1, 0}, x])/(45*(-1 + x^2)^7) - 
      (2*x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 13200*x^4 - 7055*x^5 + 
         9810*x^6 - 2169*x^7 + 1476*x^8 - 5*x^9 + 6*x^10 + x^11)*
        HPL[{0, 0}, x])/(45*(-1 + x^2)^10) - 
      ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
        HPL[{1, 0}, x])/(45*(-1 + x^2)^7))
 
CbarLData["a", 1, 4] = 
    CF*NC*(-(4519 + 2230*x + 7106*x^2 + 2867370*x^3 - 2876915*x^4 + 
         14316800*x^5 - 7125020*x^6 + 14316800*x^7 - 2876915*x^8 + 
         2867370*x^9 + 7106*x^10 + 2230*x^11 + 4519*x^12 + 
         240*Pi^2*(-1 - 7*x + 4*x^2 - 105*x^3 + 65*x^4 - 140*x^5 + 140*x^7 - 
           65*x^8 + 105*x^9 - 4*x^10 + 7*x^11 + x^12))/
       (226800*(-1 + x^2)^10) + (x^2*(4 + 6928*x - 11460*x^2 + 81817*x^3 - 
         81218*x^4 + 217254*x^5 - 119018*x^6 + 153217*x^7 - 37836*x^8 + 
         23896*x^9 - 836*x^10 + 168*x^11 + 24*x^12)*HPL[{0}, x])/
       (315*(-1 + x^2)^11) + 
      lm*((-4*(1 + 7*x - 34*x^2 + 714*x^3 - 1133*x^4 + 3689*x^5 - 2708*x^6 + 
           3689*x^7 - 1133*x^8 + 714*x^9 - 34*x^10 + 7*x^11 + x^12))/
         (105*(-1 + x^2)^10) + (16*x^3*(1 - 2*x + 10*x^2 - 10*x^3 + 20*x^4 - 
           10*x^5 + 10*x^6 - 2*x^7 + x^8)*HPL[{0}, x])/(-1 + x^2)^11) + 
      (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*x^7 - 
         3*x^8 + 7*x^9 + x^10)*HPL[{-1, 0}, x])/(315*(-1 + x^2)^9) - 
      (8*x^3*(630 - 1260*x + 12285*x^2 - 16310*x^3 + 58975*x^4 - 47040*x^5 + 
         83860*x^6 - 36344*x^7 + 34902*x^8 - 6356*x^9 + 3241*x^10 - 6*x^11 + 
         7*x^12 + x^13)*HPL[{0, 0}, x])/(315*(-1 + x^2)^12) - 
      (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*x^7 - 
         3*x^8 + 7*x^9 + x^10)*HPL[{1, 0}, x])/(315*(-1 + x^2)^9))
 
CbarLData["a", 1, 5] = 
    CF*NC*(-(33887 + 88456*x - 357835*x^2 + 38148864*x^3 - 58045437*x^4 + 
         308482680*x^5 - 254107015*x^6 + 581132800*x^7 - 254107015*x^8 + 
         308482680*x^9 - 58045437*x^10 + 38148864*x^11 - 357835*x^12 + 
         88456*x^13 + 33887*x^14 + 1200*Pi^2*(-1 - 8*x + 5*x^2 - 192*x^3 + 
           171*x^4 - 600*x^5 + 225*x^6 - 225*x^8 + 600*x^9 - 171*x^10 + 
           192*x^11 - 5*x^12 + 8*x^13 + x^14))/(1814400*(-1 + x^2)^12) + 
      (x^2*(10 + 34310*x - 73129*x^2 + 587186*x^3 - 767766*x^4 + 
         2446244*x^5 - 1929345*x^6 + 3181244*x^7 - 1414566*x^8 + 
         1292786*x^9 - 264229*x^10 + 128390*x^11 - 3590*x^12 + 600*x^13 + 
         75*x^14)*HPL[{0}, x])/(1260*(-1 + x^2)^13) + 
      lm*(-(5 + 40*x - 235*x^2 + 6312*x^3 - 12975*x^4 + 53352*x^5 - 
           56095*x^6 + 102352*x^7 - 56095*x^8 + 53352*x^9 - 12975*x^10 + 
           6312*x^11 - 235*x^12 + 40*x^13 + 5*x^14)/(168*(-1 + x^2)^12) + 
        (10*x^3*(2 - 5*x + 30*x^2 - 40*x^3 + 100*x^4 - 75*x^5 + 100*x^6 - 
           40*x^7 + 30*x^8 - 5*x^9 + 2*x^10)*HPL[{0}, x])/(-1 + x^2)^13) + 
      ((1 + 8*x - 4*x^2 + 200*x^3 - 175*x^4 + 800*x^5 - 400*x^6 + 800*x^7 - 
         175*x^8 + 200*x^9 - 4*x^10 + 8*x^11 + x^12)*HPL[{-1, 0}, x])/
       (126*(-1 + x^2)^11) - (x^3*(1008 - 2520*x + 28224*x^2 - 47432*x^3 + 
         201488*x^4 - 214228*x^5 + 467264*x^6 - 301924*x^7 + 376880*x^8 - 
         135520*x^9 + 99008*x^10 - 15280*x^11 + 6224*x^12 - 7*x^13 + 8*x^14 + 
         x^15)*HPL[{0, 0}, x])/(63*(-1 + x^2)^14) - 
      ((1 + 8*x - 4*x^2 + 200*x^3 - 175*x^4 + 800*x^5 - 400*x^6 + 800*x^7 - 
         175*x^8 + 200*x^9 - 4*x^10 + 8*x^11 + x^12)*HPL[{1, 0}, x])/
       (126*(-1 + x^2)^11))
 
CbarLData["a", 1, 6] = 
    CF*NC*(-(106795 + 447867*x - 2475714*x^2 + 195845265*x^3 - 
         393705676*x^4 + 2342972583*x^5 - 2676880150*x^6 + 7136097885*x^7 - 
         4801356910*x^8 + 7136097885*x^9 - 2676880150*x^10 + 
         2342972583*x^11 - 393705676*x^12 + 195845265*x^13 - 2475714*x^14 + 
         447867*x^15 + 106795*x^16 + 2800*Pi^2*(-1 - 9*x + 6*x^2 - 315*x^3 + 
           364*x^4 - 1701*x^5 + 1106*x^6 - 1575*x^7 + 1575*x^9 - 1106*x^10 + 
           1701*x^11 - 364*x^12 + 315*x^13 - 6*x^14 + 9*x^15 + x^16))/
       (6350400*(-1 + x^2)^14) + (x^2*(15 + 92115*x - 240375*x^2 + 
         2157813*x^3 - 3507887*x^4 + 12971727*x^5 - 13369639*x^6 + 
         26775333*x^7 - 17179879*x^8 + 20354067*x^9 - 7556267*x^10 + 
         5348889*x^11 - 929523*x^12 + 367191*x^13 - 8490*x^14 + 1215*x^15 + 
         135*x^16)*HPL[{0}, x])/(2835*(-1 + x^2)^15) + 
      lm*(-(5 + 45*x - 310*x^2 + 10233*x^3 - 25834*x^4 + 128421*x^5 - 
           175774*x^6 + 401841*x^7 - 316894*x^8 + 401841*x^9 - 175774*x^10 + 
           128421*x^11 - 25834*x^12 + 10233*x^13 - 310*x^14 + 45*x^15 + 
           5*x^16)/(210*(-1 + x^2)^14) + 
        (24*x^3*(1 - 3*x + 21*x^2 - 35*x^3 + 105*x^4 - 105*x^5 + 175*x^6 - 
           105*x^7 + 105*x^8 - 35*x^9 + 21*x^10 - 3*x^11 + x^12)*HPL[{0}, x])/
         (-1 + x^2)^15) + ((1 + 9*x - 5*x^2 + 324*x^3 - 369*x^4 + 2025*x^5 - 
         1475*x^6 + 3600*x^7 - 1475*x^8 + 2025*x^9 - 369*x^10 + 324*x^11 - 
         5*x^12 + 9*x^13 + x^14)*HPL[{-1, 0}, x])/(189*(-1 + x^2)^13) - 
      (2*x^3*(1512 - 4536*x + 57456*x^2 - 116928*x^3 + 571536*x^4 - 
         760284*x^5 + 1963332*x^6 - 1687392*x^7 + 2595348*x^8 - 1393476*x^9 + 
         1332072*x^10 - 407616*x^11 + 239976*x^12 - 32103*x^13 + 10881*x^14 - 
         8*x^15 + 9*x^16 + x^17)*HPL[{0, 0}, x])/(189*(-1 + x^2)^16) - 
      ((1 + 9*x - 5*x^2 + 324*x^3 - 369*x^4 + 2025*x^5 - 1475*x^6 + 
         3600*x^7 - 1475*x^8 + 2025*x^9 - 369*x^10 + 324*x^11 - 5*x^12 + 
         9*x^13 + x^14)*HPL[{1, 0}, x])/(189*(-1 + x^2)^13))
 
CbarLData["a", 1, 7] = 
    CF*NC*(-(948403 + 5256730*x - 35145481*x^2 + 2659091040*x^3 - 
         6611849840*x^4 + 44230292960*x^5 - 64503115824*x^6 + 
         198683465120*x^7 - 180536005258*x^8 + 320641292300*x^9 - 
         180536005258*x^10 + 198683465120*x^11 - 64503115824*x^12 + 
         44230292960*x^13 - 6611849840*x^14 + 2659091040*x^15 - 
         35145481*x^16 + 5256730*x^17 + 948403*x^18 + 
         19600*Pi^2*(-1 - 10*x + 7*x^2 - 480*x^3 + 680*x^4 - 3920*x^5 + 
           3528*x^6 - 7840*x^7 + 3136*x^8 - 3136*x^10 + 7840*x^11 - 
           3528*x^12 + 3920*x^13 - 680*x^14 + 480*x^15 - 7*x^16 + 10*x^17 + 
           x^18))/(63504000*(-1 + x^2)^16) + 
      (x^2*(42 + 428316*x - 1322892*x^2 + 13167258*x^3 - 25623722*x^4 + 
         107884186*x^5 - 137408132*x^6 + 323292470*x^7 - 271097002*x^8 + 
         393305630*x^9 - 211310912*x^10 + 195011674*x^11 - 61948010*x^12 + 
         35774682*x^13 - 5399055*x^14 + 1797054*x^15 - 35238*x^16 + 
         4410*x^17 + 441*x^18)*HPL[{0}, x])/(11340*(-1 + x^2)^17) + 
      lm*(-(7 + 70*x - 553*x^2 + 21796*x^3 - 65254*x^4 + 380644*x^5 - 
           641830*x^6 + 1763620*x^7 - 1814890*x^8 + 2874940*x^9 - 
           1814890*x^10 + 1763620*x^11 - 641830*x^12 + 380644*x^13 - 
           65254*x^14 + 21796*x^15 - 553*x^16 + 70*x^17 + 7*x^18)/
         (360*(-1 + x^2)^16) + (14*x^3*(2 - 7*x + 56*x^2 - 112*x^3 + 
           392*x^4 - 490*x^5 + 980*x^6 - 784*x^7 + 980*x^8 - 490*x^9 + 
           392*x^10 - 112*x^11 + 56*x^12 - 7*x^13 + 2*x^14)*HPL[{0}, x])/
         (-1 + x^2)^17) + ((1 + 10*x - 6*x^2 + 490*x^3 - 686*x^4 + 4410*x^5 - 
         4214*x^6 + 12250*x^7 - 7350*x^8 + 12250*x^9 - 4214*x^10 + 
         4410*x^11 - 686*x^12 + 490*x^13 - 6*x^14 + 10*x^15 + x^16)*
        HPL[{-1, 0}, x])/(270*(-1 + x^2)^15) - 
      (x^3*(2160 - 7560*x + 106920*x^2 - 255600*x^3 + 1414080*x^4 - 
         2259900*x^5 + 6746040*x^6 - 7239636*x^7 + 13238640*x^8 - 
         9456396*x^9 + 11179560*x^10 - 5114340*x^11 + 3954720*x^12 - 
         1051575*x^13 + 518130*x^14 - 61145*x^15 + 17740*x^16 - 9*x^17 + 
         10*x^18 + x^19)*HPL[{0, 0}, x])/(135*(-1 + x^2)^18) - 
      ((1 + 10*x - 6*x^2 + 490*x^3 - 686*x^4 + 4410*x^5 - 4214*x^6 + 
         12250*x^7 - 7350*x^8 + 12250*x^9 - 4214*x^10 + 4410*x^11 - 
         686*x^12 + 490*x^13 - 6*x^14 + 10*x^15 + x^16)*HPL[{1, 0}, x])/
       (270*(-1 + x^2)^15))
 
CbarLData["a", 1, 8] = 
    CF*NC*(-(6925253 + 46878933*x - 363460124*x^2 + 28270305819*x^3 - 
         83584045413*x^4 + 624881491560*x^5 - 1107817911192*x^6 + 
         3890395556376*x^7 - 4453872501456*x^8 + 9239726703312*x^9 - 
         6947690102136*x^10 + 9239726703312*x^11 - 4453872501456*x^12 + 
         3890395556376*x^13 - 1107817911192*x^14 + 624881491560*x^15 - 
         83584045413*x^16 + 28270305819*x^17 - 363460124*x^18 + 
         46878933*x^19 + 6925253*x^20 + 117600*Pi^2*(-1 - 11*x + 8*x^2 - 
           693*x^3 + 1161*x^4 - 7920*x^5 + 9024*x^6 - 25872*x^7 + 17052*x^8 - 
           19404*x^9 + 19404*x^11 - 17052*x^12 + 25872*x^13 - 9024*x^14 + 
           7920*x^15 - 1161*x^16 + 693*x^17 - 8*x^18 + 11*x^19 + x^20))/
       (523908000*(-1 + x^2)^18) + (x^2*(168 + 2685648*x - 9584214*x^2 + 
         104910591*x^3 - 237933368*x^4 + 1123823546*x^5 - 1705383141*x^6 + 
         4605758962*x^7 - 4769843125*x^8 + 8176180026*x^9 - 5747804725*x^10 + 
         6522563698*x^11 - 3005872485*x^12 + 2270234042*x^13 - 
         629317592*x^14 + 306861087*x^15 - 40893558*x^16 + 11760384*x^17 - 
         199416*x^18 + 22176*x^19 + 2016*x^20)*HPL[{0}, x])/
       (62370*(-1 + x^2)^19) + 
      lm*((-4*(14 + 154*x - 1372*x^2 + 63173*x^3 - 218798*x^4 + 1465607*x^5 - 
           2936744*x^6 + 9426791*x^7 - 11967920*x^8 + 22737935*x^9 - 
           18759320*x^10 + 22737935*x^11 - 11967920*x^12 + 9426791*x^13 - 
           2936744*x^14 + 1465607*x^15 - 218798*x^16 + 63173*x^17 - 
           1372*x^18 + 154*x^19 + 14*x^20))/(3465*(-1 + x^2)^18) + 
        (32*x^3*(1 - 4*x + 36*x^2 - 84*x^3 + 336*x^4 - 504*x^5 + 1176*x^6 - 
           1176*x^7 + 1764*x^8 - 1176*x^9 + 1176*x^10 - 504*x^11 + 336*x^12 - 
           84*x^13 + 36*x^14 - 4*x^15 + x^16)*HPL[{0}, x])/(-1 + x^2)^19) + 
      (4*(1 + 11*x - 7*x^2 + 704*x^3 - 1168*x^4 + 8624*x^5 - 10192*x^6 + 
         34496*x^7 - 27244*x^8 + 53900*x^9 - 27244*x^10 + 34496*x^11 - 
         10192*x^12 + 8624*x^13 - 1168*x^14 + 704*x^15 - 7*x^16 + 11*x^17 + 
         x^18)*HPL[{-1, 0}, x])/(1485*(-1 + x^2)^17) - 
      (8*x^3*(2970 - 11880*x + 185625*x^2 - 509850*x^3 + 3150675*x^4 - 
         5881095*x^5 + 19929690*x^6 - 25653276*x^7 + 54373374*x^8 - 
         48489540*x^9 + 68311914*x^10 - 41594916*x^11 + 39863670*x^12 - 
         15860460*x^13 + 10289400*x^14 - 2417360*x^15 + 1023770*x^16 - 
         108064*x^17 + 27401*x^18 - 10*x^19 + 11*x^20 + x^21)*HPL[{0, 0}, x])/
       (1485*(-1 + x^2)^20) - (4*(1 + 11*x - 7*x^2 + 704*x^3 - 1168*x^4 + 
         8624*x^5 - 10192*x^6 + 34496*x^7 - 27244*x^8 + 53900*x^9 - 
         27244*x^10 + 34496*x^11 - 10192*x^12 + 8624*x^13 - 1168*x^14 + 
         704*x^15 - 7*x^16 + 11*x^17 + x^18)*HPL[{1, 0}, x])/
       (1485*(-1 + x^2)^17))
 
CbarLData["a", 1, 9] = 
    CF*NC*(-(73645157 + 583594764*x - 5125791933*x^2 + 421055817600*x^3 - 
         1441475870555*x^4 + 11949383141460*x^5 - 24935254284525*x^6 + 
         98571880736640*x^7 - 136160587053720*x^8 + 323808841994400*x^9 - 
         304877203292424*x^10 + 476218409974272*x^11 - 304877203292424*x^12 + 
         323808841994400*x^13 - 136160587053720*x^14 + 98571880736640*x^15 - 
         24935254284525*x^16 + 11949383141460*x^17 - 1441475870555*x^18 + 
         421055817600*x^19 - 5125791933*x^20 + 583594764*x^21 + 
         73645157*x^22 + 1058400*Pi^2*(-1 - 12*x + 9*x^2 - 960*x^3 + 
           1855*x^4 - 14580*x^5 + 20025*x^6 - 69120*x^7 + 61020*x^8 - 
           105840*x^9 + 44100*x^10 - 44100*x^12 + 105840*x^13 - 61020*x^14 + 
           69120*x^15 - 20025*x^16 + 14580*x^17 - 1855*x^18 + 960*x^19 - 
           9*x^20 + 12*x^21 + x^22))/(6286896000*(-1 + x^2)^20) + 
      (x^2*(56 + 1340472*x - 5428566*x^2 + 64864056*x^3 - 168070068*x^4 + 
         880088112*x^5 - 1550693875*x^6 + 4725298044*x^7 - 5825879830*x^8 + 
         11510577756*x^9 - 9998343654*x^10 + 13446941724*x^11 - 
         8117902486*x^12 + 7557395004*x^13 - 3044954335*x^14 + 
         1945652832*x^15 - 478043028*x^16 + 201686016*x^17 - 24050466*x^18 + 
         6088512*x^19 - 90664*x^20 + 9072*x^21 + 756*x^22)*HPL[{0}, x])/
       (27720*(-1 + x^2)^21) + 
      lm*(-(21 + 252*x - 2499*x^2 + 132142*x^3 - 519774*x^4 + 3932752*x^5 - 
           9130134*x^6 + 33531772*x^7 - 50637369*x^8 + 112201132*x^9 - 
           114304665*x^10 + 165989020*x^11 - 114304665*x^12 + 
           112201132*x^13 - 50637369*x^14 + 33531772*x^15 - 9130134*x^16 + 
           3932752*x^17 - 519774*x^18 + 132142*x^19 - 2499*x^20 + 252*x^21 + 
           21*x^22)/(1540*(-1 + x^2)^20) + 
        (18*x^3*(2 - 9*x + 90*x^2 - 240*x^3 + 1080*x^4 - 1890*x^5 + 
           5040*x^6 - 6048*x^7 + 10584*x^8 - 8820*x^9 + 10584*x^10 - 
           6048*x^11 + 5040*x^12 - 1890*x^13 + 1080*x^14 - 240*x^15 + 
           90*x^16 - 9*x^17 + 2*x^18)*HPL[{0}, x])/(-1 + x^2)^21) + 
      ((1 + 12*x - 8*x^2 + 972*x^3 - 1863*x^4 + 15552*x^5 - 21888*x^6 + 
         84672*x^7 - 82908*x^8 + 190512*x^9 - 127008*x^10 + 190512*x^11 - 
         82908*x^12 + 84672*x^13 - 21888*x^14 + 15552*x^15 - 1863*x^16 + 
         972*x^17 - 8*x^18 + 12*x^19 + x^20)*HPL[{-1, 0}, x])/
       (495*(-1 + x^2)^19) - (2*x^3*(3960 - 17820*x + 304920*x^2 - 
         946220*x^3 + 6461400*x^4 - 13798235*x^5 + 52337340*x^6 - 
         78581151*x^7 + 189433728*x^8 - 202573844*x^9 + 331305744*x^10 - 
         251899604*x^11 + 288085248*x^12 - 152618796*x^13 + 122886720*x^14 - 
         43224060*x^15 + 24144120*x^16 - 5078964*x^17 + 1885752*x^18 - 
         180036*x^19 + 40536*x^20 - 11*x^21 + 12*x^22 + x^23)*HPL[{0, 0}, x])/
       (495*(-1 + x^2)^22) - ((1 + 12*x - 8*x^2 + 972*x^3 - 1863*x^4 + 
         15552*x^5 - 21888*x^6 + 84672*x^7 - 82908*x^8 + 190512*x^9 - 
         127008*x^10 + 190512*x^11 - 82908*x^12 + 84672*x^13 - 21888*x^14 + 
         15552*x^15 - 1863*x^16 + 972*x^17 - 8*x^18 + 12*x^19 + x^20)*
        HPL[{1, 0}, x])/(495*(-1 + x^2)^19))
 

CbarData["a", 2, -1] = 
    NC*(CF^2*(-(lm^3*(1 + x)^2)/4 - (Pi^2*(1 + x^2)*HPL[{-2}, x])/9 + 
        lm^2*((7 + 2*x + 7*x^2)/16 + (3*x^3*(2 + x)*HPL[{0}, x])/
           (2*(-1 + x^2))) + (Pi^2*(1 + x^2)*HPL[{2}, x])/9 + 
        (x^2*(-6 + 12*x + 57*x^2 - 39*x^3 - 46*x^4 + 22*x^5 + 22*x^6 + x^7 - 
           5*x^8 - 2*x^9)*HPL[{-2, 0}, x])/(9*(-1 + x^2)^2) + 
        ((12 + 30*x + 12*x^2 + (181 - 12*Pi^2)*x^3 - 6*x^4 - 554*x^5 - 
           6*x^6 + (181 + 12*Pi^2)*x^7 + 12*x^8 + 30*x^9 + 12*x^10)*
          HPL[{-1, 0}, x])/(108*x^3*(-1 + x^2)) - 
        (x^2*(-384 + 747*x + 99*x^2 + 1746*x^3 + 3923*x^4 + 15*x^6 + 6*x^7)*
          HPL[{0, 0}, x])/(27*(-1 + x^2)^2) - 
        ((12 + 30*x + 12*x^2 + (181 - 12*Pi^2)*x^3 - 6*x^4 - 554*x^5 - 
           6*x^6 + (181 + 12*Pi^2)*x^7 + 12*x^8 + 30*x^9 + 12*x^10)*
          HPL[{1, 0}, x])/(108*x^3*(-1 + x^2)) + 
        (x^2*(6 - 12*x - 57*x^2 + 39*x^3 + 46*x^4 - 22*x^5 - 22*x^6 - x^7 + 
           5*x^8 + 2*x^9)*HPL[{2, 0}, x])/(9*(-1 + x^2)^2) + 
        (4*(1 + x^2)*HPL[{-2, -1, 0}, x])/3 - 
        (8*(1 + x^2)*HPL[{-2, 0, 0}, x])/3 - (4*(1 + x^2)*HPL[{-2, 1, 0}, x])/
         3 - (4*(1 + x^2)*HPL[{-1, -2, 0}, x])/3 + 
        ((1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 11*x^6 - x^8 + 2*x^9)*
          HPL[{-1, -1, 0}, x])/(18*x^5) - 
        ((-56 + 85*x - 39*x^2 - 3*x^3 + 3*x^4 + 9*x^5 - 13*x^6 - 5*x^7 + 
           x^8 + 2*x^9)*HPL[{-1, 0, 0}, x])/(9*(-1 + x)^2) - 
        ((1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 11*x^6 - x^8 + 2*x^9)*
          HPL[{-1, 1, 0}, x])/(18*x^5) + (4*(1 + x^2)*HPL[{-1, 2, 0}, x])/3 + 
        (2*x^2*(-3 + 366*x + 309*x^2 - 828*x^3 - 1415*x^4 + 652*x^5 + 
           1155*x^6 - 21*x^7 - 27*x^8 - 3*x^9 + 5*x^10 + 2*x^11)*
          HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
        (4*(1 + x^2)*HPL[{1, -2, 0}, x])/3 - 
        ((1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 11*x^6 - x^8 + 2*x^9)*
          HPL[{1, -1, 0}, x])/(18*x^5) - 
        ((56 + 91*x + 51*x^2 + 39*x^3 + 69*x^4 + 39*x^5 + x^6 - 15*x^7 - 
           9*x^8 - 2*x^9)*HPL[{1, 0, 0}, x])/(9*(1 + x)^2) + 
        ((1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 11*x^6 - x^8 + 2*x^9)*
          HPL[{1, 1, 0}, x])/(18*x^5) - (4*(1 + x^2)*HPL[{1, 2, 0}, x])/3 - 
        (4*(1 + x^2)*HPL[{2, -1, 0}, x])/3 + (8*(1 + x^2)*HPL[{2, 0, 0}, x])/
         3 + (4*(1 + x^2)*HPL[{2, 1, 0}, x])/3 - 
        (8*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/3 - 
        (8*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/3 + 
        ((-1 + x*(-1 - 4/(-1 + x^2)))*master3l10a[x])/12 + 
        ((x + x^2 + 3*x^3 - x^4)*master3l10b[x])/(12*(-1 + x^2)) + 
        ((-11 + 6*x + x^2)*master3l8a[x])/(12*(-1 + x^2)^2) + 
        ((-5 + 18*x + 39*x^2)*master3l8b[x])/(36*(-1 + x^2)^2) + 
        ((-9 + x^2)*master3l9a[x])/(3*(-1 + x^2)^2) + 
        ((-1 + 9*x^2)*master3l9b[x])/(9*(-1 + x^2)^2) + 
        lm*(-(x^2*(-4 + 2*x + 7*x^2)*HPL[{0}, x])/(4*(-1 + x^2)) + 
          (-1 + x^2)*HPL[{-1, 0}, x] - (4*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*
            HPL[{0, 0}, x])/(-1 + x^2)^2 + (1 - x^2)*HPL[{1, 0}, x] + 
          (95 - 8*Pi^2*(-1 + x^2) + x*(82 - 288*Zeta[3]) + 
            x^2*(95 - 144*Zeta[3]) - 144*Zeta[3])/96) - 
        (HPL[{-1}, x]*(Pi^2*(1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 
             11*x^6 - x^8 + 2*x^9) + 288*x^5*(1 + x^2)*Zeta[3]))/(216*x^5) + 
        (HPL[{1}, x]*(Pi^2*(1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 
             11*x^6 - x^8 + 2*x^9) + 288*x^5*(1 + x^2)*Zeta[3]))/(216*x^5) + 
        (HPL[{0}, x]*(-24 - 60*x - 12*x^2 + 4*(-2947 + 6*Pi^2)*x^3 + 
           (24 - 88*Pi^2)*x^8 - 88*Pi^2*x^9 - 4*Pi^2*x^10 + 20*Pi^2*x^11 + 
           8*Pi^2*x^12 + x^5*(12643 - 228*Pi^2 - 1728*Zeta[3]) - 
           6*x^4*(-2283 + 8*Pi^2 + 576*Zeta[3]) + 6*x^6*(1499 + 26*Pi^2 + 
             576*Zeta[3]) + x^7*(21885 + 184*Pi^2 + 1728*Zeta[3])))/
         (432*x*(-1 + x^2)^2) + (24*Pi^4*x^3*(-1 + x^2)^2*
           (39 + 88*x + 39*x^2) - 10*Pi^2*(-1 + x^2)*(12 + 30*x + 12*x^2 - 
            554*x^5 + 12*x^8 + 30*x^9 + 12*x^10 + x^7*(181 - 576*Log[2]^2) + 
            6*x^4*(-1 + 192*Log[2]^2) - 6*x^6*(1 + 192*Log[2]^2) + 
            x^3*(181 + 576*Log[2]^2)) - 15*x^2*(-12 - 528*x^9*Zeta[3] - 
            24*x^10*Zeta[3] + 120*x^11*Zeta[3] + 48*x^12*Zeta[3] - 
            12*x^8*(1 + 44*Zeta[3]) + 3*x^2*(377 + 256*Log[2]^4 + 
              6144*PolyLog[4, 1/2] + 4072*Zeta[3]) - 
            6*x^4*(-2927 + 256*Log[2]^4 + 6144*PolyLog[4, 1/2] + 
              4192*Zeta[3]) + 3*x^6*(377 + 256*Log[2]^4 + 6144*PolyLog[4, 
                1/2] + 4384*Zeta[3]) - x^3*(10405 + 384*Log[2]^4 + 
              9216*PolyLog[4, 1/2] + 6288*Zeta[3]) - 
            x^5*(-17675 + 384*Log[2]^4 + 9216*PolyLog[4, 1/2] + 
              6504*Zeta[3]) + x*(-14255 + 384*Log[2]^4 + 9216*PolyLog[4, 
                1/2] + 9096*Zeta[3]) + x^7*(6625 + 384*Log[2]^4 + 
              9216*PolyLog[4, 1/2] + 9768*Zeta[3])))/
         (12960*x^3*(-1 + x^2)^2)) + CA*CF*((-11*lm^3*(1 + x)^2)/72 + 
        (Pi^2*(1 + x^2)*HPL[{-2}, x])/18 + 
        lm^2*((-119 - 304*x - 119*x^2)/144 + (11*x^3*(2 + x)*HPL[{0}, x])/
           (12*(-1 + x^2))) - (Pi^2*(1 + x^2)*HPL[{2}, x])/18 - 
        (x^2*(-6 + 6*x + 42*x^2 - 21*x^3 - 31*x^4 + 6*x^5 + 9*x^6 + 3*x^7)*
          HPL[{-2, 0}, x])/(18*(-1 + x^2)^2) + 
        ((6 + (161 + 4*Pi^2)*x - 12*x^2 - 294*x^3 - 12*x^4 + 
           (161 - 4*Pi^2)*x^5 + 6*x^6)*HPL[{-1, 0}, x])/(72*x*(-1 + x^2)) + 
        (x^2*(-326 + 1666*x + 711*x^2 + 598*x^3 + 2229*x^4 - 6*x^5)*
          HPL[{0, 0}, x])/(36*(-1 + x^2)^2) + 
        ((6 + 161*x + 4*Pi^2*x - 12*x^2 - 294*x^3 - 12*x^4 + 161*x^5 - 
           4*Pi^2*x^5 + 6*x^6)*HPL[{1, 0}, x])/(72*x - 72*x^3) + 
        (x^2*(-6 + 6*x + 42*x^2 - 21*x^3 - 31*x^4 + 6*x^5 + 9*x^6 + 3*x^7)*
          HPL[{2, 0}, x])/(18*(-1 + x^2)^2) - 
        (2*(1 + x^2)*HPL[{-2, -1, 0}, x])/3 + (8*x^2*HPL[{-2, 0, 0}, x])/3 + 
        (2*(1 + x^2)*HPL[{-2, 1, 0}, x])/3 + 
        (2*(1 + x^2)*HPL[{-1, -2, 0}, x])/3 + 
        ((-3 - 9*x - 12*x^2 + 35*x^3 - 35*x^5 + 12*x^6 + 9*x^7 + 3*x^8)*
          HPL[{-1, -1, 0}, x])/(36*x^3) - 
        ((67 - 101*x + 93*x^2 - 107*x^3 + 61*x^4 - 3*x^5 + 3*x^6 + 3*x^7)*
          HPL[{-1, 0, 0}, x])/(18*(-1 + x)^2) + 
        ((3 + 9*x + 12*x^2 - 35*x^3 + 35*x^5 - 12*x^6 - 9*x^7 - 3*x^8)*
          HPL[{-1, 1, 0}, x])/(36*x^3) - (2*(1 + x^2)*HPL[{-1, 2, 0}, x])/3 + 
        (x^2*(9 - 330*x - 72*x^2 - 366*x^3 - 907*x^4 + 6*x^5 + 9*x^6 + 3*x^7)*
          HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^2) - 
        (2*(1 + x^2)*HPL[{1, -2, 0}, x])/3 + 
        ((3 + 9*x + 12*x^2 - 35*x^3 + 35*x^5 - 12*x^6 - 9*x^7 - 3*x^8)*
          HPL[{1, -1, 0}, x])/(36*x^3) + 
        ((67 + 119*x + 129*x^2 + 149*x^3 + 109*x^4 + 33*x^5 + 15*x^6 + 3*x^7)*
          HPL[{1, 0, 0}, x])/(18*(1 + x)^2) + 
        ((-3 - 9*x - 12*x^2 + 35*x^3 - 35*x^5 + 12*x^6 + 9*x^7 + 3*x^8)*
          HPL[{1, 1, 0}, x])/(36*x^3) + (2*(1 + x^2)*HPL[{1, 2, 0}, x])/3 + 
        (2*(1 + x^2)*HPL[{2, -1, 0}, x])/3 - (8*x^2*HPL[{2, 0, 0}, x])/3 - 
        (2*(1 + x^2)*HPL[{2, 1, 0}, x])/3 - 
        (4*(-1 + x^2)*HPL[{-1, 0, 0, 0}, x])/3 + 
        (4*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/3 + 
        (4*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/3 + 
        (4*(-1 + x^2)*HPL[{1, 0, 0, 0}, x])/3 + 
        ((1 + x + (4*x)/(-1 + x^2))*master3l10a[x])/24 + 
        ((x + x^2 + 3*x^3 - x^4)*master3l10b[x])/(24 - 24*x^2) - 
        ((-11 + 6*x + x^2)*master3l8a[x])/(24*(-1 + x^2)^2) + 
        ((5 - 18*x - 39*x^2)*master3l8b[x])/(72*(-1 + x^2)^2) - 
        ((-9 + x^2)*master3l9a[x])/(6*(-1 + x^2)^2) + 
        ((1 - 9*x^2)*master3l9b[x])/(18*(-1 + x^2)^2) + 
        (HPL[{1}, x]*(Pi^2*(-3 - 9*x - 12*x^2 + 35*x^3 - 35*x^5 + 12*x^6 + 
             9*x^7 + 3*x^8) - 288*x^3*(1 + x^2)*Zeta[3]))/(432*x^3) + 
        (HPL[{-1}, x]*(Pi^2*(3 + 9*x + 12*x^2 - 35*x^3 + 35*x^5 - 12*x^6 - 
             9*x^7 - 3*x^8) + 288*x^3*(1 + x^2)*Zeta[3]))/(432*x^3) + 
        (x*HPL[{0}, x]*(-18 - 12*(-426 + Pi^2)*x + 12*Pi^2*x^6 + 
           18*Pi^2*x^7 + 6*Pi^2*x^8 + 6*x^2*(-1905 + 2*Pi^2 + 288*Zeta[3]) - 
           6*x^4*(-18 + 7*Pi^2 + 288*Zeta[3]) - x^5*(10107 + 62*Pi^2 + 
             864*Zeta[3]) + x^3*(-6345 + 84*Pi^2 + 864*Zeta[3])))/
         (432*(-1 + x^2)^2) - (8*Pi^4*x*(-1 + x^2)^2*(47 + 88*x + 31*x^2) + 
          10*Pi^2*(-1 + x^2)*(6 - 294*x^3 + 6*x^6 + x*(161 - 192*Log[2]^2) + 
            12*x^4*(-1 + 32*Log[2]^2) - 12*x^2*(1 + 32*Log[2]^2) + 
            x^5*(161 + 192*Log[2]^2)) + 15*x*(5269 - 128*Log[2]^4 - 
            3072*PolyLog[4, 1/2] - 2256*Zeta[3] + 48*x^7*Zeta[3] + 
            72*x^8*Zeta[3] + 24*x^9*Zeta[3] + 16*x^3*(-878 + 32*Log[2]^4 + 
              768*PolyLog[4, 1/2] + 415*Zeta[3]) - 4*x*(-931 + 64*Log[2]^4 + 
              1536*PolyLog[4, 1/2] + 806*Zeta[3]) - 
            4*x^5*(-931 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 848*Zeta[3]) + 
            x^2*(2951 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 1096*Zeta[3]) + 
            x^4*(-6409 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 
              2008*Zeta[3]) - x^6*(1691 + 128*Log[2]^4 + 3072*PolyLog[4, 
                1/2] + 2680*Zeta[3])))/(8640*x*(-1 + x^2)^2) + 
        lm*((x^2*(22 + 304*x + 119*x^2)*HPL[{0}, x])/(36*(-1 + x^2)) + 
          (11*(-1 + x^2)*HPL[{-1, 0}, x])/18 - 
          (22*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
           (9*(-1 + x^2)^2) - (11*(-1 + x^2)*HPL[{1, 0}, x])/18 + 
          (-44*Pi^2*(-1 + x^2) + 9*(-137 + 72*Zeta[3] + 2*x*(-275 + 
                72*Zeta[3]) + x^2*(-137 + 72*Zeta[3])))/864)) + 
      CF*(NH*((lm^3*(1 + x)^2)/36 - (x*(48 + 472*x + 2985*x^2 + 1552*x^3 - 
             807*x^4 - 521*x^5 + 102*x^6 + 49*x^7)*HPL[{0}, x])/
           (36*(-1 + x^2)^3) + lm^2*((7 + 20*x + 7*x^2)/72 - 
            (x^3*(2 + x)*HPL[{0}, x])/(6*(-1 + x^2))) + 
          (x*(24 + 136*x + 1016*x^2 + 523*x^3 - 378*x^4 - 208*x^5 + 58*x^6 + 
             29*x^7)*HPL[{0, 0}, x])/(18*(-1 + x^2)^3) + 
          lm*((4*Pi^2*(-1 + x^2) + 9*(9 + 38*x + 9*x^2))/432 - 
            (x^2*(2 + 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((1 - x^2)*HPL[{-1, 0}, x])/9 + (4*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*
              HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + ((-1 + x^2)*HPL[{1, 0}, x])/
             9) + ((-2 + 43*x + 12*x^2 - 5*x^3 - 8*x^4)*HPL[{-1, 0, 0}, x])/
           (9*(-1 + x)^2) + (2*x^3*(-54 - 33*x + 6*x^2 + x^5)*
            HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
          ((14 - 5*x + 19*x^3 + 8*x^4)*HPL[{1, 0, 0}, x])/(9*(1 + x)^2) + 
          ((-9 - 54*x - 28*x^2 + 6*x^3 + 5*x^4)*master3l8a[x])/
           (18*(-1 + x^2)^3) - ((27 + 108*x + 51*x^2 - 12*x^3 - 15*x^4 + x^6)*
            master3l9a[x])/(18*(-1 + x^2)^3) + (x*(16923 - 768*Zeta[3]) + 
            39*(99 - 32*Zeta[3]) + 4*x^8*(113 + 32*Zeta[3]) - 
            3*x^3*(-6687 + 64*Zeta[3]) + 3*x^7*(309 + 64*Zeta[3]) + 
            3*x^4*(3253 + 96*Zeta[3]) - x^6*(4517 + 320*Zeta[3]) + 
            3*x^2*(3535 + 384*Zeta[3]) + x^5*(-7671 + 768*Zeta[3]))/
           (432*(-1 + x^2)^3)) + NM*((lm^3*(1 + x)^2)/36 - 
          ((2*Pi^2*(-1 + x^2)^4 + 3*(38 - 219*x^2 + 9*x^3 - 188*x^4 + 459*
                x^5 + 1030*x^6 + 1860*x^7 + 891*x^8))*HPL[{0}, x])/
           (108*(-1 + x^2)^3) + lm^2*((7 + 20*x + 7*x^2)/72 - 
            (x^3*(2 + x)*HPL[{0}, x])/(6*(-1 + x^2))) + 
          (2*(-1 + x^2)*HPL[{-2, 0}, x])/9 + 
          ((12 + 14*x^2 + 32*x^3 - 601*x^4 - 30*x^5 + 978*x^6 + 2446*x^7 + 
             1229*x^8)*HPL[{0, 0}, x])/(18*(-1 + x^2)^3) + 
          lm*((4*Pi^2*(-1 + x^2) + 9*(9 + 38*x + 9*x^2))/432 - 
            (x^2*(2 + 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((1 - x^2)*HPL[{-1, 0}, x])/9 + (4*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*
              HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + ((-1 + x^2)*HPL[{1, 0}, x])/
             9) - (2*(-1 + x^2)*HPL[{2, 0}, x])/9 + 
          ((-12 + 3*x + 12*x^2 + 35*x^3 + 2*x^4)*HPL[{-1, 0, 0}, x])/
           (9*(-1 + x)^2) - (2*(1 + 28*x^2 + 30*x^3 - 243*x^4 - 138*x^5 + 
             332*x^6 + 1020*x^7 + 490*x^8)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x^2)^3) + ((12 + 27*x - 13*x^3 + 10*x^4)*
            HPL[{1, 0, 0}, x])/(9*(1 + x)^2) - 
          ((2 - 15*x^2 - 6*x^3 + 18*x^4 + 54*x^5 + 27*x^6)*master3l8b[x])/
           (54*x^2*(-1 + x^2)^3) - ((1 - 15*x^2 - 12*x^3 + 51*x^4 + 108*x^5 + 
             27*x^6)*master3l9b[x])/(54*x^2*(-1 + x^2)^3) + 
          (-15 + x^5*(3171 - 768*Zeta[3]) + x^2*(13 - 128*Zeta[3]) + 
            156*x^10*(9 + 8*Zeta[3]) - 3*x^3*(249 + 64*Zeta[3]) + 
            3*x^7*(1173 + 64*Zeta[3]) - 12*x^8*(-485 + 96*Zeta[3]) - 
            3*x^6*(283 + 96*Zeta[3]) + x^4*(347 + 320*Zeta[3]) + 
            x^9*(4137 + 768*Zeta[3]))/(432*x^2*(-1 + x^2)^3)) + 
        NL*((lm^3*(1 + x)^2)/36 - (Pi^2*(-1 + x^2)*HPL[{-1}, x])/54 + 
          (x^2*(84 - 6*(-57 + 4*Pi^2)*x - 3*(1 + 4*Pi^2)*x^2 - 342*x^3 + 
             (-81 + 4*Pi^2)*x^4)*HPL[{0}, x])/(216*(-1 + x^2)^2) + 
          lm^2*((7 + 20*x + 7*x^2)/72 - (x^3*(2 + x)*HPL[{0}, x])/
             (6*(-1 + x^2))) + (Pi^2*(-1 + x^2)*HPL[{1}, x])/54 - 
          (2*x^3*(-6 - 3*x + x^3)*HPL[{-2, 0}, x])/(9*(-1 + x^2)^2) + 
          ((7 + 6*x - 10*x^2 + 6*x^3 + 7*x^4)*HPL[{-1, 0}, x])/
           (18 - 18*x^2) + (2*x^3*(-20 - 10*x + 13*x^2 + 7*x^3)*
            HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + 
          ((7 + 6*x - 10*x^2 + 6*x^3 + 7*x^4)*HPL[{1, 0}, x])/
           (18*(-1 + x^2)) + lm*((4*Pi^2*(-1 + x^2) + 9*(9 + 38*x + 9*x^2))/
             432 - (x^2*(2 + 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((1 - x^2)*HPL[{-1, 0}, x])/9 + (4*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*
              HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + ((-1 + x^2)*HPL[{1, 0}, x])/
             9) + (2*x^3*(-6 - 3*x + x^3)*HPL[{2, 0}, x])/(9*(-1 + x^2)^2) + 
          (2*(-1 + x^2)*HPL[{-1, -1, 0}, x])/9 - 
          (2*(-1 + x^2)*HPL[{-1, 1, 0}, x])/9 - 
          (8*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x^2)^2) - (2*(-1 + x^2)*HPL[{1, -1, 0}, x])/9 + 
          (2*(-1 + x^2)*HPL[{1, 1, 0}, x])/9 + 
          (4*Pi^2*(-7 - 6*x + 17*x^2 - 17*x^4 + 6*x^5 + 7*x^6) + 
            3*(73 + 96*Zeta[3] + 8*x*(41 + 16*Zeta[3]) + 8*x^5*(41 + 
                16*Zeta[3]) - 16*x^3*(41 + 28*Zeta[3]) - x^4*(73 + 
                64*Zeta[3]) + x^6*(73 + 64*Zeta[3]) - x^2*(73 + 
                160*Zeta[3])))/(864*(-1 + x^2)^2))))
 
CbarData["a", 2, 0] = 
    NC*(CF*(NL*(lm^2/36 + (Pi^2*(2 + 9*x + 2*x^2)*HPL[{-1}, x])/
           (243*(-1 + x^2)) - (x^2*(90 + (309 + 54*Pi^2)*x + 
             6*(-10 + 9*Pi^2)*x^2 + 3*(-124 + 9*Pi^2)*x^3 - 
             4*(9 + Pi^2)*x^4 + 9*(7 + Pi^2)*x^5 + 2*(3 + Pi^2)*x^6)*
            HPL[{0}, x])/(243*(-1 + x^2)^4) - (Pi^2*(2 + 9*x + 2*x^2)*
            HPL[{1}, x])/(243*(-1 + x^2)) + 
          (4*x^3*(54 + 54*x + 27*x^2 - 4*x^3 + 9*x^4 + 2*x^5)*
            HPL[{-2, 0}, x])/(81*(-1 + x^2)^4) + 
          ((30 + 29*x - 82*x^2 - 238*x^3 - 82*x^4 + 29*x^5 + 30*x^6)*
            HPL[{-1, 0}, x])/(81*(-1 + x^2)^3) - 
          (2*x^3*(180 + 180*x + 9*x^2 - 68*x^3 + 29*x^4 + 21*x^5)*
            HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + 
          ((-30 - 29*x + 82*x^2 + 238*x^3 + 82*x^4 - 29*x^5 - 30*x^6)*
            HPL[{1, 0}, x])/(81*(-1 + x^2)^3) + 
          lm*((6 + 63*x + 66*x^2 + 63*x^3 + 6*x^4 + Pi^2*(2 + 9*x - 9*x^3 - 
                2*x^4))/(486*(-1 + x^2)^2) + (x^2*(4 + 48*x + 31*x^2 - 9*x^4)*
              HPL[{0}, x])/(81*(-1 + x^2)^3) + (2*(2 + 9*x + 2*x^2)*
              HPL[{-1, 0}, x])/(81*(-1 + x^2)) - 
            (4*x^3*(54 + 54*x + 27*x^2 - 4*x^3 + 9*x^4 + 2*x^5)*
              HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + ((4 + 18*x + 4*x^2)*
              HPL[{1, 0}, x])/(81 - 81*x^2)) - 
          (4*x^3*(54 + 54*x + 27*x^2 - 4*x^3 + 9*x^4 + 2*x^5)*HPL[{2, 0}, x])/
           (81*(-1 + x^2)^4) + ((8 + 36*x + 8*x^2)*HPL[{-1, -1, 0}, x])/
           (81 - 81*x^2) + (4*(2 + 9*x + 2*x^2)*HPL[{-1, 1, 0}, x])/
           (81*(-1 + x^2)) + (8*x^3*(54 + 54*x + 27*x^2 - 4*x^3 + 9*x^4 + 
             2*x^5)*HPL[{0, 0, 0}, x])/(81*(-1 + x^2)^4) + 
          (4*(2 + 9*x + 2*x^2)*HPL[{1, -1, 0}, x])/(81*(-1 + x^2)) + 
          ((8 + 36*x + 8*x^2)*HPL[{1, 1, 0}, x])/(81 - 81*x^2) + 
          (1139*x^6 + 351*x^7 - 164*x^8 + Pi^2*(30 + 29*x - 112*x^2 - 
              267*x^3 + 267*x^5 + 112*x^6 - 29*x^7 - 30*x^8) - 
            27*x*(-13 + 8*Zeta[3]) - 4*(41 + 12*Zeta[3]) - 
            27*x^3*(13 + 24*Zeta[3]) - 27*x^5*(13 + 48*Zeta[3]) + 
            x^2*(1139 + 96*Zeta[3]) - 6*x^4*(325 + 216*Zeta[3]))/
           (972*(-1 + x^2)^4)) + NH*(lm^2/36 + 
          (x*(3888 - 15264*x + 674280*x^2 + 769648*x^3 - 40495*x^4 - 
             368496*x^5 - 3853*x^6 + 82102*x^7 - 649*x^8 - 8972*x^9 + 
             45*x^10 + 374*x^11)*HPL[{0}, x])/(324*(-9 + x^2)*(-1 + x^2)^5) - 
          (x*(972 - 828*x + 119340*x^2 + 127460*x^3 - 18663*x^4 - 68920*x^5 - 
             3909*x^6 + 14768*x^7 + 147*x^8 - 1500*x^9 + 33*x^10 + 60*x^11)*
            HPL[{0, 0}, x])/(81*(-9 + x^2)*(-1 + x^2)^5) + 
          lm*((6 + 63*x + 66*x^2 + 63*x^3 + 6*x^4 + Pi^2*(2 + 9*x - 9*x^3 - 
                2*x^4))/(486*(-1 + x^2)^2) + (x^2*(4 + 48*x + 31*x^2 - 9*x^4)*
              HPL[{0}, x])/(81*(-1 + x^2)^3) + (2*(2 + 9*x + 2*x^2)*
              HPL[{-1, 0}, x])/(81*(-1 + x^2)) - 
            (4*x^3*(54 + 54*x + 27*x^2 - 4*x^3 + 9*x^4 + 2*x^5)*
              HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + ((4 + 18*x + 4*x^2)*
              HPL[{1, 0}, x])/(81 - 81*x^2)) + 
          (2*(-17 + 499*x + 289*x^2 - 22*x^3 - 86*x^4 + 37*x^5 + 4*x^6)*
            HPL[{-1, 0, 0}, x])/(81*(-1 + x)^4*(1 + x)^2) - 
          (4*x^3*(-7722 - 6984*x + 639*x^2 + 2484*x^3 + 681*x^4 - 222*x^5 - 
             135*x^6 - 16*x^7 + 9*x^8 + 2*x^9)*HPL[{0, 0, 0}, x])/
           (81*(-9 + x^2)*(-1 + x^2)^5) + (2*(71 - 269*x - 475*x^2 - 
             238*x^3 + 14*x^4 + x^5 - 4*x^6)*HPL[{1, 0, 0}, x])/
           (81*(-1 + x)^2*(1 + x)^4) + ((-216 + 5985*x + 6984*x^2 + 531*x^3 - 
             2418*x^4 + 23*x^5 + 412*x^6 - 11*x^7 - 26*x^8)*master3l8a[x])/
           (81*(-9 + x^2)*(-1 + x^2)^5) + ((-648 + 10233*x + 13968*x^2 + 
             2232*x^3 - 4770*x^4 + 750*x^5 + 1014*x^6 - 168*x^7 - 94*x^8 + 
             9*x^9 + 2*x^10)*master3l9a[x])/(81*(-9 + x^2)*(-1 + x^2)^5) + 
          (185904 + x^5*(728478 - 408768*Zeta[3]) + 
            x^6*(2738996 - 51072*Zeta[3]) + x^11*(169 - 576*Zeta[3]) - 
            63936*Zeta[3] + 152*x^8*(-4771 + 40*Zeta[3]) - 
            2*x^12*(2173 + 64*Zeta[3]) + 8*x^10*(11447 + 192*Zeta[3]) + 
            27*x*(-131299 + 1600*Zeta[3]) - 6*x^7*(-1999 + 9696*Zeta[3]) + 
            x^9*(-205 + 16128*Zeta[3]) - 2*x^4*(1947983 + 182208*Zeta[3]) + 
            x^3*(-5420643 + 408192*Zeta[3]) + x^2*(-4358332 + 
              471936*Zeta[3]))/(3888*(-9 + x^2)*(-1 + x^2)^5)) + 
        NM*(lm^2/36 + ((4*Pi^2*(-1 + x^2)^4*(-2 - 9*x + 16*x^2 + 81*x^3 + 18*
                x^4) + 3*(-152 - 684*x + 3820*x^2 + 10858*x^3 - 20114*x^4 - 
               40409*x^5 + 11216*x^6 - 193583*x^7 - 56946*x^8 - 241539*x^9 - 
               439264*x^10 - 167859*x^11 + 42048*x^12))*HPL[{0}, x])/
           (972*(-1 + x^2)^5*(-1 + 9*x^2)) + ((8 + 36*x + 8*x^2)*
            HPL[{-2, 0}, x])/(81 - 81*x^2) + 
          ((24 + 108*x - 416*x^2 - 1230*x^3 - 1338*x^4 - 4431*x^5 + 
             27072*x^6 + 95535*x^7 - 61168*x^8 + 130923*x^9 + 306360*x^10 + 
             112023*x^11 - 28998*x^12)*HPL[{0, 0}, x])/(81*(-1 + x^2)^5*
            (-1 + 9*x^2)) + lm*((6 + 63*x + 66*x^2 + 63*x^3 + 6*x^4 + 
              Pi^2*(2 + 9*x - 9*x^3 - 2*x^4))/(486*(-1 + x^2)^2) + 
            (x^2*(4 + 48*x + 31*x^2 - 9*x^4)*HPL[{0}, x])/(81*(-1 + x^2)^3) + 
            (2*(2 + 9*x + 2*x^2)*HPL[{-1, 0}, x])/(81*(-1 + x^2)) - 
            (4*x^3*(54 + 54*x + 27*x^2 - 4*x^3 + 9*x^4 + 2*x^5)*
              HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + ((4 + 18*x + 4*x^2)*
              HPL[{1, 0}, x])/(81 - 81*x^2)) + (4*(2 + 9*x + 2*x^2)*
            HPL[{2, 0}, x])/(81*(-1 + x^2)) + 
          ((24 + 114*x - 300*x^2 - 44*x^3 + 706*x^4 + 958*x^5 - 50*x^6)*
            HPL[{-1, 0, 0}, x])/(81*(-1 + x)^4*(1 + x)^2) + 
          (4*(-2 - 9*x - 40*x^2 - 9*x^3 + 1894*x^4 + 3129*x^5 - 14812*x^6 - 
             21633*x^7 + 42408*x^8 - 56856*x^9 - 131600*x^10 - 48654*x^11 + 
             12168*x^12)*HPL[{0, 0, 0}, x])/(81*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          (2*(-12 - 51*x - 66*x^2 - 238*x^3 - 395*x^4 - 217*x^5 + 79*x^6)*
            HPL[{1, 0, 0}, x])/(81*(-1 + x)^2*(1 + x)^4) - 
          ((4 + 18*x - 110*x^2 - 303*x^3 + 792*x^4 + 1431*x^5 - 2286*x^6 + 
             2871*x^7 + 6984*x^8 + 2511*x^9 - 648*x^10)*master3l8b[x])/
           (243*x^2*(-1 + x^2)^5*(-1 + 9*x^2)) - 
          ((2 + 9*x - 94*x^2 - 168*x^3 + 1014*x^4 + 750*x^5 - 4770*x^6 + 
             2232*x^7 + 13968*x^8 + 10233*x^9 - 648*x^10)*master3l9b[x])/
           (243*x^2*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          (-60 - 270*x + x^9*(1785348 - 408768*Zeta[3]) + 
            x^10*(967814 - 364416*Zeta[3]) + x^3*(9529 - 576*Zeta[3]) - 
            2*x^2*(283 + 64*Zeta[3]) + 64*x^6*(-2063 + 95*Zeta[3]) + 
            16*x^4*(1051 + 96*Zeta[3]) - 576*x^14*(116 + 111*Zeta[3]) + 
            27*x^13*(16511 + 1600*Zeta[3]) - 8*x^8*(-53227 + 6384*Zeta[3]) - 
            6*x^7*(-39919 + 9696*Zeta[3]) + x^5*(-99835 + 16128*Zeta[3]) + 
            x^11*(361677 + 408192*Zeta[3]) + x^12*(778148 + 471936*Zeta[3]))/
           (3888*x^2*(-1 + x^2)^5*(-1 + 9*x^2)))) + 
      CA*CF*((-11*lm^2)/72 - (Pi^2*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{-2}, x])/(81*(-1 + x^2)^2) + 
        (Pi^2*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{2}, x])/
         (81*(-1 + x^2)^2) + (x*(45 - 153*x^2 - 144*x^3 + 645*x^4 + 408*x^5 - 
           381*x^6 - 412*x^7 + 108*x^8 + 192*x^9 + 12*x^10 - 40*x^11 - 
           16*x^12)*HPL[{-2, 0}, x])/(81*(-1 + x^2)^4) + 
        ((48 + 120*x + 36*x^2 - 2*(509 + 6*Pi^2)*x^3 - (2819 + 54*Pi^2)*x^4 + 
           (892 - 48*Pi^2)*x^5 + 4690*x^6 + (892 + 48*Pi^2)*x^7 + 
           (-2819 + 54*Pi^2)*x^8 + 2*(-509 + 6*Pi^2)*x^9 + 36*x^10 + 
           120*x^11 + 48*x^12)*HPL[{-1, 0}, x])/(486*x^3*(-1 + x^2)^3) - 
        (x*(-7290 - 10692*x - 171099*x^2 - 84645*x^3 + 1875594*x^4 + 
           1661100*x^5 + 1481856*x^6 + 4364912*x^7 + 3930232*x^8 - 
           922636*x^9 - 454773*x^10 + 26985*x^11 - 8088*x^12 + 2160*x^13 + 
           864*x^14)*HPL[{0, 0}, x])/(486*(-1 + x^2)^4*(9 - 82*x^2 + 
           9*x^4)) - ((48 + 120*x + 36*x^2 - 2*(509 + 6*Pi^2)*x^3 - 
           (2819 + 54*Pi^2)*x^4 + (892 - 48*Pi^2)*x^5 + 4690*x^6 + 
           (892 + 48*Pi^2)*x^7 + (-2819 + 54*Pi^2)*x^8 + 2*(-509 + 6*Pi^2)*
            x^9 + 36*x^10 + 120*x^11 + 48*x^12)*HPL[{1, 0}, x])/
         (486*x^3*(-1 + x^2)^3) + lm*((11*Pi^2*(-2 - 9*x + 9*x^3 + 2*x^4) - 
            3*(139 + 231*x + 8*x^2 + 231*x^3 + 139*x^4))/(972*(-1 + x^2)^2) + 
          (11*x^2*(-4 - 48*x - 31*x^2 + 9*x^4)*HPL[{0}, x])/
           (162*(-1 + x^2)^3) - (11*(2 + 9*x + 2*x^2)*HPL[{-1, 0}, x])/
           (81*(-1 + x^2)) + (22*x^3*(54 + 54*x + 27*x^2 - 4*x^3 + 9*x^4 + 
             2*x^5)*HPL[{0, 0}, x])/(81*(-1 + x^2)^4) + 
          (11*(2 + 9*x + 2*x^2)*HPL[{1, 0}, x])/(81*(-1 + x^2))) + 
        (x*(-45 + 153*x^2 + 144*x^3 - 645*x^4 - 408*x^5 + 381*x^6 + 412*x^7 - 
           108*x^8 - 192*x^9 - 12*x^10 + 40*x^11 + 16*x^12)*HPL[{2, 0}, x])/
         (81*(-1 + x^2)^4) + (4*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{-2, -1, 0}, x])/(27*(-1 + x^2)^2) - 
        (16*x^2*(5 + 9*x + 2*x^2)*HPL[{-2, 0, 0}, x])/(27*(-1 + x^2)^2) - 
        (4*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{-2, 1, 0}, x])/
         (27*(-1 + x^2)^2) - (4*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{-1, -2, 0}, x])/(27*(-1 + x^2)^2) + 
        (2*(4 + 10*x + 9*x^2 - 18*x^3 - 12*x^4 + 30*x^5 + 97*x^6 + 30*x^7 - 
           12*x^8 - 18*x^9 + 9*x^10 + 10*x^11 + 4*x^12)*HPL[{-1, -1, 0}, x])/
         (81*x^5*(-1 + x^2)) - (2*(57 - 124*x - 115*x^2 + 496*x^3 - 103*x^4 - 
           250*x^5 + 137*x^6 + 80*x^7 - 56*x^8 - 22*x^9 + 4*x^10 + 8*x^11)*
          HPL[{-1, 0, 0}, x])/(81*(-1 + x)^4*(1 + x)^2) - 
        (2*(4 + 10*x + 9*x^2 - 18*x^3 - 12*x^4 + 30*x^5 + 97*x^6 + 30*x^7 - 
           12*x^8 - 18*x^9 + 9*x^10 + 10*x^11 + 4*x^12)*HPL[{-1, 1, 0}, x])/
         (81*x^5*(-1 + x^2)) + (4*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{-1, 2, 0}, x])/(27*(-1 + x^2)^2) + 
        (x*(-405 - 1512*x - 37647*x^2 - 5466*x^3 + 328662*x^4 + 79644*x^5 + 
           244398*x^6 + 1329128*x^7 + 945199*x^8 - 367284*x^9 - 91215*x^10 + 
           56130*x^11 + 312*x^12 - 10016*x^13 - 2840*x^14 + 720*x^15 + 
           288*x^16)*HPL[{0, 0, 0}, x])/(81*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4)) + (4*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{1, -2, 0}, x])/(27*(-1 + x^2)^2) - 
        (2*(4 + 10*x + 9*x^2 - 18*x^3 - 12*x^4 + 30*x^5 + 97*x^6 + 30*x^7 - 
           12*x^8 - 18*x^9 + 9*x^10 + 10*x^11 + 4*x^12)*HPL[{1, -1, 0}, x])/
         (81*x^5*(-1 + x^2)) + (2*(57 + 152*x + 157*x^2 + 128*x^3 + 249*x^4 + 
           234*x^5 - 31*x^6 - 144*x^7 - 16*x^8 + 58*x^9 + 36*x^10 + 8*x^11)*
          HPL[{1, 0, 0}, x])/(81*(-1 + x)^2*(1 + x)^4) + 
        (2*(4 + 10*x + 9*x^2 - 18*x^3 - 12*x^4 + 30*x^5 + 97*x^6 + 30*x^7 - 
           12*x^8 - 18*x^9 + 9*x^10 + 10*x^11 + 4*x^12)*HPL[{1, 1, 0}, x])/
         (81*x^5*(-1 + x^2)) - (4*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{1, 2, 0}, x])/(27*(-1 + x^2)^2) - 
        (4*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{2, -1, 0}, x])/
         (27*(-1 + x^2)^2) + (16*x^2*(5 + 9*x + 2*x^2)*HPL[{2, 0, 0}, x])/
         (27*(-1 + x^2)^2) + (4*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{2, 1, 0}, x])/(27*(-1 + x^2)^2) + 
        (8*(2 + 9*x + 2*x^2)*HPL[{-1, 0, 0, 0}, x])/(27*(-1 + x^2)) - 
        (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{-1, 1, 0, 0}, x])/
         (27*(-1 + x^2)^2) - (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{1, -1, 0, 0}, x])/(27*(-1 + x^2)^2) - 
        (8*(2 + 9*x + 2*x^2)*HPL[{1, 0, 0, 0}, x])/(27*(-1 + x^2)) + 
        ((-4 + 13*x + 22*x^2 + 9*x^3 - 4*x^4 + 4*x^5)*master3l10a[x])/
         (54*(-1 + x^2)^3) + (x*(-4 + 4*x - 9*x^2 - 22*x^3 - 13*x^4 + 4*x^5)*
          master3l10b[x])/(54*(-1 + x^2)^3) + 
        ((729 - 9*x - 1005*x^2 + 888*x^3 + 429*x^4 - 95*x^5 - 41*x^6)*
          master3l8a[x])/(324*(-9 + x^2)*(-1 + x^2)^4) - 
        ((-30 + 9*x + 223*x^2 - 233*x^3 + 102*x^4 + 2553*x^5 + 2025*x^6 - 
           297*x^7)*master3l8b[x])/(324*x*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        ((513 - 1017*x - 1779*x^2 + 393*x^3 + 331*x^4 - 159*x^5 - 25*x^6 + 
           15*x^7)*master3l9a[x])/(108*(-9 + x^2)*(-1 + x^2)^4) + 
        ((15 - 25*x - 159*x^2 + 331*x^3 + 393*x^4 - 1779*x^5 - 1017*x^6 + 
           513*x^7)*master3l9b[x])/(324*x*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        (HPL[{-1}, x]*(Pi^2*(4 + 10*x + 5*x^2 - 28*x^3 - 21*x^4 + 48*x^5 + 
             109*x^6 - 109*x^8 - 48*x^9 + 21*x^10 + 28*x^11 - 5*x^12 - 
             10*x^13 - 4*x^14) - 72*x^5*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
            Zeta[3]))/(486*x^5*(-1 + x^2)^2) + 
        (HPL[{1}, x]*(Pi^2*(-4 - 10*x - 5*x^2 + 28*x^3 + 21*x^4 - 48*x^5 - 
             109*x^6 + 109*x^8 + 48*x^9 - 21*x^10 - 28*x^11 + 5*x^12 + 
             10*x^13 + 4*x^14) + 72*x^5*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
            Zeta[3]))/(486*x^5*(-1 + x^2)^2) + 
        (HPL[{0}, x]*(-864 - 2160*x - 6*(6419 + 135*Pi^2)*x^2 - 47568*x^3 + 
           3*(-186071 + 8118*Pi^2)*x^12 + 24*(36 + 13*Pi^2)*x^14 - 
           10016*Pi^2*x^15 - 2840*Pi^2*x^16 + 720*Pi^2*x^17 + 288*Pi^2*x^18 + 
           3*x^13*(37449 + 13208*Pi^2 + 7776*Zeta[3]) - 
           6*x^10*(-703355 + 12673*Pi^2 + 11664*Zeta[3]) - 
           48*x^7*(-31837 + 645*Pi^2 + 15228*Zeta[3]) - 
           16*x^11*(116523 + 4898*Pi^2 + 19116*Zeta[3]) + 
           3*x^4*(139181 + 3378*Pi^2 + 23328*Zeta[3]) + 
           x^5*(571043 + 2592*Pi^2 + 69984*Zeta[3]) - 
           8*x^6*(121780 + 4689*Pi^2 + 88452*Zeta[3]) + 
           2*x^8*(3345367 + 57696*Pi^2 + 353808*Zeta[3]) + 
           x^9*(7524610 + 76920*Pi^2 + 943488*Zeta[3])))/
         (1944*x*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4)) + 
        (24*Pi^4*x^3*(-1 + x^2)^2*(1242 + 243*x - 14142*x^2 - 3267*x^3 + 
            27944*x^4 + 9837*x^5 - 11518*x^6 - 1053*x^7 + 954*x^8) - 
          20*Pi^2*(-9 + 91*x^2 - 91*x^4 + 9*x^6)*(48 + 120*x + 36*x^2 - 
            2819*x^4 + 4690*x^6 - 2819*x^8 + 36*x^10 + 120*x^11 + 48*x^12 + 
            x^5*(892 - 2592*Log[2]^2) + 2*x^3*(-509 + 432*Log[2]^2) - 
            2*x^9*(509 + 432*Log[2]^2) + 4*x^7*(223 + 648*Log[2]^2)) - 
          15*x^2*(5211 + x^6*(4512380 - 2738688*Zeta[3]) + 
            x^2*(247308 - 244512*Zeta[3]) - 120192*x^15*Zeta[3] - 
            34080*x^16*Zeta[3] + 8640*x^17*Zeta[3] + 3456*x^18*Zeta[3] + 
            288*x^14*(-3 + 13*Zeta[3]) + 9*x*(-30839 + 1152*Log[2]^4 + 
              27648*PolyLog[4, 1/2] + 11520*Zeta[3]) + 
            3*x^12*(-61789 + 33408*Zeta[3]) + 24*x^10*(16609 + 
              39424*Zeta[3]) + 9*x^13*(3631 + 1152*Log[2]^4 + 
              27648*PolyLog[4, 1/2] + 65408*Zeta[3]) - 
            4*x^3*(-798785 + 33984*Log[2]^4 + 815616*PolyLog[4, 1/2] + 
              413712*Zeta[3]) + x^8*(11513885 + 436224*Zeta[3]) - 
            16*x^7*(-836075 + 40608*Log[2]^4 + 974592*PolyLog[4, 1/2] + 
              621912*Zeta[3]) - 4*x^11*(118585 + 33984*Log[2]^4 + 
              815616*PolyLog[4, 1/2] + 675216*Zeta[3]) + 
            3*x^4*(-1108363 + 832736*Zeta[3]) + x^5*(-7366219 + 
              450432*Log[2]^4 + 10810368*PolyLog[4, 1/2] + 7498944*Zeta[3]) + 
            x^9*(332291 + 450432*Log[2]^4 + 10810368*PolyLog[4, 1/2] + 
              8573568*Zeta[3])))/(116640*x^3*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4))) + 
      CF^2*((3*lm)/8 + (2*Pi^2*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{-2}, x])/(81*(-1 + x^2)^2) - 
        (2*Pi^2*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{2}, x])/
         (81*(-1 + x^2)^2) - (2*x*(45 - 33*x^2 - 168*x^3 + 687*x^4 + 
           564*x^5 - 757*x^6 - 846*x^7 + 589*x^8 + 699*x^9 - 167*x^10 - 
           321*x^11 - 43*x^12 + 63*x^13 + 27*x^14)*HPL[{-2, 0}, x])/
         (81*(-1 + x^2)^4) + ((108 + 252*x - 10*x^2 - 906*x^3 - 728*x^4 + 
           (1047 + 16*Pi^2)*x^5 + 2*(523 + 36*Pi^2)*x^6 + (-411 + 64*Pi^2)*
            x^7 + 560*x^8 - (411 + 64*Pi^2)*x^9 + (1046 - 72*Pi^2)*x^10 + 
           (1047 - 16*Pi^2)*x^11 - 728*x^12 - 906*x^13 - 10*x^14 + 252*x^15 + 
           108*x^16)*HPL[{-1, 0}, x])/(324*x^5*(-1 + x^2)^3) - 
        (x*(4860 + 4068*x + 57618*x^2 + 41380*x^3 - 744822*x^4 - 730006*x^5 - 
           983106*x^6 - 2848025*x^7 - 2468812*x^8 + 527226*x^9 + 
           344590*x^10 + 73599*x^11 + 4186*x^12 - 31086*x^13 - 9918*x^14 + 
           2268*x^15 + 972*x^16)*HPL[{0, 0}, x])/(162*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4)) + ((-108 - 252*x + 10*x^2 + 906*x^3 + 
           728*x^4 - (1047 + 16*Pi^2)*x^5 - 2*(523 + 36*Pi^2)*x^6 + 
           (411 - 64*Pi^2)*x^7 - 560*x^8 + (411 + 64*Pi^2)*x^9 + 
           2*(-523 + 36*Pi^2)*x^10 + (-1047 + 16*Pi^2)*x^11 + 728*x^12 + 
           906*x^13 + 10*x^14 - 252*x^15 - 108*x^16)*HPL[{1, 0}, x])/
         (324*x^5*(-1 + x^2)^3) + (2*x*(45 - 33*x^2 - 168*x^3 + 687*x^4 + 
           564*x^5 - 757*x^6 - 846*x^7 + 589*x^8 + 699*x^9 - 167*x^10 - 
           321*x^11 - 43*x^12 + 63*x^13 + 27*x^14)*HPL[{2, 0}, x])/
         (81*(-1 + x^2)^4) - (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{-2, -1, 0}, x])/(27*(-1 + x^2)^2) + 
        (16*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{-2, 0, 0}, x])/
         (27*(-1 + x^2)^2) + (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{-2, 1, 0}, x])/(27*(-1 + x^2)^2) + 
        (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{-1, -2, 0}, x])/
         (27*(-1 + x^2)^2) + ((-27 - 63*x - 65*x^2 + 69*x^3 + 69*x^4 - 
           45*x^5 - 31*x^6 + 31*x^8 + 45*x^9 - 69*x^10 - 69*x^11 + 65*x^12 + 
           63*x^13 + 27*x^14)*HPL[{-1, -1, 0}, x])/(81*x^7) - 
        (2*(-151 + 275*x + 206*x^2 - 1046*x^3 + 371*x^4 + 665*x^5 - 532*x^6 - 
           430*x^7 + 395*x^8 + 229*x^9 - 154*x^10 - 88*x^11 + 9*x^12 + 
           27*x^13)*HPL[{-1, 0, 0}, x])/(81*(-1 + x)^4*(1 + x)^2) + 
        ((27 + 63*x + 65*x^2 - 69*x^3 - 69*x^4 + 45*x^5 + 31*x^6 - 31*x^8 - 
           45*x^9 + 69*x^10 + 69*x^11 - 65*x^12 - 63*x^13 - 27*x^14)*
          HPL[{-1, 1, 0}, x])/(81*x^7) - 
        (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{-1, 2, 0}, x])/
         (27*(-1 + x^2)^2) + (2*x*(-405 - 1080*x + 21078*x^2 + 47406*x^3 - 
           138807*x^4 - 432810*x^5 - 235356*x^6 + 1453636*x^7 + 433045*x^8 - 
           1879056*x^9 - 781634*x^10 + 628766*x^11 - 42849*x^12 - 
           220758*x^13 + 32684*x^14 + 82470*x^15 + 9734*x^16 - 17244*x^17 - 
           5688*x^18 + 1134*x^19 + 486*x^20)*HPL[{0, 0, 0}, x])/
         (81*(-1 + x^2)^5*(9 - 82*x^2 + 9*x^4)) - 
        (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{1, -2, 0}, x])/
         (27*(-1 + x^2)^2) + ((27 + 63*x + 65*x^2 - 69*x^3 - 69*x^4 + 
           45*x^5 + 31*x^6 - 31*x^8 - 45*x^9 + 69*x^10 + 69*x^11 - 65*x^12 - 
           63*x^13 - 27*x^14)*HPL[{1, -1, 0}, x])/(81*x^7) + 
        (2*(-151 - 425*x - 526*x^2 - 634*x^3 - 1009*x^4 - 671*x^5 + 404*x^6 + 
           554*x^7 - 293*x^8 - 551*x^9 - 110*x^10 + 164*x^11 + 117*x^12 + 
           27*x^13)*HPL[{1, 0, 0}, x])/(81*(-1 + x)^2*(1 + x)^4) + 
        ((-27 - 63*x - 65*x^2 + 69*x^3 + 69*x^4 - 45*x^5 - 31*x^6 + 31*x^8 + 
           45*x^9 - 69*x^10 - 69*x^11 + 65*x^12 + 63*x^13 + 27*x^14)*
          HPL[{1, 1, 0}, x])/(81*x^7) + (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{1, 2, 0}, x])/(27*(-1 + x^2)^2) + 
        (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{2, -1, 0}, x])/
         (27*(-1 + x^2)^2) - (16*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{2, 0, 0}, x])/(27*(-1 + x^2)^2) - 
        (8*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{2, 1, 0}, x])/
         (27*(-1 + x^2)^2) + (16*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
          HPL[{-1, 1, 0, 0}, x])/(27*(-1 + x^2)^2) + 
        (16*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*HPL[{1, -1, 0, 0}, x])/
         (27*(-1 + x^2)^2) - ((-4 + 13*x + 22*x^2 + 9*x^3 - 4*x^4 + 4*x^5)*
          master3l10a[x])/(27*(-1 + x^2)^3) + 
        (x*(4 - 4*x + 9*x^2 + 22*x^3 + 13*x^4 - 4*x^5)*master3l10b[x])/
         (27*(-1 + x^2)^3) + ((-729 + 9*x + 1005*x^2 - 888*x^3 - 429*x^4 + 
           95*x^5 + 41*x^6)*master3l8a[x])/(162*(-9 + x^2)*(-1 + x^2)^4) + 
        ((-30 + 9*x + 223*x^2 - 233*x^3 + 102*x^4 + 2553*x^5 + 2025*x^6 - 
           297*x^7)*master3l8b[x])/(162*x*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        ((-513 + 1017*x + 1779*x^2 - 393*x^3 - 331*x^4 + 159*x^5 + 25*x^6 - 
           15*x^7)*master3l9a[x])/(54*(-9 + x^2)*(-1 + x^2)^4) + 
        ((-15 + 25*x + 159*x^2 - 331*x^3 - 393*x^4 + 1779*x^5 + 1017*x^6 - 
           513*x^7)*master3l9b[x])/(162*x*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(27 + 63*x + 92*x^2 - 6*x^3 + 
             23*x^4 + 39*x^5 + 54*x^6 + 39*x^7 + 23*x^8 - 6*x^9 + 92*x^10 + 
             63*x^11 + 27*x^12) - 288*x^7*(2 + 9*x + 10*x^2 + 9*x^3 + 2*x^4)*
            Zeta[3]))/(972*x^7*(-1 + x^2)^2) + 
        (HPL[{-1}, x]*(-(Pi^2*(-1 + x^2)^3*(27 + 63*x + 92*x^2 - 6*x^3 + 
              23*x^4 + 39*x^5 + 54*x^6 + 39*x^7 + 23*x^8 - 6*x^9 + 92*x^10 + 
              63*x^11 + 27*x^12)) + 288*x^7*(2 + 9*x + 10*x^2 + 9*x^3 + 
             2*x^4)*Zeta[3]))/(972*x^7*(-1 + x^2)^2) + 
        (HPL[{0}, x]*(-2916 - 6804*x + 28296*x^2 + 89856*x^3 + 
           3*(31229 + 540*Pi^2)*x^4 - 120195*x^5 + (1149663 - 226456*Pi^2)*
            x^14 + 8*(-3537 + 9304*Pi^2)*x^16 + 84*(81 + 1580*Pi^2)*x^17 + 
           4*(729 + 2266*Pi^2)*x^18 - 32220*Pi^2*x^19 - 10404*Pi^2*x^20 + 
           2268*Pi^2*x^21 + 972*Pi^2*x^22 - 12*x^15*(24444 + 22607*Pi^2 + 
             3888*Zeta[3]) - 9*x^6*(100177 + 1772*Pi^2 + 15552*Zeta[3]) - 
           6*x^7*(197357 + 1008*Pi^2 + 23328*Zeta[3]) + 
           9*x^13*(420471 + 35884*Pi^2 + 67968*Zeta[3]) + 
           12*x^9*(-246777 + 6284*Pi^2 + 121824*Zeta[3]) + 
           x^12*(-8878257 + 294232*Pi^2 + 139968*Zeta[3]) + 
           6*x^8*(131217 + 6196*Pi^2 + 235872*Zeta[3]) - 
           6*x^10*(1960947 + 42296*Pi^2 + 235872*Zeta[3]) - 
           6*x^11*(2493211 + 36916*Pi^2 + 314496*Zeta[3])))/
         (1944*x^3*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4)) - 
        (32*Pi^4*x^5*(-1 + x^2)^2*(1098 - 405*x - 12830*x^2 + 3285*x^3 + 
            27944*x^4 + 3285*x^5 - 12830*x^6 - 405*x^7 + 1098*x^8) + 
          20*Pi^2*(-9 + 91*x^2 - 91*x^4 + 9*x^6)*(108 + 252*x - 10*x^2 - 
            906*x^3 - 728*x^4 + 1046*x^6 + 560*x^8 + 1046*x^10 - 728*x^12 - 
            906*x^13 - 10*x^14 + 252*x^15 + 108*x^16 - 
            3*x^5*(-349 + 384*Log[2]^2) + 3*x^11*(349 + 384*Log[2]^2) - 
            3*x^9*(137 + 1152*Log[2]^2) + x^7*(-411 + 3456*Log[2]^2)) + 
          5*x^2*(-5832 - 13608*x + 34236*x^2 + x^6*(5386276 - 
              6573600*Zeta[3]) + x^14*(1501212 - 4818048*Zeta[3]) - 
            773280*x^19*Zeta[3] - 249696*x^20*Zeta[3] + 54432*x^21*Zeta[3] + 
            23328*x^22*Zeta[3] + 504*x^17*(-27 + 6320*Zeta[3]) + 
            24*x^18*(-243 + 9064*Zeta[3]) + 64*x^12*(-148571 + 
              13605*Zeta[3]) + 48*x^4*(-4781 + 13662*Zeta[3]) - 
            36*x^10*(1081957 + 23568*Zeta[3]) + 144*x^8*(-76003 + 
              42600*Zeta[3]) - 9*x^3*(-126455 + 4608*Log[2]^4 + 
              110592*PolyLog[4, 1/2] + 62496*Zeta[3]) + 
            24*x^16*(2439 + 74432*Zeta[3]) - 9*x^15*(11425 + 4608*Log[2]^4 + 
              110592*PolyLog[4, 1/2] + 785920*Zeta[3]) + 
            12*x^9*(-2262319 + 216576*Log[2]^4 + 5197824*PolyLog[4, 1/2] + 
              3610528*Zeta[3]) + 2*x^5*(-5258119 + 271872*Log[2]^4 + 
              6524928*PolyLog[4, 1/2] + 4146480*Zeta[3]) + 
            2*x^13*(2080841 + 271872*Log[2]^4 + 6524928*PolyLog[4, 1/2] + 
              8021952*Zeta[3]) - 3*x^7*(-4668595 + 600576*Log[2]^4 + 
              14413824*PolyLog[4, 1/2] + 11145152*Zeta[3]) - 
            3*x^11*(5596085 + 600576*Log[2]^4 + 14413824*PolyLog[4, 1/2] + 
              12868736*Zeta[3])))/(77760*x^5*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4))))
 
CbarData["a", 2, 1] = 
    NC*(CA*CF*((Pi^2*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 12*x^5 + 9*x^6)*
          HPL[{-2}, x])/(324*(-1 + x^2)^4) + 
        lm^2*((-11*(3 - 4*x - 21*x^2 - 40*x^3 - 21*x^4 - 4*x^5 + 3*x^6))/
           (288*(-1 + x^2)^4) - (11*x^3*(2 + 3*x + 2*x^2)*HPL[{0}, x])/
           (12*(-1 + x^2)^5)) + (Pi^2*(-9 + 12*x + 91*x^2 + 168*x^3 + 
           91*x^4 + 12*x^5 - 9*x^6)*HPL[{2}, x])/(324*(-1 + x^2)^4) + 
        (x*(237 + 653*x + 342*x^2 - 2627*x^3 + 10926*x^4 + 13653*x^5 - 
           3714*x^6 - 12905*x^7 + 6138*x^8 + 9991*x^9 - 3636*x^10 - 
           5782*x^11 + 508*x^12 + 2042*x^13 + 388*x^14 - 315*x^15 - 135*x^16)*
          HPL[{-2, 0}, x])/(648*(-1 + x^2)^6) + 
        ((1620 + 3780*x - 2226*x^2 - 18834*x^3 - 10110*x^4 + 
           (50827 + 432*Pi^2)*x^5 - 16*(901 + 36*Pi^2)*x^6 - 
           16*(8741 + 300*Pi^2)*x^7 - 8*(5149 + 936*Pi^2)*x^8 + 151646*x^9 + 
           8*(-5149 + 936*Pi^2)*x^10 + 16*(-8741 + 300*Pi^2)*x^11 + 
           16*(-901 + 36*Pi^2)*x^12 + (50827 - 432*Pi^2)*x^13 - 10110*x^14 - 
           18834*x^15 - 2226*x^16 + 3780*x^17 + 1620*x^18)*HPL[{-1, 0}, x])/
         (15552*x^5*(-1 + x^2)^5) + (x*(691092 + 2541780*x + 22315662*x^2 + 
           2977857*x^3 - 488417472*x^4 - 679367181*x^5 + 1325077662*x^6 + 
           2887391724*x^7 + 4800441492*x^8 + 8768691812*x^9 + 
           18749220934*x^10 + 10454311599*x^11 - 624638642*x^12 - 
           3856727449*x^13 - 536442282*x^14 + 573618462*x^15 + 
           63331428*x^16 - 73746126*x^17 - 16193412*x^18 + 7411014*x^19 + 
           2702646*x^20 - 306180*x^21 - 131220*x^22)*HPL[{0, 0}, x])/
         (7776*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        ((-1620 - 3780*x + 2226*x^2 + 18834*x^3 + 10110*x^4 - 
           (50827 + 432*Pi^2)*x^5 + 16*(901 + 36*Pi^2)*x^6 + 
           16*(8741 + 300*Pi^2)*x^7 + 8*(5149 + 936*Pi^2)*x^8 - 151646*x^9 - 
           8*(-5149 + 936*Pi^2)*x^10 - 16*(-8741 + 300*Pi^2)*x^11 - 
           16*(-901 + 36*Pi^2)*x^12 + (-50827 + 432*Pi^2)*x^13 + 10110*x^14 + 
           18834*x^15 + 2226*x^16 - 3780*x^17 - 1620*x^18)*HPL[{1, 0}, x])/
         (15552*x^5*(-1 + x^2)^5) + 
        lm*((-7515 + 1440*x + 35907*x^2 + 74592*x^3 + 35907*x^4 + 1440*x^5 - 
            7515*x^6 - 44*Pi^2*(-9 + 12*x + 41*x^2 - 41*x^4 - 12*x^5 + 
              9*x^6))/(15552*(-1 + x^2)^4) + 
          (x^2*(198 - 8310*x - 12839*x^2 - 11874*x^3 - 2178*x^4 - 396*x^5 + 
             297*x^6)*HPL[{0}, x])/(648*(-1 + x^2)^5) + 
          (11*(9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*HPL[{-1, 0}, x])/
           (324*(-1 + x^2)^3) + (11*x^3*(216 + 324*x + 648*x^2 + 516*x^3 + 
             408*x^4 + 59*x^5 + 12*x^6 - 9*x^7)*HPL[{0, 0}, x])/
           (162*(-1 + x^2)^6) - (11*(9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*
            HPL[{1, 0}, x])/(324*(-1 + x^2)^3)) + 
        (x*(-237 - 653*x - 342*x^2 + 2627*x^3 - 10926*x^4 - 13653*x^5 + 
           3714*x^6 + 12905*x^7 - 6138*x^8 - 9991*x^9 + 3636*x^10 + 
           5782*x^11 - 508*x^12 - 2042*x^13 - 388*x^14 + 315*x^15 + 135*x^16)*
          HPL[{2, 0}, x])/(648*(-1 + x^2)^6) + 
        ((-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{-2, -1, 0}, x])/(27*(-1 + x^2)^4) + 
        (4*x^2*(-25 - 84*x - 66*x^2 - 12*x^3 + 9*x^4)*HPL[{-2, 0, 0}, x])/
         (27*(-1 + x^2)^4) - ((-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 
           12*x^5 - 9*x^6)*HPL[{-2, 1, 0}, x])/(27*(-1 + x^2)^4) - 
        ((-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{-1, -2, 0}, x])/(27*(-1 + x^2)^4) + 
        ((135 + 315*x + 17*x^2 - 1097*x^3 - 862*x^4 + 1546*x^5 + 1134*x^6 - 
           2143*x^7 + 632*x^8 + 3990*x^9 + 632*x^10 - 2143*x^11 + 1134*x^12 + 
           1546*x^13 - 862*x^14 - 1097*x^15 + 17*x^16 + 315*x^17 + 135*x^18)*
          HPL[{-1, -1, 0}, x])/(1296*x^7*(-1 + x^2)^3) - 
        ((607 + 885*x - 1081*x^2 + 3865*x^3 + 2485*x^4 - 2743*x^5 + 
           1663*x^6 + 7117*x^7 - 3639*x^8 - 4169*x^9 + 2989*x^10 + 
           1827*x^11 - 861*x^12 - 613*x^13 + 45*x^14 + 135*x^15)*
          HPL[{-1, 0, 0}, x])/(648*(-1 + x)^6*(1 + x)^4) - 
        ((135 + 315*x + 17*x^2 - 1097*x^3 - 862*x^4 + 1546*x^5 + 1134*x^6 - 
           2143*x^7 + 632*x^8 + 3990*x^9 + 632*x^10 - 2143*x^11 + 1134*x^12 + 
           1546*x^13 - 862*x^14 - 1097*x^15 + 17*x^16 + 315*x^17 + 135*x^18)*
          HPL[{-1, 1, 0}, x])/(1296*x^7*(-1 + x^2)^3) + 
        ((-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{-1, 2, 0}, x])/(27*(-1 + x^2)^4) + 
        (x*(-19197 - 35397*x - 2323026*x^2 - 3299499*x^3 + 37904334*x^4 + 
           59164897*x^5 - 75611898*x^6 - 111515963*x^7 - 345395808*x^8 - 
           1029716517*x^9 - 2019841118*x^10 - 1070436685*x^11 - 
           114698222*x^12 + 233298519*x^13 + 151335162*x^14 + 75392045*x^15 - 
           23546141*x^16 - 46441042*x^17 - 3653408*x^18 + 11302848*x^19 + 
           2922300*x^20 - 1260684*x^21 - 461376*x^22 + 51030*x^23 + 
           21870*x^24)*HPL[{0, 0, 0}, x])/(648*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) + ((-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 
           12*x^5 - 9*x^6)*HPL[{1, -2, 0}, x])/(27*(-1 + x^2)^4) - 
        ((135 + 315*x + 17*x^2 - 1097*x^3 - 862*x^4 + 1546*x^5 + 1134*x^6 - 
           2143*x^7 + 632*x^8 + 3990*x^9 + 632*x^10 - 2143*x^11 + 1134*x^12 + 
           1546*x^13 - 862*x^14 - 1097*x^15 + 17*x^16 + 315*x^17 + 135*x^18)*
          HPL[{1, -1, 0}, x])/(1296*x^7*(-1 + x^2)^3) + 
        ((607 + 2449*x + 6739*x^2 + 16113*x^3 + 24253*x^4 + 19605*x^5 + 
           3251*x^6 - 2907*x^7 + 4345*x^8 + 6403*x^9 - 527*x^10 - 3821*x^11 - 
           1333*x^12 + 647*x^13 + 585*x^14 + 135*x^15)*HPL[{1, 0, 0}, x])/
         (648*(-1 + x)^4*(1 + x)^6) + ((135 + 315*x + 17*x^2 - 1097*x^3 - 
           862*x^4 + 1546*x^5 + 1134*x^6 - 2143*x^7 + 632*x^8 + 3990*x^9 + 
           632*x^10 - 2143*x^11 + 1134*x^12 + 1546*x^13 - 862*x^14 - 
           1097*x^15 + 17*x^16 + 315*x^17 + 135*x^18)*HPL[{1, 1, 0}, x])/
         (1296*x^7*(-1 + x^2)^3) - ((-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 
           12*x^5 - 9*x^6)*HPL[{1, 2, 0}, x])/(27*(-1 + x^2)^4) - 
        ((-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{2, -1, 0}, x])/(27*(-1 + x^2)^4) + 
        (4*x^2*(25 + 84*x + 66*x^2 + 12*x^3 - 9*x^4)*HPL[{2, 0, 0}, x])/
         (27*(-1 + x^2)^4) + ((-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 
           12*x^5 - 9*x^6)*HPL[{2, 1, 0}, x])/(27*(-1 + x^2)^4) - 
        (2*(9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*HPL[{-1, 0, 0, 0}, x])/
         (27*(-1 + x^2)^3) + (2*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 
           12*x^5 + 9*x^6)*HPL[{-1, 1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        (2*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 12*x^5 + 9*x^6)*
          HPL[{1, -1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        (2*(9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*HPL[{1, 0, 0, 0}, x])/
         (27*(-1 + x^2)^3) + ((-18 + 41*x + 167*x^2 + 475*x^3 + 364*x^4 + 
           163*x^5 - 33*x^6 + 17*x^7)*master3l10a[x])/(432*(-1 + x^2)^5) + 
        (x*(-17 + 33*x - 163*x^2 - 364*x^3 - 475*x^4 - 167*x^5 - 41*x^6 + 
           18*x^7)*master3l10b[x])/(432*(-1 + x^2)^5) - 
        ((37341 + 102897*x + 31860*x^2 + 3816*x^3 + 28278*x^4 + 83922*x^5 - 
           3916*x^6 - 19744*x^7 - 1003*x^8 + 1141*x^9 + 112*x^10)*
          master3l8a[x])/(2592*(-9 + x^2)^2*(-1 + x^2)^6) - 
        ((474 + 754*x - 8031*x^2 - 13071*x^3 + 35748*x^4 + 11232*x^5 - 
           160038*x^6 + 290070*x^7 + 1260954*x^8 + 998838*x^9 + 339309*x^10 - 
           59535*x^11)*master3l8b[x])/(7776*x*(1 - 9*x^2)^2*(-1 + x^2)^6) - 
        ((-9531 + 1701*x + 49122*x^2 + 69606*x^3 + 16860*x^4 - 15144*x^5 + 
           3150*x^6 + 3594*x^7 - 209*x^8 - 237*x^9)*master3l9a[x])/
         (2592*(-9 + x^2)*(-1 + x^2)^6) - 
        ((-237 - 209*x + 3594*x^2 + 3150*x^3 - 15144*x^4 + 16860*x^5 + 
           69606*x^6 + 49122*x^7 + 1701*x^8 - 9531*x^9)*master3l9b[x])/
         (7776*x*(-1 + x^2)^6*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(-135 - 315*x + 118*x^2 + 1412*x^3 + 879*x^4 - 
             2643*x^5 - 1996*x^6 + 3689*x^7 + 502*x^8 - 6133*x^9 + 
             6133*x^11 - 502*x^12 - 3689*x^13 + 1996*x^14 + 2643*x^15 - 
             879*x^16 - 1412*x^17 - 118*x^18 + 315*x^19 + 135*x^20) - 
           576*x^7*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 12*x^5 + 9*x^6)*
            Zeta[3]))/(15552*x^7*(-1 + x^2)^4) + 
        (HPL[{-1}, x]*(Pi^2*(135 + 315*x - 118*x^2 - 1412*x^3 - 879*x^4 + 
             2643*x^5 + 1996*x^6 - 3689*x^7 - 502*x^8 + 6133*x^9 - 
             6133*x^11 + 502*x^12 + 3689*x^13 - 1996*x^14 - 2643*x^15 + 
             879*x^16 + 1412*x^17 + 118*x^18 - 315*x^19 - 135*x^20) + 
           576*x^7*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 12*x^5 + 9*x^6)*
            Zeta[3]))/(15552*x^7*(-1 + x^2)^4) + 
        (HPL[{0}, x]*(-131220 - 306180*x + 2637036*x^2 + 7257924*x^3 - 
           27*(713435 + 2844*Pi^2)*x^4 - 81*(996919 + 2612*Pi^2)*x^5 - 
           18*(372132793 + 17939974*Pi^2)*x^12 + 
           8*(-50562873 + 29323190*Pi^2)*x^19 - (47817405 + 35113516*Pi^2)*
            x^20 + (7194501 - 95478620*Pi^2)*x^21 - 4*(659259 + 1826704*Pi^2)*
            x^22 + 108*(2835 + 209312*Pi^2)*x^23 + 180*(729 + 32470*Pi^2)*
            x^24 - 2521368*Pi^2*x^25 - 922752*Pi^2*x^26 + 102060*Pi^2*x^27 + 
           43740*Pi^2*x^28 + x^14*(-31272679562 + 204111528*Pi^2 - 
             846650880*Zeta[3]) + 6*x^18*(119412331 + 23410932*Pi^2 - 
             1679616*Zeta[3]) + 12*x^7*(54569765 + 392205*Pi^2 + 
             1259712*Zeta[3]) + 6*x^6*(16926221 + 214740*Pi^2 + 
             1679616*Zeta[3]) - 4*x^17*(-1093420074 + 97651333*Pi^2 + 
             3779136*Zeta[3]) - 12*x^8*(49261735 + 670732*Pi^2 + 
             15303168*Zeta[3]) - 4*x^9*(761133737 + 9479903*Pi^2 + 
             72643392*Zeta[3]) + 4*x^15*(-2835103570 + 124443503*Pi^2 + 
             72643392*Zeta[3]) + 10*x^10*(269946041 + 5768964*Pi^2 + 
             84665088*Zeta[3]) + x^16*(2040367404 - 216164088*Pi^2 + 
             183638016*Zeta[3]) + 4*x^11*(1623803795 + 40250483*Pi^2 + 
             390137472*Zeta[3]) - 2*x^13*(11649268015 + 235603908*Pi^2 + 
             780274944*Zeta[3])))/(31104*x^3*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) + 
        (192*Pi^4*x^5*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(-27 + 36*x - 127*x^2 - 
            840*x^3 - 783*x^4 - 156*x^5 + 117*x^6) - 
          20*Pi^2*(9 - 82*x^2 + 9*x^4)^2*(-1620 - 3780*x + 3846*x^2 + 
            22614*x^3 + 7884*x^4 - 69661*x^5 + 4306*x^6 + 190683*x^7 + 
            26776*x^8 - 291502*x^9 + 291502*x^11 - 26776*x^12 - 190683*x^13 - 
            4306*x^14 + 69661*x^15 - 7884*x^16 - 22614*x^17 - 3846*x^18 + 
            3780*x^19 + 1620*x^20) - 15*x^2*(-262440 - 612360*x + 
            6513372*x^2 + x^17*(6571071712 - 5695154496*Zeta[3]) + 
            x^21*(40888719 - 2283547584*Zeta[3]) - 60512832*x^25*Zeta[3] - 
            22146048*x^26*Zeta[3] + 2449440*x^27*Zeta[3] + 
            1049760*x^28*Zeta[3] + 1080*x^24*(-243 + 129880*Zeta[3]) + 
            81*x^3*(-308681 + 136032*Zeta[3]) + 576*x^8*(-4834897 + 
              209683*Zeta[3]) + 648*x^23*(-945 + 837248*Zeta[3]) - 
            54*x^4*(2063963 + 858384*Zeta[3]) - 48*x^22*(-111699 + 
              3653408*Zeta[3]) - 320*x^15*(32888314 + 7363999*Zeta[3]) - 
            576*x^16*(-16189023 + 7596044*Zeta[3]) - 
            78*x^20*(985599 + 11322160*Zeta[3]) + 24*x^6*(44166181 + 
              26476848*Zeta[3]) - 9*x^5*(-64758355 + 43345344*Zeta[3]) + 
            32*x^7*(-85793689 + 139597266*Zeta[3]) + 
            33*x^19*(-25772925 + 161252128*Zeta[3]) - 
            64*x^9*(-29820655 + 278960516*Zeta[3]) + 
            12*x^18*(8455727 + 324389088*Zeta[3]) - 
            16*x^10*(66993491 + 1354138632*Zeta[3]) - 
            8*x^14*(6333169117 + 2364596496*Zeta[3]) - 
            2*x^13*(24123535753 + 4162244096*Zeta[3]) + 
            2*x^11*(-7081057873 + 5951018992*Zeta[3]) + 
            4*x^12*(-11419095443 + 7061259672*Zeta[3])))/
         (3732480*x^5*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF^2*((Pi^2*(-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{-2}, x])/(162*(-1 + x^2)^4) + 
        lm^2*(-(-3 + 4*x + 21*x^2 + 40*x^3 + 21*x^4 + 4*x^5 - 3*x^6)/
           (16*(-1 + x^2)^4) + (3*x^3*(2 + 3*x + 2*x^2)*HPL[{0}, x])/
           (2*(-1 + x^2)^5)) + (Pi^2*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 
           12*x^5 + 9*x^6)*HPL[{2}, x])/(162*(-1 + x^2)^4) - 
        (x*(237 + 653*x + 2574*x^2 - 1343*x^3 + 13422*x^4 + 16729*x^5 - 
           12850*x^6 - 25229*x^7 + 26902*x^8 + 33433*x^9 - 25170*x^10 - 
           31124*x^11 + 12054*x^12 + 18780*x^13 - 1010*x^14 - 6489*x^15 - 
           1431*x^16 + 972*x^17 + 432*x^18)*HPL[{-2, 0}, x])/
         (324*(-1 + x^2)^6) + ((25920 + 58320*x - 46980*x^2 - 301860*x^3 - 
           141870*x^4 + 649710*x^5 + 528930*x^6 - (760111 + 2160*Pi^2)*x^7 + 
           10*(-63113 + 288*Pi^2)*x^8 + 12*(44447 + 2000*Pi^2)*x^9 + 
           10*(71993 + 3744*Pi^2)*x^10 + 24074*x^11 + (719930 - 37440*Pi^2)*
            x^12 + (533364 - 24000*Pi^2)*x^13 - 10*(63113 + 288*Pi^2)*x^14 + 
           (-760111 + 2160*Pi^2)*x^15 + 528930*x^16 + 649710*x^17 - 
           141870*x^18 - 301860*x^19 - 46980*x^20 + 58320*x^21 + 25920*x^22)*
          HPL[{-1, 0}, x])/(38880*x^7*(-1 + x^2)^5) - 
        (x*(3455460 + 15138900*x + 106844670*x^2 - 54584955*x^3 - 
           2371620060*x^4 - 2752779765*x^5 + 6548689290*x^6 + 
           12670752360*x^7 + 21957484950*x^8 + 41908771904*x^9 + 
           99066420010*x^10 + 56471596471*x^11 - 12968282210*x^12 - 
           28308384601*x^13 + 3623430450*x^14 + 10733640426*x^15 - 
           1399754370*x^16 - 4127948946*x^17 - 345854880*x^18 + 
           1010294370*x^19 + 278399430*x^20 - 115254900*x^21 - 
           44162820*x^22 + 4723920*x^23 + 2099520*x^24)*HPL[{0, 0}, x])/
         (19440*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        ((-25920 - 58320*x + 46980*x^2 + 301860*x^3 + 141870*x^4 - 
           649710*x^5 - 528930*x^6 + (760111 + 2160*Pi^2)*x^7 + 
           (631130 - 2880*Pi^2)*x^8 - 12*(44447 + 2000*Pi^2)*x^9 - 
           10*(71993 + 3744*Pi^2)*x^10 - 24074*x^11 + 10*(-71993 + 3744*Pi^2)*
            x^12 + 12*(-44447 + 2000*Pi^2)*x^13 + 10*(63113 + 288*Pi^2)*
            x^14 + (760111 - 2160*Pi^2)*x^15 - 528930*x^16 - 649710*x^17 + 
           141870*x^18 + 301860*x^19 + 46980*x^20 - 58320*x^21 - 25920*x^22)*
          HPL[{1, 0}, x])/(38880*x^7*(-1 + x^2)^5) + 
        lm*((2*Pi^2*(-9 + 12*x + 41*x^2 - 41*x^4 - 12*x^5 + 9*x^6) + 
            3*(84 + 18*x - 335*x^2 - 732*x^3 - 335*x^4 + 18*x^5 + 84*x^6))/
           (432*(-1 + x^2)^4) + (x^2*(-18 + 636*x + 988*x^2 + 960*x^3 + 
             198*x^4 + 36*x^5 - 27*x^6)*HPL[{0}, x])/(36*(-1 + x^2)^5) + 
          ((-9 + 12*x + 32*x^2 + 12*x^3 - 9*x^4)*HPL[{-1, 0}, x])/
           (18*(-1 + x^2)^3) + (x^3*(-216 - 324*x - 648*x^2 - 516*x^3 - 
             408*x^4 - 59*x^5 - 12*x^6 + 9*x^7)*HPL[{0, 0}, x])/
           (9*(-1 + x^2)^6) + ((9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*
            HPL[{1, 0}, x])/(18*(-1 + x^2)^3)) + 
        (x*(237 + 653*x + 2574*x^2 - 1343*x^3 + 13422*x^4 + 16729*x^5 - 
           12850*x^6 - 25229*x^7 + 26902*x^8 + 33433*x^9 - 25170*x^10 - 
           31124*x^11 + 12054*x^12 + 18780*x^13 - 1010*x^14 - 6489*x^15 - 
           1431*x^16 + 972*x^17 + 432*x^18)*HPL[{2, 0}, x])/
         (324*(-1 + x^2)^6) + (2*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 
           12*x^5 + 9*x^6)*HPL[{-2, -1, 0}, x])/(27*(-1 + x^2)^4) + 
        (4*(-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{-2, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        (2*(-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{-2, 1, 0}, x])/(27*(-1 + x^2)^4) + 
        (2*(-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{-1, -2, 0}, x])/(27*(-1 + x^2)^4) + 
        ((432 + 972*x + 729*x^2 - 1629*x^3 - 1685*x^4 + 915*x^5 + 659*x^6 - 
           539*x^7 + 105*x^8 + 762*x^9 + 105*x^10 - 539*x^11 + 659*x^12 + 
           915*x^13 - 1685*x^14 - 1629*x^15 + 729*x^16 + 972*x^17 + 432*x^18)*
          HPL[{-1, -1, 0}, x])/(648*x^9*(-1 + x^2)) + 
        ((539 + 1563*x - 415*x^2 + 3177*x^3 + 1189*x^4 - 5949*x^5 + 
           4517*x^6 + 17113*x^7 - 11735*x^8 - 18099*x^9 + 15363*x^10 + 
           12543*x^11 - 9325*x^12 - 5947*x^13 + 2439*x^14 + 2079*x^15 - 
           108*x^16 - 432*x^17)*HPL[{-1, 0, 0}, x])/(324*(-1 + x)^6*
          (1 + x)^4) - ((432 + 972*x + 729*x^2 - 1629*x^3 - 1685*x^4 + 
           915*x^5 + 659*x^6 - 539*x^7 + 105*x^8 + 762*x^9 + 105*x^10 - 
           539*x^11 + 659*x^12 + 915*x^13 - 1685*x^14 - 1629*x^15 + 
           729*x^16 + 972*x^17 + 432*x^18)*HPL[{-1, 1, 0}, x])/
         (648*x^9*(-1 + x^2)) + (2*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 
           12*x^5 + 9*x^6)*HPL[{-1, 2, 0}, x])/(27*(-1 + x^2)^4) + 
        (x*(-19197 - 70389*x + 1801899*x^2 + 3709026*x^3 - 17768640*x^4 - 
           42162548*x^5 - 52320264*x^6 + 125260764*x^7 + 743446890*x^8 - 
           14488642*x^9 - 347876102*x^10 + 524255480*x^11 + 1281473696*x^12 + 
           480514932*x^13 + 993855000*x^14 + 768275246*x^15 - 
           793414035*x^16 - 921121819*x^17 + 302564197*x^18 + 
           526697922*x^19 - 33227644*x^20 - 188300772*x^21 - 26058924*x^22 + 
           39504834*x^23 + 11517282*x^24 - 4078026*x^25 - 1577070*x^26 + 
           157464*x^27 + 69984*x^28)*HPL[{0, 0, 0}, x])/
         (324*(-1 + x^2)^7*(9 - 82*x^2 + 9*x^4)^2) + 
        (2*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 12*x^5 + 9*x^6)*
          HPL[{1, -2, 0}, x])/(27*(-1 + x^2)^4) - 
        ((432 + 972*x + 729*x^2 - 1629*x^3 - 1685*x^4 + 915*x^5 + 659*x^6 - 
           539*x^7 + 105*x^8 + 762*x^9 + 105*x^10 - 539*x^11 + 659*x^12 + 
           915*x^13 - 1685*x^14 - 1629*x^15 + 729*x^16 + 972*x^17 + 432*x^18)*
          HPL[{1, -1, 0}, x])/(648*x^9*(-1 + x^2)) - 
        ((539 + 2855*x + 9573*x^2 + 22697*x^3 + 32581*x^4 + 23191*x^5 - 
           2759*x^6 - 6015*x^7 + 18889*x^8 + 18473*x^9 - 14513*x^10 - 
           22329*x^11 + 979*x^12 + 12233*x^13 + 4707*x^14 - 1809*x^15 - 
           1836*x^16 - 432*x^17)*HPL[{1, 0, 0}, x])/(324*(-1 + x)^4*
          (1 + x)^6) + ((432 + 972*x + 729*x^2 - 1629*x^3 - 1685*x^4 + 
           915*x^5 + 659*x^6 - 539*x^7 + 105*x^8 + 762*x^9 + 105*x^10 - 
           539*x^11 + 659*x^12 + 915*x^13 - 1685*x^14 - 1629*x^15 + 
           729*x^16 + 972*x^17 + 432*x^18)*HPL[{1, 1, 0}, x])/
         (648*x^9*(-1 + x^2)) + (2*(-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 
           12*x^5 - 9*x^6)*HPL[{1, 2, 0}, x])/(27*(-1 + x^2)^4) + 
        (2*(-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{2, -1, 0}, x])/(27*(-1 + x^2)^4) + 
        (4*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 12*x^5 + 9*x^6)*
          HPL[{2, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        (2*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 12*x^5 + 9*x^6)*
          HPL[{2, 1, 0}, x])/(27*(-1 + x^2)^4) + 
        (4*(-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{-1, 1, 0, 0}, x])/(27*(-1 + x^2)^4) + 
        (4*(-9 + 12*x + 91*x^2 + 168*x^3 + 91*x^4 + 12*x^5 - 9*x^6)*
          HPL[{1, -1, 0, 0}, x])/(27*(-1 + x^2)^4) - 
        ((-18 + 41*x + 167*x^2 + 475*x^3 + 364*x^4 + 163*x^5 - 33*x^6 + 
           17*x^7)*master3l10a[x])/(216*(-1 + x^2)^5) + 
        (x*(17 - 33*x + 163*x^2 + 364*x^3 + 475*x^4 + 167*x^5 + 41*x^6 - 
           18*x^7)*master3l10b[x])/(216*(-1 + x^2)^5) + 
        ((37341 + 102897*x + 31860*x^2 + 3816*x^3 + 28278*x^4 + 83922*x^5 - 
           3916*x^6 - 19744*x^7 - 1003*x^8 + 1141*x^9 + 112*x^10)*
          master3l8a[x])/(1296*(-9 + x^2)^2*(-1 + x^2)^6) + 
        ((474 + 754*x - 8031*x^2 - 13071*x^3 + 35748*x^4 + 11232*x^5 - 
           160038*x^6 + 290070*x^7 + 1260954*x^8 + 998838*x^9 + 339309*x^10 - 
           59535*x^11)*master3l8b[x])/(3888*x*(1 - 9*x^2)^2*(-1 + x^2)^6) + 
        ((-9531 + 1701*x + 49122*x^2 + 69606*x^3 + 16860*x^4 - 15144*x^5 + 
           3150*x^6 + 3594*x^7 - 209*x^8 - 237*x^9)*master3l9a[x])/
         (1296*(-9 + x^2)*(-1 + x^2)^6) + 
        ((-237 - 209*x + 3594*x^2 + 3150*x^3 - 15144*x^4 + 16860*x^5 + 
           69606*x^6 + 49122*x^7 + 1701*x^8 - 9531*x^9)*master3l9b[x])/
         (3888*x*(-1 + x^2)^6*(-1 + 9*x^2)) - 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(432 + 972*x + 729*x^2 - 1629*x^3 - 
             1685*x^4 + 915*x^5 + 659*x^6 - 539*x^7 + 105*x^8 + 762*x^9 + 
             105*x^10 - 539*x^11 + 659*x^12 + 915*x^13 - 1685*x^14 - 
             1629*x^15 + 729*x^16 + 972*x^17 + 432*x^18) + 
           576*x^9*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 12*x^5 + 9*x^6)*
            Zeta[3]))/(7776*x^9*(-1 + x^2)^4) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(432 + 972*x + 729*x^2 - 1629*x^3 - 
             1685*x^4 + 915*x^5 + 659*x^6 - 539*x^7 + 105*x^8 + 762*x^9 + 
             105*x^10 - 539*x^11 + 659*x^12 + 915*x^13 - 1685*x^14 - 
             1629*x^15 + 729*x^16 + 972*x^17 + 432*x^18) + 
           576*x^9*(9 - 12*x - 91*x^2 - 168*x^3 - 91*x^4 - 12*x^5 + 9*x^6)*
            Zeta[3]))/(7776*x^9*(-1 + x^2)^4) + 
        (HPL[{0}, x]*(-2099520 - 4723920*x + 43113060*x^2 + 112892940*x^3 - 
           257017860*x^4 - 954241560*x^5 + 135*(1798043 + 2844*Pi^2)*x^6 + 
           27*(137601311 + 39180*Pi^2)*x^7 + 30*(1295918739 + 73193018*Pi^2)*
            x^14 - 2*(707711931 + 2939554100*Pi^2)*x^21 + 
           15*(5917167 + 164944900*Pi^2)*x^22 + 
           15*(59120361 + 250163564*Pi^2)*x^23 + (257017860 - 492763720*Pi^2)*
            x^24 - 180*(627183 + 8484250*Pi^2)*x^25 - 
           180*(239517 + 891596*Pi^2)*x^26 + 6480*(729 + 54914*Pi^2)*x^27 + 
           1080*(1944 + 92687*Pi^2)*x^28 - 39205620*Pi^2*x^29 - 
           15070860*Pi^2*x^30 + 1574640*Pi^2*x^31 + 699840*Pi^2*x^32 - 
           20*x^16*(-6750934609 + 149833600*Pi^2 - 211662720*Zeta[3]) + 
           20*x^18*(-109360041 + 243428248*Pi^2 - 45909504*Zeta[3]) - 
           60*x^10*(73210591 + 360020*Pi^2 - 15303168*Zeta[3]) - 
           120*x^20*(45335611 + 38657056*Pi^2 - 419904*Zeta[3]) - 
           120*x^8*(-11436085 + 23553*Pi^2 + 419904*Zeta[3]) - 
           18*x^9*(525072367 + 1191790*Pi^2 + 4199040*Zeta[3]) + 
           2*x^19*(-7272744687 + 3162728950*Pi^2 + 37791360*Zeta[3]) + 
           10*x^11*(1875002741 + 15667750*Pi^2 + 145286784*Zeta[3]) - 
           10*x^17*(-4923227725 + 500791666*Pi^2 + 145286784*Zeta[3]) - 
           20*x^12*(-88859507 + 3476970*Pi^2 + 211662720*Zeta[3]) + 
           4*x^15*(26579607073 + 785885660*Pi^2 + 1950687360*Zeta[3]) - 
           2*x^13*(9691774181 + 369472790*Pi^2 + 3901374720*Zeta[3])))/
         (77760*x^5*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) - 
        (960*Pi^4*x^7*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(9 - 12*x - 91*x^2 - 
            168*x^3 - 91*x^4 - 12*x^5 + 9*x^6) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^
            2*(-25920 - 58320*x + 72900*x^2 + 360180*x^3 + 94890*x^4 - 
            951570*x^5 - 670800*x^6 + 1409821*x^7 + 1160060*x^8 - 
            1293475*x^9 - 1351060*x^10 + 509290*x^11 - 509290*x^13 + 
            1351060*x^14 + 1293475*x^15 - 1160060*x^16 - 1409821*x^17 + 
            670800*x^18 + 951570*x^19 - 94890*x^20 - 360180*x^21 - 
            72900*x^22 + 58320*x^23 + 25920*x^24) + 
          3*x^2*(-4199040 - 9447840*x + 87625800*x^2 + 228935160*x^3 - 
            548011980*x^4 + x^17*(85256818408 - 63980624960*Zeta[3]) + 
            x^13*(48832058090 - 48543054880*Zeta[3]) - 940934880*x^29*
             Zeta[3] - 361700640*x^30*Zeta[3] + 37791360*x^31*Zeta[3] + 
            16796160*x^32*Zeta[3] - 1215*x^5*(1451777 + 27552*Zeta[3]) + 
            25920*x^28*(-162 + 92687*Zeta[3]) + 1620*x^6*
             (713077 + 113448*Zeta[3]) + 38880*x^27*(-243 + 219656*Zeta[3]) - 
            1080*x^26*(-81135 + 3566384*Zeta[3]) - 240*x^8*
             (19294325 + 10468836*Zeta[3]) - 40*x^10*(-383704957 + 
              13834992*Zeta[3]) - 1080*x^25*(-211977 + 33937000*Zeta[3]) - 
            240*x^24*(2259387 + 49276372*Zeta[3]) + 
            27*x^7*(151252799 + 50732160*Zeta[3]) + 160*x^16*
             (1695921907 + 112187556*Zeta[3]) + 180*x^22*(5457213 + 
              330766328*Zeta[3]) - 300*x^20*(-539867 + 378124512*Zeta[3]) - 
            24*x^9*(93977389 + 706769520*Zeta[3]) + 168*x^19*
             (-290701227 + 822165800*Zeta[3]) + 45*x^23*(-46519299 + 
              2000844544*Zeta[3]) + 40*x^12*(584505493 + 2126823960*Zeta[
                3]) - 40*x^14*(-4695631559 + 2457167580*Zeta[3]) + 
            40*x^18*(-1130017283 + 2869264512*Zeta[3]) + 
            10*x^15*(21925683689 + 6531003968*Zeta[3]) + 
            8*x^11*(2886613301 + 8846381480*Zeta[3]) - 
            3*x^21*(-3750161391 + 46688781920*Zeta[3])))/
         (1866240*x^7*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF*(NH*((x*(-279936 + 602640*x - 103809600*x^2 - 146091951*x^3 - 
             83073096*x^4 + 15027336*x^5 + 28227792*x^6 + 9410845*x^7 - 
             1967664*x^8 - 2313096*x^9 - 9600*x^10 + 204747*x^11 + 696*x^12 - 
             7280*x^13 + 48*x^14 + 39*x^15)*HPL[{0}, x])/(2592*(-9 + x^2)^2*
            (-1 + x^2)^7) + lm^2*(-(-3 + 4*x + 21*x^2 + 40*x^3 + 21*x^4 + 4*
                x^5 - 3*x^6)/(144*(-1 + x^2)^4) + (x^3*(2 + 3*x + 2*x^2)*
              HPL[{0}, x])/(6*(-1 + x^2)^5)) + 
          (x*(69984 - 972*x + 18742752*x^2 + 25800903*x^3 + 13080312*x^4 - 
             5241168*x^5 - 7334544*x^6 - 2006935*x^7 + 228864*x^8 + 
             526624*x^9 + 100464*x^10 - 31779*x^11 - 4440*x^12 - 324*x^13 - 
             192*x^14 + 51*x^15)*HPL[{0, 0}, x])/(648*(-9 + x^2)^2*
            (-1 + x^2)^7) + lm*((4*Pi^2*(-9 + 12*x + 41*x^2 - 41*x^4 - 
                12*x^5 + 9*x^6) + 3*(159 + 48*x - 607*x^2 - 1344*x^3 - 
                607*x^4 + 48*x^5 + 159*x^6))/(7776*(-1 + x^2)^4) + 
            (x^2*(-18 + 618*x + 961*x^2 + 942*x^3 + 198*x^4 + 36*x^5 - 27*
                x^6)*HPL[{0}, x])/(324*(-1 + x^2)^5) + 
            ((-9 + 12*x + 32*x^2 + 12*x^3 - 9*x^4)*HPL[{-1, 0}, x])/
             (162*(-1 + x^2)^3) + (x^3*(-216 - 324*x - 648*x^2 - 516*x^3 - 
               408*x^4 - 59*x^5 - 12*x^6 + 9*x^7)*HPL[{0, 0}, x])/
             (81*(-1 + x^2)^6) + ((9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*
              HPL[{1, 0}, x])/(162*(-1 + x^2)^3)) + 
          ((9 + 1671*x + 1838*x^2 + 1703*x^3 + 204*x^4 + 266*x^5 + 8*x^6 + 
             30*x^7 - 9*x^8)*HPL[{-1, 0, 0}, x])/(81*(-1 + x)^6*(1 + x)^4) + 
          (x^3*(-650916 - 838863*x - 462024*x^2 + 137286*x^3 + 279972*x^4 + 
             83535*x^5 + 10776*x^6 - 18660*x^7 - 7764*x^8 + 2007*x^9 + 
             528*x^10 - 194*x^11 - 12*x^12 + 9*x^13)*HPL[{0, 0, 0}, x])/
           (81*(-9 + x^2)^2*(-1 + x^2)^7) - 
          ((-99 + 1329*x + 2438*x^2 + 2593*x^3 + 1392*x^4 + 622*x^5 + 
             56*x^6 - 6*x^7 - 9*x^8)*HPL[{1, 0, 0}, x])/(81*(-1 + x)^4*
            (1 + x)^6) - ((-11259 + 922536*x + 1298700*x^2 + 852912*x^3 + 
             50481*x^4 - 120528*x^5 - 78944*x^6 + 4352*x^7 + 11511*x^8 - 
             408*x^9 - 748*x^10 + 16*x^11 + 19*x^12)*master3l8a[x])/
           (648*(-9 + x^2)^2*(-1 + x^2)^7) + 
          ((-3753 + 162864*x + 246069*x^2 + 199728*x^3 + 74676*x^4 + 
             44232*x^5 + 546*x^6 + 8760*x^7 - 249*x^8 - 888*x^9 + 169*x^10 + 
             24*x^11 - 18*x^12)*master3l9a[x])/(648*(-9 + x^2)*
            (-1 + x^2)^7) + (x^4*(562595505 - 41296128*Zeta[3]) + 
            x^9*(15675132 - 6526464*Zeta[3]) + x^10*(9051967 - 
              566400*Zeta[3]) + x^14*(63031 - 14720*Zeta[3]) - 
            8*x^15*(-299 + 96*Zeta[3]) - 88*x^11*(11407 + 96*Zeta[3]) + 
            972*x*(276687 + 512*Zeta[3]) + x^16*(-1127 + 576*Zeta[3]) + 
            12*x^13*(1313 + 3072*Zeta[3]) + 486*(-9671 + 3104*Zeta[3]) + 
            x^12*(-1137813 + 171008*Zeta[3]) - 216*x^3*(-2973303 + 
              201824*Zeta[3]) - 27*x^2*(-14258327 + 417920*Zeta[3]) + 
            12*x^5*(20174379 + 1075328*Zeta[3]) + 24*x^7*(-5119201 + 
              1528800*Zeta[3]) - 3*x^8*(6926713 + 2624000*Zeta[3]) + 
            3*x^6*(-43372449 + 19784320*Zeta[3]))/(15552*(-9 + x^2)^2*
            (-1 + x^2)^7)) + 
        NM*(((-8*Pi^2*(1 - 9*x^2)^2*(-1 + x^2)^4*(9 - 12*x - 32*x^2 - 12*
                x^3 + 9*x^4) + 3*(-1368 + 1824*x + 24748*x^2 - 79248*x^3 - 
               174139*x^4 + 1096752*x^5 + 1244220*x^6 - 187272*x^7 - 1834455*
                x^8 - 32172480*x^9 - 32680900*x^10 - 73015008*x^11 - 57556425*
                x^12 - 45611856*x^13 - 34358148*x^14 - 10944072*x^15 + 
               2169747*x^16))*HPL[{0}, x])/(7776*(1 - 9*x^2)^2*
            (-1 + x^2)^7) + lm^2*(-(-3 + 4*x + 21*x^2 + 40*x^3 + 21*x^4 + 4*
                x^5 - 3*x^6)/(144*(-1 + x^2)^4) + (x^3*(2 + 3*x + 2*x^2)*
              HPL[{0}, x])/(6*(-1 + x^2)^5)) + 
          ((9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*HPL[{-2, 0}, x])/
           (81*(-1 + x^2)^3) + ((216 - 288*x - 2664*x^2 + 13392*x^3 + 
             5587*x^4 - 115776*x^5 - 14316*x^6 - 1490328*x^7 - 1540795*x^8 + 
             10061424*x^9 + 12074508*x^10 + 38492784*x^11 + 31899393*x^12 + 
             30345840*x^13 + 23847048*x^14 + 7295832*x^15 - 1511217*x^16)*
            HPL[{0, 0}, x])/(648*(1 - 9*x^2)^2*(-1 + x^2)^7) + 
          lm*((4*Pi^2*(-9 + 12*x + 41*x^2 - 41*x^4 - 12*x^5 + 9*x^6) + 
              3*(159 + 48*x - 607*x^2 - 1344*x^3 - 607*x^4 + 48*x^5 + 
                159*x^6))/(7776*(-1 + x^2)^4) + 
            (x^2*(-18 + 618*x + 961*x^2 + 942*x^3 + 198*x^4 + 36*x^5 - 27*
                x^6)*HPL[{0}, x])/(324*(-1 + x^2)^5) + 
            ((-9 + 12*x + 32*x^2 + 12*x^3 - 9*x^4)*HPL[{-1, 0}, x])/
             (162*(-1 + x^2)^3) + (x^3*(-216 - 324*x - 648*x^2 - 516*x^3 - 
               408*x^4 - 59*x^5 - 12*x^6 + 9*x^7)*HPL[{0, 0}, x])/
             (81*(-1 + x^2)^6) + ((9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*
              HPL[{1, 0}, x])/(162*(-1 + x^2)^3)) + 
          ((-9 + 12*x + 32*x^2 + 12*x^3 - 9*x^4)*HPL[{2, 0}, x])/
           (81*(-1 + x^2)^3) + ((-27 + 90*x + 24*x^2 + 126*x^3 + 204*x^4 + 
             1843*x^5 + 1822*x^6 + 1611*x^7 + 27*x^8)*HPL[{-1, 0, 0}, x])/
           (81*(-1 + x)^6*(1 + x)^4) - ((9 - 12*x + 58*x^2 + 624*x^3 - 
             2486*x^4 + 4476*x^5 + 18216*x^6 - 212496*x^7 - 207232*x^8 + 
             319500*x^9 + 470086*x^10 + 6833712*x^11 + 6855786*x^12 + 
             7083396*x^13 + 5235192*x^14 + 1730160*x^15 - 306909*x^16)*
            HPL[{0, 0, 0}, x])/(81*(1 - 9*x^2)^2*(-1 + x^2)^7) - 
          ((-27 - 18*x + 168*x^2 + 810*x^3 + 1392*x^4 + 2405*x^5 + 2326*x^6 + 
             1341*x^7 - 81*x^8)*HPL[{1, 0, 0}, x])/(81*(-1 + x)^4*
            (1 + x)^6) - ((36 - 48*x - 719*x^2 + 2160*x^3 + 5784*x^4 - 
             32280*x^5 - 40107*x^6 + 56160*x^7 + 97308*x^8 + 758304*x^9 + 
             700587*x^10 + 710640*x^11 + 540648*x^12 + 163944*x^13 - 
             33777*x^14)*master3l8b[x])/(1944*(-1 + x^2)^7*(x - 9*x^3)^2) - 
          ((-18 + 24*x + 169*x^2 - 888*x^3 - 249*x^4 + 8760*x^5 + 546*x^6 + 
             44232*x^7 + 74676*x^8 + 199728*x^9 + 246069*x^10 + 162864*x^11 - 
             3753*x^12)*master3l9b[x])/(1944*x^2*(-1 + x^2)^7*(-1 + 9*x^2)) + 
          (-270 + 360*x + x^12*(185481747 - 59352960*Zeta[3]) + 
            x^13*(166926132 - 12903936*Zeta[3]) + 
            x^6*(1539873 - 171008*Zeta[3]) + x^5*(495804 - 36864*Zeta[3]) + 
            x^2*(10412 - 576*Zeta[3]) + 88*x^7*(-37733 + 96*Zeta[3]) + 
            8*x^3*(-3089 + 96*Zeta[3]) - 972*x^17*(-17373 + 512*Zeta[3]) - 
            243*x^18*(7763 + 6208*Zeta[3]) + x^4*(-165511 + 14720*Zeta[3]) + 
            216*x^15*(131097 + 201824*Zeta[3]) + 27*x^16*(1463023 + 
              417920*Zeta[3]) + 12*x^9*(-1134271 + 543872*Zeta[3]) + 
            x^8*(-8329267 + 566400*Zeta[3]) - 24*x^11*(-6362311 + 
              1528800*Zeta[3]) + 3*x^10*(-965477 + 2624000*Zeta[3]) + 
            x^14*(53393835 + 41296128*Zeta[3]))/(15552*(-1 + x^2)^7*
            (x - 9*x^3)^2)) + NL*((Pi^2*(-9 + 12*x + 32*x^2 + 12*x^3 - 
             9*x^4)*HPL[{-1}, x])/(972*(-1 + x^2)^3) + 
          (x^2*(102 - 48*(290 + 27*Pi^2)*x - 27*(733 + 72*Pi^2)*x^2 - 
             144*(29 + 18*Pi^2)*x^3 - 3*(-5831 + 472*Pi^2)*x^4 - 
             240*(-76 + 5*Pi^2)*x^5 + (2673 - 236*Pi^2)*x^6 - 
             48*(3 + Pi^2)*x^7 + 9*(-53 + 4*Pi^2)*x^8)*HPL[{0}, x])/
           (3888*(-1 + x^2)^6) + lm^2*(-(-3 + 4*x + 21*x^2 + 40*x^3 + 21*
                x^4 + 4*x^5 - 3*x^6)/(144*(-1 + x^2)^4) + 
            (x^3*(2 + 3*x + 2*x^2)*HPL[{0}, x])/(6*(-1 + x^2)^5)) + 
          (Pi^2*(9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*HPL[{1}, x])/
           (972*(-1 + x^2)^3) + (x^3*(324 + 486*x + 648*x^2 + 354*x^3 + 
             300*x^4 + 59*x^5 + 12*x^6 - 9*x^7)*HPL[{-2, 0}, x])/
           (81*(-1 + x^2)^6) + ((-17 + 64*x + 66*x^2 - 2632*x^3 - 3658*x^4 - 
             2632*x^5 + 66*x^6 + 64*x^7 - 17*x^8)*HPL[{-1, 0}, x])/
           (648*(-1 + x^2)^5) + (x^3*(-1440 - 2160*x - 3024*x^2 - 1920*x^3 - 
             1792*x^4 - 497*x^5 - 136*x^6 + 71*x^7)*HPL[{0, 0}, x])/
           (324*(-1 + x^2)^6) + ((17 - 64*x - 66*x^2 + 2632*x^3 + 3658*x^4 + 
             2632*x^5 - 66*x^6 - 64*x^7 + 17*x^8)*HPL[{1, 0}, x])/
           (648*(-1 + x^2)^5) + lm*((4*Pi^2*(-9 + 12*x + 41*x^2 - 41*x^4 - 
                12*x^5 + 9*x^6) + 3*(159 + 48*x - 607*x^2 - 1344*x^3 - 
                607*x^4 + 48*x^5 + 159*x^6))/(7776*(-1 + x^2)^4) + 
            (x^2*(-18 + 618*x + 961*x^2 + 942*x^3 + 198*x^4 + 36*x^5 - 27*
                x^6)*HPL[{0}, x])/(324*(-1 + x^2)^5) + 
            ((-9 + 12*x + 32*x^2 + 12*x^3 - 9*x^4)*HPL[{-1, 0}, x])/
             (162*(-1 + x^2)^3) + (x^3*(-216 - 324*x - 648*x^2 - 516*x^3 - 
               408*x^4 - 59*x^5 - 12*x^6 + 9*x^7)*HPL[{0, 0}, x])/
             (81*(-1 + x^2)^6) + ((9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*
              HPL[{1, 0}, x])/(162*(-1 + x^2)^3)) + 
          (x^3*(-324 - 486*x - 648*x^2 - 354*x^3 - 300*x^4 - 59*x^5 - 
             12*x^6 + 9*x^7)*HPL[{2, 0}, x])/(81*(-1 + x^2)^6) + 
          ((9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*HPL[{-1, -1, 0}, x])/
           (81*(-1 + x^2)^3) + ((-9 + 12*x + 32*x^2 + 12*x^3 - 9*x^4)*
            HPL[{-1, 1, 0}, x])/(81*(-1 + x^2)^3) + 
          (2*x^3*(216 + 324*x + 648*x^2 + 516*x^3 + 408*x^4 + 59*x^5 + 
             12*x^6 - 9*x^7)*HPL[{0, 0, 0}, x])/(81*(-1 + x^2)^6) + 
          ((-9 + 12*x + 32*x^2 + 12*x^3 - 9*x^4)*HPL[{1, -1, 0}, x])/
           (81*(-1 + x^2)^3) + ((9 - 12*x - 32*x^2 - 12*x^3 + 9*x^4)*
            HPL[{1, 1, 0}, x])/(81*(-1 + x^2)^3) + 
          (4*Pi^2*(-17 + 64*x + 83*x^2 - 2696*x^3 - 3724*x^4 + 3724*x^6 + 
              2696*x^7 - 83*x^8 - 64*x^9 + 17*x^10) + 
            3*(407 + 707*x^8 + 2048*x^9 + 407*x^10 + x^2*(707 - 
                3776*Zeta[3]) + 576*Zeta[3] - 256*x*(-8 + 3*Zeta[3]) - 
              32*x^3*(143 + 600*Zeta[3]) - 64*x^5*(-79 + 648*Zeta[3]) - 
              32*x^7*(143 + 648*Zeta[3]) - 2*x^4*(557 + 11328*Zeta[3]) - 
              2*x^6*(557 + 15552*Zeta[3])))/(31104*(-1 + x^2)^6))))
 
CbarData["a", 2, 2] = 
    NC*(CF*(NL*((Pi^2*(-2 + 5*x + 12*x^2 + 20*x^3 + 12*x^4 + 5*x^5 - 2*x^6)*
            HPL[{-1}, x])/(810*(-1 + x^2)^5) + 
          (x^2*(28 - 50*(2015 + 144*Pi^2)*x - 32*(5839 + 450*Pi^2)*x^2 - 
             675*(365 + 48*Pi^2)*x^3 - 10*(7217 + 3120*Pi^2)*x^4 - 
             5*(-37161 + 6320*Pi^2)*x^5 - 4*(-62297 + 3450*Pi^2)*x^6 + 
             (160555 - 7300*Pi^2)*x^7 + (10862 - 360*Pi^2)*x^8 + 
             (765 - 100*Pi^2)*x^9 + 20*(-53 + 2*Pi^2)*x^10)*HPL[{0}, x])/
           (16200*(-1 + x^2)^8) + lm^2*(-(-2 + 5*x + 28*x^2 + 145*x^3 + 188*
                x^4 + 145*x^5 + 28*x^6 + 5*x^7 - 2*x^8)/(180*(-1 + x^2)^6) + 
            (2*x^3*(1 + x + x^2)^2*HPL[{0}, x])/(3*(-1 + x^2)^7)) + 
          (Pi^2*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 5*x^5 + 2*x^6)*
            HPL[{1}, x])/(810*(-1 + x^2)^5) + 
          (2*x^3*(360 + 720*x + 1620*x^2 + 1560*x^3 + 1580*x^4 + 690*x^5 + 
             365*x^6 + 18*x^7 + 5*x^8 - 2*x^9)*HPL[{-2, 0}, x])/
           (135*(-1 + x^2)^8) - ((14 - 155*x + 2008*x^2 + 51050*x^3 + 
             87558*x^4 + 134010*x^5 + 87558*x^6 + 51050*x^7 + 2008*x^8 - 
             155*x^9 + 14*x^10)*HPL[{-1, 0}, x])/(8100*(-1 + x^2)^7) + 
          (x^3*(-18000 - 36000*x - 99000*x^2 - 111600*x^3 - 137000*x^4 - 
             78250*x^5 - 44975*x^6 - 3526*x^7 - 1055*x^8 + 374*x^9)*
            HPL[{0, 0}, x])/(4050*(-1 + x^2)^8) + 
          ((14 - 155*x + 2008*x^2 + 51050*x^3 + 87558*x^4 + 134010*x^5 + 
             87558*x^6 + 51050*x^7 + 2008*x^8 - 155*x^9 + 14*x^10)*
            HPL[{1, 0}, x])/(8100*(-1 + x^2)^7) + 
          lm*(-(-212 + 153*x + 1754*x^2 + 12267*x^3 + 16188*x^4 + 12267*x^5 + 
               1754*x^6 + 153*x^7 - 212*x^8 - 4*Pi^2*(-2 + 5*x + 14*x^2 + 
                 15*x^3 - 15*x^5 - 14*x^6 - 5*x^7 + 2*x^8))/
             (6480*(-1 + x^2)^6) + (x^2*(-2 + 449*x + 868*x^2 + 1667*x^3 + 
               1348*x^4 + 869*x^5 + 88*x^6 + 15*x^7 - 6*x^8)*HPL[{0}, x])/
             (135*(-1 + x^2)^7) + ((-2 + 5*x + 12*x^2 + 20*x^3 + 12*x^4 + 5*
                x^5 - 2*x^6)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^5) + 
            (2*x^3*(-180 - 360*x - 1260*x^2 - 1560*x^3 - 1940*x^4 - 1050*
                x^5 - 545*x^6 - 18*x^7 - 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x^2)^8) - ((-2 + 5*x + 12*x^2 + 20*x^3 + 12*x^4 + 5*
                x^5 - 2*x^6)*HPL[{1, 0}, x])/(135*(-1 + x^2)^5)) + 
          (2*x^3*(-360 - 720*x - 1620*x^2 - 1560*x^3 - 1580*x^4 - 690*x^5 - 
             365*x^6 - 18*x^7 - 5*x^8 + 2*x^9)*HPL[{2, 0}, x])/
           (135*(-1 + x^2)^8) + (2*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 
             5*x^5 + 2*x^6)*HPL[{-1, -1, 0}, x])/(135*(-1 + x^2)^5) + 
          ((-4 + 10*x + 24*x^2 + 40*x^3 + 24*x^4 + 10*x^5 - 4*x^6)*
            HPL[{-1, 1, 0}, x])/(135*(-1 + x^2)^5) + 
          (4*x^3*(180 + 360*x + 1260*x^2 + 1560*x^3 + 1940*x^4 + 1050*x^5 + 
             545*x^6 + 18*x^7 + 5*x^8 - 2*x^9)*HPL[{0, 0, 0}, x])/
           (135*(-1 + x^2)^8) + ((-4 + 10*x + 24*x^2 + 40*x^3 + 24*x^4 + 
             10*x^5 - 4*x^6)*HPL[{1, -1, 0}, x])/(135*(-1 + x^2)^5) + 
          (2*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 5*x^5 + 2*x^6)*
            HPL[{1, 1, 0}, x])/(135*(-1 + x^2)^5) + 
          (11830 - 486*x^10 + 40605*x^11 + 11830*x^12 + 
            4*Pi^2*(-14 + 155*x - 1994*x^2 - 51205*x^3 - 85550*x^4 - 
              82960*x^5 + 82960*x^7 + 85550*x^8 + 51205*x^9 + 1994*x^10 - 
              155*x^11 + 14*x^12) + x^7*(525990 - 4665600*Zeta[3]) + 
            x^5*(525990 - 4550400*Zeta[3]) + x^6*(1299052 - 4492800*Zeta[
                3]) + 5760*Zeta[3] - 162*x^2*(3 + 320*Zeta[3]) - 
            15*x*(-2707 + 960*Zeta[3]) - 405*x^9*(1399 + 2560*Zeta[3]) - 
            90*x^4*(7343 + 22080*Zeta[3]) - 90*x^8*(7343 + 23040*Zeta[3]) - 
            45*x^3*(12591 + 23360*Zeta[3]))/(388800*(-1 + x^2)^8)) + 
        NH*(-(x*(283435200 - 895655232*x + 193724110080*x^2 + 
              334961660664*x^3 + 422207082315*x^4 + 204021712494*x^5 - 
              55657536210*x^6 - 148146572772*x^7 - 55838240910*x^8 + 
              23777655876*x^9 + 17928876150*x^10 + 638719628*x^11 - 
              2117219400*x^12 - 582916656*x^13 + 108881130*x^14 + 
              69062324*x^15 - 1708050*x^16 - 3555172*x^17 - 36750*x^18 + 
              67756*x^19 + 1245*x^20 + 290*x^21)*HPL[{0}, x])/
           (32400*(-9 + x^2)^4*(-1 + x^2)^9) + 
          lm^2*(-(-2 + 5*x + 28*x^2 + 145*x^3 + 188*x^4 + 145*x^5 + 28*x^6 + 
               5*x^7 - 2*x^8)/(180*(-1 + x^2)^6) + (2*x^3*(1 + x + x^2)^2*
              HPL[{0}, x])/(3*(-1 + x^2)^7)) + 
          (x*(70858800 - 48183984*x + 35292887460*x^2 + 60412868604*x^3 + 
             73419739335*x^4 + 30450916602*x^5 - 19581691950*x^6 - 
             32646678588*x^7 - 12800192400*x^8 + 5648451984*x^9 + 
             4485917610*x^10 + 340000428*x^11 - 361780890*x^12 - 
             177962396*x^13 - 18070410*x^14 + 17009612*x^15 + 3402120*x^16 - 
             512208*x^17 - 92310*x^18 - 6456*x^19 - 1365*x^20 + 402*x^21)*
            HPL[{0, 0}, x])/(8100*(-9 + x^2)^4*(-1 + x^2)^9) + 
          lm*(-(-212 + 153*x + 1754*x^2 + 12267*x^3 + 16188*x^4 + 12267*x^5 + 
               1754*x^6 + 153*x^7 - 212*x^8 - 4*Pi^2*(-2 + 5*x + 14*x^2 + 
                 15*x^3 - 15*x^5 - 14*x^6 - 5*x^7 + 2*x^8))/
             (6480*(-1 + x^2)^6) + (x^2*(-2 + 449*x + 868*x^2 + 1667*x^3 + 
               1348*x^4 + 869*x^5 + 88*x^6 + 15*x^7 - 6*x^8)*HPL[{0}, x])/
             (135*(-1 + x^2)^7) + ((-2 + 5*x + 12*x^2 + 20*x^3 + 12*x^4 + 5*
                x^5 - 2*x^6)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^5) + 
            (2*x^3*(-180 - 360*x - 1260*x^2 - 1560*x^3 - 1940*x^4 - 1050*
                x^5 - 545*x^6 - 18*x^7 - 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x^2)^8) - ((-2 + 5*x + 12*x^2 + 20*x^3 + 12*x^4 + 5*
                x^5 - 2*x^6)*HPL[{1, 0}, x])/(135*(-1 + x^2)^5)) + 
          (2*(57 + 2091*x + 3368*x^2 + 6338*x^3 + 4126*x^4 + 2800*x^5 + 
             359*x^6 + 452*x^7 + 2*x^8 + 9*x^9 - 2*x^10)*HPL[{-1, 0, 0}, x])/
           (135*(-1 + x)^8*(1 + x)^6) + (2*x^3*(-424423800 - 695617632*x - 
             872211645*x^2 - 358250634*x^3 + 250668720*x^4 + 402710796*x^5 + 
             210566880*x^6 - 53176980*x^7 - 62085360*x^8 - 9134780*x^9 + 
             2276030*x^10 + 2627248*x^11 + 719120*x^12 - 234444*x^13 - 
             78920*x^14 + 11236*x^15 + 2600*x^16 - 420*x^17 - 25*x^18 + 
             10*x^19)*HPL[{0, 0, 0}, x])/(675*(-9 + x^2)^4*(-1 + x^2)^9) + 
          (2*(33 - 1959*x - 3908*x^2 - 7042*x^3 - 6786*x^4 - 5220*x^5 - 
             1969*x^6 - 668*x^7 - 22*x^8 - x^9 + 2*x^10)*HPL[{1, 0, 0}, x])/
           (135*(-1 + x)^6*(1 + x)^8) - ((-15037812 + 1735636005*x + 
             2985204942*x^2 + 3929620230*x^3 + 2166048324*x^4 + 
             34797330*x^5 - 962469540*x^6 - 415724850*x^7 + 83359836*x^8 + 
             92233980*x^9 + 12121928*x^10 - 9708110*x^11 - 3086388*x^12 + 
             555870*x^13 + 261924*x^14 - 11910*x^15 - 9720*x^16 - 145*x^17 + 
             106*x^18)*master3l8a[x])/(8100*(-9 + x^2)^4*(-1 + x^2)^9) + 
          ((-1670868 + 98532045*x + 176922090*x^2 + 253747665*x^3 + 
             180718794*x^4 + 87764715*x^5 + 2630094*x^6 + 10352625*x^7 - 
             2262670*x^8 - 2398235*x^9 - 934478*x^10 - 839365*x^11 + 
             137070*x^12 + 128305*x^13 - 7766*x^14 - 4605*x^15 + 554*x^16 + 
             50*x^17 - 20*x^18)*master3l9a[x])/(2700*(-9 + x^2)^3*
            (-1 + x^2)^9) + (x^20*(610726 - 88320*Zeta[3]) + 
            30*x^22*(-99 + 64*Zeta[3]) - 5*x^21*(-6763 + 960*Zeta[3]) + 
            45*x^19*(12373 + 5760*Zeta[3]) + 450*x^17*(-116919 + 
              10976*Zeta[3]) + 72*x^18*(-279623 + 26800*Zeta[3]) + 
            52488*(-115219 + 35040*Zeta[3]) - 152*x^16*(-1776967 + 
              50400*Zeta[3]) + 65610*x*(7675867 + 55200*Zeta[3]) - 
            5832*x^2*(-149392627 + 1209360*Zeta[3]) + 29700*x^7*
             (-14482525 + 5848768*Zeta[3]) - 10935*x^3*(-171178807 + 
              7905920*Zeta[3]) - 20*x^15*(-54618791 + 14909760*Zeta[3]) + 
            120*x^9*(-1213981919 + 24091840*Zeta[3]) - 
            12*x^14*(106229743 + 36372800*Zeta[3]) - 2025*x^5*
             (-752159255 + 38493504*Zeta[3]) - 450*x^11*(-154325491 + 
              43482752*Zeta[3]) - 1458*x^4*(-1302116703 + 96035200*Zeta[3]) + 
            30*x^13*(-393112961 + 134657280*Zeta[3]) + 
            36*x^12*(-219122481 + 213760000*Zeta[3]) - 
            16*x^10*(-8103852209 + 3034918800*Zeta[3]) + 
            32*x^8*(-17392594003 + 3057891600*Zeta[3]) + 
            18*x^6*(19996977463 + 4927012800*Zeta[3]))/(194400*(-9 + x^2)^4*
            (-1 + x^2)^9)) + 
        NM*(-((4560 - 11400*x - 171624*x^2 + 1076100*x^3 + 3672218*x^4 - 
              32999925*x^5 - 69218376*x^6 + 306149430*x^7 + 709902164*x^8 + 
              577046250*x^9 - 1407294772*x^10 - 16757782650*x^11 - 
              18860631944*x^12 + 13856559840*x^13 + 48455898188*x^14 + 
              206024214690*x^15 + 206272762524*x^16 + 233810252190*x^17 + 
              143179154604*x^18 + 75181286430*x^19 + 38474565678*x^20 + 
              7671853845*x^21 - 2918464020*x^22 + 40*Pi^2*(1 - 10*x^2 + 
                 9*x^4)^4*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 5*x^5 + 
                2*x^6))*HPL[{0}, x])/(32400*(1 - 9*x^2)^4*(-1 + x^2)^9) + 
          lm^2*(-(-2 + 5*x + 28*x^2 + 145*x^3 + 188*x^4 + 145*x^5 + 28*x^6 + 
               5*x^7 - 2*x^8)/(180*(-1 + x^2)^6) + (2*x^3*(1 + x + x^2)^2*
              HPL[{0}, x])/(3*(-1 + x^2)^7)) + 
          (2*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 5*x^5 + 2*x^6)*
            HPL[{-2, 0}, x])/(135*(-1 + x^2)^5) + 
          ((720 - 1800*x - 23088*x^2 + 206760*x^3 + 501738*x^4 - 
             5192505*x^5 - 9201032*x^6 + 8454690*x^7 + 39622400*x^8 + 
             742629600*x^9 + 941411892*x^10 - 4996507710*x^11 - 
             9102026508*x^12 - 10192242330*x^13 + 3846046068*x^14 + 
             88025859270*x^15 + 102691991808*x^16 + 139987653840*x^17 + 
             94406418540*x^18 + 55127118510*x^19 + 26796711762*x^20 + 
             5039340075*x^21 - 2025380700*x^22)*HPL[{0, 0}, x])/
           (8100*(1 - 9*x^2)^4*(-1 + x^2)^9) + 
          lm*(-(-212 + 153*x + 1754*x^2 + 12267*x^3 + 16188*x^4 + 12267*x^5 + 
               1754*x^6 + 153*x^7 - 212*x^8 - 4*Pi^2*(-2 + 5*x + 14*x^2 + 
                 15*x^3 - 15*x^5 - 14*x^6 - 5*x^7 + 2*x^8))/
             (6480*(-1 + x^2)^6) + (x^2*(-2 + 449*x + 868*x^2 + 1667*x^3 + 
               1348*x^4 + 869*x^5 + 88*x^6 + 15*x^7 - 6*x^8)*HPL[{0}, x])/
             (135*(-1 + x^2)^7) + ((-2 + 5*x + 12*x^2 + 20*x^3 + 12*x^4 + 5*
                x^5 - 2*x^6)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^5) + 
            (2*x^3*(-180 - 360*x - 1260*x^2 - 1560*x^3 - 1940*x^4 - 1050*
                x^5 - 545*x^6 - 18*x^7 - 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x^2)^8) - ((-2 + 5*x + 12*x^2 + 20*x^3 + 12*x^4 + 5*
                x^5 - 2*x^6)*HPL[{1, 0}, x])/(135*(-1 + x^2)^5)) + 
          ((-4 + 10*x + 24*x^2 + 40*x^3 + 24*x^4 + 10*x^5 - 4*x^6)*
            HPL[{2, 0}, x])/(135*(-1 + x^2)^5) + 
          (2*(-6 + 27*x + 6*x^2 + 436*x^3 + 327*x^4 + 2800*x^5 + 4158*x^6 + 
             6354*x^7 + 3364*x^8 + 2073*x^9 + 61*x^10)*HPL[{-1, 0, 0}, x])/
           (135*(-1 + x)^8*(1 + x)^6) + (2*(-10 + 25*x + 140*x^2 - 3700*x^3 - 
             3698*x^4 + 33835*x^5 + 49740*x^6 + 1440630*x^7 + 1884816*x^8 - 
             21008770*x^9 - 38083856*x^10 - 28414050*x^11 + 99613588*x^12 + 
             1394486970*x^13 + 1404533052*x^14 - 3380714910*x^15 - 
             5689906830*x^16 - 9826444935*x^17 - 7354994724*x^18 - 
             4656888450*x^19 - 2067497946*x^20 - 479248245*x^21 + 
             134159328*x^22)*HPL[{0, 0, 0}, x])/(675*(1 - 9*x^2)^4*
            (-1 + x^2)^9) + (2*(6 - 3*x - 66*x^2 - 764*x^3 - 2057*x^4 - 
             5220*x^5 - 6698*x^6 - 6946*x^7 - 3864*x^8 - 1957*x^9 + 29*x^10)*
            HPL[{1, 0, 0}, x])/(135*(-1 + x)^6*(1 + x)^8) - 
          ((40 - 100*x - 1574*x^2 + 10255*x^3 + 35224*x^4 - 327590*x^5 - 
             675852*x^6 + 3432350*x^7 + 7422604*x^8 - 603990*x^9 - 
             24417192*x^10 - 156107460*x^11 - 129348084*x^12 + 
             426542670*x^13 + 648373644*x^14 + 1037472210*x^15 + 
             733045788*x^16 + 440773650*x^17 + 202734414*x^18 + 
             37940805*x^19 - 15037812*x^20)*master3l8b[x])/
           (8100*x^2*(1 - 9*x^2)^4*(-1 + x^2)^9) - 
          ((-20 + 50*x + 554*x^2 - 4605*x^3 - 7766*x^4 + 128305*x^5 + 
             137070*x^6 - 839365*x^7 - 934478*x^8 - 2398235*x^9 - 
             2262670*x^10 + 10352625*x^11 + 2630094*x^12 + 87764715*x^13 + 
             180718794*x^14 + 253747665*x^15 + 176922090*x^16 + 
             98532045*x^17 - 1670868*x^18)*master3l9b[x])/
           (8100*x^2*(-1 + x^2)^9*(-1 + 9*x^2)^3) + 
          (-900 + 2250*x + x^16*(364807305476 - 97852531200*Zeta[3]) + 
            x^12*(5765193036 - 7695360000*Zeta[3]) + 
            x^6*(38198286 - 1929600*Zeta[3]) - 480*x^2*(-105 + 4*Zeta[3]) + 
            10*x^3*(-29729 + 480*Zeta[3]) - 45*x^5*(-237607 + 5760*Zeta[3]) - 
            225*x^7*(695041 + 21952*Zeta[3]) - 98415*x^23*
             (-154017 + 36800*Zeta[3]) + 2*x^4*(-850673 + 44160*Zeta[3]) - 
            26244*x^24*(104767 + 70080*Zeta[3]) - 1920*x^11*
             (-5564969 + 2104020*Zeta[3]) + 1458*x^22*(34559147 + 
              4837440*Zeta[3]) + 12150*x^19*(26662771 + 6415584*Zeta[3]) + 
            40*x^9*(11902547 + 7454880*Zeta[3]) + x^8*(-509218004 + 
              7660800*Zeta[3]) + 10935*x^21*(4114093 + 7905920*Zeta[3]) + 
            48*x^10*(62320087 + 9093200*Zeta[3]) + 450*x^13*
             (-212668031 + 43482752*Zeta[3]) - 30*x^15*(-3558772931 + 
              96367360*Zeta[3]) - 1350*x^17*(-534058057 + 128672896*Zeta[
                3]) - 576*x^18*(-902997571 + 153969150*Zeta[3]) + 
            486*x^20*(201304001 + 288105600*Zeta[3]) + 
            4*x^14*(-35686652921 + 12139675200*Zeta[3]))/
           (194400*x^2*(1 - 9*x^2)^4*(-1 + x^2)^9))) + 
      CF^2*((Pi^2*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 
           180*x^6 + 15*x^7 - 6*x^8)*HPL[{-2}, x])/(405*(-1 + x^2)^6) + 
        lm^2*(-(-2 + 5*x + 28*x^2 + 145*x^3 + 188*x^4 + 145*x^5 + 28*x^6 + 
             5*x^7 - 2*x^8)/(10*(-1 + x^2)^6) + (12*x^3*(1 + x + x^2)^2*
            HPL[{0}, x])/(-1 + x^2)^7) + 
        (Pi^2*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{2}, x])/(405*(-1 + x^2)^6) - 
        (x*(2265 + 9630*x + 71235*x^2 + 48750*x^3 + 455400*x^4 + 546220*x^5 - 
           53640*x^6 - 549270*x^7 + 1110390*x^8 + 1325717*x^9 - 
           1639548*x^10 - 1939342*x^11 + 1643684*x^12 + 1995612*x^13 - 
           970156*x^14 - 1395818*x^15 + 255359*x^16 + 632907*x^17 + 
           43479*x^18 - 167904*x^19 - 46728*x^20 + 19800*x^21 + 9000*x^22)*
          HPL[{-2, 0}, x])/(4050*(-1 + x^2)^8) + 
        ((270000 + 594000*x - 996840*x^2 - 4146120*x^3 - 303390*x^4 + 
           12520530*x^5 + 7609785*x^6 - 21390945*x^7 - 17526180*x^8 + 
           (22712411 - 3600*Pi^2)*x^9 + 5*(4046893 + 1800*Pi^2)*x^10 + 
           6*(-2524693 + 18600*Pi^2)*x^11 + 80*(-95557 + 5400*Pi^2)*x^12 + 
           4*(3188203 + 121800*Pi^2)*x^13 + 23135640*x^14 + 
           (12752812 - 487200*Pi^2)*x^15 - 80*(95557 + 5400*Pi^2)*x^16 - 
           6*(2524693 + 18600*Pi^2)*x^17 + (20234465 - 9000*Pi^2)*x^18 + 
           (22712411 + 3600*Pi^2)*x^19 - 17526180*x^20 - 21390945*x^21 + 
           7609785*x^22 + 12520530*x^23 - 303390*x^24 - 4146120*x^25 - 
           996840*x^26 + 594000*x^27 + 270000*x^28)*HPL[{-1, 0}, x])/
         (243000*x^9*(-1 + x^2)^7) - (x*(2674919700 + 13894229700*x + 
           119095600050*x^2 - 68480185995*x^3 - 5244364071450*x^4 - 
           8340862561470*x^5 + 53470233819450*x^6 + 143229175268400*x^7 - 
           61728109532730*x^8 - 723570727130538*x^9 - 1150617251604660*x^10 + 
           134011631379693*x^11 - 252619836316830*x^12 + 1483499750049022*
            x^13 + 22864715271541570*x^14 + 26943094647880748*x^15 + 
           4009416485271340*x^16 - 13003680031234168*x^17 + 
           725239902739810*x^18 + 7418110553039167*x^19 - 3903659185305150*
            x^20 - 6026323550962602*x^21 + 2060440935409830*x^22 + 
           3594229359873552*x^23 - 386817451769610*x^24 - 1444198195732482*
            x^25 - 106032103284960*x^26 + 383068664168607*x^27 + 
           80528762400390*x^28 - 64077414622470*x^29 - 19679958667890*x^30 + 
           6398939232180*x^31 + 2393751063060*x^32 - 346264910640*x^33 - 
           145743954480*x^34 + 7794468000*x^35 + 3542940000*x^36)*
          HPL[{0, 0}, x])/(243000*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        ((-270000 - 594000*x + 996840*x^2 + 4146120*x^3 + 303390*x^4 - 
           12520530*x^5 - 7609785*x^6 + 21390945*x^7 + 17526180*x^8 + 
           (-22712411 + 3600*Pi^2)*x^9 - 5*(4046893 + 1800*Pi^2)*x^10 - 
           6*(-2524693 + 18600*Pi^2)*x^11 - 80*(-95557 + 5400*Pi^2)*x^12 - 
           4*(3188203 + 121800*Pi^2)*x^13 - 23135640*x^14 + 
           4*(-3188203 + 121800*Pi^2)*x^15 + 80*(95557 + 5400*Pi^2)*x^16 + 
           6*(2524693 + 18600*Pi^2)*x^17 + 5*(-4046893 + 1800*Pi^2)*x^18 - 
           (22712411 + 3600*Pi^2)*x^19 + 17526180*x^20 + 21390945*x^21 - 
           7609785*x^22 - 12520530*x^23 + 303390*x^24 + 4146120*x^25 + 
           996840*x^26 - 594000*x^27 - 270000*x^28)*HPL[{1, 0}, x])/
         (243000*x^9*(-1 + x^2)^7) + 
        lm*(-(-79 + 9*x + 499*x^2 + 4176*x^3 + 5556*x^4 + 4176*x^5 + 
             499*x^6 + 9*x^7 - 79*x^8 - 2*Pi^2*(-2 + 5*x + 14*x^2 + 15*x^3 - 
               15*x^5 - 14*x^6 - 5*x^7 + 2*x^8))/(180*(-1 + x^2)^6) + 
          (x^2*(-4 + 763*x + 1466*x^2 + 2929*x^3 + 2426*x^4 + 1603*x^5 + 
             176*x^6 + 30*x^7 - 12*x^8)*HPL[{0}, x])/(15*(-1 + x^2)^7) + 
          ((-4 + 10*x + 24*x^2 + 40*x^3 + 24*x^4 + 10*x^5 - 4*x^6)*
            HPL[{-1, 0}, x])/(15*(-1 + x^2)^5) + 
          (4*x^3*(-180 - 360*x - 1260*x^2 - 1560*x^3 - 1940*x^4 - 1050*x^5 - 
             545*x^6 - 18*x^7 - 5*x^8 + 2*x^9)*HPL[{0, 0}, x])/
           (15*(-1 + x^2)^8) + (2*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 
             5*x^5 + 2*x^6)*HPL[{1, 0}, x])/(15*(-1 + x^2)^5)) + 
        (x*(2265 + 9630*x + 71235*x^2 + 48750*x^3 + 455400*x^4 + 546220*x^5 - 
           53640*x^6 - 549270*x^7 + 1110390*x^8 + 1325717*x^9 - 
           1639548*x^10 - 1939342*x^11 + 1643684*x^12 + 1995612*x^13 - 
           970156*x^14 - 1395818*x^15 + 255359*x^16 + 632907*x^17 + 
           43479*x^18 - 167904*x^19 - 46728*x^20 + 19800*x^21 + 9000*x^22)*
          HPL[{2, 0}, x])/(4050*(-1 + x^2)^8) + 
        (4*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{-2, -1, 0}, x])/(135*(-1 + x^2)^6) - 
        (8*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{-2, 0, 0}, x])/(135*(-1 + x^2)^6) + 
        (4*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 180*x^6 + 
           15*x^7 - 6*x^8)*HPL[{-2, 1, 0}, x])/(135*(-1 + x^2)^6) + 
        (4*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 180*x^6 + 
           15*x^7 - 6*x^8)*HPL[{-1, -2, 0}, x])/(135*(-1 + x^2)^6) + 
        ((9000 + 19800*x - 1728*x^2 - 68904*x^3 - 55161*x^4 + 90387*x^5 + 
           86834*x^6 - 56843*x^7 - 46656*x^8 + 19487*x^9 + 8094*x^10 - 
           3127*x^11 + 2234*x^12 - 3127*x^13 + 8094*x^14 + 19487*x^15 - 
           46656*x^16 - 56843*x^17 + 86834*x^18 + 90387*x^19 - 55161*x^20 - 
           68904*x^21 - 1728*x^22 + 19800*x^23 + 9000*x^24)*
          HPL[{-1, -1, 0}, x])/(8100*x^11*(-1 + x^2)^3) + 
        ((958 + 24743*x + 42681*x^2 + 169658*x^3 + 33667*x^4 - 146256*x^5 + 
           91329*x^6 + 606574*x^7 - 258393*x^8 - 854580*x^9 + 725151*x^10 + 
           1067350*x^11 - 917391*x^12 - 876252*x^13 + 674283*x^14 + 
           497842*x^15 - 274149*x^16 - 204903*x^17 + 51048*x^18 + 
           59328*x^19 - 1800*x^20 - 9000*x^21)*HPL[{-1, 0, 0}, x])/
         (4050*(-1 + x)^8*(1 + x)^6) + ((-9000 - 19800*x + 1728*x^2 + 
           68904*x^3 + 55161*x^4 - 90387*x^5 - 86834*x^6 + 56843*x^7 + 
           46656*x^8 - 19487*x^9 - 8094*x^10 + 3127*x^11 - 2234*x^12 + 
           3127*x^13 - 8094*x^14 - 19487*x^15 + 46656*x^16 + 56843*x^17 - 
           86834*x^18 - 90387*x^19 + 55161*x^20 + 68904*x^21 + 1728*x^22 - 
           19800*x^23 - 9000*x^24)*HPL[{-1, 1, 0}, x])/
         (8100*x^11*(-1 + x^2)^3) + (4*(6 - 15*x - 180*x^2 - 735*x^3 - 
           992*x^4 - 735*x^5 - 180*x^6 - 15*x^7 + 6*x^8)*HPL[{-1, 2, 0}, x])/
         (135*(-1 + x^2)^6) + (x*(-14860665 - 67906350*x + 2197169550*x^2 + 
           5375180898*x^3 - 45027361755*x^4 - 102678709266*x^5 + 
           120201421932*x^6 + 449097269616*x^7 + 3790662756735*x^8 + 
           5179388846670*x^9 - 30534002316606*x^10 - 54519044986194*x^11 + 
           33577155357381*x^12 + 134001712450974*x^13 + 174250709445704*
            x^14 - 5705564451284*x^15 - 18830896379385*x^16 + 
           189387836582468*x^17 + 793336565176434*x^18 + 477371492445412*
            x^19 - 719324202635667*x^20 - 723141520050286*x^21 + 
           494557622336172*x^22 + 631982292463648*x^23 - 265846159400847*
            x^24 - 412233714348730*x^25 + 87019631749534*x^26 + 
           198556458439014*x^27 - 6383598854517*x^28 - 68235661703358*x^29 - 
           7836419462976*x^30 + 16062239230308*x^31 + 3701335938066*x^32 - 
           2460659191578*x^33 - 777705476256*x^34 + 230719476438*x^35 + 
           87128107326*x^36 - 11931887088*x^37 - 5035278816*x^38 + 
           259815600*x^39 + 118098000*x^40)*HPL[{0, 0, 0}, x])/
         (4050*(-1 + x^2)^9*(9 - 82*x^2 + 9*x^4)^4) + 
        (4*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{1, -2, 0}, x])/(135*(-1 + x^2)^6) + 
        ((-9000 - 19800*x + 1728*x^2 + 68904*x^3 + 55161*x^4 - 90387*x^5 - 
           86834*x^6 + 56843*x^7 + 46656*x^8 - 19487*x^9 - 8094*x^10 + 
           3127*x^11 - 2234*x^12 + 3127*x^13 - 8094*x^14 - 19487*x^15 + 
           46656*x^16 + 56843*x^17 - 86834*x^18 - 90387*x^19 + 55161*x^20 + 
           68904*x^21 + 1728*x^22 - 19800*x^23 - 9000*x^24)*
          HPL[{1, -1, 0}, x])/(8100*x^11*(-1 + x^2)^3) - 
        ((958 + 25695*x + 150757*x^2 + 521982*x^3 + 1016071*x^4 + 
           1194240*x^5 + 654813*x^6 + 351706*x^7 + 801883*x^8 + 453668*x^9 - 
           1129749*x^10 - 1052974*x^11 + 966261*x^12 + 1341812*x^13 - 
           278249*x^14 - 928154*x^15 - 182241*x^16 + 308313*x^17 + 
           165960*x^18 - 19872*x^19 - 37800*x^20 - 9000*x^21)*
          HPL[{1, 0, 0}, x])/(4050*(-1 + x)^6*(1 + x)^8) + 
        ((9000 + 19800*x - 1728*x^2 - 68904*x^3 - 55161*x^4 + 90387*x^5 + 
           86834*x^6 - 56843*x^7 - 46656*x^8 + 19487*x^9 + 8094*x^10 - 
           3127*x^11 + 2234*x^12 - 3127*x^13 + 8094*x^14 + 19487*x^15 - 
           46656*x^16 - 56843*x^17 + 86834*x^18 + 90387*x^19 - 55161*x^20 - 
           68904*x^21 - 1728*x^22 + 19800*x^23 + 9000*x^24)*
          HPL[{1, 1, 0}, x])/(8100*x^11*(-1 + x^2)^3) + 
        (4*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 180*x^6 + 
           15*x^7 - 6*x^8)*HPL[{1, 2, 0}, x])/(135*(-1 + x^2)^6) + 
        (4*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 180*x^6 + 
           15*x^7 - 6*x^8)*HPL[{2, -1, 0}, x])/(135*(-1 + x^2)^6) + 
        (8*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{2, 0, 0}, x])/(135*(-1 + x^2)^6) + 
        (4*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{2, 1, 0}, x])/(135*(-1 + x^2)^6) - 
        (8*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{-1, 1, 0, 0}, x])/(135*(-1 + x^2)^6) - 
        (8*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{1, -1, 0, 0}, x])/(135*(-1 + x^2)^6) - 
        ((-12 + 59*x + 288*x^2 + 2032*x^3 + 3056*x^4 + 3408*x^5 + 1432*x^6 + 
           592*x^7 - 84*x^8 + 29*x^9)*master3l10a[x])/(540*(-1 + x^2)^7) + 
        (x*(29 - 84*x + 592*x^2 + 1432*x^3 + 3408*x^4 + 3056*x^5 + 2032*x^6 + 
           288*x^7 + 59*x^8 - 12*x^9)*master3l10b[x])/(540*(-1 + x^2)^7) + 
        ((18254889 + 105470991*x + 300347757*x^2 + 382662549*x^3 + 
           116505*x^4 + 2498499*x^5 + 73616445*x^6 + 43746489*x^7 - 
           42249717*x^8 - 32410419*x^9 + 7137951*x^10 + 6597295*x^11 - 
           371045*x^12 - 546655*x^13 - 10313*x^14 + 16323*x^15 + 1048*x^16)*
          master3l8a[x])/(16200*(-9 + x^2)^4*(-1 + x^2)^8) + 
        ((1510 + 5132*x - 53133*x^2 - 205139*x^3 + 721473*x^4 + 3009345*x^5 - 
           5808417*x^6 - 20867427*x^7 + 43093641*x^8 + 88829313*x^9 - 
           247173111*x^10 - 394340481*x^11 + 457334163*x^12 + 
           1164732939*x^13 + 1015853157*x^14 + 309744567*x^15 + 
           78339069*x^16 - 13530969*x^17)*master3l8b[x])/
         (16200*x*(1 - 9*x^2)^4*(-1 + x^2)^8) + 
        ((-1765881 - 1507329*x + 325836*x^2 + 35009775*x^3 + 64737117*x^4 + 
           29158623*x^5 - 18804594*x^6 - 12922353*x^7 + 5192769*x^8 + 
           2758853*x^9 - 978880*x^10 - 382667*x^11 + 79035*x^12 + 
           27933*x^13 - 2042*x^14 - 755*x^15)*master3l9a[x])/
         (5400*(-9 + x^2)^3*(-1 + x^2)^8) + 
        ((-755 - 2042*x + 27933*x^2 + 79035*x^3 - 382667*x^4 - 978880*x^5 + 
           2758853*x^6 + 5192769*x^7 - 12922353*x^8 - 18804594*x^9 + 
           29158623*x^10 + 64737117*x^11 + 35009775*x^12 + 325836*x^13 - 
           1507329*x^14 - 1765881*x^15)*master3l9b[x])/(16200*x*(-1 + x^2)^8*
          (-1 + 9*x^2)^3) - (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*
            (9000 + 19800*x - 1728*x^2 - 68904*x^3 - 55161*x^4 + 90387*x^5 + 
             86834*x^6 - 56843*x^7 - 46656*x^8 + 19487*x^9 + 8094*x^10 - 
             3127*x^11 + 2234*x^12 - 3127*x^13 + 8094*x^14 + 19487*x^15 - 
             46656*x^16 - 56843*x^17 + 86834*x^18 + 90387*x^19 - 55161*x^20 - 
             68904*x^21 - 1728*x^22 + 19800*x^23 + 9000*x^24) + 
           2880*x^11*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 
             180*x^6 - 15*x^7 + 6*x^8)*Zeta[3]))/(97200*x^11*(-1 + x^2)^6) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(9000 + 19800*x - 1728*x^2 - 
             68904*x^3 - 55161*x^4 + 90387*x^5 + 86834*x^6 - 56843*x^7 - 
             46656*x^8 + 19487*x^9 + 8094*x^10 - 3127*x^11 + 2234*x^12 - 
             3127*x^13 + 8094*x^14 + 19487*x^15 - 46656*x^16 - 56843*x^17 + 
             86834*x^18 + 90387*x^19 - 55161*x^20 - 68904*x^21 - 1728*x^22 + 
             19800*x^23 + 9000*x^24) + 2880*x^11*(6 - 15*x - 180*x^2 - 
             735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 15*x^7 + 6*x^8)*
            Zeta[3]))/(97200*x^11*(-1 + x^2)^6) + 
        (HPL[{0}, x]*(-3542940000 - 7794468000*x + 143972484480*x^2 + 
           342367676640*x^3 - 2322060065820*x^4 - 6228404932860*x^5 + 
           18530778719520*x^6 + 60991418026260*x^7 + 
           135*(-529140974287 + 2201580*Pi^2)*x^8 + 
           27*(-13074795032687 + 46801800*Pi^2)*x^9 + 
           160*(17968254167025 + 5432102454149*Pi^2)*x^21 + 
           9*(39522027098661 + 160107440723500*Pi^2)*x^33 - 
           45*(-1592389942491 + 2492934038248*Pi^2)*x^34 - 
           45*(1356403134213 + 12092052073208*Pi^2)*x^35 - 
           1440*(12868596333 + 33545681074*Pi^2)*x^36 + 
           180*(34602249627 + 767812635760*Pi^2)*x^37 + 
           180*(12900333699 + 166991188240*Pi^2)*x^38 - 
           3240*(105669036 + 6918554897*Pi^2)*x^39 - 
           1620*(88871904 + 4293176233*Pi^2)*x^40 + 
           12028500*(648 + 182107*Pi^2)*x^41 + 218700*(16200 + 3759073*Pi^2)*
            x^42 - 116720714880*Pi^2*x^43 - 49171808160*Pi^2*x^44 + 
           2598156000*Pi^2*x^45 + 1180980000*Pi^2*x^46 + 
           x^25*(-3632488794564871 + 2570737937974540*Pi^2 - 
             316132844544000*Zeta[3]) - 8*x^23*(-3694805515306738 + 
             184152482412615*Pi^2 - 94270706928000*Zeta[3]) + 
           60*x^20*(56224061917471 + 9096693087120*Pi^2 - 15661773273600*
              Zeta[3]) - 60*x^22*(-337204009992359 + 13515648158256*Pi^2 - 
             15661773273600*Zeta[3]) + 120*x^14*(-16877131313671 + 
             13138155630*Pi^2 - 181618977600*Zeta[3]) + 
           60*x^29*(56834337304203 + 59522421102260*Pi^2 - 
             61977830400*Zeta[3]) - 2*x^31*(662224570830711 + 
             1336120893738980*Pi^2 - 51018336000*Zeta[3]) - 
           180*x^12*(-2385143958973 + 731567700*Pi^2 - 9762768000*Zeta[3]) - 
           135*x^10*(-526957133407 + 10994940*Pi^2 + 377913600*Zeta[3]) - 
           27*x^11*(-47061687152261 + 1468740600*Pi^2 + 3779136000*Zeta[3]) + 
           180*x^13*(-16473253885841 + 2627699940*Pi^2 + 20659276800*
              Zeta[3]) - 40*x^30*(11314941798951 + 47405404492934*Pi^2 + 
             43932456000*Zeta[3]) + x^32*(-75410670010995 + 
             758812804774240*Pi^2 + 51018336000*Zeta[3]) + 
           20*x^28*(152767374636561 + 143298639254732*Pi^2 + 
             1089713865600*Zeta[3]) - 5*x^18*(1581982977234319 + 
             24706000356552*Pi^2 + 6695132889600*Zeta[3]) + 
           5*x^24*(3992001507310129 + 397833609725520*Pi^2 + 
             6695132889600*Zeta[3]) + 15*x^16*(319131100512073 + 
             229980766640*Pi^2 + 7001875872000*Zeta[3]) - 
           15*x^26*(812638715301763 + 193455069571464*Pi^2 + 
             7001875872000*Zeta[3]) - 6*x^15*(-749496209142359 + 
             572266520100*Pi^2 + 8521321824000*Zeta[3]) + 
           x^27*(-5321663491206279 - 3508633495451960*Pi^2 + 
             51127930944000*Zeta[3]) + x^17*(-3975364987749329 + 
             28708663786740*Pi^2 + 316132844544000*Zeta[3]) - 
           x^19*(80133933322079 + 220927597424520*Pi^2 + 754165655424000*
              Zeta[3])))/(972000*x^7*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) - 
        (2400*Pi^4*x^9*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
            15*x^7 + 6*x^8) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^4*
           (-270000 - 594000*x + 1266840*x^2 + 4740120*x^3 - 693450*x^4 - 
            16666650*x^5 - 7913175*x^6 + 33911475*x^7 + 25135965*x^8 - 
            44103356*x^9 - 37760645*x^10 + 37860569*x^11 + 27879025*x^12 - 
            27900970*x^13 - 30780200*x^14 + 30780200*x^16 + 27900970*x^17 - 
            27879025*x^18 - 37860569*x^19 + 37760645*x^20 + 44103356*x^21 - 
            25135965*x^22 - 33911475*x^23 + 7913175*x^24 + 16666650*x^25 + 
            693450*x^26 - 4740120*x^27 - 1266840*x^28 + 594000*x^29 + 
            270000*x^30) + 3*x^2*(-3542940000 - 7794468000*x + 
            145153464480*x^2 + 344965832640*x^3 - 2369608026480*x^4 - 
            6341553183240*x^5 + 19284819118650*x^6 + 
            x^27*(5742981159048390 - 42420021592190400*Zeta[3]) + 
            x^31*(1347369154107876 - 32081420328859200*Zeta[3]) + 
            x^21*(11614536438903452 - 7941702242791680*Zeta[3]) + 
            x^23*(28738598169585144 - 3678361481985600*Zeta[3]) - 
            1400648578560*x^43*Zeta[3] - 590061697920*x^44*Zeta[3] + 
            31177872000*x^45*Zeta[3] + 14171760000*x^46*Zeta[3] + 
            144342000*x^41*(-54 + 182107*Zeta[3]) - 38880*x^7*
             (-1622246780 + 345141*Zeta[3]) + 2624400*x^42*
             (-1350 + 3759073*Zeta[3]) + 135*x^8*(-570535962127 + 
              469907568*Zeta[3]) - 19440*x^40*(-7466742 + 4293176233*Zeta[
                3]) - 38880*x^39*(-8872578 + 6918554897*Zeta[3]) - 
            45*x^10*(-1885832217637 + 25725360240*Zeta[3]) + 
            27*x^9*(-13833843387269 + 30739804560*Zeta[3]) - 
            270*x^12*(-1789254468041 + 37258932096*Zeta[3]) - 
            4320*x^36*(-4464594495 + 134182724296*Zeta[3]) + 
            2160*x^38*(-1097040753 + 166991188240*Zeta[3]) + 
            1200*x^14*(-1870783348225 + 311971986432*Zeta[3]) - 
            18*x^11*(-76460677624357 + 992724219360*Zeta[3]) + 
            1080*x^37*(-5871808503 + 1535625271520*Zeta[3]) + 
            54*x^13*(-57882551245857 + 3066406950080*Zeta[3]) - 
            1350*x^35*(-46656303759 + 4836828249920*Zeta[3]) + 
            180*x^20*(78265511654881 + 5305616191936*Zeta[3]) - 
            60*x^15*(-61401871099079 + 8433146279408*Zeta[3]) - 
            135*x^34*(572154849997 + 9971355649984*Zeta[3]) - 
            90*x^22*(-315444851437077 + 161659618001536*Zeta[3]) + 
            234*x^29*(-13417916060367 + 183710099550080*Zeta[3]) - 
            5*x^17*(378640617885509 + 318823619910816*Zeta[3]) - 
            60*x^30*(-5608245841767 + 379449418873504*Zeta[3]) - 
            5*x^16*(-734431922952509 + 602936886426624*Zeta[3]) + 
            15*x^32*(6201268150881 + 606994347598592*Zeta[3]) + 
            27*x^33*(-13727422703669 + 640454216385760*Zeta[3]) + 
            35*x^25*(-419933449980227 + 814283342153472*Zeta[3]) + 
            30*x^28*(-29638420587535 + 1158898628399296*Zeta[3]) + 
            5*x^18*(-951034469785193 + 1604973185370432*Zeta[3]) + 
            6*x^19*(560919705422849 + 1812586452515200*Zeta[3]) + 
            5*x^24*(711589067496277 + 6617818296393696*Zeta[3]) - 
            5*x^26*(475666584549541 + 7576362914806368*Zeta[3])))/
         (11664000*x^9*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4)) + 
      CA*CF*((Pi^2*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 
           180*x^6 - 15*x^7 + 6*x^8)*HPL[{-2}, x])/(810*(-1 + x^2)^6) + 
        lm^2*((-11*(2 - 5*x - 28*x^2 - 145*x^3 - 188*x^4 - 145*x^5 - 28*x^6 - 
             5*x^7 + 2*x^8))/(360*(-1 + x^2)^6) - 
          (11*x^3*(1 + x + x^2)^2*HPL[{0}, x])/(3*(-1 + x^2)^7)) + 
        (Pi^2*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 180*x^6 + 
           15*x^7 - 6*x^8)*HPL[{2}, x])/(810*(-1 + x^2)^6) + 
        (x*(2265 + 9630*x + 26775*x^2 - 1770*x^3 + 316980*x^4 + 405760*x^5 + 
           166020*x^6 - 171450*x^7 + 279600*x^8 + 331656*x^9 - 277566*x^10 - 
           360012*x^11 + 177380*x^12 + 259960*x^13 - 52300*x^14 - 
           120380*x^15 - 5815*x^16 + 32490*x^17 + 8505*x^18 - 3888*x^19 - 
           1728*x^20)*HPL[{-2, 0}, x])/(8100*(-1 + x^2)^8) + 
        ((51840 + 116640*x - 177390*x^2 - 799740*x^3 - 113235*x^4 + 
           2363190*x^5 + 1470900*x^6 + (-3787973 + 3600*Pi^2)*x^7 - 
           (4037921 + 9000*Pi^2)*x^8 - 9*(-232171 + 12400*Pi^2)*x^9 - 
           4*(358669 + 108000*Pi^2)*x^10 - 4*(1427899 + 121800*Pi^2)*x^11 - 
           10722516*x^12 + (-5711596 + 487200*Pi^2)*x^13 + 
           4*(-358669 + 108000*Pi^2)*x^14 + 9*(232171 + 12400*Pi^2)*x^15 + 
           (-4037921 + 9000*Pi^2)*x^16 - (3787973 + 3600*Pi^2)*x^17 + 
           1470900*x^18 + 2363190*x^19 - 113235*x^20 - 799740*x^21 - 
           177390*x^22 + 116640*x^23 + 51840*x^24)*HPL[{-1, 0}, x])/
         (486000*x^7*(-1 + x^2)^7) + (x*(2674919700 + 12871501020*x + 
           70110911610*x^2 - 105760312875*x^3 - 3766497902910*x^4 - 
           6436326930300*x^5 + 39388760396550*x^6 + 119444922415530*x^7 - 
           37202075851050*x^8 - 631028278141944*x^9 - 926807687217348*x^10 + 
           241614115988259*x^11 - 257426335483434*x^12 + 1008962161829476*
            x^13 + 17563852149472966*x^14 + 22709569646200004*x^15 + 
           8963276043461332*x^16 - 6767036146062724*x^17 - 
           4567893147161510*x^18 + 641170111227211*x^19 + 
           311857715754342*x^20 - 386066220833316*x^21 + 71532039771066*
            x^22 + 239326294042746*x^23 + 12341103510006*x^24 - 
           71936777906496*x^25 - 14233354561728*x^26 + 12399118168221*x^27 + 
           3652453624050*x^28 - 1248188390820*x^29 - 451998246870*x^30 + 
           67804785720*x^31 + 27799088220*x^32 - 1530550080*x^33 - 
           680244480*x^34)*HPL[{0, 0}, x])/(486000*(-1 + x^2)^8*
          (9 - 82*x^2 + 9*x^4)^4) + ((-51840 - 116640*x + 177390*x^2 + 
           799740*x^3 + 113235*x^4 - 2363190*x^5 - 1470900*x^6 + 
           (3787973 - 3600*Pi^2)*x^7 + (4037921 + 9000*Pi^2)*x^8 + 
           9*(-232171 + 12400*Pi^2)*x^9 + 4*(358669 + 108000*Pi^2)*x^10 + 
           (5711596 + 487200*Pi^2)*x^11 + 10722516*x^12 + 
           (5711596 - 487200*Pi^2)*x^13 + (1434676 - 432000*Pi^2)*x^14 - 
           9*(232171 + 12400*Pi^2)*x^15 + (4037921 - 9000*Pi^2)*x^16 + 
           (3787973 + 3600*Pi^2)*x^17 - 1470900*x^18 - 2363190*x^19 + 
           113235*x^20 + 799740*x^21 + 177390*x^22 - 116640*x^23 - 
           51840*x^24)*HPL[{1, 0}, x])/(486000*x^7*(-1 + x^2)^7) + 
        lm*((-3340 + 4203*x + 33406*x^2 + 208017*x^3 + 272820*x^4 + 
            208017*x^5 + 33406*x^6 + 4203*x^7 - 3340*x^8 - 
            44*Pi^2*(-2 + 5*x + 14*x^2 + 15*x^3 - 15*x^5 - 14*x^6 - 5*x^7 + 
              2*x^8))/(12960*(-1 + x^2)^6) + 
          (x^2*(22 - 6199*x - 12068*x^2 - 22117*x^3 - 17348*x^4 - 10819*x^5 - 
             968*x^6 - 165*x^7 + 66*x^8)*HPL[{0}, x])/(270*(-1 + x^2)^7) + 
          (11*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 5*x^5 + 2*x^6)*
            HPL[{-1, 0}, x])/(270*(-1 + x^2)^5) + 
          (11*x^3*(180 + 360*x + 1260*x^2 + 1560*x^3 + 1940*x^4 + 1050*x^5 + 
             545*x^6 + 18*x^7 + 5*x^8 - 2*x^9)*HPL[{0, 0}, x])/
           (135*(-1 + x^2)^8) - (11*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 
             5*x^5 + 2*x^6)*HPL[{1, 0}, x])/(270*(-1 + x^2)^5)) + 
        (x*(-2265 - 9630*x - 26775*x^2 + 1770*x^3 - 316980*x^4 - 405760*x^5 - 
           166020*x^6 + 171450*x^7 - 279600*x^8 - 331656*x^9 + 277566*x^10 + 
           360012*x^11 - 177380*x^12 - 259960*x^13 + 52300*x^14 + 
           120380*x^15 + 5815*x^16 - 32490*x^17 - 8505*x^18 + 3888*x^19 + 
           1728*x^20)*HPL[{2, 0}, x])/(8100*(-1 + x^2)^8) + 
        (2*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 180*x^6 + 
           15*x^7 - 6*x^8)*HPL[{-2, -1, 0}, x])/(135*(-1 + x^2)^6) + 
        (8*x^2*(-69 - 345*x - 496*x^2 - 390*x^3 - 111*x^4 - 15*x^5 + 6*x^6)*
          HPL[{-2, 0, 0}, x])/(135*(-1 + x^2)^6) + 
        (2*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{-2, 1, 0}, x])/(135*(-1 + x^2)^6) + 
        (2*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{-1, -2, 0}, x])/(135*(-1 + x^2)^6) + 
        ((1728 + 3888*x - 3321*x^2 - 20826*x^3 - 9332*x^4 + 46238*x^5 + 
           35995*x^6 - 54880*x^7 - 44720*x^8 + 34512*x^9 + 31654*x^10 + 
           4268*x^11 + 15592*x^12 + 4268*x^13 + 31654*x^14 + 34512*x^15 - 
           44720*x^16 - 54880*x^17 + 35995*x^18 + 46238*x^19 - 9332*x^20 - 
           20826*x^21 - 3321*x^22 + 3888*x^23 + 1728*x^24)*
          HPL[{-1, -1, 0}, x])/(16200*x^9*(-1 + x^2)^5) - 
        ((2116 + 17441*x + 29292*x^2 + 159440*x^3 + 48328*x^4 - 47208*x^5 + 
           71328*x^6 + 290800*x^7 - 66948*x^8 - 177564*x^9 + 154460*x^10 + 
           166848*x^11 - 124708*x^12 - 94812*x^13 + 54372*x^14 + 38368*x^15 - 
           10728*x^16 - 11097*x^17 + 432*x^18 + 1728*x^19)*
          HPL[{-1, 0, 0}, x])/(8100*(-1 + x)^8*(1 + x)^6) - 
        ((1728 + 3888*x - 3321*x^2 - 20826*x^3 - 9332*x^4 + 46238*x^5 + 
           35995*x^6 - 54880*x^7 - 44720*x^8 + 34512*x^9 + 31654*x^10 + 
           4268*x^11 + 15592*x^12 + 4268*x^13 + 31654*x^14 + 34512*x^15 - 
           44720*x^16 - 54880*x^17 + 35995*x^18 + 46238*x^19 - 9332*x^20 - 
           20826*x^21 - 3321*x^22 + 3888*x^23 + 1728*x^24)*
          HPL[{-1, 1, 0}, x])/(16200*x^9*(-1 + x^2)^5) + 
        (2*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 180*x^6 + 
           15*x^7 - 6*x^8)*HPL[{-1, 2, 0}, x])/(135*(-1 + x^2)^6) + 
        (x*(-14860665 - 58458510*x - 1951121115*x^2 - 3336974172*x^3 + 
           64111056930*x^4 + 149305544082*x^5 - 548692063938*x^6 - 
           1774862278542*x^7 - 94067362203*x^8 + 6061409878068*x^9 + 
           12673655626671*x^10 + 11567647290198*x^11 + 34985267972676*x^12 - 
           2044866072348*x^13 - 320758014106228*x^14 - 461342962598756*x^15 - 
           289293076319281*x^16 + 55108552721110*x^17 + 171616962132977*
            x^18 + 79356051836384*x^19 - 49195324794598*x^20 - 
           56615699018294*x^21 + 14514398638454*x^22 + 27946246684762*x^23 - 
           2407021148905*x^24 - 10410505393032*x^25 - 762172214787*x^26 + 
           2662040150982*x^27 + 539786179440*x^28 - 434956695264*x^29 - 
           129205483344*x^30 + 42732107928*x^31 + 15528036798*x^32 - 
           2285668692*x^33 - 937973682*x^34 + 51018336*x^35 + 22674816*x^36)*
          HPL[{0, 0, 0}, x])/(8100*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        (2*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 180*x^6 + 
           15*x^7 - 6*x^8)*HPL[{1, -2, 0}, x])/(135*(-1 + x^2)^6) - 
        ((1728 + 3888*x - 3321*x^2 - 20826*x^3 - 9332*x^4 + 46238*x^5 + 
           35995*x^6 - 54880*x^7 - 44720*x^8 + 34512*x^9 + 31654*x^10 + 
           4268*x^11 + 15592*x^12 + 4268*x^13 + 31654*x^14 + 34512*x^15 - 
           44720*x^16 - 54880*x^17 + 35995*x^18 + 46238*x^19 - 9332*x^20 - 
           20826*x^21 - 3321*x^22 + 3888*x^23 + 1728*x^24)*
          HPL[{1, -1, 0}, x])/(16200*x^9*(-1 + x^2)^5) + 
        ((2116 + 23025*x + 117424*x^2 + 413688*x^3 + 813652*x^4 + 
           1015848*x^5 + 693204*x^6 + 350152*x^7 + 300280*x^8 + 196148*x^9 - 
           168400*x^10 - 237624*x^11 + 56600*x^12 + 173444*x^13 + 
           30328*x^14 - 60488*x^15 - 30924*x^16 + 4455*x^17 + 7344*x^18 + 
           1728*x^19)*HPL[{1, 0, 0}, x])/(8100*(-1 + x)^6*(1 + x)^8) + 
        ((1728 + 3888*x - 3321*x^2 - 20826*x^3 - 9332*x^4 + 46238*x^5 + 
           35995*x^6 - 54880*x^7 - 44720*x^8 + 34512*x^9 + 31654*x^10 + 
           4268*x^11 + 15592*x^12 + 4268*x^13 + 31654*x^14 + 34512*x^15 - 
           44720*x^16 - 54880*x^17 + 35995*x^18 + 46238*x^19 - 9332*x^20 - 
           20826*x^21 - 3321*x^22 + 3888*x^23 + 1728*x^24)*HPL[{1, 1, 0}, x])/
         (16200*x^9*(-1 + x^2)^5) + (2*(6 - 15*x - 180*x^2 - 735*x^3 - 
           992*x^4 - 735*x^5 - 180*x^6 - 15*x^7 + 6*x^8)*HPL[{1, 2, 0}, x])/
         (135*(-1 + x^2)^6) + (2*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 
           735*x^5 - 180*x^6 - 15*x^7 + 6*x^8)*HPL[{2, -1, 0}, x])/
         (135*(-1 + x^2)^6) + (8*x^2*(69 + 345*x + 496*x^2 + 390*x^3 + 
           111*x^4 + 15*x^5 - 6*x^6)*HPL[{2, 0, 0}, x])/(135*(-1 + x^2)^6) + 
        (2*(-6 + 15*x + 180*x^2 + 735*x^3 + 992*x^4 + 735*x^5 + 180*x^6 + 
           15*x^7 - 6*x^8)*HPL[{2, 1, 0}, x])/(135*(-1 + x^2)^6) + 
        ((-8 + 20*x + 48*x^2 + 80*x^3 + 48*x^4 + 20*x^5 - 8*x^6)*
          HPL[{-1, 0, 0, 0}, x])/(45*(-1 + x^2)^5) + 
        (4*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{-1, 1, 0, 0}, x])/(135*(-1 + x^2)^6) + 
        (4*(6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
           15*x^7 + 6*x^8)*HPL[{1, -1, 0, 0}, x])/(135*(-1 + x^2)^6) + 
        (4*(2 - 5*x - 12*x^2 - 20*x^3 - 12*x^4 - 5*x^5 + 2*x^6)*
          HPL[{1, 0, 0, 0}, x])/(45*(-1 + x^2)^5) + 
        ((-12 + 59*x + 288*x^2 + 2032*x^3 + 3056*x^4 + 3408*x^5 + 1432*x^6 + 
           592*x^7 - 84*x^8 + 29*x^9)*master3l10a[x])/(1080*(-1 + x^2)^7) + 
        (x*(-29 + 84*x - 592*x^2 - 1432*x^3 - 3408*x^4 - 3056*x^5 - 
           2032*x^6 - 288*x^7 - 59*x^8 + 12*x^9)*master3l10b[x])/
         (1080*(-1 + x^2)^7) - ((18254889 + 105470991*x + 300347757*x^2 + 
           382662549*x^3 + 116505*x^4 + 2498499*x^5 + 73616445*x^6 + 
           43746489*x^7 - 42249717*x^8 - 32410419*x^9 + 7137951*x^10 + 
           6597295*x^11 - 371045*x^12 - 546655*x^13 - 10313*x^14 + 
           16323*x^15 + 1048*x^16)*master3l8a[x])/(32400*(-9 + x^2)^4*
          (-1 + x^2)^8) - ((1510 + 5132*x - 53133*x^2 - 205139*x^3 + 
           721473*x^4 + 3009345*x^5 - 5808417*x^6 - 20867427*x^7 + 
           43093641*x^8 + 88829313*x^9 - 247173111*x^10 - 394340481*x^11 + 
           457334163*x^12 + 1164732939*x^13 + 1015853157*x^14 + 
           309744567*x^15 + 78339069*x^16 - 13530969*x^17)*master3l8b[x])/
         (32400*x*(1 - 9*x^2)^4*(-1 + x^2)^8) + 
        ((1765881 + 1507329*x - 325836*x^2 - 35009775*x^3 - 64737117*x^4 - 
           29158623*x^5 + 18804594*x^6 + 12922353*x^7 - 5192769*x^8 - 
           2758853*x^9 + 978880*x^10 + 382667*x^11 - 79035*x^12 - 
           27933*x^13 + 2042*x^14 + 755*x^15)*master3l9a[x])/
         (10800*(-9 + x^2)^3*(-1 + x^2)^8) + 
        ((755 + 2042*x - 27933*x^2 - 79035*x^3 + 382667*x^4 + 978880*x^5 - 
           2758853*x^6 - 5192769*x^7 + 12922353*x^8 + 18804594*x^9 - 
           29158623*x^10 - 64737117*x^11 - 35009775*x^12 - 325836*x^13 + 
           1507329*x^14 + 1765881*x^15)*master3l9b[x])/(32400*x*(-1 + x^2)^8*
          (-1 + 9*x^2)^3) + (HPL[{1}, x]*(Pi^2*(-1728 - 3888*x + 5049*x^2 + 
             24714*x^3 + 6011*x^4 - 67064*x^5 - 45327*x^6 + 101118*x^7 + 
             80715*x^8 - 89392*x^9 - 76374*x^10 + 30244*x^11 + 16062*x^12 - 
             16062*x^14 - 30244*x^15 + 76374*x^16 + 89392*x^17 - 80715*x^18 - 
             101118*x^19 + 45327*x^20 + 67064*x^21 - 6011*x^22 - 24714*x^23 - 
             5049*x^24 + 3888*x^25 + 1728*x^26) - 2880*x^9*
            (6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
             15*x^7 + 6*x^8)*Zeta[3]))/(194400*x^9*(-1 + x^2)^6) + 
        (HPL[{-1}, x]*(Pi^2*(1728 + 3888*x - 5049*x^2 - 24714*x^3 - 
             6011*x^4 + 67064*x^5 + 45327*x^6 - 101118*x^7 - 80715*x^8 + 
             89392*x^9 + 76374*x^10 - 30244*x^11 - 16062*x^12 + 16062*x^14 + 
             30244*x^15 - 76374*x^16 - 89392*x^17 + 80715*x^18 + 
             101118*x^19 - 45327*x^20 - 67064*x^21 + 6011*x^22 + 24714*x^23 + 
             5049*x^24 - 3888*x^25 - 1728*x^26) + 2880*x^9*
            (6 - 15*x - 180*x^2 - 735*x^3 - 992*x^4 - 735*x^5 - 180*x^6 - 
             15*x^7 + 6*x^8)*Zeta[3]))/(194400*x^9*(-1 + x^2)^6) + 
        (HPL[{0}, x]*(-680244480 - 1530550080*x + 27458965980*x^2 + 
           67039510680*x^3 - 438325450920*x^4 - 1214796181320*x^5 - 
           3645*(-937890163 + 81540*Pi^2)*x^6 - 4374*(-2683769423 + 
             288900*Pi^2)*x^7 - 80*(21805317383055 + 6446942021368*Pi^2)*
            x^19 - 54*(268250229063 + 1919604504760*Pi^2)*x^31 - 
           45*(81105790293 + 168474590656*Pi^2)*x^32 + 
           405*(3117272769 + 65709804208*Pi^2)*x^33 + 
           1080*(405856899 + 4998020180*Pi^2)*x^34 - 
           29160*(2299023 + 149162104*Pi^2)*x^35 - 
           4860*(5649993 + 265854904*Pi^2)*x^36 + 42515280*(36 + 10051*Pi^2)*
            x^37 + 393660*(1728 + 394453*Pi^2)*x^38 - 22856686920*Pi^2*x^39 - 
           9379736820*Pi^2*x^40 + 510183360*Pi^2*x^41 + 226748160*Pi^2*x^42 + 
           x^30*(-24927820932760*Pi^2 + 81*(200454178421 - 629856000*
                Zeta[3])) + x^25*(906199721805507 + 637554126015240*Pi^2 - 
             51127930944000*Zeta[3]) + 60*x^20*(-462124407227617 + 
             1513773724096*Pi^2 - 15661773273600*Zeta[3]) - 
           60*x^18*(-81347229507967 + 4482140395104*Pi^2 - 15661773273600*
              Zeta[3]) + 2*x^29*(59688763379973 + 135280027675220*Pi^2 - 
             51018336000*Zeta[3]) - 80*x^27*(7970948963865 + 
             6146691248278*Pi^2 - 46483372800*Zeta[3]) - 
           64800*x^11*(-2726817334 + 10743111*Pi^2 + 57386880*Zeta[3]) + 
           243*x^9*(-263400986897 + 190474200*Pi^2 + 419904000*Zeta[3]) + 
           81*x^8*(-145498027871 + 90350100*Pi^2 + 629856000*Zeta[3]) - 
           108*x^10*(94678281157 + 581229000*Pi^2 + 16271280000*Zeta[3]) + 
           8*x^28*(4168839402207 + 17971623674980*Pi^2 + 219662280000*
              Zeta[3]) + 24*x^12*(12511949066219 + 27573363000*Pi^2 + 
             908094888000*Zeta[3]) - 4*x^26*(339883554413739 + 
             84162287278480*Pi^2 + 5448569328000*Zeta[3]) - 
           15*x^14*(103282964014319 + 763908420200*Pi^2 + 7001875872000*
              Zeta[3]) + 15*x^24*(616588580857829 + 31296625057040*Pi^2 + 
             7001875872000*Zeta[3]) + 6*x^13*(-3609634427297 + 
             1006779145500*Pi^2 + 8521321824000*Zeta[3]) + 
           x^16*(3242170324587989 + 94019279407920*Pi^2 + 33475664448000*
              Zeta[3]) - x^22*(16319157009877739 + 368167922879880*Pi^2 + 
             33475664448000*Zeta[3]) - 2*x^15*(769197310864079 + 
             19149032732760*Pi^2 + 158066422272000*Zeta[3]) + 
           x^23*(9259764669935758 - 606567082856160*Pi^2 + 316132844544000*
              Zeta[3]) + x^17*(5034369301986347 + 185625131609280*Pi^2 + 
             754165655424000*Zeta[3]) + 4*x^21*(126510282730800*Pi^2 - 
             37*(241905159761339 + 5095713888000*Zeta[3]))))/
         (1944000*x^5*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        (480*Pi^4*x^7*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (-18 + 45*x - 564*x^2 - 3315*x^3 - 4960*x^4 - 4035*x^5 - 
            1236*x^6 - 195*x^7 + 78*x^8) - 4*Pi^2*(9 - 82*x^2 + 9*x^4)^4*
           (-51840 - 116640*x + 229230*x^2 + 916380*x^3 - 64155*x^4 - 
            3162930*x^5 - 1584135*x^6 + 6151163*x^7 + 5508821*x^8 - 
            5877512*x^9 - 2603245*x^10 + 7801135*x^11 + 9287840*x^12 - 
            9287840*x^14 - 7801135*x^15 + 2603245*x^16 + 5877512*x^17 - 
            5508821*x^18 - 6151163*x^19 + 1584135*x^20 + 3162930*x^21 + 
            64155*x^22 - 916380*x^23 - 229230*x^24 + 116640*x^25 + 
            51840*x^26) - 3*x^2*(-680244480 - 1530550080*x + 
            27685714140*x^2 + 67549694040*x^3 - 445164309270*x^4 + 
            x^16*(76409282282257 - 10050554898714240*Zeta[3]) + 
            x^27*(30576940357284 - 6068866013710080*Zeta[3]) + 
            x^23*(9979249682777230 - 4419005030417280*Zeta[3]) - 
            274280243040*x^39*Zeta[3] - 112556841840*x^40*Zeta[3] + 
            6122200320*x^41*Zeta[3] + 2720977920*x^42*Zeta[3] + 
            510183360*x^37*(-3 + 10051*Zeta[3]) + 98415*x^5*
             (-13006727 + 173504*Zeta[3]) + 4723920*x^38*
             (-144 + 394453*Zeta[3]) - 3645*x^6*(-904374073 + 
              21056112*Zeta[3]) - 102060*x^36*(-271269 + 151917088*Zeta[3]) - 
            4374*x^7*(-2964906411 + 232013360*Zeta[3]) - 
            87480*x^35*(-772173 + 596648416*Zeta[3]) + 
            81*x^8*(-82620937277 + 17362907280*Zeta[3]) + 
            729*x^9*(-87824694117 + 29262318080*Zeta[3]) + 
            1620*x^34*(-276168771 + 39984161440*Zeta[3]) + 
            54*x^10*(-909622826161 + 221314317120*Zeta[3]) + 
            1215*x^33*(-981985437 + 262851559936*Zeta[3]) - 
            135*x^32*(-26036987841 + 674401967488*Zeta[3]) - 
            108*x^11*(-152243976923 + 1791112715200*Zeta[3]) - 
            162*x^31*(-62315692497 + 7684005705760*Zeta[3]) - 
            24*x^12*(-7434590762363 + 18767661921360*Zeta[3]) + 
            15*x^13*(76430992846965 + 37201165260032*Zeta[3]) + 
            36*x^18*(-336070057290441 + 51475700997280*Zeta[3]) - 
            3*x^30*(4949622796329 + 99333152130880*Zeta[3]) + 
            12*x^28*(8123693604363 + 145029842086880*Zeta[3]) + 
            10*x^15*(-282521797710317 + 214947438001440*Zeta[3]) + 
            18*x^20*(-1466709255217457 + 316425001386560*Zeta[3]) - 
            33*x^17*(6995870286809 + 428349319285760*Zeta[3]) + 
            15*x^25*(-60826933359945 + 536367387855104*Zeta[3]) - 
            6*x^26*(196226203657873 + 751713003481280*Zeta[3]) + 
            8*x^19*(-1738110166595167 + 1837618136025120*Zeta[3]) + 
            x^29*(-35101158880743 + 3265740963897600*Zeta[3]) - 
            3*x^21*(8534647885504249 + 3526658077847680*Zeta[3]) + 
            x^14*(628781277013163 + 3652313631768000*Zeta[3]) + 
            x^24*(6679273814523413 + 9425544762751200*Zeta[3]) - 
            x^22*(8236708404125093 + 15420709017951840*Zeta[3])))/
         (23328000*x^7*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4)))
 
CbarData["a", 2, 3] = 
    NC*(CF*(NL*((Pi^2*(-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 
             42*x^6 + 18*x^7 - 5*x^8)*HPL[{-1}, x])/(4860*(-1 + x^2)^7) + 
          (x^2*(-675 - 27*(48529 + 3000*Pi^2)*x - 18*(168809 + 11250*Pi^2)*
              x^2 - 27*(270661 + 24000*Pi^2)*x^3 - 4*(1733029 + 215625*Pi^2)*
              x^4 - 90*(21271 + 13200*Pi^2)*x^5 + (4933466 - 850950*Pi^2)*
              x^6 + (8094312 - 639900*Pi^2)*x^7 - 27*(-182851 + 7550*Pi^2)*
              x^8 - 9*(-269657 + 9360*Pi^2)*x^9 + (107170 - 1710*Pi^2)*x^10 - 
             45*(-251 + 12*Pi^2)*x^11 + 10*(-626 + 15*Pi^2)*x^12)*
            HPL[{0}, x])/(145800*(-1 + x^2)^10) + 
          lm^2*(-(-5 + 18*x + 115*x^2 + 1068*x^3 + 1990*x^4 + 2868*x^5 + 1990*
                x^6 + 1068*x^7 + 115*x^8 + 18*x^9 - 5*x^10)/
             (720*(-1 + x^2)^8) + (x^3*(6 + 15*x + 36*x^2 + 40*x^3 + 36*x^4 + 
               15*x^5 + 6*x^6)*HPL[{0}, x])/(6*(-1 + x^2)^9)) + 
          (Pi^2*(5 - 18*x - 42*x^2 - 162*x^3 - 186*x^4 - 162*x^5 - 42*x^6 - 
             18*x^7 + 5*x^8)*HPL[{1}, x])/(4860*(-1 + x^2)^7) + 
          (x^3*(2700 + 6750*x + 21600*x^2 + 28750*x^3 + 39600*x^4 + 
             28365*x^5 + 21330*x^6 + 6795*x^7 + 2808*x^8 + 57*x^9 + 18*x^10 - 
             5*x^11)*HPL[{-2, 0}, x])/(405*(-1 + x^2)^10) - 
          ((-75 + 178*x + 6512*x^2 + 148486*x^3 + 320287*x^4 + 731896*x^5 + 
             760792*x^6 + 731896*x^7 + 320287*x^8 + 148486*x^9 + 6512*x^10 + 
             178*x^11 - 75*x^12)*HPL[{-1, 0}, x])/(16200*(-1 + x^2)^9) + 
          (x^3*(-36000 - 90000*x - 369000*x^2 - 563000*x^3 - 980000*x^4 - 
             872225*x^5 - 761850*x^6 - 303375*x^7 - 134892*x^8 - 4463*x^9 - 
             1442*x^10 + 375*x^11)*HPL[{0, 0}, x])/(8100*(-1 + x^2)^10) + 
          ((-75 + 178*x + 6512*x^2 + 148486*x^3 + 320287*x^4 + 731896*x^5 + 
             760792*x^6 + 731896*x^7 + 320287*x^8 + 148486*x^9 + 6512*x^10 + 
             178*x^11 - 75*x^12)*HPL[{1, 0}, x])/(16200*(-1 + x^2)^9) + 
          lm*(-(-1252 + 2259*x + 18795*x^2 + 227844*x^3 + 418525*x^4 + 610722*
                x^5 + 418525*x^6 + 227844*x^7 + 18795*x^8 + 2259*x^9 - 1252*
                x^10 - 6*Pi^2*(-5 + 18*x + 47*x^2 + 144*x^3 + 144*x^4 - 
                 144*x^6 - 144*x^7 - 47*x^8 - 18*x^9 + 5*x^10))/
             (58320*(-1 + x^2)^8) + (x^2*(-10 + 7716*x + 18450*x^2 + 53154*
                x^3 + 64374*x^4 + 69354*x^5 + 35325*x^6 + 17166*x^7 + 1070*
                x^8 + 162*x^9 - 45*x^10)*HPL[{0}, x])/(1620*(-1 + x^2)^9) + 
            ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 18*
                x^7 - 5*x^8)*HPL[{-1, 0}, x])/(810*(-1 + x^2)^7) + 
            (x^3*(-1080 - 2700*x - 13500*x^2 - 22000*x^3 - 39600*x^4 - 35115*
                x^5 - 29430*x^6 - 10845*x^7 - 4428*x^8 - 57*x^9 - 18*x^10 + 5*
                x^11)*HPL[{0, 0}, x])/(405*(-1 + x^2)^10) - 
            ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 18*
                x^7 - 5*x^8)*HPL[{1, 0}, x])/(810*(-1 + x^2)^7)) + 
          (x^3*(-2700 - 6750*x - 21600*x^2 - 28750*x^3 - 39600*x^4 - 
             28365*x^5 - 21330*x^6 - 6795*x^7 - 2808*x^8 - 57*x^9 - 18*x^10 + 
             5*x^11)*HPL[{2, 0}, x])/(405*(-1 + x^2)^10) - 
          ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 
             18*x^7 - 5*x^8)*HPL[{-1, -1, 0}, x])/(405*(-1 + x^2)^7) + 
          ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 
             18*x^7 - 5*x^8)*HPL[{-1, 1, 0}, x])/(405*(-1 + x^2)^7) + 
          (2*x^3*(1080 + 2700*x + 13500*x^2 + 22000*x^3 + 39600*x^4 + 
             35115*x^5 + 29430*x^6 + 10845*x^7 + 4428*x^8 + 57*x^9 + 
             18*x^10 - 5*x^11)*HPL[{0, 0, 0}, x])/(405*(-1 + x^2)^10) + 
          ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 
             18*x^7 - 5*x^8)*HPL[{1, -1, 0}, x])/(405*(-1 + x^2)^7) - 
          ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 
             18*x^7 - 5*x^8)*HPL[{1, 1, 0}, x])/(405*(-1 + x^2)^7) + 
          (-512555*x^12 + 363750*x^13 + 158695*x^14 - 
            36*Pi^2*(-75 + 178*x + 6587*x^2 + 148308*x^3 + 313775*x^4 + 
              583410*x^5 + 440505*x^6 - 440505*x^8 - 583410*x^9 - 
              313775*x^10 - 148308*x^11 - 6587*x^12 - 178*x^13 + 75*x^14) + 
            x^7*(85846056 - 342144000*Zeta[3]) + 
            x^8*(42159877 - 248400000*Zeta[3]) + 
            x^6*(42159877 - 245073600*Zeta[3]) - 
            30*x*(-12125 + 5184*Zeta[3]) + 5*(31739 + 8640*Zeta[3]) - 
            324*x^11*(75157 + 72000*Zeta[3]) - 324*x^3*(75157 + 
              74880*Zeta[3]) - 5*x^2*(102511 + 98496*Zeta[3]) - 
            270*x^5*(70133 + 682560*Zeta[3]) - 270*x^9*(70133 + 
              691200*Zeta[3]) - 27*x^10*(1548371 + 2160000*Zeta[3]) - 
            27*x^4*(1548371 + 2174400*Zeta[3]))/(6998400*(-1 + x^2)^10)) + 
        NH*((x*(-413248521600 + 1755103506768*x - 470910675292164*x^2 - 
             963328705662609*x^3 - 1977193939887810*x^4 - 1762170667632846*
              x^5 - 649824958324890*x^6 + 603299080135476*x^7 + 
             803120910602130*x^8 + 248886617940630*x^9 - 134738215856298*
              x^10 - 156418619879349*x^11 - 25630966127844*x^12 + 
             31335771699684*x^13 + 12066079139532*x^14 - 2602799976816*x^15 - 
             1850635288620*x^16 - 26703154004*x^17 + 146917690200*x^18 + 
             24433582725*x^19 - 6145805178*x^20 - 2150676022*x^21 + 
             104568750*x^22 + 85464188*x^23 + 760122*x^24 - 1380210*x^25 - 
             33930*x^26 + 385*x^27)*HPL[{0}, x])/(583200*(-9 + x^2)^6*
            (-1 + x^2)^11) + lm^2*(-(-5 + 18*x + 115*x^2 + 1068*x^3 + 1990*
                x^4 + 2868*x^5 + 1990*x^6 + 1068*x^7 + 115*x^8 + 18*x^9 - 5*
                x^10)/(720*(-1 + x^2)^8) + (x^3*(6 + 15*x + 36*x^2 + 40*x^3 + 
               36*x^4 + 15*x^5 + 6*x^6)*HPL[{0}, x])/(6*(-1 + x^2)^9)) + 
          (x*(11479125600 - 15942468924*x + 9572760862632*x^2 + 
             19491402723363*x^3 + 39341791697022*x^4 + 33677737348446*x^5 + 
             8773300507302*x^6 - 16804136226438*x^7 - 19905027698250*x^8 - 
             5319974331522*x^9 + 3669992980110*x^10 + 4068252313425*x^11 + 
             877907395596*x^12 - 792899520052*x^13 - 371544816132*x^14 + 
             41623264092*x^15 + 45272794956*x^16 + 6343692032*x^17 - 
             1461852380*x^18 - 1123613387*x^19 - 140358730*x^20 + 
             68147254*x^21 + 12800094*x^22 - 1565430*x^23 - 268194*x^24 - 
             3234*x^25 - 1626*x^26 + 375*x^27)*HPL[{0, 0}, x])/
           (16200*(-9 + x^2)^6*(-1 + x^2)^11) + 
          lm*(-(-1252 + 2259*x + 18795*x^2 + 227844*x^3 + 418525*x^4 + 610722*
                x^5 + 418525*x^6 + 227844*x^7 + 18795*x^8 + 2259*x^9 - 1252*
                x^10 - 6*Pi^2*(-5 + 18*x + 47*x^2 + 144*x^3 + 144*x^4 - 
                 144*x^6 - 144*x^7 - 47*x^8 - 18*x^9 + 5*x^10))/
             (58320*(-1 + x^2)^8) + (x^2*(-10 + 7716*x + 18450*x^2 + 53154*
                x^3 + 64374*x^4 + 69354*x^5 + 35325*x^6 + 17166*x^7 + 1070*
                x^8 + 162*x^9 - 45*x^10)*HPL[{0}, x])/(1620*(-1 + x^2)^9) + 
            ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 18*
                x^7 - 5*x^8)*HPL[{-1, 0}, x])/(810*(-1 + x^2)^7) + 
            (x^3*(-1080 - 2700*x - 13500*x^2 - 22000*x^3 - 39600*x^4 - 35115*
                x^5 - 29430*x^6 - 10845*x^7 - 4428*x^8 - 57*x^9 - 18*x^10 + 5*
                x^11)*HPL[{0, 0}, x])/(405*(-1 + x^2)^10) - 
            ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 18*
                x^7 - 5*x^8)*HPL[{1, 0}, x])/(810*(-1 + x^2)^7)) + 
          ((641 + 17795*x + 37522*x^2 + 102883*x^3 + 110937*x^4 + 
             119363*x^5 + 55152*x^6 + 32803*x^7 + 4487*x^8 + 3908*x^9 + 
             6*x^10 + 28*x^11 - 5*x^12)*HPL[{-1, 0, 0}, x])/
           (405*(-1 + x)^10*(1 + x)^8) + 
          (x^3*(-354029591700 - 699240498831*x - 1433156115942*x^2 - 
             1197153873936*x^3 - 302134781538*x^4 + 630502061022*x^5 + 
             836784824526*x^6 + 264836959776*x^7 - 103180308642*x^8 - 
             170694833841*x^9 - 61733587284*x^10 + 27195063064*x^11 + 
             18662604948*x^12 - 104591716*x^13 - 1682896668*x^14 - 
             435648488*x^15 - 20582064*x^16 + 53137351*x^17 + 13127418*x^18 - 
             2844456*x^19 - 816114*x^20 + 79590*x^21 + 17550*x^22 - 
             1560*x^23 - 90*x^24 + 25*x^25)*HPL[{0, 0, 0}, x])/
           (2025*(-9 + x^2)^6*(-1 + x^2)^11) - 
          ((101 + 17929*x + 40390*x^2 + 106673*x^3 + 135081*x^4 + 
             151909*x^5 + 101052*x^6 + 61565*x^7 + 17723*x^8 + 5056*x^9 + 
             78*x^10 + 8*x^11 - 5*x^12)*HPL[{1, 0, 0}, x])/
           (405*(-1 + x)^8*(1 + x)^10) - ((-9188424621 + 1419421161078*x + 
             2881898457462*x^2 + 6012119012958*x^3 + 5508851357628*x^4 + 
             2590960630626*x^5 - 1036610225694*x^6 - 1857452561910*x^7 - 
             743163988401*x^8 + 196395988140*x^9 + 314937415116*x^10 + 
             59576629500*x^11 - 49649673504*x^12 - 20924512236*x^13 + 
             3113339828*x^14 + 2999904036*x^15 + 112490961*x^16 - 
             237238530*x^17 - 32989346*x^18 + 9753030*x^19 + 2256612*x^20 - 
             131478*x^21 - 64566*x^22 - 1614*x^23 + 525*x^24)*master3l8a[x])/
           (48600*(-9 + x^2)^6*(-1 + x^2)^11) + 
          ((-1020936069 + 79040219742*x + 164710724859*x^2 + 
             358316333424*x^3 + 364361592735*x^4 + 260556377886*x^5 + 
             65417276565*x^6 + 8519273892*x^7 - 16452532476*x^8 - 
             160595028*x^9 - 4767198338*x^10 - 7116793344*x^11 - 
             2971746*x^12 + 1031544924*x^13 + 322353850*x^14 + 
             73961736*x^15 - 48494685*x^16 - 22715658*x^17 + 2754519*x^18 + 
             1476912*x^19 - 75309*x^20 - 31866*x^21 + 2145*x^22 + 180*x^23 - 
             50*x^24)*master3l9a[x])/(16200*(-9 + x^2)^5*(-1 + x^2)^11) + 
          (x^12*(532864317727828 - 91306377691200*Zeta[3]) + 
            x^16*(17599116495503 - 7482350347200*Zeta[3]) + 
            320*x^28*(-137 + 45*Zeta[3]) - 120*x^27*(-4711 + 432*Zeta[3]) - 
            15*x^26*(-734081 + 63744*Zeta[3]) + 6*x^25*(3591343 + 
              164160*Zeta[3]) + 15234642*x*(80990087 + 751680*Zeta[3]) + 
            1240029*(-8721347 + 2531520*Zeta[3]) + 108*x^23*
             (-20884019 + 2844480*Zeta[3]) + x^24*(-457429043 + 
              25721280*Zeta[3]) + 19683*x^2*(127403584793 + 256193280*Zeta[
                3]) + x^22*(7364701874 + 256296960*Zeta[3]) - 
            24*x^21*(-2644307081 + 619892640*Zeta[3]) - 131220*x^3*
             (-53340849793 + 1526094432*Zeta[3]) - 18*x^20*(1292357633 + 
              1629100960*Zeta[3]) - 118098*x^4*(-71567279447 + 
              3828593760*Zeta[3]) - 29160*x^5*(-324076931161 + 
              20616050016*Zeta[3]) + 12*x^19*(-78082409761 + 23637434400*Zeta[
                3]) - 54*x^17*(-150275435207 + 48075595200*Zeta[3]) + 
            192*x^13*(81657330119 + 121967836200*Zeta[3]) - 
            1458*x^6*(-3634516174841 + 129516871680*Zeta[3]) - 
            1296*x^11*(-552930619123 + 207183828600*Zeta[3]) + 
            24*x^15*(-1548834622903 + 381961944000*Zeta[3]) + 
            972*x^7*(283660807369 + 561433446720*Zeta[3]) + 
            x^18*(-985180325267 + 672726931200*Zeta[3]) - 
            81*x^10*(4998369064727 + 1963081939200*Zeta[3]) + 
            243*x^8*(-13450499534279 + 3487693060800*Zeta[3]) + 
            12*x^14*(-11604967223311 + 3537360115200*Zeta[3]) + 
            54*x^9*(-51480825262123 + 8935288459200*Zeta[3]))/
           (3499200*(-9 + x^2)^6*(-1 + x^2)^11)) + 
        NM*(-((34200 - 123120*x - 1909980*x^2 + 20366388*x^3 + 
              79738677*x^4 - 985943070*x^5 - 2770962178*x^6 + 
              17152990218*x^7 + 52320700980*x^8 - 65742495570*x^9 - 
              425658009506*x^10 - 1286336800710*x^11 + 23076510121*x^12 + 
              13925084929668*x^13 + 19759294210236*x^14 - 22264496035596*x^
                15 - 79136866926376*x^16 - 199400085648612*x^17 - 
              136002545806320*x^18 + 375735040810200*x^19 + 731268123570279*x^
                20 + 1365671521473210*x^21 + 1047691314795366*x^22 + 
              788303526012450*x^23 + 373699946404764*x^24 + 122278700172294*x^
                25 + 47684164802382*x^26 + 2321372669850*x^27 - 
              5361921120645*x^28 + 120*Pi^2*(1 - 9*x^2)^6*(-1 + x^2)^4*(5 - 
                18*x - 42*x^2 - 162*x^3 - 186*x^4 - 162*x^5 - 42*x^6 - 
                18*x^7 + 5*x^8))*HPL[{0}, x])/(583200*(1 - 9*x^2)^6*
            (-1 + x^2)^11) + lm^2*(-(-5 + 18*x + 115*x^2 + 1068*x^3 + 1990*
                x^4 + 2868*x^5 + 1990*x^6 + 1068*x^7 + 115*x^8 + 18*x^9 - 5*
                x^10)/(720*(-1 + x^2)^8) + (x^3*(6 + 15*x + 36*x^2 + 40*x^3 + 
               36*x^4 + 15*x^5 + 6*x^6)*HPL[{0}, x])/(6*(-1 + x^2)^9)) - 
          ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 
             18*x^7 - 5*x^8)*HPL[{-2, 0}, x])/(405*(-1 + x^2)^7) + 
          ((600 - 2160*x - 30440*x^2 + 469104*x^3 + 1490311*x^4 - 
             19503306*x^5 - 50698138*x^6 + 188045422*x^7 + 676920218*x^8 + 
             2890086878*x^9 + 1281308730*x^10 - 66784251330*x^11 - 
             113278125491*x^12 + 343625949852*x^13 + 921580615004*x^14 + 
             994200938988*x^15 - 1072098930636*x^16 - 11617064162388*x^17 - 
             14086047257172*x^18 + 5582375380908*x^19 + 29866503937905*x^20 + 
             77596738495470*x^21 + 67784647663134*x^22 + 58596227641638*
              x^23 + 30189092938938*x^24 + 11280962934054*x^25 + 
             3715280162082*x^26 + 135424748070*x^27 - 413000811045*x^28)*
            HPL[{0, 0}, x])/(16200*(1 - 9*x^2)^6*(-1 + x^2)^11) + 
          lm*(-(-1252 + 2259*x + 18795*x^2 + 227844*x^3 + 418525*x^4 + 610722*
                x^5 + 418525*x^6 + 227844*x^7 + 18795*x^8 + 2259*x^9 - 1252*
                x^10 - 6*Pi^2*(-5 + 18*x + 47*x^2 + 144*x^3 + 144*x^4 - 
                 144*x^6 - 144*x^7 - 47*x^8 - 18*x^9 + 5*x^10))/
             (58320*(-1 + x^2)^8) + (x^2*(-10 + 7716*x + 18450*x^2 + 53154*
                x^3 + 64374*x^4 + 69354*x^5 + 35325*x^6 + 17166*x^7 + 1070*
                x^8 + 162*x^9 - 45*x^10)*HPL[{0}, x])/(1620*(-1 + x^2)^9) + 
            ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 18*
                x^7 - 5*x^8)*HPL[{-1, 0}, x])/(810*(-1 + x^2)^7) + 
            (x^3*(-1080 - 2700*x - 13500*x^2 - 22000*x^3 - 39600*x^4 - 35115*
                x^5 - 29430*x^6 - 10845*x^7 - 4428*x^8 - 57*x^9 - 18*x^10 + 5*
                x^11)*HPL[{0, 0}, x])/(405*(-1 + x^2)^10) - 
            ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 18*
                x^7 - 5*x^8)*HPL[{1, 0}, x])/(810*(-1 + x^2)^7)) + 
          ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 
             18*x^7 - 5*x^8)*HPL[{2, 0}, x])/(405*(-1 + x^2)^7) + 
          ((-15 + 84*x + 18*x^2 + 4044*x^3 + 4293*x^4 + 32515*x^5 + 
             55152*x^6 + 119651*x^7 + 111131*x^8 + 102747*x^9 + 37510*x^10 + 
             17739*x^11 + 651*x^12)*HPL[{-1, 0, 0}, x])/(405*(-1 + x)^10*
            (1 + x)^8) + ((-25 + 90*x + 860*x^2 - 25830*x^3 - 66285*x^4 + 
             550932*x^5 + 1764478*x^6 + 8934744*x^7 + 5517619*x^8 - 
             323693382*x^9 - 717497010*x^10 + 1274984166*x^11 + 
             7740626643*x^12 + 38243195232*x^13 + 9263597588*x^14 - 
             460682257848*x^15 - 604100128499*x^16 + 1441668696822*x^17 + 
             3172989323808*x^18 + 2517882556878*x^19 - 1918447031655*x^20 - 
             12940165353204*x^21 - 13965095530962*x^22 - 13781042850528*
              x^23 - 7569751754727*x^24 - 3298714801290*x^25 - 
             968388129162*x^26 - 127233943182*x^27 + 80644459329*x^28)*
            HPL[{0, 0, 0}, x])/(2025*(1 - 9*x^2)^6*(-1 + x^2)^11) - 
          ((-15 + 24*x + 234*x^2 + 5568*x^3 + 18681*x^4 + 62429*x^5 + 
             101052*x^6 + 151045*x^7 + 134123*x^8 + 106161*x^9 + 40234*x^10 + 
             17913*x^11 + 111*x^12)*HPL[{1, 0, 0}, x])/(405*(-1 + x)^8*
            (1 + x)^10) - ((100 - 360*x - 5715*x^2 + 68586*x^3 + 253794*x^4 - 
             3395934*x^5 - 9121212*x^6 + 62262702*x^7 + 179560058*x^8 - 
             319566786*x^9 - 1630102991*x^10 - 3731682636*x^11 + 
             2694972964*x^12 + 53725907556*x^13 + 59130578752*x^14 - 
             187357719636*x^15 - 367841920248*x^16 - 216325246428*x^17 + 
             316183850703*x^18 + 1489686736194*x^19 + 1485398018394*x^20 + 
             1382421504474*x^21 + 720235861884*x^22 + 279494549190*x^23 + 
             84936462138*x^24 + 3302794278*x^25 - 9188424621*x^26)*
            master3l8b[x])/(48600*x^2*(1 - 9*x^2)^6*(-1 + x^2)^11) - 
          ((-50 + 180*x + 2145*x^2 - 31866*x^3 - 75309*x^4 + 1476912*x^5 + 
             2754519*x^6 - 22715658*x^7 - 48494685*x^8 + 73961736*x^9 + 
             322353850*x^10 + 1031544924*x^11 - 2971746*x^12 - 
             7116793344*x^13 - 4767198338*x^14 - 160595028*x^15 - 
             16452532476*x^16 + 8519273892*x^17 + 65417276565*x^18 + 
             260556377886*x^19 + 364361592735*x^20 + 358316333424*x^21 + 
             164710724859*x^22 + 79040219742*x^23 - 1020936069*x^24)*
            master3l9b[x])/(48600*x^2*(-1 + x^2)^11*(-1 + 9*x^2)^5) + 
          (-6750 + 24300*x + x^6*(1120601558 - 25721280*Zeta[3]) + 
            x^2*(502165 - 14400*Zeta[3]) + 30*x^3*(-182491 + 1728*Zeta[3]) - 
            96*x^5*(-3005897 + 10260*Zeta[3]) + 15*x^4*(-1953437 + 
              63744*Zeta[3]) - 4251528*x^30*(1249189 + 738360*Zeta[3]) - 
            216*x^7*(29427893 + 1422240*Zeta[3]) - 2125764*x^29*
             (-6861199 + 5387040*Zeta[3]) - 177147*x^28*(-428265143 + 
              28465920*Zeta[3]) - 4*x^8*(6126486341 + 64074240*Zeta[3]) + 
            2099520*x^25*(350303065 + 286334028*Zeta[3]) + 
            489888*x^24*(3310633339 + 385466880*Zeta[3]) + 
            24*x^9*(2033444809 + 619892640*Zeta[3]) + 196830*x^27*
             (294906583 + 1017396288*Zeta[3]) + 9*x^10*(30885992431 + 
              3258201920*Zeta[3]) - 768*x^15*(-104922689789 + 
              11936310750*Zeta[3]) + 108*x^13*(-107480418871 + 
              24037797600*Zeta[3]) - 6*x^11*(-74704672697 + 47274868800*Zeta[
                3]) + 6561*x^26*(33454293169 + 68914687680*Zeta[3]) - 
            1944*x^23*(-1681139904133 + 280716723360*Zeta[3]) - 
            x^12*(917285980813 + 672726931200*Zeta[3]) + 
            162*x^19*(-5095218485759 + 1657470628800*Zeta[3]) - 
            486*x^22*(-6086468610697 + 1743846530400*Zeta[3]) + 
            4*x^14*(-3324451085177 + 1870587586800*Zeta[3]) - 
            12*x^17*(10296111283499 + 1951485379200*Zeta[3]) + 
            81*x^20*(-1641821404093 + 1963081939200*Zeta[3]) - 
            216*x^21*(-9708732657937 + 2233822114800*Zeta[3]) - 
            6*x^16*(-26361138819827 + 7074720230400*Zeta[3]) + 
            x^18*(-552860529620653 + 91306377691200*Zeta[3]))/
           (3499200*x^2*(1 - 9*x^2)^6*(-1 + x^2)^11))) + 
      CA*CF*((Pi^2*(5 - 18*x - 339*x^2 - 2100*x^3 - 4286*x^4 - 5844*x^5 - 
           4286*x^6 - 2100*x^7 - 339*x^8 - 18*x^9 + 5*x^10)*HPL[{-2}, x])/
         (1620*(-1 + x^2)^8) + lm^2*((-11*(5 - 18*x - 115*x^2 - 1068*x^3 - 
             1990*x^4 - 2868*x^5 - 1990*x^6 - 1068*x^7 - 115*x^8 - 18*x^9 + 
             5*x^10))/(1440*(-1 + x^2)^8) - 
          (11*x^3*(6 + 15*x + 36*x^2 + 40*x^3 + 36*x^4 + 15*x^5 + 6*x^6)*
            HPL[{0}, x])/(12*(-1 + x^2)^9)) + 
        (Pi^2*(-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 
           4286*x^6 + 2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{2}, x])/
         (1620*(-1 + x^2)^8) + (x*(3725 + 23139*x + 108750*x^2 + 121566*x^3 + 
           1354365*x^4 + 1933295*x^5 + 2375400*x^6 + 1120945*x^7 + 
           2439075*x^8 + 1626432*x^9 - 1734126*x^10 - 2235843*x^11 + 
           1962739*x^12 + 2443138*x^13 - 1365120*x^14 - 1895490*x^15 + 
           548550*x^16 + 1026110*x^17 - 61180*x^18 - 368778*x^19 - 
           50598*x^20 + 79194*x^21 + 24312*x^22 - 7700*x^23 - 3500*x^24)*
          HPL[{-2, 0}, x])/(16200*(-1 + x^2)^10) + 
        ((210000 + 462000*x - 1143720*x^2 - 4058640*x^3 + 1232800*x^4 + 
           15846220*x^5 + 5987800*x^6 - 36125420*x^7 - 24400520*x^8 + 
           (53380277 + 6000*Pi^2)*x^9 + (39625658 - 21600*Pi^2)*x^10 - 
           16*(3703013 + 25800*Pi^2)*x^11 - 2*(40275797 + 1249200*Pi^2)*
            x^12 - 3*(4823907 + 1578800*Pi^2)*x^13 - 
           8*(13629023 + 561600*Pi^2)*x^14 - 143529496*x^15 + 
           8*(-13629023 + 561600*Pi^2)*x^16 + 3*(-4823907 + 1578800*Pi^2)*
            x^17 + (-80551594 + 2498400*Pi^2)*x^18 + 
           16*(-3703013 + 25800*Pi^2)*x^19 + (39625658 + 21600*Pi^2)*x^20 + 
           (53380277 - 6000*Pi^2)*x^21 - 24400520*x^22 - 36125420*x^23 + 
           5987800*x^24 + 15846220*x^25 + 1232800*x^26 - 4058640*x^27 - 
           1143720*x^28 + 462000*x^29 + 210000*x^30)*HPL[{-1, 0}, x])/
         (1944000*x^9*(-1 + x^2)^9) + (x*(712662381000 + 3956974030764*x + 
           7441803358740*x^2 - 74978240432409*x^3 - 1069615070003430*x^4 - 
           2252822389937109*x^5 + 16148408968378080*x^6 + 83142560858018796*
            x^7 + 29646916839335880*x^8 - 947448273849927660*x^9 - 
           2461728699767971296*x^10 + 3914968062653209728*x^11 + 
           18429893343453579552*x^12 + 2010863366346560880*x^13 - 
           15530301781121260608*x^14 - 8341332254024339316*x^15 - 
           277952439091879365816*x^16 - 418951887767902661612*x^17 + 
           503557935825975608120*x^18 + 1485786255853362502470*x^19 + 
           1483944415806824872308*x^20 + 312960076497259660094*x^21 - 
           330562083336445168416*x^22 - 362431173100935023308*x^23 - 
           224398352773041054296*x^24 - 18113855669686471820*x^25 + 
           131532763248651323088*x^26 + 92597292478366882968*x^27 - 
           36166445215319808960*x^28 - 54173333977664360600*x^29 + 
           4997561820508164064*x^30 + 20630504708276062020*x^31 + 
           1139612427104348112*x^32 - 5693723774463709392*x^33 - 
           936122543850678828*x^34 + 1128661104929225787*x^35 + 
           281032709074371234*x^36 - 156792971527415649*x^37 - 
           49196954861035200*x^38 + 14785830641131920*x^39 + 
           5370659412726960*x^40 - 898221102368760*x^41 - 
           360453864134160*x^42 + 31649054676480*x^43 + 13640729981040*x^44 - 
           491051484000*x^45 - 223205220000*x^46)*HPL[{0, 0}, x])/
         (1944000*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        ((-210000 - 462000*x + 1143720*x^2 + 4058640*x^3 - 1232800*x^4 - 
           15846220*x^5 - 5987800*x^6 + 36125420*x^7 + 24400520*x^8 - 
           (53380277 + 6000*Pi^2)*x^9 + (-39625658 + 21600*Pi^2)*x^10 + 
           16*(3703013 + 25800*Pi^2)*x^11 + (80551594 + 2498400*Pi^2)*x^12 + 
           3*(4823907 + 1578800*Pi^2)*x^13 + 8*(13629023 + 561600*Pi^2)*
            x^14 + 143529496*x^15 - 8*(-13629023 + 561600*Pi^2)*x^16 + 
           (14471721 - 4736400*Pi^2)*x^17 + (80551594 - 2498400*Pi^2)*x^18 + 
           (59248208 - 412800*Pi^2)*x^19 - 2*(19812829 + 10800*Pi^2)*x^20 + 
           (-53380277 + 6000*Pi^2)*x^21 + 24400520*x^22 + 36125420*x^23 - 
           5987800*x^24 - 15846220*x^25 - 1232800*x^26 + 4058640*x^27 + 
           1143720*x^28 - 462000*x^29 - 210000*x^30)*HPL[{1, 0}, x])/
         (1944000*x^9*(-1 + x^2)^9) + 
        lm*((-19442 + 45261*x + 337155*x^2 + 3717396*x^3 + 6860435*x^4 + 
            9970254*x^5 + 6860435*x^6 + 3717396*x^7 + 337155*x^8 + 
            45261*x^9 - 19442*x^10 - 66*Pi^2*(-5 + 18*x + 47*x^2 + 144*x^3 + 
              144*x^4 - 144*x^6 - 144*x^7 - 47*x^8 - 18*x^9 + 5*x^10))/
           (116640*(-1 + x^2)^8) + (x^2*(110 - 107556*x - 259650*x^2 - 
             720774*x^3 - 859314*x^4 - 898974*x^5 - 445275*x^6 - 211506*x^7 - 
             11770*x^8 - 1782*x^9 + 495*x^10)*HPL[{0}, x])/
           (3240*(-1 + x^2)^9) + (11*(5 - 18*x - 42*x^2 - 162*x^3 - 186*x^4 - 
             162*x^5 - 42*x^6 - 18*x^7 + 5*x^8)*HPL[{-1, 0}, x])/
           (1620*(-1 + x^2)^7) + (11*x^3*(1080 + 2700*x + 13500*x^2 + 
             22000*x^3 + 39600*x^4 + 35115*x^5 + 29430*x^6 + 10845*x^7 + 
             4428*x^8 + 57*x^9 + 18*x^10 - 5*x^11)*HPL[{0, 0}, x])/
           (810*(-1 + x^2)^10) - (11*(5 - 18*x - 42*x^2 - 162*x^3 - 186*x^4 - 
             162*x^5 - 42*x^6 - 18*x^7 + 5*x^8)*HPL[{1, 0}, x])/
           (1620*(-1 + x^2)^7)) + (x*(-3725 - 23139*x - 108750*x^2 - 
           121566*x^3 - 1354365*x^4 - 1933295*x^5 - 2375400*x^6 - 
           1120945*x^7 - 2439075*x^8 - 1626432*x^9 + 1734126*x^10 + 
           2235843*x^11 - 1962739*x^12 - 2443138*x^13 + 1365120*x^14 + 
           1895490*x^15 - 548550*x^16 - 1026110*x^17 + 61180*x^18 + 
           368778*x^19 + 50598*x^20 - 79194*x^21 - 24312*x^22 + 7700*x^23 + 
           3500*x^24)*HPL[{2, 0}, x])/(16200*(-1 + x^2)^10) + 
        ((-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 4286*x^6 + 
           2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{-2, -1, 0}, x])/
         (135*(-1 + x^2)^8) + (4*x^2*(-146 - 978*x - 2071*x^2 - 2922*x^3 - 
           2215*x^4 - 1122*x^5 - 193*x^6 - 18*x^7 + 5*x^8)*
          HPL[{-2, 0, 0}, x])/(135*(-1 + x^2)^8) - 
        ((-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 4286*x^6 + 
           2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{-2, 1, 0}, x])/
         (135*(-1 + x^2)^8) - ((-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 
           5844*x^5 + 4286*x^6 + 2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*
          HPL[{-1, -2, 0}, x])/(135*(-1 + x^2)^8) + 
        ((1750 + 3850*x - 6906*x^2 - 28047*x^3 - 669*x^4 + 88698*x^5 + 
           51051*x^6 - 158970*x^7 - 126021*x^8 + 176694*x^9 + 150675*x^10 - 
           126429*x^11 - 96388*x^12 + 67422*x^13 + 66108*x^14 + 10764*x^15 + 
           66108*x^16 + 67422*x^17 - 96388*x^18 - 126429*x^19 + 150675*x^20 + 
           176694*x^21 - 126021*x^22 - 158970*x^23 + 51051*x^24 + 
           88698*x^25 - 669*x^26 - 28047*x^27 - 6906*x^28 + 3850*x^29 + 
           1750*x^30)*HPL[{-1, -1, 0}, x])/(16200*x^11*(-1 + x^2)^7) - 
        ((2707 + 14639*x + 56874*x^2 + 345831*x^3 + 297167*x^4 + 311730*x^5 + 
           124806*x^6 + 619222*x^7 + 130708*x^8 - 141398*x^9 + 440408*x^10 + 
           644358*x^11 - 517044*x^12 - 571704*x^13 + 442140*x^14 + 
           369984*x^15 - 234363*x^16 - 175533*x^17 + 72374*x^18 + 
           61375*x^19 - 10735*x^20 - 14606*x^21 + 350*x^22 + 1750*x^23)*
          HPL[{-1, 0, 0}, x])/(8100*(-1 + x)^10*(1 + x)^8) - 
        ((1750 + 3850*x - 6906*x^2 - 28047*x^3 - 669*x^4 + 88698*x^5 + 
           51051*x^6 - 158970*x^7 - 126021*x^8 + 176694*x^9 + 150675*x^10 - 
           126429*x^11 - 96388*x^12 + 67422*x^13 + 66108*x^14 + 10764*x^15 + 
           66108*x^16 + 67422*x^17 - 96388*x^18 - 126429*x^19 + 150675*x^20 + 
           176694*x^21 - 126021*x^22 - 158970*x^23 + 51051*x^24 + 
           88698*x^25 - 669*x^26 - 28047*x^27 - 6906*x^28 + 3850*x^29 + 
           1750*x^30)*HPL[{-1, 1, 0}, x])/(16200*x^11*(-1 + x^2)^7) + 
        ((-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 4286*x^6 + 
           2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{-1, 2, 0}, x])/
         (135*(-1 + x^2)^8) + (x*(-9898088625 - 59890743495*x - 
           1297235999250*x^2 - 2155045438278*x^3 + 61504222952880*x^4 + 
           185664692541240*x^5 - 792905666049180*x^6 - 3936320730622602*x^7 - 
           421093876451130*x^8 + 35497646722053000*x^9 + 84218410255668000*
            x^10 - 115599630976536270*x^11 - 534377308564434490*x^12 - 
           34587127993123744*x^13 - 531939487922062660*x^14 - 
           2057953161295055670*x^15 + 12070950233975632480*x^16 + 
           27271180626578075854*x^17 - 5726637390365717860*x^18 - 
           66962102749388983070*x^19 - 104234025981717915670*x^20 - 
           43863003239111897060*x^21 + 41380611719120788060*x^22 + 
           50755055913175439246*x^23 - 10101728158597814170*x^24 - 
           28844977391690676700*x^25 + 8987753277263943480*x^26 + 
           18096338936700368514*x^27 - 6171992360730901530*x^28 - 
           11014452732588507740*x^29 + 2278162030964476660*x^30 + 
           5328029609647849110*x^31 - 309931551246409335*x^32 - 
           1938942282260103663*x^33 - 133248699756656490*x^34 + 
           519711394351625420*x^35 + 89305412187539150*x^36 - 
           100468846472608692*x^37 - 25429590295696800*x^38 + 
           13675955332010580*x^39 + 4321067434916580*x^40 - 
           1269360352630980*x^41 - 462479909792760*x^42 + 
           76167059062500*x^43 + 30604635724140*x^44 - 2657881701540*x^45 - 
           1146027715920*x^46 + 40920957000*x^47 + 18600435000*x^48)*
          HPL[{0, 0, 0}, x])/(81000*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        ((-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 4286*x^6 + 
           2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{1, -2, 0}, x])/
         (135*(-1 + x^2)^8) - ((1750 + 3850*x - 6906*x^2 - 28047*x^3 - 
           669*x^4 + 88698*x^5 + 51051*x^6 - 158970*x^7 - 126021*x^8 + 
           176694*x^9 + 150675*x^10 - 126429*x^11 - 96388*x^12 + 67422*x^13 + 
           66108*x^14 + 10764*x^15 + 66108*x^16 + 67422*x^17 - 96388*x^18 - 
           126429*x^19 + 150675*x^20 + 176694*x^21 - 126021*x^22 - 
           158970*x^23 + 51051*x^24 + 88698*x^25 - 669*x^26 - 28047*x^27 - 
           6906*x^28 + 3850*x^29 + 1750*x^30)*HPL[{1, -1, 0}, x])/
         (16200*x^11*(-1 + x^2)^7) + ((2707 + 24267*x + 139006*x^2 + 
           657723*x^3 + 1643743*x^4 + 2874538*x^5 + 3196590*x^6 + 
           2828678*x^7 + 2000548*x^8 + 904538*x^9 - 481552*x^10 - 
           554106*x^11 + 589740*x^12 + 770952*x^13 - 266148*x^14 - 
           620688*x^15 - 27483*x^16 + 291447*x^17 + 97322*x^18 - 66213*x^19 - 
           45359*x^20 + 794*x^21 + 7350*x^22 + 1750*x^23)*HPL[{1, 0, 0}, x])/
         (8100*(-1 + x)^8*(1 + x)^10) + 
        ((1750 + 3850*x - 6906*x^2 - 28047*x^3 - 669*x^4 + 88698*x^5 + 
           51051*x^6 - 158970*x^7 - 126021*x^8 + 176694*x^9 + 150675*x^10 - 
           126429*x^11 - 96388*x^12 + 67422*x^13 + 66108*x^14 + 10764*x^15 + 
           66108*x^16 + 67422*x^17 - 96388*x^18 - 126429*x^19 + 150675*x^20 + 
           176694*x^21 - 126021*x^22 - 158970*x^23 + 51051*x^24 + 
           88698*x^25 - 669*x^26 - 28047*x^27 - 6906*x^28 + 3850*x^29 + 
           1750*x^30)*HPL[{1, 1, 0}, x])/(16200*x^11*(-1 + x^2)^7) - 
        ((-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 4286*x^6 + 
           2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{1, 2, 0}, x])/
         (135*(-1 + x^2)^8) - ((-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 
           5844*x^5 + 4286*x^6 + 2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*
          HPL[{2, -1, 0}, x])/(135*(-1 + x^2)^8) + 
        (4*x^2*(146 + 978*x + 2071*x^2 + 2922*x^3 + 2215*x^4 + 1122*x^5 + 
           193*x^6 + 18*x^7 - 5*x^8)*HPL[{2, 0, 0}, x])/(135*(-1 + x^2)^8) + 
        ((-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 4286*x^6 + 
           2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{2, 1, 0}, x])/
         (135*(-1 + x^2)^8) + ((-10 + 36*x + 84*x^2 + 324*x^3 + 372*x^4 + 
           324*x^5 + 84*x^6 + 36*x^7 - 10*x^8)*HPL[{-1, 0, 0, 0}, x])/
         (135*(-1 + x^2)^7) + (2*(5 - 18*x - 339*x^2 - 2100*x^3 - 4286*x^4 - 
           5844*x^5 - 4286*x^6 - 2100*x^7 - 339*x^8 - 18*x^9 + 5*x^10)*
          HPL[{-1, 1, 0, 0}, x])/(135*(-1 + x^2)^8) + 
        (2*(5 - 18*x - 339*x^2 - 2100*x^3 - 4286*x^4 - 5844*x^5 - 4286*x^6 - 
           2100*x^7 - 339*x^8 - 18*x^9 + 5*x^10)*HPL[{1, -1, 0, 0}, x])/
         (135*(-1 + x^2)^8) + (2*(5 - 18*x - 42*x^2 - 162*x^3 - 186*x^4 - 
           162*x^5 - 42*x^6 - 18*x^7 + 5*x^8)*HPL[{1, 0, 0, 0}, x])/
         (135*(-1 + x^2)^7) + ((-5 + 40*x + 259*x^2 + 2838*x^3 + 5923*x^4 + 
           11104*x^5 + 9852*x^6 + 7360*x^7 + 1976*x^8 + 756*x^9 - 85*x^10 + 
           22*x^11)*master3l10a[x])/(1080*(-1 + x^2)^9) + 
        (x*(-22 + 85*x - 756*x^2 - 1976*x^3 - 7360*x^4 - 9852*x^5 - 
           11104*x^6 - 5923*x^7 - 2838*x^8 - 259*x^9 - 40*x^10 + 5*x^11)*
          master3l10b[x])/(1080*(-1 + x^2)^9) - 
        ((10976238072 + 124671826755*x + 2006610448095*x^2 + 
           5321363131530*x^3 + 5396289697584*x^4 + 2903131955115*x^5 - 
           2106400096719*x^6 - 1106003137320*x^7 + 725142880944*x^8 + 
           4788470790*x^9 - 421510114314*x^10 - 57475594020*x^11 + 
           135959798880*x^12 + 41609898030*x^13 - 22164880126*x^14 - 
           9218534760*x^15 + 1857169176*x^16 + 967823255*x^17 - 
           68215941*x^18 - 50001110*x^19 - 5456*x^20 + 1026375*x^21 + 
           46205*x^22)*master3l8a[x])/(1944000*(-9 + x^2)^6*(-1 + x^2)^10) - 
        ((74500 + 410575*x - 3897575*x^2 - 24733044*x^3 + 85548810*x^4 + 
           623485525*x^5 - 1120075015*x^6 - 8734263288*x^7 + 
           11185290480*x^8 + 77307121862*x^9 - 91730176750*x^10 - 
           477249952568*x^11 + 486783823020*x^12 + 2157025911834*x^13 - 
           794233538790*x^14 - 6212306154240*x^15 - 4454173859940*x^16 + 
           5379481848987*x^17 + 15124703422005*x^18 + 13441544301132*x^19 + 
           7526268401850*x^20 + 1299862807137*x^21 + 298982440845*x^22 - 
           1410300072*x^23)*master3l8b[x])/(1944000*x*(1 - 9*x^2)^6*
          (-1 + x^2)^10) + ((688141008 - 9683923005*x + 39340217943*x^2 - 
           123570728685*x^3 - 442587453759*x^4 - 692706273570*x^5 - 
           465058714068*x^6 + 109042120860*x^7 + 333740644836*x^8 + 
           56505902850*x^9 - 106169707582*x^10 - 23958200630*x^11 + 
           22270574238*x^12 + 4745759640*x^13 - 3051714084*x^14 - 
           606239220*x^15 + 249333572*x^16 + 48634435*x^17 - 10724129*x^18 - 
           2126725*x^19 + 182185*x^20 + 37250*x^21)*master3l9a[x])/
         (648000*(-9 + x^2)^5*(-1 + x^2)^10) + 
        ((37250 + 182185*x - 2126725*x^2 - 10724129*x^3 + 48634435*x^4 + 
           249333572*x^5 - 606239220*x^6 - 3051714084*x^7 + 4745759640*x^8 + 
           22270574238*x^9 - 23958200630*x^10 - 106169707582*x^11 + 
           56505902850*x^12 + 333740644836*x^13 + 109042120860*x^14 - 
           465058714068*x^15 - 692706273570*x^16 - 442587453759*x^17 - 
           123570728685*x^18 + 39340217943*x^19 - 9683923005*x^20 + 
           688141008*x^21)*master3l9b[x])/(1944000*x*(-1 + x^2)^10*
          (-1 + 9*x^2)^5) + (HPL[{1}, x]*(Pi^2*(-1750 - 3850*x + 8656*x^2 + 
             31897*x^3 - 6237*x^4 - 116745*x^5 - 51720*x^6 + 247668*x^7 + 
             177072*x^8 - 335664*x^9 - 276696*x^10 + 303123*x^11 + 
             247063*x^12 - 193851*x^13 - 162496*x^14 + 56658*x^15 - 
             56658*x^17 + 162496*x^18 + 193851*x^19 - 247063*x^20 - 
             303123*x^21 + 276696*x^22 + 335664*x^23 - 177072*x^24 - 
             247668*x^25 + 51720*x^26 + 116745*x^27 + 6237*x^28 - 
             31897*x^29 - 8656*x^30 + 3850*x^31 + 1750*x^32) - 
           1440*x^11*(5 - 18*x - 339*x^2 - 2100*x^3 - 4286*x^4 - 5844*x^5 - 
             4286*x^6 - 2100*x^7 - 339*x^8 - 18*x^9 + 5*x^10)*Zeta[3]))/
         (194400*x^11*(-1 + x^2)^8) + 
        (HPL[{-1}, x]*(Pi^2*(1750 + 3850*x - 8656*x^2 - 31897*x^3 + 
             6237*x^4 + 116745*x^5 + 51720*x^6 - 247668*x^7 - 177072*x^8 + 
             335664*x^9 + 276696*x^10 - 303123*x^11 - 247063*x^12 + 
             193851*x^13 + 162496*x^14 - 56658*x^15 + 56658*x^17 - 
             162496*x^18 - 193851*x^19 + 247063*x^20 + 303123*x^21 - 
             276696*x^22 - 335664*x^23 + 177072*x^24 + 247668*x^25 - 
             51720*x^26 - 116745*x^27 - 6237*x^28 + 31897*x^29 + 8656*x^30 - 
             3850*x^31 - 1750*x^32) + 1440*x^11*(5 - 18*x - 339*x^2 - 
             2100*x^3 - 4286*x^4 - 5844*x^5 - 4286*x^6 - 2100*x^7 - 339*x^8 - 
             18*x^9 + 5*x^10)*Zeta[3]))/(194400*x^11*(-1 + x^2)^8) - 
        (HPL[{0}, x]*(669615660000 + 1473154452000*x - 40587382113120*x^2 - 
           94210586803440*x^3 + 1061123702650920*x^4 + 2647680776575560*x^5 - 
           15584770768045680*x^6 - 43041441035906100*x^7 + 
           43740*(3198417313421 + 5431050*Pi^2)*x^8 + 
           87480*(5134337958280 + 16868331*Pi^2)*x^9 + 
           3600*(463058813042500839 + 997226195344738*Pi^2)*x^26 - 
           15*(29863289504086767 + 415780077216255592*Pi^2)*x^43 - 
           30*(4657484649737223 + 35723171383643948*Pi^2)*x^44 + 
           23895*(1801020218229 + 50455191276448*Pi^2)*x^45 + 
           6480*(2405057217291 + 47091833880920*Pi^2)*x^46 - 
           29160*(90798380541 + 5627965157206*Pi^2)*x^47 - 
           29160*(36389701737 + 1778217051406*Pi^2)*x^48 + 
           174960*(538469289 + 87061752581*Pi^2)*x^49 + 
           349920*(115990461 + 15860079211*Pi^2)*x^50 - 
           826686000*(1782 + 1105625*Pi^2)*x^51 - 
           4723920*(141750 + 77743829*Pi^2)*x^52 + 31894580418480*Pi^2*x^53 + 
           13752332591040*Pi^2*x^54 - 491051484000*Pi^2*x^55 - 
           223205220000*Pi^2*x^56 + 48*x^24*(-55697086943724823939 + 
             410453952711366960*Pi^2 - 3081056039662968000*Zeta[3]) - 
           72*x^22*(-9337984586371086483 + 239956006754125180*Pi^2 - 
             861742699121952000*Zeta[3]) + 16*x^20*(-3765081621784830289 + 
             280183473400725240*Pi^2 - 350131120295400000*Zeta[3]) + 
           30*x^29*(95917810167524797435 + 4789117039005421836*Pi^2 - 
             344374141566816000*Zeta[3]) - 120*x^23*(7013171568453539011 + 
             338948800751186745*Pi^2 - 86093535391704000*Zeta[3]) - 
           24*x^34*(-10129235668023859601 + 6279258314732247000*Pi^2 - 
             65362857312672000*Zeta[3]) + 120*x^36*(-335526103623763831 + 
             675230772385701630*Pi^2 - 3780852672528000*Zeta[3]) + 
           72*x^14*(-45155504598830903 + 6233862003300*Pi^2 - 
             673493053536000*Zeta[3]) + 36*x^40*(-70773343724506751 + 
             103518811983074130*Pi^2 - 68415588576000*Zeta[3]) - 
           972*x^10*(798024983479657 + 6225295500*Pi^2 + 51018336000*
              Zeta[3]) - 243*x^11*(13045283946972499 + 300064973040*Pi^2 + 
             510183360000*Zeta[3]) + 144*x^41*(21705163869536568 + 
             161621495221164595*Pi^2 + 860934420000*Zeta[3]) - 
           180*x^39*(83743102311565501 + 355655252365696682*Pi^2 + 
             36503619408000*Zeta[3]) + 18*x^12*(137792302678704427 + 
             248111432100*Pi^2 + 136831177152000*Zeta[3]) + 
           45*x^13*(348479854970716183 + 34350732076536*Pi^2 + 
             146014477632000*Zeta[3]) + 240*x^16*(-16214491752480187 + 
             78663589070220*Pi^2 + 1890426336264000*Zeta[3]) - 
           72*x^15*(789896733075620099 + 273519843905565*Pi^2 + 
             1994625618840000*Zeta[3]) + 12*x^37*(4627257806233011999 + 
             11020005803842772510*Pi^2 + 11967753713040000*Zeta[3]) - 
           24*x^18*(-628546590913353799 + 20753505132332580*Pi^2 + 
             65362857312672000*Zeta[3]) + 24*x^17*(6843462822707662952 + 
             7957039714235235*Pi^2 + 68313119665320000*Zeta[3]) - 
           12*x^35*(17926718205809344219 + 17345230661834856630*Pi^2 + 
             136626239330640000*Zeta[3]) - 60*x^19*(6963241141684867583 + 
             26644081194857142*Pi^2 + 166671661105584000*Zeta[3]) + 
           40*x^33*(24530459759119366570 + 6290196098844199953*Pi^2 + 
             250007491658376000*Zeta[3]) + 8*x^32*(-44053291617943553797 + 
             25053338369399387550*Pi^2 + 700262240590800000*Zeta[3]) - 
           72*x^30*(35573410970487510683 + 2784415213769329300*Pi^2 + 
             861742699121952000*Zeta[3]) - 8*x^31*(388459160930994476156 + 
             28759498363149860745*Pi^2 + 3372409453834440000*Zeta[3]) + 
           4*x^21*(221058031068547327907 + 2570157147174349410*Pi^2 + 
             6744818907668880000*Zeta[3]) + 12*x^28*(681070974804100775581 + 
             10768169674149619800*Pi^2 + 12324224158651872000*Zeta[3]) + 
           x^27*(6288341828847607694946 - 56925582493554356280*Pi^2 + 
             183958173592580160000*Zeta[3]) + 36*x^42*
            (44437717300045180*Pi^2 + 27*(793942701119557 + 51018336000*
                Zeta[3])) + x^38*(-27825515150882377440*Pi^2 + 
             72*(90636966517399103 + 673493053536000*Zeta[3])) + 
           8*x^25*(9655965864044121225*Pi^2 - 4*(70665837652279342753 + 
               5748692924768130000*Zeta[3]))))/(23328000*x^7*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6) + (2880*Pi^4*x^9*(-1 + x^2)^2*
           (9 - 82*x^2 + 9*x^4)^6*(-15 + 54*x - 1319*x^2 - 9348*x^3 - 
            20278*x^4 - 29220*x^5 - 22582*x^6 - 11652*x^7 - 2071*x^8 - 
            234*x^9 + 65*x^10) - 12*Pi^2*(9 - 82*x^2 + 9*x^4)^6*
           (-210000 - 462000*x + 1353720*x^2 + 4520640*x^3 - 2376520*x^4 - 
            19904860*x^5 - 4755000*x^6 + 51971640*x^7 + 30388320*x^8 - 
            89505697*x^9 - 64026178*x^10 + 112628485*x^11 + 120177252*x^12 - 
            44776487*x^13 + 28480590*x^14 + 129057775*x^15 - 129057775*x^17 - 
            28480590*x^18 + 44776487*x^19 - 120177252*x^20 - 112628485*x^21 + 
            64026178*x^22 + 89505697*x^23 - 30388320*x^24 - 51971640*x^25 + 
            4755000*x^26 + 19904860*x^27 + 2376520*x^28 - 4520640*x^29 - 
            1353720*x^30 + 462000*x^31 + 210000*x^32) + 
          x^2*(2008846980000 + 4419463356000*x - 122431761999360*x^2 - 
            284104914862320*x^3 + 3223707384193380*x^4 + 8036700483610620*
             x^5 - 47805700209615540*x^6 + x^21*(396629109312445729044 - 
              3642741358123290768000*Zeta[3]) + x^38*(4434858193430648844 - 
              996948404025578415360*Zeta[3]) + x^25*(5299695982690758580086 - 
              203691870136406871360*Zeta[3]) + x^17*(657297499894383928356 - 
              68825945596916142720*Zeta[3]) + 1148204895065280*x^53*Zeta[3] + 
            495083973277440*x^54*Zeta[3] - 17677853424000*x^55*Zeta[3] - 
            8035387920000*x^56*Zeta[3] - 14880348000*x^51*
             (-297 + 2211250*Zeta[3]) - 85030560*x^52*(-23625 + 
              155487658*Zeta[3]) - 19683*x^7*(6694944127141 + 
              329624640*Zeta[3]) + 65610*x^8*(6631736852165 + 
              2634571008*Zeta[3]) + 12597120*x^50*(-9719028 + 
              15860079211*Zeta[3]) + 6561*x^9*(212598522859829 + 
              200421112320*Zeta[3]) + 1574640*x^49*(-180425313 + 
              348247010324*Zeta[3]) - 2916*x^10*(841076084870659 + 
              1001428349760*Zeta[3]) - 131220*x^48*(-24567195429 + 
              14225736411248*Zeta[3]) - 131220*x^47*(-61246002771 + 
              45023721257648*Zeta[3]) - 729*x^11*(13921519034254453 + 
              66824092929600*Zeta[3]) + 29160*x^46*(-1639244006919 + 
              376734671047360*Zeta[3]) + 351*x^13*(152952086884647209 + 
              1872449076591360*Zeta[3]) - 54*x^12*(-140124000289026913 + 
              2338397878559040*Zeta[3]) - 288*x^15*(754426459536345631 + 
              3272552925691500*Zeta[3]) + 729*x^45*(-180757451402937 + 
              59537120270551360*Zeta[3]) + 72*x^14*(16561715200976627 + 
              65583283163718240*Zeta[3]) - 270*x^44*(-1611006743324205 + 
              142892110679806208*Zeta[3]) + 324*x^42*(-7559413276097331 + 
              177743894267740480*Zeta[3]) - 36*x^16*(4288791319770900949 + 
              1773919931769306000*Zeta[3]) + 54*x^40*(137485027890724363 + 
              2481957209858172480*Zeta[3]) + 144*x^18*(6157084010219262461 + 
              2870089207012473480*Zeta[3]) - 27*x^43*(-51576145250541057 + 
              8315560988971176320*Zeta[3]) - 120*x^22*(-8174262467756267447 + 
              9734027512062082752*Zeta[3]) + 81*x^41*(-123642521929082547 + 
              10343264843075790400*Zeta[3]) - 480*x^30*(6930653427065694367 + 
              16370493769946046456*Zeta[3]) - 144*x^34*
             (-7179863509125408761 + 34709836997213961840*Zeta[3]) + 
            128*x^32*(-15450331459888937297 + 47071071280383346890*Zeta[3]) + 
            12*x^19*(-97688416713496332539 + 65559022013076717600*Zeta[3]) + 
            72*x^37*(-2327822164137410509 + 66126204600170309400*Zeta[3]) - 
            16*x^20*(139175585459491076251 + 66211786706339682540*Zeta[3]) + 
            36*x^36*(-5251912120453814449 + 79235598450228148800*Zeta[3]) - 
            27*x^39*(-1860411008865083627 + 85337701091092162560*Zeta[3]) - 
            36*x^35*(-6463159329470978951 + 210345097735125252720*Zeta[3]) - 
            18*x^27*(-731193378738201052237 + 266132691578486971680*Zeta[
                3]) - 36*x^31*(145206822363629052841 + 341266224132724889200*
               Zeta[3]) + 18*x^23*(-17127282755873258081 + 
              364155823411773979040*Zeta[3]) + 18*x^29*
             (231716365081365358609 + 726795029577560098400*Zeta[3]) + 
            12*x^33*(80078935454395394971 + 825882751960207791120*Zeta[3]) + 
            12*x^24*(57014840645885776729 + 829615969029341540160*Zeta[3]) + 
            12*x^28*(972851760602873164579 + 1167638671629341241120*Zeta[
                3]) - 8*x^26*(-1728302866437534334219 + 
              1450020566367258969600*Zeta[3])))/(279936000*x^9*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6)) + 
      CF^2*((Pi^2*(-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 
           4286*x^6 + 2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{-2}, x])/
         (810*(-1 + x^2)^8) + lm^2*((3*(5 - 18*x - 115*x^2 - 1068*x^3 - 
             1990*x^4 - 2868*x^5 - 1990*x^6 - 1068*x^7 - 115*x^8 - 18*x^9 + 
             5*x^10))/(80*(-1 + x^2)^8) + (9*x^3*(6 + 15*x + 36*x^2 + 
             40*x^3 + 36*x^4 + 15*x^5 + 6*x^6)*HPL[{0}, x])/
           (2*(-1 + x^2)^9)) + (Pi^2*(5 - 18*x - 339*x^2 - 2100*x^3 - 
           4286*x^4 - 5844*x^5 - 4286*x^6 - 2100*x^7 - 339*x^8 - 18*x^9 + 
           5*x^10)*HPL[{2}, x])/(810*(-1 + x^2)^8) - 
        (x*(3725 + 23139*x + 231630*x^2 + 325326*x^3 + 2109765*x^4 + 
           2839815*x^5 + 2104080*x^6 - 67655*x^7 + 6644615*x^8 + 
           6694772*x^9 - 10646458*x^10 - 12701665*x^11 + 16402899*x^12 + 
           18677612*x^13 - 16601904*x^14 - 19801836*x^15 + 11013486*x^16 + 
           15067284*x^17 - 4200704*x^18 - 8033134*x^19 + 372854*x^20 + 
           2852514*x^21 + 427592*x^22 - 606600*x^23 - 192500*x^24 + 
           58500*x^25 + 27000*x^26)*HPL[{-2, 0}, x])/(8100*(-1 + x^2)^10) + 
        ((11340000 + 24570000*x - 63840000*x^2 - 217917000*x^3 + 
           79103640*x^4 + 860942880*x^5 + 301381640*x^6 - 1992726960*x^7 - 
           1342696320*x^8 + 2989147140*x^9 + 2483636680*x^10 - 
           (3036226469 + 42000*Pi^2)*x^11 + 70*(-38413039 + 2160*Pi^2)*x^12 + 
           8*(268241509 + 361200*Pi^2)*x^13 + 630*(3376279 + 27760*Pi^2)*
            x^14 + (-593839067 + 33154800*Pi^2)*x^15 + 
           280*(2532529 + 112320*Pi^2)*x^16 + 1878025048*x^17 - 
           280*(-2532529 + 112320*Pi^2)*x^18 - (593839067 + 33154800*Pi^2)*
            x^19 - 630*(-3376279 + 27760*Pi^2)*x^20 - 
           8*(-268241509 + 361200*Pi^2)*x^21 - 70*(38413039 + 2160*Pi^2)*
            x^22 + (-3036226469 + 42000*Pi^2)*x^23 + 2483636680*x^24 + 
           2989147140*x^25 - 1342696320*x^26 - 1992726960*x^27 + 
           301381640*x^28 + 860942880*x^29 + 79103640*x^30 - 217917000*x^31 - 
           63840000*x^32 + 24570000*x^33 + 11340000*x^34)*HPL[{-1, 0}, x])/
         (6804000*x^11*(-1 + x^2)^9) - (x*(4988636667000 + 28855021254948*x + 
           282272560225740*x^2 - 93694510241703*x^3 - 17381668501037610*x^4 - 
           37460932283851083*x^5 + 263274522671326320*x^6 + 
           978577065386296992*x^7 - 472541291310558960*x^8 - 
           9712650953886209280*x^9 - 22414254788197424880*x^10 + 
           31065014400696732708*x^11 + 186789286176476646600*x^12 + 
           98624274277682422284*x^13 - 132067848863252322720*x^14 - 
           404394982343161903080*x^15 - 3393275076419418850800*x^16 - 
           3678314852805211988824*x^17 + 8299139341992032044840*x^18 + 
           15923544136568362480670*x^19 + 7631291948208875779700*x^20 - 
           3519706129969139938178*x^21 + 3554625389931753482240*x^22 + 
           4986696003811609733912*x^23 - 9302715769353421787680*x^24 - 
           9161466056493319388896*x^25 + 7350696054883504169840*x^26 + 
           8800751322971027772996*x^27 - 3936946248789793003240*x^28 - 
           5916071491638378881700*x^29 + 1389713185454564787040*x^30 + 
           2975453294627566766952*x^31 - 204631434482322732360*x^32 - 
           1116920808693789988140*x^33 - 74234159736739496340*x^34 + 
           307412591746252677201*x^35 + 53660135895076252710*x^36 - 
           60715826133731261163*x^37 - 15697542224869853040*x^38 + 
           8404828802878876200*x^39 + 2712099643130802960*x^40 - 
           790365601866576960*x^41 - 293666205573750240*x^42 + 
           47910932321006160*x^43 + 19600844664930480*x^44 - 
           1685355654654000*x^45 - 738809278200000*x^46 + 
           26115010740000*x^47 + 12053081880000*x^48)*HPL[{0, 0}, x])/
         (6804000*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        ((-11340000 - 24570000*x + 63840000*x^2 + 217917000*x^3 - 
           79103640*x^4 - 860942880*x^5 - 301381640*x^6 + 1992726960*x^7 + 
           1342696320*x^8 - 2989147140*x^9 - 2483636680*x^10 + 
           (3036226469 + 42000*Pi^2)*x^11 - 70*(-38413039 + 2160*Pi^2)*x^12 - 
           8*(268241509 + 361200*Pi^2)*x^13 - 630*(3376279 + 27760*Pi^2)*
            x^14 + (593839067 - 33154800*Pi^2)*x^15 - 
           280*(2532529 + 112320*Pi^2)*x^16 - 1878025048*x^17 + 
           280*(-2532529 + 112320*Pi^2)*x^18 + (593839067 + 33154800*Pi^2)*
            x^19 + 630*(-3376279 + 27760*Pi^2)*x^20 + 
           8*(-268241509 + 361200*Pi^2)*x^21 + 70*(38413039 + 2160*Pi^2)*
            x^22 + (3036226469 - 42000*Pi^2)*x^23 - 2483636680*x^24 - 
           2989147140*x^25 + 1342696320*x^26 + 1992726960*x^27 - 
           301381640*x^28 - 860942880*x^29 - 79103640*x^30 + 217917000*x^31 + 
           63840000*x^32 - 24570000*x^33 - 11340000*x^34)*HPL[{1, 0}, x])/
         (6804000*x^11*(-1 + x^2)^9) + 
        lm*(-(-1649 + 1440*x + 17925*x^2 + 273060*x^3 + 496760*x^4 + 
             731016*x^5 + 496760*x^6 + 273060*x^7 + 17925*x^8 + 1440*x^9 - 
             1649*x^10 - 12*Pi^2*(-5 + 18*x + 47*x^2 + 144*x^3 + 144*x^4 - 
               144*x^6 - 144*x^7 - 47*x^8 - 18*x^9 + 5*x^10))/
           (4320*(-1 + x^2)^8) + (x^2*(-10 + 6006*x + 14175*x^2 + 42894*x^3 + 
             52974*x^4 + 59094*x^5 + 31050*x^6 + 15456*x^7 + 1070*x^8 + 
             162*x^9 - 45*x^10)*HPL[{0}, x])/(60*(-1 + x^2)^9) + 
          ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 
             18*x^7 - 5*x^8)*HPL[{-1, 0}, x])/(30*(-1 + x^2)^7) + 
          (x^3*(-1080 - 2700*x - 13500*x^2 - 22000*x^3 - 39600*x^4 - 
             35115*x^5 - 29430*x^6 - 10845*x^7 - 4428*x^8 - 57*x^9 - 
             18*x^10 + 5*x^11)*HPL[{0, 0}, x])/(15*(-1 + x^2)^10) - 
          ((-5 + 18*x + 42*x^2 + 162*x^3 + 186*x^4 + 162*x^5 + 42*x^6 + 
             18*x^7 - 5*x^8)*HPL[{1, 0}, x])/(30*(-1 + x^2)^7)) + 
        (x*(3725 + 23139*x + 231630*x^2 + 325326*x^3 + 2109765*x^4 + 
           2839815*x^5 + 2104080*x^6 - 67655*x^7 + 6644615*x^8 + 
           6694772*x^9 - 10646458*x^10 - 12701665*x^11 + 16402899*x^12 + 
           18677612*x^13 - 16601904*x^14 - 19801836*x^15 + 11013486*x^16 + 
           15067284*x^17 - 4200704*x^18 - 8033134*x^19 + 372854*x^20 + 
           2852514*x^21 + 427592*x^22 - 606600*x^23 - 192500*x^24 + 
           58500*x^25 + 27000*x^26)*HPL[{2, 0}, x])/(8100*(-1 + x^2)^10) + 
        (2*(5 - 18*x - 339*x^2 - 2100*x^3 - 4286*x^4 - 5844*x^5 - 4286*x^6 - 
           2100*x^7 - 339*x^8 - 18*x^9 + 5*x^10)*HPL[{-2, -1, 0}, x])/
         (135*(-1 + x^2)^8) + (4*(-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 
           5844*x^5 + 4286*x^6 + 2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*
          HPL[{-2, 0, 0}, x])/(135*(-1 + x^2)^8) + 
        (2*(-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 4286*x^6 + 
           2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{-2, 1, 0}, x])/
         (135*(-1 + x^2)^8) + (2*(-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 
           5844*x^5 + 4286*x^6 + 2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*
          HPL[{-1, -2, 0}, x])/(135*(-1 + x^2)^8) + 
        ((13500 + 29250*x - 28750*x^2 - 157050*x^3 - 64954*x^4 + 348507*x^5 + 
           284157*x^6 - 411032*x^7 - 385027*x^8 + 276662*x^9 + 247748*x^10 - 
           107718*x^11 - 74352*x^12 + 25041*x^13 + 9478*x^14 - 5120*x^15 + 
           9478*x^16 + 25041*x^17 - 74352*x^18 - 107718*x^19 + 247748*x^20 + 
           276662*x^21 - 385027*x^22 - 411032*x^23 + 284157*x^24 + 
           348507*x^25 - 64954*x^26 - 157050*x^27 - 28750*x^28 + 29250*x^29 + 
           13500*x^30)*HPL[{-1, -1, 0}, x])/(8100*x^13*(-1 + x^2)^5) + 
        ((2012 + 19757*x + 70126*x^2 + 384519*x^3 + 314313*x^4 + 157596*x^5 + 
           73392*x^6 + 1171600*x^7 - 156010*x^8 - 1883364*x^9 + 
           1879342*x^10 + 4079092*x^11 - 3578862*x^12 - 5102034*x^13 + 
           4447486*x^14 + 4508014*x^15 - 3562596*x^16 - 2889565*x^17 + 
           1808084*x^18 + 1373749*x^19 - 539015*x^20 - 482146*x^21 + 
           77050*x^22 + 114250*x^23 - 2250*x^24 - 13500*x^25)*
          HPL[{-1, 0, 0}, x])/(4050*(-1 + x)^10*(1 + x)^8) + 
        ((-13500 - 29250*x + 28750*x^2 + 157050*x^3 + 64954*x^4 - 
           348507*x^5 - 284157*x^6 + 411032*x^7 + 385027*x^8 - 276662*x^9 - 
           247748*x^10 + 107718*x^11 + 74352*x^12 - 25041*x^13 - 9478*x^14 + 
           5120*x^15 - 9478*x^16 - 25041*x^17 + 74352*x^18 + 107718*x^19 - 
           247748*x^20 - 276662*x^21 + 385027*x^22 + 411032*x^23 - 
           284157*x^24 - 348507*x^25 + 64954*x^26 + 157050*x^27 + 
           28750*x^28 - 29250*x^29 - 13500*x^30)*HPL[{-1, 1, 0}, x])/
         (8100*x^13*(-1 + x^2)^5) + (2*(5 - 18*x - 339*x^2 - 2100*x^3 - 
           4286*x^4 - 5844*x^5 - 4286*x^6 - 2100*x^7 - 339*x^8 - 18*x^9 + 
           5*x^10)*HPL[{-1, 2, 0}, x])/(135*(-1 + x^2)^8) + 
        (x*(-9898088625 - 63079389495*x + 2053087638975*x^2 + 
           6439468900617*x^3 - 63382829205870*x^4 - 175233921354882*x^5 + 
           495840753844740*x^6 + 1313665039519758*x^7 + 5888653595017650*
            x^8 + 17692018694087202*x^9 - 120126861551584470*x^10 - 
           409722844696620870*x^11 + 539894125536866150*x^12 + 
           3040757419022971406*x^13 + 1804642115269044390*x^14 - 
           8936080493877023666*x^15 - 21234146246658656860*x^16 + 
           1181939029080023204*x^17 + 50131174056256926340*x^18 + 
           26499202059248001376*x^19 - 56956980131278238770*x^20 - 
           14713027303750192350*x^21 + 276973805423305021610*x^22 + 
           227685251454270573646*x^23 - 281965171854770443430*x^24 - 
           325385443774759221386*x^25 + 274547616275866477370*x^26 + 
           345765608177845001074*x^27 - 239331461282819676450*x^28 - 
           311412725386385377254*x^29 + 156421727533675657670*x^30 + 
           226227826098907725430*x^31 - 71520055330780124155*x^32 - 
           128966941460928955333*x^33 + 19770140412923920965*x^34 + 
           56852838325977410223*x^35 - 849794984348147720*x^36 - 
           19082516568176878632*x^37 - 1918449485587651670*x^38 + 
           4785170296520722572*x^39 + 932431486169597220*x^40 - 
           876790589663439720*x^41 - 236752941690308340*x^42 + 
           114407979404439060*x^43 + 37627802030073780*x^44 - 
           10273013616016800*x^45 - 3849700089983940*x^46 + 
           600593417350740*x^47 + 246596198805720*x^48 - 20530097271000*
            x^49 - 9010582155000*x^50 + 310892985000*x^51 + 
           143489070000*x^52)*HPL[{0, 0, 0}, x])/(40500*(-1 + x^2)^11*
          (9 - 82*x^2 + 9*x^4)^6) + (2*(5 - 18*x - 339*x^2 - 2100*x^3 - 
           4286*x^4 - 5844*x^5 - 4286*x^6 - 2100*x^7 - 339*x^8 - 18*x^9 + 
           5*x^10)*HPL[{1, -2, 0}, x])/(135*(-1 + x^2)^8) + 
        ((-13500 - 29250*x + 28750*x^2 + 157050*x^3 + 64954*x^4 - 
           348507*x^5 - 284157*x^6 + 411032*x^7 + 385027*x^8 - 276662*x^9 - 
           247748*x^10 + 107718*x^11 + 74352*x^12 - 25041*x^13 - 9478*x^14 + 
           5120*x^15 - 9478*x^16 - 25041*x^17 + 74352*x^18 + 107718*x^19 - 
           247748*x^20 - 276662*x^21 + 385027*x^22 + 411032*x^23 - 
           284157*x^24 - 348507*x^25 + 64954*x^26 + 157050*x^27 + 
           28750*x^28 - 29250*x^29 - 13500*x^30)*HPL[{1, -1, 0}, x])/
         (8100*x^13*(-1 + x^2)^5) - ((2012 + 26605*x + 167170*x^2 + 
           782023*x^3 + 1971953*x^4 + 3325504*x^5 + 3427776*x^6 + 
           3135500*x^7 + 3149630*x^8 + 1132856*x^9 - 3505714*x^10 - 
           2260112*x^11 + 5448474*x^12 + 4975194*x^13 - 4833530*x^14 - 
           6341302*x^15 + 2051844*x^16 + 4938247*x^17 + 291008*x^18 - 
           2255879*x^19 - 786199*x^20 + 497054*x^21 + 354050*x^22 - 
           2750*x^23 - 56250*x^24 - 13500*x^25)*HPL[{1, 0, 0}, x])/
         (4050*(-1 + x)^8*(1 + x)^10) + 
        ((13500 + 29250*x - 28750*x^2 - 157050*x^3 - 64954*x^4 + 348507*x^5 + 
           284157*x^6 - 411032*x^7 - 385027*x^8 + 276662*x^9 + 247748*x^10 - 
           107718*x^11 - 74352*x^12 + 25041*x^13 + 9478*x^14 - 5120*x^15 + 
           9478*x^16 + 25041*x^17 - 74352*x^18 - 107718*x^19 + 247748*x^20 + 
           276662*x^21 - 385027*x^22 - 411032*x^23 + 284157*x^24 + 
           348507*x^25 - 64954*x^26 - 157050*x^27 - 28750*x^28 + 29250*x^29 + 
           13500*x^30)*HPL[{1, 1, 0}, x])/(8100*x^13*(-1 + x^2)^5) + 
        (2*(-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 4286*x^6 + 
           2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{1, 2, 0}, x])/
         (135*(-1 + x^2)^8) + (2*(-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 
           5844*x^5 + 4286*x^6 + 2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*
          HPL[{2, -1, 0}, x])/(135*(-1 + x^2)^8) + 
        (4*(5 - 18*x - 339*x^2 - 2100*x^3 - 4286*x^4 - 5844*x^5 - 4286*x^6 - 
           2100*x^7 - 339*x^8 - 18*x^9 + 5*x^10)*HPL[{2, 0, 0}, x])/
         (135*(-1 + x^2)^8) + (2*(5 - 18*x - 339*x^2 - 2100*x^3 - 4286*x^4 - 
           5844*x^5 - 4286*x^6 - 2100*x^7 - 339*x^8 - 18*x^9 + 5*x^10)*
          HPL[{2, 1, 0}, x])/(135*(-1 + x^2)^8) + 
        (4*(-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 5844*x^5 + 4286*x^6 + 
           2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*HPL[{-1, 1, 0, 0}, x])/
         (135*(-1 + x^2)^8) + (4*(-5 + 18*x + 339*x^2 + 2100*x^3 + 4286*x^4 + 
           5844*x^5 + 4286*x^6 + 2100*x^7 + 339*x^8 + 18*x^9 - 5*x^10)*
          HPL[{1, -1, 0, 0}, x])/(135*(-1 + x^2)^8) - 
        ((-5 + 40*x + 259*x^2 + 2838*x^3 + 5923*x^4 + 11104*x^5 + 9852*x^6 + 
           7360*x^7 + 1976*x^8 + 756*x^9 - 85*x^10 + 22*x^11)*master3l10a[x])/
         (540*(-1 + x^2)^9) + (x*(22 - 85*x + 756*x^2 + 1976*x^3 + 7360*x^4 + 
           9852*x^5 + 11104*x^6 + 5923*x^7 + 2838*x^8 + 259*x^9 + 40*x^10 - 
           5*x^11)*master3l10b[x])/(540*(-1 + x^2)^9) + 
        ((10976238072 + 124671826755*x + 2006610448095*x^2 + 
           5321363131530*x^3 + 5396289697584*x^4 + 2903131955115*x^5 - 
           2106400096719*x^6 - 1106003137320*x^7 + 725142880944*x^8 + 
           4788470790*x^9 - 421510114314*x^10 - 57475594020*x^11 + 
           135959798880*x^12 + 41609898030*x^13 - 22164880126*x^14 - 
           9218534760*x^15 + 1857169176*x^16 + 967823255*x^17 - 
           68215941*x^18 - 50001110*x^19 - 5456*x^20 + 1026375*x^21 + 
           46205*x^22)*master3l8a[x])/(972000*(-9 + x^2)^6*(-1 + x^2)^10) + 
        ((74500 + 410575*x - 3897575*x^2 - 24733044*x^3 + 85548810*x^4 + 
           623485525*x^5 - 1120075015*x^6 - 8734263288*x^7 + 
           11185290480*x^8 + 77307121862*x^9 - 91730176750*x^10 - 
           477249952568*x^11 + 486783823020*x^12 + 2157025911834*x^13 - 
           794233538790*x^14 - 6212306154240*x^15 - 4454173859940*x^16 + 
           5379481848987*x^17 + 15124703422005*x^18 + 13441544301132*x^19 + 
           7526268401850*x^20 + 1299862807137*x^21 + 298982440845*x^22 - 
           1410300072*x^23)*master3l8b[x])/(972000*x*(1 - 9*x^2)^6*
          (-1 + x^2)^10) + ((-688141008 + 9683923005*x - 39340217943*x^2 + 
           123570728685*x^3 + 442587453759*x^4 + 692706273570*x^5 + 
           465058714068*x^6 - 109042120860*x^7 - 333740644836*x^8 - 
           56505902850*x^9 + 106169707582*x^10 + 23958200630*x^11 - 
           22270574238*x^12 - 4745759640*x^13 + 3051714084*x^14 + 
           606239220*x^15 - 249333572*x^16 - 48634435*x^17 + 10724129*x^18 + 
           2126725*x^19 - 182185*x^20 - 37250*x^21)*master3l9a[x])/
         (324000*(-9 + x^2)^5*(-1 + x^2)^10) + 
        ((-37250 - 182185*x + 2126725*x^2 + 10724129*x^3 - 48634435*x^4 - 
           249333572*x^5 + 606239220*x^6 + 3051714084*x^7 - 4745759640*x^8 - 
           22270574238*x^9 + 23958200630*x^10 + 106169707582*x^11 - 
           56505902850*x^12 - 333740644836*x^13 - 109042120860*x^14 + 
           465058714068*x^15 + 692706273570*x^16 + 442587453759*x^17 + 
           123570728685*x^18 - 39340217943*x^19 + 9683923005*x^20 - 
           688141008*x^21)*master3l9b[x])/(972000*x*(-1 + x^2)^10*
          (-1 + 9*x^2)^5) - (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*
            (13500 + 29250*x - 28750*x^2 - 157050*x^3 - 64954*x^4 + 
             348507*x^5 + 284157*x^6 - 411032*x^7 - 385027*x^8 + 276662*x^9 + 
             247748*x^10 - 107718*x^11 - 74352*x^12 + 25041*x^13 + 
             9478*x^14 - 5120*x^15 + 9478*x^16 + 25041*x^17 - 74352*x^18 - 
             107718*x^19 + 247748*x^20 + 276662*x^21 - 385027*x^22 - 
             411032*x^23 + 284157*x^24 + 348507*x^25 - 64954*x^26 - 
             157050*x^27 - 28750*x^28 + 29250*x^29 + 13500*x^30) + 
           1440*x^13*(5 - 18*x - 339*x^2 - 2100*x^3 - 4286*x^4 - 5844*x^5 - 
             4286*x^6 - 2100*x^7 - 339*x^8 - 18*x^9 + 5*x^10)*Zeta[3]))/
         (97200*x^13*(-1 + x^2)^8) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(13500 + 29250*x - 28750*x^2 - 
             157050*x^3 - 64954*x^4 + 348507*x^5 + 284157*x^6 - 411032*x^7 - 
             385027*x^8 + 276662*x^9 + 247748*x^10 - 107718*x^11 - 
             74352*x^12 + 25041*x^13 + 9478*x^14 - 5120*x^15 + 9478*x^16 + 
             25041*x^17 - 74352*x^18 - 107718*x^19 + 247748*x^20 + 
             276662*x^21 - 385027*x^22 - 411032*x^23 + 284157*x^24 + 
             348507*x^25 - 64954*x^26 - 157050*x^27 - 28750*x^28 + 
             29250*x^29 + 13500*x^30) + 1440*x^13*(5 - 18*x - 339*x^2 - 
             2100*x^3 - 4286*x^4 - 5844*x^5 - 4286*x^6 - 2100*x^7 - 339*x^8 - 
             18*x^9 + 5*x^10)*Zeta[3]))/(97200*x^13*(-1 + x^2)^8) + 
        (HPL[{0}, x]*(-36159245640000 - 78345032220000*x + 
           2198348211780000*x^2 + 5016894447852000*x^3 - 57706373159371440*
            x^4 - 141230878491777480*x^5 + 852327119190645000*x^6 + 
           2300896176514820640*x^7 - 7714853590587192000*x^8 - 
           24075600590423222820*x^9 + 306180*(141433061679767 + 5431050*Pi^2)*
            x^10 + 87480*(1946687235501709 + 118078317*Pi^2)*x^11 - 
           5040*(-2340558037312852475 + 305416653542808746*Pi^2)*x^28 - 
           135*(1261390262475837393 + 9376537767487827496*Pi^2)*x^45 - 
           210*(206203779100377171 + 475503059172754076*Pi^2)*x^46 + 
           945*(25476776671386069 + 356719565300841808*Pi^2)*x^47 + 
           181440*(42520136632425 + 337821470150509*Pi^2)*x^48 - 
           816480*(2818068019443 + 79431610047526*Pi^2)*x^49 - 
           204120*(4175617867875 + 83430909730246*Pi^2)*x^50 + 
           1837080*(76877914131 + 4788081390100*Pi^2)*x^51 + 
           1224720*(47118013227 + 2333047396832*Pi^2)*x^52 - 
           11022480*(455151150 + 73865564723*Pi^2)*x^53 - 
           99202320*(22160250 + 3058452289*Pi^2)*x^54 + 
           297606960*(263250 + 163811471*Pi^2)*x^55 + 1190427840*
            (30375 + 16774847*Pi^2)*x^56 - 1698413160024000*Pi^2*x^57 - 
           744835819140000*Pi^2*x^58 + 26115010740000*Pi^2*x^59 + 
           12053081880000*Pi^2*x^60 - 600*x^25*(804701742705905205*Pi^2 + 
             64*(594839926165389911 - 1883296086693525*Zeta[3])) - 
           42*x^29*(-637329332381086970639 + 60983772627026334460*Pi^2 - 
             30659695598763360000*Zeta[3]) + 168*x^27*(8484670674432337609 + 
             8162882267794689105*Pi^2 - 7664923899690840000*Zeta[3]) + 
           30*x^31*(1238662047955596644017 + 198080919057341761196*Pi^2 - 
             2410618990967712000*Zeta[3]) - 280*x^24*(-67729445427564397009 + 
             956079684698841612*Pi^2 - 1551136858419513600*Zeta[3]) + 
           2240*x^22*(-6631659190229187347 + 21953778161003868*Pi^2 - 
             17506556014770000*Zeta[3]) - 840*x^36*(8914789832865361471 + 
             14005888600248235584*Pi^2 - 13072571462534400*Zeta[3]) + 
           840*x^38*(4074405039490877765 + 10328371015346525778*Pi^2 - 
             3780852672528000*Zeta[3]) - 840*x^40*(776025038565364167 + 
             5384092799543792804*Pi^2 - 404095832121600*Zeta[3]) - 
           8400*x^18*(444803572834111529 + 33594168088386*Pi^2 - 
             378085267252800*Zeta[3]) + 7560*x^16*(89341161527149223 + 
             7039655394660*Pi^2 - 44899536902400*Zeta[3]) + 
           2100*x^42*(-74698918310748399 + 709317325552546574*Pi^2 - 
             8209870629120*Zeta[3]) - 3150*x^14*(-49633280350340311 + 
             835001542620*Pi^2 - 5473247086080*Zeta[3]) + 
           170100*x^12*(-822724365063839 + 73474452*Pi^2 - 
             2040733440*Zeta[3]) + 1728*x^43*(485374798709150892 + 
             2031161799647600585*Pi^2 + 502211745000*Zeta[3]) - 
           81*x^13*(10358478913078793351 + 5178394171440*Pi^2 + 
             10713850560000*Zeta[3]) + 1215*x^15*(2424204600374788891 + 
             5146212571416*Pi^2 + 37855605312000*Zeta[3]) - 
           216*x^17*(34873146186782471279 + 216197068505985*Pi^2 + 
             4654126443960000*Zeta[3]) - 840*x^20*(-11091721109917061431 + 
             3563994599297568*Pi^2 + 13072571462534400*Zeta[3]) + 
           36*x^39*(209023211748556334019 + 324359542804122916370*Pi^2 + 
             27924758663760000*Zeta[3]) - 540*x^21*(39223247239907281379 + 
             15478174598865678*Pi^2 + 129633514193232000*Zeta[3]) + 
           280*x^34*(42533007300742872421 + 42029568960010291890*Pi^2 + 
             140052448118160000*Zeta[3]) + 72*x^19*(199667255993663411102 + 
             6577577274567915*Pi^2 + 159397279219080000*Zeta[3]) - 
           36*x^37*(409597411679011353739 + 399614561704042168890*Pi^2 + 
             318794558438160000*Zeta[3]) - 280*x^32*(114576286117444333849 + 
             31710714662564474484*Pi^2 + 1551136858419513600*Zeta[3]) + 
           140*x^30*(457675263447909782155 + 35416076453954881536*Pi^2 + 
             7394534495191123200*Zeta[3]) - 24*x^33*(1705671963684374076421 + 
             430578694144300171715*Pi^2 + 7868955392280360000*Zeta[3]) + 
           12*x^23*(2104694067724811794697 + 7386467782689773190*Pi^2 + 
             15737910784560720000*Zeta[3]) - 420*x^44*
            (407700239397101276*Pi^2 - 405*(822573601815227 + 2040733440*
                Zeta[3])) - 60*x^41*(122063728614821989814*Pi^2 + 
             729*(67244134479290057 + 1051544592000*Zeta[3])) + 
           120*x^35*(114998321113636235387*Pi^2 + 1185*(177086198361253067 + 
               492279167822400*Zeta[3])) + 560*x^26*
            (1257519688842712158*Pi^2 - 5*(9204214341377589767 + 
               369726724759556160*Zeta[3]))))/(81648000*x^9*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6) + (-33600*Pi^4*x^11*(-1 + x^2)^2*
           (9 - 82*x^2 + 9*x^4)^6*(5 - 18*x - 339*x^2 - 2100*x^3 - 4286*x^4 - 
            5844*x^5 - 4286*x^6 - 2100*x^7 - 339*x^8 - 18*x^9 + 5*x^10) - 
          4*Pi^2*(9 - 82*x^2 + 9*x^4)^6*(-11340000 - 24570000*x + 
            75180000*x^2 + 242487000*x^3 - 142943640*x^4 - 1078859880*x^5 - 
            222278000*x^6 + 2853669840*x^7 + 1644077960*x^8 - 
            4981874100*x^9 - 3826333000*x^10 + 6025373609*x^11 + 
            5172549410*x^12 - 5182158541*x^13 - 4815968500*x^14 + 
            2739771139*x^15 + 1417947650*x^16 - 2471864115*x^17 + 
            2471864115*x^19 - 1417947650*x^20 - 2739771139*x^21 + 
            4815968500*x^22 + 5182158541*x^23 - 5172549410*x^24 - 
            6025373609*x^25 + 3826333000*x^26 + 4981874100*x^27 - 
            1644077960*x^28 - 2853669840*x^29 + 222278000*x^30 + 
            1078859880*x^31 + 142943640*x^32 - 242487000*x^33 - 
            75180000*x^34 + 24570000*x^35 + 11340000*x^36) + 
          x^2*(36159245640000 + 78345032220000*x - 2210401293660000*x^2 - 
            5043009458592000*x^3 + 58434635990926440*x^4 + 142893383512033980*
             x^5 - 871290294442687980*x^6 - 2347351464833335800*x^7 + 
            7991912819405852820*x^8 + x^35*(20273745446592116876556 - 
              167254734086786990266560*Zeta[3]) + 
            x^21*(25251231307293085246836 - 1508451004123878810240*Zeta[3]) + 
            20380957920288000*x^57*Zeta[3] + 8938029829680000*x^58*Zeta[3] - 
            313380128880000*x^59*Zeta[3] - 144636982560000*x^60*Zeta[3] + 
            137781*x^9*(180179659012757 + 28615680*Zeta[3]) - 
            3571283520*x^56*(-10125 + 67099388*Zeta[3]) - 1785641760*x^55*
             (-43875 + 327622942*Zeta[3]) - 153090*x^10*(298998217339907 + 
              2257217280*Zeta[3]) + 595213920*x^54*(-3713625 + 
              6116904578*Zeta[3]) + 132269760*x^53*(-38126700 + 
              73865564723*Zeta[3]) + 34020*x^12*(4510957281064519 + 
              175892396832*Zeta[3]) - 2187*x^11*(81415368160203493 + 
              1012636054080*Zeta[3]) - 1837080*x^52*(-31808432943 + 
              18664379174656*Zeta[3]) - 2755620*x^51*(-51855257079 + 
              38304651120800*Zeta[3]) + 3150*x^14*(-62527526441861419 + 
              77871101901696*Zeta[3]) + 306180*x^50*(-2845679974011 + 
              667447277841968*Zeta[3]) + 81*x^13*(11030059321128237827 + 
              1118317546221120*Zeta[3]) + 612360*x^49*(-3833286734655 + 
              1270905760760416*Zeta[3]) - 4200*x^16*(158311709952753125 + 
              2212774508743488*Zeta[3]) - 68040*x^48*(-117458852848533 + 
              10810287044816288*Zeta[3]) + 108*x^17*(78758670034416945493 + 
              21786231213437040*Zeta[3]) - 27*x^15*(119052490837843800191 + 
              47516536633587840*Zeta[3]) + 1296*x^19*(-13070950063665822767 + 
              99786684010080900*Zeta[3]) + 420*x^18*(10198710982554051271 + 
              299837609802221904*Zeta[3]) - 840*x^20*(14711695661652548495 + 
              964725908628731904*Zeta[3]) + 1260*x^44*(121789683696098853 + 
              1630803814568926688*Zeta[3]) + 630*x^46*(-72656061501845511 + 
              1902011802510805184*Zeta[3]) + 560*x^22*(40711800119077830883 + 
              3525312826453768044*Zeta[3]) - 3150*x^42*(62421967545929317 + 
              5674455741089577664*Zeta[3]) - 567*x^47*(-43783639020010341 + 
              7134391324572393920*Zeta[3]) + 8960*x^32*
             (-1675795696818889459 + 11982415619549873853*Zeta[3]) + 
            280*x^24*(-89522338474223507603 + 12448409655096574272*Zeta[3]) - 
            210*x^25*(-103150348091604709799 + 52973545327716320224*Zeta[
                3]) - 1120*x^34*(-19836802266859596179 + 
              123955176537156192576*Zeta[3]) + 420*x^40*
             (-1601130514521755315 + 129196743147864584256*Zeta[3]) + 
            280*x^28*(-211875689089983018325 + 161138264304825870528*Zeta[
                3]) + 840*x^36*(-15120807461215007015 + 167091541299483164928*
               Zeta[3]) + 81*x^45*(-2198148599144296341 + 
              187530741336017972480*Zeta[3]) - 140*x^26*
             (-172909418047751276629 + 187571663560535563584*Zeta[3]) + 
            28*x^23*(-937591119375267390583 + 246881381256769278720*Zeta[
                3]) - 420*x^38*(-10391335142690633971 + 247589475428699846208*
               Zeta[3]) - 30*x^27*(690596400064551622231 + 
              281514324163111156320*Zeta[3]) - 210*x^31*
             (-53381618524156986461 + 417157895256292354720*Zeta[3]) - 
            81*x^43*(-11026206639243420257 + 519976697623938101120*Zeta[3]) - 
            140*x^30*(10257965943646200941 + 556854490762968616992*Zeta[3]) + 
            216*x^37*(-73838715276695552647 + 799949158792806918840*Zeta[
                3]) + 30*x^29*(-1302068553866529650245 + 
              1245064255575257938464*Zeta[3]) - 108*x^39*
             (-77685517652626766803 + 1297457515308222852080*Zeta[3]) + 
            28*x^33*(-468918226508343087973 + 4711633832062027408080*Zeta[
                3]) + 9*x^41*(-356261709669084089943 + 9765010833620938141120*
               Zeta[3])))/(326592000*x^11*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^
           6)))
 
CbarData["a", 2, 4] = 
    NC*(CF*(NL*((Pi^2*(-9 + 42*x + 97*x^2 + 672*x^3 + 1032*x^4 + 1512*x^5 + 
             1032*x^6 + 672*x^7 + 97*x^8 + 42*x^9 - 9*x^10)*HPL[{-1}, x])/
           (17010*(-1 + x^2)^9) + (x^2*(-40734 - 630*(134051 + 7560*Pi^2)*x - 
             9*(26158271 + 1587600*Pi^2)*x^2 - 189*(4343957 + 315000*Pi^2)*
              x^3 - 30*(38136239 + 3339840*Pi^2)*x^4 - 
             21*(56400791 + 8589000*Pi^2)*x^5 - 35*(8506727 + 5102580*Pi^2)*
              x^6 - 588*(-1372717 + 305400*Pi^2)*x^7 + 
             (1234513758 - 99454320*Pi^2)*x^8 - 1134*(-976277 + 52360*Pi^2)*
              x^9 - 15*(-29153885 + 972552*Pi^2)*x^10 - 
             105*(-1666597 + 47544*Pi^2)*x^11 + (5685058 - 52080*Pi^2)*x^12 - 
             105*(-5983 + 168*Pi^2)*x^13 + 63*(-3481 + 60*Pi^2)*x^14)*
            HPL[{0}, x])/(7144200*(-1 + x^2)^12) + 
          lm^2*(-(-3 + 14*x + 102*x^2 + 1428*x^3 + 3399*x^4 + 7378*x^5 + 8124*
                x^6 + 7378*x^7 + 3399*x^8 + 1428*x^9 + 102*x^10 + 14*x^11 - 3*
                x^12)/(630*(-1 + x^2)^10) + (4*x^3*(1 + 3*x + 10*x^2 + 15*
                x^3 + 20*x^4 + 15*x^5 + 10*x^6 + 3*x^7 + x^8)*HPL[{0}, x])/
             (3*(-1 + x^2)^11)) + (Pi^2*(9 - 42*x - 97*x^2 - 672*x^3 - 
             1032*x^4 - 1512*x^5 - 1032*x^6 - 672*x^7 - 97*x^8 - 42*x^9 + 
             9*x^10)*HPL[{1}, x])/(17010*(-1 + x^2)^9) + 
          (2*x^3*(11340 + 34020*x + 141750*x^2 + 238560*x^3 + 429450*x^4 + 
             425215*x^5 + 427560*x^6 + 236796*x^7 + 141372*x^8 + 34734*x^9 + 
             11886*x^10 + 124*x^11 + 42*x^12 - 9*x^13)*HPL[{-2, 0}, x])/
           (2835*(-1 + x^2)^12) - ((-2263 + 9464*x + 191285*x^2 + 
             4941496*x^3 + 12977163*x^4 + 39520180*x^5 + 54694615*x^6 + 
             73933720*x^7 + 54694615*x^8 + 39520180*x^9 + 12977163*x^10 + 
             4941496*x^11 + 191285*x^12 + 9464*x^13 - 2263*x^14)*
            HPL[{-1, 0}, x])/(396900*(-1 + x^2)^11) + 
          (x^3*(-882000 - 2646000*x - 14420700*x^2 - 27400800*x^3 - 
             63185500*x^4 - 75248075*x^5 - 90821500*x^6 - 60984028*x^7 - 
             40870116*x^8 - 12007842*x^9 - 4403728*x^10 - 76092*x^11 - 
             25816*x^12 + 5297*x^13)*HPL[{0, 0}, x])/(198450*(-1 + x^2)^12) + 
          ((-2263 + 9464*x + 191285*x^2 + 4941496*x^3 + 12977163*x^4 + 
             39520180*x^5 + 54694615*x^6 + 73933720*x^7 + 54694615*x^8 + 
             39520180*x^9 + 12977163*x^10 + 4941496*x^11 + 191285*x^12 + 
             9464*x^13 - 2263*x^14)*HPL[{1, 0}, x])/(396900*(-1 + x^2)^11) + 
          lm*(-(-31329 + 89745*x + 743674*x^2 + 13113855*x^3 + 30359225*x^4 + 
               67008000*x^5 + 72892860*x^6 + 67008000*x^7 + 30359225*x^8 + 
               13113855*x^9 + 743674*x^10 + 89745*x^11 - 31329*x^12 - 60*Pi^2*
                (-9 + 42*x + 106*x^2 + 630*x^3 + 935*x^4 + 840*x^5 - 
                 840*x^7 - 935*x^8 - 630*x^9 - 106*x^10 - 42*x^11 + 9*x^12))/
             (2041200*(-1 + x^2)^10) + (x^2*(-18 + 35184*x + 100724*x^2 + 
               389451*x^3 + 612882*x^4 + 939762*x^5 + 782982*x^6 + 603651*
                x^7 + 219416*x^8 + 86088*x^9 + 3762*x^10 + 504*x^11 - 108*
                x^12)*HPL[{0}, x])/(5670*(-1 + x^2)^11) + 
            ((-9 + 42*x + 97*x^2 + 672*x^3 + 1032*x^4 + 1512*x^5 + 1032*x^6 + 
               672*x^7 + 97*x^8 + 42*x^9 - 9*x^10)*HPL[{-1, 0}, x])/
             (2835*(-1 + x^2)^9) + (2*x^3*(-3780 - 11340*x - 73710*x^2 - 
               147840*x^3 - 353850*x^4 - 425215*x^5 - 503160*x^6 - 327516*
                x^7 - 209412*x^8 - 57414*x^9 - 19446*x^10 - 124*x^11 - 42*
                x^12 + 9*x^13)*HPL[{0, 0}, x])/(2835*(-1 + x^2)^12) - 
            ((-9 + 42*x + 97*x^2 + 672*x^3 + 1032*x^4 + 1512*x^5 + 1032*x^6 + 
               672*x^7 + 97*x^8 + 42*x^9 - 9*x^10)*HPL[{1, 0}, x])/
             (2835*(-1 + x^2)^9)) + (2*x^3*(-11340 - 34020*x - 141750*x^2 - 
             238560*x^3 - 429450*x^4 - 425215*x^5 - 427560*x^6 - 236796*x^7 - 
             141372*x^8 - 34734*x^9 - 11886*x^10 - 124*x^11 - 42*x^12 + 
             9*x^13)*HPL[{2, 0}, x])/(2835*(-1 + x^2)^12) + 
          (2*(9 - 42*x - 97*x^2 - 672*x^3 - 1032*x^4 - 1512*x^5 - 1032*x^6 - 
             672*x^7 - 97*x^8 - 42*x^9 + 9*x^10)*HPL[{-1, -1, 0}, x])/
           (2835*(-1 + x^2)^9) + (2*(-9 + 42*x + 97*x^2 + 672*x^3 + 
             1032*x^4 + 1512*x^5 + 1032*x^6 + 672*x^7 + 97*x^8 + 42*x^9 - 
             9*x^10)*HPL[{-1, 1, 0}, x])/(2835*(-1 + x^2)^9) + 
          (4*x^3*(3780 + 11340*x + 73710*x^2 + 147840*x^3 + 353850*x^4 + 
             425215*x^5 + 503160*x^6 + 327516*x^7 + 209412*x^8 + 57414*x^9 + 
             19446*x^10 + 124*x^11 + 42*x^12 - 9*x^13)*HPL[{0, 0, 0}, x])/
           (2835*(-1 + x^2)^12) + (2*(-9 + 42*x + 97*x^2 + 672*x^3 + 
             1032*x^4 + 1512*x^5 + 1032*x^6 + 672*x^7 + 97*x^8 + 42*x^9 - 
             9*x^10)*HPL[{1, -1, 0}, x])/(2835*(-1 + x^2)^9) + 
          (2*(9 - 42*x - 97*x^2 - 672*x^3 - 1032*x^4 - 1512*x^5 - 1032*x^6 - 
             672*x^7 - 97*x^8 - 42*x^9 + 9*x^10)*HPL[{1, 1, 0}, x])/
           (2835*(-1 + x^2)^9) - (12572078*x^14 - 1805349*x^15 - 
            1509963*x^16 + 18*Pi^2*(-2263 + 9464*x + 193548*x^2 + 
              4932032*x^3 + 12785878*x^4 + 34578684*x^5 + 41717452*x^6 + 
              34413540*x^7 - 34413540*x^9 - 41717452*x^10 - 34578684*x^11 - 
              12785878*x^12 - 4932032*x^13 - 193548*x^14 - 9464*x^15 + 
              2263*x^16) - 21*(71903 + 12960*Zeta[3]) + 
            21*x*(-85969 + 60480*Zeta[3]) + 2*x^2*(6286039 + 1874880*Zeta[
                3]) + 147*x^13*(3733421 + 2332800*Zeta[3]) + 
            147*x^3*(3733421 + 2445120*Zeta[3]) + 189*x^5*
             (9463277 + 22619520*Zeta[3]) + 189*x^11*(9463277 + 
              22680000*Zeta[3]) + 30*x^12*(39983081 + 34292160*Zeta[3]) + 
            30*x^4*(39983081 + 35011872*Zeta[3]) + 162*x^6*
             (3672633 + 44201920*Zeta[3]) + 162*x^10*(3672633 + 
              44531200*Zeta[3]) + 21*x^7*(-111217471 + 615686400*Zeta[3]) + 
            21*x^9*(-111217471 + 618408000*Zeta[3]) + 
            2*x^8*(-1805521091 + 6429250800*Zeta[3]))/
           (85730400*(-1 + x^2)^12)) + 
        NH*((x*(-820091691115200 + 4351033303725744*x - 1449795946756993164*
              x^2 - 3418903784653343271*x^3 - 9945690018891840738*x^4 - 
             12163711121442710271*x^5 - 10310588302931995428*x^6 - 
             1668258036091206063*x^7 + 5507300504318706954*x^8 + 
             5838994115638812729*x^9 + 1684804090081503132*x^10 - 
             1723134590476036227*x^11 - 1482185311080060258*x^12 - 
             101752941290566347*x^13 + 329785809460080372*x^14 + 
             154858481339629077*x^15 - 15585238273279878*x^16 - 
             38001484140700563*x^17 - 6490245374469108*x^18 + 
             4723278213207627*x^19 + 1531651658164362*x^20 - 
             303157761721437*x^21 - 164859158762844*x^22 + 3802758255923*
              x^23 + 10194699032910*x^24 + 931676345803*x^25 - 
             357214132380*x^26 - 75395309025*x^27 + 5651661498*x^28 + 
             2559653863*x^29 + 11966220*x^30 - 36138841*x^31 - 920850*x^32 + 
             59679*x^33)*HPL[{0}, x])/(14288400*(-9 + x^2)^8*(-1 + x^2)^13) + 
          lm^2*(-(-3 + 14*x + 102*x^2 + 1428*x^3 + 3399*x^4 + 7378*x^5 + 8124*
                x^6 + 7378*x^7 + 3399*x^8 + 1428*x^9 + 102*x^10 + 14*x^11 - 3*
                x^12)/(630*(-1 + x^2)^10) + (4*x^3*(1 + 3*x + 10*x^2 + 15*
                x^3 + 20*x^4 + 15*x^5 + 10*x^6 + 3*x^7 + x^8)*HPL[{0}, x])/
             (3*(-1 + x^2)^11)) + (x*(22780324753200 - 47223853637292*x + 
             29527615268405856*x^2 + 69498559759525263*x^3 + 
             200389695238911780*x^4 + 240808037734812987*x^5 + 
             190155579967846584*x^6 + 5489094336786369*x^7 - 
             145941413662897776*x^8 - 135605655652086783*x^9 - 
             35406015618866760*x^10 + 45739746378576567*x^11 + 
             38922245917417044*x^12 + 2899338636359115*x^13 - 
             8342385066477504*x^14 - 4427769642626679*x^15 - 
             8125560587424*x^16 + 1023931159235001*x^17 + 276262460611536*
              x^18 - 103663627420459*x^19 - 48390396059124*x^20 + 
             2314580247913*x^21 + 3563742599480*x^22 + 559086320283*x^23 - 
             63344456784*x^24 - 63015884821*x^25 - 7563900008*x^26 + 
             2864590117*x^27 + 491890812*x^28 - 54202671*x^29 - 
             8574384*x^30 + 88539*x^31 - 24528*x^32 + 4551*x^33)*
            HPL[{0, 0}, x])/(396900*(-9 + x^2)^8*(-1 + x^2)^13) + 
          lm*(-(-31329 + 89745*x + 743674*x^2 + 13113855*x^3 + 30359225*x^4 + 
               67008000*x^5 + 72892860*x^6 + 67008000*x^7 + 30359225*x^8 + 
               13113855*x^9 + 743674*x^10 + 89745*x^11 - 31329*x^12 - 60*Pi^2*
                (-9 + 42*x + 106*x^2 + 630*x^3 + 935*x^4 + 840*x^5 - 
                 840*x^7 - 935*x^8 - 630*x^9 - 106*x^10 - 42*x^11 + 9*x^12))/
             (2041200*(-1 + x^2)^10) + (x^2*(-18 + 35184*x + 100724*x^2 + 
               389451*x^3 + 612882*x^4 + 939762*x^5 + 782982*x^6 + 603651*
                x^7 + 219416*x^8 + 86088*x^9 + 3762*x^10 + 504*x^11 - 108*
                x^12)*HPL[{0}, x])/(5670*(-1 + x^2)^11) + 
            ((-9 + 42*x + 97*x^2 + 672*x^3 + 1032*x^4 + 1512*x^5 + 1032*x^6 + 
               672*x^7 + 97*x^8 + 42*x^9 - 9*x^10)*HPL[{-1, 0}, x])/
             (2835*(-1 + x^2)^9) + (2*x^3*(-3780 - 11340*x - 73710*x^2 - 
               147840*x^3 - 353850*x^4 - 425215*x^5 - 503160*x^6 - 327516*
                x^7 - 209412*x^8 - 57414*x^9 - 19446*x^10 - 124*x^11 - 42*
                x^12 + 9*x^13)*HPL[{0, 0}, x])/(2835*(-1 + x^2)^12) - 
            ((-9 + 42*x + 97*x^2 + 672*x^3 + 1032*x^4 + 1512*x^5 + 1032*x^6 + 
               672*x^7 + 97*x^8 + 42*x^9 - 9*x^10)*HPL[{1, 0}, x])/
             (2835*(-1 + x^2)^9)) + (2*(3264 + 84465*x + 219822*x^2 + 
             777450*x^3 + 1142619*x^4 + 1726250*x^5 + 1352585*x^6 + 
             1070370*x^7 + 390870*x^8 + 209145*x^9 + 27816*x^10 + 
             17680*x^11 + 13*x^12 + 60*x^13 - 9*x^14)*HPL[{-1, 0, 0}, x])/
           (2835*(-1 + x)^12*(1 + x)^10) + (2*x^3*(-1111398435774900 - 
             2559323203238673*x - 7432308303986286*x^2 - 8741994552108567*
              x^3 - 6958713570187428*x^4 - 66706121069685*x^5 + 
             5985886029183018*x^6 + 5601774848594661*x^7 + 1986917418288684*
              x^8 - 1610717975636517*x^9 - 1745892528042978*x^10 - 
             318837624522579*x^11 + 264759365501820*x^12 + 226431299375199*
              x^13 + 42100589345598*x^14 - 43036342972383*x^15 - 
             18730871843964*x^16 + 3086667390125*x^17 + 2461527189534*x^18 + 
             119218036283*x^19 - 123554256588*x^20 - 39508229391*x^21 - 
             3042941034*x^22 + 3121322431*x^23 + 667231236*x^24 - 
             118872183*x^25 - 29870862*x^26 + 2267439*x^27 + 479220*x^28 - 
             26075*x^29 - 1470*x^30 + 315*x^31)*HPL[{0, 0, 0}, x])/
           (99225*(-9 + x^2)^8*(-1 + x^2)^13) + 
          (2*(-1374 - 88071*x - 226584*x^2 - 793686*x^3 - 1209399*x^4 - 
             1849210*x^5 - 1695725*x^6 - 1462230*x^7 - 741360*x^8 - 
             374655*x^9 - 86406*x^10 - 21464*x^11 - 181*x^12 - 24*x^13 + 
             9*x^14)*HPL[{1, 0, 0}, x])/(2835*(-1 + x)^10*(1 + x)^12) - 
          ((-21903432754293 + 4408495244933724*x + 10309238258339007*x^2 + 
             30176502875162280*x^3 + 37129382999876115*x^4 + 
             33400367229778920*x^5 + 9034407342991431*x^6 - 11512964437247448*
              x^7 - 14746447481398641*x^8 - 5166439315686684*x^9 + 
             3213098028866547*x^10 + 3184774577012448*x^11 + 
             377573890927815*x^12 - 617827595420448*x^13 - 295700160590901*
              x^14 + 29586882031056*x^15 + 62413241242833*x^16 + 
             9912177993060*x^17 - 7034251137363*x^18 - 2382372291096*x^19 + 
             419657725129*x^20 + 258379405704*x^21 - 5428168987*x^22 - 
             15700455288*x^23 - 994158891*x^24 + 498239196*x^25 + 
             68019297*x^26 - 5290992*x^27 - 1652067*x^28 - 46032*x^29 + 
             10569*x^30)*master3l8a[x])/(1190700*(-9 + x^2)^8*
            (-1 + x^2)^13) + ((-2433714750477 + 242855374820436*x + 
             576462015234576*x^2 + 1728304626890016*x^3 + 2246872878988173*
              x^4 + 2356804968477120*x^5 + 1238651997760026*x^6 + 
             312845843288412*x^7 - 256027309605477*x^8 - 97750959535656*x^9 - 
             29373914667996*x^10 - 44973493178796*x^11 - 32163919198371*
              x^12 - 14809150843956*x^13 + 13888724329014*x^14 + 
             10997656653144*x^15 - 1085635596991*x^16 - 1839101004636*x^17 - 
             216283550456*x^18 + 77953453704*x^19 + 49090027471*x^20 + 
             9913816248*x^21 - 3928288922*x^22 - 1319169012*x^23 + 
             146688561*x^24 + 57059184*x^25 - 2559612*x^26 - 885948*x^27 + 
             35911*x^28 + 2940*x^29 - 630*x^30)*master3l9a[x])/
           (396900*(-9 + x^2)^7*(-1 + x^2)^13) + 
          (x^18*(286233026343645970 - 73504813156588800*Zeta[3]) + 
            x^26*(3386969948012 - 4062241935360*Zeta[3]) + 
            x^32*(531541319 - 31489920*Zeta[3]) - 42*x^33*
             (-587929 + 40320*Zeta[3]) + 3*x^34*(-601463 + 120960*Zeta[3]) - 
            1008*x^31*(-1757591 + 126000*Zeta[3]) + 420*x^29*
             (-487133215 + 74624256*Zeta[3]) + 4*x^30*(-6319161269 + 
              165090240*Zeta[3]) + 43046721*(-1177809209 + 330583680*Zeta[
                3]) + 66961566*x*(114435988517 + 1141983360*Zeta[3]) + 
            12*x^28*(32551936103 + 4985830080*Zeta[3]) - 
            168*x^27*(-43024637281 + 9445917600*Zeta[3]) + 
            1594323*x^2*(11224713982649 + 79632927360*Zeta[3]) - 
            9920232*x^3*(-6386280618829 + 109338919200*Zeta[3]) + 
            252*x^25*(-540670581967 + 150124141440*Zeta[3]) - 
            2688*x^23*(-569320166069 + 180130296150*Zeta[3]) + 
            2520*x^19*(4961668969037 + 258824210400*Zeta[3]) + 
            489888*x^7*(102865564004129 + 566397279000*Zeta[3]) - 
            1653372*x^5*(-79152413895017 + 4278840733440*Zeta[3]) - 
            236196*x^4*(-383303139885929 + 13601999960640*Zeta[3]) - 
            108*x^22*(-40811683318411 + 15780025024960*Zeta[3]) + 
            4*x^24*(-58822793588621 + 27873557832960*Zeta[3]) + 
            84*x^21*(-114116402126623 + 35630046869760*Zeta[3]) - 
            111132*x^12*(-137012223249413 + 40237393256640*Zeta[3]) + 
            15120*x^15*(-185252204356843 + 58791633339600*Zeta[3]) - 
            1680*x^17*(-191441152895669 + 83779406565120*Zeta[3]) + 
            102060*x^9*(-510760083639037 + 110285219737728*Zeta[3]) + 
            78732*x^8*(-248597658281983 + 111530683192320*Zeta[3]) - 
            26244*x^6*(-3944463739573807 + 249106122740160*Zeta[3]) - 
            4536*x^11*(715958788193563 + 529223498445600*Zeta[3]) + 
            90*x^16*(-9514549813039039 + 908002251354240*Zeta[3]) - 
            756*x^13*(-12373627926628967 + 2382653961596160*Zeta[3]) + 
            4*x^20*(-11549084872810729 + 3822780227676480*Zeta[3]) + 
            972*x^10*(-36815247680121287 + 4445489720689920*Zeta[3]) + 
            108*x^14*(-7833870653959097 + 8859170245141440*Zeta[3]))/
           (171460800*(-9 + x^2)^8*(-1 + x^2)^13)) + 
        NM*(-((430920 - 2010960*x - 31708188*x^2 + 525937860*x^3 + 
              2264852355*x^4 - 34857187218*x^5 - 120156777333*x^6 + 
              865577598900*x^7 + 3305019211219*x^8 - 6878256286230*x^9 - 
              44679358428325*x^10 - 77111450400516*x^11 + 203504385894063*x^
                12 + 1978777869609198*x^13 + 1904768338022087*x^14 - 
              14056277890684932*x^15 - 28745348455299377*x^16 + 
              13701259420901178*x^17 + 111326382391276863*x^18 + 
              284265306679941468*x^19 + 144674712711319113*x^20 - 
              943241251782170502*x^21 - 1722698571353895999*x^22 - 
              1600179352123154292*x^23 + 637760452989086073*x^24 + 
              6186421561279705326*x^25 + 7769225311592135121*x^26 + 
              8989275755343108708*x^27 + 5192628162555895749*x^28 + 
              2687399947304921898*x^29 + 980474840813323053*x^30 + 
              103342162780212804*x^31 + 37215449703854685*x^32 - 
              20936614927588290*x^33 - 12794627611150479*x^34 + 
              840*Pi^2*(1 - 9*x^2)^8*(-1 + x^2)^4*(9 - 42*x - 97*x^2 - 
                672*x^3 - 1032*x^4 - 1512*x^5 - 1032*x^6 - 672*x^7 - 97*x^8 - 
                42*x^9 + 9*x^10))*HPL[{0}, x])/(14288400*(1 - 9*x^2)^8*
            (-1 + x^2)^13) + lm^2*(-(-3 + 14*x + 102*x^2 + 1428*x^3 + 3399*
                x^4 + 7378*x^5 + 8124*x^6 + 7378*x^7 + 3399*x^8 + 1428*x^9 + 
               102*x^10 + 14*x^11 - 3*x^12)/(630*(-1 + x^2)^10) + 
            (4*x^3*(1 + 3*x + 10*x^2 + 15*x^3 + 20*x^4 + 15*x^5 + 10*x^6 + 3*
                x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11)) + 
          (2*(9 - 42*x - 97*x^2 - 672*x^3 - 1032*x^4 - 1512*x^5 - 1032*x^6 - 
             672*x^7 - 97*x^8 - 42*x^9 + 9*x^10)*HPL[{-2, 0}, x])/
           (2835*(-1 + x^2)^9) + ((7560 - 35280*x - 521784*x^2 + 
             12793032*x^3 + 47012011*x^4 - 739252080*x^5 - 2403836529*x^6 + 
             11904903752*x^7 + 51232405605*x^8 + 102915432228*x^9 - 
             245088995715*x^10 - 5529672084608*x^11 - 8106147142125*x^12 + 
             65333988931008*x^13 + 152503345091135*x^14 - 211783911552528*
              x^15 - 988021055565891*x^16 - 1736948718808044*x^17 + 
             642146975915613*x^18 + 15458216618464200*x^19 + 
             22097540271403017*x^20 - 18381200159293776*x^21 - 
             79259541772447035*x^22 - 147613433730568344*x^23 - 
             62000461681821081*x^24 + 252455383332749772*x^25 + 
             418824091357907103*x^26 + 576524421035693424*x^27 + 
             376258533309750393*x^28 + 225509416841786112*x^29 + 
             88211540713871277*x^30 + 16105823847705312*x^31 + 
             2997484052827311*x^32 - 1695250118851380*x^33 - 
             985003607521665*x^34)*HPL[{0, 0}, x])/(396900*(1 - 9*x^2)^8*
            (-1 + x^2)^13) + lm*(-(-31329 + 89745*x + 743674*x^2 + 13113855*
                x^3 + 30359225*x^4 + 67008000*x^5 + 72892860*x^6 + 67008000*
                x^7 + 30359225*x^8 + 13113855*x^9 + 743674*x^10 + 89745*
                x^11 - 31329*x^12 - 60*Pi^2*(-9 + 42*x + 106*x^2 + 630*x^3 + 
                 935*x^4 + 840*x^5 - 840*x^7 - 935*x^8 - 630*x^9 - 106*x^10 - 
                 42*x^11 + 9*x^12))/(2041200*(-1 + x^2)^10) + 
            (x^2*(-18 + 35184*x + 100724*x^2 + 389451*x^3 + 612882*x^4 + 
               939762*x^5 + 782982*x^6 + 603651*x^7 + 219416*x^8 + 86088*
                x^9 + 3762*x^10 + 504*x^11 - 108*x^12)*HPL[{0}, x])/
             (5670*(-1 + x^2)^11) + ((-9 + 42*x + 97*x^2 + 672*x^3 + 1032*
                x^4 + 1512*x^5 + 1032*x^6 + 672*x^7 + 97*x^8 + 42*x^9 - 9*
                x^10)*HPL[{-1, 0}, x])/(2835*(-1 + x^2)^9) + 
            (2*x^3*(-3780 - 11340*x - 73710*x^2 - 147840*x^3 - 353850*x^4 - 
               425215*x^5 - 503160*x^6 - 327516*x^7 - 209412*x^8 - 57414*
                x^9 - 19446*x^10 - 124*x^11 - 42*x^12 + 9*x^13)*
              HPL[{0, 0}, x])/(2835*(-1 + x^2)^12) - 
            ((-9 + 42*x + 97*x^2 + 672*x^3 + 1032*x^4 + 1512*x^5 + 1032*x^6 + 
               672*x^7 + 97*x^8 + 42*x^9 - 9*x^10)*HPL[{1, 0}, x])/
             (2835*(-1 + x^2)^9)) + (2*(-9 + 42*x + 97*x^2 + 672*x^3 + 
             1032*x^4 + 1512*x^5 + 1032*x^6 + 672*x^7 + 97*x^8 + 42*x^9 - 
             9*x^10)*HPL[{2, 0}, x])/(2835*(-1 + x^2)^9) + 
          (2*(-27 + 180*x + 39*x^2 + 18600*x^3 + 27378*x^4 + 208345*x^5 + 
             389380*x^6 + 1070370*x^7 + 1354075*x^8 + 1727050*x^9 + 
             1143057*x^10 + 776530*x^11 + 219796*x^12 + 84345*x^13 + 
             3282*x^14)*HPL[{-1, 0, 0}, x])/(2835*(-1 + x)^12*(1 + x)^10) + 
          (2*(-315 + 1470*x + 17255*x^2 - 702660*x^3 - 2401342*x^4 + 
             22578486*x^5 + 92300256*x^6 + 151445196*x^7 - 519337644*x^8 - 
             13837378674*x^9 - 33791581538*x^10 + 105614253108*x^11 + 
             681572840462*x^12 + 2912137311426*x^13 - 1975703943364*x^14 - 
             65969205226764*x^15 - 75897471543486*x^16 + 527325998606862*
              x^17 + 1017350522733360*x^18 - 1367756017427772*x^19 - 
             5036424843438594*x^20 - 5055897075629526*x^21 + 
             5622113660709672*x^22 + 33358950640188180*x^23 + 
             32478283736498700*x^24 - 17387204046501870*x^25 - 
             64136782301115222*x^26 - 114258463745163444*x^27 - 
             86818197760318926*x^28 - 59403437488138338*x^29 - 
             24613016262199236*x^30 - 7135025459735124*x^31 - 
             1301728195588455*x^32 + 68622257477844*x^33 + 190061762266017*
              x^34)*HPL[{0, 0, 0}, x])/(99225*(1 - 9*x^2)^8*(-1 + x^2)^13) - 
          (2*(-27 + 72*x + 543*x^2 + 23232*x^3 + 91008*x^4 + 381335*x^5 + 
             746590*x^6 + 1462230*x^7 + 1690495*x^8 + 1842530*x^9 + 
             1204797*x^10 + 791918*x^11 + 226222*x^12 + 88023*x^13 + 
             1392*x^14)*HPL[{1, 0, 0}, x])/(2835*(-1 + x)^10*(1 + x)^12) - 
          ((1260 - 5880*x - 93731*x^2 + 1870848*x^3 + 7417689*x^4 - 
             124774440*x^5 - 407469435*x^6 + 3167164140*x^7 + 
             11491130833*x^8 - 27872219424*x^9 - 163461086551*x^10 - 
             235837620648*x^11 + 896529870261*x^12 + 7463736467040*x^13 + 
             5312418423137*x^14 - 65011309382796*x^15 - 109732130646699*
              x^16 + 197989239413448*x^17 + 610025036909895*x^18 + 
             441209866586832*x^19 - 897776607162501*x^20 - 3798795535159464*
              x^21 - 3229773873679521*x^22 + 2781230357468052*x^23 + 
             7660651912980003*x^24 + 12430579679484624*x^25 + 
             8767582858712691*x^26 + 5565512949029208*x^27 + 
             2161404791441847*x^28 + 447269659217136*x^29 + 
             71945445384315*x^30 - 37098498165876*x^31 - 21903432754293*x^32)*
            master3l8b[x])/(1190700*x^2*(1 - 9*x^2)^8*(-1 + x^2)^13) + 
          ((630 - 2940*x - 35911*x^2 + 885948*x^3 + 2559612*x^4 - 
             57059184*x^5 - 146688561*x^6 + 1319169012*x^7 + 3928288922*x^8 - 
             9913816248*x^9 - 49090027471*x^10 - 77953453704*x^11 + 
             216283550456*x^12 + 1839101004636*x^13 + 1085635596991*x^14 - 
             10997656653144*x^15 - 13888724329014*x^16 + 14809150843956*
              x^17 + 32163919198371*x^18 + 44973493178796*x^19 + 
             29373914667996*x^20 + 97750959535656*x^21 + 256027309605477*
              x^22 - 312845843288412*x^23 - 1238651997760026*x^24 - 
             2356804968477120*x^25 - 2246872878988173*x^26 - 
             1728304626890016*x^27 - 576462015234576*x^28 - 
             242855374820436*x^29 + 2433714750477*x^30)*master3l9b[x])/
           (1190700*x^2*(-1 + x^2)^13*(-1 + 9*x^2)^7) + 
          (-170100 + 793800*x + x^16*(51175140127946116 - 15291120910705920*
               Zeta[3]) + x^6*(83410207916 - 660360960*Zeta[3]) + 
            x^2*(15752859 - 362880*Zeta[3]) + 7056*x^5*(2794567 + 
              18000*Zeta[3]) + 42*x^3*(-6755809 + 40320*Zeta[3]) + 
            x^4*(-1487318909 + 31489920*Zeta[3]) - 420*x^7*(1352314955 + 
              74624256*Zeta[3]) - 129140163*x^36*(202727207 + 
              110194560*Zeta[3]) - 200884698*x^35*(-44743541 + 
              380661120*Zeta[3]) + 238085568*x^33*(-699108251 + 
              4555788300*Zeta[3]) - 12*x^8*(210900673073 + 4985830080*Zeta[
                3]) - 14348907*x^34*(-15926990089 + 8848103040*Zeta[3]) + 
            168*x^9*(37757014259 + 9445917600*Zeta[3]) - 
            3276*x^11*(-13895497909 + 11548010880*Zeta[3]) + 
            18816*x^13*(-119265335807 + 25732899450*Zeta[3]) - 
            1469664*x^29*(-21263296389757 + 188799093000*Zeta[3]) - 
            2520*x^17*(60842266615091 + 258824210400*Zeta[3]) + 
            2834352*x^32*(299869201903 + 1133499996720*Zeta[3]) + 
            756*x^14*(-2154298702903 + 2254289289280*Zeta[3]) + 
            x^10*(41490803952148 + 4062241935360*Zeta[3]) + 
            1653372*x^31*(1859197422493 + 4278840733440*Zeta[3]) + 
            236196*x^30*(47378568019187 + 27678458082240*Zeta[3]) - 
            4*x^12*(72193189306759 + 27873557832960*Zeta[3]) + 
            4200*x^19*(23116119823561 + 33511762626048*Zeta[3]) - 
            84*x^15*(-333803190107893 + 35630046869760*Zeta[3]) - 
            15120*x^21*(-191918515746019 + 58791633339600*Zeta[3]) - 
            102060*x^27*(-437622844538699 + 110285219737728*Zeta[3]) - 
            61236*x^28*(-657865668775481 + 143396592675840*Zeta[3]) + 
            5292*x^23*(-2016006970308491 + 340379137370880*Zeta[3]) + 
            4536*x^25*(-684732611498297 + 529223498445600*Zeta[3]) - 
            90*x^20*(-16915932575671537 + 908002251354240*Zeta[3]) - 
            756*x^22*(-365491482209321 + 1265595749305920*Zeta[3]) + 
            50*x^18*(-8677950043450547 + 1470096263131776*Zeta[3]) - 
            972*x^26*(-18566427502486427 + 4445489720689920*Zeta[3]) + 
            324*x^24*(-46971714766065269 + 13801425887027520*Zeta[3]))/
           (171460800*x^2*(1 - 9*x^2)^8*(-1 + x^2)^13))) + 
      CA*CF*((Pi^2*(9 - 42*x - 1166*x^2 - 9576*x^3 - 26077*x^4 - 52122*x^5 - 
           60612*x^6 - 52122*x^7 - 26077*x^8 - 9576*x^9 - 1166*x^10 - 
           42*x^11 + 9*x^12)*HPL[{-2}, x])/(5670*(-1 + x^2)^10) + 
        lm^2*((-11*(3 - 14*x - 102*x^2 - 1428*x^3 - 3399*x^4 - 7378*x^5 - 
             8124*x^6 - 7378*x^7 - 3399*x^8 - 1428*x^9 - 102*x^10 - 14*x^11 + 
             3*x^12))/(1260*(-1 + x^2)^10) - 
          (22*x^3*(1 + 3*x + 10*x^2 + 15*x^3 + 20*x^4 + 15*x^5 + 10*x^6 + 
             3*x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11)) + 
        (Pi^2*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 26077*x^4 + 52122*x^5 + 
           60612*x^6 + 52122*x^7 + 26077*x^8 + 9576*x^9 + 1166*x^10 + 
           42*x^11 - 9*x^12)*HPL[{2}, x])/(5670*(-1 + x^2)^10) + 
        (x*(39095 + 326620*x + 2127335*x^2 + 4089330*x^3 + 32250960*x^4 + 
           52944150*x^5 + 103939290*x^6 + 95963350*x^7 + 139699770*x^8 + 
           84512246*x^9 - 24627456*x^10 - 61851594*x^11 + 84604807*x^12 + 
           96539820*x^13 - 87236441*x^14 - 105146822*x^15 + 64157940*x^16 + 
           85614760*x^17 - 30816940*x^18 - 51370088*x^19 + 7513352*x^20 + 
           22087296*x^21 + 836136*x^22 - 6447028*x^23 - 1275428*x^24 + 
           1145480*x^25 + 387100*x^26 - 93600*x^27 - 43200*x^28)*
          HPL[{-2, 0}, x])/(198450*(-1 + x^2)^12) + 
        ((18144000 + 39312000*x - 135366000*x^2 - 422133600*x^3 + 
           325070760*x^4 + 2058171360*x^5 + 192075520*x^6 - 6015156280*x^7 - 
           2997577660*x^8 + 11712119440*x^9 + 8355101720*x^10 + 
           2*(-7974470951 + 132300*Pi^2)*x^11 - 3*(4469503963 + 411600*Pi^2)*
            x^12 - 40*(-374091149 + 863625*Pi^2)*x^13 + 
           (8464875724 - 280299600*Pi^2)*x^14 - 
           8*(2489316686 + 91547925*Pi^2)*x^15 - 
           5*(8017295239 + 250170480*Pi^2)*x^16 - 
           30*(1077280223 + 33844300*Pi^2)*x^17 - 43908326360*x^18 + 
           30*(-1077280223 + 33844300*Pi^2)*x^19 + 
           5*(-8017295239 + 250170480*Pi^2)*x^20 + 
           8*(-2489316686 + 91547925*Pi^2)*x^21 + 
           4*(2116218931 + 70074900*Pi^2)*x^22 + 40*(374091149 + 863625*Pi^2)*
            x^23 + 3*(-4469503963 + 411600*Pi^2)*x^24 - 
           2*(7974470951 + 132300*Pi^2)*x^25 + 8355101720*x^26 + 
           11712119440*x^27 - 2997577660*x^28 - 6015156280*x^29 + 
           192075520*x^30 + 2058171360*x^31 + 325070760*x^32 - 
           422133600*x^33 - 135366000*x^34 + 39312000*x^35 + 18144000*x^36)*
          HPL[{-1, 0}, x])/(166698000*x^11*(-1 + x^2)^11) - 
        (x*(-4240937124887400 - 33640999260505560*x + 68152078657983600*x^2 + 
           1439033628552462180*x^3 + 1847188532808158085*x^4 - 
           13450669887999917790*x^5 + 30816995883391002285*x^6 - 
           251855983806854962500*x^7 - 4022084426927273862750*x^8 + 
           5295080710661780592036*x^9 + 94602175618185783319842*x^10 + 
           421133178232873576260*x^11 - 1020554099115296352638787*x^12 - 
           756076468175457092265222*x^13 + 4871180323137804360375933*x^14 + 
           6870451646867957814716460*x^15 + 1854336114849775281990192*x^16 - 
           10080420386398254622893264*x^17 - 115389986949562782618886560*
            x^18 - 163926378333082055317555752*x^19 + 
           318876242465636653379315706*x^20 + 865383828527303309564375140*
            x^21 + 511080741641162523622016554*x^22 - 
           810040883046010460150267976*x^23 - 2321977980240845126558308916*
            x^24 - 2224836750455186784849744840*x^25 - 
           1060384349982960467637066804*x^26 + 722133789145183794503189928*
            x^27 + 1548262274549933490151055330*x^28 + 
           613626005607037570535915748*x^29 - 684707986276786005345406654*
            x^30 - 642126752452202930797693000*x^31 + 
           256309382071036834477262784*x^32 + 394879107012750290405704504*
            x^33 - 106507585403831277298376296*x^34 - 
           209777130839272933348567820*x^35 + 34691399789547167156295281*
            x^36 + 94520463209430614398869498*x^37 - 
           4778031923172387137988135*x^38 - 34196214144773655798388404*x^39 - 
           1883815844161579630986558*x^40 + 9668023619759055900732420*x^41 + 
           1397928410484852561693858*x^42 - 2105042019253825241891052*x^43 - 
           459241451890231925447487*x^44 + 348529934077718601921570*x^45 + 
           96827968396511178187617*x^46 - 43228390756347695337444*x^47 - 
           14090152397816201981400*x^48 + 3933039089361603004560*x^49 + 
           1434861938096249047560*x^50 - 253994438059127987760*x^51 - 
           100684045609131393360*x^52 + 11003063477599509120*x^53 + 
           4646264196924367920*x^54 - 286420277454091200*x^55 - 
           127074436952652000*x^56 + 3384505391904000*x^57 + 
           1562079411648000*x^58)*HPL[{0, 0}, x])/(166698000*(-1 + x^2)^12*
          (9 - 82*x^2 + 9*x^4)^8) - ((18144000 + 39312000*x - 135366000*x^2 - 
           422133600*x^3 + 325070760*x^4 + 2058171360*x^5 + 192075520*x^6 - 
           6015156280*x^7 - 2997577660*x^8 + 11712119440*x^9 + 
           8355101720*x^10 + 2*(-7974470951 + 132300*Pi^2)*x^11 - 
           3*(4469503963 + 411600*Pi^2)*x^12 - 40*(-374091149 + 863625*Pi^2)*
            x^13 + (8464875724 - 280299600*Pi^2)*x^14 - 
           8*(2489316686 + 91547925*Pi^2)*x^15 - 
           5*(8017295239 + 250170480*Pi^2)*x^16 - 
           30*(1077280223 + 33844300*Pi^2)*x^17 - 43908326360*x^18 + 
           30*(-1077280223 + 33844300*Pi^2)*x^19 + 
           5*(-8017295239 + 250170480*Pi^2)*x^20 + 
           8*(-2489316686 + 91547925*Pi^2)*x^21 + 
           4*(2116218931 + 70074900*Pi^2)*x^22 + 40*(374091149 + 863625*Pi^2)*
            x^23 + 3*(-4469503963 + 411600*Pi^2)*x^24 - 
           2*(7974470951 + 132300*Pi^2)*x^25 + 8355101720*x^26 + 
           11712119440*x^27 - 2997577660*x^28 - 6015156280*x^29 + 
           192075520*x^30 + 2058171360*x^31 + 325070760*x^32 - 
           422133600*x^33 - 135366000*x^34 + 39312000*x^35 + 18144000*x^36)*
          HPL[{1, 0}, x])/(166698000*x^11*(-1 + x^2)^11) + 
        lm*((-480699 + 1622235*x + 12807134*x^2 + 209026485*x^3 + 
            488130115*x^4 + 1071754080*x^5 + 1170326100*x^6 + 
            1071754080*x^7 + 488130115*x^8 + 209026485*x^9 + 12807134*x^10 + 
            1622235*x^11 - 480699*x^12 - 660*Pi^2*(-9 + 42*x + 106*x^2 + 
              630*x^3 + 935*x^4 + 840*x^5 - 840*x^7 - 935*x^8 - 630*x^9 - 
              106*x^10 - 42*x^11 + 9*x^12))/(4082400*(-1 + x^2)^10) + 
          (x^2*(198 - 492864*x - 1425484*x^2 - 5342361*x^3 - 8329302*x^4 - 
             12454182*x^5 - 10200402*x^6 - 7698561*x^7 - 2731096*x^8 - 
             1052808*x^9 - 41382*x^10 - 5544*x^11 + 1188*x^12)*HPL[{0}, x])/
           (11340*(-1 + x^2)^11) + (11*(9 - 42*x - 97*x^2 - 672*x^3 - 
             1032*x^4 - 1512*x^5 - 1032*x^6 - 672*x^7 - 97*x^8 - 42*x^9 + 
             9*x^10)*HPL[{-1, 0}, x])/(5670*(-1 + x^2)^9) + 
          (11*x^3*(3780 + 11340*x + 73710*x^2 + 147840*x^3 + 353850*x^4 + 
             425215*x^5 + 503160*x^6 + 327516*x^7 + 209412*x^8 + 57414*x^9 + 
             19446*x^10 + 124*x^11 + 42*x^12 - 9*x^13)*HPL[{0, 0}, x])/
           (2835*(-1 + x^2)^12) - (11*(9 - 42*x - 97*x^2 - 672*x^3 - 
             1032*x^4 - 1512*x^5 - 1032*x^6 - 672*x^7 - 97*x^8 - 42*x^9 + 
             9*x^10)*HPL[{1, 0}, x])/(5670*(-1 + x^2)^9)) + 
        (x*(-39095 - 326620*x - 2127335*x^2 - 4089330*x^3 - 32250960*x^4 - 
           52944150*x^5 - 103939290*x^6 - 95963350*x^7 - 139699770*x^8 - 
           84512246*x^9 + 24627456*x^10 + 61851594*x^11 - 84604807*x^12 - 
           96539820*x^13 + 87236441*x^14 + 105146822*x^15 - 64157940*x^16 - 
           85614760*x^17 + 30816940*x^18 + 51370088*x^19 - 7513352*x^20 - 
           22087296*x^21 - 836136*x^22 + 6447028*x^23 + 1275428*x^24 - 
           1145480*x^25 - 387100*x^26 + 93600*x^27 + 43200*x^28)*
          HPL[{2, 0}, x])/(198450*(-1 + x^2)^12) + 
        (2*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 26077*x^4 + 52122*x^5 + 
           60612*x^6 + 52122*x^7 + 26077*x^8 + 9576*x^9 + 1166*x^10 + 
           42*x^11 - 9*x^12)*HPL[{-2, -1, 0}, x])/(945*(-1 + x^2)^10) + 
        (8*x^2*(-530 - 4473*x - 12571*x^2 - 25641*x^3 - 30306*x^4 - 
           26481*x^5 - 13506*x^6 - 5103*x^7 - 636*x^8 - 42*x^9 + 9*x^10)*
          HPL[{-2, 0, 0}, x])/(945*(-1 + x^2)^10) + 
        (2*(9 - 42*x - 1166*x^2 - 9576*x^3 - 26077*x^4 - 52122*x^5 - 
           60612*x^6 - 52122*x^7 - 26077*x^8 - 9576*x^9 - 1166*x^10 - 
           42*x^11 + 9*x^12)*HPL[{-2, 1, 0}, x])/(945*(-1 + x^2)^10) + 
        (2*(9 - 42*x - 1166*x^2 - 9576*x^3 - 26077*x^4 - 52122*x^5 - 
           60612*x^6 - 52122*x^7 - 26077*x^8 - 9576*x^9 - 1166*x^10 - 
           42*x^11 + 9*x^12)*HPL[{-1, -2, 0}, x])/(945*(-1 + x^2)^10) + 
        ((10800 + 23400*x - 64375*x^2 - 216170*x^3 + 93332*x^4 + 893047*x^5 + 
           274887*x^6 - 2170773*x^7 - 1398048*x^8 + 3434892*x^9 + 
           2778762*x^10 - 3693648*x^11 - 3234168*x^12 + 2728580*x^13 + 
           2390131*x^14 - 1327854*x^15 - 862604*x^16 + 759726*x^17 + 
           1154466*x^18 + 759726*x^19 - 862604*x^20 - 1327854*x^21 + 
           2390131*x^22 + 2728580*x^23 - 3234168*x^24 - 3693648*x^25 + 
           2778762*x^26 + 3434892*x^27 - 1398048*x^28 - 2170773*x^29 + 
           274887*x^30 + 893047*x^31 + 93332*x^32 - 216170*x^33 - 
           64375*x^34 + 23400*x^35 + 10800*x^36)*HPL[{-1, -1, 0}, x])/
         (99225*x^13*(-1 + x^2)^9) - ((39723 + 391244*x + 1975325*x^2 + 
           14082176*x^3 + 20996527*x^4 + 40327692*x^5 + 24717185*x^6 + 
           45554296*x^7 + 18078245*x^8 + 19300392*x^9 + 39480251*x^10 + 
           55311504*x^11 - 33575911*x^12 - 52633504*x^13 + 45331775*x^14 + 
           49683840*x^15 - 39505980*x^16 - 34829820*x^17 + 23550860*x^18 + 
           18545040*x^19 - 9270852*x^20 - 7516688*x^21 + 2216932*x^22 + 
           2246688*x^23 - 263280*x^24 - 444700*x^25 + 7200*x^26 + 43200*x^27)*
          HPL[{-1, 0, 0}, x])/(198450*(-1 + x)^12*(1 + x)^10) - 
        ((10800 + 23400*x - 64375*x^2 - 216170*x^3 + 93332*x^4 + 893047*x^5 + 
           274887*x^6 - 2170773*x^7 - 1398048*x^8 + 3434892*x^9 + 
           2778762*x^10 - 3693648*x^11 - 3234168*x^12 + 2728580*x^13 + 
           2390131*x^14 - 1327854*x^15 - 862604*x^16 + 759726*x^17 + 
           1154466*x^18 + 759726*x^19 - 862604*x^20 - 1327854*x^21 + 
           2390131*x^22 + 2728580*x^23 - 3234168*x^24 - 3693648*x^25 + 
           2778762*x^26 + 3434892*x^27 - 1398048*x^28 - 2170773*x^29 + 
           274887*x^30 + 893047*x^31 + 93332*x^32 - 216170*x^33 - 
           64375*x^34 + 23400*x^35 + 10800*x^36)*HPL[{-1, 1, 0}, x])/
         (99225*x^13*(-1 + x^2)^9) + (2*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 
           26077*x^4 + 52122*x^5 + 60612*x^6 + 52122*x^7 + 26077*x^8 + 
           9576*x^9 + 1166*x^10 + 42*x^11 - 9*x^12)*HPL[{-1, 2, 0}, x])/
         (945*(-1 + x^2)^10) + (x*(-1682911557495 - 13897203407640*x - 
           200907198326205*x^2 - 212696080395102*x^3 + 11795079698921358*
            x^4 + 43229803650842754*x^5 - 154127929731455115*x^6 - 
           1312810092330682986*x^7 - 2050905302899019199*x^8 + 
           17492354119002202542*x^9 + 80361374995033567371*x^10 - 
           98676406817179302816*x^11 - 913977932397443351064*x^12 + 
           4334250671988551028*x^13 + 4009433589192073906473*x^14 + 
           431086004040250990716*x^15 + 4963818043500625676170*x^16 + 
           34466727049337403844632*x^17 - 91439184494303683996402*x^18 - 
           345720858331328257138868*x^19 + 2816906895018531909284*x^20 + 
           1124705946757199978302476*x^21 + 1858701377887777911298682*x^22 - 
           87674402947120093489780*x^23 - 4598423346851065557800430*x^24 - 
           5043932903621867132452300*x^25 - 166250832516375537757754*x^26 + 
           3144808406209901985517912*x^27 + 404842664840083393365768*x^28 - 
           1515569410700368913522576*x^29 + 935624938344844284898426*x^30 + 
           1514965655534455673986384*x^31 - 1126461924497580576183915*x^32 - 
           1455932342616498111158048*x^33 + 720381957259915465365527*x^34 + 
           1051053571079927678230354*x^35 - 321662749900705659702322*x^36 - 
           590914318824060545777886*x^37 + 94439587491881901988641*x^38 + 
           263144007621252099625670*x^39 - 9955717681519490487611*x^40 - 
           92546112230058678862114*x^41 - 6037676269281983703737*x^42 + 
           25463778704420507376696*x^43 + 3856726518208400340576*x^44 - 
           5418943085484021470868*x^45 - 1206060274586036582307*x^46 + 
           880544694191961714660*x^47 + 247042389577272864120*x^48 - 
           107557631646220005264*x^49 - 35236626904779910344*x^50 + 
           9664598169760930704*x^51 + 3535290537534295344*x^52 - 
           617791053482217216*x^53 - 245230126804340496*x^54 + 
           26538075176691816*x^55 + 11213502957419976*x^56 - 
           685982214642960*x^57 - 304417801567800*x^58 + 8058346171200*x^59 + 
           3719236694400*x^60)*HPL[{0, 0, 0}, x])/(198450*(-1 + x^2)^12*
          (9 - 82*x^2 + 9*x^4)^8) + (2*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 
           26077*x^4 + 52122*x^5 + 60612*x^6 + 52122*x^7 + 26077*x^8 + 
           9576*x^9 + 1166*x^10 + 42*x^11 - 9*x^12)*HPL[{1, -2, 0}, x])/
         (945*(-1 + x^2)^10) - ((10800 + 23400*x - 64375*x^2 - 216170*x^3 + 
           93332*x^4 + 893047*x^5 + 274887*x^6 - 2170773*x^7 - 1398048*x^8 + 
           3434892*x^9 + 2778762*x^10 - 3693648*x^11 - 3234168*x^12 + 
           2728580*x^13 + 2390131*x^14 - 1327854*x^15 - 862604*x^16 + 
           759726*x^17 + 1154466*x^18 + 759726*x^19 - 862604*x^20 - 
           1327854*x^21 + 2390131*x^22 + 2728580*x^23 - 3234168*x^24 - 
           3693648*x^25 + 2778762*x^26 + 3434892*x^27 - 1398048*x^28 - 
           2170773*x^29 + 274887*x^30 + 893047*x^31 + 93332*x^32 - 
           216170*x^33 - 64375*x^34 + 23400*x^35 + 10800*x^36)*
          HPL[{1, -1, 0}, x])/(99225*x^13*(-1 + x^2)^9) + 
        ((39723 + 535016*x + 3898405*x^2 + 23201144*x^3 + 69626167*x^4 + 
           159051728*x^5 + 239008977*x^6 + 291332968*x^7 + 259468757*x^8 + 
           165666108*x^9 + 32185331*x^10 - 1125432*x^11 + 58077233*x^12 + 
           50321356*x^13 - 50875105*x^14 - 64372800*x^15 + 27322980*x^16 + 
           54860820*x^17 - 3216100*x^18 - 30476080*x^19 - 6365972*x^20 + 
           10230784*x^21 + 4740244*x^22 - 1586432*x^23 - 1466080*x^24 - 
           70300*x^25 + 180000*x^26 + 43200*x^27)*HPL[{1, 0, 0}, x])/
         (198450*(-1 + x)^10*(1 + x)^12) + 
        ((10800 + 23400*x - 64375*x^2 - 216170*x^3 + 93332*x^4 + 893047*x^5 + 
           274887*x^6 - 2170773*x^7 - 1398048*x^8 + 3434892*x^9 + 
           2778762*x^10 - 3693648*x^11 - 3234168*x^12 + 2728580*x^13 + 
           2390131*x^14 - 1327854*x^15 - 862604*x^16 + 759726*x^17 + 
           1154466*x^18 + 759726*x^19 - 862604*x^20 - 1327854*x^21 + 
           2390131*x^22 + 2728580*x^23 - 3234168*x^24 - 3693648*x^25 + 
           2778762*x^26 + 3434892*x^27 - 1398048*x^28 - 2170773*x^29 + 
           274887*x^30 + 893047*x^31 + 93332*x^32 - 216170*x^33 - 
           64375*x^34 + 23400*x^35 + 10800*x^36)*HPL[{1, 1, 0}, x])/
         (99225*x^13*(-1 + x^2)^9) + (2*(9 - 42*x - 1166*x^2 - 9576*x^3 - 
           26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 26077*x^8 - 
           9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*HPL[{1, 2, 0}, x])/
         (945*(-1 + x^2)^10) + (2*(9 - 42*x - 1166*x^2 - 9576*x^3 - 
           26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 26077*x^8 - 
           9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*HPL[{2, -1, 0}, x])/
         (945*(-1 + x^2)^10) + (8*x^2*(530 + 4473*x + 12571*x^2 + 25641*x^3 + 
           30306*x^4 + 26481*x^5 + 13506*x^6 + 5103*x^7 + 636*x^8 + 42*x^9 - 
           9*x^10)*HPL[{2, 0, 0}, x])/(945*(-1 + x^2)^10) + 
        (2*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 26077*x^4 + 52122*x^5 + 
           60612*x^6 + 52122*x^7 + 26077*x^8 + 9576*x^9 + 1166*x^10 + 
           42*x^11 - 9*x^12)*HPL[{2, 1, 0}, x])/(945*(-1 + x^2)^10) + 
        (4*(-9 + 42*x + 97*x^2 + 672*x^3 + 1032*x^4 + 1512*x^5 + 1032*x^6 + 
           672*x^7 + 97*x^8 + 42*x^9 - 9*x^10)*HPL[{-1, 0, 0, 0}, x])/
         (945*(-1 + x^2)^9) + (4*(9 - 42*x - 1166*x^2 - 9576*x^3 - 
           26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 26077*x^8 - 
           9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*HPL[{-1, 1, 0, 0}, x])/
         (945*(-1 + x^2)^10) + (4*(9 - 42*x - 1166*x^2 - 9576*x^3 - 
           26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 26077*x^8 - 
           9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*HPL[{1, -1, 0, 0}, x])/
         (945*(-1 + x^2)^10) + (4*(9 - 42*x - 97*x^2 - 672*x^3 - 1032*x^4 - 
           1512*x^5 - 1032*x^6 - 672*x^7 - 97*x^8 - 42*x^9 + 9*x^10)*
          HPL[{1, 0, 0, 0}, x])/(945*(-1 + x^2)^9) + 
        ((-9 + 104*x + 875*x^2 + 12709*x^3 + 33740*x^4 + 89488*x^5 + 
           115400*x^6 + 132280*x^7 + 80865*x^8 + 46942*x^9 + 8829*x^10 + 
           3175*x^11 - 300*x^12 + 62*x^13)*master3l10a[x])/
         (3780*(-1 + x^2)^11) + (x*(-62 + 300*x - 3175*x^2 - 8829*x^3 - 
           46942*x^4 - 80865*x^5 - 132280*x^6 - 115400*x^7 - 89488*x^8 - 
           33740*x^9 - 12709*x^10 - 875*x^11 - 104*x^12 + 9*x^13)*
          master3l10b[x])/(3780*(-1 + x^2)^11) - 
        ((2479730278050 - 107524867458528*x + 272739750997968*x^2 + 
           1519550082742725*x^3 + 3255603196706424*x^4 + 4015435464536598*
            x^5 + 1173310093442790*x^6 - 988180886879388*x^7 - 
           1594643283954900*x^8 - 369202880391318*x^9 + 568578633023466*
            x^10 + 99950433863625*x^11 - 170075101414770*x^12 + 
           10526799805596*x^13 + 55398491076924*x^14 - 2635986284112*x^15 - 
           13722197311446*x^16 - 1079226908556*x^17 + 2169689517476*x^18 + 
           399787073607*x^19 - 211457735644*x^20 - 56160929682*x^21 + 
           12122806782*x^22 + 4139873196*x^23 - 350173720*x^24 - 
           159525150*x^25 + 2003074*x^26 + 2540907*x^27 + 84726*x^28)*
          master3l8a[x])/(4762800*(-9 + x^2)^8*(-1 + x^2)^12) - 
        ((156380 + 1214194*x - 10638647*x^2 - 96499398*x^3 + 311015182*x^4 + 
           3370020040*x^5 - 5394532284*x^6 - 68844209374*x^7 + 
           66713110046*x^8 + 924826205116*x^9 - 649191555475*x^10 - 
           8711417399528*x^11 + 4494848374108*x^12 + 59272377822830*x^13 - 
           12206920527600*x^14 - 284827641450396*x^15 - 104847499396392*
            x^16 + 842880359812698*x^17 + 1146422927274579*x^18 - 
           740616719699574*x^19 - 3927496519311930*x^20 - 3498609688771212*
            x^21 + 2464873800625260*x^22 + 7679846810516058*x^23 + 
           8543737901732238*x^24 + 4607477135054424*x^25 + 
           1964675498417847*x^26 + 269931963725892*x^27 + 
           50888378126448*x^28 - 1503430645770*x^29)*master3l8b[x])/
         (4762800*x*(1 - 9*x^2)^8*(-1 + x^2)^12) + 
        ((221286717990 - 8800735865832*x + 180575594892*x^2 - 
           25707049300377*x^3 - 75084043731012*x^4 - 254428696433133*x^5 - 
           369816933585294*x^6 - 220106226687273*x^7 + 64685140980318*x^8 + 
           173226732530337*x^9 + 79920313037982*x^10 - 38889946019460*x^11 - 
           47395268619528*x^12 + 2088578175726*x^13 + 13635310849348*x^14 + 
           763782810830*x^15 - 2540219635310*x^16 - 224806092278*x^17 + 
           322259313688*x^18 + 33298135807*x^19 - 27320295188*x^20 - 
           3126542673*x^21 + 1462579210*x^22 + 182295563*x^23 - 
           44168630*x^24 - 5886067*x^25 + 564734*x^26 + 78190*x^27)*
          master3l9a[x])/(1587600*(-9 + x^2)^7*(-1 + x^2)^12) + 
        ((78190 + 564734*x - 5886067*x^2 - 44168630*x^3 + 182295563*x^4 + 
           1462579210*x^5 - 3126542673*x^6 - 27320295188*x^7 + 
           33298135807*x^8 + 322259313688*x^9 - 224806092278*x^10 - 
           2540219635310*x^11 + 763782810830*x^12 + 13635310849348*x^13 + 
           2088578175726*x^14 - 47395268619528*x^15 - 38889946019460*x^16 + 
           79920313037982*x^17 + 173226732530337*x^18 + 64685140980318*x^19 - 
           220106226687273*x^20 - 369816933585294*x^21 - 254428696433133*
            x^22 - 75084043731012*x^23 - 25707049300377*x^24 + 
           180575594892*x^25 - 8800735865832*x^26 + 221286717990*x^27)*
          master3l9b[x])/(4762800*x*(-1 + x^2)^12*(-1 + 9*x^2)^7) + 
        (HPL[{1}, x]*(Pi^2*(-10800 - 23400*x + 75175*x^2 + 239570*x^3 - 
             157707*x^4 - 1109217*x^5 - 181555*x^6 + 3063820*x^7 + 
             1672935*x^8 - 5605665*x^9 - 4176810*x^10 + 7128540*x^11 + 
             6012930*x^12 - 6422228*x^13 - 5624299*x^14 + 4056434*x^15 + 
             3252735*x^16 - 2087580*x^17 - 2017070*x^18 + 2017070*x^20 + 
             2087580*x^21 - 3252735*x^22 - 4056434*x^23 + 5624299*x^24 + 
             6422228*x^25 - 6012930*x^26 - 7128540*x^27 + 4176810*x^28 + 
             5605665*x^29 - 1672935*x^30 - 3063820*x^31 + 181555*x^32 + 
             1109217*x^33 + 157707*x^34 - 239570*x^35 - 75175*x^36 + 
             23400*x^37 + 10800*x^38) - 2520*x^13*(9 - 42*x - 1166*x^2 - 
             9576*x^3 - 26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 
             26077*x^8 - 9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*Zeta[3]))/
         (1190700*x^13*(-1 + x^2)^10) + 
        (HPL[{-1}, x]*(Pi^2*(10800 + 23400*x - 75175*x^2 - 239570*x^3 + 
             157707*x^4 + 1109217*x^5 + 181555*x^6 - 3063820*x^7 - 
             1672935*x^8 + 5605665*x^9 + 4176810*x^10 - 7128540*x^11 - 
             6012930*x^12 + 6422228*x^13 + 5624299*x^14 - 4056434*x^15 - 
             3252735*x^16 + 2087580*x^17 + 2017070*x^18 - 2017070*x^20 - 
             2087580*x^21 + 3252735*x^22 + 4056434*x^23 - 5624299*x^24 - 
             6422228*x^25 + 6012930*x^26 + 7128540*x^27 - 4176810*x^28 - 
             5605665*x^29 + 1672935*x^30 + 3063820*x^31 - 181555*x^32 - 
             1109217*x^33 - 157707*x^34 + 239570*x^35 + 75175*x^36 - 
             23400*x^37 - 10800*x^38) + 2520*x^13*(9 - 42*x - 1166*x^2 - 
             9576*x^3 - 26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 
             26077*x^8 - 9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*Zeta[3]))/
         (1190700*x^13*(-1 + x^2)^10) + (HPL[{0}, x]*(-4686238234944000 - 
           10153516175712000*x + 378880191740484000*x^2 + 854184074274417600*
            x^3 - 13749743014755773760*x^4 - 32582944522009294560*x^5 + 
           295208643409401544200*x^6 + 745762600859394862800*x^7 - 
           4158111641491906920360*x^8 - 11428915889968861115160*x^9 - 
           115736040*(-347474810090122 + 12214395*Pi^2)*x^10 - 
           38263752*(-3241472441625937 + 308655900*Pi^2)*x^11 + 
           1960*(-1211738113803029625482495 + 14433044114554743432696*Pi^2)*
            x^33 - 4374*(28358775921974525361 + 520337134551299597840*Pi^2)*
            x^55 - 8505*(4728557488915486791 + 59558511238393924280*Pi^2)*
            x^56 + 918540*(12442542181809957 + 402626738019177412*Pi^2)*
            x^57 + 612360*(6790305770285301 + 169439224675770140*Pi^2)*x^58 - 
           2678462640*(278429345895 + 16865721633292*Pi^2)*x^59 - 
           5511240*(53564831763705 + 2685309168174052*Pi^2)*x^60 + 
           12499492320*(2606741433 + 324743687774*Pi^2)*x^61 + 
           2777664960*(4950108531 + 534557640013*Pi^2)*x^62 - 
           10713850560*(79727085 + 24218392912*Pi^2)*x^63 - 
           1785641760*(212181525 + 57680468482*Pi^2)*x^64 + 
           433910947680*(23400 + 25687279*Pi^2)*x^65 + 16070775840*
            (291600 + 293058113*Pi^2)*x^66 - 288112530150043200*Pi^2*x^67 - 
           127855476658476000*Pi^2*x^68 + 3384505391904000*Pi^2*x^69 + 
           1562079411648000*Pi^2*x^70 - 6*x^52*(422656208858721607649600*
              Pi^2 + 243*(853196022613496855807 - 15093136976400000*
                Zeta[3])) + 588*x^49*(187957352571838179813340*Pi^2 + 
             2187*(20322341482942312993 - 1639854030528000*Zeta[3])) + 
           8*x^29*(-327880091902554599643562367 + 4941237788495503198622100*
              Pi^2 - 14698346468908950619128000*Zeta[3]) - 
           28*x^31*(-221265885593123189155979939 + 1168675772350453149134520*
              Pi^2 - 7712233998878843542080000*Zeta[3]) + 
           14*x^40*(-65882445355506047645041733 + 42678816228988460664836520*
              Pi^2 - 1655571148880065425792000*Zeta[3]) - 
           50*x^38*(-91952104674827736021082093 + 11774229026359704526583304*
              Pi^2 - 1232259948318484285804800*Zeta[3]) - 
           112*x^26*(2278629066382316954165924 + 49745803993578972210705*
              Pi^2 - 206946393610008178224000*Zeta[3]) + 
           36*x^36*(-69024443493835606152337813 + 13980157839585360011455440*
              Pi^2 - 153485133864211567152000*Zeta[3]) + 
           45*x^24*(6393533493673672177397809 + 30968958602548795288488*
              Pi^2 - 78154137465273247795200*Zeta[3]) - 
           24*x^43*(10961809872889925981569271 + 26712566735323554600574220*
              Pi^2 - 75481000808260912704000*Zeta[3]) - 
           3*x^22*(37314370585648516876063489 + 56042253414865206011880*
              Pi^2 - 32898328863454351584000*Zeta[3]) - 
           360*x^42*(655418318972039249828213 + 1337676578994781594178883*
              Pi^2 - 9769267183159155974400*Zeta[3]) + 
           24*x^44*(6232823594820630507680558 + 12351789729156928517252555*
              Pi^2 - 4112291107931793948000*Zeta[3]) + 
           84*x^45*(2470399530806774725232757 + 5300670283104910316395100*
              Pi^2 - 4000139520759831960000*Zeta[3]) - 
           126*x^47*(696498963541169839693273 + 1971503237098847717654760*
              Pi^2 - 275055333338939328000*Zeta[3]) + 
           90*x^18*(40510443688862907070981 + 1606823294056966440*Pi^2 - 
             86541107542083936000*Zeta[3]) - 81*x^16*
            (44116578234835761107891 + 463855004135082000*Pi^2 - 
             7170893746623936000*Zeta[3]) + 729*x^14*
            (1707656881622750558989 + 1568640163204800*Pi^2 - 
             30186273952800000*Zeta[3]) + 2916*x^53*(337757010934515955353 + 
             3667600184198374493300*Pi^2 - 354360607272000*Zeta[3]) + 
           52488*x^12*(-5157333220283556079 + 497565846225*Pi^2 + 
             6562233468000*Zeta[3]) + 78732*x^13*(-12503618468028139889 + 
             9055720012500*Pi^2 + 13124466936000*Zeta[3]) - 
           65610*x^15*(-88860576721566395737 + 284748231652920*Pi^2 + 
             1084955933376000*Zeta[3]) + 61236*x^17*(-426221897052430206823 + 
             4857312198910500*Pi^2 + 34436934641088000*Zeta[3]) - 
           6*x^50*(-587179085454114314584491 + 695655802048886635758200*
              Pi^2 + 96807065579423136000*Zeta[3]) - 
           252*x^19*(-352862024926611390167219 + 14837050154686847220*Pi^2 + 
             137527666669469664000*Zeta[3]) + 45*x^48*
            (-59841818098048326367667 + 878164454902074830980560*Pi^2 + 
             173082215084167872000*Zeta[3]) + 252*x^21*
            (-910756226724728164309709 + 177951833441351248860*Pi^2 + 
             1333379840253277320000*Zeta[3]) + 18*x^20*
            (1058458835751957823677217 + 482363294441180730480*Pi^2 + 
             2575753198497008208000*Zeta[3]) - 
           3*x^46*(9364580477654836547683077 + 44555386331761549147967840*
              Pi^2 + 15454519190982049248000*Zeta[3]) + 
           36*x^25*(-16867946527176620360034049 + 97686374036616597741180*
              Pi^2 + 92815840127357504640000*Zeta[3]) - 
           6*x^23*(-72922370990093607995512859 + 78284036509092559761840*
              Pi^2 + 301924003233043650816000*Zeta[3]) + 
           18*x^30*(38510807201816412782310701 + 555553159842551550172080*
              Pi^2 + 306970267728423134304000*Zeta[3]) - 
           36*x^39*(12202040586395557821771991 + 19773851175953973917087360*
              Pi^2 + 496977184782127050624000*Zeta[3]) - 
           56*x^35*(237433188464398543493499907 + 5347770135745537538924340*
              Pi^2 + 3856116999439421771040000*Zeta[3]) - 
           36*x^34*(386914401051308140595512461 + 9837743932814674249991240*
              Pi^2 + 7052983723389082604832000*Zeta[3]) + 
           8*x^37*(817197063737294644940492717 + 69347172387353299851891780*
              Pi^2 + 14698346468908950619128000*Zeta[3]) + 
           x^27*(885921940359007341456877136 - 16290797016102598481056320*
              Pi^2 + 17891178652156573822464000*Zeta[3]) + 
           6*x^32*(1074051311293803699602946191 + 7544742763929630668760960*
              Pi^2 + 42317902340334495628992000*Zeta[3]) + 
           27*x^54*(59993335625725760850200*Pi^2 - 
             243*(-41262502770044967857 + 52497867744000*Zeta[3])) - 
           60*x^51*(647804543129322282961684*Pi^2 - 
             2187*(-44493980286619166239 + 542477966688000*Zeta[3])) + 
           96*x^41*(7780228675429914187378825*Pi^2 - 
             384*(1133791801120381598029 + 90640468874372563125*Zeta[3])) + 
           400*x^28*(17475799158861274043589*Pi^2 - 
             2*(773549918668352697072709 + 77016246769905267862800*
                Zeta[3]))))/(2000376000*x^9*(-1 + x^2)^12*
          (9 - 82*x^2 + 9*x^4)^8) + (70560*Pi^4*x^11*(-1 + x^2)^2*
           (9 - 82*x^2 + 9*x^4)^8*(-27 + 126*x - 4982*x^2 - 42840*x^3 - 
            122905*x^4 - 253890*x^5 - 303060*x^6 - 267330*x^7 - 137865*x^8 - 
            52920*x^9 - 6678*x^10 - 546*x^11 + 117*x^12) - 
          12*Pi^2*(9 - 82*x^2 + 9*x^4)^8*(-18144000 - 39312000*x + 
            153510000*x^2 + 461445600*x^3 - 460436760*x^4 - 2480304960*x^5 + 
            132995240*x^6 + 8073327640*x^7 + 3189653180*x^8 - 
            17727275720*x^9 - 11352679380*x^10 + 27661061342*x^11 + 
            21763613609*x^12 - 30912587862*x^13 - 21873387613*x^14 + 
            34878179448*x^15 + 48551351919*x^16 + 12403873202*x^17 + 
            3821850165*x^18 - 3821850165*x^20 - 12403873202*x^21 - 
            48551351919*x^22 - 34878179448*x^23 + 21873387613*x^24 + 
            30912587862*x^25 - 21763613609*x^26 - 27661061342*x^27 + 
            11352679380*x^28 + 17727275720*x^29 - 3189653180*x^30 - 
            8073327640*x^31 - 132995240*x^32 + 2480304960*x^33 + 
            460436760*x^34 - 461445600*x^35 - 153510000*x^36 + 
            39312000*x^37 + 18144000*x^38) + x^2*(14058714704832000 + 
            30460548527136000*x - 1141326813456396000*x^2 - 
            2572705738998964800*x^3 + 41626351896669701280*x^4 + 
            98599210071736409280*x^5 - 899234569470690004860*x^6 - 
            2269552543388210916360*x^7 + 12764433899496006304920*x^8 + 
            x^41*(5372631973308210530172340762 - 
              25539619557458079573655397760*Zeta[3]) + 
            x^40*(4903715957460426777691385954 - 
              20073687684486310732047523200*Zeta[3]) + 
            x^32*(10117077984500147893052254334 - 
              6276212976904449449060090880*Zeta[3]) + 
            x^29*(1875786515475674901631062544 - 3057258981140424743008112640*
               Zeta[3]) + 10372051085401555200*x^67*Zeta[3] + 
            4602797159705136000*x^68*Zeta[3] - 121842194108544000*x^69*
             Zeta[3] - 56234858819328000*x^70*Zeta[3] - 15620794116480*x^65*
             (-1950 + 25687279*Zeta[3]) - 1004423490*x^9*(-34866026029027 + 
              70137792*Zeta[3]) - 578547930240*x^66*(-24300 + 
              293058113*Zeta[3]) + 96424655040*x^63*(-26680995 + 
              96873571648*Zeta[3]) + 6200145*x^10*(-20112821636615333 + 
              165375971136*Zeta[3]) + 16070775840*x^64*(-71018775 + 
              230721873928*Zeta[3]) + 3188646*x^11*(-120182152659595819 + 
              3743256041280*Zeta[3]) - 32141551680*x^61*(-3067655571 + 
              4546411628836*Zeta[3]) + 84371573160*x^59*(-26899493021 + 
              19275110438048*Zeta[3]) - 1785641760*x^62*(-23311703853 + 
              29935227840728*Zeta[3]) - 1417176*x^13*(-2167630260525433679 + 
              358661668493520*Zeta[3]) - 19683*x^12*(-43258615574569828289 + 
              583094007599040*Zeta[3]) + 173604060*x^60*(-5179801494681 + 
              3068924763627488*Zeta[3]) + 170586*x^15*
             (-107905875028462545473 + 47737331717483520*Zeta[3]) + 
            26244*x^17*(3188014669160108159707 + 158365884079569600*Zeta[
                3]) - 2187*x^14*(1836635808922635439687 + 868896016205333760*
               Zeta[3]) - 2755620*x^58*(-4632157447879041 + 
              1355513797406161120*Zeta[3]) - 4133430*x^57*
             (-8472440711429721 + 3221013919014451712*Zeta[3]) + 
            11907*x^16*(1043777474425855878929 + 6769397416843330560*Zeta[
                3]) + 76545*x^56*(-1629053469505135503 + 
              238234057134197748416*Zeta[3]) + 39366*x^55*
             (-9734926405262658489 + 2081348810748146018240*Zeta[3]) - 
            52488*x^53*(-58538542621057619733 + 7335209003434220075440*Zeta[
                3]) - 5103*x^22*(-12037353101809601092479 + 
              13747142527940811465280*Zeta[3]) - 54*x^19*
             (5435151920763496877370193 + 39409560420304375728000*Zeta[3]) + 
            405*x^24*(-1017448614735900120851663 + 41862805411023123846592*
               Zeta[3]) - 27*x^18*(796255197756863439034501 + 
              54742914984738881174400*Zeta[3]) + 360*x^21*
             (2290283565196279170555221 + 97984484413218708079824*Zeta[3]) - 
            243*x^54*(-3501806909633466735159 + 239973375489117043538240*Zeta[
                3]) + 189*x^50*(64318658428420190268777 + 
              795457175831682748343680*Zeta[3]) + 
            9*x^20*(740477328569539001007097 + 1612676705196240524050560*Zeta[
                3]) - 2646*x^36*(-3673984480400447169179219 + 
              1649124752522793960989120*Zeta[3]) + 27*x^52*
             (-148175301275975374560297 + 3381178669897074905568640*Zeta[
                3]) - 18*x^23*(110604733992767547453860263 + 
              15929444466231623176409280*Zeta[3]) + 
            54*x^51*(-341352929783294329308957 + 25912308542165701635226240*
               Zeta[3]) + 378*x^30*(8605961069905166187089883 + 
              35628440595690236510056960*Zeta[3]) - 108*x^49*
             (-779959851740802391364001 + 36839429333340650710637440*Zeta[
                3]) - 360*x^45*(-2481466889569937270746901 + 
              44422620282267090201434544*Zeta[3]) - 
            27*x^48*(689157274267254009239251 + 52744294895738462348371200*
               Zeta[3]) - 189*x^44*(-927540791413999069682883 + 
              56861185976039001701972800*Zeta[3]) + 135*x^42*
             (-7153810976278770731761079 + 128854789917629954962768320*Zeta[
                3]) + 54*x^47*(-5579907085452817087144243 + 
              165563248742045223121140480*Zeta[3]) - 
            4*x^27*(1545472771187833603642862959 + 
              525369645516855632957331840*Zeta[3]) + 
            9*x^46*(-1570845686172618410067353 + 536298006397188319522022400*
               Zeta[3]) + 2*x^25*(2114072919659475620978035181 + 
              617172109796691631204606080*Zeta[3]) + 
            2*x^26*(1277331935017671104880796177 + 
              806416103152641652200472320*Zeta[3]) + 
            18*x^43*(-131646173850138367365268213 + 
              1265380588449398196145809600*Zeta[3]) - 
            16*x^37*(217377917664453793372720991 + 
              1359041063837840016283727280*Zeta[3]) - 
            8*x^33*(-1915295486451479627185831453 + 
              2349593244639359297096711760*Zeta[3]) - 
            2*x^28*(3680087537231530151184229703 + 
              3888617892348936105162921600*Zeta[3]) + 
            4*x^31*(455518065525412761832869151 + 
              4017735859796771475574592640*Zeta[3]) + 
            2*x^34*(9381173938356606926433728617 + 
              4160344720655069995736237760*Zeta[3]) + 
            4*x^39*(-1749359550125975316958364209 + 
              5749204751199572195084771520*Zeta[3]) + 
            4*x^35*(3639685567995935301048854101 + 
              6455212431300719899616784960*Zeta[3]) + 
            2*x^38*(-6948200052967688802473393453 + 
              6823039203800442568745956800*Zeta[3])))/(24004512000*x^11*
          (-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8)) + 
      CF^2*((Pi^2*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 26077*x^4 + 52122*x^5 + 
           60612*x^6 + 52122*x^7 + 26077*x^8 + 9576*x^9 + 1166*x^10 + 
           42*x^11 - 9*x^12)*HPL[{-2}, x])/(2835*(-1 + x^2)^10) + 
        lm^2*((2*(3 - 14*x - 102*x^2 - 1428*x^3 - 3399*x^4 - 7378*x^5 - 
             8124*x^6 - 7378*x^7 - 3399*x^8 - 1428*x^9 - 102*x^10 - 14*x^11 + 
             3*x^12))/(35*(-1 + x^2)^10) + (48*x^3*(1 + 3*x + 10*x^2 + 
             15*x^3 + 20*x^4 + 15*x^5 + 10*x^6 + 3*x^7 + x^8)*HPL[{0}, x])/
           (-1 + x^2)^11) + (Pi^2*(9 - 42*x - 1166*x^2 - 9576*x^3 - 
           26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 26077*x^8 - 
           9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*HPL[{2}, x])/
         (2835*(-1 + x^2)^10) - (x*(39095 + 326620*x + 4055765*x^2 + 
           8269380*x^3 + 51904440*x^4 + 81820620*x^5 + 121853760*x^6 + 
           92976240*x^7 + 264730550*x^8 + 224881944*x^9 - 299131287*x^10 - 
           392247345*x^11 + 696903382*x^12 + 769582684*x^13 - 
           982396957*x^14 - 1095683448*x^15 + 1000256202*x^16 + 
           1173557010*x^17 - 714379413*x^18 - 942174727*x^19 + 
           333083927*x^20 + 559212538*x^21 - 76891716*x^22 - 238370276*x^23 - 
           11233998*x^24 + 69088470*x^25 + 14260450*x^26 - 12203550*x^27 - 
           4210650*x^28 + 992250*x^29 + 463050*x^30)*HPL[{-2, 0}, x])/
         (99225*(-1 + x^2)^12) + ((194481000 + 416745000*x - 1476751500*x^2 - 
           4500373500*x^3 + 3693228000*x^4 + 22092953400*x^5 + 
           1428772590*x^6 - 65118294570*x^7 - 31631646760*x^8 + 
           128167575480*x^9 + 91719648650*x^10 - 177184366870*x^11 - 
           149385574870*x^12 - 8*(-22014192626 + 33075*Pi^2)*x^13 + 
           63*(2527743929 + 19600*Pi^2)*x^14 + 30*(-4205988011 + 
             1151500*Pi^2)*x^15 + 112*(-976456421 + 2502675*Pi^2)*x^16 + 
           (76456443502 + 732383400*Pi^2)*x^17 + 
           35*(2865242327 + 35738640*Pi^2)*x^18 + 
           20*(1637069149 + 50766450*Pi^2)*x^19 + 38287998140*x^20 - 
           20*(-1637069149 + 50766450*Pi^2)*x^21 - 
           35*(-2865242327 + 35738640*Pi^2)*x^22 + 
           (76456443502 - 732383400*Pi^2)*x^23 - 
           112*(976456421 + 2502675*Pi^2)*x^24 - 
           30*(4205988011 + 1151500*Pi^2)*x^25 - 
           63*(-2527743929 + 19600*Pi^2)*x^26 + 8*(22014192626 + 33075*Pi^2)*
            x^27 - 149385574870*x^28 - 177184366870*x^29 + 91719648650*x^30 + 
           128167575480*x^31 - 31631646760*x^32 - 65118294570*x^33 + 
           1428772590*x^34 + 22092953400*x^35 + 3693228000*x^36 - 
           4500373500*x^37 - 1476751500*x^38 + 416745000*x^39 + 
           194481000*x^40)*HPL[{-1, 0}, x])/(83349000*x^13*(-1 + x^2)^11) - 
        (x*(4240937124887400 + 34299422964364320*x + 277114912246504080*x^2 - 
           569906647583812560*x^3 - 20613853625097294765*x^4 - 
           40080536533186548210*x^5 + 341715654682309811295*x^6 + 
           1543909830341468478210*x^7 + 1736679222969298582590*x^8 - 
           19686475703329861083084*x^9 - 122189224198824606675726*x^10 + 
           38485237127079879627120*x^11 + 1567102570335594112001391*x^12 + 
           1546493912163466453310598*x^13 - 7643316926869970266889829*x^14 - 
           15663956116971226816440180*x^15 - 9941815437959423874249576*x^16 + 
           37527737069362389761122356*x^17 + 264362116439715058113316380*
            x^18 + 245536097858333473926625428*x^19 - 
           925434032716370259344324118*x^20 - 1641116645938706266547471240*
            x^21 + 326215718294513125332658698*x^22 + 
           2534467697725844686906997764*x^23 + 1949800638083036869808760908*
            x^24 + 922926116315963704383569760*x^25 + 
           3878701331023873114949310612*x^26 + 2137924135915326056426300528*
            x^27 - 6055230978088564059120435130*x^28 - 
           5321009841937051733807609492*x^29 + 5449129257653680773186488462*
            x^30 + 6109660578066639111744583600*x^31 - 
           4231953672613633574824173552*x^32 - 5381003346709020139945746296*
            x^33 + 2676595174458201795178654848*x^34 + 
           3855748605243164155649359320*x^35 - 1257121589590167638065793393*
            x^36 - 2224316045952389046615221922*x^37 + 
           390035861144408002313721435*x^38 + 1020726047356677000177233346*
            x^39 - 47413605613290654675909426*x^40 - 
           368867732224435147370969100*x^41 - 22856810275630835297439534*
            x^42 + 103884103389082831414863408*x^43 + 
           15771237778988954519445531*x^44 - 22543706768332281419558610*
            x^45 - 5077459142627181262541001*x^46 + 3722875578514168759586196*
            x^47 + 1059499452447941147052480*x^48 - 460813192726268815983900*
            x^49 - 153172621527804863476380*x^50 + 41858400769313190112260*
            x^51 + 15527611963600035141780*x^52 - 2699696589341440775940*
            x^53 - 1085932038284269277220*x^54 + 116827942519867357800*x^55 + 
           49984232103574839000*x^56 - 3038512938054237000*x^57 - 
           1364300089752033000*x^58 + 35879011486290000*x^59 + 
           16743538693602000*x^60)*HPL[{0, 0}, x])/(83349000*(-1 + x^2)^12*
          (9 - 82*x^2 + 9*x^4)^8) - ((194481000 + 416745000*x - 
           1476751500*x^2 - 4500373500*x^3 + 3693228000*x^4 + 
           22092953400*x^5 + 1428772590*x^6 - 65118294570*x^7 - 
           31631646760*x^8 + 128167575480*x^9 + 91719648650*x^10 - 
           177184366870*x^11 - 149385574870*x^12 - 
           8*(-22014192626 + 33075*Pi^2)*x^13 + 63*(2527743929 + 19600*Pi^2)*
            x^14 + 30*(-4205988011 + 1151500*Pi^2)*x^15 + 
           112*(-976456421 + 2502675*Pi^2)*x^16 + 
           (76456443502 + 732383400*Pi^2)*x^17 + 
           35*(2865242327 + 35738640*Pi^2)*x^18 + 
           20*(1637069149 + 50766450*Pi^2)*x^19 + 38287998140*x^20 - 
           20*(-1637069149 + 50766450*Pi^2)*x^21 - 
           35*(-2865242327 + 35738640*Pi^2)*x^22 + 
           (76456443502 - 732383400*Pi^2)*x^23 - 
           112*(976456421 + 2502675*Pi^2)*x^24 - 
           30*(4205988011 + 1151500*Pi^2)*x^25 - 
           63*(-2527743929 + 19600*Pi^2)*x^26 + 8*(22014192626 + 33075*Pi^2)*
            x^27 - 149385574870*x^28 - 177184366870*x^29 + 91719648650*x^30 + 
           128167575480*x^31 - 31631646760*x^32 - 65118294570*x^33 + 
           1428772590*x^34 + 22092953400*x^35 + 3693228000*x^36 - 
           4500373500*x^37 - 1476751500*x^38 + 416745000*x^39 + 
           194481000*x^40)*HPL[{1, 0}, x])/(83349000*x^13*(-1 + x^2)^11) + 
        lm*(-(-19584 + 34935*x + 344344*x^2 + 7523235*x^3 + 17052140*x^4 + 
             38123130*x^5 + 41087400*x^6 + 38123130*x^7 + 17052140*x^8 + 
             7523235*x^9 + 344344*x^10 + 34935*x^11 - 19584*x^12 - 
             60*Pi^2*(-9 + 42*x + 106*x^2 + 630*x^3 + 935*x^4 + 840*x^5 - 840*
                x^7 - 935*x^8 - 630*x^9 - 106*x^10 - 42*x^11 + 9*x^12))/
           (56700*(-1 + x^2)^10) + (2*x^2*(-18 + 26049*x + 73319*x^2 + 
             298101*x^3 + 475857*x^4 + 757062*x^5 + 645957*x^6 + 512301*x^7 + 
             192011*x^8 + 76953*x^9 + 3762*x^10 + 504*x^11 - 108*x^12)*
            HPL[{0}, x])/(315*(-1 + x^2)^11) + 
          (4*(-9 + 42*x + 97*x^2 + 672*x^3 + 1032*x^4 + 1512*x^5 + 1032*x^6 + 
             672*x^7 + 97*x^8 + 42*x^9 - 9*x^10)*HPL[{-1, 0}, x])/
           (315*(-1 + x^2)^9) + (8*x^3*(-3780 - 11340*x - 73710*x^2 - 
             147840*x^3 - 353850*x^4 - 425215*x^5 - 503160*x^6 - 327516*x^7 - 
             209412*x^8 - 57414*x^9 - 19446*x^10 - 124*x^11 - 42*x^12 + 
             9*x^13)*HPL[{0, 0}, x])/(315*(-1 + x^2)^12) + 
          (4*(9 - 42*x - 97*x^2 - 672*x^3 - 1032*x^4 - 1512*x^5 - 1032*x^6 - 
             672*x^7 - 97*x^8 - 42*x^9 + 9*x^10)*HPL[{1, 0}, x])/
           (315*(-1 + x^2)^9)) + (x*(39095 + 326620*x + 4055765*x^2 + 
           8269380*x^3 + 51904440*x^4 + 81820620*x^5 + 121853760*x^6 + 
           92976240*x^7 + 264730550*x^8 + 224881944*x^9 - 299131287*x^10 - 
           392247345*x^11 + 696903382*x^12 + 769582684*x^13 - 
           982396957*x^14 - 1095683448*x^15 + 1000256202*x^16 + 
           1173557010*x^17 - 714379413*x^18 - 942174727*x^19 + 
           333083927*x^20 + 559212538*x^21 - 76891716*x^22 - 238370276*x^23 - 
           11233998*x^24 + 69088470*x^25 + 14260450*x^26 - 12203550*x^27 - 
           4210650*x^28 + 992250*x^29 + 463050*x^30)*HPL[{2, 0}, x])/
         (99225*(-1 + x^2)^12) + (4*(9 - 42*x - 1166*x^2 - 9576*x^3 - 
           26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 26077*x^8 - 
           9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*HPL[{-2, -1, 0}, x])/
         (945*(-1 + x^2)^10) + (8*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 
           26077*x^4 + 52122*x^5 + 60612*x^6 + 52122*x^7 + 26077*x^8 + 
           9576*x^9 + 1166*x^10 + 42*x^11 - 9*x^12)*HPL[{-2, 0, 0}, x])/
         (945*(-1 + x^2)^10) + (4*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 
           26077*x^4 + 52122*x^5 + 60612*x^6 + 52122*x^7 + 26077*x^8 + 
           9576*x^9 + 1166*x^10 + 42*x^11 - 9*x^12)*HPL[{-2, 1, 0}, x])/
         (945*(-1 + x^2)^10) + (4*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 
           26077*x^4 + 52122*x^5 + 60612*x^6 + 52122*x^7 + 26077*x^8 + 
           9576*x^9 + 1166*x^10 + 42*x^11 - 9*x^12)*HPL[{-1, -2, 0}, x])/
         (945*(-1 + x^2)^10) + ((463050 + 992250*x - 1895400*x^2 - 
           7242300*x^3 + 152950*x^4 + 22954470*x^5 + 13115252*x^6 - 
           41252426*x^7 - 34114206*x^8 + 46021458*x^9 + 42829927*x^10 - 
           32794727*x^11 - 30595348*x^12 + 14829885*x^13 + 12414822*x^14 - 
           4132893*x^15 - 2528750*x^16 + 673283*x^17 + 462406*x^18 + 
           673283*x^19 - 2528750*x^20 - 4132893*x^21 + 12414822*x^22 + 
           14829885*x^23 - 30595348*x^24 - 32794727*x^25 + 42829927*x^26 + 
           46021458*x^27 - 34114206*x^28 - 41252426*x^29 + 13115252*x^30 + 
           22954470*x^31 + 152950*x^32 - 7242300*x^33 - 1895400*x^34 + 
           992250*x^35 + 463050*x^36)*HPL[{-1, -1, 0}, x])/
         (198450*x^15*(-1 + x^2)^7) + ((29074 + 483500*x + 2283330*x^2 + 
           15663075*x^3 + 22789567*x^4 + 36881366*x^5 + 21562605*x^6 + 
           64137766*x^7 + 6058455*x^8 - 70224324*x^9 + 113889053*x^10 + 
           292558080*x^11 - 243888721*x^12 - 478290940*x^13 + 
           434181461*x^14 + 592799878*x^15 - 524046015*x^16 - 
           544964050*x^17 + 440417105*x^18 + 378509253*x^19 - 
           255260884*x^20 - 201071412*x^21 + 98191170*x^22 + 81580788*x^23 - 
           22982470*x^24 - 24381850*x^25 + 2657700*x^26 + 4806000*x^27 - 
           66150*x^28 - 463050*x^29)*HPL[{-1, 0, 0}, x])/
         (99225*(-1 + x)^12*(1 + x)^10) - 
        ((463050 + 992250*x - 1895400*x^2 - 7242300*x^3 + 152950*x^4 + 
           22954470*x^5 + 13115252*x^6 - 41252426*x^7 - 34114206*x^8 + 
           46021458*x^9 + 42829927*x^10 - 32794727*x^11 - 30595348*x^12 + 
           14829885*x^13 + 12414822*x^14 - 4132893*x^15 - 2528750*x^16 + 
           673283*x^17 + 462406*x^18 + 673283*x^19 - 2528750*x^20 - 
           4132893*x^21 + 12414822*x^22 + 14829885*x^23 - 30595348*x^24 - 
           32794727*x^25 + 42829927*x^26 + 46021458*x^27 - 34114206*x^28 - 
           41252426*x^29 + 13115252*x^30 + 22954470*x^31 + 152950*x^32 - 
           7242300*x^33 - 1895400*x^34 + 992250*x^35 + 463050*x^36)*
          HPL[{-1, 1, 0}, x])/(198450*x^15*(-1 + x^2)^7) + 
        (4*(9 - 42*x - 1166*x^2 - 9576*x^3 - 26077*x^4 - 52122*x^5 - 
           60612*x^6 - 52122*x^7 - 26077*x^8 - 9576*x^9 - 1166*x^10 - 
           42*x^11 + 9*x^12)*HPL[{-1, 2, 0}, x])/(945*(-1 + x^2)^10) + 
        (x*(-1682911557495 - 14222636618400*x + 462923819390970*x^2 + 
           1811456304745518*x^3 - 19003563398480157*x^4 - 65344537349425764*
            x^5 + 243296575936648407*x^6 + 786077275127639580*x^7 + 
           1284784548626459376*x^8 + 6745150387285830648*x^9 - 
           61660721031918404310*x^10 - 314805576718917671130*x^11 + 
           454287950699239643697*x^12 + 4000941841070265810732*x^13 + 
           2304924290844645819417*x^14 - 24244475729071848377646*x^15 - 
           56729601345557007989807*x^16 + 52405830748827799031118*x^17 + 
           366283263053641804988866*x^18 + 166456564647677981809534*x^19 - 
           1063905953253132647210970*x^20 - 1086217246511861780163706*x^21 + 
           1651599358604680160950812*x^22 + 1809866049301500109913996*x^23 - 
           5321362778204134242472372*x^24 - 4162509919128844106295628*x^25 + 
           18636893290412900299922220*x^26 + 19314666442257617494139052*
            x^27 - 20524438594658094760012774*x^28 - 
           27026031272216991421279136*x^29 + 27051525971671409558019090*
            x^30 + 33701368474354451815378032*x^31 - 
           32181709492401904265710641*x^32 - 38479505804521124662734764*
            x^33 + 29438917130128807809953382*x^34 + 
           36653138773175038354354802*x^35 - 20827986028983711856619713*
            x^36 - 28522740757888058967937552*x^37 + 
           11282869688850467920215607*x^38 + 18081785632767721555276668*
            x^39 - 4443108558378102096042240*x^40 - 9296431590393193432425928*
            x^41 + 1077531409673501751622810*x^42 + 3848617880675385044952342*
            x^43 - 16122890896058919319507*x^44 - 1271286312563892315099276*
            x^45 - 115683262208197562785059*x^46 + 331505677675303971805242*
            x^47 + 56720800627339494135555*x^48 - 67424581762718752981170*
            x^49 - 16023570818504992965810*x^50 + 10551013465629030715314*
            x^51 + 3084961259978170805736*x^52 - 1249335347085338572962*
            x^53 - 421224879035850653610*x^54 + 109420233109891527276*x^55 + 
           40898286177071235588*x^56 - 6848102512428458292*x^57 - 
           2765419398006942816*x^58 + 289049194083495240*x^59 + 
           123899187411091800*x^60 - 7362693941151600*x^61 - 
           3308131899505800*x^62 + 85426217824500*x^63 + 39865568318100*x^64)*
          HPL[{0, 0, 0}, x])/(99225*(-1 + x^2)^13*(9 - 82*x^2 + 9*x^4)^8) + 
        (4*(9 - 42*x - 1166*x^2 - 9576*x^3 - 26077*x^4 - 52122*x^5 - 
           60612*x^6 - 52122*x^7 - 26077*x^8 - 9576*x^9 - 1166*x^10 - 
           42*x^11 + 9*x^12)*HPL[{1, -2, 0}, x])/(945*(-1 + x^2)^10) - 
        ((463050 + 992250*x - 1895400*x^2 - 7242300*x^3 + 152950*x^4 + 
           22954470*x^5 + 13115252*x^6 - 41252426*x^7 - 34114206*x^8 + 
           46021458*x^9 + 42829927*x^10 - 32794727*x^11 - 30595348*x^12 + 
           14829885*x^13 + 12414822*x^14 - 4132893*x^15 - 2528750*x^16 + 
           673283*x^17 + 462406*x^18 + 673283*x^19 - 2528750*x^20 - 
           4132893*x^21 + 12414822*x^22 + 14829885*x^23 - 30595348*x^24 - 
           32794727*x^25 + 42829927*x^26 + 46021458*x^27 - 34114206*x^28 - 
           41252426*x^29 + 13115252*x^30 + 22954470*x^31 + 152950*x^32 - 
           7242300*x^33 - 1895400*x^34 + 992250*x^35 + 463050*x^36)*
          HPL[{1, -1, 0}, x])/(198450*x^15*(-1 + x^2)^7) - 
        ((29074 + 584676*x + 4490242*x^2 + 26624323*x^3 + 81143531*x^4 + 
           180383930*x^5 + 261901825*x^6 + 324614446*x^7 + 325131435*x^8 + 
           168729160*x^9 - 144011663*x^10 - 60043008*x^11 + 455028219*x^12 + 
           294104424*x^13 - 633037951*x^14 - 577323586*x^15 + 
           574125981*x^16 + 725319346*x^17 - 297044299*x^18 - 
           605028531*x^19 + 29161964*x^20 + 330268532*x^21 + 72162562*x^22 - 
           109051692*x^23 - 51895670*x^24 + 16494350*x^25 + 15795900*x^26 + 
           837000*x^27 - 1918350*x^28 - 463050*x^29)*HPL[{1, 0, 0}, x])/
         (99225*(-1 + x)^10*(1 + x)^12) + 
        ((463050 + 992250*x - 1895400*x^2 - 7242300*x^3 + 152950*x^4 + 
           22954470*x^5 + 13115252*x^6 - 41252426*x^7 - 34114206*x^8 + 
           46021458*x^9 + 42829927*x^10 - 32794727*x^11 - 30595348*x^12 + 
           14829885*x^13 + 12414822*x^14 - 4132893*x^15 - 2528750*x^16 + 
           673283*x^17 + 462406*x^18 + 673283*x^19 - 2528750*x^20 - 
           4132893*x^21 + 12414822*x^22 + 14829885*x^23 - 30595348*x^24 - 
           32794727*x^25 + 42829927*x^26 + 46021458*x^27 - 34114206*x^28 - 
           41252426*x^29 + 13115252*x^30 + 22954470*x^31 + 152950*x^32 - 
           7242300*x^33 - 1895400*x^34 + 992250*x^35 + 463050*x^36)*
          HPL[{1, 1, 0}, x])/(198450*x^15*(-1 + x^2)^7) + 
        (4*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 26077*x^4 + 52122*x^5 + 
           60612*x^6 + 52122*x^7 + 26077*x^8 + 9576*x^9 + 1166*x^10 + 
           42*x^11 - 9*x^12)*HPL[{1, 2, 0}, x])/(945*(-1 + x^2)^10) + 
        (4*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 26077*x^4 + 52122*x^5 + 
           60612*x^6 + 52122*x^7 + 26077*x^8 + 9576*x^9 + 1166*x^10 + 
           42*x^11 - 9*x^12)*HPL[{2, -1, 0}, x])/(945*(-1 + x^2)^10) + 
        (8*(9 - 42*x - 1166*x^2 - 9576*x^3 - 26077*x^4 - 52122*x^5 - 
           60612*x^6 - 52122*x^7 - 26077*x^8 - 9576*x^9 - 1166*x^10 - 
           42*x^11 + 9*x^12)*HPL[{2, 0, 0}, x])/(945*(-1 + x^2)^10) + 
        (4*(9 - 42*x - 1166*x^2 - 9576*x^3 - 26077*x^4 - 52122*x^5 - 
           60612*x^6 - 52122*x^7 - 26077*x^8 - 9576*x^9 - 1166*x^10 - 
           42*x^11 + 9*x^12)*HPL[{2, 1, 0}, x])/(945*(-1 + x^2)^10) + 
        (8*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 26077*x^4 + 52122*x^5 + 
           60612*x^6 + 52122*x^7 + 26077*x^8 + 9576*x^9 + 1166*x^10 + 
           42*x^11 - 9*x^12)*HPL[{-1, 1, 0, 0}, x])/(945*(-1 + x^2)^10) + 
        (8*(-9 + 42*x + 1166*x^2 + 9576*x^3 + 26077*x^4 + 52122*x^5 + 
           60612*x^6 + 52122*x^7 + 26077*x^8 + 9576*x^9 + 1166*x^10 + 
           42*x^11 - 9*x^12)*HPL[{1, -1, 0, 0}, x])/(945*(-1 + x^2)^10) - 
        ((-9 + 104*x + 875*x^2 + 12709*x^3 + 33740*x^4 + 89488*x^5 + 
           115400*x^6 + 132280*x^7 + 80865*x^8 + 46942*x^9 + 8829*x^10 + 
           3175*x^11 - 300*x^12 + 62*x^13)*master3l10a[x])/
         (1890*(-1 + x^2)^11) + (x*(62 - 300*x + 3175*x^2 + 8829*x^3 + 
           46942*x^4 + 80865*x^5 + 132280*x^6 + 115400*x^7 + 89488*x^8 + 
           33740*x^9 + 12709*x^10 + 875*x^11 + 104*x^12 - 9*x^13)*
          master3l10b[x])/(1890*(-1 + x^2)^11) + 
        ((2479730278050 - 107524867458528*x + 272739750997968*x^2 + 
           1519550082742725*x^3 + 3255603196706424*x^4 + 4015435464536598*
            x^5 + 1173310093442790*x^6 - 988180886879388*x^7 - 
           1594643283954900*x^8 - 369202880391318*x^9 + 568578633023466*
            x^10 + 99950433863625*x^11 - 170075101414770*x^12 + 
           10526799805596*x^13 + 55398491076924*x^14 - 2635986284112*x^15 - 
           13722197311446*x^16 - 1079226908556*x^17 + 2169689517476*x^18 + 
           399787073607*x^19 - 211457735644*x^20 - 56160929682*x^21 + 
           12122806782*x^22 + 4139873196*x^23 - 350173720*x^24 - 
           159525150*x^25 + 2003074*x^26 + 2540907*x^27 + 84726*x^28)*
          master3l8a[x])/(2381400*(-9 + x^2)^8*(-1 + x^2)^12) + 
        ((156380 + 1214194*x - 10638647*x^2 - 96499398*x^3 + 311015182*x^4 + 
           3370020040*x^5 - 5394532284*x^6 - 68844209374*x^7 + 
           66713110046*x^8 + 924826205116*x^9 - 649191555475*x^10 - 
           8711417399528*x^11 + 4494848374108*x^12 + 59272377822830*x^13 - 
           12206920527600*x^14 - 284827641450396*x^15 - 104847499396392*
            x^16 + 842880359812698*x^17 + 1146422927274579*x^18 - 
           740616719699574*x^19 - 3927496519311930*x^20 - 3498609688771212*
            x^21 + 2464873800625260*x^22 + 7679846810516058*x^23 + 
           8543737901732238*x^24 + 4607477135054424*x^25 + 
           1964675498417847*x^26 + 269931963725892*x^27 + 
           50888378126448*x^28 - 1503430645770*x^29)*master3l8b[x])/
         (2381400*x*(1 - 9*x^2)^8*(-1 + x^2)^12) + 
        ((-221286717990 + 8800735865832*x - 180575594892*x^2 + 
           25707049300377*x^3 + 75084043731012*x^4 + 254428696433133*x^5 + 
           369816933585294*x^6 + 220106226687273*x^7 - 64685140980318*x^8 - 
           173226732530337*x^9 - 79920313037982*x^10 + 38889946019460*x^11 + 
           47395268619528*x^12 - 2088578175726*x^13 - 13635310849348*x^14 - 
           763782810830*x^15 + 2540219635310*x^16 + 224806092278*x^17 - 
           322259313688*x^18 - 33298135807*x^19 + 27320295188*x^20 + 
           3126542673*x^21 - 1462579210*x^22 - 182295563*x^23 + 
           44168630*x^24 + 5886067*x^25 - 564734*x^26 - 78190*x^27)*
          master3l9a[x])/(793800*(-9 + x^2)^7*(-1 + x^2)^12) + 
        ((-78190 - 564734*x + 5886067*x^2 + 44168630*x^3 - 182295563*x^4 - 
           1462579210*x^5 + 3126542673*x^6 + 27320295188*x^7 - 
           33298135807*x^8 - 322259313688*x^9 + 224806092278*x^10 + 
           2540219635310*x^11 - 763782810830*x^12 - 13635310849348*x^13 - 
           2088578175726*x^14 + 47395268619528*x^15 + 38889946019460*x^16 - 
           79920313037982*x^17 - 173226732530337*x^18 - 64685140980318*x^19 + 
           220106226687273*x^20 + 369816933585294*x^21 + 254428696433133*
            x^22 + 75084043731012*x^23 + 25707049300377*x^24 - 
           180575594892*x^25 + 8800735865832*x^26 - 221286717990*x^27)*
          master3l9b[x])/(2381400*x*(-1 + x^2)^12*(-1 + 9*x^2)^7) - 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(463050 + 992250*x - 1895400*x^2 - 
             7242300*x^3 + 152950*x^4 + 22954470*x^5 + 13115252*x^6 - 
             41252426*x^7 - 34114206*x^8 + 46021458*x^9 + 42829927*x^10 - 
             32794727*x^11 - 30595348*x^12 + 14829885*x^13 + 12414822*x^14 - 
             4132893*x^15 - 2528750*x^16 + 673283*x^17 + 462406*x^18 + 
             673283*x^19 - 2528750*x^20 - 4132893*x^21 + 12414822*x^22 + 
             14829885*x^23 - 30595348*x^24 - 32794727*x^25 + 42829927*x^26 + 
             46021458*x^27 - 34114206*x^28 - 41252426*x^29 + 13115252*x^30 + 
             22954470*x^31 + 152950*x^32 - 7242300*x^33 - 1895400*x^34 + 
             992250*x^35 + 463050*x^36) + 10080*x^15*(9 - 42*x - 1166*x^2 - 
             9576*x^3 - 26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 
             26077*x^8 - 9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*Zeta[3]))/
         (2381400*x^15*(-1 + x^2)^10) + 
        (HPL[{1}, x]*(Pi^2*(-1 + x^2)^3*(463050 + 992250*x - 1895400*x^2 - 
             7242300*x^3 + 152950*x^4 + 22954470*x^5 + 13115252*x^6 - 
             41252426*x^7 - 34114206*x^8 + 46021458*x^9 + 42829927*x^10 - 
             32794727*x^11 - 30595348*x^12 + 14829885*x^13 + 12414822*x^14 - 
             4132893*x^15 - 2528750*x^16 + 673283*x^17 + 462406*x^18 + 
             673283*x^19 - 2528750*x^20 - 4132893*x^21 + 12414822*x^22 + 
             14829885*x^23 - 30595348*x^24 - 32794727*x^25 + 42829927*x^26 + 
             46021458*x^27 - 34114206*x^28 - 41252426*x^29 + 13115252*x^30 + 
             22954470*x^31 + 152950*x^32 - 7242300*x^33 - 1895400*x^34 + 
             992250*x^35 + 463050*x^36) + 10080*x^15*(9 - 42*x - 1166*x^2 - 
             9576*x^3 - 26077*x^4 - 52122*x^5 - 60612*x^6 - 52122*x^7 - 
             26077*x^8 - 9576*x^9 - 1166*x^10 - 42*x^11 + 9*x^12)*Zeta[3]))/
         (2381400*x^15*(-1 + x^2)^10) + (HPL[{0}, x]*(-50230616080806000 - 
           107637034458870000*x + 4067784961215696000*x^2 + 
           9061720296933276000*x^3 - 147922989714790069500*x^4 - 
           345961937164007007900*x^5 + 3184171509133177404660*x^6 + 
           7926859457923960810620*x^7 - 45002908886533178484960*x^8 - 
           121640228009150627626920*x^9 + 437275700710505630283240*x^10 + 
           1322265857825545292438100*x^11 + 688905*(-4301727847779036547 + 
             2052018360*Pi^2)*x^12 + 531441*(-19790171526539773591 + 
             22223224800*Pi^2)*x^13 - 10080*(-169396394385736463853565 + 
             67651563150560448271223*Pi^2)*x^35 + 
           729*(14427050241244899292749 + 157563734169644375847680*Pi^2)*
            x^57 + 5670*(522660111202465164333 + 3214756982142347287892*Pi^2)*
            x^58 - 918540*(1439530041255234093 + 26529515190540504128*Pi^2)*
            x^59 - 204120*(2142248190821603127 + 27410660370087507442*Pi^2)*
            x^60 + 49601160*(2452366598062437 + 79633287786986362*Pi^2)*
            x^61 + 1837080*(24496978295193012 + 617738884006050377*Pi^2)*
            x^62 - 74401740*(106541318226213 + 6471921311461754*Pi^2)*x^63 - 
           8266860*(385173029316231 + 19456961913108086*Pi^2)*x^64 + 
           669615660*(516657476565 + 64512587802988*Pi^2)*x^65 + 
           74401740*(1988165729925 + 215942114177176*Pi^2)*x^66 - 
           48212327520*(187954425 + 57202358567*Pi^2)*x^67 - 
           2678462640*(1518701400 + 414719676773*Pi^2)*x^68 + 
           1084777369200*(99225 + 109095389*Pi^2)*x^69 + 
           602654094000*(83349 + 84069763*Pi^2)*x^70 - 3056452443797382000*
            Pi^2*x^71 - 1372671859098834000*Pi^2*x^72 + 35879011486290000*
            Pi^2*x^73 + 16743538693602000*Pi^2*x^74 + 
           45*x^53*(26607612498686123969207584*Pi^2 + 
             243*(25719588830707459867873 - 6509735600256000*Zeta[3])) - 
           2*x^31*(-5717869941546180460612290157 + 54995569687328271338767500*
              Pi^2 - 58793385875635802476512000*Zeta[3]) + 
           14*x^33*(-752368879112560375143019037 + 19005998915930706701209080*
              Pi^2 - 15424467997757687084160000*Zeta[3]) + 
           6*x^29*(-2027576852767456842849878869 + 5099842094877495938409080*
              Pi^2 - 2981863108692762303744000*Zeta[3]) + 
           14*x^28*(668111250050527078386800191 + 1070381553262648225251600*
              Pi^2 - 1655571148880065425792000*Zeta[3]) - 
           28*x^42*(291068652368957594445122783 + 246440832372191939358510120*
              Pi^2 - 827785574440032712896000*Zeta[3]) - 
           210*x^30*(46105017617080066199338405 + 237313669421902679658124*
              Pi^2 - 293395225790115306144000*Zeta[3]) - 
           12*x^43*(908251935646340552985963883 + 661997322519138402980484000*
              Pi^2 - 278447520382072513920000*Zeta[3]) + 
           9*x^45*(972618854225426164162214469 + 926057510428880228249226880*
              Pi^2 - 201282668822029100544000*Zeta[3]) - 
           42*x^38*(150860479534800450479500223 + 81858018900020710043415360*
              Pi^2 - 131558686169324200416000*Zeta[3]) + 
           840*x^40*(6415505458532397730442515 + 6461987861048287049807302*
              Pi^2 - 73348806447528826536000*Zeta[3]) + 
           105*x^44*(61790775994491795331280873 + 66083414859660553159494744*
              Pi^2 - 33494630342259963340800*Zeta[3]) + 
           168*x^32*(53132848512656347038551387 + 842738607657222704814915*
              Pi^2 - 32889671542331050104000*Zeta[3]) - 
           210*x^26*(31066143186725841751942009 + 12795382403690283849780*
              Pi^2 - 16747315171129981670400*Zeta[3]) - 
           21*x^47*(257579300635642435625834577 + 337974882232808482891066000*
              Pi^2 - 16000558083039327840000*Zeta[3]) - 
           21*x^46*(157449151441036271850389461 + 259816867010171450890367880*
              Pi^2 - 4699761266207764512000*Zeta[3]) + 
           21*x^49*(123595618681565635897579347 + 232742480702729933270458240*
              Pi^2 - 1650332000033635968000*Zeta[3]) + 
           336*x^24*(9710654288979162766860346 + 727195908737904525675*Pi^2 - 
             293735079137985282000*Zeta[3]) - 189*x^21*
            (13739978873352804785667593 + 1543509911313236160*Pi^2 - 
             183370222225959552000*Zeta[3]) - 315*x^20*
            (-521643750653448218197111 + 4821632084370986640*Pi^2 - 
             24726030726309696000*Zeta[3]) - 168*x^51*
            (5778266437646336646026019 + 16114099070049239495994760*Pi^2 - 
             12552262676676576000*Zeta[3]) + 2268*x^18*
            (21720453654768561651971 + 65721771625734000*Pi^2 - 
             256103348093712000*Zeta[3]) - 23814*x^16*
            (1706990263834230425737 + 231606102859200*Pi^2 - 
             924069610800000*Zeta[3]) - 1512*x^56*(9117256115149119200493 + 
             20078898809326458541690*Pi^2 - 227803247532000*Zeta[3]) + 
           107163*x^14*(128638334413764266857 + 406990639800*Pi^2 - 
             3214155168000*Zeta[3]) - 19683*x^15*(-3174197522008522739869 + 
             28543793796000*Pi^2 + 52497867744000*Zeta[3]) + 
           10935*x^17*(-25718822398386197491027 + 796480367306400*Pi^2 + 
             6509735600256000*Zeta[3]) - 31752*x^19*
            (-30572018259905879869931 + 665447903722800*Pi^2 + 
             66414088236384000*Zeta[3]) + 189*x^52*
            (-260345827281655600344627 + 2197998177251956128418000*Pi^2 + 
             3073240177124544000*Zeta[3]) - 1260*x^50*
            (131248771975811101983949 + 1151185671133684413373992*Pi^2 + 
             6181507681577424000*Zeta[3]) - 441*x^22*
            (2468681979151398268361713 + 7625325639306421080*Pi^2 + 
             105132783612122784000*Zeta[3]) + 42*x^48*
            (26160828823386313265242149 + 78254128098531236163228520*Pi^2 + 
             1103894227927289232000*Zeta[3]) - 63*x^23*
            (-86245913860344619077094019 + 241484665951249834680*Pi^2 + 
             5333519361013109280000*Zeta[3]) + 27*x^25*
            (-331315221297178998532242773 + 16357763406147957874080*Pi^2 + 
             67094222940676366848000*Zeta[3]) - 12*x^27*
            (-968860843607631684381376993 + 416134474298052325210080*Pi^2 + 
             278447520382072513920000*Zeta[3]) + 
           6*x^41*(1923409840292394595118339959 + 
             1027350275305830208865880440*Pi^2 + 2981863108692762303744000*
              Zeta[3]) - 28*x^34*(524031697118489524767291191 + 
             19456171946736451934285520*Pi^2 + 9068121930071677634784000*
              Zeta[3]) + 14*x^37*(1313439504891521624825608787 + 
             140235451893448164840973320*Pi^2 + 15424467997757687084160000*
              Zeta[3]) + 14*x^36*(1545455303219733955383908557 + 
             126062538895585225573014360*Pi^2 + 18136243860143355269568000*
              Zeta[3]) - 2*x^39*(7660766159651907946398581557 + 
             1951213848390816996523632480*Pi^2 + 58793385875635802476512000*
              Zeta[3]) - 27*x^55*(15521341785040547351455000*Pi^2 - 
             19683*(-117563777049033446447 + 1944365472000*Zeta[3])) - 
           21*x^54*(1768126827208190521384280*Pi^2 + 
             81*(-23897191863604641334943 + 12936974551200000*Zeta[3]))))/
         (1000188000*x^11*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        (-1411200*Pi^4*x^13*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^8*
           (9 - 42*x - 1166*x^2 - 9576*x^3 - 26077*x^4 - 52122*x^5 - 
            60612*x^6 - 52122*x^7 - 26077*x^8 - 9576*x^9 - 1166*x^10 - 
            42*x^11 + 9*x^12) - 48*Pi^2*(9 - 82*x^2 + 9*x^4)^8*
           (-194481000 - 416745000*x + 1671232500*x^2 + 4917118500*x^3 - 
            5169979500*x^4 - 26593326900*x^5 + 2264455410*x^6 + 
            87211247970*x^7 + 33060419350*x^8 - 193285870050*x^9 - 
            123351295410*x^10 + 305351942350*x^11 + 241105223520*x^12 - 
            353297907878*x^13 - 308633442397*x^14 + 302293181338*x^15 + 
            268610986679*x^16 - 202636083832*x^17 - 209646600597*x^18 + 
            43715060522*x^19 + 61995483305*x^20 - 61995483305*x^22 - 
            43715060522*x^23 + 209646600597*x^24 + 202636083832*x^25 - 
            268610986679*x^26 - 302293181338*x^27 + 308633442397*x^28 + 
            353297907878*x^29 - 241105223520*x^30 - 305351942350*x^31 + 
            123351295410*x^32 + 193285870050*x^33 - 33060419350*x^34 - 
            87211247970*x^35 - 2264455410*x^36 + 26593326900*x^37 + 
            5169979500*x^38 - 4917118500*x^39 - 1671232500*x^40 + 
            416745000*x^41 + 194481000*x^42) + x^2*(602767392969672000 + 
            1291644413506440000*x - 49014341998911576000*x^2 - 
            109171191701034792000*x^3 + 1791271670498222409000*x^4 + 
            4187628671604128893800*x^5 - 38795690249862199594920*x^6 - 
            96492658360826873570040*x^7 + 552553070523850324083960*x^8 + 
            1490878723567960951990920*x^9 - 5422664722569343878507480*x^10 + 
            x^41*(199741694613273401219725665656 - 
              877984762038746317571082620160*Zeta[3]) + 
            x^33*(127443712481883437296050899416 - 
              89339629042416052566057012480*Zeta[3]) + 440129151906823008000*
             x^71*Zeta[3] + 197664747710232096000*x^72*Zeta[3] - 
            5166577654025760000*x^73*Zeta[3] - 2411069571878688000*x^74*
             Zeta[3] - 21695547384000*x^70*(-27783 + 336279052*Zeta[3]) - 
            39051985291200*x^69*(-33075 + 436381556*Zeta[3]) + 
            167403915*x^11*(-97621035537430805 + 1256840064*Zeta[3]) + 
            32109410128320*x^67*(-3399975 + 12368077528*Zeta[3]) - 
            8266860*x^12*(-4505456438211822433 + 437915362176*Zeta[3]) + 
            96424655040*x^68*(-508317525 + 1658878707092*Zeta[3]) - 
            12754584*x^13*(-10295953674002442881 + 3159895959360*Zeta[3]) + 
            183708*x^14*(-961632388772568097903 + 251212744366560*Zeta[3]) - 
            12053081880*x^65*(-347432193135 + 516100702423904*Zeta[3]) - 
            1339231320*x^66*(-1337537170575 + 1727536913417408*Zeta[3]) + 
            472392*x^15*(-1672150278790364799157 + 3781128550888080*Zeta[
                3]) + 1339231320*x^63*(-72050777875197 + 51775370491694032*
               Zeta[3]) - 4910514840*x^61*(-303609452805963 + 
              115830236781071072*Zeta[3]) + 148803480*x^64*
             (-260717627369079 + 155655695304864688*Zeta[3]) - 
            157464*x^17*(-22925193352692991379507 + 191279374325303040*Zeta[
                3]) + 20412*x^16*(26403047780406113217869 + 
              310851429797953440*Zeta[3]) - 16533720*x^62*
             (-33419767029068493 + 9883822144096806032*Zeta[3]) - 
            6804*x^18*(108388422516649249489369 + 40348880777613899520*Zeta[
                3]) + 486*x^19*(-26105421819383149812132113 + 
              63393672689067530880*Zeta[3]) + 1837080*x^60*
             (-2951784816010983531 + 438570565921400119072*Zeta[3]) + 
            5832*x^21*(5945936781723844283106761 + 1161839701935392880960*
               Zeta[3]) + 2066715*x^59*(-7907303849622904485 + 
              1697888972239255773056*Zeta[3]) + 756*x^20*
             (-2376677387326684204160771 + 6698290199163709296960*Zeta[3]) + 
            3780*x^26*(23035561364186003841966797 + 7146469947174295766784*
               Zeta[3]) - 102060*x^58*(-364941716245975497663 + 
              25718055885215580111232*Zeta[3]) - 1080*x^23*
             (69004556048134783789032865 + 108481042061262325403424*Zeta[
                3]) - 252*x^22*(-53670255405272915155426247 + 
              197396933958002695619520*Zeta[3]) - 52488*x^57*
             (-2501917258902099811533 + 315127468879749927869440*Zeta[3]) + 
            6804*x^56*(-25963768646586954449631 + 642524764753442562752000*
               Zeta[3]) + 252*x^24*(-166766561904448023998368277 + 
              938971482273630603538560*Zeta[3]) + 216*x^25*
             (590672699973741623594856169 + 4453328867645703801201600*Zeta[
                3]) + 756*x^54*(712797690178571043160413 + 
              7072515654166349807854400*Zeta[3]) - 6804*x^52*
             (108228497798826057255619 + 8792030869815527979737920*Zeta[3]) - 
            3024*x^32*(37449016410682157706030977 + 
              23939004862823546987155400*Zeta[3]) + 1944*x^55*
             (-406333870509440704518351 + 31042684249408017930695840*Zeta[
                3]) - 112*x^28*(1218286847406869325734209429 + 
              57568529691981780960236400*Zeta[3]) + 6048*x^38*
             (-23002490778565569852306651 + 73417151695388409731097320*Zeta[
                3]) + 448*x^34*(-10934423916207559055626291 + 
              230378101865478200308319640*Zeta[3]) - 3780*x^44*
             (-23621484954481871037567667 + 264401115078937828304404992*Zeta[
                3]) - 648*x^53*(-5570981408227190621273451 + 
              266076156953737799769842560*Zeta[3]) + 756*x^50*
             (-2391977090682342694131521 + 276290912794167227361104640*Zeta[
                3]) + 112*x^30*(1476114857420636154990256781 + 
              291907616160217422767521320*Zeta[3]) + 
            8*x^29*(24559938268782891725834705707 + 
              749623604427147290412670560*Zeta[3]) + 1080*x^47*
             (-69259467147299661255955105 + 946216799028652648957952464*Zeta[
                3]) - 252*x^48*(-54000444407378937642722597 + 
              1878291830386373114422793760*Zeta[3]) - 
            112*x^36*(352497334672439734787333839 + 
              2073460113890506807842842640*Zeta[3]) + 
            8*x^31*(-20410615382388573145305610813 + 
              2288812006495797167586050640*Zeta[3]) + 
            252*x^46*(-168574158677443443518926127 + 
              3118808976013141065949612320*Zeta[3]) - 
            216*x^49*(-160685048271233115853656597 + 
              3258359885955895548169227200*Zeta[3]) - 
            224*x^40*(-854775732843752315041169953 + 
              3374274215586969791575517160*Zeta[3]) - 
            x^27*(176654831086735640987269980617 + 
              4086892228822412838022615680*Zeta[3]) - 
            216*x^45*(-597686513259531896898658819 + 
              5551647735482370430683479040*Zeta[3]) + 
            54*x^51*(-234990974671527517177630617 + 
              7219114956450537614847721600*Zeta[3]) + 
            112*x^42*(-1302181564814908060303130629 + 
              8830742237004794600218263120*Zeta[3]) - 
            8*x^37*(-9562129055294384583574392527 + 
              41957537932988846227109363040*Zeta[3]) + 
            4*x^35*(-47011626734075294085116244901 + 
              42234831525753706719573953280*Zeta[3]) + 
            8*x^39*(-17733698783335105347508311613 + 
              70779288200211524134697317920*Zeta[3]) + 
            x^43*(-181232775622692678140135062217 + 
              1139283735461249655838150558080*Zeta[3])))/
         (48009024000*x^13*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8)))
 
CbarLData["a", 2, -1] = 
    NC*(CF^2*((lm^3*(1 + x)^2)/4 + (Pi^2*(1 + x^2)*HPL[{-2}, x])/9 + 
        lm^2*((-7 - 2*x - 7*x^2)/16 - (3*x^3*(2 + x)*HPL[{0}, x])/
           (2*(-1 + x^2))) - (Pi^2*(1 + x^2)*HPL[{2}, x])/9 + 
        (x^2*(6 - 12*x - 57*x^2 + 39*x^3 + 46*x^4 - 22*x^5 - 22*x^6 - x^7 + 
           5*x^8 + 2*x^9)*HPL[{-2, 0}, x])/(9*(-1 + x^2)^2) - 
        ((12 + 30*x + 12*x^2 + (181 - 12*Pi^2)*x^3 - 6*x^4 - 554*x^5 - 
           6*x^6 + (181 + 12*Pi^2)*x^7 + 12*x^8 + 30*x^9 + 12*x^10)*
          HPL[{-1, 0}, x])/(108*x^3*(-1 + x^2)) + 
        (x^2*(-384 + 747*x + 99*x^2 + 1746*x^3 + 3923*x^4 + 15*x^6 + 6*x^7)*
          HPL[{0, 0}, x])/(27*(-1 + x^2)^2) + 
        ((12 + 30*x + 12*x^2 + (181 - 12*Pi^2)*x^3 - 6*x^4 - 554*x^5 - 
           6*x^6 + (181 + 12*Pi^2)*x^7 + 12*x^8 + 30*x^9 + 12*x^10)*
          HPL[{1, 0}, x])/(108*x^3*(-1 + x^2)) + 
        (x^2*(-6 + 12*x + 57*x^2 - 39*x^3 - 46*x^4 + 22*x^5 + 22*x^6 + x^7 - 
           5*x^8 - 2*x^9)*HPL[{2, 0}, x])/(9*(-1 + x^2)^2) - 
        (4*(1 + x^2)*HPL[{-2, -1, 0}, x])/3 + 
        (8*(1 + x^2)*HPL[{-2, 0, 0}, x])/3 + (4*(1 + x^2)*HPL[{-2, 1, 0}, x])/
         3 + (4*(1 + x^2)*HPL[{-1, -2, 0}, x])/3 - 
        ((1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 11*x^6 - x^8 + 2*x^9)*
          HPL[{-1, -1, 0}, x])/(18*x^5) + 
        ((-56 + 85*x - 39*x^2 - 3*x^3 + 3*x^4 + 9*x^5 - 13*x^6 - 5*x^7 + 
           x^8 + 2*x^9)*HPL[{-1, 0, 0}, x])/(9*(-1 + x)^2) + 
        ((1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 11*x^6 - x^8 + 2*x^9)*
          HPL[{-1, 1, 0}, x])/(18*x^5) - (4*(1 + x^2)*HPL[{-1, 2, 0}, x])/3 - 
        (2*x^2*(-3 + 366*x + 309*x^2 - 828*x^3 - 1415*x^4 + 652*x^5 + 
           1155*x^6 - 21*x^7 - 27*x^8 - 3*x^9 + 5*x^10 + 2*x^11)*
          HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) - 
        (4*(1 + x^2)*HPL[{1, -2, 0}, x])/3 + 
        ((1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 11*x^6 - x^8 + 2*x^9)*
          HPL[{1, -1, 0}, x])/(18*x^5) + 
        ((56 + 91*x + 51*x^2 + 39*x^3 + 69*x^4 + 39*x^5 + x^6 - 15*x^7 - 
           9*x^8 - 2*x^9)*HPL[{1, 0, 0}, x])/(9*(1 + x)^2) - 
        ((1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 11*x^6 - x^8 + 2*x^9)*
          HPL[{1, 1, 0}, x])/(18*x^5) + (4*(1 + x^2)*HPL[{1, 2, 0}, x])/3 + 
        (4*(1 + x^2)*HPL[{2, -1, 0}, x])/3 - (8*(1 + x^2)*HPL[{2, 0, 0}, x])/
         3 - (4*(1 + x^2)*HPL[{2, 1, 0}, x])/3 + 
        (8*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/3 + 
        (8*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/3 + 
        ((1 + x + (4*x)/(-1 + x^2))*master3l10a[x])/12 + 
        ((x + x^2 + 3*x^3 - x^4)*master3l10b[x])/(12 - 12*x^2) - 
        ((-11 + 6*x + x^2)*master3l8a[x])/(12*(-1 + x^2)^2) + 
        ((5 - 18*x - 39*x^2)*master3l8b[x])/(36*(-1 + x^2)^2) - 
        ((-9 + x^2)*master3l9a[x])/(3*(-1 + x^2)^2) + 
        ((1 - 9*x^2)*master3l9b[x])/(9*(-1 + x^2)^2) + 
        (HPL[{-1}, x]*(Pi^2*(1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 
             11*x^6 - x^8 + 2*x^9) + 288*x^5*(1 + x^2)*Zeta[3]))/(216*x^5) - 
        (HPL[{1}, x]*(Pi^2*(1 + x)^3*(-2 + x + 11*x^3 - 16*x^4 + 16*x^5 - 
             11*x^6 - x^8 + 2*x^9) + 288*x^5*(1 + x^2)*Zeta[3]))/(216*x^5) + 
        (HPL[{0}, x]*(24 + 60*x + 12*x^2 - 4*(-2947 + 6*Pi^2)*x^3 + 
           8*(-3 + 11*Pi^2)*x^8 + 88*Pi^2*x^9 + 4*Pi^2*x^10 - 20*Pi^2*x^11 - 
           8*Pi^2*x^12 + 6*x^4*(-2283 + 8*Pi^2 + 576*Zeta[3]) - 
           6*x^6*(1499 + 26*Pi^2 + 576*Zeta[3]) - x^7*(21885 + 184*Pi^2 + 
             1728*Zeta[3]) + x^5*(-12643 + 228*Pi^2 + 1728*Zeta[3])))/
         (432*x*(-1 + x^2)^2) + lm*((x^2*(-4 + 2*x + 7*x^2)*HPL[{0}, x])/
           (4*(-1 + x^2)) + (1 - x^2)*HPL[{-1, 0}, x] + 
          (4*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/(-1 + x^2)^2 + 
          (-1 + x^2)*HPL[{1, 0}, x] + (-95 + 8*Pi^2*(-1 + x^2) + 
            144*Zeta[3] + x^2*(-95 + 144*Zeta[3]) + x*(-82 + 288*Zeta[3]))/
           96) + (-24*Pi^4*x^3*(-1 + x^2)^2*(39 + 88*x + 39*x^2) + 
          10*Pi^2*(-1 + x^2)*(12 + 30*x + 12*x^2 - 554*x^5 + 12*x^8 + 
            30*x^9 + 12*x^10 + x^7*(181 - 576*Log[2]^2) + 
            6*x^4*(-1 + 192*Log[2]^2) - 6*x^6*(1 + 192*Log[2]^2) + 
            x^3*(181 + 576*Log[2]^2)) + 15*x^2*(-12 - 528*x^9*Zeta[3] - 
            24*x^10*Zeta[3] + 120*x^11*Zeta[3] + 48*x^12*Zeta[3] - 
            12*x^8*(1 + 44*Zeta[3]) + 3*x^2*(377 + 256*Log[2]^4 + 
              6144*PolyLog[4, 1/2] + 4072*Zeta[3]) - 
            6*x^4*(-2927 + 256*Log[2]^4 + 6144*PolyLog[4, 1/2] + 
              4192*Zeta[3]) + 3*x^6*(377 + 256*Log[2]^4 + 6144*PolyLog[4, 
                1/2] + 4384*Zeta[3]) - x^3*(10405 + 384*Log[2]^4 + 
              9216*PolyLog[4, 1/2] + 6288*Zeta[3]) - 
            x^5*(-17675 + 384*Log[2]^4 + 9216*PolyLog[4, 1/2] + 
              6504*Zeta[3]) + x*(-14255 + 384*Log[2]^4 + 9216*PolyLog[4, 
                1/2] + 9096*Zeta[3]) + x^7*(6625 + 384*Log[2]^4 + 
              9216*PolyLog[4, 1/2] + 9768*Zeta[3])))/
         (12960*x^3*(-1 + x^2)^2)) + CA*CF*((11*lm^3*(1 + x)^2)/72 - 
        (Pi^2*(1 + x^2)*HPL[{-2}, x])/18 + 
        lm^2*((119 + 304*x + 119*x^2)/144 - (11*x^3*(2 + x)*HPL[{0}, x])/
           (12*(-1 + x^2))) + (Pi^2*(1 + x^2)*HPL[{2}, x])/18 + 
        (x^2*(-6 + 6*x + 42*x^2 - 21*x^3 - 31*x^4 + 6*x^5 + 9*x^6 + 3*x^7)*
          HPL[{-2, 0}, x])/(18*(-1 + x^2)^2) + 
        ((6 + 161*x + 4*Pi^2*x - 12*x^2 - 294*x^3 - 12*x^4 + 161*x^5 - 
           4*Pi^2*x^5 + 6*x^6)*HPL[{-1, 0}, x])/(72*x - 72*x^3) + 
        (x^2*(326 - 1666*x - 711*x^2 - 598*x^3 - 2229*x^4 + 6*x^5)*
          HPL[{0, 0}, x])/(36*(-1 + x^2)^2) + 
        ((6 + (161 + 4*Pi^2)*x - 12*x^2 - 294*x^3 - 12*x^4 + 
           (161 - 4*Pi^2)*x^5 + 6*x^6)*HPL[{1, 0}, x])/(72*x*(-1 + x^2)) - 
        (x^2*(-6 + 6*x + 42*x^2 - 21*x^3 - 31*x^4 + 6*x^5 + 9*x^6 + 3*x^7)*
          HPL[{2, 0}, x])/(18*(-1 + x^2)^2) + 
        (2*(1 + x^2)*HPL[{-2, -1, 0}, x])/3 - (8*x^2*HPL[{-2, 0, 0}, x])/3 - 
        (2*(1 + x^2)*HPL[{-2, 1, 0}, x])/3 - 
        (2*(1 + x^2)*HPL[{-1, -2, 0}, x])/3 + 
        ((3 + 9*x + 12*x^2 - 35*x^3 + 35*x^5 - 12*x^6 - 9*x^7 - 3*x^8)*
          HPL[{-1, -1, 0}, x])/(36*x^3) + 
        ((67 - 101*x + 93*x^2 - 107*x^3 + 61*x^4 - 3*x^5 + 3*x^6 + 3*x^7)*
          HPL[{-1, 0, 0}, x])/(18*(-1 + x)^2) + 
        ((-3 - 9*x - 12*x^2 + 35*x^3 - 35*x^5 + 12*x^6 + 9*x^7 + 3*x^8)*
          HPL[{-1, 1, 0}, x])/(36*x^3) + (2*(1 + x^2)*HPL[{-1, 2, 0}, x])/3 + 
        (x^2*(-9 + 330*x + 72*x^2 + 366*x^3 + 907*x^4 - 6*x^5 - 9*x^6 - 
           3*x^7)*HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^2) + 
        (2*(1 + x^2)*HPL[{1, -2, 0}, x])/3 + 
        ((-3 - 9*x - 12*x^2 + 35*x^3 - 35*x^5 + 12*x^6 + 9*x^7 + 3*x^8)*
          HPL[{1, -1, 0}, x])/(36*x^3) - 
        ((67 + 119*x + 129*x^2 + 149*x^3 + 109*x^4 + 33*x^5 + 15*x^6 + 3*x^7)*
          HPL[{1, 0, 0}, x])/(18*(1 + x)^2) + 
        ((3 + 9*x + 12*x^2 - 35*x^3 + 35*x^5 - 12*x^6 - 9*x^7 - 3*x^8)*
          HPL[{1, 1, 0}, x])/(36*x^3) - (2*(1 + x^2)*HPL[{1, 2, 0}, x])/3 - 
        (2*(1 + x^2)*HPL[{2, -1, 0}, x])/3 + (8*x^2*HPL[{2, 0, 0}, x])/3 + 
        (2*(1 + x^2)*HPL[{2, 1, 0}, x])/3 + 
        (4*(-1 + x^2)*HPL[{-1, 0, 0, 0}, x])/3 - 
        (4*(1 + x^2)*HPL[{-1, 1, 0, 0}, x])/3 - 
        (4*(1 + x^2)*HPL[{1, -1, 0, 0}, x])/3 - 
        (4*(-1 + x^2)*HPL[{1, 0, 0, 0}, x])/3 + 
        ((-1 + x*(-1 - 4/(-1 + x^2)))*master3l10a[x])/24 + 
        ((x + x^2 + 3*x^3 - x^4)*master3l10b[x])/(24*(-1 + x^2)) + 
        ((-11 + 6*x + x^2)*master3l8a[x])/(24*(-1 + x^2)^2) + 
        ((-5 + 18*x + 39*x^2)*master3l8b[x])/(72*(-1 + x^2)^2) + 
        ((-9 + x^2)*master3l9a[x])/(6*(-1 + x^2)^2) + 
        ((-1 + 9*x^2)*master3l9b[x])/(18*(-1 + x^2)^2) + 
        (HPL[{-1}, x]*(Pi^2*(-3 - 9*x - 12*x^2 + 35*x^3 - 35*x^5 + 12*x^6 + 
             9*x^7 + 3*x^8) - 288*x^3*(1 + x^2)*Zeta[3]))/(432*x^3) + 
        (HPL[{1}, x]*(Pi^2*(3 + 9*x + 12*x^2 - 35*x^3 + 35*x^5 - 12*x^6 - 
             9*x^7 - 3*x^8) + 288*x^3*(1 + x^2)*Zeta[3]))/(432*x^3) + 
        (x*HPL[{0}, x]*(18 + 12*(-426 + Pi^2)*x - 12*Pi^2*x^6 - 18*Pi^2*x^7 - 
           6*Pi^2*x^8 + x^3*(6345 - 84*Pi^2 - 864*Zeta[3]) - 
           6*x^2*(-1905 + 2*Pi^2 + 288*Zeta[3]) + 6*x^4*(-18 + 7*Pi^2 + 
             288*Zeta[3]) + x^5*(10107 + 62*Pi^2 + 864*Zeta[3])))/
         (432*(-1 + x^2)^2) + (8*Pi^4*x*(-1 + x^2)^2*(47 + 88*x + 31*x^2) + 
          10*Pi^2*(-1 + x^2)*(6 - 294*x^3 + 6*x^6 + x*(161 - 192*Log[2]^2) + 
            12*x^4*(-1 + 32*Log[2]^2) - 12*x^2*(1 + 32*Log[2]^2) + 
            x^5*(161 + 192*Log[2]^2)) + 15*x*(5269 - 128*Log[2]^4 - 
            3072*PolyLog[4, 1/2] - 2256*Zeta[3] + 48*x^7*Zeta[3] + 
            72*x^8*Zeta[3] + 24*x^9*Zeta[3] + 16*x^3*(-878 + 32*Log[2]^4 + 
              768*PolyLog[4, 1/2] + 415*Zeta[3]) - 4*x*(-931 + 64*Log[2]^4 + 
              1536*PolyLog[4, 1/2] + 806*Zeta[3]) - 
            4*x^5*(-931 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 848*Zeta[3]) + 
            x^2*(2951 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 1096*Zeta[3]) + 
            x^4*(-6409 + 128*Log[2]^4 + 3072*PolyLog[4, 1/2] + 
              2008*Zeta[3]) - x^6*(1691 + 128*Log[2]^4 + 3072*PolyLog[4, 
                1/2] + 2680*Zeta[3])))/(8640*x*(-1 + x^2)^2) + 
        lm*(-(x^2*(22 + 304*x + 119*x^2)*HPL[{0}, x])/(36*(-1 + x^2)) - 
          (11*(-1 + x^2)*HPL[{-1, 0}, x])/18 + 
          (22*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0}, x])/
           (9*(-1 + x^2)^2) + (11*(-1 + x^2)*HPL[{1, 0}, x])/18 + 
          (44*Pi^2*(-1 + x^2) - 9*(-137 + 72*Zeta[3] + 2*x*(-275 + 
                72*Zeta[3]) + x^2*(-137 + 72*Zeta[3])))/864)) + 
      CF*(NH*(-(lm^3*(1 + x)^2)/36 + (x*(48 + 472*x + 2985*x^2 + 1552*x^3 - 
             807*x^4 - 521*x^5 + 102*x^6 + 49*x^7)*HPL[{0}, x])/
           (36*(-1 + x^2)^3) + lm^2*((-7 - 20*x - 7*x^2)/72 + 
            (x^3*(2 + x)*HPL[{0}, x])/(6*(-1 + x^2))) - 
          (x*(24 + 136*x + 1016*x^2 + 523*x^3 - 378*x^4 - 208*x^5 + 58*x^6 + 
             29*x^7)*HPL[{0, 0}, x])/(18*(-1 + x^2)^3) + 
          lm*((-4*Pi^2*(-1 + x^2) - 9*(9 + 38*x + 9*x^2))/432 + 
            (x^2*(2 + 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((-1 + x^2)*HPL[{-1, 0}, x])/9 - (4*x^3*(-6 - 3*x + 3*x^2 + 2*
                x^3)*HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + 
            ((1 - x^2)*HPL[{1, 0}, x])/9) + 
          ((2 - 43*x - 12*x^2 + 5*x^3 + 8*x^4)*HPL[{-1, 0, 0}, x])/
           (9*(-1 + x)^2) - (2*x^3*(-54 - 33*x + 6*x^2 + x^5)*
            HPL[{0, 0, 0}, x])/(9*(-1 + x^2)^3) - 
          ((14 - 5*x + 19*x^3 + 8*x^4)*HPL[{1, 0, 0}, x])/(9*(1 + x)^2) + 
          ((9 + 54*x + 28*x^2 - 6*x^3 - 5*x^4)*master3l8a[x])/
           (18*(-1 + x^2)^3) + ((27 + 108*x + 51*x^2 - 12*x^3 - 15*x^4 + x^6)*
            master3l9a[x])/(18*(-1 + x^2)^3) + (x^5*(7671 - 768*Zeta[3]) + 
            39*(-99 + 32*Zeta[3]) - 4*x^8*(113 + 32*Zeta[3]) + 
            3*x^3*(-6687 + 64*Zeta[3]) - 3*x^7*(309 + 64*Zeta[3]) - 
            3*x^4*(3253 + 96*Zeta[3]) + 3*x*(-5641 + 256*Zeta[3]) + 
            x^6*(4517 + 320*Zeta[3]) - 3*x^2*(3535 + 384*Zeta[3]))/
           (432*(-1 + x^2)^3)) + NM*(-(lm^3*(1 + x)^2)/36 + 
          ((2*Pi^2*(-1 + x^2)^4 + 3*(38 - 219*x^2 + 9*x^3 - 188*x^4 + 459*
                x^5 + 1030*x^6 + 1860*x^7 + 891*x^8))*HPL[{0}, x])/
           (108*(-1 + x^2)^3) + lm^2*((-7 - 20*x - 7*x^2)/72 + 
            (x^3*(2 + x)*HPL[{0}, x])/(6*(-1 + x^2))) - 
          (2*(-1 + x^2)*HPL[{-2, 0}, x])/9 - 
          ((12 + 14*x^2 + 32*x^3 - 601*x^4 - 30*x^5 + 978*x^6 + 2446*x^7 + 
             1229*x^8)*HPL[{0, 0}, x])/(18*(-1 + x^2)^3) + 
          lm*((-4*Pi^2*(-1 + x^2) - 9*(9 + 38*x + 9*x^2))/432 + 
            (x^2*(2 + 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((-1 + x^2)*HPL[{-1, 0}, x])/9 - (4*x^3*(-6 - 3*x + 3*x^2 + 2*
                x^3)*HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + 
            ((1 - x^2)*HPL[{1, 0}, x])/9) + (2*(-1 + x^2)*HPL[{2, 0}, x])/9 - 
          ((-12 + 3*x + 12*x^2 + 35*x^3 + 2*x^4)*HPL[{-1, 0, 0}, x])/
           (9*(-1 + x)^2) + (2*(1 + 28*x^2 + 30*x^3 - 243*x^4 - 138*x^5 + 
             332*x^6 + 1020*x^7 + 490*x^8)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x^2)^3) - ((12 + 27*x - 13*x^3 + 10*x^4)*
            HPL[{1, 0, 0}, x])/(9*(1 + x)^2) + 
          ((2 - 15*x^2 - 6*x^3 + 18*x^4 + 54*x^5 + 27*x^6)*master3l8b[x])/
           (54*x^2*(-1 + x^2)^3) + ((1 - 15*x^2 - 12*x^3 + 51*x^4 + 108*x^5 + 
             27*x^6)*master3l9b[x])/(54*x^2*(-1 + x^2)^3) + 
          (15 - 156*x^10*(9 + 8*Zeta[3]) + 3*x^3*(249 + 64*Zeta[3]) - 
            3*x^7*(1173 + 64*Zeta[3]) + 12*x^8*(-485 + 96*Zeta[3]) + 
            3*x^6*(283 + 96*Zeta[3]) + x^2*(-13 + 128*Zeta[3]) - 
            3*x^9*(1379 + 256*Zeta[3]) - x^4*(347 + 320*Zeta[3]) + 
            x^5*(-3171 + 768*Zeta[3]))/(432*x^2*(-1 + x^2)^3)) + 
        NL*(-(lm^3*(1 + x)^2)/36 + (Pi^2*(-1 + x^2)*HPL[{-1}, x])/54 + 
          (x^2*(-84 + 6*(-57 + 4*Pi^2)*x + 3*(1 + 4*Pi^2)*x^2 + 342*x^3 + 
             (81 - 4*Pi^2)*x^4)*HPL[{0}, x])/(216*(-1 + x^2)^2) + 
          lm^2*((-7 - 20*x - 7*x^2)/72 + (x^3*(2 + x)*HPL[{0}, x])/
             (6*(-1 + x^2))) - (Pi^2*(-1 + x^2)*HPL[{1}, x])/54 + 
          (2*x^3*(-6 - 3*x + x^3)*HPL[{-2, 0}, x])/(9*(-1 + x^2)^2) + 
          ((7 + 6*x - 10*x^2 + 6*x^3 + 7*x^4)*HPL[{-1, 0}, x])/
           (18*(-1 + x^2)) + (2*x^3*(20 + 10*x - 13*x^2 - 7*x^3)*
            HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + 
          ((7 + 6*x - 10*x^2 + 6*x^3 + 7*x^4)*HPL[{1, 0}, x])/(18 - 18*x^2) + 
          lm*((-4*Pi^2*(-1 + x^2) - 9*(9 + 38*x + 9*x^2))/432 + 
            (x^2*(2 + 20*x + 7*x^2)*HPL[{0}, x])/(18*(-1 + x^2)) + 
            ((-1 + x^2)*HPL[{-1, 0}, x])/9 - (4*x^3*(-6 - 3*x + 3*x^2 + 2*
                x^3)*HPL[{0, 0}, x])/(9*(-1 + x^2)^2) + 
            ((1 - x^2)*HPL[{1, 0}, x])/9) - (2*x^3*(-6 - 3*x + x^3)*
            HPL[{2, 0}, x])/(9*(-1 + x^2)^2) - 
          (2*(-1 + x^2)*HPL[{-1, -1, 0}, x])/9 + 
          (2*(-1 + x^2)*HPL[{-1, 1, 0}, x])/9 + 
          (8*x^3*(-6 - 3*x + 3*x^2 + 2*x^3)*HPL[{0, 0, 0}, x])/
           (9*(-1 + x^2)^2) + (2*(-1 + x^2)*HPL[{1, -1, 0}, x])/9 - 
          (2*(-1 + x^2)*HPL[{1, 1, 0}, x])/9 - 
          (4*Pi^2*(-7 - 6*x + 17*x^2 - 17*x^4 + 6*x^5 + 7*x^6) + 
            3*(73 + 96*Zeta[3] + 8*x*(41 + 16*Zeta[3]) + 8*x^5*(41 + 
                16*Zeta[3]) - 16*x^3*(41 + 28*Zeta[3]) - x^4*(73 + 
                64*Zeta[3]) + x^6*(73 + 64*Zeta[3]) - x^2*(73 + 
                160*Zeta[3])))/(864*(-1 + x^2)^2))))
 
CbarLData["a", 2, 0] = 
    NC*(CA*CF*((Pi^2*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2}, x])/
         (27*(-1 + x^2)^2) - (Pi^2*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{2}, x])/(27*(-1 + x^2)^2) + 
        (x^2*(18 + 36*x + 54*x^2 - 309*x^3 - 96*x^4 + 171*x^5 + 134*x^6 - 
           27*x^7 - 78*x^8 - 15*x^9 + 20*x^10 + 8*x^11)*HPL[{-2, 0}, x])/
         (27*(-1 + x^2)^4) + ((-24 - 60*x + 9*x^2 + (293 + 6*Pi^2)*x^3 + 
           2*(374 + 9*Pi^2)*x^4 - (311 + 30*Pi^2)*x^5 - 1058*x^6 + 
           (-311 + 30*Pi^2)*x^7 + (748 - 18*Pi^2)*x^8 + (293 - 6*Pi^2)*x^9 + 
           9*x^10 - 60*x^11 - 24*x^12)*HPL[{-1, 0}, x])/
         (162*x^3*(-1 + x^2)^3) + (x^2*(486 - 84942*x + 37827*x^2 + 
           699990*x^3 - 298536*x^4 + 978312*x^5 + 1600633*x^6 - 160972*x^7 - 
           462668*x^8 + 10686*x^9 + 22362*x^10 - 4530*x^11 + 1080*x^12 + 
           432*x^13)*HPL[{0, 0}, x])/(162*(-1 + x^2)^4*(9 - 82*x^2 + 
           9*x^4)) + ((24 + 60*x - 9*x^2 - (293 + 6*Pi^2)*x^3 - 
           2*(374 + 9*Pi^2)*x^4 + (311 + 30*Pi^2)*x^5 + 1058*x^6 + 
           (311 - 30*Pi^2)*x^7 + 2*(-374 + 9*Pi^2)*x^8 + (-293 + 6*Pi^2)*
            x^9 - 9*x^10 + 60*x^11 + 24*x^12)*HPL[{1, 0}, x])/
         (162*x^3*(-1 + x^2)^3) + 
        lm*((-11*(4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) - 3*(1 + 36*x - 22*x^2 + 36*
                x^3 + x^4)))/(1296*(-1 + x^2)^2) + 
          (11*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x^2)^3) + 
          (11*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x^2)) - 
          (22*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
           (27*(-1 + x^2)^4) - (11*(1 + 3*x + x^2)*HPL[{1, 0}, x])/
           (27*(-1 + x^2))) - (x^2*(18 + 36*x + 54*x^2 - 309*x^3 - 96*x^4 + 
           171*x^5 + 134*x^6 - 27*x^7 - 78*x^8 - 15*x^9 + 20*x^10 + 8*x^11)*
          HPL[{2, 0}, x])/(27*(-1 + x^2)^4) - 
        (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2, -1, 0}, x])/
         (9*(-1 + x^2)^2) + (16*x^2*(-2 + 3*x + x^2)*HPL[{-2, 0, 0}, x])/
         (9*(-1 + x^2)^2) + (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-2, 1, 0}, x])/(9*(-1 + x^2)^2) + 
        (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-1, -2, 0}, x])/
         (9*(-1 + x^2)^2) + ((8 + 20*x + 9*x^2 - 18*x^3 - 24*x^4 + 42*x^5 + 
           146*x^6 + 42*x^7 - 24*x^8 - 18*x^9 + 9*x^10 + 20*x^11 + 8*x^12)*
          HPL[{-1, -1, 0}, x])/(54*x^5 - 54*x^7) - 
        ((51 + x - 179*x^2 + 152*x^3 - 119*x^4 + 28*x^5 + 7*x^6 - 44*x^7 + 
           20*x^8 + 31*x^9 - 4*x^10 - 8*x^11)*HPL[{-1, 0, 0}, x])/
         (27*(-1 + x)^4*(1 + x)^2) + ((8 + 20*x + 9*x^2 - 18*x^3 - 24*x^4 + 
           42*x^5 + 146*x^6 + 42*x^7 - 24*x^8 - 18*x^9 + 9*x^10 + 20*x^11 + 
           8*x^12)*HPL[{-1, 1, 0}, x])/(54*x^5*(-1 + x^2)) - 
        (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-1, 2, 0}, x])/
         (9*(-1 + x^2)^2) - (2*x^2*(27 - 5049*x + 2679*x^2 + 34182*x^3 - 
           35826*x^4 + 123906*x^5 + 208865*x^6 - 30821*x^7 - 72525*x^8 + 
           3906*x^9 + 12030*x^10 + 1059*x^11 - 2342*x^12 - 791*x^13 + 
           180*x^14 + 72*x^15)*HPL[{0, 0, 0}, x])/(27*(-1 + x^2)^4*
          (9 - 82*x^2 + 9*x^4)) - (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x^2)^2) + 
        ((8 + 20*x + 9*x^2 - 18*x^3 - 24*x^4 + 42*x^5 + 146*x^6 + 42*x^7 - 
           24*x^8 - 18*x^9 + 9*x^10 + 20*x^11 + 8*x^12)*HPL[{1, -1, 0}, x])/
         (54*x^5*(-1 + x^2)) + ((51 + 157*x - 7*x^2 - 200*x^3 - 99*x^4 + 
           120*x^5 + 139*x^6 + 108*x^7 + 16*x^8 - 49*x^9 - 36*x^10 - 8*x^11)*
          HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*(1 + x)^4) + 
        ((8 + 20*x + 9*x^2 - 18*x^3 - 24*x^4 + 42*x^5 + 146*x^6 + 42*x^7 - 
           24*x^8 - 18*x^9 + 9*x^10 + 20*x^11 + 8*x^12)*HPL[{1, 1, 0}, x])/
         (54*x^5 - 54*x^7) + (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x^2)^2) + 
        (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{2, -1, 0}, x])/
         (9*(-1 + x^2)^2) - (16*x^2*(-2 + 3*x + x^2)*HPL[{2, 0, 0}, x])/
         (9*(-1 + x^2)^2) - (4*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{2, 1, 0}, x])/(9*(-1 + x^2)^2) - 
        (8*(1 + 3*x + x^2)*HPL[{-1, 0, 0, 0}, x])/(9*(-1 + x^2)) + 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-1, 1, 0, 0}, x])/
         (9*(-1 + x^2)^2) + (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x^2)^2) + 
        (8*(1 + 3*x + x^2)*HPL[{1, 0, 0, 0}, x])/(9*(-1 + x^2)) - 
        ((2 + 7*x - 8*x^2 + 12*x^3 + 2*x^4 + x^5)*master3l10a[x])/
         (36*(-1 + x^2)^3) + (x*(1 + 2*x + 12*x^2 - 8*x^3 + 7*x^4 + 2*x^5)*
          master3l10b[x])/(36*(-1 + x^2)^3) + 
        ((-81 - 819*x + 795*x^2 - 264*x^3 - 129*x^4 + 43*x^5 + 7*x^6)*
          master3l8a[x])/(108*(-9 + x^2)*(-1 + x^2)^4) + 
        ((15 - 31*x - 169*x^2 + 384*x^3 + 903*x^4 - 81*x^5 - 189*x^6)*
          master3l8b[x])/(108*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        ((-135 - 450*x + 849*x^2 + 60*x^3 - 149*x^4 + 6*x^5 + 11*x^6)*
          master3l9a[x])/(36*(-9 + x^2)*(-1 + x^2)^4) + 
        ((11 + 6*x - 149*x^2 + 60*x^3 + 849*x^4 - 450*x^5 - 135*x^6)*
          master3l9b[x])/(108*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(8 + 20*x + x^2 - 38*x^3 - 33*x^4 + 60*x^5 + 
             170*x^6 - 170*x^8 - 60*x^9 + 33*x^10 + 38*x^11 - x^12 - 
             20*x^13 - 8*x^14) - 288*x^5*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
            Zeta[3]))/(648*x^5*(-1 + x^2)^2) + 
        (HPL[{-1}, x]*(Pi^2*(-8 - 20*x - x^2 + 38*x^3 + 33*x^4 - 60*x^5 - 
             170*x^6 + 170*x^8 + 60*x^9 - 33*x^10 - 38*x^11 + x^12 + 
             20*x^13 + 8*x^14) + 288*x^5*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
            Zeta[3]))/(648*x^5*(-1 + x^2)^2) + 
        (HPL[{0}, x]*(432 + 1080*x - 4314*x^2 - 12*(2230 + 27*Pi^2)*x^3 + 
           (27611 + 1980*Pi^2)*x^5 + 12*(30898 + 855*Pi^2)*x^7 - 
           2*(1238827 + 9564*Pi^2)*x^9 + 4*(198036 + 6277*Pi^2)*x^11 - 
           6*(6463 + 1206*Pi^2)*x^12 - 3*(19359 + 5188*Pi^2)*x^13 - 
           6*(72 + 353*Pi^2)*x^14 + 4684*Pi^2*x^15 + 1582*Pi^2*x^16 - 
           360*Pi^2*x^17 - 144*Pi^2*x^18 - 6*x^4*(-25021 + 108*Pi^2 + 
             3888*Zeta[3]) + 6*x^10*(98447 + 5682*Pi^2 + 3888*Zeta[3]) + 
           2*x^6*(-651148 + 5733*Pi^2 + 117936*Zeta[3]) - 
           2*x^8*(866990 + 27201*Pi^2 + 117936*Zeta[3])))/
         (648*x*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4)) + 
        (48*Pi^4*x^3*(-1 + x^2)^2*(-27 - 81*x + 66*x^2 + 1089*x^3 + 
            1730*x^4 - 3279*x^5 - 1246*x^6 + 351*x^7 + 117*x^8) + 
          40*Pi^2*(-216 - 540*x + 2265*x^2 + 8097*x^3 + 3729*x^4 - 
            34922*x^5 - 76555*x^6 + 52705*x^7 + 170997*x^8 - 170997*x^10 - 
            52705*x^11 + 76555*x^12 + 34922*x^13 - 3729*x^14 - 8097*x^15 - 
            2265*x^16 + 540*x^17 + 216*x^18) + 
          15*x^2*(-864 + x^6*(9692024 - 1586256*Zeta[3]) + 
            x^3*(1308406 - 378720*Zeta[3]) - 112416*x^15*Zeta[3] - 
            37968*x^16*Zeta[3] + 8640*x^17*Zeta[3] + 3456*x^18*Zeta[3] + 
            144*x^14*(-6 + 353*Zeta[3]) + 45*x*(-1817 + 576*Zeta[3]) - 
            48*x^2*(6253 + 639*Zeta[3]) + 48*x^12*(4817 + 3573*Zeta[3]) + 
            45*x^13*(1891 + 9088*Zeta[3]) + 24*x^4*(71881 + 18430*Zeta[3]) - 
            24*x^10*(102719 + 30698*Zeta[3]) + 8*x^8*(394483 + 
              110994*Zeta[3]) + 4*x^7*(-68983 + 179304*Zeta[3]) + 
            3*x^5*(-1590085 + 402432*Zeta[3]) - 2*x^11*(588157 + 
              547344*Zeta[3]) + 3*x^9*(1297295 + 632192*Zeta[3])))/
         (77760*x^3*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4))) + 
      CF^2*((-2*Pi^2*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2}, x])/
         (27*(-1 + x^2)^2) + (2*Pi^2*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{2}, x])/(27*(-1 + x^2)^2) + 
        (x^2*(-36 - 24*x - 132*x^2 + 786*x^3 + 204*x^4 - 658*x^5 - 486*x^6 + 
           337*x^7 + 519*x^8 - 23*x^9 - 285*x^10 - 73*x^11 + 63*x^12 + 
           27*x^13)*HPL[{-2, 0}, x])/(27*(-1 + x^2)^4) + 
        ((-108 - 252*x + 130*x^2 + 762*x^3 + 332*x^4 - (735 + 16*Pi^2)*x^5 - 
           2*(107 + 24*Pi^2)*x^6 + (531 + 80*Pi^2)*x^7 - 1768*x^8 + 
           (531 - 80*Pi^2)*x^9 + (-214 + 48*Pi^2)*x^10 + (-735 + 16*Pi^2)*
            x^11 + 332*x^12 + 762*x^13 + 130*x^14 - 252*x^15 - 108*x^16)*
          HPL[{-1, 0}, x])/(216*x^5*(-1 + x^2)^3) + 
        (x^2*(-2412 + 69444*x - 22538*x^2 - 539634*x^3 + 286706*x^4 - 
           1311030*x^5 - 2100677*x^6 + 323352*x^7 + 561810*x^8 - 4856*x^9 + 
           47481*x^10 + 18670*x^11 - 29790*x^12 - 10998*x^13 + 2268*x^14 + 
           972*x^15)*HPL[{0, 0}, x])/(108*(-1 + x^2)^4*(9 - 82*x^2 + 
           9*x^4)) + ((108 + 252*x - 130*x^2 - 762*x^3 - 332*x^4 + 
           (735 + 16*Pi^2)*x^5 + (214 + 48*Pi^2)*x^6 - (531 + 80*Pi^2)*x^7 + 
           1768*x^8 + (-531 + 80*Pi^2)*x^9 + (214 - 48*Pi^2)*x^10 + 
           (735 - 16*Pi^2)*x^11 - 332*x^12 - 762*x^13 - 130*x^14 + 252*x^15 + 
           108*x^16)*HPL[{1, 0}, x])/(216*x^5*(-1 + x^2)^3) + 
        (x^2*(36 + 24*x + 132*x^2 - 786*x^3 - 204*x^4 + 658*x^5 + 486*x^6 - 
           337*x^7 - 519*x^8 + 23*x^9 + 285*x^10 + 73*x^11 - 63*x^12 - 
           27*x^13)*HPL[{2, 0}, x])/(27*(-1 + x^2)^4) + 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2, -1, 0}, x])/
         (9*(-1 + x^2)^2) - (16*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x^2)^2) - 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{-2, 1, 0}, x])/
         (9*(-1 + x^2)^2) - (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x^2)^2) + 
        ((27 + 63*x + 35*x^2 - 33*x^3 - 45*x^4 + 9*x^5 + 55*x^6 - 55*x^8 - 
           9*x^9 + 45*x^10 + 33*x^11 - 35*x^12 - 63*x^13 - 27*x^14)*
          HPL[{-1, -1, 0}, x])/(54*x^7) + 
        ((101 - 55*x - 106*x^2 - 218*x^3 + 263*x^4 + 17*x^5 - 172*x^6 - 
           184*x^7 + 155*x^8 + 211*x^9 - 58*x^10 - 118*x^11 + 9*x^12 + 
           27*x^13)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^2) + 
        ((-27 - 63*x - 35*x^2 + 33*x^3 + 45*x^4 - 9*x^5 - 55*x^6 + 55*x^8 + 
           9*x^9 - 45*x^10 - 33*x^11 + 35*x^12 + 63*x^13 + 27*x^14)*
          HPL[{-1, 1, 0}, x])/(54*x^7) + (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-1, 2, 0}, x])/(9*(-1 + x^2)^2) - 
        (2*x^2*(270 + 9342*x + 2796*x^2 - 89910*x^3 - 78174*x^4 + 
           130956*x^5 + 552146*x^6 - 416260*x^7 - 628902*x^8 + 159854*x^9 + 
           235426*x^10 - 41508*x^11 - 87402*x^12 - 1760*x^13 + 36339*x^14 + 
           8893*x^15 - 8298*x^16 - 3114*x^17 + 567*x^18 + 243*x^19)*
          HPL[{0, 0, 0}, x])/(27*(-1 + x^2)^5*(9 - 82*x^2 + 9*x^4)) + 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{1, -2, 0}, x])/
         (9*(-1 + x^2)^2) + ((-27 - 63*x - 35*x^2 + 33*x^3 + 45*x^4 - 9*x^5 - 
           55*x^6 + 55*x^8 + 9*x^9 - 45*x^10 - 33*x^11 + 35*x^12 + 63*x^13 + 
           27*x^14)*HPL[{1, -1, 0}, x])/(54*x^7) - 
        ((101 + 253*x + 2*x^2 - 382*x^3 - 469*x^4 + 121*x^5 + 548*x^6 + 
           368*x^7 - 197*x^8 - 425*x^9 - 134*x^10 + 134*x^11 + 117*x^12 + 
           27*x^13)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*(1 + x)^4) + 
        ((27 + 63*x + 35*x^2 - 33*x^3 - 45*x^4 + 9*x^5 + 55*x^6 - 55*x^8 - 
           9*x^9 + 45*x^10 + 33*x^11 - 35*x^12 - 63*x^13 - 27*x^14)*
          HPL[{1, 1, 0}, x])/(54*x^7) - (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x^2)^2) - 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{2, -1, 0}, x])/
         (9*(-1 + x^2)^2) + (16*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{2, 0, 0}, x])/(9*(-1 + x^2)^2) + 
        (8*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{2, 1, 0}, x])/
         (9*(-1 + x^2)^2) - (16*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x^2)^2) - 
        (16*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*HPL[{1, -1, 0, 0}, x])/
         (9*(-1 + x^2)^2) + ((2 + 7*x - 8*x^2 + 12*x^3 + 2*x^4 + x^5)*
          master3l10a[x])/(18*(-1 + x^2)^3) - 
        (x*(1 + 2*x + 12*x^2 - 8*x^3 + 7*x^4 + 2*x^5)*master3l10b[x])/
         (18*(-1 + x^2)^3) + ((81 + 819*x - 795*x^2 + 264*x^3 + 129*x^4 - 
           43*x^5 - 7*x^6)*master3l8a[x])/(54*(-9 + x^2)*(-1 + x^2)^4) + 
        ((-15 + 31*x + 169*x^2 - 384*x^3 - 903*x^4 + 81*x^5 + 189*x^6)*
          master3l8b[x])/(54*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        ((135 + 450*x - 849*x^2 - 60*x^3 + 149*x^4 - 6*x^5 - 11*x^6)*
          master3l9a[x])/(18*(-9 + x^2)*(-1 + x^2)^4) + 
        ((-11 - 6*x + 149*x^2 - 60*x^3 - 849*x^4 + 450*x^5 + 135*x^6)*
          master3l9b[x])/(54*(-1 + x^2)^4*(-1 + 9*x^2)) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(27 + 63*x + 62*x^2 + 30*x^3 + 
             17*x^4 + 39*x^5 + 72*x^6 + 39*x^7 + 17*x^8 + 30*x^9 + 62*x^10 + 
             63*x^11 + 27*x^12) - 576*x^7*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
            Zeta[3]))/(648*x^7*(-1 + x^2)^2) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(27 + 63*x + 62*x^2 + 30*x^3 + 
              17*x^4 + 39*x^5 + 72*x^6 + 39*x^7 + 17*x^8 + 30*x^9 + 62*x^10 + 
              63*x^11 + 27*x^12)) + 576*x^7*(1 + 3*x - 4*x^2 + 3*x^3 + x^4)*
            Zeta[3]))/(648*x^7*(-1 + x^2)^2) + 
        (HPL[{0}, x]*(2916 + 6804*x - 31536*x^2 - 85968*x^3 + 40485*x^4 + 
           9*(33467 + 144*Pi^2)*x^5 - 6*(38797 + 1176*Pi^2)*x^7 - 
           24*(50235 + 2056*Pi^2)*x^9 + (9717342 + 89160*Pi^2)*x^11 - 
           27*(123089 + 6868*Pi^2)*x^13 + (89115 + 135052*Pi^2)*x^14 + 
           12*(26064 + 16499*Pi^2)*x^15 - 8*(-3942 + 2131*Pi^2)*x^16 - 
           12*(567 + 9536*Pi^2)*x^17 - 4*(729 + 6022*Pi^2)*x^18 + 
           30924*Pi^2*x^19 + 11484*Pi^2*x^20 - 2268*Pi^2*x^21 - 
           972*Pi^2*x^22 + 9*x^6*(-62581 + 96*Pi^2 + 10368*Zeta[3]) - 
           6*x^8*(-946879 + 6028*Pi^2 + 157248*Zeta[3]) + 
           6*x^10*(1012361 + 47060*Pi^2 + 157248*Zeta[3]) - 
           x^12*(256252*Pi^2 + 729*(2699 + 128*Zeta[3]))))/
         (1296*x^3*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4)) + 
        (-64*Pi^4*x^5*(-1 + x^2)^2*(9 + 27*x - 118*x^2 - 219*x^3 + 346*x^4 - 
            219*x^5 - 118*x^6 + 27*x^7 + 9*x^8) + 
          4*Pi^2*(-972 - 2268*x + 10998*x^2 + 29790*x^3 - 18670*x^4 - 
            98889*x^5 - 19336*x^6 + 143274*x^7 + 32604*x^8 - 117285*x^9 + 
            136500*x^10 - 136500*x^12 + 117285*x^13 - 32604*x^14 - 
            143274*x^15 + 19336*x^16 + 98889*x^17 + 18670*x^18 - 29790*x^19 - 
            10998*x^20 + 2268*x^21 + 972*x^22) + 
          x^2*(-5832 - 13608*x + 65016*x^2 - 742176*x^19*Zeta[3] - 
            275616*x^20*Zeta[3] + 54432*x^21*Zeta[3] + 23328*x^22*Zeta[3] - 
            48*x^4*(-36811 + 1782*Zeta[3]) + 24*x^16*(2709 + 17048*Zeta[3]) - 
            9*x^3*(-56615 + 17568*Zeta[3]) + 16*x^6*(-841013 + 
              22626*Zeta[3]) + 24*x^18*(-243 + 24088*Zeta[3]) + 
            72*x^17*(-189 + 38144*Zeta[3]) - 48*x^14*(7469 + 69308*Zeta[3]) - 
            48*x^10*(139373 + 75948*Zeta[3]) + 48*x^8*(-684053 + 
              83316*Zeta[3]) - 12*x^9*(634843 + 94592*Zeta[3]) - 
            39*x^7*(-622855 + 176576*Zeta[3]) - 33*x^11*(313855 + 
              278656*Zeta[3]) + 16*x^12*(206587 + 408300*Zeta[3]) - 
            9*x^15*(17545 + 545536*Zeta[3]) + x^5*(-6251894 + 
              2213856*Zeta[3]) + x^13*(3686986 + 6695424*Zeta[3])))/
         (10368*x^5*(-1 + x^2)^4*(9 - 82*x^2 + 9*x^4))) + 
      CF*(NH*((x*(-2592 - 19728*x - 430128*x^2 - 114871*x^3 + 64570*x^4 + 
             6624*x^5 - 4322*x^6 + 4382*x^7 - 74*x^8 - 592*x^9 + 66*x^10 + 
             25*x^11)*HPL[{0}, x])/(216*(-9 + x^2)*(-1 + x^2)^5) + 
          (x*(648 + 3060*x + 77256*x^2 + 18407*x^3 - 19194*x^4 - 1708*x^5 - 
             1278*x^6 - 640*x^7 + 162*x^8 + 84*x^9 + 6*x^10 - 3*x^11)*
            HPL[{0, 0}, x])/(54*(-9 + x^2)*(-1 + x^2)^5) + 
          lm*((4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) - 3*(1 + 36*x - 22*x^2 + 
                36*x^3 + x^4))/(648*(-1 + x^2)^2) - 
            (2*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x^2)^3) - 
            (2*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x^2)) + 
            (4*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x^2)^4) + (2*(1 + 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x^2))) - (2*(-13 + 188*x - 61*x^2 + 52*x^3 - 10*x^4 + 
             2*x^5 + 2*x^6)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^2) + 
          (4*x^3*(-2646 - 549*x + 549*x^2 - 108*x^3 + 219*x^4 + 24*x^5 - 
             45*x^6 - 8*x^7 + 3*x^8 + x^9)*HPL[{0, 0, 0}, x])/
           (27*(-9 + x^2)*(-1 + x^2)^5) + (2*(-31 + 100*x + 65*x^2 + 20*x^3 + 
             14*x^4 + 10*x^5 + 2*x^6)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*
            (1 + x)^4) - ((189 + 3798*x + 1044*x^2 + 18*x^3 + 66*x^4 + 
             26*x^5 - 20*x^6 - 2*x^7 + x^8)*master3l8a[x])/
           (54*(-9 + x^2)*(-1 + x^2)^5) - ((567 + 6102*x + 2034*x^2 + 
             1152*x^3 - 18*x^4 + 516*x^5 - 12*x^6 - 96*x^7 - 13*x^8 + 6*x^9 + 
             2*x^10)*master3l9a[x])/(54*(-9 + x^2)*(-1 + x^2)^5) + 
          (76302 + x^2*(395631 - 19968*Zeta[3]) + x^9*(1271 - 5376*Zeta[3]) + 
            x^10*(3255 - 768*Zeta[3]) - 22464*Zeta[3] + 
            x^12*(-135 + 64*Zeta[3]) + x^11*(-515 + 192*Zeta[3]) + 
            4*x^8*(-5643 + 752*Zeta[3]) + 27*x*(40457 + 832*Zeta[3]) - 
            6*x^6*(5841 + 2944*Zeta[3]) + 6*x^7*(5683 + 2976*Zeta[3]) + 
            6*x^5*(-63735 + 25952*Zeta[3]) + x^4*(388965 + 57792*Zeta[3]) - 
            3*x^3*(-558139 + 63616*Zeta[3]))/(1296*(-9 + x^2)*
            (-1 + x^2)^5)) + 
        NM*(((-8*Pi^2*(-1 + x^2)^4*(-1 - 3*x + 8*x^2 + 27*x^3 + 9*x^4) + 
             3*(152 + 456*x - 796*x^2 - 6748*x^3 - 847*x^4 + 28838*x^5 - 7304*
                x^6 + 142394*x^7 + 15966*x^8 + 151650*x^9 + 80116*x^10 + 
               55890*x^11 + 36873*x^12))*HPL[{0}, x])/(648*(-1 + x^2)^5*
            (-1 + 9*x^2)) + (4*(1 + 3*x + x^2)*HPL[{-2, 0}, x])/
           (27*(-1 + x^2)) - ((24 + 72*x + 16*x^2 - 756*x^3 - 1167*x^4 - 
             2010*x^5 + 108*x^6 + 66378*x^7 - 4936*x^8 + 96354*x^9 + 
             45720*x^10 + 35802*x^11 + 25515*x^12)*HPL[{0, 0}, x])/
           (54*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          lm*((4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) - 3*(1 + 36*x - 22*x^2 + 
                36*x^3 + x^4))/(648*(-1 + x^2)^2) - 
            (2*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x^2)^3) - 
            (2*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x^2)) + 
            (4*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x^2)^4) + (2*(1 + 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x^2))) - (4*(1 + 3*x + x^2)*HPL[{2, 0}, x])/
           (27*(-1 + x^2)) + (2*(-6 - 6*x + 30*x^2 - 52*x^3 + 41*x^4 - 
             184*x^5 + 17*x^6)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^4*
            (1 + x)^2) + (4*(1 + 3*x + 20*x^2 + 3*x^3 - 191*x^4 - 939*x^5 + 
             116*x^6 + 7371*x^7 - 2061*x^8 + 21456*x^9 + 9424*x^10 + 
             8586*x^11 + 4851*x^12)*HPL[{0, 0, 0}, x])/(27*(-1 + x^2)^5*
            (-1 + 9*x^2)) + ((12 + 60*x + 84*x^2 + 40*x^3 + 74*x^4 + 
             160*x^5 - 70*x^6)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^2*(1 + x)^4) + 
          ((4 + 12*x - 29*x^2 - 186*x^3 + 36*x^4 + 954*x^5 - 234*x^6 + 
             2250*x^7 + 936*x^8 + 810*x^9 + 567*x^10)*master3l8b[x])/
           (162*x^2*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          ((2 + 6*x - 13*x^2 - 96*x^3 - 12*x^4 + 516*x^5 - 18*x^6 + 
             1152*x^7 + 2034*x^8 + 6102*x^9 + 567*x^10)*master3l9b[x])/
           (162*x^2*(-1 + x^2)^5*(-1 + 9*x^2)) + 
          (30 + 90*x + x^8*(2124 - 17664*Zeta[3]) + 
            x^5*(30881 - 5376*Zeta[3]) + x^4*(5805 - 768*Zeta[3]) + 
            x^2*(-810 + 64*Zeta[3]) + x^3*(-3395 + 192*Zeta[3]) + 
            27*x^13*(-3613 + 832*Zeta[3]) - 27*x^14*(1269 + 832*Zeta[3]) + 
            6*x^7*(-8957 + 2976*Zeta[3]) + x^6*(-17427 + 3008*Zeta[3]) + 
            12*x^10*(-7265 + 4816*Zeta[3]) - 3*x^12*(45693 + 6656*Zeta[3]) + 
            12*x^9*(-55665 + 12976*Zeta[3]) - 3*x^11*(4901 + 63616*Zeta[3]))/
           (1296*x^2*(-1 + x^2)^5*(-1 + 9*x^2))) + 
        NL*(-(Pi^2*(1 + 3*x + x^2)*HPL[{-1}, x])/(81*(-1 + x^2)) + 
          (x^2*(18 + 12*(29 + 6*Pi^2)*x + 69*x^2 + 12*(-38 + 3*Pi^2)*x^3 - 
             2*(45 + 4*Pi^2)*x^4 + 12*(9 + Pi^2)*x^5 + (3 + 4*Pi^2)*x^6)*
            HPL[{0}, x])/(324*(-1 + x^2)^4) + (Pi^2*(1 + 3*x + x^2)*
            HPL[{1}, x])/(81*(-1 + x^2)) - (4*x^3*(18 + 9*x^2 - 2*x^3 + 
             3*x^4 + x^5)*HPL[{-2, 0}, x])/(27*(-1 + x^2)^4) + 
          ((-3 - 14*x + x^2 + 148*x^3 + x^4 - 14*x^5 - 3*x^6)*
            HPL[{-1, 0}, x])/(54*(-1 + x^2)^3) + 
          (x^3*(120 + 6*x^2 + 4*x^3 + 14*x^4 + 3*x^5)*HPL[{0, 0}, x])/
           (27*(-1 + x^2)^4) - ((-3 - 14*x + x^2 + 148*x^3 + x^4 - 14*x^5 - 
             3*x^6)*HPL[{1, 0}, x])/(54*(-1 + x^2)^3) + 
          lm*((4*Pi^2*(-1 - 3*x + 3*x^3 + x^4) - 3*(1 + 36*x - 22*x^2 + 
                36*x^3 + x^4))/(648*(-1 + x^2)^2) - 
            (2*x^2*(1 + 6*x + x^2)*HPL[{0}, x])/(27*(-1 + x^2)^3) - 
            (2*(1 + 3*x + x^2)*HPL[{-1, 0}, x])/(27*(-1 + x^2)) + 
            (4*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0}, x])/
             (27*(-1 + x^2)^4) + (2*(1 + 3*x + x^2)*HPL[{1, 0}, x])/
             (27*(-1 + x^2))) + (4*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*
            HPL[{2, 0}, x])/(27*(-1 + x^2)^4) + 
          (4*(1 + 3*x + x^2)*HPL[{-1, -1, 0}, x])/(27*(-1 + x^2)) - 
          (4*(1 + 3*x + x^2)*HPL[{-1, 1, 0}, x])/(27*(-1 + x^2)) - 
          (8*x^3*(18 + 9*x^2 - 2*x^3 + 3*x^4 + x^5)*HPL[{0, 0, 0}, x])/
           (27*(-1 + x^2)^4) - (4*(1 + 3*x + x^2)*HPL[{1, -1, 0}, x])/
           (27*(-1 + x^2)) + (4*(1 + 3*x + x^2)*HPL[{1, 1, 0}, x])/
           (27*(-1 + x^2)) + (4*Pi^2*(-3 - 14*x + 4*x^2 + 162*x^3 - 162*x^5 - 
              4*x^6 + 14*x^7 + 3*x^8) - 3*(15 + 338*x^4 - 184*x^6 + 360*x^7 + 
              15*x^8 - 64*Zeta[3] - 24*x*(-15 + 8*Zeta[3]) - 
              72*x^3*(5 + 8*Zeta[3]) + 8*x^2*(-23 + 16*Zeta[3]) - 
              72*x^5*(5 + 16*Zeta[3])))/(2592*(-1 + x^2)^4))))
 
CbarLData["a", 2, 1] = 
    NC*(CA*CF*((Pi^2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-2}, x])/(108*(-1 + x^2)^4) + 
        lm^2*((-11*(1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6))/
           (288*(-1 + x^2)^4) + (11*x^3*(2 - x + 2*x^2)*HPL[{0}, x])/
           (12*(-1 + x^2)^5)) - (Pi^2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{2}, x])/(108*(-1 + x^2)^4) + 
        (x*(-3 + 165*x + 6*x^2 + 789*x^3 - 5754*x^4 + 461*x^5 + 1310*x^6 + 
           2175*x^7 - 1582*x^8 - 3313*x^9 + 540*x^10 + 2682*x^11 + 372*x^12 - 
           1110*x^13 - 348*x^14 + 189*x^15 + 81*x^16)*HPL[{-2, 0}, x])/
         (216*(-1 + x^2)^6) + ((-1620 - 3780*x + 4530*x^2 + 16530*x^3 + 
           30*x^4 + (-24331 + 80*Pi^2)*x^5 + 80*(69 + 4*Pi^2)*x^6 + 
           (8784 - 1600*Pi^2)*x^7 + 40*(1133 + 104*Pi^2)*x^8 - 35166*x^9 + 
           (45320 - 4160*Pi^2)*x^10 + 16*(549 + 100*Pi^2)*x^11 - 
           80*(-69 + 4*Pi^2)*x^12 - (24331 + 80*Pi^2)*x^13 + 30*x^14 + 
           16530*x^15 + 4530*x^16 - 3780*x^17 - 1620*x^18)*HPL[{-1, 0}, x])/
         (8640*x^5*(-1 + x^2)^5) + (x*(-14580 + 2165292*x - 19896030*x^2 - 
           21856833*x^3 + 294211440*x^4 - 82997683*x^5 - 376333390*x^6 + 
           1348334612*x^7 - 5464656740*x^8 - 3527388452*x^9 - 
           2746622870*x^10 + 1456475729*x^11 - 454371390*x^12 - 
           661341095*x^13 + 271517850*x^14 - 27492126*x^15 - 66953460*x^16 + 
           49956750*x^17 + 20597220*x^18 - 7224390*x^19 - 2889270*x^20 + 
           306180*x^21 + 131220*x^22)*HPL[{0, 0}, x])/(4320*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) + ((1620 + 3780*x - 4530*x^2 - 16530*x^3 - 
           30*x^4 + (24331 - 80*Pi^2)*x^5 - 80*(69 + 4*Pi^2)*x^6 + 
           16*(-549 + 100*Pi^2)*x^7 - 40*(1133 + 104*Pi^2)*x^8 + 35166*x^9 + 
           40*(-1133 + 104*Pi^2)*x^10 - 16*(549 + 100*Pi^2)*x^11 + 
           80*(-69 + 4*Pi^2)*x^12 + (24331 + 80*Pi^2)*x^13 - 30*x^14 - 
           16530*x^15 - 4530*x^16 + 3780*x^17 + 1620*x^18)*HPL[{1, 0}, x])/
         (8640*x^5*(-1 + x^2)^5) + 
        lm*(-(44*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 
             3*(161 - 16*x + 39*x^2 + 6528*x^3 + 39*x^4 - 16*x^5 + 161*x^6))/
           (5184*(-1 + x^2)^4) + (x^2*(22 + 2506*x - 879*x^2 + 3694*x^3 - 
             242*x^4 + 132*x^5 + 33*x^6)*HPL[{0}, x])/(216*(-1 + x^2)^5) + 
          (11*(1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0}, x])/(108*(-1 + x^2)^3) - 
          (11*x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*x^5 + 4*x^6 + 
             x^7)*HPL[{0, 0}, x])/(54*(-1 + x^2)^6) - 
          (11*(1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/(108*(-1 + x^2)^3)) - 
        (x*(-3 + 165*x + 6*x^2 + 789*x^3 - 5754*x^4 + 461*x^5 + 1310*x^6 + 
           2175*x^7 - 1582*x^8 - 3313*x^9 + 540*x^10 + 2682*x^11 + 372*x^12 - 
           1110*x^13 - 348*x^14 + 189*x^15 + 81*x^16)*HPL[{2, 0}, x])/
         (216*(-1 + x^2)^6) - ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + 
           x^6)*HPL[{-2, -1, 0}, x])/(9*(-1 + x^2)^4) + 
        (4*x^2*(-9 + 28*x - 10*x^2 + 4*x^3 + x^4)*HPL[{-2, 0, 0}, x])/
         (9*(-1 + x^2)^4) + ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + 
           x^6)*HPL[{-2, 1, 0}, x])/(9*(-1 + x^2)^4) + 
        ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x^2)^4) - 
        ((81 + 189*x - 105*x^2 - 543*x^3 - 186*x^4 + 486*x^5 + 378*x^6 + 
           7*x^7 + 184*x^8 - 102*x^9 + 184*x^10 + 7*x^11 + 378*x^12 + 
           486*x^13 - 186*x^14 - 543*x^15 - 105*x^16 + 189*x^17 + 81*x^18)*
          HPL[{-1, -1, 0}, x])/(432*x^7*(-1 + x^2)^3) + 
        ((797 - 809*x - 2299*x^2 + 7267*x^3 - 865*x^4 + 4747*x^5 + 221*x^6 + 
           4951*x^7 - 2533*x^8 - 7875*x^9 + 2295*x^10 + 5985*x^11 - 
           855*x^12 - 2415*x^13 + 135*x^14 + 405*x^15)*HPL[{-1, 0, 0}, x])/
         (1080*(-1 + x)^6*(1 + x)^4) + ((81 + 189*x - 105*x^2 - 543*x^3 - 
           186*x^4 + 486*x^5 + 378*x^6 + 7*x^7 + 184*x^8 - 102*x^9 + 
           184*x^10 + 7*x^11 + 378*x^12 + 486*x^13 - 186*x^14 - 543*x^15 - 
           105*x^16 + 189*x^17 + 81*x^18)*HPL[{-1, 1, 0}, x])/
         (432*x^7*(-1 + x^2)^3) - ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{-1, 2, 0}, x])/(9*(-1 + x^2)^4) - 
        (x*(-1215 + 57105*x - 3662550*x^2 + 3206655*x^3 + 45744330*x^4 - 
           80230173*x^5 + 70296690*x^6 + 612033039*x^7 - 1595727840*x^8 - 
           1810115311*x^9 - 498635290*x^10 + 1016478681*x^11 - 
           439968730*x^12 - 715901371*x^13 + 154641870*x^14 + 
           323189703*x^15 + 15419505*x^16 - 125149782*x^17 - 30212160*x^18 + 
           31570560*x^19 + 11015460*x^20 - 3688740*x^21 - 1477440*x^22 + 
           153090*x^23 + 65610*x^24)*HPL[{0, 0, 0}, x])/(1080*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) - ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{1, -2, 0}, x])/(9*(-1 + x^2)^4) + 
        ((81 + 189*x - 105*x^2 - 543*x^3 - 186*x^4 + 486*x^5 + 378*x^6 + 
           7*x^7 + 184*x^8 - 102*x^9 + 184*x^10 + 7*x^11 + 378*x^12 + 
           486*x^13 - 186*x^14 - 543*x^15 - 105*x^16 + 189*x^17 + 81*x^18)*
          HPL[{1, -1, 0}, x])/(432*x^7*(-1 + x^2)^3) - 
        ((797 + 2859*x + 3721*x^2 + 4203*x^3 + 9015*x^4 + 1263*x^5 - 
           4679*x^6 - 2721*x^7 + 8747*x^8 + 12705*x^9 + 675*x^10 - 
           8655*x^11 - 4575*x^12 + 1365*x^13 + 1755*x^14 + 405*x^15)*
          HPL[{1, 0, 0}, x])/(1080*(-1 + x)^4*(1 + x)^6) - 
        ((81 + 189*x - 105*x^2 - 543*x^3 - 186*x^4 + 486*x^5 + 378*x^6 + 
           7*x^7 + 184*x^8 - 102*x^9 + 184*x^10 + 7*x^11 + 378*x^12 + 
           486*x^13 - 186*x^14 - 543*x^15 - 105*x^16 + 189*x^17 + 81*x^18)*
          HPL[{1, 1, 0}, x])/(432*x^7*(-1 + x^2)^3) + 
        ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, 2, 0}, x])/(9*(-1 + x^2)^4) + 
        ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x^2)^4) - 
        (4*x^2*(-9 + 28*x - 10*x^2 + 4*x^3 + x^4)*HPL[{2, 0, 0}, x])/
         (9*(-1 + x^2)^4) - ((1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + 
           x^6)*HPL[{2, 1, 0}, x])/(9*(-1 + x^2)^4) - 
        (2*(1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0, 0, 0}, x])/(9*(-1 + x^2)^3) + 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x^2)^4) + 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x^2)^4) + 
        (2*(1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0, 0, 0}, x])/(9*(-1 + x^2)^3) - 
        ((2 + 11*x - 31*x^2 + 177*x^3 - 76*x^4 + 73*x^5 + 9*x^6 + 3*x^7)*
          master3l10a[x])/(144*(-1 + x^2)^5) + 
        (x*(3 + 9*x + 73*x^2 - 76*x^3 + 177*x^4 - 31*x^5 + 11*x^6 + 2*x^7)*
          master3l10b[x])/(144*(-1 + x^2)^5) + 
        ((-78489 + 266355*x - 335988*x^2 + 795960*x^3 - 323646*x^4 - 
           63690*x^5 + 88764*x^6 - 17120*x^7 - 6641*x^8 + 1535*x^9 + 
           128*x^10)*master3l8a[x])/(4320*(-9 + x^2)^2*(-1 + x^2)^6) + 
        ((10 - 638*x + 1425*x^2 + 13729*x^3 - 29180*x^4 - 124352*x^5 + 
           127290*x^6 + 475446*x^7 + 85770*x^8 - 105786*x^9 + 111645*x^10 + 
           68769*x^11)*master3l8b[x])/(4320*x*(1 - 9*x^2)^2*(-1 + x^2)^6) + 
        ((8181 - 8595*x + 13698*x^2 - 40410*x^3 + 45916*x^4 + 6120*x^5 - 
           6738*x^6 + 10*x^7 + 383*x^8 - 5*x^9)*master3l9a[x])/
         (1440*(-9 + x^2)*(-1 + x^2)^6) + 
        ((-5 + 383*x + 10*x^2 - 6738*x^3 + 6120*x^4 + 45916*x^5 - 40410*x^6 + 
           13698*x^7 - 8595*x^8 + 8181*x^9)*master3l9b[x])/
         (4320*x*(-1 + x^2)^6*(-1 + 9*x^2)) + 
        (HPL[{1}, x]*(Pi^2*(81 + 189*x - 186*x^2 - 732*x^3 - 81*x^4 + 
             1029*x^5 + 564*x^6 - 479*x^7 - 194*x^8 - 109*x^9 + 109*x^11 + 
             194*x^12 + 479*x^13 - 564*x^14 - 1029*x^15 + 81*x^16 + 
             732*x^17 + 186*x^18 - 189*x^19 - 81*x^20) - 
           576*x^7*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
            Zeta[3]))/(5184*x^7*(-1 + x^2)^4) + 
        (HPL[{-1}, x]*(Pi^2*(-81 - 189*x + 186*x^2 + 732*x^3 + 81*x^4 - 
             1029*x^5 - 564*x^6 + 479*x^7 + 194*x^8 + 109*x^9 - 109*x^11 - 
             194*x^12 - 479*x^13 + 564*x^14 + 1029*x^15 - 81*x^16 - 
             732*x^17 - 186*x^18 + 189*x^19 + 81*x^20) + 
           576*x^7*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
            Zeta[3]))/(5184*x^7*(-1 + x^2)^4) + 
        (HPL[{0}, x]*(393660 + 918540*x - 8470980*x^2 - 21213900*x^3 + 
           405*(142879 + 12*Pi^2)*x^4 - 243*(-513079 + 1100*Pi^2)*x^5 + 
           150*(186761105 + 5559046*Pi^2)*x^12 - 216*(4261087 + 2332230*Pi^2)*
            x^19 + (2065095 - 43132380*Pi^2)*x^20 + 
           15*(4117311 + 16199212*Pi^2)*x^21 + 60*(141183 + 1007072*Pi^2)*
            x^22 - 34020*(27 + 1856*Pi^2)*x^23 - 540*(729 + 40798*Pi^2)*
            x^24 + 7377480*Pi^2*x^25 + 2954880*Pi^2*x^26 - 306180*Pi^2*x^27 - 
           131220*Pi^2*x^28 + 10*x^13*(882854985 + 2910812*Pi^2 - 
             86697216*Zeta[3]) + 20*x^16*(52902375 + 14060194*Pi^2 - 
             15303168*Zeta[3]) - 12*x^15*(375783054 + 32446255*Pi^2 - 
             13452480*Zeta[3]) + 20*x^17*(217112874 + 30034819*Pi^2 - 
             419904*Zeta[3]) - 90*x^18*(8028935 + 1240516*Pi^2 - 
             186624*Zeta[3]) + 180*x^7*(882815 + 19959*Pi^2 + 
             46656*Zeta[3]) - 90*x^6*(923281 + 1092*Pi^2 + 186624*Zeta[3]) + 
           60*x^8*(-7921179 + 165196*Pi^2 + 5101056*Zeta[3]) - 
           12*x^9*(192759431 + 14945*Pi^2 + 13452480*Zeta[3]) - 
           30*x^10*(72129745 + 5763172*Pi^2 + 47036160*Zeta[3]) + 
           x^11*(812707740 - 93705060*Pi^2 + 866972160*Zeta[3]) + 
           x^14*(-397856440*Pi^2 + 30*(403031513 + 47036160*Zeta[3]))))/
         (51840*x^3*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        (64*Pi^4*x^5*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(-3 - 12*x - 87*x^2 + 
            280*x^3 - 103*x^4 + 52*x^5 + 13*x^6) + 
          4*Pi^2*(9 - 82*x^2 + 9*x^4)^2*(-1620 - 3780*x + 6150*x^2 + 
            20310*x^3 - 4500*x^4 - 40861*x^5 + 5490*x^6 + 33115*x^7 + 
            39800*x^8 - 43950*x^9 + 43950*x^11 - 39800*x^12 - 33115*x^13 - 
            5490*x^14 + 40861*x^15 + 4500*x^16 - 20310*x^17 - 6150*x^18 + 
            3780*x^19 + 1620*x^20) + x^2*(-787320 - 1837080*x + 
            17277300*x^2 + x^7*(3482676640 - 4766682432*Zeta[3]) - 
            177059520*x^25*Zeta[3] - 70917120*x^26*Zeta[3] + 
            7348320*x^27*Zeta[3] + 3149280*x^28*Zeta[3] + 
            204120*x^23*(-9 + 7424*Zeta[3]) - 810*x^4*(380303 + 
              69456*Zeta[3]) + 3240*x^24*(-243 + 163192*Zeta[3]) - 
            81*x^3*(-1934245 + 387552*Zeta[3]) - 720*x^22*
             (-23895 + 2014144*Zeta[3]) + 1620*x^18*(21251 + 2194784*Zeta[
                3]) - 440*x^14*(-884767 + 2322768*Zeta[3]) + 
            360*x^6*(6009217 + 2824368*Zeta[3]) + 90*x^20*(-1389447 + 
              10954192*Zeta[3]) - 320*x^8*(-31792037 + 13526943*Zeta[3]) - 
            320*x^16*(-11961617 + 31276620*Zeta[3]) - 
            80*x^10*(1217950169 + 64332792*Zeta[3]) + 
            9*x^5*(-218927495 + 73606848*Zeta[3]) - 224*x^17*
             (-3789035 + 84157938*Zeta[3]) + 64*x^9*(347633345 + 
              250085748*Zeta[3]) + 64*x^15*(-385627570 + 386667183*Zeta[3]) + 
            60*x^12*(-1766691143 + 417676856*Zeta[3]) - 
            9*x^21*(1114875 + 651266368*Zeta[3]) + 
            9*x^19*(45603745 + 1412224608*Zeta[3]) - 
            6*x^11*(-5283157295 + 5244788752*Zeta[3]) - 
            6*x^13*(-4027677815 + 5601577472*Zeta[3])))/
         (414720*x^5*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF^2*(-(Pi^2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
           HPL[{-2}, x])/(54*(-1 + x^2)^4) + 
        lm^2*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
           (16*(-1 + x^2)^4) + (3*x^3*(-2 + x - 2*x^2)*HPL[{0}, x])/
           (2*(-1 + x^2)^5)) + (Pi^2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{2}, x])/(54*(-1 + x^2)^4) + 
        (x*(15 - 825*x + 2730*x^2 - 5085*x^3 + 38610*x^4 - 4885*x^5 - 
           22950*x^6 - 22695*x^7 + 38830*x^8 + 53827*x^9 - 28334*x^10 - 
           66964*x^11 + 4306*x^12 + 47356*x^13 + 8706*x^14 - 18099*x^15 - 
           6129*x^16 + 2916*x^17 + 1296*x^18)*HPL[{-2, 0}, x])/
         (540*(-1 + x^2)^6) + ((-77760 - 174960*x + 251100*x^2 + 823500*x^3 - 
           113310*x^4 - 1533210*x^5 - 529710*x^6 + (1396573 - 1200*Pi^2)*
            x^7 - 30*(-33893 + 160*Pi^2)*x^8 + 4*(-132403 + 6000*Pi^2)*x^9 - 
           30*(55317 + 2080*Pi^2)*x^10 + 902658*x^11 + 
           30*(-55317 + 2080*Pi^2)*x^12 - 4*(132403 + 6000*Pi^2)*x^13 + 
           30*(33893 + 160*Pi^2)*x^14 + (1396573 + 1200*Pi^2)*x^15 - 
           529710*x^16 - 1533210*x^17 - 113310*x^18 + 823500*x^19 + 
           251100*x^20 - 174960*x^21 - 77760*x^22)*HPL[{-1, 0}, x])/
         (64800*x^7*(-1 + x^2)^5) + (x*(218700 - 34442820*x + 268201530*x^2 + 
           422417295*x^3 - 3936086460*x^4 + 34005585*x^5 + 4471314990*x^6 - 
           15570856200*x^7 + 75196130610*x^8 + 51845369792*x^9 + 
           49208866590*x^10 - 8825980267*x^11 - 6172209750*x^12 - 
           11251412923*x^13 + 1308159510*x^14 + 19488145758*x^15 + 
           2486885130*x^16 - 10709350038*x^17 - 2883444480*x^18 + 
           2869395030*x^19 + 1050369930*x^20 - 339116220*x^21 - 
           141411420*x^22 + 14171760*x^23 + 6298560*x^24)*HPL[{0, 0}, x])/
         (32400*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2) + 
        ((77760 + 174960*x - 251100*x^2 - 823500*x^3 + 113310*x^4 + 
           1533210*x^5 + 529710*x^6 + (-1396573 + 1200*Pi^2)*x^7 + 
           30*(-33893 + 160*Pi^2)*x^8 + (529612 - 24000*Pi^2)*x^9 + 
           30*(55317 + 2080*Pi^2)*x^10 - 902658*x^11 - 
           30*(-55317 + 2080*Pi^2)*x^12 + 4*(132403 + 6000*Pi^2)*x^13 - 
           30*(33893 + 160*Pi^2)*x^14 - (1396573 + 1200*Pi^2)*x^15 + 
           529710*x^16 + 1533210*x^17 + 113310*x^18 - 823500*x^19 - 
           251100*x^20 + 174960*x^21 + 77760*x^22)*HPL[{1, 0}, x])/
         (64800*x^7*(-1 + x^2)^5) + 
        lm*((2*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 
            3*(4 - 14*x + 25*x^2 + 164*x^3 + 25*x^4 - 14*x^5 + 4*x^6))/
           (144*(-1 + x^2)^4) - (x^2*(2 + 188*x - 60*x^2 + 296*x^3 - 22*x^4 + 
             12*x^5 + 3*x^6)*HPL[{0}, x])/(12*(-1 + x^2)^5) - 
          ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0}, x])/(6*(-1 + x^2)^3) + 
          (x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*x^5 + 4*x^6 + x^7)*
            HPL[{0, 0}, x])/(3*(-1 + x^2)^6) + ((1 + 4*x + 4*x^3 + x^4)*
            HPL[{1, 0}, x])/(6*(-1 + x^2)^3)) - 
        (x*(15 - 825*x + 2730*x^2 - 5085*x^3 + 38610*x^4 - 4885*x^5 - 
           22950*x^6 - 22695*x^7 + 38830*x^8 + 53827*x^9 - 28334*x^10 - 
           66964*x^11 + 4306*x^12 + 47356*x^13 + 8706*x^14 - 18099*x^15 - 
           6129*x^16 + 2916*x^17 + 1296*x^18)*HPL[{2, 0}, x])/
         (540*(-1 + x^2)^6) + (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{-2, -1, 0}, x])/(9*(-1 + x^2)^4) - 
        (4*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-2, 0, 0}, x])/(9*(-1 + x^2)^4) - 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-2, 1, 0}, x])/(9*(-1 + x^2)^4) - 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-1, -2, 0}, x])/(9*(-1 + x^2)^4) - 
        ((1296 + 2916*x + 351*x^2 - 3519*x^3 - 2499*x^4 + 601*x^5 + 
           1261*x^6 + 391*x^7 - 9*x^8 - 178*x^9 - 9*x^10 + 391*x^11 + 
           1261*x^12 + 601*x^13 - 2499*x^14 - 3519*x^15 + 351*x^16 + 
           2916*x^17 + 1296*x^18)*HPL[{-1, -1, 0}, x])/
         (1080*x^9*(-1 + x^2)) - ((961 + 45*x - 7709*x^2 + 22375*x^3 - 
           23329*x^4 + 16909*x^5 + 2303*x^6 + 12607*x^7 - 11765*x^8 - 
           26645*x^9 + 12009*x^10 + 30961*x^11 - 6967*x^12 - 21333*x^13 + 
           2277*x^14 + 8073*x^15 - 324*x^16 - 1296*x^17)*HPL[{-1, 0, 0}, x])/
         (540*(-1 + x)^6*(1 + x)^4) + ((1296 + 2916*x + 351*x^2 - 3519*x^3 - 
           2499*x^4 + 601*x^5 + 1261*x^6 + 391*x^7 - 9*x^8 - 178*x^9 - 
           9*x^10 + 391*x^11 + 1261*x^12 + 601*x^13 - 2499*x^14 - 3519*x^15 + 
           351*x^16 + 2916*x^17 + 1296*x^18)*HPL[{-1, 1, 0}, x])/
         (1080*x^9*(-1 + x^2)) + (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{-1, 2, 0}, x])/(9*(-1 + x^2)^4) - 
        (x*(-1215 + 76545*x + 3181545*x^2 - 655290*x^3 - 47253120*x^4 - 
           31166748*x^5 + 129241320*x^6 + 620025492*x^7 - 26451570*x^8 - 
           3373313510*x^9 + 3535336414*x^10 + 3028346856*x^11 - 
           986161904*x^12 - 2610887716*x^13 + 1542414584*x^14 + 
           2708218538*x^15 - 738676569*x^16 - 2213587489*x^17 + 
           7544639*x^18 + 1324611878*x^19 + 234137292*x^20 - 509769612*x^21 - 
           150588612*x^22 + 112799142*x^23 + 42170382*x^24 - 12012462*x^25 - 
           5028642*x^26 + 472392*x^27 + 209952*x^28)*HPL[{0, 0, 0}, x])/
         (540*(-1 + x^2)^7*(9 - 82*x^2 + 9*x^4)^2) + 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, -2, 0}, x])/(9*(-1 + x^2)^4) + 
        ((1296 + 2916*x + 351*x^2 - 3519*x^3 - 2499*x^4 + 601*x^5 + 
           1261*x^6 + 391*x^7 - 9*x^8 - 178*x^9 - 9*x^10 + 391*x^11 + 
           1261*x^12 + 601*x^13 - 2499*x^14 - 3519*x^15 + 351*x^16 + 
           2916*x^17 + 1296*x^18)*HPL[{1, -1, 0}, x])/(1080*x^9*(-1 + x^2)) + 
        ((961 + 4369*x + 3039*x^2 + 6471*x^3 + 16575*x^4 - 3543*x^5 - 
           17909*x^6 - 393*x^7 + 34795*x^8 + 32895*x^9 - 22051*x^10 - 
           48663*x^11 - 8311*x^12 + 27735*x^13 + 16425*x^14 - 3591*x^15 - 
           5508*x^16 - 1296*x^17)*HPL[{1, 0, 0}, x])/(540*(-1 + x)^4*
          (1 + x)^6) - ((1296 + 2916*x + 351*x^2 - 3519*x^3 - 2499*x^4 + 
           601*x^5 + 1261*x^6 + 391*x^7 - 9*x^8 - 178*x^9 - 9*x^10 + 
           391*x^11 + 1261*x^12 + 601*x^13 - 2499*x^14 - 3519*x^15 + 
           351*x^16 + 2916*x^17 + 1296*x^18)*HPL[{1, 1, 0}, x])/
         (1080*x^9*(-1 + x^2)) - (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 
           4*x^5 + x^6)*HPL[{1, 2, 0}, x])/(9*(-1 + x^2)^4) - 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{2, -1, 0}, x])/(9*(-1 + x^2)^4) + 
        (4*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{2, 0, 0}, x])/(9*(-1 + x^2)^4) + 
        (2*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{2, 1, 0}, x])/(9*(-1 + x^2)^4) - 
        (4*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{-1, 1, 0, 0}, x])/(9*(-1 + x^2)^4) - 
        (4*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
          HPL[{1, -1, 0, 0}, x])/(9*(-1 + x^2)^4) + 
        ((2 + 11*x - 31*x^2 + 177*x^3 - 76*x^4 + 73*x^5 + 9*x^6 + 3*x^7)*
          master3l10a[x])/(72*(-1 + x^2)^5) - 
        (x*(3 + 9*x + 73*x^2 - 76*x^3 + 177*x^4 - 31*x^5 + 11*x^6 + 2*x^7)*
          master3l10b[x])/(72*(-1 + x^2)^5) + 
        ((78489 - 266355*x + 335988*x^2 - 795960*x^3 + 323646*x^4 + 
           63690*x^5 - 88764*x^6 + 17120*x^7 + 6641*x^8 - 1535*x^9 - 
           128*x^10)*master3l8a[x])/(2160*(-9 + x^2)^2*(-1 + x^2)^6) - 
        ((10 - 638*x + 1425*x^2 + 13729*x^3 - 29180*x^4 - 124352*x^5 + 
           127290*x^6 + 475446*x^7 + 85770*x^8 - 105786*x^9 + 111645*x^10 + 
           68769*x^11)*master3l8b[x])/(2160*x*(1 - 9*x^2)^2*(-1 + x^2)^6) - 
        ((8181 - 8595*x + 13698*x^2 - 40410*x^3 + 45916*x^4 + 6120*x^5 - 
           6738*x^6 + 10*x^7 + 383*x^8 - 5*x^9)*master3l9a[x])/
         (720*(-9 + x^2)*(-1 + x^2)^6) - 
        ((-5 + 383*x + 10*x^2 - 6738*x^3 + 6120*x^4 + 45916*x^5 - 40410*x^6 + 
           13698*x^7 - 8595*x^8 + 8181*x^9)*master3l9b[x])/
         (2160*x*(-1 + x^2)^6*(-1 + 9*x^2)) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(1296 + 2916*x + 351*x^2 - 
             3519*x^3 - 2499*x^4 + 601*x^5 + 1261*x^6 + 391*x^7 - 9*x^8 - 
             178*x^9 - 9*x^10 + 391*x^11 + 1261*x^12 + 601*x^13 - 2499*x^14 - 
             3519*x^15 + 351*x^16 + 2916*x^17 + 1296*x^18) - 
           2880*x^9*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
            Zeta[3]))/(12960*x^9*(-1 + x^2)^4) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(1296 + 2916*x + 351*x^2 - 
              3519*x^3 - 2499*x^4 + 601*x^5 + 1261*x^6 + 391*x^7 - 9*x^8 - 
              178*x^9 - 9*x^10 + 391*x^11 + 1261*x^12 + 601*x^13 - 
              2499*x^14 - 3519*x^15 + 351*x^16 + 2916*x^17 + 1296*x^18)) + 
           2880*x^9*(1 + 4*x - 19*x^2 + 56*x^3 - 19*x^4 + 4*x^5 + x^6)*
            Zeta[3]))/(12960*x^9*(-1 + x^2)^4) + 
        (HPL[{0}, x]*(6298560 + 14171760*x - 138262140*x^2 - 332030340*x^3 + 
           981763740*x^4 + 2704560840*x^5 - 405*(5938783 + 60*Pi^2)*x^6 + 
           81*(-114940631 + 16500*Pi^2)*x^7 - 450*(329642927 + 13282650*Pi^2)*
            x^14 + 2*(6617526093 + 6137645260*Pi^2)*x^21 - 
           5*(-422257293 + 245083300*Pi^2)*x^22 - 
           5*(581025393 + 1824970348*Pi^2)*x^23 - 
           60*(16362729 + 20150062*Pi^2)*x^24 + 1620*(204957 + 2521670*Pi^2)*
            x^25 + 540*(256041 + 2096980*Pi^2)*x^26 - 
           19440*(729 + 52088*Pi^2)*x^27 - 3240*(1944 + 115283*Pi^2)*x^28 + 
           115400700*Pi^2*x^29 + 48186900*Pi^2*x^30 - 4723920*Pi^2*x^31 - 
           2099520*Pi^2*x^32 - 4*x^15*(14719840269 + 58291660*Pi^2 - 
             1083715200*Zeta[3]) + 6*x^13*(1955538721 + 94752150*Pi^2 - 
             722476800*Zeta[3]) - 10*x^11*(413940491 + 2857650*Pi^2 - 
             80714880*Zeta[3]) + 10*x^17*(3678653861 + 468704262*Pi^2 - 
             80714880*Zeta[3]) - 2*x^19*(18123623319 + 5064295570*Pi^2 - 
             20995200*Zeta[3]) - 100*x^18*(146845419 + 69310952*Pi^2 - 
             15303168*Zeta[3]) + 300*x^10*(35738039 + 53252*Pi^2 - 
             5101056*Zeta[3]) + 160*x^20*(20297529 + 32491303*Pi^2 - 
             524880*Zeta[3]) - 360*x^8*(-2088386 + 11055*Pi^2 - 
             233280*Zeta[3]) - 6*x^9*(-2366373523 + 2686050*Pi^2 + 
             6998400*Zeta[3]) + 300*x^12*(-37570841 + 2671378*Pi^2 + 
             23518080*Zeta[3]) + 60*x^16*(91469688*Pi^2 - 
             5*(96743131 + 23518080*Zeta[3]))))/(129600*x^5*(-1 + x^2)^6*
          (9 - 82*x^2 + 9*x^4)^2) + 
        (-4800*Pi^4*x^7*(9 - 91*x^2 + 91*x^4 - 9*x^6)^2*(1 + 4*x - 19*x^2 + 
            56*x^3 - 19*x^4 + 4*x^5 + x^6) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^2*
           (-77760 - 174960*x + 328860*x^2 + 998460*x^3 - 364410*x^4 - 
            2356710*x^5 - 416400*x^6 + 2929783*x^7 + 1546500*x^8 - 
            1926185*x^9 - 2676300*x^10 + 1432270*x^11 - 1432270*x^13 + 
            2676300*x^14 + 1926185*x^15 - 1546500*x^16 - 2929783*x^17 + 
            416400*x^18 + 2356710*x^19 + 364410*x^20 - 998460*x^21 - 
            328860*x^22 + 174960*x^23 + 77760*x^24) + 
          3*x^2*(-12597120 - 28343520*x + 280723320*x^2 + 673508520*x^3 - 
            2054492100*x^4 - 2769616800*x^29*Zeta[3] - 1156485600*x^30*
             Zeta[3] + 113374080*x^31*Zeta[3] + 50388480*x^32*Zeta[3] + 
            77760*x^28*(-162 + 115283*Zeta[3]) + 1620*x^6*
             (4131611 + 122904*Zeta[3]) + 116640*x^27*
             (-243 + 208352*Zeta[3]) + 405*x^5*(-15285113 + 349536*Zeta[3]) - 
            3600*x^8*(5203229 + 1118340*Zeta[3]) - 3240*x^26*
             (-86643 + 8387920*Zeta[3]) - 9720*x^25*(-69291 + 
              10086680*Zeta[3]) + 720*x^24*(-2852955 + 40300124*Zeta[3]) - 
            9*x^7*(-3140185031 + 321283200*Zeta[3]) - 
            120*x^14*(-3207606931 + 461701996*Zeta[3]) + 
            60*x^22*(96303897 + 493008728*Zeta[3]) - 
            40*x^12*(-13835275103 + 493167000*Zeta[3]) + 
            40*x^10*(-1002124325 + 578262672*Zeta[3]) - 
            160*x^16*(-401777807 + 793721172*Zeta[3]) - 
            60*x^20*(134786115 + 2138700832*Zeta[3]) + 
            8*x^9*(-5223864701 + 2505966960*Zeta[3]) + 
            40*x^18*(-208907525 + 4661504832*Zeta[3]) - 
            8*x^11*(16228902977 + 8652628200*Zeta[3]) + 
            15*x^23*(-357128811 + 14608733696*Zeta[3]) + 
            10*x^13*(-12916743709 + 16056549648*Zeta[3]) + 
            10*x^15*(-9150305269 + 17650532544*Zeta[3]) - 
            8*x^17*(-13101533623 + 22493175960*Zeta[3]) + 
            8*x^19*(-3577656701 + 32717701080*Zeta[3]) - 
            3*x^21*(-5452586493 + 99105974560*Zeta[3])))/
         (3110400*x^7*(-1 + x^2)^6*(9 - 82*x^2 + 9*x^4)^2)) + 
      CF*(NH*((x*(466560 + 3873744*x + 172225440*x^2 - 9453555*x^3 + 
             90194760*x^4 + 32261800*x^5 - 38253440*x^6 - 6593175*x^7 + 
             3974640*x^8 - 380392*x^9 - 153280*x^10 + 167455*x^11 - 
             760*x^12 - 10352*x^13 + 480*x^14 + 75*x^15)*HPL[{0}, x])/
           (4320*(-9 + x^2)^2*(-1 + x^2)^7) + 
          lm^2*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
             (144*(-1 + x^2)^4) + (x^3*(-2 + x - 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x^2)^5)) + (x*(-116640 - 598428*x - 31298400*x^2 + 
             2336427*x^3 - 14110200*x^4 - 5818448*x^5 + 10848640*x^6 + 
             949125*x^7 - 528320*x^8 + 78880*x^9 - 129680*x^10 - 19991*x^11 + 
             6360*x^12 + 396*x^13 + 240*x^14 + 39*x^15)*HPL[{0, 0}, x])/
           (1080*(-9 + x^2)^2*(-1 + x^2)^7) + 
          lm*((4*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 3*(7 - 32*x + 
                57*x^2 + 288*x^3 + 57*x^4 - 32*x^5 + 7*x^6))/
             (2592*(-1 + x^2)^4) - (x^2*(2 + 182*x - 57*x^2 + 290*x^3 - 22*
                x^4 + 12*x^5 + 3*x^6)*HPL[{0}, x])/(108*(-1 + x^2)^5) - 
            ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0}, x])/(54*(-1 + x^2)^3) + 
            (x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*x^5 + 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x^2)^6) + 
            ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x^2)^3)) - 
          ((-41 + 689*x - 494*x^2 + 977*x^3 - 308*x^4 + 182*x^5 - 8*x^6 + 
             2*x^7 + x^8)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^6*(1 + x)^4) + 
          (x^3*(1132380 - 130707*x + 558360*x^2 + 226062*x^3 - 521820*x^4 + 
             17331*x^5 - 2760*x^6 - 11412*x^7 + 12300*x^8 + 1211*x^9 - 
             880*x^10 - 90*x^11 + 20*x^12 + 5*x^13)*HPL[{0, 0, 0}, x])/
           (135*(-9 + x^2)^2*(-1 + x^2)^7) + 
          ((-77 + 471*x + 26*x^2 + 423*x^3 + 216*x^4 + 114*x^5 + 8*x^6 + 
             6*x^7 + x^8)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^6) + 
          ((38799 + 1532520*x - 73116*x^2 + 974880*x^3 + 263763*x^4 - 
             164880*x^5 - 19360*x^6 + 13600*x^7 - 5915*x^8 - 920*x^9 + 
             636*x^10 - 7*x^12)*master3l8a[x])/(1080*(-9 + x^2)^2*
            (-1 + x^2)^7) - ((12933 + 259200*x + 6111*x^2 + 229680*x^3 + 
             38364*x^4 + 86520*x^5 - 6042*x^6 + 14760*x^7 - 107*x^8 - 
             1400*x^9 - 69*x^10 + 40*x^11 + 10*x^12)*master3l9a[x])/
           (1080*(-9 + x^2)*(-1 + x^2)^7) + 
          (x^10*(1345891 - 901760*Zeta[3]) + x^14*(67707 - 7040*Zeta[3]) + 
            40*x^15*(-167 + 32*Zeta[3]) + 5*x^16*(-143 + 64*Zeta[3]) - 
            200*x^11*(-12577 + 160*Zeta[3]) - 60*x^13*(599 + 1024*Zeta[3]) - 
            4860*x*(90497 + 1792*Zeta[3]) + 300*x^5*(-855625 + 
              2176*Zeta[3]) + 1458*(-10473 + 3040*Zeta[3]) + 
            19*x^12*(-49467 + 5120*Zeta[3]) + 405*x^2*(-17675 + 
              34432*Zeta[3]) + 1080*x^3*(-857527 + 60832*Zeta[3]) + 
            180*x^9*(-157913 + 66432*Zeta[3]) - 120*x^7*(-1373397 + 
              579232*Zeta[3]) - 45*x^4*(446239 + 717056*Zeta[3]) + 
            3*x^8*(11157259 + 755200*Zeta[3]) + 9*x^6*(-13384447 + 
              1381760*Zeta[3]))/(25920*(-9 + x^2)^2*(-1 + x^2)^7)) + 
        NM*(((-40*Pi^2*(1 - 9*x^2)^2*(-1 + x^2)^4*(1 + 4*x + 4*x^3 + x^4) + 
             3*(-760 - 3040*x + 11388*x^2 + 130640*x^3 - 94735*x^4 - 1793440*
                x^5 + 1010188*x^6 - 934840*x^7 - 3670395*x^8 + 62244640*x^9 - 
               13303220*x^10 + 128239520*x^11 + 4780955*x^12 + 35655840*
                x^13 + 23572044*x^14 + 4915080*x^15 + 7560135*x^16))*
            HPL[{0}, x])/(12960*(1 - 9*x^2)^2*(-1 + x^2)^7) + 
          lm^2*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 4*x^5 + x^6)/
             (144*(-1 + x^2)^4) + (x^3*(-2 + x - 2*x^2)*HPL[{0}, x])/
             (6*(-1 + x^2)^5)) + ((1 + 4*x + 4*x^3 + x^4)*HPL[{-2, 0}, x])/
           (27*(-1 + x^2)^3) - ((-120 - 480*x + 1096*x^2 + 22000*x^3 - 
             5959*x^4 - 189360*x^5 + 78588*x^6 - 2698200*x^7 + 484687*x^8 + 
             17415440*x^9 - 7591900*x^10 + 75562320*x^11 - 2252733*x^12 + 
             27077760*x^13 + 14498136*x^14 + 2925720*x^15 + 5233005*x^16)*
            HPL[{0, 0}, x])/(1080*(1 - 9*x^2)^2*(-1 + x^2)^7) + 
          lm*((4*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 3*(7 - 32*x + 
                57*x^2 + 288*x^3 + 57*x^4 - 32*x^5 + 7*x^6))/
             (2592*(-1 + x^2)^4) - (x^2*(2 + 182*x - 57*x^2 + 290*x^3 - 22*
                x^4 + 12*x^5 + 3*x^6)*HPL[{0}, x])/(108*(-1 + x^2)^5) - 
            ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0}, x])/(54*(-1 + x^2)^3) + 
            (x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*x^5 + 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x^2)^6) + 
            ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x^2)^3)) - 
          ((1 + 4*x + 4*x^3 + x^4)*HPL[{2, 0}, x])/(27*(-1 + x^2)^3) + 
          ((-3 - 6*x + 24*x^2 - 194*x^3 + 308*x^4 - 965*x^5 + 478*x^6 - 
             685*x^7 + 43*x^8)*HPL[{-1, 0, 0}, x])/(27*(-1 + x)^6*
            (1 + x)^4) + ((-5 - 20*x - 50*x^2 + 1040*x^3 + 862*x^4 + 
             7540*x^5 - 3336*x^6 - 347200*x^7 + 165088*x^8 + 194580*x^9 - 
             1203214*x^10 + 14289040*x^11 - 750338*x^12 + 7127820*x^13 + 
             2739240*x^14 + 1101600*x^15 + 997353*x^16)*HPL[{0, 0, 0}, x])/
           (135*(1 - 9*x^2)^2*(-1 + x^2)^7) + 
          ((3 + 18*x + 24*x^2 + 118*x^3 + 216*x^4 + 419*x^5 + 10*x^6 + 
             459*x^7 - 79*x^8)*HPL[{1, 0, 0}, x])/(27*(-1 + x)^4*(1 + x)^6) + 
          ((-20 - 80*x + 339*x^2 + 3520*x^3 - 2936*x^4 - 51960*x^5 + 
             27903*x^6 + 51840*x^7 - 127404*x^8 + 1592640*x^9 - 112959*x^10 + 
             691200*x^11 + 303480*x^12 + 68040*x^13 + 116397*x^14)*
            master3l8b[x])/(3240*x^2*(1 - 9*x^2)^2*(-1 + x^2)^7) + 
          ((10 + 40*x - 69*x^2 - 1400*x^3 - 107*x^4 + 14760*x^5 - 6042*x^6 + 
             86520*x^7 + 38364*x^8 + 229680*x^9 + 6111*x^10 + 259200*x^11 + 
             12933*x^12)*master3l9b[x])/(3240*x^2*(-1 + x^2)^7*
            (-1 + 9*x^2)) + (-150 - 600*x + x^6*(1108413 - 97280*Zeta[3]) + 
            x^2*(5500 - 320*Zeta[3]) - 40*x^3*(-1067 + 32*Zeta[3]) + 
            200*x^7*(22013 + 160*Zeta[3]) + 60*x^5*(-13151 + 1024*Zeta[3]) + 
            4860*x^17*(-3103 + 1792*Zeta[3]) - 300*x^13*(830921 + 
              2176*Zeta[3]) - 729*x^18*(10189 + 6080*Zeta[3]) + 
            x^4*(-111627 + 7040*Zeta[3]) - 540*x^9*(-57181 + 22144*Zeta[3]) + 
            2760*x^11*(-100899 + 25184*Zeta[3]) - 405*x^16*
             (71555 + 34432*Zeta[3]) - 1080*x^15*(-12697 + 60832*Zeta[3]) + 
            45*x^14*(-1209029 + 717056*Zeta[3]) - 3*x^10*(2372209 + 
              755200*Zeta[3]) + x^8*(-3855751 + 901760*Zeta[3]) - 
            9*x^12*(-6419567 + 1381760*Zeta[3]))/(25920*(-1 + x^2)^7*
            (x - 9*x^3)^2)) + NL*(-(Pi^2*(1 + 4*x + 4*x^3 + x^4)*
             HPL[{-1}, x])/(324*(-1 + x^2)^3) + 
          (x^2*(78 + 240*(89 + 9*Pi^2)*x - 3*(1777 + 360*Pi^2)*x^2 + 
             480*(10 + 9*Pi^2)*x^3 + (6081 - 1000*Pi^2)*x^4 + 
             80*(-333 + 25*Pi^2)*x^5 - 3*(241 + 20*Pi^2)*x^6 + 
             80*(6 + Pi^2)*x^7 + 5*(-21 + 4*Pi^2)*x^8)*HPL[{0}, x])/
           (6480*(-1 + x^2)^6) + lm^2*((1 + 4*x - 7*x^2 + 40*x^3 - 7*x^4 + 
              4*x^5 + x^6)/(144*(-1 + x^2)^4) + (x^3*(-2 + x - 2*x^2)*
              HPL[{0}, x])/(6*(-1 + x^2)^5)) + (Pi^2*(1 + 4*x + 4*x^3 + x^4)*
            HPL[{1}, x])/(324*(-1 + x^2)^3) - 
          (x^3*(108 - 54*x + 216*x^2 - 50*x^3 + 100*x^4 - 3*x^5 + 4*x^6 + 
             x^7)*HPL[{-2, 0}, x])/(27*(-1 + x^2)^6) - 
          ((13 + 80*x + 198*x^2 - 4360*x^3 + 1698*x^4 - 4360*x^5 + 198*x^6 + 
             80*x^7 + 13*x^8)*HPL[{-1, 0}, x])/(1080*(-1 + x^2)^5) + 
          (x^3*(2400 - 1200*x + 5040*x^2 - 640*x^3 + 2560*x^4 - 45*x^5 + 
             200*x^6 + 43*x^7)*HPL[{0, 0}, x])/(540*(-1 + x^2)^6) + 
          ((13 + 80*x + 198*x^2 - 4360*x^3 + 1698*x^4 - 4360*x^5 + 198*x^6 + 
             80*x^7 + 13*x^8)*HPL[{1, 0}, x])/(1080*(-1 + x^2)^5) + 
          lm*((4*Pi^2*(-1 - 4*x + x^2 - x^4 + 4*x^5 + x^6) + 3*(7 - 32*x + 
                57*x^2 + 288*x^3 + 57*x^4 - 32*x^5 + 7*x^6))/
             (2592*(-1 + x^2)^4) - (x^2*(2 + 182*x - 57*x^2 + 290*x^3 - 22*
                x^4 + 12*x^5 + 3*x^6)*HPL[{0}, x])/(108*(-1 + x^2)^5) - 
            ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 0}, x])/(54*(-1 + x^2)^3) + 
            (x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*x^5 + 4*x^6 + x^
                7)*HPL[{0, 0}, x])/(27*(-1 + x^2)^6) + 
            ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 0}, x])/(54*(-1 + x^2)^3)) + 
          (x^3*(108 - 54*x + 216*x^2 - 50*x^3 + 100*x^4 - 3*x^5 + 4*x^6 + 
             x^7)*HPL[{2, 0}, x])/(27*(-1 + x^2)^6) + 
          ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, -1, 0}, x])/(27*(-1 + x^2)^3) - 
          ((1 + 4*x + 4*x^3 + x^4)*HPL[{-1, 1, 0}, x])/(27*(-1 + x^2)^3) - 
          (2*x^3*(72 - 36*x + 216*x^2 - 68*x^3 + 136*x^4 - 3*x^5 + 4*x^6 + 
             x^7)*HPL[{0, 0, 0}, x])/(27*(-1 + x^2)^6) - 
          ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, -1, 0}, x])/(27*(-1 + x^2)^3) + 
          ((1 + 4*x + 4*x^3 + x^4)*HPL[{1, 1, 0}, x])/(27*(-1 + x^2)^3) + 
          (4*Pi^2*(-13 - 80*x - 185*x^2 + 4440*x^3 - 1500*x^4 + 1500*x^6 - 
              4440*x^7 + 185*x^8 + 80*x^9 + 13*x^10) - 
            3*(5 - 5111*x^8 + 3920*x^9 + 5*x^10 - 320*Zeta[3] - 
              80*x*(-49 + 16*Zeta[3]) - 480*x^7*(7 + 72*Zeta[3]) - 
              160*x^3*(21 + 200*Zeta[3]) - 160*x^5*(7 + 432*Zeta[3]) + 
              x^2*(-5111 + 960*Zeta[3]) + 6*x^6*(851 + 2880*Zeta[3]) + 
              2*x^4*(2553 + 8000*Zeta[3])))/(51840*(-1 + x^2)^6))))
 
CbarLData["a", 2, 2] = 
    NC*(CF*(NL*(-(Pi^2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*
             HPL[{-1}, x])/(810*(-1 + x^2)^5) + 
          (x^2*(-6 + 90*(1047 + 80*Pi^2)*x - 3*(23143 + 2400*Pi^2)*x^2 + 
             45*(5027 + 720*Pi^2)*x^3 - 20*(1033 + 800*Pi^2)*x^4 + 
             25*(-7029 + 1264*Pi^2)*x^5 + (88824 - 7100*Pi^2)*x^6 + 
             5*(-28863 + 1460*Pi^2)*x^7 + (1626 - 80*Pi^2)*x^8 + 
             5*(-81 + 20*Pi^2)*x^9 + 5*(-71 + 4*Pi^2)*x^10)*HPL[{0}, x])/
           (16200*(-1 + x^2)^8) + lm^2*((1 + 5*x - 14*x^2 + 145*x^3 - 
              94*x^4 + 145*x^5 - 14*x^6 + 5*x^7 + x^8)/(180*(-1 + x^2)^6) - 
            (2*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x^2)^7)) + (Pi^2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 
             5*x^5 + x^6)*HPL[{1}, x])/(810*(-1 + x^2)^5) - 
          (2*x^3*(360 - 360*x + 1620*x^2 - 800*x^3 + 1580*x^4 - 355*x^5 + 
             365*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{-2, 0}, x])/
           (135*(-1 + x^2)^8) + ((1 - 25*x - 803*x^2 + 17070*x^3 - 
             14378*x^4 + 44510*x^5 - 14378*x^6 + 17070*x^7 - 803*x^8 - 
             25*x^9 + x^10)*HPL[{-1, 0}, x])/(2700*(-1 + x^2)^7) + 
          (x^3*(6000 - 6000*x + 33000*x^2 - 16000*x^3 + 43000*x^4 - 
             9725*x^5 + 13525*x^6 - 116*x^7 + 325*x^8 + 59*x^9)*
            HPL[{0, 0}, x])/(1350*(-1 + x^2)^8) + 
          ((-1 + 25*x + 803*x^2 - 17070*x^3 + 14378*x^4 - 44510*x^5 + 
             14378*x^6 - 17070*x^7 + 803*x^8 + 25*x^9 - x^10)*HPL[{1, 0}, x])/
           (2700*(-1 + x^2)^7) + lm*((71 + 81*x - 182*x^2 + 10179*x^3 - 
              4314*x^4 + 10179*x^5 - 182*x^6 + 81*x^7 + 71*x^8 + 
              4*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 15*x^5 - 2*x^6 + 5*x^7 + 
                x^8))/(6480*(-1 + x^2)^6) - (x^2*(1 + 413*x - 334*x^2 + 1559*
                x^3 - 574*x^4 + 833*x^5 - 44*x^6 + 15*x^7 + 3*x^8)*
              HPL[{0}, x])/(135*(-1 + x^2)^7) + 
            ((-1 - 5*x + x^2 - 20*x^3 + x^4 - 5*x^5 - x^6)*HPL[{-1, 0}, x])/
             (135*(-1 + x^2)^5) + (2*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 
               1940*x^4 - 535*x^5 + 545*x^6 - 4*x^7 + 5*x^8 + x^9)*
              HPL[{0, 0}, x])/(135*(-1 + x^2)^8) + 
            ((1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{1, 0}, x])/
             (135*(-1 + x^2)^5)) + (2*x^3*(360 - 360*x + 1620*x^2 - 800*x^3 + 
             1580*x^4 - 355*x^5 + 365*x^6 - 4*x^7 + 5*x^8 + x^9)*
            HPL[{2, 0}, x])/(135*(-1 + x^2)^8) + 
          (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{-1, -1, 0}, 
             x])/(135*(-1 + x^2)^5) - (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 
             5*x^5 + x^6)*HPL[{-1, 1, 0}, x])/(135*(-1 + x^2)^5) - 
          (4*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 1940*x^4 - 535*x^5 + 
             545*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{0, 0, 0}, x])/
           (135*(-1 + x^2)^8) - (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + 
             x^6)*HPL[{1, -1, 0}, x])/(135*(-1 + x^2)^5) + 
          (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{1, 1, 0}, x])/
           (135*(-1 + x^2)^5) + (96972*x^10 - 48285*x^11 + 2365*x^12 - 
            12*Pi^2*(-1 + 25*x + 804*x^2 - 17095*x^3 + 13575*x^4 - 
              27440*x^5 + 27440*x^7 - 13575*x^8 + 17095*x^9 - 804*x^10 - 
              25*x^11 + x^12) + 45*x*(-1073 + 320*Zeta[3]) + 
            5*(473 + 576*Zeta[3]) - 12*x^2*(-8081 + 960*Zeta[3]) + 
            135*x^9*(2693 + 7680*Zeta[3]) + 45*x^3*(8079 + 23360*Zeta[3]) + 
            90*x^5*(-3503 + 50560*Zeta[3]) + 90*x^7*(-3503 + 51840*Zeta[3]) - 
            15*x^4*(6499 + 68160*Zeta[3]) - 15*x^8*(6499 + 69120*Zeta[3]) - 
            8*x^6*(463 + 288000*Zeta[3]))/(388800*(-1 + x^2)^8)) + 
        NM*(((-2280 - 11400*x + 73452*x^2 + 1081140*x^3 - 1828239*x^4 - 
             32627445*x^5 + 38392273*x^6 + 278469990*x^7 - 405309622*x^8 + 
             1048381530*x^9 + 1130622306*x^10 - 19689020010*x^11 + 
             7281803612*x^12 + 16827011280*x^13 - 27485371124*x^14 + 
             232524544050*x^15 - 65392370802*x^16 + 204095829870*x^17 + 
             13529755458*x^18 + 7817020830*x^19 + 25940545731*x^20 - 
             2331134235*x^21 + 5314639635*x^22 - 40*Pi^2*(1 - 10*x^2 + 9*x^4)^
               4*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6))*HPL[{0}, x])/
           (32400*(1 - 9*x^2)^4*(-1 + x^2)^9) + 
          lm^2*((1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 
              5*x^7 + x^8)/(180*(-1 + x^2)^6) - 
            (2*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x^2)^7)) + (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + 
             x^6)*HPL[{-2, 0}, x])/(135*(-1 + x^2)^5) + 
          ((120 + 600*x - 3208*x^2 - 68600*x^3 + 90533*x^4 + 1696515*x^5 - 
             1792587*x^6 - 783270*x^7 + 9734400*x^8 - 276847440*x^9 + 
             120564172*x^10 + 1752361370*x^11 - 1334871578*x^12 + 
             4293282030*x^13 + 1240110138*x^14 - 34742728530*x^15 + 
             14251168728*x^16 - 44722497600*x^17 - 462919860*x^18 - 
             4142068650*x^19 - 5576432283*x^20 + 629691975*x^21 - 
             1226742975*x^22)*HPL[{0, 0}, x])/(2700*(1 - 9*x^2)^4*
            (-1 + x^2)^9) + lm*((71 + 81*x - 182*x^2 + 10179*x^3 - 4314*x^4 + 
              10179*x^5 - 182*x^6 + 81*x^7 + 71*x^8 + 4*Pi^2*(-1 - 5*x + 
                2*x^2 - 15*x^3 + 15*x^5 - 2*x^6 + 5*x^7 + x^8))/
             (6480*(-1 + x^2)^6) - (x^2*(1 + 413*x - 334*x^2 + 1559*x^3 - 574*
                x^4 + 833*x^5 - 44*x^6 + 15*x^7 + 3*x^8)*HPL[{0}, x])/
             (135*(-1 + x^2)^7) + ((-1 - 5*x + x^2 - 20*x^3 + x^4 - 5*x^5 - x^
                6)*HPL[{-1, 0}, x])/(135*(-1 + x^2)^5) + 
            (2*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 1940*x^4 - 535*x^5 + 
               545*x^6 - 4*x^7 + 5*x^8 + x^9)*HPL[{0, 0}, x])/
             (135*(-1 + x^2)^8) + ((1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^
                6)*HPL[{1, 0}, x])/(135*(-1 + x^2)^5)) - 
          (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{2, 0}, x])/
           (135*(-1 + x^2)^5) + (2*(-3 - 9*x + 33*x^2 - 692*x^3 + 1461*x^4 - 
             5405*x^5 + 4504*x^6 - 8648*x^7 + 2887*x^8 - 2676*x^9 + 148*x^10)*
            HPL[{-1, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^6) + 
          (2*(-5 - 25*x + 45*x^2 + 3700*x^3 - 2879*x^4 - 32075*x^5 + 
             52445*x^6 - 1425030*x^7 + 946068*x^8 + 18388770*x^9 - 
             24935088*x^10 + 78965010*x^11 + 127888324*x^12 - 
             1785206170*x^13 + 303221596*x^14 + 4552985070*x^15 - 
             2696106015*x^16 + 9675214695*x^17 - 245293677*x^18 + 
             1804632210*x^19 + 994008267*x^20 + 38349045*x^21 + 
             232777719*x^22)*HPL[{0, 0, 0}, x])/(675*(1 - 9*x^2)^4*
            (-1 + x^2)^9) + ((6 + 42*x + 54*x^2 + 1016*x^3 + 1178*x^4 + 
             4590*x^5 + 552*x^6 + 9624*x^7 - 2214*x^8 + 3988*x^9 - 476*x^10)*
            HPL[{1, 0, 0}, x])/(135*(-1 + x)^6*(1 + x)^8) + 
          ((-20 - 100*x + 677*x^2 + 10175*x^3 - 16927*x^4 - 319510*x^5 + 
             354946*x^6 + 3089550*x^7 - 4007742*x^8 + 5099130*x^9 + 
             15884316*x^10 - 198305460*x^11 + 38331132*x^12 + 
             548521470*x^13 - 307774962*x^14 + 1037858850*x^15 - 
             27042174*x^16 + 131308290*x^17 + 119366703*x^18 - 
             13380795*x^19 + 27278451*x^20)*master3l8b[x])/
           (8100*x^2*(1 - 9*x^2)^4*(-1 + x^2)^9) + 
          ((10 + 50*x - 217*x^2 - 4525*x^3 + 3218*x^4 + 125585*x^5 - 
             81860*x^6 - 715605*x^7 + 971994*x^8 - 4605915*x^9 - 
             3343890*x^10 + 25139745*x^11 - 1347762*x^12 + 63294795*x^13 - 
             4941612*x^14 + 197741025*x^15 - 28697220*x^16 + 97495245*x^17 + 
             3030939*x^18)*master3l9b[x])/(8100*x^2*(-1 + x^2)^9*
            (-1 + 9*x^2)^3) + (-450 - 2250*x + x^6*(22682778 - 
              993600*Zeta[3]) + x^3*(303330 - 4800*Zeta[3]) - 
            40*x^2*(-625 + 24*Zeta[3]) + 31744*x^10*(32942 + 375*Zeta[3]) + 
            15*x^5*(-693941 + 17280*Zeta[3]) + x^4*(-1014583 + 
              39360*Zeta[3]) + 98415*x^23*(-50041 + 93120*Zeta[3]) + 
            15*x^7*(9282743 + 360000*Zeta[3]) - 6561*x^24*
             (825139 + 452160*Zeta[3]) + 17*x^8*(-14902651 + 
              724800*Zeta[3]) + 2160*x^11*(-6037489 + 2033440*Zeta[3]) - 
            120*x^9*(1536061 + 2653280*Zeta[3]) - 10935*x^21*
             (-3585523 + 5919360*Zeta[3]) - 1458*x^22*(17315719 + 
              13286880*Zeta[3]) - 2430*x^19*(94107691 + 40065120*Zeta[3]) + 
            72*x^18*(1611206789 + 131067000*Zeta[3]) + 
            90*x^15*(-1422197881 + 173735680*Zeta[3]) + 
            243*x^20*(-340442729 + 183672000*Zeta[3]) + 
            810*x^17*(-893865471 + 192368000*Zeta[3]) - 
            90*x^13*(-1175315371 + 251241600*Zeta[3]) - 
            6*x^12*(-758669363 + 296812800*Zeta[3]) - 
            16*x^16*(-8521779803 + 2853572400*Zeta[3]) + 
            4*x^14*(-14407418483 + 3921134400*Zeta[3]))/
           (194400*x^2*(1 - 9*x^2)^4*(-1 + x^2)^9)) + 
        NH*((x*(283435200 + 2636052336*x + 196662563280*x^2 - 
             73189006947*x^3 + 345787606395*x^4 + 7855418313*x^5 - 
             82125137250*x^6 + 36080629506*x^7 - 31408549470*x^8 - 
             15667801998*x^9 + 13035465990*x^10 + 2298151356*x^11 - 
             1812974520*x^12 - 41658812*x^13 + 120645690*x^14 - 
             23162002*x^15 - 3491970*x^16 + 2409006*x^17 - 20910*x^18 - 
             80713*x^19 + 3165*x^20 + 355*x^21)*HPL[{0}, x])/
           (32400*(-9 + x^2)^4*(-1 + x^2)^9) + 
          lm^2*((1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 
              5*x^7 + x^8)/(180*(-1 + x^2)^6) - 
            (2*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
             (3*(-1 + x^2)^7)) + (x*(-23619600 - 135620244*x - 
             11978913420*x^2 + 4633602489*x^3 - 20372261805*x^4 - 
             532364643*x^5 + 7795632330*x^6 - 2772998208*x^7 + 
             2996508960*x^8 + 960603844*x^9 - 1234599070*x^10 - 
             82937602*x^11 + 104931950*x^12 - 7532486*x^13 + 5059230*x^14 + 
             1726192*x^15 - 990280*x^16 - 96128*x^17 + 27330*x^18 + 
             729*x^19 + 375*x^20 + 57*x^21)*HPL[{0, 0}, x])/
           (2700*(-9 + x^2)^4*(-1 + x^2)^9) + 
          lm*((71 + 81*x - 182*x^2 + 10179*x^3 - 4314*x^4 + 10179*x^5 - 
              182*x^6 + 81*x^7 + 71*x^8 + 4*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 
                15*x^5 - 2*x^6 + 5*x^7 + x^8))/(6480*(-1 + x^2)^6) - 
            (x^2*(1 + 413*x - 334*x^2 + 1559*x^3 - 574*x^4 + 833*x^5 - 44*
                x^6 + 15*x^7 + 3*x^8)*HPL[{0}, x])/(135*(-1 + x^2)^7) + 
            ((-1 - 5*x + x^2 - 20*x^3 + x^4 - 5*x^5 - x^6)*HPL[{-1, 0}, x])/
             (135*(-1 + x^2)^5) + (2*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 
               1940*x^4 - 535*x^5 + 545*x^6 - 4*x^7 + 5*x^8 + x^9)*
              HPL[{0, 0}, x])/(135*(-1 + x^2)^8) + 
            ((1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{1, 0}, x])/
             (135*(-1 + x^2)^5)) - (2*(-146 + 2682*x - 2909*x^2 + 8696*x^3 - 
             4568*x^4 + 5405*x^5 - 1397*x^6 + 644*x^7 - 11*x^8 + 3*x^9 + 
             x^10)*HPL[{-1, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^6) + 
          (2*x^3*(445419000 - 190336311*x + 775432845*x^2 + 5632443*x^3 - 
             332973360*x^4 + 150293358*x^5 - 192779280*x^6 - 33539190*x^7 + 
             65856240*x^8 - 1896240*x^9 - 3466830*x^10 + 1149504*x^11 - 
             621840*x^12 - 122062*x^13 + 76600*x^14 + 5878*x^15 - 2600*x^16 - 
             185*x^17 + 25*x^18 + 5*x^19)*HPL[{0, 0, 0}, x])/
           (675*(-9 + x^2)^4*(-1 + x^2)^9) + 
          (2*(-236 + 2008*x - 1089*x^2 + 4844*x^3 + 332*x^4 + 2295*x^5 + 
             533*x^6 + 476*x^7 + 9*x^8 + 7*x^9 + x^10)*HPL[{1, 0, 0}, x])/
           (135*(-1 + x)^6*(1 + x)^8) + ((9092817 + 589431735*x - 
             213992847*x^2 + 1077679890*x^3 - 1504134*x^4 - 98011530*x^5 + 
             97799490*x^6 - 74198550*x^7 - 31941876*x^8 + 21706500*x^9 + 
             2766452*x^10 - 2922730*x^11 + 196758*x^12 + 200730*x^13 - 
             44434*x^14 - 4370*x^15 + 2195*x^16 - 75*x^17 - 21*x^18)*
            master3l8a[x])/(2700*(-9 + x^2)^4*(-1 + x^2)^9) + 
          ((-3030939 - 97495245*x + 28697220*x^2 - 197741025*x^3 + 
             4941612*x^4 - 63294795*x^5 + 1347762*x^6 - 25139745*x^7 + 
             3343890*x^8 + 4605915*x^9 - 971994*x^10 + 715605*x^11 + 
             81860*x^12 - 125585*x^13 - 3218*x^14 + 4525*x^15 + 217*x^16 - 
             50*x^17 - 10*x^18)*master3l9a[x])/(2700*(-9 + x^2)^3*
            (-1 + x^2)^9) + (x^10*(70930497362 - 15684537600*Zeta[3]) + 
            x^14*(663879382 - 11904000*Zeta[3]) + 
            x^17*(60655830 - 5400000*Zeta[3]) + x^20*(566698 - 
              39360*Zeta[3]) + 5*x^22*(-797 + 192*Zeta[3]) + 
            15*x^21*(-2897 + 320*Zeta[3]) - 590490*x*(860959 + 
              15520*Zeta[3]) - 15*x^19*(41839 + 17280*Zeta[3]) + 
            52488*(-200887 + 56520*Zeta[3]) + 3*x^18*(-4717421 + 
              331200*Zeta[3]) - 16*x^16*(-6230327 + 770100*Zeta[3]) + 
            60*x^15*(-18832693 + 5306560*Zeta[3]) - 270*x^13*
             (-38093777 + 16267520*Zeta[3]) + 3645*x^3*(-454059989 + 
              17758080*Zeta[3]) + 729*x^2*(217379693 + 26573760*Zeta[3]) - 
            360*x^9*(-184326259 + 43433920*Zeta[3]) - 
            486*x^4*(-578858207 + 91836000*Zeta[3]) - 
            1620*x^7*(-269517793 + 96184000*Zeta[3]) + 
            12*x^12*(-1129346239 + 148406400*Zeta[3]) + 
            405*x^5*(-2865596539 + 240390720*Zeta[3]) + 
            90*x^11*(-549165631 + 251241600*Zeta[3]) - 
            9*x^6*(12466764877 + 1048536000*Zeta[3]) + 
            8*x^8*(-14383222201 + 5707144800*Zeta[3]))/(194400*(-9 + x^2)^4*
            (-1 + x^2)^9))) + 
      CA*CF*((Pi^2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 
           5*x^7 + x^8)*HPL[{-2}, x])/(270*(-1 + x^2)^6) + 
        lm^2*((-11*(1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 
             5*x^7 + x^8))/(360*(-1 + x^2)^6) + 
          (11*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/
           (3*(-1 + x^2)^7)) - (Pi^2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{2}, x])/(270*(-1 + x^2)^6) + 
        (x*(-30 + 1290*x - 2475*x^2 + 9840*x^3 - 75135*x^4 + 35780*x^5 - 
           50015*x^6 + 37750*x^7 - 38600*x^8 - 61052*x^9 + 31597*x^10 + 
           82454*x^11 - 9660*x^12 - 68520*x^13 - 7500*x^14 + 35160*x^15 + 
           9105*x^16 - 10230*x^17 - 3735*x^18 + 1296*x^19 + 576*x^20)*
          HPL[{-2, 0}, x])/(1350*(-1 + x^2)^8) + 
        ((-5760 - 12960*x + 28710*x^2 + 82860*x^3 - 45585*x^4 - 221910*x^5 - 
           5100*x^6 + 4*(80718 + 25*Pi^2)*x^7 + (145569 + 500*Pi^2)*x^8 - 
           2*(147523 + 2550*Pi^2)*x^9 + 2*(77257 + 12000*Pi^2)*x^10 - 
           32*(6083 + 600*Pi^2)*x^11 + 914024*x^12 + 32*(-6083 + 600*Pi^2)*
            x^13 + (154514 - 24000*Pi^2)*x^14 + (-295046 + 5100*Pi^2)*x^15 + 
           (145569 - 500*Pi^2)*x^16 - 4*(-80718 + 25*Pi^2)*x^17 - 5100*x^18 - 
           221910*x^19 - 45585*x^20 + 82860*x^21 + 28710*x^22 - 12960*x^23 - 
           5760*x^24)*HPL[{-1, 0}, x])/(27000*x^7*(-1 + x^2)^7) + 
        (x*(-11809800 + 520637220*x - 10141162740*x^2 - 547327125*x^3 + 
           303619643865*x^4 - 323011723050*x^5 - 2599762873275*x^6 + 
           5368484145330*x^7 - 1054252087425*x^8 - 33864946932034*x^9 + 
           95235525626947*x^10 + 87203138478249*x^11 - 193499362766224*x^12 - 
           98497791861664*x^13 - 589685341071424*x^14 + 217859066411444*
            x^15 - 271223390649598*x^16 - 71406459566864*x^17 + 
           175121593852890*x^18 - 50666613438579*x^19 - 33777658550463*x^20 + 
           55787234655174*x^21 + 11899592917101*x^22 - 26407866755694*x^23 - 
           7076793104109*x^24 + 7543074059694*x^25 + 2519461764567*x^26 - 
           1317043155969*x^27 - 500083749450*x^28 + 135205894980*x^29 + 
           55407404430*x^30 - 7455133080*x^31 - 3206885580*x^32 + 
           170061120*x^33 + 75582720*x^34)*HPL[{0, 0}, x])/
         (27000*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        ((5760 + 12960*x - 28710*x^2 - 82860*x^3 + 45585*x^4 + 221910*x^5 + 
           5100*x^6 - 4*(80718 + 25*Pi^2)*x^7 - (145569 + 500*Pi^2)*x^8 + 
           (295046 + 5100*Pi^2)*x^9 - 2*(77257 + 12000*Pi^2)*x^10 + 
           32*(6083 + 600*Pi^2)*x^11 - 914024*x^12 - 32*(-6083 + 600*Pi^2)*
            x^13 + 2*(-77257 + 12000*Pi^2)*x^14 + (295046 - 5100*Pi^2)*x^15 + 
           (-145569 + 500*Pi^2)*x^16 + 4*(-80718 + 25*Pi^2)*x^17 + 
           5100*x^18 + 221910*x^19 + 45585*x^20 - 82860*x^21 - 28710*x^22 + 
           12960*x^23 + 5760*x^24)*HPL[{1, 0}, x])/(27000*x^7*(-1 + x^2)^7) + 
        lm*(-(1285 + 3411*x - 9058*x^2 + 185049*x^3 - 94830*x^4 + 
             185049*x^5 - 9058*x^6 + 3411*x^7 + 1285*x^8 + 
             44*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 15*x^5 - 2*x^6 + 5*x^7 + x^
                8))/(12960*(-1 + x^2)^6) + (x^2*(11 + 5803*x - 4934*x^2 + 
             20929*x^3 - 7574*x^4 + 10423*x^5 - 484*x^6 + 165*x^7 + 33*x^8)*
            HPL[{0}, x])/(270*(-1 + x^2)^7) + 
          (11*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{-1, 0}, x])/
           (270*(-1 + x^2)^5) - (11*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 
             1940*x^4 - 535*x^5 + 545*x^6 - 4*x^7 + 5*x^8 + x^9)*
            HPL[{0, 0}, x])/(135*(-1 + x^2)^8) - 
          (11*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{1, 0}, x])/
           (270*(-1 + x^2)^5)) + (x*(30 - 1290*x + 2475*x^2 - 9840*x^3 + 
           75135*x^4 - 35780*x^5 + 50015*x^6 - 37750*x^7 + 38600*x^8 + 
           61052*x^9 - 31597*x^10 - 82454*x^11 + 9660*x^12 + 68520*x^13 + 
           7500*x^14 - 35160*x^15 - 9105*x^16 + 10230*x^17 + 3735*x^18 - 
           1296*x^19 - 576*x^20)*HPL[{2, 0}, x])/(1350*(-1 + x^2)^8) - 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-2, -1, 0}, x])/(45*(-1 + x^2)^6) + 
        (8*x^2*(-24 + 115*x - 121*x^2 + 130*x^3 - 26*x^4 + 5*x^5 + x^6)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x^2)^6) + 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-2, 1, 0}, x])/(45*(-1 + x^2)^6) + 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-1, -2, 0}, x])/(45*(-1 + x^2)^6) - 
        ((576 + 1296*x - 2007*x^2 - 6342*x^3 + 1356*x^4 + 12246*x^5 + 
           3165*x^6 - 11460*x^7 - 6240*x^8 + 5104*x^9 + 5318*x^10 - 
           844*x^11 + 2264*x^12 - 844*x^13 + 5318*x^14 + 5104*x^15 - 
           6240*x^16 - 11460*x^17 + 3165*x^18 + 12246*x^19 + 1356*x^20 - 
           6342*x^21 - 2007*x^22 + 1296*x^23 + 576*x^24)*HPL[{-1, -1, 0}, x])/
         (2700*x^9*(-1 + x^2)^5) + ((-203 + 582*x - 1331*x^2 + 26360*x^3 - 
           44714*x^4 + 74114*x^5 - 37514*x^6 + 41480*x^7 - 11411*x^8 - 
           31053*x^9 + 11245*x^10 + 39816*x^11 - 8736*x^12 - 32004*x^13 + 
           4224*x^14 + 16056*x^15 - 1176*x^16 - 4599*x^17 + 144*x^18 + 
           576*x^19)*HPL[{-1, 0, 0}, x])/(1350*(-1 + x)^8*(1 + x)^6) + 
        ((576 + 1296*x - 2007*x^2 - 6342*x^3 + 1356*x^4 + 12246*x^5 + 
           3165*x^6 - 11460*x^7 - 6240*x^8 + 5104*x^9 + 5318*x^10 - 
           844*x^11 + 2264*x^12 - 844*x^13 + 5318*x^14 + 5104*x^15 - 
           6240*x^16 - 11460*x^17 + 3165*x^18 + 12246*x^19 + 1356*x^20 - 
           6342*x^21 - 2007*x^22 + 1296*x^23 + 576*x^24)*HPL[{-1, 1, 0}, x])/
         (2700*x^9*(-1 + x^2)^5) - (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x^2)^6) + (x*(196830 - 8070030*x + 356513805*x^2 - 
           370005651*x^3 - 9139532535*x^4 + 19576634256*x^5 + 
           42301223811*x^6 - 306290660436*x^7 + 638260657491*x^8 + 
           2261731865694*x^9 - 6554153714892*x^10 - 8665747640091*x^11 + 
           12546516066138*x^12 + 18271448612816*x^13 + 21126767941126*x^14 - 
           25328170972448*x^15 + 30430975020202*x^16 + 22842828791530*x^17 - 
           18465495677669*x^18 - 17527820957353*x^19 + 4294376328381*x^20 + 
           12886004067648*x^21 + 430808558487*x^22 - 7497482831004*x^23 - 
           1329704954265*x^24 + 3052037815194*x^25 + 829593175014*x^26 - 
           820531553769*x^27 - 276736945680*x^28 + 138419510688*x^29 + 
           52752336048*x^30 - 13891928976*x^31 - 5700454866*x^32 + 
           754016364*x^33 + 324467694*x^34 - 17006112*x^35 - 7558272*x^36)*
          HPL[{0, 0, 0}, x])/(1350*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) - 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{1, -2, 0}, x])/(45*(-1 + x^2)^6) + 
        ((576 + 1296*x - 2007*x^2 - 6342*x^3 + 1356*x^4 + 12246*x^5 + 
           3165*x^6 - 11460*x^7 - 6240*x^8 + 5104*x^9 + 5318*x^10 - 
           844*x^11 + 2264*x^12 - 844*x^13 + 5318*x^14 + 5104*x^15 - 
           6240*x^16 - 11460*x^17 + 3165*x^18 + 12246*x^19 + 1356*x^20 - 
           6342*x^21 - 2007*x^22 + 1296*x^23 + 576*x^24)*HPL[{1, -1, 0}, x])/
         (2700*x^9*(-1 + x^2)^5) - ((-203 + 10*x + 1053*x^2 + 28376*x^3 + 
           32774*x^4 + 10266*x^5 + 14558*x^6 + 21464*x^7 + 32805*x^8 + 
           33751*x^9 - 26375*x^10 - 55008*x^11 - 1500*x^12 + 42348*x^13 + 
           17676*x^14 - 14496*x^15 - 11508*x^16 + 585*x^17 + 2448*x^18 + 
           576*x^19)*HPL[{1, 0, 0}, x])/(1350*(-1 + x)^6*(1 + x)^8) - 
        ((576 + 1296*x - 2007*x^2 - 6342*x^3 + 1356*x^4 + 12246*x^5 + 
           3165*x^6 - 11460*x^7 - 6240*x^8 + 5104*x^9 + 5318*x^10 - 
           844*x^11 + 2264*x^12 - 844*x^13 + 5318*x^14 + 5104*x^15 - 
           6240*x^16 - 11460*x^17 + 3165*x^18 + 12246*x^19 + 1356*x^20 - 
           6342*x^21 - 2007*x^22 + 1296*x^23 + 576*x^24)*HPL[{1, 1, 0}, x])/
         (2700*x^9*(-1 + x^2)^5) + (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x^2)^6) + (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{2, -1, 0}, x])/
         (45*(-1 + x^2)^6) - (8*x^2*(-24 + 115*x - 121*x^2 + 130*x^3 - 
           26*x^4 + 5*x^5 + x^6)*HPL[{2, 0, 0}, x])/(45*(-1 + x^2)^6) - 
        (2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{2, 1, 0}, x])/(45*(-1 + x^2)^6) - 
        (4*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{-1, 0, 0, 0}, 
           x])/(45*(-1 + x^2)^5) + (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{-1, 1, 0, 0}, x])/
         (45*(-1 + x^2)^6) + (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{1, -1, 0, 0}, x])/
         (45*(-1 + x^2)^6) + (4*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*
          HPL[{1, 0, 0, 0}, x])/(45*(-1 + x^2)^5) - 
        ((1 + 8*x - 39*x^2 + 359*x^3 - 353*x^4 + 651*x^5 - 161*x^6 + 
           119*x^7 + 12*x^8 + 3*x^9)*master3l10a[x])/(180*(-1 + x^2)^7) + 
        (x*(3 + 12*x + 119*x^2 - 161*x^3 + 651*x^4 - 353*x^5 + 359*x^6 - 
           39*x^7 + 8*x^8 + x^9)*master3l10b[x])/(180*(-1 + x^2)^7) + 
        ((-22599 + 62421354*x - 196915212*x^2 + 366482556*x^3 - 
           205839180*x^4 + 149609106*x^5 + 9454680*x^6 - 88567884*x^7 + 
           25698522*x^8 + 10580814*x^9 - 6134716*x^10 + 118580*x^11 + 
           550620*x^12 - 84170*x^13 - 19792*x^14 + 3612*x^15 + 157*x^16)*
          master3l8a[x])/(10800*(-9 + x^2)^4*(-1 + x^2)^8) + 
        ((40 - 1837*x + 2848*x^2 + 72224*x^3 - 125038*x^4 - 1250220*x^5 + 
           1582952*x^6 + 11916132*x^7 - 7274646*x^8 - 61801058*x^9 + 
           4353216*x^10 + 139324296*x^11 + 6170022*x^12 - 29581524*x^13 + 
           173969208*x^14 + 26955828*x^15 + 5346486*x^16 - 764721*x^17)*
          master3l8b[x])/(10800*x*(1 - 9*x^2)^4*(-1 + x^2)^8) + 
        ((-41229 - 3170826*x + 12432699*x^2 - 11047500*x^3 + 11173503*x^4 - 
           9196338*x^5 + 8456479*x^6 + 4140468*x^7 - 3921479*x^8 - 
           531918*x^9 + 567105*x^10 + 22252*x^11 - 37035*x^12 + 202*x^13 + 
           997*x^14 - 20*x^15)*master3l9a[x])/(3600*(-9 + x^2)^3*
          (-1 + x^2)^8) + ((-20 + 997*x + 202*x^2 - 37035*x^3 + 22252*x^4 + 
           567105*x^5 - 531918*x^6 - 3921479*x^7 + 4140468*x^8 + 
           8456479*x^9 - 9196338*x^10 + 11173503*x^11 - 11047500*x^12 + 
           12432699*x^13 - 3170826*x^14 - 41229*x^15)*master3l9b[x])/
         (10800*x*(-1 + x^2)^8*(-1 + 9*x^2)^3) + 
        (HPL[{1}, x]*(Pi^2*(576 + 1296*x - 2583*x^2 - 7638*x^3 + 3363*x^4 + 
             18588*x^5 + 1809*x^6 - 23706*x^7 - 9405*x^8 + 16564*x^9 + 
             11558*x^10 - 5948*x^11 - 3054*x^12 + 3054*x^14 + 5948*x^15 - 
             11558*x^16 - 16564*x^17 + 9405*x^18 + 23706*x^19 - 1809*x^20 - 
             18588*x^21 - 3363*x^22 + 7638*x^23 + 2583*x^24 - 1296*x^25 - 
             576*x^26) - 1440*x^9*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
             245*x^5 - 50*x^6 + 5*x^7 + x^8)*Zeta[3]))/
         (32400*x^9*(-1 + x^2)^6) + 
        (HPL[{-1}, x]*(Pi^2*(-576 - 1296*x + 2583*x^2 + 7638*x^3 - 3363*x^4 - 
             18588*x^5 - 1809*x^6 + 23706*x^7 + 9405*x^8 - 16564*x^9 - 
             11558*x^10 + 5948*x^11 + 3054*x^12 - 3054*x^14 - 5948*x^15 + 
             11558*x^16 + 16564*x^17 - 9405*x^18 - 23706*x^19 + 1809*x^20 + 
             18588*x^21 + 3363*x^22 - 7638*x^23 - 2583*x^24 + 1296*x^25 + 
             576*x^26) + 1440*x^9*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
             245*x^5 - 50*x^6 + 5*x^7 + x^8)*Zeta[3]))/
         (32400*x^9*(-1 + x^2)^6) + (HPL[{0}, x]*(226748160 + 510183360*x - 
           9507282660*x^2 - 22110307560*x^3 + 161487467640*x^4 + 
           394605046440*x^5 + 1215*(-1168778563 + 3240*Pi^2)*x^6 - 
           4374*(861149891 + 38700*Pi^2)*x^7 - 20*(-9377207229065 + 
             657157005176*Pi^2)*x^19 + 24*(159633707391 + 1271156451320*Pi^2)*
            x^31 + 180*(7925412789 + 46079914813*Pi^2)*x^32 - 
           135*(2929020669 + 60778996808*Pi^2)*x^33 - 
           360*(448576299 + 7687137380*Pi^2)*x^34 + 
           29160*(758241 + 47468968*Pi^2)*x^35 + 
           1620*(5868693 + 325631704*Pi^2)*x^36 - 349920*(1458 + 397003*Pi^2)*
            x^37 - 43740*(5184 + 1303259*Pi^2)*x^38 + 7540163640*Pi^2*x^39 + 
           3244676940*Pi^2*x^40 - 170061120*Pi^2*x^41 - 75582720*Pi^2*x^42 + 
           30*x^18*(10007221817567 + 1964244353636*Pi^2 - 5220591091200*
              Zeta[3]) + 12*x^15*(-18243162336697 + 45222440320*Pi^2 - 
             2195366976000*Zeta[3]) + 3*x^28*(2435097086541 + 
             1842971916740*Pi^2 - 97627680000*Zeta[3]) - 
           81*x^10*(214085735633 + 4500*Pi^2 - 3615840000*Zeta[3]) - 
           6*x^30*(1116927497007 + 2216188370180*Pi^2 - 1417176000*Zeta[3]) + 
           27*x^8*(253885802771 + 6714900*Pi^2 - 314928000*Zeta[3]) + 
           81*x^9*(260701084897 + 60220800*Pi^2 + 104976000*Zeta[3]) - 
           450*x^11*(162555269027 + 94723992*Pi^2 + 688642560*Zeta[3]) - 
           6*x^29*(3840147140247 + 12437287972580*Pi^2 + 1417176000*
              Zeta[3]) + 30*x^27*(3372238047255 + 4140862781336*Pi^2 + 
             10329638400*Zeta[3]) + 18*x^13*(8962990419283 + 
             2694022500*Pi^2 + 236703384000*Zeta[3]) + 
           60*x^14*(2200981212237 + 62149398400*Pi^2 + 291744828000*
              Zeta[3]) - 9*x^12*(-1036110693347 + 22448026500*Pi^2 + 
             403597728000*Zeta[3]) - 6*x^16*(101178006747923 + 
             4207986708690*Pi^2 + 929879568000*Zeta[3]) + 
           3*x^26*(44423908626009 + 7204364199380*Pi^2 + 1210793184000*
              Zeta[3]) - 5*x^24*(173931429546279 + 9820611655840*Pi^2 + 
             3500937936000*Zeta[3]) - x^25*(373899649098169 + 
             143381162972080*Pi^2 + 4260660912000*Zeta[3]) + 
           x^22*(1198090137251163 + 37941449649460*Pi^2 + 5579277408000*
              Zeta[3]) + 2*x^23*(508827579850707 + 57525698624360*Pi^2 + 
             13172201856000*Zeta[3]) - 4*x^21*(338470872522069 + 
             13975303708100*Pi^2 + 15711784488000*Zeta[3]) + 
           3*x^17*(57129955100017 + 755498057080*Pi^2 + 20949045984000*
              Zeta[3]) + 10*x^20*(305602153708*Pi^2 + 
             51*(6096140591399 + 307093593600*Zeta[3]))))/
         (324000*x^5*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        (240*Pi^4*x^7*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (-3 - 15*x - 234*x^2 + 1105*x^3 - 1210*x^4 + 1345*x^5 - 266*x^6 + 
            65*x^7 + 13*x^8) + 12*Pi^2*(9 - 82*x^2 + 9*x^4)^4*
           (-5760 - 12960*x + 34470*x^2 + 95820*x^3 - 74295*x^4 - 
            304770*x^5 + 40485*x^6 + 544782*x^7 + 150669*x^8 - 617918*x^9 + 
            8945*x^10 + 100390*x^11 + 759510*x^12 - 759510*x^14 - 
            100390*x^15 - 8945*x^16 + 617918*x^17 - 150669*x^18 - 
            544782*x^19 - 40485*x^20 + 304770*x^21 + 74295*x^22 - 
            95820*x^23 - 34470*x^24 + 12960*x^25 + 5760*x^26) + 
          x^2*(-680244480 - 1530550080*x + 28748596140*x^2 + 
            66841106040*x^3 - 493796081520*x^4 - 271445891040*x^39*Zeta[3] - 
            116808369840*x^40*Zeta[3] + 6122200320*x^41*Zeta[3] + 
            2720977920*x^42*Zeta[3] + 32805*x^5*(-36950231 + 35712*Zeta[3]) - 
            29160*x^6*(-143812181 + 373734*Zeta[3]) + 6298560*x^37*
             (-243 + 794006*Zeta[3]) + 1574640*x^38*(-432 + 1303259*Zeta[
                3]) - 2916*x^7*(-4377968929 + 22298040*Zeta[3]) + 
            324*x^8*(-48848934413 + 50043420*Zeta[3]) - 262440*x^35*
             (-254691 + 189875872*Zeta[3]) - 14580*x^36*(-1971783 + 
              1302526816*Zeta[3]) + 243*x^9*(-409374449101 + 5484234240*Zeta[
                3]) - 3888*x^12*(63319044551 + 43904811430*Zeta[3]) + 
            1620*x^34*(-304867071 + 61497099040*Zeta[3]) - 
            2376*x^28*(-39647528981 + 79567955540*Zeta[3]) + 
            108*x^10*(158282931857 + 81467820360*Zeta[3]) - 
            3240*x^32*(-1372570209 + 92162347592*Zeta[3]) - 
            72*x^11*(-8741359875197 + 191986282800*Zeta[3]) + 
            1215*x^33*(-991342287 + 243117379136*Zeta[3]) - 
            180*x^15*(-20146975664831 + 3888368468320*Zeta[3]) + 
            108*x^30*(-218759101089 + 4431734617720*Zeta[3]) - 
            108*x^26*(3544925516111 + 8908407494360*Zeta[3]) - 
            108*x^31*(-105503235183 + 10170104676640*Zeta[3]) + 
            108*x^14*(24738394306711 + 11888060251000*Zeta[3]) + 
            5*x^13*(-508973095636355 + 19571874780096*Zeta[3]) - 
            180*x^23*(5148170516389 + 26935017844496*Zeta[3]) - 
            96*x^16*(45015231369733 + 40838011131840*Zeta[3]) - 
            256*x^19*(-39778711073069 + 45761028781590*Zeta[3]) - 
            72*x^27*(-1528442446997 + 62364673334640*Zeta[3]) + 
            36*x^24*(25186501622883 + 88528634951200*Zeta[3]) + 
            27*x^29*(-2124046149759 + 99566730260800*Zeta[3]) + 
            24*x^18*(-645092073920849 + 101631649404120*Zeta[3]) - 
            48*x^22*(-42754999128709 + 127233754812630*Zeta[3]) + 
            12*x^20*(-765758728457623 + 351105001992240*Zeta[3]) + 
            5*x^25*(48848328816415 + 1054649176336512*Zeta[3]) + 
            3*x^17*(931574668022351 + 1384278704792640*Zeta[3]) + 
            x^21*(-3111682800853497 + 6272777047512960*Zeta[3])))/
         (3888000*x^7*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4)) + 
      CF^2*(-(Pi^2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 
            5*x^7 + x^8)*HPL[{-2}, x])/(135*(-1 + x^2)^6) + 
        lm^2*((1 + 5*x - 14*x^2 + 145*x^3 - 94*x^4 + 145*x^5 - 14*x^6 + 
            5*x^7 + x^8)/(10*(-1 + x^2)^6) - 
          (12*x^3*(1 - x + 3*x^2 - x^3 + x^4)*HPL[{0}, x])/(-1 + x^2)^7) + 
        (Pi^2*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 
           5*x^7 + x^8)*HPL[{2}, x])/(135*(-1 + x^2)^6) + 
        (x*(60 - 2580*x + 16890*x^2 - 28500*x^3 + 216150*x^4 - 102320*x^5 + 
           43190*x^6 - 147130*x^7 + 325660*x^8 + 412803*x^9 - 418722*x^10 - 
           812413*x^11 + 317296*x^12 + 989548*x^13 - 61264*x^14 - 
           773847*x^15 - 109254*x^16 + 379803*x^17 + 106026*x^18 - 
           106896*x^19 - 40512*x^20 + 13200*x^21 + 6000*x^22)*
          HPL[{-2, 0}, x])/(1350*(-1 + x^2)^8) + 
        ((-360000 - 792000*x + 1890720*x^2 + 5225760*x^3 - 3375480*x^4 - 
           14619540*x^5 + 719220*x^6 + 22357110*x^7 + 6087840*x^8 - 
           (19946173 + 1200*Pi^2)*x^9 - 20*(505147 + 300*Pi^2)*x^10 + 
           3*(3422023 + 20400*Pi^2)*x^11 - 40*(-90929 + 7200*Pi^2)*x^12 + 
           (2858734 + 230400*Pi^2)*x^13 - 21084240*x^14 + 
           (2858734 - 230400*Pi^2)*x^15 + 40*(90929 + 7200*Pi^2)*x^16 + 
           (10266069 - 61200*Pi^2)*x^17 + 20*(-505147 + 300*Pi^2)*x^18 + 
           (-19946173 + 1200*Pi^2)*x^19 + 6087840*x^20 + 22357110*x^21 + 
           719220*x^22 - 14619540*x^23 - 3375480*x^24 + 5225760*x^25 + 
           1890720*x^26 - 792000*x^27 - 360000*x^28)*HPL[{-1, 0}, x])/
         (162000*x^9*(-1 + x^2)^7) + (x*(70858800 - 3317897700*x + 
           71883628200*x^2 + 12478132620*x^3 - 2150931959550*x^4 + 
           1738112221170*x^5 + 18679600823850*x^6 - 29584605691575*x^7 + 
           1022929740630*x^8 + 180954915419358*x^9 - 610476981434370*x^10 - 
           403923962550363*x^11 + 1044673618325640*x^12 + 
           193054704625498*x^13 + 5107315230871640*x^14 - 
           354355949021818*x^15 + 315663050111780*x^16 - 1743757818268912*
            x^17 + 67099971371540*x^18 + 3401247748578478*x^19 - 
           349345453104030*x^20 - 3278082703495218*x^21 - 
           174097018768470*x^22 + 2058560083476093*x^23 + 
           382888271550270*x^24 - 868106451224538*x^25 - 244356928116570*
            x^26 + 239270788678113*x^27 + 83224339080660*x^28 - 
           41099739060330*x^29 - 16104161938860*x^30 + 4178057178420*x^31 + 
           1758604578840*x^32 - 228859227360*x^33 - 100847293920*x^34 + 
           5196312000*x^35 + 2361960000*x^36)*HPL[{0, 0}, x])/
         (81000*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4) + 
        ((360000 + 792000*x - 1890720*x^2 - 5225760*x^3 + 3375480*x^4 + 
           14619540*x^5 - 719220*x^6 - 22357110*x^7 - 6087840*x^8 + 
           (19946173 + 1200*Pi^2)*x^9 + 20*(505147 + 300*Pi^2)*x^10 - 
           3*(3422023 + 20400*Pi^2)*x^11 + 40*(-90929 + 7200*Pi^2)*x^12 - 
           2*(1429367 + 115200*Pi^2)*x^13 + 21084240*x^14 + 
           (-2858734 + 230400*Pi^2)*x^15 - 40*(90929 + 7200*Pi^2)*x^16 + 
           3*(-3422023 + 20400*Pi^2)*x^17 - 20*(-505147 + 300*Pi^2)*x^18 + 
           (19946173 - 1200*Pi^2)*x^19 - 6087840*x^20 - 22357110*x^21 - 
           719220*x^22 + 14619540*x^23 + 3375480*x^24 - 5225760*x^25 - 
           1890720*x^26 + 792000*x^27 + 360000*x^28)*HPL[{1, 0}, x])/
         (162000*x^9*(-1 + x^2)^7) + 
        lm*((22 - 27*x + 98*x^2 + 3132*x^3 - 888*x^4 + 3132*x^5 + 98*x^6 - 
            27*x^7 + 22*x^8 + 2*Pi^2*(-1 - 5*x + 2*x^2 - 15*x^3 + 15*x^5 - 
              2*x^6 + 5*x^7 + x^8))/(180*(-1 + x^2)^6) - 
          (x^2*(2 + 691*x - 533*x^2 + 2713*x^3 - 1013*x^4 + 1531*x^5 - 
             88*x^6 + 30*x^7 + 6*x^8)*HPL[{0}, x])/(15*(-1 + x^2)^7) - 
          (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{-1, 0}, x])/
           (15*(-1 + x^2)^5) + (4*x^3*(180 - 180*x + 1260*x^2 - 800*x^3 + 
             1940*x^4 - 535*x^5 + 545*x^6 - 4*x^7 + 5*x^8 + x^9)*
            HPL[{0, 0}, x])/(15*(-1 + x^2)^8) + 
          (2*(1 + 5*x - x^2 + 20*x^3 - x^4 + 5*x^5 + x^6)*HPL[{1, 0}, x])/
           (15*(-1 + x^2)^5)) - (x*(60 - 2580*x + 16890*x^2 - 28500*x^3 + 
           216150*x^4 - 102320*x^5 + 43190*x^6 - 147130*x^7 + 325660*x^8 + 
           412803*x^9 - 418722*x^10 - 812413*x^11 + 317296*x^12 + 
           989548*x^13 - 61264*x^14 - 773847*x^15 - 109254*x^16 + 
           379803*x^17 + 106026*x^18 - 106896*x^19 - 40512*x^20 + 
           13200*x^21 + 6000*x^22)*HPL[{2, 0}, x])/(1350*(-1 + x^2)^8) + 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-2, -1, 0}, x])/(45*(-1 + x^2)^6) - 
        (8*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-2, 0, 0}, x])/(45*(-1 + x^2)^6) - 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-2, 1, 0}, x])/(45*(-1 + x^2)^6) - 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{-1, -2, 0}, x])/(45*(-1 + x^2)^6) + 
        ((-6000 - 13200*x + 10512*x^2 + 40896*x^3 + 6534*x^4 - 43323*x^5 - 
           23196*x^6 + 16272*x^7 + 15064*x^8 + 2*x^9 - 3236*x^10 - 847*x^11 - 
           356*x^12 - 847*x^13 - 3236*x^14 + 2*x^15 + 15064*x^16 + 
           16272*x^17 - 23196*x^18 - 43323*x^19 + 6534*x^20 + 40896*x^21 + 
           10512*x^22 - 13200*x^23 - 6000*x^24)*HPL[{-1, -1, 0}, x])/
         (2700*x^11*(-1 + x^2)^3) + ((153 - 2802*x + 14646*x^2 - 101362*x^3 + 
           193122*x^4 - 253486*x^5 + 130774*x^6 - 164026*x^7 + 85492*x^8 + 
           228740*x^9 - 119834*x^10 - 408550*x^11 + 125034*x^12 + 
           475778*x^13 - 87042*x^14 - 362958*x^15 + 39111*x^16 + 
           175482*x^17 - 10272*x^18 - 48912*x^19 + 1200*x^20 + 6000*x^21)*
          HPL[{-1, 0, 0}, x])/(1350*(-1 + x)^8*(1 + x)^6) + 
        ((6000 + 13200*x - 10512*x^2 - 40896*x^3 - 6534*x^4 + 43323*x^5 + 
           23196*x^6 - 16272*x^7 - 15064*x^8 - 2*x^9 + 3236*x^10 + 847*x^11 + 
           356*x^12 + 847*x^13 + 3236*x^14 - 2*x^15 - 15064*x^16 - 
           16272*x^17 + 23196*x^18 + 43323*x^19 - 6534*x^20 - 40896*x^21 - 
           10512*x^22 + 13200*x^23 + 6000*x^24)*HPL[{-1, 1, 0}, x])/
         (2700*x^11*(-1 + x^2)^3) + (4*(1 + 5*x - 50*x^2 + 245*x^3 - 
           242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x^2)^6) - (x*(-196830 + 8857350*x + 332588025*x^2 - 
           355269159*x^3 - 9018876960*x^4 + 562710753*x^5 + 71409011454*x^6 + 
           152761356072*x^7 - 64358188680*x^8 - 2674235367660*x^9 + 
           300284572803*x^10 + 18039998897457*x^11 - 19094877285798*x^12 - 
           46282689270877*x^13 + 83161616473588*x^14 + 24387812783387*x^15 - 
           12282103060040*x^16 - 86774374448164*x^17 + 88623403078063*x^18 + 
           135012094617754*x^19 - 77789478865834*x^20 - 164926038657617*
            x^21 + 38199573272414*x^22 + 158484501831526*x^23 - 
           3152853262384*x^24 - 112692046835100*x^25 - 13874744389707*x^26 + 
           57693941276433*x^27 + 13055621594886*x^28 - 20734392938211*x^29 - 
           6264061915392*x^30 + 5044216698951*x^31 + 1801819466862*x^32 - 
           791032772106*x^33 - 313066501632*x^34 + 75391852491*x^35 + 
           31847661162*x^36 - 3944228256*x^37 - 1739837232*x^38 + 
           86605200*x^39 + 39366000*x^40)*HPL[{0, 0, 0}, x])/
         (675*(-1 + x^2)^9*(9 - 82*x^2 + 9*x^4)^4) + 
        (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
           x^8)*HPL[{1, -2, 0}, x])/(45*(-1 + x^2)^6) + 
        ((6000 + 13200*x - 10512*x^2 - 40896*x^3 - 6534*x^4 + 43323*x^5 + 
           23196*x^6 - 16272*x^7 - 15064*x^8 - 2*x^9 + 3236*x^10 + 847*x^11 + 
           356*x^12 + 847*x^13 + 3236*x^14 - 2*x^15 - 15064*x^16 - 
           16272*x^17 + 23196*x^18 + 43323*x^19 - 6534*x^20 - 40896*x^21 - 
           10512*x^22 + 13200*x^23 + 6000*x^24)*HPL[{1, -1, 0}, x])/
         (2700*x^11*(-1 + x^2)^3) + ((-153 + 2670*x - 1302*x^2 + 73598*x^3 + 
           84254*x^4 - 12390*x^5 - 4358*x^6 + 83734*x^7 + 224412*x^8 + 
           133392*x^9 - 378366*x^10 - 470166*x^11 + 249934*x^12 + 
           652738*x^13 + 65994*x^14 - 459486*x^15 - 211119*x^16 + 
           146502*x^17 + 124320*x^18 - 3888*x^19 - 25200*x^20 - 6000*x^21)*
          HPL[{1, 0, 0}, x])/(1350*(-1 + x)^6*(1 + x)^8) + 
        ((-6000 - 13200*x + 10512*x^2 + 40896*x^3 + 6534*x^4 - 43323*x^5 - 
           23196*x^6 + 16272*x^7 + 15064*x^8 + 2*x^9 - 3236*x^10 - 847*x^11 - 
           356*x^12 - 847*x^13 - 3236*x^14 + 2*x^15 + 15064*x^16 + 
           16272*x^17 - 23196*x^18 - 43323*x^19 + 6534*x^20 + 40896*x^21 + 
           10512*x^22 - 13200*x^23 - 6000*x^24)*HPL[{1, 1, 0}, x])/
         (2700*x^11*(-1 + x^2)^3) - (4*(1 + 5*x - 50*x^2 + 245*x^3 - 
           242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x^2)^6) - (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{2, -1, 0}, x])/
         (45*(-1 + x^2)^6) + (8*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{2, 0, 0}, x])/
         (45*(-1 + x^2)^6) + (4*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{2, 1, 0}, x])/
         (45*(-1 + x^2)^6) - (8*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{-1, 1, 0, 0}, x])/
         (45*(-1 + x^2)^6) - (8*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
           245*x^5 - 50*x^6 + 5*x^7 + x^8)*HPL[{1, -1, 0, 0}, x])/
         (45*(-1 + x^2)^6) + ((1 + 8*x - 39*x^2 + 359*x^3 - 353*x^4 + 
           651*x^5 - 161*x^6 + 119*x^7 + 12*x^8 + 3*x^9)*master3l10a[x])/
         (90*(-1 + x^2)^7) - (x*(3 + 12*x + 119*x^2 - 161*x^3 + 651*x^4 - 
           353*x^5 + 359*x^6 - 39*x^7 + 8*x^8 + x^9)*master3l10b[x])/
         (90*(-1 + x^2)^7) - ((-22599 + 62421354*x - 196915212*x^2 + 
           366482556*x^3 - 205839180*x^4 + 149609106*x^5 + 9454680*x^6 - 
           88567884*x^7 + 25698522*x^8 + 10580814*x^9 - 6134716*x^10 + 
           118580*x^11 + 550620*x^12 - 84170*x^13 - 19792*x^14 + 3612*x^15 + 
           157*x^16)*master3l8a[x])/(5400*(-9 + x^2)^4*(-1 + x^2)^8) - 
        ((40 - 1837*x + 2848*x^2 + 72224*x^3 - 125038*x^4 - 1250220*x^5 + 
           1582952*x^6 + 11916132*x^7 - 7274646*x^8 - 61801058*x^9 + 
           4353216*x^10 + 139324296*x^11 + 6170022*x^12 - 29581524*x^13 + 
           173969208*x^14 + 26955828*x^15 + 5346486*x^16 - 764721*x^17)*
          master3l8b[x])/(5400*x*(1 - 9*x^2)^4*(-1 + x^2)^8) + 
        ((41229 + 3170826*x - 12432699*x^2 + 11047500*x^3 - 11173503*x^4 + 
           9196338*x^5 - 8456479*x^6 - 4140468*x^7 + 3921479*x^8 + 
           531918*x^9 - 567105*x^10 - 22252*x^11 + 37035*x^12 - 202*x^13 - 
           997*x^14 + 20*x^15)*master3l9a[x])/(1800*(-9 + x^2)^3*
          (-1 + x^2)^8) + ((20 - 997*x - 202*x^2 + 37035*x^3 - 22252*x^4 - 
           567105*x^5 + 531918*x^6 + 3921479*x^7 - 4140468*x^8 - 
           8456479*x^9 + 9196338*x^10 - 11173503*x^11 + 11047500*x^12 - 
           12432699*x^13 + 3170826*x^14 + 41229*x^15)*master3l9b[x])/
         (5400*x*(-1 + x^2)^8*(-1 + 9*x^2)^3) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(6000 + 13200*x - 10512*x^2 - 
             40896*x^3 - 6534*x^4 + 43323*x^5 + 23196*x^6 - 16272*x^7 - 
             15064*x^8 - 2*x^9 + 3236*x^10 + 847*x^11 + 356*x^12 + 847*x^13 + 
             3236*x^14 - 2*x^15 - 15064*x^16 - 16272*x^17 + 23196*x^18 + 
             43323*x^19 - 6534*x^20 - 40896*x^21 - 10512*x^22 + 13200*x^23 + 
             6000*x^24) - 2880*x^11*(1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 
             245*x^5 - 50*x^6 + 5*x^7 + x^8)*Zeta[3]))/
         (32400*x^11*(-1 + x^2)^6) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(6000 + 13200*x - 10512*x^2 - 
              40896*x^3 - 6534*x^4 + 43323*x^5 + 23196*x^6 - 16272*x^7 - 
              15064*x^8 - 2*x^9 + 3236*x^10 + 847*x^11 + 356*x^12 + 
              847*x^13 + 3236*x^14 - 2*x^15 - 15064*x^16 - 16272*x^17 + 
              23196*x^18 + 43323*x^19 - 6534*x^20 - 40896*x^21 - 10512*x^22 + 
              13200*x^23 + 6000*x^24)) + 2880*x^11*(1 + 5*x - 50*x^2 + 
             245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + x^8)*Zeta[3]))/
         (32400*x^11*(-1 + x^2)^6) + (HPL[{0}, x]*(2361960000 + 
           5196312000*x - 99666313920*x^2 - 226261071360*x^3 + 
           1708968251880*x^4 + 4065359668740*x^5 - 15257884924080*x^6 - 
           39085697802240*x^7 - 90*(-841480793707 + 87480*Pi^2)*x^8 + 
           9*(24453266583499 + 37616400*Pi^2)*x^9 + 
           40*(-1067590990125 + 67347665356*Pi^2)*x^21 - 
           3*(73409723590197 + 275219744708300*Pi^2)*x^33 - 
           120*(631195103694 + 1385051667943*Pi^2)*x^34 + 
           30*(1302921558243 + 10939773241478*Pi^2)*x^35 + 
           240*(63574520517 + 395430146686*Pi^2)*x^36 - 
           60*(67755994479 + 1441572718760*Pi^2)*x^37 - 
           120*(14241402099 + 253150025860*Pi^2)*x^38 + 
           540*(419001984 + 26648094173*Pi^2)*x^39 + 
           1080*(92283624 + 5239246513*Pi^2)*x^40 - 
           72900*(71280 + 19625303*Pi^2)*x^41 - 145800*(16200 + 4135417*Pi^2)*
            x^42 + 77152461120*Pi^2*x^43 + 34009424640*Pi^2*x^44 - 
           1732104000*Pi^2*x^45 - 787320000*Pi^2*x^46 + 
           20*x^22*(-196956623369393 + 10306452272572*Pi^2 - 
             15661773273600*Zeta[3]) - 20*x^20*(159989558716117 + 
             11133338135460*Pi^2 - 15661773273600*Zeta[3]) + 
           18*x^15*(-139526265847877 + 19244079300*Pi^2 - 473406768000*
              Zeta[3]) - 270*x^14*(99360124033 + 222429620*Pi^2 - 
             26906515200*Zeta[3]) + 30*x^12*(9506002496831 + 
             1615196700*Pi^2 - 19525536000*Zeta[3]) - 
           90*x^10*(2308101097681 + 21437460*Pi^2 - 188956800*Zeta[3]) + 
           120*x^32*(1727993960877 + 927664667132*Pi^2 - 141717600*Zeta[3]) - 
           144*x^11*(5290119729517 + 59711175*Pi^2 + 118098000*Zeta[3]) + 
           18*x^31*(42560441575511 + 79299363083680*Pi^2 + 
             944784000*Zeta[3]) - 160*x^29*(11007900948687 + 
             10817628087980*Pi^2 + 3873614400*Zeta[3]) + 
           120*x^13*(14172502601531 + 392571360*Pi^2 + 5164819200*Zeta[3]) + 
           10*x^30*(-26522862153783 + 17098645091924*Pi^2 + 
             58576608000*Zeta[3]) + 20*x^18*(119461452102271 + 
             3510358060782*Pi^2 + 557927740800*Zeta[3]) - 
           10*x^28*(24487340011839 + 53963807540636*Pi^2 + 726475910400*
              Zeta[3]) - 10*x^24*(313548979755737 + 52711150882220*Pi^2 + 
             1115855481600*Zeta[3]) - 20*x^16*(37809675891739 + 
             359568484620*Pi^2 + 1750468968000*Zeta[3]) + 
           4*x^27*(738097172779509 + 370076282866310*Pi^2 + 
             2130330456000*Zeta[3]) + 10*x^26*(210272084631443 + 
             69984338447424*Pi^2 + 3500937936000*Zeta[3]) - 
           9*x^25*(435695304656879 + 98287583861140*Pi^2 + 5854311936000*
              Zeta[3]) - 6*x^19*(204125831035669 + 309329879770*Pi^2 + 
             20949045984000*Zeta[3]) + 4*x^23*(801613783049991 + 
             85080835391795*Pi^2 + 31423568976000*Zeta[3]) + 
           x^17*(-3067446117660*Pi^2 + 99*(23868572330689 + 532210176000*
                Zeta[3]))))/(324000*x^7*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^
           4) + (-4800*Pi^4*x^9*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^4*
           (1 + 5*x - 50*x^2 + 245*x^3 - 242*x^4 + 245*x^5 - 50*x^6 + 5*x^7 + 
            x^8) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^4*(-360000 - 792000*x + 
            2250720*x^2 + 6017760*x^3 - 5266200*x^4 - 19845300*x^5 + 
            4094700*x^6 + 36976650*x^7 + 5368620*x^8 - 42303283*x^9 - 
            16190780*x^10 + 30212242*x^11 + 13740100*x^12 - 7407335*x^13 - 
            24721400*x^14 + 24721400*x^16 + 7407335*x^17 - 13740100*x^18 - 
            30212242*x^19 + 16190780*x^20 + 42303283*x^21 - 5368620*x^22 - 
            36976650*x^23 - 4094700*x^24 + 19845300*x^25 + 5266200*x^26 - 
            6017760*x^27 - 2250720*x^28 + 792000*x^29 + 360000*x^30) + 
          x^2*(-14171760000 - 31177872000*x + 602721803520*x^2 + 
            1367959052160*x^3 - 10451370669120*x^4 - 24840782921160*x^5 + 
            94891126168800*x^6 + x^23*(21385978407334551 - 38368262276942400*
               Zeta[3]) + x^11*(5124021431135679 - 9563875571520*Zeta[3]) - 
            5554977200640*x^43*Zeta[3] - 2448678574080*x^44*Zeta[3] + 
            124711488000*x^45*Zeta[3] + 56687040000*x^46*Zeta[3] + 
            10497600*x^42*(-1350 + 4135417*Zeta[3]) - 
            1215*x^7*(-199590778795 + 7177248*Zeta[3]) + 
            1080*x^8*(-446908487201 + 13629384*Zeta[3]) + 
            5248800*x^41*(-5940 + 19625303*Zeta[3]) + 
            360*x^10*(3773725899173 + 1227315240*Zeta[3]) - 
            77760*x^40*(-7751052 + 5239246513*Zeta[3]) - 
            4320*x^12*(429641255719 + 6961503204*Zeta[3]) + 
            54*x^9*(-25931427110713 + 8880833520*Zeta[3]) - 
            38880*x^39*(-35184132 + 26648094173*Zeta[3]) + 
            8640*x^38*(-1209649383 + 253150025860*Zeta[3]) + 
            720*x^14*(1581331416599 + 705169925640*Zeta[3]) + 
            36*x^13*(-369257561718367 + 2458956703680*Zeta[3]) - 
            2160*x^36*(-43931240955 + 3163441173488*Zeta[3]) - 
            8640*x^22*(-4243906014317 + 3959111613024*Zeta[3]) + 
            1080*x^37*(-23000724927 + 5766290875040*Zeta[3]) - 
            720*x^20*(-85888566797409 + 6786728434624*Zeta[3]) + 
            1080*x^34*(-447847614161 + 11080410701648*Zeta[3]) + 
            2880*x^28*(585148840991 + 13679519349434*Zeta[3]) - 
            720*x^30*(3006225157749 + 17146377549848*Zeta[3]) - 
            360*x^32*(-3860380656593 + 22261436203008*Zeta[3]) + 
            90*x^17*(-357958617378017 + 22526303064672*Zeta[3]) - 
            120*x^16*(64394914339355 + 31126677591264*Zeta[3]) - 
            675*x^35*(-359217941391 + 35007292330624*Zeta[3]) - 
            5*x^15*(-5393814643684217 + 86519143468224*Zeta[3]) + 
            120*x^18*(126138856679801 + 96215483140752*Zeta[3]) + 
            120*x^24*(-86317882309279 + 449804167666656*Zeta[3]) - 
            120*x^26*(5560496782655 + 455411214775248*Zeta[3]) + 
            90*x^25*(-155597447928257 + 729639872223552*Zeta[3]) + 
            54*x^33*(-25829811703513 + 1100890858481120*Zeta[3]) + 
            36*x^29*(-311554222292767 + 3464697277478080*Zeta[3]) - 
            3*x^19*(746549604115883 + 4520600529945600*Zeta[3]) + 
            8*x^21*(-5300158343875999 + 5946737595334560*Zeta[3]) - 
            9*x^31*(-550611827864831 + 11420486445758400*Zeta[3]) - 
            5*x^27*(-3162528945873137 + 21413527913448000*Zeta[3])))/
         (7776000*x^9*(-1 + x^2)^8*(9 - 82*x^2 + 9*x^4)^4)))
 
CbarLData["a", 2, 3] = 
    NC*(CF*(NL*(-(Pi^2*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 
              6*x^7 + x^8)*HPL[{-1}, x])/(1620*(-1 + x^2)^7) + 
          (x^2*(-1233 + 63*(45809 + 3000*Pi^2)*x - 18*(195203 + 15750*Pi^2)*
              x^2 + 63*(254581 + 24000*Pi^2)*x^3 - 4*(1953451 + 301875*Pi^2)*
              x^4 + 210*(18871 + 13200*Pi^2)*x^5 + (5742014 - 1198050*Pi^2)*
              x^6 + 252*(-70094 + 5925*Pi^2)*x^7 + (5504139 - 285390*Pi^2)*
              x^8 + 63*(-82579 + 3120*Pi^2)*x^9 + (89398 - 1050*Pi^2)*x^10 + 
             105*(-203 + 12*Pi^2)*x^11 + 70*(-98 + 3*Pi^2)*x^12)*HPL[{0}, x])/
           (340200*(-1 + x^2)^10) + lm^2*((1 + 6*x - 23*x^2 + 356*x^3 - 
              398*x^4 + 956*x^5 - 398*x^6 + 356*x^7 - 23*x^8 + 6*x^9 + x^10)/
             (240*(-1 + x^2)^8) - (x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*
                x^5 + 2*x^6)*HPL[{0}, x])/(2*(-1 + x^2)^9)) + 
          (Pi^2*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + 
             x^8)*HPL[{1}, x])/(1620*(-1 + x^2)^7) - 
          (x^3*(900 - 1350*x + 7200*x^2 - 5750*x^3 + 13200*x^4 - 5705*x^5 + 
             7110*x^6 - 1359*x^7 + 936*x^8 - 5*x^9 + 6*x^10 + x^11)*
            HPL[{-2, 0}, x])/(135*(-1 + x^2)^10) + 
          ((137 + 602*x - 13968*x^2 + 347774*x^3 - 454821*x^4 + 1706264*x^5 - 
             1046216*x^6 + 1706264*x^7 - 454821*x^8 + 347774*x^9 - 
             13968*x^10 + 602*x^11 + 137*x^12)*HPL[{-1, 0}, x])/
           (37800*(-1 + x^2)^9) + (x^3*(84000 - 126000*x + 861000*x^2 - 
             721000*x^3 + 2212000*x^4 - 1045275*x^5 + 1668450*x^6 - 
             344757*x^7 + 291228*x^8 - 1365*x^9 + 3178*x^10 + 493*x^11)*
            HPL[{0, 0}, x])/(18900*(-1 + x^2)^10) - 
          ((137 + 602*x - 13968*x^2 + 347774*x^3 - 454821*x^4 + 1706264*x^5 - 
             1046216*x^6 + 1706264*x^7 - 454821*x^8 + 347774*x^9 - 
             13968*x^10 + 602*x^11 + 137*x^12)*HPL[{1, 0}, x])/
           (37800*(-1 + x^2)^9) + lm*((196 + 609*x - 2127*x^2 + 67404*x^3 - 
              61321*x^4 + 180630*x^5 - 61321*x^6 + 67404*x^7 - 2127*x^8 + 
              609*x^9 + 196*x^10 + 6*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 
                16*x^4 - 16*x^6 + 48*x^7 - 3*x^8 + 6*x^9 + x^10))/
             (19440*(-1 + x^2)^8) - (x^2*(2 + 2412*x - 3130*x^2 + 16758*x^3 - 
               11358*x^4 + 22158*x^5 - 6505*x^6 + 5562*x^7 - 214*x^8 + 54*
                x^9 + 9*x^10)*HPL[{0}, x])/(540*(-1 + x^2)^9) - 
            ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^
                8)*HPL[{-1, 0}, x])/(270*(-1 + x^2)^7) + 
            (x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 13200*x^4 - 7055*x^5 + 
               9810*x^6 - 2169*x^7 + 1476*x^8 - 5*x^9 + 6*x^10 + x^11)*
              HPL[{0, 0}, x])/(135*(-1 + x^2)^10) + 
            ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^
                8)*HPL[{1, 0}, x])/(270*(-1 + x^2)^7)) + 
          (x^3*(900 - 1350*x + 7200*x^2 - 5750*x^3 + 13200*x^4 - 5705*x^5 + 
             7110*x^6 - 1359*x^7 + 936*x^8 - 5*x^9 + 6*x^10 + x^11)*
            HPL[{2, 0}, x])/(135*(-1 + x^2)^10) + 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{-1, -1, 0}, x])/(135*(-1 + x^2)^7) - 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{-1, 1, 0}, x])/(135*(-1 + x^2)^7) - 
          (2*x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 13200*x^4 - 7055*x^5 + 
             9810*x^6 - 2169*x^7 + 1476*x^8 - 5*x^9 + 6*x^10 + x^11)*
            HPL[{0, 0, 0}, x])/(135*(-1 + x^2)^10) - 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{1, -1, 0}, x])/(135*(-1 + x^2)^7) + 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{1, 1, 0}, x])/(135*(-1 + x^2)^7) + 
          (2759767*x^12 - 1083390*x^13 + 131005*x^14 - 
            36*Pi^2*(-137 - 602*x + 14105*x^2 - 347172*x^3 + 440853*x^4 - 
              1358490*x^5 + 591395*x^6 - 591395*x^8 + 1358490*x^9 - 
              440853*x^10 + 347172*x^11 - 14105*x^12 + 602*x^13 + 137*x^14) + 
            x^2*(2759767 - 302400*Zeta[3]) + 210*x*(-5159 + 1728*Zeta[3]) + 
            35*(3743 + 1728*Zeta[3]) + 252*x^11*(174391 + 216000*Zeta[3]) + 
            252*x^3*(174391 + 224640*Zeta[3]) + 630*x^5*
             (56909 + 682560*Zeta[3]) + 630*x^9*(56909 + 691200*Zeta[3]) - 
            27*x^10*(1007201 + 3024000*Zeta[3]) - 27*x^4*(1007201 + 
              3044160*Zeta[3]) + 168*x^7*(-937093 + 4752000*Zeta[3]) - 
            5*x^6*(-4860731 + 69007680*Zeta[3]) - 5*x^8*(-4860731 + 
              69552000*Zeta[3]))/(16329600*(-1 + x^2)^10)) + 
        NH*((x*(964246550400 + 9949254819696*x + 1126512716072436*x^2 - 
             769700029364811*x^3 + 4117798490348970*x^4 - 1013461146341658*
              x^5 + 789271041204450*x^6 + 786249767764188*x^7 - 
             1542223615448250*x^8 - 13589688309966*x^9 + 349982760245202*
              x^10 - 107396456038263*x^11 + 17631537296436*x^12 + 
             36590998182732*x^13 - 18664867884348*x^14 - 5538763746576*x^15 + 
             3349681943580*x^16 + 377572057828*x^17 - 303704730840*x^18 + 
             2089773639*x^19 + 15103115202*x^20 - 2192465554*x^21 - 
             348743430*x^22 + 143855348*x^23 - 478338*x^24 - 3447078*x^25 + 
             124530*x^26 + 12475*x^27)*HPL[{0}, x])/(1360800*(-9 + x^2)^6*
            (-1 + x^2)^11) + lm^2*((1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 
              956*x^5 - 398*x^6 + 356*x^7 - 23*x^8 + 6*x^9 + x^10)/
             (240*(-1 + x^2)^8) - (x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*
                x^5 + 2*x^6)*HPL[{0}, x])/(2*(-1 + x^2)^9)) + 
          (x*(-26784626400 - 170660454228*x - 22931072966088*x^2 + 
             15945043536945*x^3 - 82825302376278*x^4 + 20448773578314*x^5 - 
             7938559171998*x^6 - 19190717670402*x^7 + 40133549561490*x^8 - 
             869188316886*x^9 - 8907586415910*x^10 + 3067531468587*x^11 - 
             1356306125244*x^12 - 811715479484*x^13 + 701210282388*x^14 + 
             77603957236*x^15 - 88091577084*x^16 + 961382592*x^17 + 
             2699426380*x^18 - 816897961*x^19 + 307758290*x^20 + 
             67738770*x^21 - 27222006*x^22 - 2218834*x^23 + 569226*x^24 + 
             14922*x^25 + 3234*x^26 + 429*x^27)*HPL[{0, 0}, x])/
           (37800*(-9 + x^2)^6*(-1 + x^2)^11) + 
          lm*((196 + 609*x - 2127*x^2 + 67404*x^3 - 61321*x^4 + 180630*x^5 - 
              61321*x^6 + 67404*x^7 - 2127*x^8 + 609*x^9 + 196*x^10 + 
              6*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*x^4 - 16*x^6 + 48*x^7 - 
                3*x^8 + 6*x^9 + x^10))/(19440*(-1 + x^2)^8) - 
            (x^2*(2 + 2412*x - 3130*x^2 + 16758*x^3 - 11358*x^4 + 22158*x^5 - 
               6505*x^6 + 5562*x^7 - 214*x^8 + 54*x^9 + 9*x^10)*HPL[{0}, x])/
             (540*(-1 + x^2)^9) - ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*
                x^5 - 2*x^6 + 6*x^7 + x^8)*HPL[{-1, 0}, x])/
             (270*(-1 + x^2)^7) + (x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 
               13200*x^4 - 7055*x^5 + 9810*x^6 - 2169*x^7 + 1476*x^8 - 5*
                x^9 + 6*x^10 + x^11)*HPL[{0, 0}, x])/(135*(-1 + x^2)^10) + 
            ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^
                8)*HPL[{1, 0}, x])/(270*(-1 + x^2)^7)) - 
          ((-381 + 7641*x - 11226*x^2 + 43865*x^3 - 32485*x^4 + 57545*x^5 - 
             24160*x^6 + 20745*x^7 - 4395*x^8 + 1660*x^9 - 14*x^10 + 4*x^11 + 
             x^12)*HPL[{-1, 0, 0}, x])/(135*(-1 + x)^10*(1 + x)^8) + 
          (x^3*(867831999300 - 638448236757*x + 3157253788878*x^2 - 
             832176116496*x^3 + 277665815322*x^4 + 829097131050*x^5 - 
             1916783213814*x^6 + 172454857920*x^7 + 295176047418*x^8 - 
             180985589163*x^9 + 133513748676*x^10 + 34850023624*x^11 - 
             44483948292*x^12 - 935467276*x^13 + 4389159852*x^14 - 
             484600760*x^15 - 5063184*x^16 + 69255485*x^17 - 28060242*x^18 - 
             4059928*x^19 + 1862826*x^20 + 116226*x^21 - 40950*x^22 - 
             1960*x^23 + 210*x^24 + 35*x^25)*HPL[{0, 0, 0}, x])/
           (4725*(-9 + x^2)^6*(-1 + x^2)^11) + 
          ((-561 + 6027*x - 6750*x^2 + 28387*x^3 - 10357*x^4 + 29839*x^5 - 
             220*x^6 + 9591*x^7 + 657*x^8 + 1328*x^9 + 10*x^10 + 8*x^11 + 
             x^12)*HPL[{1, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^10) + 
          ((35187738687 + 3409851309102*x - 2289614951250*x^2 + 
             12551343804342*x^3 - 3201193243764*x^4 + 3618822460554*x^5 + 
             1866748472586*x^6 - 3595112653230*x^7 + 81885700683*x^8 + 
             661450533660*x^9 - 256118713668*x^10 + 25571691180*x^11 + 
             72060163104*x^12 - 29801473884*x^13 - 8702743100*x^14 + 
             5557322484*x^15 + 349712181*x^16 - 513303210*x^17 + 
             24773558*x^18 + 23212350*x^19 - 3145260*x^20 - 323022*x^21 + 
             109074*x^22 - 4326*x^23 - 831*x^24)*master3l8a[x])/
           (113400*(-9 + x^2)^6*(-1 + x^2)^11) - 
          ((3909748743 + 186020812278*x - 112089858777*x^2 + 
             713650782096*x^3 - 183214541061*x^4 + 419682401334*x^5 + 
             2815518825*x^6 + 73126241748*x^7 - 28912055148*x^8 + 
             16024964508*x^9 + 8548934390*x^10 - 25047871296*x^11 + 
             1212116694*x^12 + 3790950156*x^13 - 624410206*x^14 + 
             63328104*x^15 + 77167055*x^16 - 48872082*x^17 - 4063373*x^18 + 
             3384528*x^19 + 101247*x^20 - 73794*x^21 - 2459*x^22 + 420*x^23 + 
             70*x^24)*master3l9a[x])/(37800*(-9 + x^2)^5*(-1 + x^2)^11) + 
          (x^16*(31427468457173 - 7395694689600*Zeta[3]) + 
            x^20*(89645769594 - 20287834560*Zeta[3]) + 
            x^22*(8131736582 - 209664000*Zeta[3]) + 160*x^28*
             (-799 + 126*Zeta[3]) + 840*x^27*(-1855 + 144*Zeta[3]) - 
            42*x^25*(1306741 + 54720*Zeta[3]) - 3*x^26*(-8111431 + 
              403200*Zeta[3]) - 252*x^23*(-22625159 + 2940480*Zeta[3]) + 
            5*x^24*(-164879341 + 7640640*Zeta[3]) - 2480058*x*
             (1188166087 + 19414080*Zeta[3]) + 177147*(-227381303 + 
              62354880*Zeta[3]) + 168*x^21*(-892430297 + 215952480*Zeta[3]) + 
            918540*x^3*(-16298018147 + 329228064*Zeta[3]) + 
            653184*x^11*(-2465847488 + 879682925*Zeta[3]) + 
            19683*x^2*(93915887267 + 6383059200*Zeta[3]) + 
            204120*x^5*(-88204117829 + 6530650272*Zeta[3]) - 
            39366*x^4*(-141045318583 + 6768367200*Zeta[3]) - 
            84*x^19*(-23640974107 + 8390152800*Zeta[3]) - 
            567*x^10*(-846489483349 + 34079366400*Zeta[3]) - 
            672*x^13*(-140512977119 + 41770148400*Zeta[3]) + 
            126*x^17*(-116399370607 + 53165937600*Zeta[3]) - 
            7290*x^6*(-293560885831 + 68994938880*Zeta[3]) - 
            6804*x^7*(-140830579657 + 135498536640*Zeta[3]) - 
            168*x^15*(-296857672441 + 160371432000*Zeta[3]) + 
            84*x^14*(-1925198681443 + 562126118400*Zeta[3]) + 
            x^18*(-2990523728897 + 591327878400*Zeta[3]) + 
            243*x^8*(-13115632192829 + 3065320802880*Zeta[3]) - 
            378*x^9*(-13172226917561 + 3150735278400*Zeta[3]) - 
            28*x^12*(-11836691874121 + 4757528840400*Zeta[3]))/
           (8164800*(-9 + x^2)^6*(-1 + x^2)^11)) + 
        NM*(-((47880 + 287280*x - 2339892*x^2 - 48039012*x^3 + 
              114690807*x^4 + 2288301750*x^5 - 4125733846*x^6 - 
              37885939602*x^7 + 76121183196*x^8 + 93818078970*x^9 - 
              619748750198*x^10 + 3735043460190*x^11 + 446080343251*x^12 - 
              36646840032852*x^13 + 23947565715348*x^14 + 56658458220924*x^
                15 - 107959083615352*x^16 + 518539707710388*x^17 - 
              102681631474704*x^18 - 1043595489588120*x^19 + 
              900844778821437*x^20 - 3354795372249090*x^21 + 
              777493194172578*x^22 - 1196783585624970*x^23 - 
              229749460520364*x^24 + 173451939151554*x^25 - 164705104901286*x^
                26 + 35044926646590*x^27 - 20570244390855*x^28 + 
              840*Pi^2*(1 - 9*x^2)^6*(-1 + x^2)^4*(1 + 6*x - 2*x^2 + 54*x^3 - 
                18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8))*HPL[{0}, x])/
           (1360800*(1 - 9*x^2)^6*(-1 + x^2)^11) + 
          lm^2*((1 + 6*x - 23*x^2 + 356*x^3 - 398*x^4 + 956*x^5 - 398*x^6 + 
              356*x^7 - 23*x^8 + 6*x^9 + x^10)/(240*(-1 + x^2)^8) - 
            (x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 3*x^5 + 2*x^6)*
              HPL[{0}, x])/(2*(-1 + x^2)^9)) + 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{-2, 0}, x])/(135*(-1 + x^2)^7) - 
          ((-840 - 5040*x + 36856*x^2 + 1092336*x^3 - 2220125*x^4 - 
             44783634*x^5 + 75086814*x^6 + 373807238*x^7 - 1001744606*x^8 + 
             8365811062*x^9 - 207313406*x^10 - 172810817130*x^11 + 
             129292238241*x^12 + 856889383308*x^13 - 1085477324404*x^14 + 
             2666798430492*x^15 + 1362416357700*x^16 - 30116700228132*x^17 + 
             16761322434204*x^18 + 16475984895132*x^19 - 42845516091531*
              x^20 + 202848684308550*x^21 - 61118586897930*x^22 + 
             100150586849502*x^23 + 10168351607106*x^24 - 6918601666914*
              x^25 + 12157161030666*x^26 - 2797253284770*x^27 + 
             1582778625255*x^28)*HPL[{0, 0}, x])/(37800*(1 - 9*x^2)^6*
            (-1 + x^2)^11) + lm*((196 + 609*x - 2127*x^2 + 67404*x^3 - 
              61321*x^4 + 180630*x^5 - 61321*x^6 + 67404*x^7 - 2127*x^8 + 
              609*x^9 + 196*x^10 + 6*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 
                16*x^4 - 16*x^6 + 48*x^7 - 3*x^8 + 6*x^9 + x^10))/
             (19440*(-1 + x^2)^8) - (x^2*(2 + 2412*x - 3130*x^2 + 16758*x^3 - 
               11358*x^4 + 22158*x^5 - 6505*x^6 + 5562*x^7 - 214*x^8 + 54*
                x^9 + 9*x^10)*HPL[{0}, x])/(540*(-1 + x^2)^9) - 
            ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^
                8)*HPL[{-1, 0}, x])/(270*(-1 + x^2)^7) + 
            (x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 13200*x^4 - 7055*x^5 + 
               9810*x^6 - 2169*x^7 + 1476*x^8 - 5*x^9 + 6*x^10 + x^11)*
              HPL[{0, 0}, x])/(135*(-1 + x^2)^10) + 
            ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^
                8)*HPL[{1, 0}, x])/(270*(-1 + x^2)^7)) - 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{2, 0}, x])/(135*(-1 + x^2)^7) + 
          ((-3 - 12*x + 42*x^2 - 1780*x^3 + 4625*x^4 - 20905*x^5 + 
             24160*x^6 - 57385*x^7 + 32255*x^8 - 43745*x^9 + 11198*x^10 - 
             7633*x^11 + 383*x^12)*HPL[{-1, 0, 0}, x])/(135*(-1 + x)^10*
            (1 + x)^8) + ((-35 - 210*x + 980*x^2 + 60270*x^3 - 104543*x^4 - 
             1247988*x^5 + 2950602*x^6 - 20801256*x^7 + 5059073*x^8 + 
             680091678*x^9 - 1137659238*x^10 - 668975454*x^11 + 
             14399514113*x^12 - 120887950848*x^13 - 30013517540*x^14 + 
             1300332630072*x^15 - 588303062241*x^16 - 4104391691358*x^17 + 
             4019345188416*x^18 - 5793750622422*x^19 - 5086246984893*x^20 + 
             35572598168436*x^21 - 13033331718822*x^22 + 25093047136752*
              x^23 + 575824989123*x^24 + 1062205932690*x^25 + 
             2115707837202*x^26 - 293032906362*x^27 + 299056435803*x^28)*
            HPL[{0, 0, 0}, x])/(4725*(1 - 9*x^2)^6*(-1 + x^2)^11) + 
          ((3 + 24*x + 30*x^2 + 1424*x^3 + 811*x^4 + 9623*x^5 - 220*x^6 + 
             29807*x^7 - 10511*x^8 + 28291*x^9 - 6770*x^10 + 6011*x^11 - 
             563*x^12)*HPL[{1, 0, 0}, x])/(135*(-1 + x)^8*(1 + x)^10) - 
          ((140 + 840*x - 7009*x^2 - 159474*x^3 + 355830*x^4 + 7774326*x^5 - 
             13094452*x^6 - 135453318*x^7 + 252248382*x^8 + 493050474*x^9 - 
             2288115221*x^10 + 11999316924*x^11 + 4960873996*x^12 - 
             148134319284*x^13 + 67339931392*x^14 + 508483303524*x^15 - 
             467823642984*x^16 + 519253656012*x^17 + 607933730997*x^18 - 
             4072020202026*x^19 + 1449640051614*x^20 - 2508159199266*x^21 - 
             127511222220*x^22 + 77671351170*x^23 - 264177995778*x^24 + 
             61476688098*x^25 - 35187738687*x^26)*master3l8b[x])/
           (113400*x^2*(1 - 9*x^2)^6*(-1 + x^2)^11) + 
          ((70 + 420*x - 2459*x^2 - 73794*x^3 + 101247*x^4 + 3384528*x^5 - 
             4063373*x^6 - 48872082*x^7 + 77167055*x^8 + 63328104*x^9 - 
             624410206*x^10 + 3790950156*x^11 + 1212116694*x^12 - 
             25047871296*x^13 + 8548934390*x^14 + 16024964508*x^15 - 
             28912055148*x^16 + 73126241748*x^17 + 2815518825*x^18 + 
             419682401334*x^19 - 183214541061*x^20 + 713650782096*x^21 - 
             112089858777*x^22 + 186020812278*x^23 + 3909748743*x^24)*
            master3l9b[x])/(113400*x^2*(-1 + x^2)^11*(-1 + 9*x^2)^5) + 
          (-9450 - 56700*x + x^2*(696055 - 20160*Zeta[3]) - 
            210*x^3*(-61609 + 576*Zeta[3]) + 336*x^5*(-1959853 + 
              6840*Zeta[3]) + 3*x^4*(-15846571 + 403200*Zeta[3]) - 
            50*x^6*(-35140849 + 764064*Zeta[3]) + 504*x^7*(27018623 + 
              1470240*Zeta[3]) - 4251528*x^30*(5051023 + 2598120*Zeta[3]) + 
            14880348*x^29*(572707 + 3235680*Zeta[3]) + 
            4*x^8*(-8503721543 + 52416000*Zeta[3]) - 
            168*x^9*(489607633 + 215952480*Zeta[3]) - 1377810*x^27*
             (-296477323 + 219485376*Zeta[3]) - 3674160*x^25*
             (168134441 + 362813904*Zeta[3]) + 1049760*x^24*
             (644707449 + 479131520*Zeta[3]) - 177147*x^28*(831123283 + 
              709228800*Zeta[3]) + 714*x^11*(-2063086267 + 987076800*Zeta[
                3]) + 9*x^10*(36149997109 + 2254203840*Zeta[3]) + 
            45927*x^26*(-14436209219 + 5801457600*Zeta[3]) - 
            252*x^13*(-121008798071 + 26582968800*Zeta[3]) + 
            672*x^15*(-304486972789 + 40092858000*Zeta[3]) - 
            10206*x^19*(-187441279357 + 56299707200*Zeta[3]) + 
            13608*x^23*(-525563267201 + 67749268320*Zeta[3]) + 
            81*x^20*(-857332362703 + 238555564800*Zeta[3]) + 
            84*x^17*(3962869501313 + 334161187200*Zeta[3]) - 
            x^12*(581014861183 + 591327878400*Zeta[3]) + 
            1512*x^21*(-3442703985209 + 787683819600*Zeta[3]) - 
            486*x^22*(-6153817157107 + 1532660401440*Zeta[3]) + 
            4*x^14*(-4666709974547 + 1848923672400*Zeta[3]) - 
            6*x^16*(-30483124287137 + 7869765657600*Zeta[3]) + 
            7*x^18*(-85674134501449 + 19030115361600*Zeta[3]))/
           (8164800*x^2*(1 - 9*x^2)^6*(-1 + x^2)^11))) + 
      CA*CF*((Pi^2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 
           1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2}, x])/
         (540*(-1 + x^2)^8) + lm^2*((-11*(1 + 6*x - 23*x^2 + 356*x^3 - 
             398*x^4 + 956*x^5 - 398*x^6 + 356*x^7 - 23*x^8 + 6*x^9 + x^10))/
           (480*(-1 + x^2)^8) + (11*x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 
             3*x^5 + 2*x^6)*HPL[{0}, x])/(4*(-1 + x^2)^9)) - 
        (Pi^2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{2}, x])/
         (540*(-1 + x^2)^8) + (x*(-29 + 1227*x - 4734*x^2 + 15486*x^3 - 
           114753*x^4 + 97607*x^5 - 229200*x^6 + 140617*x^7 - 176793*x^8 - 
           93480*x^9 + 87858*x^10 + 205013*x^11 - 75517*x^12 - 255366*x^13 + 
           23760*x^14 + 218790*x^15 + 19800*x^16 - 127490*x^17 - 28160*x^18 + 
           48510*x^19 + 15444*x^20 - 10902*x^21 - 4296*x^22 + 1100*x^23 + 
           500*x^24)*HPL[{-2, 0}, x])/(1080*(-1 + x^2)^10) + 
        ((-210000 - 462000*x + 1489320*x^2 + 3885840*x^3 - 4165000*x^4 - 
           14352940*x^5 + 4967900*x^6 + 30416540*x^7 + 812420*x^8 + 
           (-40351757 + 1680*Pi^2)*x^9 + 14*(-689677 + 720*Pi^2)*x^10 + 
           (32926448 - 174720*Pi^2)*x^11 + 14*(2376641 + 83280*Pi^2)*x^12 - 
           3*(13847733 + 590800*Pi^2)*x^13 + 56*(1349519 + 37440*Pi^2)*x^14 - 
           42304904*x^15 - 56*(-1349519 + 37440*Pi^2)*x^16 + 
           3*(-13847733 + 590800*Pi^2)*x^17 - 14*(-2376641 + 83280*Pi^2)*
            x^18 + 16*(2057903 + 10920*Pi^2)*x^19 - 14*(689677 + 720*Pi^2)*
            x^20 - (40351757 + 1680*Pi^2)*x^21 + 812420*x^22 + 
           30416540*x^23 + 4967900*x^24 - 14352940*x^25 - 4165000*x^26 + 
           3885840*x^27 + 1489320*x^28 - 462000*x^29 - 210000*x^30)*
          HPL[{-1, 0}, x])/(907200*x^9*(-1 + x^2)^9) + 
        (x*(-38837708280 + 2284087674708*x - 22995042112476*x^2 - 
           57991406106951*x^3 + 967670437408542*x^4 - 197065243403307*x^5 - 
           12257742375553248*x^6 + 21080359707338628*x^7 - 
           8497494629846712*x^8 - 261959354008296228*x^9 + 
           1493676232917171408*x^10 + 1129459021235738064*x^11 - 
           12376909031034473352*x^12 + 640217370687886848*x^13 + 
           27073695318424678896*x^14 - 12557180532030800316*x^15 + 
           78594043247676304320*x^16 - 20693805227905902244*x^17 - 
           234728663965565217224*x^18 + 143409535463545355274*x^19 - 
           448864882775746425324*x^20 + 114924912174267800434*x^21 + 
           148595730066986462064*x^22 - 182676550195879922756*x^23 + 
           33549156789665782496*x^24 + 137725146622439668124*x^25 - 
           15853827165424906896*x^26 - 88560059469416773032*x^27 - 
           7462965888643214712*x^28 + 46554978037072633832*x^29 + 
           9616389697344860528*x^30 - 18389402616248191572*x^31 - 
           5149028205191257800*x^32 + 5265421143815099040*x^33 + 
           1744479184787090052*x^34 - 1070310716887260267*x^35 - 
           394989492472222914*x^36 + 151305200386183665*x^37 + 
           60056561917522800*x^38 - 14451569132479920*x^39 - 
           6035474991326760*x^40 + 886409847401400*x^41 + 
           384018595803360*x^42 - 31465388666880*x^43 - 14008062000240*x^44 + 
           491051484000*x^45 + 223205220000*x^46)*HPL[{0, 0}, x])/
         (907200*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        ((210000 + 462000*x - 1489320*x^2 - 3885840*x^3 + 4165000*x^4 + 
           14352940*x^5 - 4967900*x^6 - 30416540*x^7 - 812420*x^8 + 
           (40351757 - 1680*Pi^2)*x^9 - 14*(-689677 + 720*Pi^2)*x^10 + 
           16*(-2057903 + 10920*Pi^2)*x^11 - 14*(2376641 + 83280*Pi^2)*x^12 + 
           3*(13847733 + 590800*Pi^2)*x^13 - 56*(1349519 + 37440*Pi^2)*x^14 + 
           42304904*x^15 + 56*(-1349519 + 37440*Pi^2)*x^16 + 
           (41543199 - 1772400*Pi^2)*x^17 + 14*(-2376641 + 83280*Pi^2)*x^18 - 
           16*(2057903 + 10920*Pi^2)*x^19 + 14*(689677 + 720*Pi^2)*x^20 + 
           (40351757 + 1680*Pi^2)*x^21 - 812420*x^22 - 30416540*x^23 - 
           4967900*x^24 + 14352940*x^25 + 4165000*x^26 - 3885840*x^27 - 
           1489320*x^28 + 462000*x^29 + 210000*x^30)*HPL[{1, 0}, x])/
         (907200*x^9*(-1 + x^2)^9) + 
        lm*(-(3290 + 13503*x - 49479*x^2 + 1145148*x^3 - 1125863*x^4 + 
             3071034*x^5 - 1125863*x^6 + 1145148*x^7 - 49479*x^8 + 
             13503*x^9 + 3290*x^10 + 66*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*
                x^4 - 16*x^6 + 48*x^7 - 3*x^8 + 6*x^9 + x^10))/
           (38880*(-1 + x^2)^8) + (x^2*(22 + 34092*x - 45770*x^2 + 
             229698*x^3 - 155178*x^4 + 289098*x^5 - 82895*x^6 + 68742*x^7 - 
             2354*x^8 + 594*x^9 + 99*x^10)*HPL[{0}, x])/(1080*(-1 + x^2)^9) + 
          (11*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + 
             x^8)*HPL[{-1, 0}, x])/(540*(-1 + x^2)^7) - 
          (11*x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 13200*x^4 - 7055*x^5 + 
             9810*x^6 - 2169*x^7 + 1476*x^8 - 5*x^9 + 6*x^10 + x^11)*
            HPL[{0, 0}, x])/(270*(-1 + x^2)^10) - 
          (11*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + 
             x^8)*HPL[{1, 0}, x])/(540*(-1 + x^2)^7)) - 
        (x*(-29 + 1227*x - 4734*x^2 + 15486*x^3 - 114753*x^4 + 97607*x^5 - 
           229200*x^6 + 140617*x^7 - 176793*x^8 - 93480*x^9 + 87858*x^10 + 
           205013*x^11 - 75517*x^12 - 255366*x^13 + 23760*x^14 + 
           218790*x^15 + 19800*x^16 - 127490*x^17 - 28160*x^18 + 48510*x^19 + 
           15444*x^20 - 10902*x^21 - 4296*x^22 + 1100*x^23 + 500*x^24)*
          HPL[{2, 0}, x])/(1080*(-1 + x^2)^10) - 
        ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x^2)^8) + (4*x^2*(-50 + 326*x - 571*x^2 + 974*x^3 - 
           587*x^4 + 374*x^5 - 53*x^6 + 6*x^7 + x^8)*HPL[{-2, 0, 0}, x])/
         (45*(-1 + x^2)^8) + ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 
           1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{-2, 1, 0}, x])/(45*(-1 + x^2)^8) + 
        ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-1, -2, 0}, x])/
         (45*(-1 + x^2)^8) + ((-250 - 550*x + 1398*x^2 + 3801*x^3 - 
           2778*x^4 - 11202*x^5 + 1302*x^6 + 18186*x^7 + 3738*x^8 - 
           17430*x^9 - 7350*x^10 + 9611*x^11 + 5650*x^12 - 2474*x^13 - 
           4350*x^14 + 996*x^15 - 4350*x^16 - 2474*x^17 + 5650*x^18 + 
           9611*x^19 - 7350*x^20 - 17430*x^21 + 3738*x^22 + 18186*x^23 + 
           1302*x^24 - 11202*x^25 - 2778*x^26 + 3801*x^27 + 1398*x^28 - 
           550*x^29 - 250*x^30)*HPL[{-1, -1, 0}, x])/
         (1080*x^11*(-1 + x^2)^7) + ((5731 - 2166*x - 72344*x^2 + 
           789090*x^3 - 1576725*x^4 + 3664582*x^5 - 3567802*x^6 + 
           4134282*x^7 - 1798100*x^8 - 254260*x^9 + 335756*x^10 + 
           1817624*x^11 - 471844*x^12 - 2190300*x^13 + 388500*x^14 + 
           1829100*x^15 - 217875*x^16 - 1046850*x^17 + 80500*x^18 + 
           393050*x^19 - 17675*x^20 - 87430*x^21 + 1750*x^22 + 8750*x^23)*
          HPL[{-1, 0, 0}, x])/(18900*(-1 + x)^10*(1 + x)^8) + 
        ((250 + 550*x - 1398*x^2 - 3801*x^3 + 2778*x^4 + 11202*x^5 - 
           1302*x^6 - 18186*x^7 - 3738*x^8 + 17430*x^9 + 7350*x^10 - 
           9611*x^11 - 5650*x^12 + 2474*x^13 + 4350*x^14 - 996*x^15 + 
           4350*x^16 + 2474*x^17 - 5650*x^18 - 9611*x^19 + 7350*x^20 + 
           17430*x^21 - 3738*x^22 - 18186*x^23 - 1302*x^24 + 11202*x^25 + 
           2778*x^26 - 3801*x^27 - 1398*x^28 + 550*x^29 + 250*x^30)*
          HPL[{-1, 1, 0}, x])/(1080*x^11*(-1 + x^2)^7) - 
        ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-1, 2, 0}, x])/
         (45*(-1 + x^2)^8) - (x*(-539412615 + 22376323305*x - 
           744174011070*x^2 + 812145134178*x^3 + 27085708472382*x^4 - 
           74286875645712*x^5 - 214270183141812*x^6 + 1793620625287590*x^7 - 
           3730578902246322*x^8 - 21560753147307336*x^9 + 83496870266489736*
            x^10 + 148179865580754306*x^11 - 597325957982667298*x^12 - 
           639990712284597904*x^13 + 1453720495375196804*x^14 + 
           2139925984722381066*x^15 + 1401034991670733048*x^16 - 
           6648485057937832258*x^17 - 2615792915889228124*x^18 + 
           13233994609820065458*x^19 - 30775793310362726878*x^20 - 
           7216427388312290468*x^21 + 14454125154855576484*x^22 + 
           10247260919733392878*x^23 - 3435072871872619558*x^24 - 
           14443297249962006252*x^25 + 1047045267963666552*x^26 + 
           13488255641023872354*x^27 + 504464298748656498*x^28 - 
           9147599962136546156*x^29 - 1264409268452469524*x^30 + 
           4641244545672532566*x^31 + 1026924191693311527*x^32 - 
           1750815948233734095*x^33 - 499928047783646790*x^34 + 
           482897055109762580*x^35 + 161428336388367272*x^36 - 
           95422126022504748*x^37 - 35376900229414800*x^38 + 
           13205266031708100*x^39 + 5253572970220680*x^40 - 
           1241014366744740*x^41 - 518860520912160*x^42 + 
           75175135064820*x^43 + 32583668864040*x^44 - 2642576200740*x^45 - 
           1176638717520*x^46 + 40920957000*x^47 + 18600435000*x^48)*
          HPL[{0, 0, 0}, x])/(37800*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) - 
        ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{1, -2, 0}, x])/
         (45*(-1 + x^2)^8) + ((250 + 550*x - 1398*x^2 - 3801*x^3 + 2778*x^4 + 
           11202*x^5 - 1302*x^6 - 18186*x^7 - 3738*x^8 + 17430*x^9 + 
           7350*x^10 - 9611*x^11 - 5650*x^12 + 2474*x^13 + 4350*x^14 - 
           996*x^15 + 4350*x^16 + 2474*x^17 - 5650*x^18 - 9611*x^19 + 
           7350*x^20 + 17430*x^21 - 3738*x^22 - 18186*x^23 - 1302*x^24 + 
           11202*x^25 + 2778*x^26 - 3801*x^27 - 1398*x^28 + 550*x^29 + 
           250*x^30)*HPL[{1, -1, 0}, x])/(1080*x^11*(-1 + x^2)^7) - 
        ((5731 + 22438*x - 21720*x^2 + 669318*x^3 + 298267*x^4 + 
           1148254*x^5 + 1486814*x^6 + 1230714*x^7 + 1181212*x^8 + 
           1336348*x^9 - 1470580*x^10 - 1949672*x^11 + 1080476*x^12 + 
           2795940*x^13 + 47460*x^14 - 2285220*x^15 - 789075*x^16 + 
           1053570*x^17 + 665140*x^18 - 216090*x^19 - 248395*x^20 - 
           10430*x^21 + 36750*x^22 + 8750*x^23)*HPL[{1, 0, 0}, x])/
         (18900*(-1 + x)^8*(1 + x)^10) + 
        ((-250 - 550*x + 1398*x^2 + 3801*x^3 - 2778*x^4 - 11202*x^5 + 
           1302*x^6 + 18186*x^7 + 3738*x^8 - 17430*x^9 - 7350*x^10 + 
           9611*x^11 + 5650*x^12 - 2474*x^13 - 4350*x^14 + 996*x^15 - 
           4350*x^16 - 2474*x^17 + 5650*x^18 + 9611*x^19 - 7350*x^20 - 
           17430*x^21 + 3738*x^22 + 18186*x^23 + 1302*x^24 - 11202*x^25 - 
           2778*x^26 + 3801*x^27 + 1398*x^28 - 550*x^29 - 250*x^30)*
          HPL[{1, 1, 0}, x])/(1080*x^11*(-1 + x^2)^7) + 
        ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{1, 2, 0}, x])/
         (45*(-1 + x^2)^8) + ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 
           1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{2, -1, 0}, x])/(45*(-1 + x^2)^8) - 
        (4*x^2*(-50 + 326*x - 571*x^2 + 974*x^3 - 587*x^4 + 374*x^5 - 
           53*x^6 + 6*x^7 + x^8)*HPL[{2, 0, 0}, x])/(45*(-1 + x^2)^8) - 
        ((1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{2, 1, 0}, x])/
         (45*(-1 + x^2)^8) - (2*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 
           2*x^6 + 6*x^7 + x^8)*HPL[{-1, 0, 0, 0}, x])/(45*(-1 + x^2)^7) + 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-1, 1, 0, 0}, x])/
         (45*(-1 + x^2)^8) + (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 
           1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{1, -1, 0, 0}, x])/(45*(-1 + x^2)^8) + 
        (2*(1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
          HPL[{1, 0, 0, 0}, x])/(45*(-1 + x^2)^7) - 
        ((1 + 11*x - 79*x^2 + 983*x^3 - 1519*x^4 + 4040*x^5 - 2444*x^6 + 
           2792*x^7 - 464*x^8 + 289*x^9 + 25*x^10 + 5*x^11)*master3l10a[x])/
         (360*(-1 + x^2)^9) + (x*(5 + 25*x + 289*x^2 - 464*x^3 + 2792*x^4 - 
           2444*x^5 + 4040*x^6 - 1519*x^7 + 983*x^8 - 79*x^9 + 11*x^10 + 
           x^11)*master3l10b[x])/(360*(-1 + x^2)^9) + 
        ((-36780231168 + 219984864687*x - 1577323152297*x^2 + 
           5156784534762*x^3 - 6203142941544*x^4 + 5606272174671*x^5 - 
           240649731351*x^6 - 1706932920168*x^7 + 973764252864*x^8 - 
           540328340034*x^9 - 98219048346*x^10 + 273934359132*x^11 - 
           45280970640*x^12 - 41091162378*x^13 + 13008879026*x^14 + 
           2236800216*x^15 - 1442524416*x^16 + 48383027*x^17 + 
           77601939*x^18 - 9956534*x^19 - 1794248*x^20 + 292635*x^21 + 
           6677*x^22)*master3l8a[x])/(907200*(-9 + x^2)^6*(-1 + x^2)^10) + 
        ((4060 - 176777*x + 150325*x^2 + 10004580*x^3 - 12840366*x^4 - 
           259152035*x^5 + 274778189*x^6 + 3964932000*x^7 - 2672435808*x^8 - 
           38371794922*x^9 + 12743040170*x^10 + 231109171192*x^11 - 
           40785838212*x^12 - 781009535382*x^13 + 292551429954*x^14 + 
           1040815666800*x^15 - 1816581627756*x^16 + 577131299235*x^17 + 
           3655791054657*x^18 - 717237731772*x^19 + 1711026799650*x^20 - 
           40656095991*x^21 + 48140635473*x^22 + 34101768528*x^23)*
          master3l8b[x])/(907200*x*(1 - 9*x^2)^6*(-1 + x^2)^10) + 
        ((3937888872 - 9546901623*x + 85807935225*x^2 - 192491752131*x^3 + 
           314306726679*x^4 - 129748034682*x^5 + 80355249108*x^6 - 
           20508043164*x^7 + 12653439564*x^8 + 43992426870*x^9 - 
           36526867106*x^10 - 12596407978*x^11 + 11296467090*x^12 + 
           1591188144*x^13 - 1599318876*x^14 - 95936652*x^15 + 
           122712148*x^16 + 1917881*x^17 - 5073871*x^18 + 52885*x^19 + 
           91727*x^20 - 2030*x^21)*master3l9a[x])/(302400*(-9 + x^2)^5*
          (-1 + x^2)^10) + ((-2030 + 91727*x + 52885*x^2 - 5073871*x^3 + 
           1917881*x^4 + 122712148*x^5 - 95936652*x^6 - 1599318876*x^7 + 
           1591188144*x^8 + 11296467090*x^9 - 12596407978*x^10 - 
           36526867106*x^11 + 43992426870*x^12 + 12653439564*x^13 - 
           20508043164*x^14 + 80355249108*x^15 - 129748034682*x^16 + 
           314306726679*x^17 - 192491752131*x^18 + 85807935225*x^19 - 
           9546901623*x^20 + 3937888872*x^21)*master3l9b[x])/
         (907200*x*(-1 + x^2)^10*(-1 + 9*x^2)^5) + 
        (HPL[{1}, x]*(Pi^2*(250 + 550*x - 1648*x^2 - 4351*x^3 + 4176*x^4 + 
             15003*x^5 - 4080*x^6 - 29388*x^7 - 2436*x^8 + 35616*x^9 + 
             11088*x^10 - 27041*x^11 - 13000*x^12 + 12085*x^13 + 10000*x^14 - 
             3470*x^15 + 3470*x^17 - 10000*x^18 - 12085*x^19 + 13000*x^20 + 
             27041*x^21 - 11088*x^22 - 35616*x^23 + 2436*x^24 + 29388*x^25 + 
             4080*x^26 - 15003*x^27 - 4176*x^28 + 4351*x^29 + 1648*x^30 - 
             550*x^31 - 250*x^32) - 288*x^11*(1 + 6*x - 103*x^2 + 700*x^3 - 
             1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + 
             x^10)*Zeta[3]))/(12960*x^11*(-1 + x^2)^8) + 
        (HPL[{-1}, x]*(Pi^2*(-250 - 550*x + 1648*x^2 + 4351*x^3 - 4176*x^4 - 
             15003*x^5 + 4080*x^6 + 29388*x^7 + 2436*x^8 - 35616*x^9 - 
             11088*x^10 + 27041*x^11 + 13000*x^12 - 12085*x^13 - 10000*x^14 + 
             3470*x^15 - 3470*x^17 + 10000*x^18 + 12085*x^19 - 13000*x^20 - 
             27041*x^21 + 11088*x^22 + 35616*x^23 - 2436*x^24 - 29388*x^25 - 
             4080*x^26 + 15003*x^27 + 4176*x^28 - 4351*x^29 - 1648*x^30 + 
             550*x^31 + 250*x^32) + 288*x^11*(1 + 6*x - 103*x^2 + 700*x^3 - 
             1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + 
             x^10)*Zeta[3]))/(12960*x^11*(-1 + x^2)^8) + 
        (HPL[{0}, x]*(669615660000 + 1473154452000*x - 41689378170720*x^2 - 
           93659588774640*x^3 + 1131266899629720*x^4 + 2612522510687880*x^5 - 
           17544237738360480*x^6 - 42056189726391540*x^7 + 
           612360*(280049084941 + 21141*Pi^2)*x^8 - 
           17496*(-24752600277626 + 31306905*Pi^2)*x^9 + 
           1680*(620379792518444825 + 12434167663613526*Pi^2)*x^26 - 
           3*(144744418081838907 + 1931522995525397960*Pi^2)*x^43 - 
           210*(816499516011615 + 9224500983427964*Pi^2)*x^44 + 
           405*(103893725206071 + 2827313422686368*Pi^2)*x^45 + 
           90720*(193388863959 + 4679484157330*Pi^2)*x^46 - 
           204120*(12798954099 + 776323693810*Pi^2)*x^47 - 
           204120*(5542165881 + 308852026468*Pi^2)*x^48 + 
           1224720*(76474287 + 12159654779*Pi^2)*x^49 + 
           2449440*(17019963 + 2541938668*Pi^2)*x^50 - 
           33067440*(44550 + 27280661*Pi^2)*x^51 - 66134880*
            (10125 + 5912221*Pi^2)*x^52 + 31710914408880*Pi^2*x^53 + 
           14119664610240*Pi^2*x^54 - 491051484000*Pi^2*x^55 - 
           223205220000*Pi^2*x^56 + 144*x^41*(145871095024886455*Pi^2 + 
             27*(777351155693173 - 8928208800*Zeta[3])) - 
           8*x^31*(-2134408344070302028 + 19425358561203709905*Pi^2 - 
             944274647073643200*Zeta[3]) + 168*x^24*(-5556647351870891849 + 
             31797301627372560*Pi^2 - 410807471955062400*Zeta[3]) + 
           8*x^33*(14611941684268865474 + 22691597012462908845*Pi^2 - 
             350010488321726400*Zeta[3]) + 24*x^23*(775357814610594553 + 
             235241647549475595*Pi^2 - 120530949548385600*Zeta[3]) - 
           504*x^22*(-196018615306448773 + 20185226352660540*Pi^2 - 
             57449513274796800*Zeta[3]) - 12*x^35*(8997085371295203163 + 
             13507180784798466150*Pi^2 - 38255347012579200*Zeta[3]) + 
           560*x^20*(116012790364159348 + 5702282920638507*Pi^2 - 
             4668414937272000*Zeta[3]) - 168*x^34*(-556919285760906203 + 
             135245303216964000*Pi^2 - 4357523820844800*Zeta[3]) + 
           12*x^37*(4080714715632289503 + 9127746123675213230*Pi^2 - 
             3350971039651200*Zeta[3]) - 36*x^39*(405032337331745009 + 
             1545737785293561090*Pi^2 - 51105067171200*Zeta[3]) - 
           126*x^12*(-37365166658167723 + 381768187500*Pi^2 - 
             9122078476800*Zeta[3]) + 6804*x^10*(-161792844953239 + 
             206584020*Pi^2 - 3401222400*Zeta[3]) + 
           252*x^42*(4368478491287073 + 23806361535983740*Pi^2 + 
             91833004800*Zeta[3]) + 243*x^11*(-12330374870254243 + 
             94774957200*Pi^2 + 142851340800*Zeta[3]) - 
           504*x^40*(9418794272891332 + 24441469934316975*Pi^2 + 
             2280519619200*Zeta[3]) - 504*x^14*(26741428762555979 + 
             502613982900*Pi^2 + 44899536902400*Zeta[3]) + 
           1680*x^16*(15923706918476849 + 16332032158083*Pi^2 + 
             126028422417600*Zeta[3]) + 168*x^38*(86324604711803817 + 
             89422592862300700*Pi^2 + 134698610707200*Zeta[3]) - 
           9*x^13*(-1588477073587759091 + 38998575864360*Pi^2 + 
             204420268684800*Zeta[3]) - 840*x^36*(45062123919731773 + 
             5007784841903574*Pi^2 + 252056844835200*Zeta[3]) + 
           72*x^15*(-662400224900929763 + 29234999458035*Pi^2 + 
             558495173275200*Zeta[3]) - 168*x^18*(263411923845474083 + 
             2629180702116720*Pi^2 + 4357523820844800*Zeta[3]) + 
           280*x^32*(-146819638906071461 + 190876667784415410*Pi^2 + 
             9336829874544000*Zeta[3]) - 24*x^17*(-4613264696301836264 + 
             164029897104885*Pi^2 + 19127673506289600*Zeta[3]) - 
           504*x^30*(1895648439501076253 + 137177145409717620*Pi^2 + 
             57449513274796800*Zeta[3]) + 12*x^19*(-13869051427606184731 + 
             6040957751273970*Pi^2 + 233340325547817600*Zeta[3]) + 
           6*x^29*(31208915380324645703 + 17889133048558671900*Pi^2 + 
             482123798193542400*Zeta[3]) + 84*x^28*(28356611282019229033 + 
             532261198377337560*Pi^2 + 821614943910124800*Zeta[3]) - 
           42*x^27*(28084438840721332099 + 1455150096058891340*Pi^2 + 
             1226387823950534400*Zeta[3]) - 4*x^21*(-28013769960182051219 + 
             301627635852516750*Pi^2 + 1888549294147286400*Zeta[3]) + 
           8*x^25*(46393824342611695256 + 151528677277569585*Pi^2 + 
             6438536075740305600*Zeta[3])))/(10886400*x^7*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6) + (4032*Pi^4*x^9*(-1 + x^2)^2*
           (9 - 82*x^2 + 9*x^4)^6*(-3 - 18*x - 491*x^2 + 3116*x^3 - 
            5662*x^4 + 9740*x^5 - 5918*x^6 + 3884*x^7 - 539*x^8 + 78*x^9 + 
            13*x^10) + 12*Pi^2*(9 - 82*x^2 + 9*x^4)^6*(-210000 - 462000*x + 
            1699320*x^2 + 4347840*x^3 - 5654320*x^4 - 18238780*x^5 + 
            9132900*x^6 + 44769480*x^7 - 4155480*x^8 - 70768297*x^9 - 
            10467898*x^10 + 73278205*x^11 + 42928452*x^12 - 74469647*x^13 + 
            42300090*x^14 - 761705*x^15 + 761705*x^17 - 42300090*x^18 + 
            74469647*x^19 - 42928452*x^20 - 73278205*x^21 + 10467898*x^22 + 
            70768297*x^23 + 4155480*x^24 - 44769480*x^25 - 9132900*x^26 + 
            18238780*x^27 + 5654320*x^28 - 4347840*x^29 - 1699320*x^30 + 
            462000*x^31 + 210000*x^32) + x^2*(-2008846980000 - 
            4419463356000*x + 125737750172160*x^2 + 282451920775920*x^3 - 
            3435238971187380*x^4 - 7930674687918780*x^5 + 53748777383971740*
             x^6 + x^33*(945508478323245855324 - 6430224102065715457728*Zeta[
                3]) + x^25*(6121511437130707020858 - 3052437854539743854784*
               Zeta[3]) + x^27*(588910402336373971398 - 767213266512819248064*
               Zeta[3]) - 1141592918719680*x^53*Zeta[3] - 508307925968640*
             x^54*Zeta[3] + 17677853424000*x^55*Zeta[3] + 8035387920000*x^56*
             Zeta[3] + 595213920*x^52*(-3375 + 23648884*Zeta[3]) + 
            595213920*x^51*(-7425 + 54561322*Zeta[3]) - 
            91854*x^8*(5790498413329 + 385588512*Zeta[3]) - 
            352719360*x^50*(-356481 + 635484667*Zeta[3]) - 
            19683*x^7*(-6544360713613 + 1125855936*Zeta[3]) + 
            20412*x^10*(170099421452689 + 8892656928*Zeta[3]) - 
            11022480*x^49*(-25625079 + 48638619116*Zeta[3]) + 
            6561*x^9*(-204425763126989 + 198781807104*Zeta[3]) + 
            918540*x^48*(-3739890447 + 2470816211744*Zeta[3]) + 
            918540*x^47*(-8634000357 + 6210589550480*Zeta[3]) - 
            91008*x^15*(-1518635200415149 + 29810088351801*Zeta[3]) - 
            729*x^11*(-12833715948327709 + 44141781829824*Zeta[3]) - 
            204120*x^46*(-263318078097 + 74871746517280*Zeta[3]) + 
            378*x^12*(-39574502567230789 + 129194849407392*Zeta[3]) - 
            504*x^14*(-74048142702213103 + 2963602945899072*Zeta[3]) + 
            4788*x^16*(1478384459284177 + 4062168209810880*Zeta[3]) + 
            27*x^13*(-1633692548611227629 + 15449478924817152*Zeta[3]) - 
            729*x^45*(-176545152041841 + 56546297881859392*Zeta[3]) + 
            36*x^17*(-8331399419965729145 + 61800107526684576*Zeta[3]) - 
            2268*x^42*(-1526560652678481 + 95225434838334688*Zeta[3]) - 
            1008*x^18*(478356098063734115 + 125261983902574368*Zeta[3]) + 
            378*x^44*(-1406253412585557 + 184489938427527904*Zeta[3]) + 
            1008*x^34*(-24281882968484975 + 672361240961639232*Zeta[3]) + 
            252*x^36*(-212536498654759337 + 681988067593434720*Zeta[3]) + 
            2688*x^30*(494554197459835673 + 949856378263085466*Zeta[3]) + 
            5364*x^35*(-82742258112201475 + 1088113865288701104*Zeta[3]) + 
            378*x^40*(-39545514246054979 + 1173325363979696352*Zeta[3]) + 
            224*x^20*(6517058009304522311 + 1493749405548144432*Zeta[3]) - 
            252*x^38*(-161756199531789641 + 2152224702772880064*Zeta[3]) + 
            168*x^22*(2495633779842948353 + 2300031895315971456*Zeta[3]) + 
            27*x^43*(-49571695025751177 + 7726137993118293632*Zeta[3]) + 
            12*x^19*(59717073839774160947 + 8459641989969073056*Zeta[3]) - 
            81*x^41*(-115849827471058011 + 9336123891753956416*Zeta[3]) - 
            112*x^32*(640959997941431003 + 13292115119962406136*Zeta[3]) - 
            36*x^21*(62016115395424092997 + 21777495451895480288*Zeta[3]) - 
            84*x^24*(56030174884897219993 + 46266535762544542176*Zeta[3]) - 
            72*x^37*(-2258323049256598561 + 54801418984787561304*Zeta[3]) - 
            18*x^29*(15556276426650829065 + 63044034625963431776*Zeta[3]) - 
            84*x^28*(2314706467099847863 + 63770130755027885376*Zeta[3]) + 
            27*x^39*(-1698587586369673859 + 74209842097124666112*Zeta[3]) + 
            56*x^26*(-163541476334647446913 + 113839174302390442080*Zeta[
                3]) + 36*x^31*(-33040399838966576767 + 132517662643664405872*
               Zeta[3]) + 18*x^23*(127452848049239642025 + 
              141468569787246819424*Zeta[3])))/(130636800*x^9*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6)) + 
      CF^2*(-(Pi^2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 
            1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2}, x])/
         (270*(-1 + x^2)^8) + lm^2*((9*(1 + 6*x - 23*x^2 + 356*x^3 - 
             398*x^4 + 956*x^5 - 398*x^6 + 356*x^7 - 23*x^8 + 6*x^9 + x^10))/
           (80*(-1 + x^2)^8) - (27*x^3*(2 - 3*x + 12*x^2 - 8*x^3 + 12*x^4 - 
             3*x^5 + 2*x^6)*HPL[{0}, x])/(2*(-1 + x^2)^9)) + 
        (Pi^2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{2}, x])/
         (270*(-1 + x^2)^8) + (x*(1015 - 42945*x + 407610*x^2 - 819210*x^3 + 
           6097875*x^4 - 4870285*x^5 + 8353800*x^6 - 7674555*x^7 + 
           15461075*x^8 + 12868912*x^9 - 20129130*x^10 - 37002133*x^11 + 
           26571699*x^12 + 64173336*x^13 - 19815616*x^14 - 76271400*x^15 + 
           4336204*x^16 + 62992620*x^17 + 7167284*x^18 - 35714786*x^19 - 
           8463716*x^20 + 13303386*x^21 + 4391560*x^22 - 2939400*x^23 - 
           1184500*x^24 + 292500*x^25 + 135000*x^26)*HPL[{-2, 0}, x])/
         (18900*(-1 + x^2)^10) + ((-56700000 - 122850000*x + 412440000*x^2 + 
           1050273000*x^3 - 1202170200*x^4 - 3960825120*x^5 + 
           1582017920*x^6 + 8626477440*x^7 - 152646900*x^8 - 
           11908724940*x^9 - 2665127780*x^10 + (10725927941 - 58800*Pi^2)*
            x^11 - 70*(-61825937 + 5040*Pi^2)*x^12 + 
           8*(-770741747 + 764400*Pi^2)*x^13 - 210*(20009839 + 194320*Pi^2)*
            x^14 + 25*(126607651 + 2481360*Pi^2)*x^15 - 
           280*(10510343 + 262080*Pi^2)*x^16 + 2096591960*x^17 + 
           280*(-10510343 + 262080*Pi^2)*x^18 + (3165191275 - 62034000*Pi^2)*
            x^19 + 210*(-20009839 + 194320*Pi^2)*x^20 - 
           8*(770741747 + 764400*Pi^2)*x^21 + 70*(61825937 + 5040*Pi^2)*
            x^22 + (10725927941 + 58800*Pi^2)*x^23 - 2665127780*x^24 - 
           11908724940*x^25 - 152646900*x^26 + 8626477440*x^27 + 
           1582017920*x^28 - 3960825120*x^29 - 1202170200*x^30 + 
           1050273000*x^31 + 412440000*x^32 - 122850000*x^33 - 56700000*x^34)*
          HPL[{-1, 0}, x])/(15876000*x^11*(-1 + x^2)^9) + 
        (x*(1359319789800 - 81681390868140*x + 1249549482473460*x^2 + 
           1756670570945325*x^3 - 52865231533318890*x^4 + 20781097242417225*
            x^5 + 714420971912889360*x^6 - 955363853684845080*x^7 - 
           957392402072586480*x^8 + 9876230295863685768*x^9 - 
           62100122026979544480*x^10 - 22885777817504974260*x^11 + 
           533519037296663664960*x^12 - 231681514068510290556*x^13 - 
           881428887447366066480*x^14 + 1408595713322251161360*x^15 - 
           6015347228148396590760*x^16 - 1193121273407717687152*x^17 + 
           18076774522125013344440*x^18 - 1691746970857645171794*x^19 + 
           11234379271094508371500*x^20 - 18941885850756276351970*x^21 + 
           3762018594557874725200*x^22 + 33404962118352608800128*x^23 - 
           11223742896708612864440*x^24 - 39036168699626595884200*x^25 + 
           5772426591606935940400*x^26 + 35737148266567336859676*x^27 + 
           689574745375509891520*x^28 - 25020270772894701247452*x^29 - 
           3459622520501745366160*x^30 + 13139781448374437135760*x^31 + 
           2965750585203704696160*x^32 - 5103388011807266293476*x^33 - 
           1488145417940579594700*x^34 + 1441472023426204552365*x^35 + 
           491818636815264000270*x^36 - 290281070088020679327*x^37 - 
           109733151988939298400*x^38 + 40768738979924473560*x^39 + 
           16520351873379487560*x^40 - 3875496101895327840*x^41 - 
           1648755439523645040*x^42 + 236863170922749840*x^43 + 
           104378339433236400*x^44 - 8384994256086000*x^45 - 
           3793149508680000*x^46 + 130575053700000*x^47 + 
           60265409400000*x^48)*HPL[{0, 0}, x])/(15876000*(-1 + x^2)^10*
          (9 - 82*x^2 + 9*x^4)^6) + ((56700000 + 122850000*x - 
           412440000*x^2 - 1050273000*x^3 + 1202170200*x^4 + 3960825120*x^5 - 
           1582017920*x^6 - 8626477440*x^7 + 152646900*x^8 + 
           11908724940*x^9 + 2665127780*x^10 + (-10725927941 + 58800*Pi^2)*
            x^11 + 70*(-61825937 + 5040*Pi^2)*x^12 - 
           8*(-770741747 + 764400*Pi^2)*x^13 + 210*(20009839 + 194320*Pi^2)*
            x^14 - 25*(126607651 + 2481360*Pi^2)*x^15 + 
           280*(10510343 + 262080*Pi^2)*x^16 - 2096591960*x^17 - 
           280*(-10510343 + 262080*Pi^2)*x^18 + 
           25*(-126607651 + 2481360*Pi^2)*x^19 - 
           210*(-20009839 + 194320*Pi^2)*x^20 + 8*(770741747 + 764400*Pi^2)*
            x^21 - 70*(61825937 + 5040*Pi^2)*x^22 - 
           (10725927941 + 58800*Pi^2)*x^23 + 2665127780*x^24 + 
           11908724940*x^25 + 152646900*x^26 - 8626477440*x^27 - 
           1582017920*x^28 + 3960825120*x^29 + 1202170200*x^30 - 
           1050273000*x^31 - 412440000*x^32 + 122850000*x^33 + 56700000*x^34)*
          HPL[{1, 0}, x])/(15876000*x^11*(-1 + x^2)^9) + 
        lm*((221 + 192*x - 321*x^2 + 73932*x^3 - 54584*x^4 + 197784*x^5 - 
            54584*x^6 + 73932*x^7 - 321*x^8 + 192*x^9 + 221*x^10 + 
            12*Pi^2*(-1 - 6*x + 3*x^2 - 48*x^3 + 16*x^4 - 16*x^6 + 48*x^7 - 
              3*x^8 + 6*x^9 + x^10))/(1440*(-1 + x^2)^8) - 
          (x^2*(2 + 1842*x - 2275*x^2 + 13338*x^3 - 9078*x^4 + 18738*x^5 - 
             5650*x^6 + 4992*x^7 - 214*x^8 + 54*x^9 + 9*x^10)*HPL[{0}, x])/
           (20*(-1 + x^2)^9) - ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 
             2*x^6 + 6*x^7 + x^8)*HPL[{-1, 0}, x])/(10*(-1 + x^2)^7) + 
          (x^3*(360 - 540*x + 4500*x^2 - 4400*x^3 + 13200*x^4 - 7055*x^5 + 
             9810*x^6 - 2169*x^7 + 1476*x^8 - 5*x^9 + 6*x^10 + x^11)*
            HPL[{0, 0}, x])/(5*(-1 + x^2)^10) + 
          ((1 + 6*x - 2*x^2 + 54*x^3 - 18*x^4 + 54*x^5 - 2*x^6 + 6*x^7 + x^8)*
            HPL[{1, 0}, x])/(10*(-1 + x^2)^7)) - 
        (x*(1015 - 42945*x + 407610*x^2 - 819210*x^3 + 6097875*x^4 - 
           4870285*x^5 + 8353800*x^6 - 7674555*x^7 + 15461075*x^8 + 
           12868912*x^9 - 20129130*x^10 - 37002133*x^11 + 26571699*x^12 + 
           64173336*x^13 - 19815616*x^14 - 76271400*x^15 + 4336204*x^16 + 
           62992620*x^17 + 7167284*x^18 - 35714786*x^19 - 8463716*x^20 + 
           13303386*x^21 + 4391560*x^22 - 2939400*x^23 - 1184500*x^24 + 
           292500*x^25 + 135000*x^26)*HPL[{2, 0}, x])/(18900*(-1 + x^2)^10) + 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2, -1, 0}, x])/
         (45*(-1 + x^2)^8) - (4*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 
           1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{-2, 0, 0}, x])/(45*(-1 + x^2)^8) - 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{-2, 1, 0}, x])/
         (45*(-1 + x^2)^8) - (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 
           1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{-1, -2, 0}, x])/(45*(-1 + x^2)^8) - 
        ((67500 + 146250*x - 254750*x^2 - 738450*x^3 + 247030*x^4 + 
           1496943*x^5 + 225792*x^6 - 1525678*x^7 - 642698*x^8 + 782740*x^9 + 
           508242*x^10 - 157290*x^11 - 171598*x^12 - 9017*x^13 + 24682*x^14 + 
           10404*x^15 + 24682*x^16 - 9017*x^17 - 171598*x^18 - 157290*x^19 + 
           508242*x^20 + 782740*x^21 - 642698*x^22 - 1525678*x^23 + 
           225792*x^24 + 1496943*x^25 + 247030*x^26 - 738450*x^27 - 
           254750*x^28 + 146250*x^29 + 67500*x^30)*HPL[{-1, -1, 0}, x])/
         (18900*x^13*(-1 + x^2)^5) + ((-6838 - 6970*x + 147286*x^2 - 
           1199152*x^3 + 2703551*x^4 - 5367776*x^5 + 5343984*x^6 - 
           6317796*x^7 + 3286506*x^8 + 3096458*x^9 - 2199838*x^10 - 
           9808662*x^11 + 3454626*x^12 + 16175446*x^13 - 3723798*x^14 - 
           18635658*x^15 + 2859414*x^16 + 15084932*x^17 - 1532968*x^18 - 
           8435354*x^19 + 546283*x^20 + 3110930*x^21 - 116450*x^22 - 
           682250*x^23 + 11250*x^24 + 67500*x^25)*HPL[{-1, 0, 0}, x])/
         (9450*(-1 + x)^10*(1 + x)^8) + ((67500 + 146250*x - 254750*x^2 - 
           738450*x^3 + 247030*x^4 + 1496943*x^5 + 225792*x^6 - 1525678*x^7 - 
           642698*x^8 + 782740*x^9 + 508242*x^10 - 157290*x^11 - 
           171598*x^12 - 9017*x^13 + 24682*x^14 + 10404*x^15 + 24682*x^16 - 
           9017*x^17 - 171598*x^18 - 157290*x^19 + 508242*x^20 + 
           782740*x^21 - 642698*x^22 - 1525678*x^23 + 225792*x^24 + 
           1496943*x^25 + 247030*x^26 - 738450*x^27 - 254750*x^28 + 
           146250*x^29 + 67500*x^30)*HPL[{-1, 1, 0}, x])/
         (18900*x^13*(-1 + x^2)^5) + (2*(1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{-1, 2, 0}, x])/(45*(-1 + x^2)^8) - 
        (x*(-539412615 + 23269144185*x + 815230658025*x^2 - 
           1594211742207*x^3 - 31056118656948*x^4 + 24526562452110*x^5 + 
           391856187431646*x^6 + 445542859704582*x^7 - 1105429170372030*x^8 - 
           19451396874940686*x^9 - 4765615656251142*x^10 + 
           268891916517843306*x^11 - 180655069430656618*x^12 - 
           1818637932471212290*x^13 + 3135607857091037334*x^14 + 
           5765943655416996022*x^15 - 16462210807305905620*x^16 - 
           5541739308455536244*x^17 + 27035029717601729068*x^18 + 
           5537555902617695832*x^19 - 1826432163426790074*x^20 - 
           73788801358987914358*x^21 + 91390327817018674242*x^22 + 
           119748058343114240102*x^23 - 95321900745595850242*x^24 - 
           187457352037323409666*x^25 + 74515713570124355710*x^26 + 
           242547619881425719418*x^27 - 42785702718907981774*x^28 - 
           242118103313941243038*x^29 + 5840933819402051578*x^30 + 
           186904729733820827086*x^31 + 17186839240699541363*x^32 - 
           111458928285775864189*x^33 - 20290944882501327213*x^34 + 
           50920616632389431967*x^35 + 12854789425703681734*x^36 - 
           17583659274820005504*x^37 - 5406980618916577352*x^38 + 
           4508886916054457244*x^39 + 1579129631004308400*x^40 - 
           840569988875067360*x^41 - 321896118155241672*x^42 + 
           111143639859018876*x^43 + 45325759238700336*x^44 - 
           10081617060140280*x^45 - 4302145039468392*x^46 + 
           594035877569652*x^47 + 262126605436920*x^48 - 20430611515800*
            x^49 - 9246541959000*x^50 + 310892985000*x^51 + 
           143489070000*x^52)*HPL[{0, 0, 0}, x])/(18900*(-1 + x^2)^11*
          (9 - 82*x^2 + 9*x^4)^6) + (2*(1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{1, -2, 0}, x])/(45*(-1 + x^2)^8) + 
        ((67500 + 146250*x - 254750*x^2 - 738450*x^3 + 247030*x^4 + 
           1496943*x^5 + 225792*x^6 - 1525678*x^7 - 642698*x^8 + 782740*x^9 + 
           508242*x^10 - 157290*x^11 - 171598*x^12 - 9017*x^13 + 24682*x^14 + 
           10404*x^15 + 24682*x^16 - 9017*x^17 - 171598*x^18 - 157290*x^19 + 
           508242*x^20 + 782740*x^21 - 642698*x^22 - 1525678*x^23 + 
           225792*x^24 + 1496943*x^25 + 247030*x^26 - 738450*x^27 - 
           254750*x^28 + 146250*x^29 + 67500*x^30)*HPL[{1, -1, 0}, x])/
         (18900*x^13*(-1 + x^2)^5) + ((6838 + 36002*x - 51262*x^2 + 
           865984*x^3 + 339497*x^4 + 893652*x^5 + 1439760*x^6 + 1725552*x^7 + 
           3320382*x^8 + 1484354*x^9 - 8622458*x^10 - 7524430*x^11 + 
           11946214*x^12 + 18142502*x^13 - 7742930*x^14 - 23720554*x^15 - 
           1562478*x^16 + 18427496*x^17 + 6921160*x^18 - 8168818*x^19 - 
           5401403*x^20 + 1597870*x^21 + 1945450*x^22 + 97250*x^23 - 
           281250*x^24 - 67500*x^25)*HPL[{1, 0, 0}, x])/
         (9450*(-1 + x)^8*(1 + x)^10) - ((67500 + 146250*x - 254750*x^2 - 
           738450*x^3 + 247030*x^4 + 1496943*x^5 + 225792*x^6 - 1525678*x^7 - 
           642698*x^8 + 782740*x^9 + 508242*x^10 - 157290*x^11 - 
           171598*x^12 - 9017*x^13 + 24682*x^14 + 10404*x^15 + 24682*x^16 - 
           9017*x^17 - 171598*x^18 - 157290*x^19 + 508242*x^20 + 
           782740*x^21 - 642698*x^22 - 1525678*x^23 + 225792*x^24 + 
           1496943*x^25 + 247030*x^26 - 738450*x^27 - 254750*x^28 + 
           146250*x^29 + 67500*x^30)*HPL[{1, 1, 0}, x])/
         (18900*x^13*(-1 + x^2)^5) - (2*(1 + 6*x - 103*x^2 + 700*x^3 - 
           1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{1, 2, 0}, x])/(45*(-1 + x^2)^8) - 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{2, -1, 0}, x])/
         (45*(-1 + x^2)^8) + (4*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 
           1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{2, 0, 0}, x])/(45*(-1 + x^2)^8) + 
        (2*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{2, 1, 0}, x])/
         (45*(-1 + x^2)^8) - (4*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 
           1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*
          HPL[{-1, 1, 0, 0}, x])/(45*(-1 + x^2)^8) - 
        (4*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
           700*x^7 - 103*x^8 + 6*x^9 + x^10)*HPL[{1, -1, 0, 0}, x])/
         (45*(-1 + x^2)^8) + ((1 + 11*x - 79*x^2 + 983*x^3 - 1519*x^4 + 
           4040*x^5 - 2444*x^6 + 2792*x^7 - 464*x^8 + 289*x^9 + 25*x^10 + 
           5*x^11)*master3l10a[x])/(180*(-1 + x^2)^9) - 
        (x*(5 + 25*x + 289*x^2 - 464*x^3 + 2792*x^4 - 2444*x^5 + 4040*x^6 - 
           1519*x^7 + 983*x^8 - 79*x^9 + 11*x^10 + x^11)*master3l10b[x])/
         (180*(-1 + x^2)^9) + ((36780231168 - 219984864687*x + 
           1577323152297*x^2 - 5156784534762*x^3 + 6203142941544*x^4 - 
           5606272174671*x^5 + 240649731351*x^6 + 1706932920168*x^7 - 
           973764252864*x^8 + 540328340034*x^9 + 98219048346*x^10 - 
           273934359132*x^11 + 45280970640*x^12 + 41091162378*x^13 - 
           13008879026*x^14 - 2236800216*x^15 + 1442524416*x^16 - 
           48383027*x^17 - 77601939*x^18 + 9956534*x^19 + 1794248*x^20 - 
           292635*x^21 - 6677*x^22)*master3l8a[x])/(453600*(-9 + x^2)^6*
          (-1 + x^2)^10) - ((4060 - 176777*x + 150325*x^2 + 10004580*x^3 - 
           12840366*x^4 - 259152035*x^5 + 274778189*x^6 + 3964932000*x^7 - 
           2672435808*x^8 - 38371794922*x^9 + 12743040170*x^10 + 
           231109171192*x^11 - 40785838212*x^12 - 781009535382*x^13 + 
           292551429954*x^14 + 1040815666800*x^15 - 1816581627756*x^16 + 
           577131299235*x^17 + 3655791054657*x^18 - 717237731772*x^19 + 
           1711026799650*x^20 - 40656095991*x^21 + 48140635473*x^22 + 
           34101768528*x^23)*master3l8b[x])/(453600*x*(1 - 9*x^2)^6*
          (-1 + x^2)^10) - ((3937888872 - 9546901623*x + 85807935225*x^2 - 
           192491752131*x^3 + 314306726679*x^4 - 129748034682*x^5 + 
           80355249108*x^6 - 20508043164*x^7 + 12653439564*x^8 + 
           43992426870*x^9 - 36526867106*x^10 - 12596407978*x^11 + 
           11296467090*x^12 + 1591188144*x^13 - 1599318876*x^14 - 
           95936652*x^15 + 122712148*x^16 + 1917881*x^17 - 5073871*x^18 + 
           52885*x^19 + 91727*x^20 - 2030*x^21)*master3l9a[x])/
         (151200*(-9 + x^2)^5*(-1 + x^2)^10) - 
        ((-2030 + 91727*x + 52885*x^2 - 5073871*x^3 + 1917881*x^4 + 
           122712148*x^5 - 95936652*x^6 - 1599318876*x^7 + 1591188144*x^8 + 
           11296467090*x^9 - 12596407978*x^10 - 36526867106*x^11 + 
           43992426870*x^12 + 12653439564*x^13 - 20508043164*x^14 + 
           80355249108*x^15 - 129748034682*x^16 + 314306726679*x^17 - 
           192491752131*x^18 + 85807935225*x^19 - 9546901623*x^20 + 
           3937888872*x^21)*master3l9b[x])/(453600*x*(-1 + x^2)^10*
          (-1 + 9*x^2)^5) + (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*
            (67500 + 146250*x - 254750*x^2 - 738450*x^3 + 247030*x^4 + 
             1496943*x^5 + 225792*x^6 - 1525678*x^7 - 642698*x^8 + 
             782740*x^9 + 508242*x^10 - 157290*x^11 - 171598*x^12 - 
             9017*x^13 + 24682*x^14 + 10404*x^15 + 24682*x^16 - 9017*x^17 - 
             171598*x^18 - 157290*x^19 + 508242*x^20 + 782740*x^21 - 
             642698*x^22 - 1525678*x^23 + 225792*x^24 + 1496943*x^25 + 
             247030*x^26 - 738450*x^27 - 254750*x^28 + 146250*x^29 + 
             67500*x^30) - 10080*x^13*(1 + 6*x - 103*x^2 + 700*x^3 - 
             1158*x^4 + 1948*x^5 - 1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + 
             x^10)*Zeta[3]))/(226800*x^13*(-1 + x^2)^8) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(67500 + 146250*x - 254750*x^2 - 
              738450*x^3 + 247030*x^4 + 1496943*x^5 + 225792*x^6 - 
              1525678*x^7 - 642698*x^8 + 782740*x^9 + 508242*x^10 - 
              157290*x^11 - 171598*x^12 - 9017*x^13 + 24682*x^14 + 
              10404*x^15 + 24682*x^16 - 9017*x^17 - 171598*x^18 - 
              157290*x^19 + 508242*x^20 + 782740*x^21 - 642698*x^22 - 
              1525678*x^23 + 225792*x^24 + 1496943*x^25 + 247030*x^26 - 
              738450*x^27 - 254750*x^28 + 146250*x^29 + 67500*x^30)) + 
           10080*x^13*(1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 
             1158*x^6 + 700*x^7 - 103*x^8 + 6*x^9 + x^10)*Zeta[3]))/
         (226800*x^13*(-1 + x^2)^8) + (HPL[{0}, x]*(180796228200000 + 
           391725161100000*x - 11289050411940000*x^2 - 24959120187708000*
            x^3 + 307505559446089200*x^4 + 698142596437820520*x^5 - 
           4793446759872710520*x^6 - 11279480612267669760*x^7 + 
           47189492097400361520*x^8 + 116723625557193334260*x^9 - 
           3061800*(99938490896131 + 147987*Pi^2)*x^10 + 
           17496*(-46490162340436882 + 1095741675*Pi^2)*x^11 + 
           35280*(-1103636209822708135 + 64717083552992562*Pi^2)*x^28 + 
           27*(30127107064501975761 + 214879623248705657480*Pi^2)*x^45 + 
           210*(1457099411915174805 + 8216941807160399236*Pi^2)*x^46 - 
           945*(123517829924853993 + 1675534473654211952*Pi^2)*x^47 - 
           45360*(1040332718196657 + 12023242135193024*Pi^2)*x^48 + 
           816480*(13814766573912 + 380110107982073*Pi^2)*x^49 + 
           204120*(23483474230221 + 577406338278728*Pi^2)*x^50 - 
           1837080*(380028412719 + 23236382935052*Pi^2)*x^51 - 
           1224720*(251082336735 + 14155225566454*Pi^2)*x^52 + 
           11022480*(2264383350 + 362280936637*Pi^2)*x^53 + 
           198404640*(56899125 + 8571528491*Pi^2)*x^54 - 
           297606960*(1316250 + 809943379*Pi^2)*x^55 - 
           5952139200*(30375 + 17854067*Pi^2)*x^56 + 8450281782936000*Pi^2*
            x^57 + 3823282213380000*Pi^2*x^58 - 130575053700000*Pi^2*x^59 - 
           60265409400000*Pi^2*x^60 + 24*x^33*(2967628209806162231269 + 
             1333510687083964100075*Pi^2 - 11016537549192504000*Zeta[3]) - 
           280*x^26*(-147046066749525853615 + 4960675747302334668*Pi^2 - 
             8626956911056310400*Zeta[3]) - 24*x^25*
            (-2041969763667158443868 + 6560566123387168515*Pi^2 - 
             4218583234193496000*Zeta[3]) + 280*x^24*(-75775987410053966033 + 
             2577475763217288324*Pi^2 - 3619319336312198400*Zeta[3]) - 
           72*x^35*(1068050889964115220433 + 664843373320902548605*Pi^2 - 
             1361151899028936000*Zeta[3]) + 108*x^21*(726388718302498485547 + 
             24639025261251870*Pi^2 - 907434599352624000*Zeta[3]) + 
           36*x^37*(1646619572706069347399 + 1512964466681535671370*Pi^2 - 
             446312381813424000*Zeta[3]) - 72*x^19*(824660045163430892062 + 
             14266876927577715*Pi^2 - 223156190906712000*Zeta[3]) - 
           560*x^22*(-19779106338141174103 + 303817754767697331*Pi^2 - 
             163394522804520000*Zeta[3]) + 840*x^36*(-2224193636641717501 + 
             16017527671322259448*Pi^2 - 30502666745913600*Zeta[3]) - 
           108*x^39*(305906511247585905413 + 437672000537937361350*Pi^2 - 
             13031554043088000*Zeta[3]) - 840*x^38*(-9085165317043054019 + 
             5833646439871289242*Pi^2 - 8821989569232000*Zeta[3]) + 
           216*x^17*(152763225871506665419 + 217132272420525*Pi^2 - 
             6515777021544000*Zeta[3]) - 22680*x^16*(-312724970691484349 + 
             3333667696380*Pi^2 - 34921862035200*Zeta[3]) + 
           3150*x^14*(-1214378431977274649 + 2113697035044*Pi^2 - 
             12770909867520*Zeta[3]) - 648*x^43*(6061470080147249003 + 
             24050548676247654820*Pi^2 - 1874923848000*Zeta[3]) - 
           34020*x^12*(-38983113312035747 + 4620562380*Pi^2 - 
             23808556800*Zeta[3]) + 10125*x^15*(-1324334412638496893 + 
             609276522456*Pi^2 + 6359741692416*Zeta[3]) - 
           81*x^13*(-48480832682694616699 + 8423654778000*Pi^2 + 
             14999390784000*Zeta[3]) + 840*x^42*(4555632518655800430 + 
             5771956754969149607*Pi^2 + 47890912003200*Zeta[3]) - 
           840*x^40*(8486502989474196423 + 2812191163615058372*Pi^2 + 
             942890274950400*Zeta[3]) - 1680*x^18*(4314867079741065157 + 
             271337634582525*Pi^2 + 4410994784616000*Zeta[3]) + 
           840*x^20*(250313134034771701 + 21566077024886100*Pi^2 + 
             30502666745913600*Zeta[3]) - 280*x^34*(43419718085997431231 + 
             63258831800434244394*Pi^2 + 326789045609040000*Zeta[3]) + 
           280*x^32*(182384956436148340313 + 55776131633386338300*Pi^2 + 
             3619319336312198400*Zeta[3]) - 168*x^27*(227554564408455003859 + 
             4795323835129114105*Pi^2 + 10730893459567176000*Zeta[3]) - 
           6*x^31*(9922113138663042083897 + 2730135066788283865340*Pi^2 + 
             16874332936773984000*Zeta[3]) - 140*x^30*
            (636391600454578829705 + 66888954267046923216*Pi^2 + 
             17253913822112620800*Zeta[3]) + 12*x^23*
            (-6206342449038172550213 + 2935591810567462410*Pi^2 + 
             22033075098385008000*Zeta[3]) + 42*x^29*
            (1637089432362168800461 + 155177023014329748540*Pi^2 + 
             42923573838268704000*Zeta[3]) - 420*x^44*
            (8746317158636390060*Pi^2 + 81*(38983276174468487 + 23808556800*
                Zeta[3])) + 60*x^41*(520440257439998484694*Pi^2 - 
             675*(-331318132364530655 + 1589935423104*Zeta[3]))))/
         (190512000*x^9*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6) + 
        (-235200*Pi^4*x^11*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^6*
           (1 + 6*x - 103*x^2 + 700*x^3 - 1158*x^4 + 1948*x^5 - 1158*x^6 + 
            700*x^7 - 103*x^8 + 6*x^9 + x^10) + 4*Pi^2*(9 - 82*x^2 + 9*x^4)^6*
           (-56700000 - 122850000*x + 469140000*x^2 + 1173123000*x^3 - 
            1614610200*x^4 - 5011098120*x^5 + 2784188120*x^6 + 
            12587302560*x^7 - 1734664820*x^8 - 20535202380*x^9 - 
            2512480880*x^10 + 22634652881*x^11 + 6992943370*x^12 - 
            16891861917*x^13 - 8529881780*x^14 + 9331125251*x^15 + 
            1259170150*x^16 - 1068599315*x^17 + 1068599315*x^19 - 
            1259170150*x^20 - 9331125251*x^21 + 8529881780*x^22 + 
            16891861917*x^23 - 6992943370*x^24 - 22634652881*x^25 + 
            2512480880*x^26 + 20535202380*x^27 + 1734664820*x^28 - 
            12587302560*x^29 - 2784188120*x^30 + 5011098120*x^31 + 
            1614610200*x^32 - 1173123000*x^33 - 469140000*x^34 + 
            122850000*x^35 + 56700000*x^36) + x^2*(-180796228200000 - 
            391725161100000*x + 11349315821340000*x^2 + 25089695241408000*
             x^3 - 311245976721544200*x^4 - 706413337521919020*x^5 + 
            4894550037013539420*x^6 + 11509102124193000600*x^7 - 
            48749648604584660460*x^8 - 101403381395232000*x^57*Zeta[3] - 
            45879386560560000*x^58*Zeta[3] + 1566900644400000*x^59*Zeta[3] + 
            723184912800000*x^60*Zeta[3] + 17856417600*x^56*
             (-10125 + 71416268*Zeta[3]) + 688905*x^9*(-174768194526857 + 
              351133056*Zeta[3]) + 238140*x^12*(-5974236887006129 + 
              422703360*Zeta[3]) + 1785641760*x^55*(-219375 + 
              1619886758*Zeta[3]) + 153090*x^10*(2097765844308733 + 
              1696248864*Zeta[3]) - 595213920*x^54*(-19067625 + 
              34286113964*Zeta[3]) - 132269760*x^53*(-189685800 + 
              362280936637*Zeta[3]) - 2187*x^11*(-389093062329837797 + 
              6304507473600*Zeta[3]) + 1837080*x^52*(-169424291115 + 
              113241804531632*Zeta[3]) + 2755620*x^51*(-256353683571 + 
              185891063480416*Zeta[3]) - 630*x^14*(-6715010991721366021 + 
              700120671741792*Zeta[3]) + 81*x^13*(-51648761128483043659 + 
              4128233253399360*Zeta[3]) - 306180*x^50*(-15985858112919 + 
              4619250706229824*Zeta[3]) - 612360*x^49*(-18794666738835 + 
              6081761727713168*Zeta[3]) + 2916*x^17*(-12615115779698186063 + 
              10818431693202000*Zeta[3]) - 5184*x^19*(-13087710131850941623 + 
              14842390056764445*Zeta[3]) + 840*x^16*(-9692466508736178931 + 
              15419921253870816*Zeta[3]) - 2940*x^18*(-2751281877145393471 + 
              57085936834470048*Zeta[3]) + 68040*x^48*(-716485085336349 + 
              96185937081544192*Zeta[3]) - 27*x^15*(-540834794318266728799 + 
              162839736080138880*Zeta[3]) + 840*x^20*(6673282757953573819 + 
              1296865020099401424*Zeta[3]) - 1120*x^22*
             (29938607012283120287 + 2454440521985124432*Zeta[3]) + 
            8820*x^44*(-161291393527978323 + 4997895987148689920*Zeta[3]) + 
            2835*x^47*(-42468213508349121 + 6702137972799613376*Zeta[3]) + 
            2940*x^38*(2991907680526552171 + 19942242326987558496*Zeta[3]) - 
            280*x^24*(-101673976576067096845 + 20908106945562264192*Zeta[
                3]) - 7840*x^32*(-2276905104266647855 + 23707247919232799448*
               Zeta[3]) - 630*x^46*(-509751236254048389 + 
              32867767017933034912*Zeta[3]) - 12*x^21*
             (7957619370180444764287 + 55966028755786914240*Zeta[3]) + 
            420*x^40*(-19480552416363901907 + 67523313563151816000*Zeta[3]) - 
            630*x^42*(-6714808073473135351 + 92352056521242420704*Zeta[3]) - 
            210*x^25*(440811481561373176079 + 134326054630249033120*Zeta[
                3]) - 840*x^36*(-316243746620085859 + 190720875305559906912*
               Zeta[3]) + 28*x^23*(4078175546458676256791 + 
              254619869281735990080*Zeta[3]) + 140*x^26*
             (93466729386111932077 + 366080661051349815648*Zeta[3]) + 
            560*x^34*(-27968703319281797449 + 371726374850432220408*Zeta[
                3]) - 280*x^28*(-535695243998140148605 + 
              405042765031164041952*Zeta[3]) - 644*x^33*
             (-158414774483122326667 + 584783929024393482480*Zeta[3]) + 
            66*x^27*(-705126417889052953351 + 726994293471724121760*Zeta[
                3]) + 210*x^31*(-297802357085482704989 + 
              795507850397225268896*Zeta[3]) - 81*x^45*
             (-10505109150739648269 + 859518645460301160320*Zeta[3]) + 
            140*x^30*(-282541549538469672833 + 1060543888899314398848*Zeta[
                3]) + 324*x^39*(-114414329828958841817 + 
              1750776380783604594000*Zeta[3]) + 81*x^43*
             (-51652802274404311009 + 2308856321204929265280*Zeta[3]) - 
            216*x^37*(-321877370739774275177 + 3026270308125146902680*Zeta[
                3]) - 6*x^29*(-3001444748653842887089 + 
              6846739935965560891680*Zeta[3]) - 9*x^41*
             (-1624775709276345804447 + 41635653373459904951360*Zeta[3]) + 
            12*x^35*(-8180164529308457468137 + 47813436133508788580880*Zeta[
                3])))/(762048000*x^11*(-1 + x^2)^10*(9 - 82*x^2 + 9*x^4)^6)))
 
CbarLData["a", 2, 4] = 
    NC*(CF*(NL*(-(Pi^2*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 
              68*x^6 + 112*x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{-1}, x])/
           (2835*(-1 + x^2)^9) + (x^2*(-20484 + 18900*(2831 + 168*Pi^2)*x - 
             54*(1678651 + 117600*Pi^2)*x^2 + 882*(589811 + 45000*Pi^2)*x^3 - 
             160*(2729912 + 277095*Pi^2)*x^4 + 14*(53183351 + 8589000*Pi^2)*
              x^5 - 105*(1039207 + 752640*Pi^2)*x^6 + 
             56*(-9187159 + 2137800*Pi^2)*x^7 + (470324908 - 44123520*Pi^2)*
              x^8 + 8316*(-83527 + 4760*Pi^2)*x^9 + (164479010 - 6444480*
                Pi^2)*x^10 + 70*(-1554661 + 47544*Pi^2)*x^11 - 
             24*(-77017 + 420*Pi^2)*x^12 + 70*(-5263 + 168*Pi^2)*x^13 + 
             7*(-11719 + 240*Pi^2)*x^14)*HPL[{0}, x])/
           (4762800*(-1 + x^2)^12) + lm^2*((1 + 7*x - 34*x^2 + 714*x^3 - 
              1133*x^4 + 3689*x^5 - 2708*x^6 + 3689*x^7 - 1133*x^8 + 
              714*x^9 - 34*x^10 + 7*x^11 + x^12)/(315*(-1 + x^2)^10) - 
            (4*x^3*(1 - 2*x + 10*x^2 - 10*x^3 + 20*x^4 - 10*x^5 + 10*x^6 - 2*
                x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11)) + 
          (Pi^2*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 
             112*x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{1}, x])/
           (2835*(-1 + x^2)^9) - (4*x^3*(1890 - 3780*x + 23625*x^2 - 
             26390*x^3 + 71575*x^4 - 47040*x^5 + 71260*x^6 - 26264*x^7 + 
             23562*x^8 - 3836*x^9 + 1981*x^10 - 6*x^11 + 7*x^12 + x^13)*
            HPL[{-2, 0}, x])/(945*(-1 + x^2)^12) + 
          ((569 + 3528*x - 55415*x^2 + 1652392*x^3 - 2935159*x^4 + 
             13175260*x^5 - 12034095*x^6 + 24629640*x^7 - 12034095*x^8 + 
             13175260*x^9 - 2935159*x^10 + 1652392*x^11 - 55415*x^12 + 
             3528*x^13 + 569*x^14)*HPL[{-1, 0}, x])/(132300*(-1 + x^2)^11) + 
          (x^3*(294000 - 588000*x + 4806900*x^2 - 5713400*x^3 + 
             20604500*x^4 - 15023400*x^5 + 28993300*x^6 - 11884264*x^7 + 
             12870732*x^8 - 2276736*x^9 + 1379056*x^10 - 3936*x^11 + 
             8232*x^12 + 1111*x^13)*HPL[{0, 0}, x])/(66150*(-1 + x^2)^12) - 
          ((569 + 3528*x - 55415*x^2 + 1652392*x^3 - 2935159*x^4 + 
             13175260*x^5 - 12034095*x^6 + 24629640*x^7 - 12034095*x^8 + 
             13175260*x^9 - 2935159*x^10 + 1652392*x^11 - 55415*x^12 + 
             3528*x^13 + 569*x^14)*HPL[{1, 0}, x])/(132300*(-1 + x^2)^11) + 
          lm*((11719 + 52630*x - 237694*x^2 + 8008170*x^3 - 11034515*x^4 + 
              40877600*x^5 - 26622620*x^6 + 40877600*x^7 - 11034515*x^8 + 
              8008170*x^9 - 237694*x^10 + 52630*x^11 + 11719*x^12 + 
              240*Pi^2*(-1 - 7*x + 4*x^2 - 105*x^3 + 65*x^4 - 140*x^5 + 
                140*x^7 - 65*x^8 + 105*x^9 - 4*x^10 + 7*x^11 + x^12))/
             (1360800*(-1 + x^2)^10) - (x^2*(4 + 11128*x - 19860*x^2 + 123817*
                x^3 - 123218*x^4 + 301254*x^5 - 161018*x^6 + 195217*x^7 - 
               46236*x^8 + 28096*x^9 - 836*x^10 + 168*x^11 + 24*x^12)*
              HPL[{0}, x])/(1890*(-1 + x^2)^11) - 
            (2*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*
                x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{-1, 0}, x])/
             (945*(-1 + x^2)^9) + (4*x^3*(630 - 1260*x + 12285*x^2 - 16310*
                x^3 + 58975*x^4 - 47040*x^5 + 83860*x^6 - 36344*x^7 + 34902*
                x^8 - 6356*x^9 + 3241*x^10 - 6*x^11 + 7*x^12 + x^13)*
              HPL[{0, 0}, x])/(945*(-1 + x^2)^12) + 
            (2*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*
                x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{1, 0}, x])/
             (945*(-1 + x^2)^9)) + (4*x^3*(1890 - 3780*x + 23625*x^2 - 
             26390*x^3 + 71575*x^4 - 47040*x^5 + 71260*x^6 - 26264*x^7 + 
             23562*x^8 - 3836*x^9 + 1981*x^10 - 6*x^11 + 7*x^12 + x^13)*
            HPL[{2, 0}, x])/(945*(-1 + x^2)^12) + 
          (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 
             112*x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{-1, -1, 0}, x])/
           (945*(-1 + x^2)^9) - (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 
             252*x^5 - 68*x^6 + 112*x^7 - 3*x^8 + 7*x^9 + x^10)*
            HPL[{-1, 1, 0}, x])/(945*(-1 + x^2)^9) - 
          (8*x^3*(630 - 1260*x + 12285*x^2 - 16310*x^3 + 58975*x^4 - 
             47040*x^5 + 83860*x^6 - 36344*x^7 + 34902*x^8 - 6356*x^9 + 
             3241*x^10 - 6*x^11 + 7*x^12 + x^13)*HPL[{0, 0, 0}, x])/
           (945*(-1 + x^2)^12) - (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 
             252*x^5 - 68*x^6 + 112*x^7 - 3*x^8 + 7*x^9 + x^10)*
            HPL[{1, -1, 0}, x])/(945*(-1 + x^2)^9) + 
          (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 
             112*x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{1, 1, 0}, x])/
           (945*(-1 + x^2)^9) + (19387248*x^14 - 7316344*x^15 + 
            1868447*x^16 - 144*Pi^2*(-569 - 3528*x + 55984*x^2 - 
              1648864*x^3 + 2879744*x^4 - 11522868*x^5 + 9098936*x^6 - 
              11454380*x^7 + 11454380*x^9 - 9098936*x^10 + 11522868*x^11 - 
              2879744*x^12 + 1648864*x^13 - 55984*x^14 + 3528*x^15 + 
              569*x^16) - 48*x^2*(-403901 + 60480*Zeta[3]) + 
            56*x*(-130649 + 60480*Zeta[3]) + 7*(266921 + 69120*Zeta[3]) + 
            13608*x^5*(297631 + 837760*Zeta[3]) + 13608*x^11*
             (297631 + 840000*Zeta[3]) + 56*x^13*(21896227 + 16329600*Zeta[
                3]) + 56*x^3*(21896227 + 17115840*Zeta[3]) - 
            40*x^12*(33017371 + 45722880*Zeta[3]) - 
            40*x^4*(33017371 + 46400256*Zeta[3]) + 56*x^7*(-94089911 + 
              615686400*Zeta[3]) + 56*x^9*(-94089911 + 618408000*Zeta[3]) - 
            16*x^6*(47068339 + 794223360*Zeta[3]) - 
            16*x^10*(47068339 + 798033600*Zeta[3]) - 
            6*x^8*(-684177523 + 3793305600*Zeta[3]))/(228614400*
            (-1 + x^2)^12)) + 
        NM*(-((95760 + 670320*x - 6244344*x^2 - 177772140*x^3 + 
              526444425*x^4 + 11598070806*x^5 - 27941332319*x^6 - 
              277290199340*x^7 + 743147059142*x^8 + 1856598838290*x^9 - 
              9817759013060*x^10 + 33569753563052*x^11 + 46108293669769*x^
                12 - 735624389450986*x^13 + 360441288359641*x^14 + 
              5027583420072444*x^15 - 5767189268466226*x^16 - 
              4287734244943646*x^17 + 23779641284657404*x^18 - 
              105062720329446516*x^19 + 16885781137363419*x^20 + 
              351453838772902194*x^21 - 321776667067180797*x^22 + 
              543133464320915244*x^23 + 219458577554072874*x^24 - 
              2324883669472444122*x^25 + 1377523672862899068*x^26 - 
              2854226580451669836*x^27 + 452629248645163347*x^28 - 
              290894115035432286*x^29 - 233730607226332221*x^30 + 
              188749252585321092*x^31 - 82916093218660110*x^32 + 
              20264096930112630*x^33 - 6532729188030972*x^34 + 
              1680*Pi^2*(1 - 9*x^2)^8*(-1 + x^2)^4*(1 + 7*x - 3*x^2 + 
                112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*x^7 - 3*x^8 + 
                7*x^9 + x^10))*HPL[{0}, x])/(4762800*(1 - 9*x^2)^8*
            (-1 + x^2)^13) + lm^2*((1 + 7*x - 34*x^2 + 714*x^3 - 1133*x^4 + 
              3689*x^5 - 2708*x^6 + 3689*x^7 - 1133*x^8 + 714*x^9 - 34*x^10 + 
              7*x^11 + x^12)/(315*(-1 + x^2)^10) - 
            (4*x^3*(1 - 2*x + 10*x^2 - 10*x^3 + 20*x^4 - 10*x^5 + 10*x^6 - 2*
                x^7 + x^8)*HPL[{0}, x])/(3*(-1 + x^2)^11)) + 
          (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 
             112*x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{-2, 0}, x])/
           (945*(-1 + x^2)^9) + ((1680 + 11760*x - 102092*x^2 - 4259864*x^3 + 
             11068593*x^4 + 243118960*x^5 - 547753727*x^6 - 3555561464*x^7 + 
             11440285055*x^8 - 48797114156*x^9 - 63904139485*x^10 + 
             2087358714336*x^11 - 1422277392855*x^12 - 23883365921856*x^13 + 
             28226147553985*x^14 + 77100065682416*x^15 - 183866363039083*
              x^16 + 614382945553188*x^17 + 115643798068029*x^18 - 
             5489074216082520*x^19 + 4224245890540131*x^20 + 
             6466113434026512*x^21 - 15896251995435405*x^22 + 
             54148035012113448*x^23 - 7704736792409943*x^24 - 
             100531226264839524*x^25 + 82457957282837949*x^26 - 
             193454337168692208*x^27 + 41020551878226579*x^28 - 
             35646909491398464*x^29 - 13217060350655109*x^30 + 
             11033185486702176*x^31 - 6219735940227357*x^32 + 
             1587190668513660*x^33 - 502644627609345*x^34)*HPL[{0, 0}, x])/
           (132300*(1 - 9*x^2)^8*(-1 + x^2)^13) + 
          lm*((11719 + 52630*x - 237694*x^2 + 8008170*x^3 - 11034515*x^4 + 
              40877600*x^5 - 26622620*x^6 + 40877600*x^7 - 11034515*x^8 + 
              8008170*x^9 - 237694*x^10 + 52630*x^11 + 11719*x^12 + 
              240*Pi^2*(-1 - 7*x + 4*x^2 - 105*x^3 + 65*x^4 - 140*x^5 + 
                140*x^7 - 65*x^8 + 105*x^9 - 4*x^10 + 7*x^11 + x^12))/
             (1360800*(-1 + x^2)^10) - (x^2*(4 + 11128*x - 19860*x^2 + 123817*
                x^3 - 123218*x^4 + 301254*x^5 - 161018*x^6 + 195217*x^7 - 
               46236*x^8 + 28096*x^9 - 836*x^10 + 168*x^11 + 24*x^12)*
              HPL[{0}, x])/(1890*(-1 + x^2)^11) - 
            (2*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*
                x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{-1, 0}, x])/
             (945*(-1 + x^2)^9) + (4*x^3*(630 - 1260*x + 12285*x^2 - 16310*
                x^3 + 58975*x^4 - 47040*x^5 + 83860*x^6 - 36344*x^7 + 34902*
                x^8 - 6356*x^9 + 3241*x^10 - 6*x^11 + 7*x^12 + x^13)*
              HPL[{0, 0}, x])/(945*(-1 + x^2)^12) + 
            (2*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*
                x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{1, 0}, x])/
             (945*(-1 + x^2)^9)) - (4*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 
             252*x^5 - 68*x^6 + 112*x^7 - 3*x^8 + 7*x^9 + x^10)*
            HPL[{2, 0}, x])/(945*(-1 + x^2)^9) + 
          (2*(-6 - 30*x + 102*x^2 - 7580*x^3 + 23339*x^4 - 126710*x^5 + 
             186905*x^6 - 530600*x^7 + 414500*x^8 - 720850*x^9 + 
             308776*x^10 - 320020*x^11 + 67273*x^12 - 35950*x^13 + 1651*x^14)*
            HPL[{-1, 0, 0}, x])/(945*(-1 + x)^12*(1 + x)^10) + 
          (2*(-70 - 490*x + 3290*x^2 + 234220*x^3 - 571696*x^4 - 
             7358722*x^5 + 22587578*x^6 - 50913492*x^7 - 137382497*x^8 + 
             4150469638*x^9 - 8241345169*x^10 - 16021734876*x^11 + 
             183541325586*x^12 - 1343988520742*x^13 - 1054927965592*x^14 + 
             26125368622388*x^15 - 10026275381323*x^16 - 201810471763194*
              x^17 + 184430813189025*x^18 + 527224564648404*x^19 - 
             1033097905274292*x^20 + 1828155789316962*x^21 + 
             1666037333181186*x^22 - 12718952621011980*x^23 + 
             4917145373995185*x^24 + 9314556198246810*x^25 - 
             13874592821457591*x^26 + 39079439908208028*x^27 - 
             10177522878373038*x^28 + 11899056925292166*x^29 + 
             1488278936988252*x^30 - 878815382379732*x^31 + 1076028651940545*
              x^32 - 215483524696188*x^33 + 94627736633421*x^34)*
            HPL[{0, 0, 0}, x])/(33075*(1 - 9*x^2)^8*(-1 + x^2)^13) + 
          (2*(6 + 54*x + 66*x^2 + 6364*x^3 + 111*x^4 + 64250*x^5 - 
             18555*x^6 + 275520*x^7 - 145560*x^8 + 446610*x^9 - 176196*x^10 + 
             227436*x^11 - 49451*x^12 + 29346*x^13 - 2281*x^14)*
            HPL[{1, 0, 0}, x])/(945*(-1 + x)^10*(1 + x)^12) + 
          ((-280 - 1960*x + 18453*x^2 + 622496*x^3 - 1684507*x^4 - 
             40947480*x^5 + 91872755*x^6 + 998073860*x^7 - 2514296729*x^8 - 
             7301538048*x^9 + 35140899773*x^10 - 115231368056*x^11 - 
             198651896923*x^12 + 2881367282080*x^13 - 922030355421*x^14 - 
             24053276637572*x^15 + 21223614009487*x^16 + 71666399744856*
              x^17 - 122733261055305*x^18 + 167333670587664*x^19 + 
             211940004906423*x^20 - 1438962443370648*x^21 + 
             523993535268273*x^22 + 1280293160876604*x^23 - 1610647108344099*
              x^24 + 4289421046872528*x^25 - 1058945509304073*x^26 + 
             1021097995605576*x^27 + 239357747293119*x^28 - 
             212567122536048*x^29 + 136297344962745*x^30 - 35079661512252*
              x^31 + 11173094768709*x^32)*master3l8b[x])/
           (396900*x^2*(1 - 9*x^2)^8*(-1 + x^2)^13) + 
          ((140 + 980*x - 6693*x^2 - 294196*x^3 + 573656*x^4 + 18736368*x^5 - 
             33415093*x^6 - 413722204*x^7 + 899736836*x^8 + 2386178536*x^9 - 
             11702317433*x^10 + 42774241048*x^11 + 60707043888*x^12 - 
             784018787412*x^13 + 174212985143*x^14 + 4550760884488*x^15 - 
             3551373763052*x^16 - 5701781373372*x^17 + 13925152377873*x^18 - 
             29958906829572*x^19 - 11972632894632*x^20 + 30428536857768*
              x^21 + 5806011188961*x^22 + 78180205266324*x^23 - 
             87358738534308*x^24 + 601273562944320*x^25 - 255851677982259*
              x^26 + 519931742998752*x^27 - 74819405701728*x^28 + 
             82512523336572*x^29 + 1241454974301*x^30)*master3l9b[x])/
           (396900*x^2*(-1 + x^2)^13*(-1 + 9*x^2)^7) + 
          (-151200 - 1058400*x + x^20*(1069429094960088890 - 
              119277176491468800*Zeta[3]) + x^16*(40204677759430052 - 
              11129476488560640*Zeta[3]) + x^6*(79677221092 - 
              674795520*Zeta[3]) + x^2*(13773373 - 322560*Zeta[3]) - 
            56*x^3*(-6813689 + 40320*Zeta[3]) - 2688*x^5*(9588197 + 
              63000*Zeta[3]) + x^4*(-1491983293 + 25482240*Zeta[3]) + 
            2410616376*x^35*(42309251 + 64874880*Zeta[3]) + 
            560*x^7*(1259382871 + 76075776*Zeta[3]) - 43046721*x^36*
             (1290256757 + 632540160*Zeta[3]) - 714256704*x^33*
             (-3224726411 + 1096426800*Zeta[3]) - 12*x^8*(183519803071 + 
              2530805760*Zeta[3]) - 224*x^9*(29778286669 + 9758397600*Zeta[
                3]) + 3024*x^11*(-31099807533 + 17547429760*Zeta[3]) - 
            21952*x^13*(-153941315393 + 31949492400*Zeta[3]) - 
            4782969*x^34*(123777695411 + 101402864640*Zeta[3]) - 
            8817984*x^29*(4057956533401 + 138242386800*Zeta[3]) - 
            16800*x^17*(-13031749598081 + 306566949024*Zeta[3]) - 
            19840464*x^31*(-132992571703 + 410923618560*Zeta[3]) + 
            4*x^10*(8082405613259 + 627699502080*Zeta[3]) + 
            708588*x^32*(-4927728442571 + 1135371202560*Zeta[3]) + 
            806400*x^21*(-4831768061915 + 1410975529362*Zeta[3]) + 
            3674160*x^27*(-16321135652069 + 3725091748224*Zeta[3]) + 
            84*x^14*(-20375681073689 + 13964722007040*Zeta[3]) - 
            4*x^12*(45791345372183 + 18313201105920*Zeta[3]) + 
            236196*x^30*(1559782205789 + 20974613345280*Zeta[3]) - 
            54432*x^25*(-41619346949303 + 37822995252000*Zeta[3]) + 
            112*x^15*(-360081673542473 + 42181076770560*Zeta[3]) - 
            61236*x^28*(-401119615257017 + 60366230830080*Zeta[3]) - 
            1120*x^19*(150074042867143 + 142235617305600*Zeta[3]) - 
            3024*x^23*(-4920433758782219 + 861956334731520*Zeta[3]) - 
            252*x^22*(-667783984459601 + 1698642268369920*Zeta[3]) - 
            972*x^26*(-13936225249809389 + 3987518166051840*Zeta[3]) + 
            10*x^18*(-31668363469127057 + 5942894664268800*Zeta[3]) + 
            324*x^24*(-31969440731221643 + 8716027214039040*Zeta[3]))/
           (228614400*x^2*(1 - 9*x^2)^8*(-1 + x^2)^13)) + 
        NH*((x*(273363897038400 + 3096790138985472*x + 497892426549723828*
              x^2 - 493679379477745683*x^3 + 3090963747260660166*x^4 - 
             1538222850526507083*x^5 + 2687190920301588876*x^6 + 
             164782578238013736*x^7 - 1816001129260774638*x^8 + 
             714638798131266882*x^9 - 287427446360683524*x^10 - 
             334811330265235131*x^11 + 391456009905294726*x^12 + 
             35055459958681269*x^13 - 102448350315122364*x^14 + 
             13987746026712216*x^15 + 8799623274439746*x^16 - 
             5679401029352694*x^17 + 1048887952381836*x^18 + 
             967708941379911*x^19 - 362594662089534*x^20 - 91572709501441*
              x^21 + 44544524257268*x^22 + 4382268447904*x^23 - 
             3075897519450*x^24 - 1287365506*x^25 + 122611730500*x^26 - 
             12090147385*x^27 - 2372842766*x^28 + 629893079*x^29 + 
             2401980*x^30 - 12087968*x^31 + 407750*x^32 + 37622*x^33)*
            HPL[{0}, x])/(4762800*(-9 + x^2)^8*(-1 + x^2)^13) + 
          lm^2*((1 + 7*x - 34*x^2 + 714*x^3 - 1133*x^4 + 3689*x^5 - 
              2708*x^6 + 3689*x^7 - 1133*x^8 + 714*x^9 - 34*x^10 + 7*x^11 + 
              x^12)/(315*(-1 + x^2)^10) - (4*x^3*(1 - 2*x + 10*x^2 - 10*x^3 + 
               20*x^4 - 10*x^5 + 10*x^6 - 2*x^7 + x^8)*HPL[{0}, x])/
             (3*(-1 + x^2)^11)) + (x*(-7593441584400 - 53153642554596*x - 
             10145557332302112*x^2 + 10169134736063859*x^3 - 
             62701729480143180*x^4 + 31302485837734851*x^5 - 
             50048344713985128*x^6 - 6309556920798543*x^7 + 47499012448150032*
              x^8 - 17694782976852459*x^9 + 7130287081484280*x^10 + 
             8042744566645371*x^11 - 11020610251054908*x^12 - 
             325170802612125*x^13 + 2572845942185568*x^14 - 
             522258891327417*x^15 - 45788784945792*x^16 + 149069650504463*
              x^17 - 73695179221552*x^18 - 17887710801927*x^19 + 
             13506354893948*x^20 + 756483949609*x^21 - 993078071720*x^22 + 
             55756884079*x^23 + 14705045488*x^24 - 9016523293*x^25 + 
             2453435096*x^26 + 485215721*x^27 - 152838644*x^28 - 
             11535263*x^29 + 2641968*x^30 + 70857*x^31 + 7056*x^32 + 
             813*x^33)*HPL[{0, 0}, x])/(132300*(-9 + x^2)^8*(-1 + x^2)^13) + 
          lm*((11719 + 52630*x - 237694*x^2 + 8008170*x^3 - 11034515*x^4 + 
              40877600*x^5 - 26622620*x^6 + 40877600*x^7 - 11034515*x^8 + 
              8008170*x^9 - 237694*x^10 + 52630*x^11 + 11719*x^12 + 
              240*Pi^2*(-1 - 7*x + 4*x^2 - 105*x^3 + 65*x^4 - 140*x^5 + 
                140*x^7 - 65*x^8 + 105*x^9 - 4*x^10 + 7*x^11 + x^12))/
             (1360800*(-1 + x^2)^10) - (x^2*(4 + 11128*x - 19860*x^2 + 123817*
                x^3 - 123218*x^4 + 301254*x^5 - 161018*x^6 + 195217*x^7 - 
               46236*x^8 + 28096*x^9 - 836*x^10 + 168*x^11 + 24*x^12)*
              HPL[{0}, x])/(1890*(-1 + x^2)^11) - 
            (2*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*
                x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{-1, 0}, x])/
             (945*(-1 + x^2)^9) + (4*x^3*(630 - 1260*x + 12285*x^2 - 16310*
                x^3 + 58975*x^4 - 47040*x^5 + 83860*x^6 - 36344*x^7 + 34902*
                x^8 - 6356*x^9 + 3241*x^10 - 6*x^11 + 7*x^12 + x^13)*
              HPL[{0, 0}, x])/(945*(-1 + x^2)^12) + 
            (2*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*
                x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{1, 0}, x])/
             (945*(-1 + x^2)^9)) - (2*(-1647 + 35970*x - 67341*x^2 + 
             320500*x^3 - 309892*x^4 + 722350*x^5 - 415880*x^6 + 530600*x^7 - 
             185525*x^8 + 125210*x^9 - 22223*x^10 + 7100*x^11 - 34*x^12 + 
             10*x^13 + 2*x^14)*HPL[{-1, 0, 0}, x])/(945*(-1 + x)^12*
            (1 + x)^10) + (2*x^3*(388846185770700 - 405456725626299*x + 
             2404720143094122*x^2 - 1233601721715861*x^3 + 1935216163947276*
              x^4 + 264284270238780*x^5 - 2093536381209966*x^6 + 
             875129973789528*x^7 - 542308267211508*x^8 - 318776621254461*
              x^9 + 569451872523366*x^10 - 37320500305467*x^11 - 
             94345398059220*x^12 + 38422872404982*x^13 - 12503885205546*
              x^14 - 8052161690074*x^15 + 6223173333188*x^16 + 
             647090382635*x^17 - 856190162618*x^18 + 16311998069*x^19 + 
             46966366916*x^20 - 7670475408*x^21 + 595929838*x^22 + 
             656912028*x^23 - 207862172*x^24 - 26647379*x^25 + 9781674*x^26 + 
             525307*x^27 - 159740*x^28 - 5250*x^29 + 490*x^30 + 70*x^31)*
            HPL[{0, 0, 0}, x])/(33075*(-9 + x^2)^8*(-1 + x^2)^13) + 
          (2*(-2277 + 29382*x - 49407*x^2 + 227852*x^3 - 175632*x^4 + 
             447070*x^5 - 144700*x^6 + 275520*x^7 - 19415*x^8 + 63790*x^9 - 
             453*x^10 + 5948*x^11 + 22*x^12 + 18*x^13 + 2*x^14)*
            HPL[{1, 0, 0}, x])/(945*(-1 + x)^10*(1 + x)^12) + 
          ((11173094768709 + 1520305081570548*x - 1485529557542451*x^2 + 
             9406313449840440*x^3 - 4695049139570325*x^4 + 8761962651394680*
              x^5 - 1808428348953*x^6 - 4084724477967336*x^7 + 
             1889872786814013*x^8 - 888939907969428*x^9 - 751112949749571*
              x^10 + 838845046722816*x^11 + 62658003684555*x^12 - 
             210047921649216*x^13 + 30958228564623*x^14 + 21650858922672*
              x^15 - 10985032750809*x^16 + 839416695180*x^17 + 
             1666331175119*x^18 - 543393368392*x^19 - 133403904647*x^20 + 
             72634099608*x^21 + 4458998141*x^22 - 4917818696*x^23 + 
             113351383*x^24 + 166625172*x^25 - 14716761*x^26 - 1820784*x^27 + 
             416721*x^28 - 16464*x^29 - 2547*x^30)*master3l8a[x])/
           (396900*(-9 + x^2)^8*(-1 + x^2)^13) - 
          ((1241454974301 + 82512523336572*x - 74819405701728*x^2 + 
             519931742998752*x^3 - 255851677982259*x^4 + 601273562944320*
              x^5 - 87358738534308*x^6 + 78180205266324*x^7 + 
             5806011188961*x^8 + 30428536857768*x^9 - 11972632894632*x^10 - 
             29958906829572*x^11 + 13925152377873*x^12 - 5701781373372*x^13 - 
             3551373763052*x^14 + 4550760884488*x^15 + 174212985143*x^16 - 
             784018787412*x^17 + 60707043888*x^18 + 42774241048*x^19 - 
             11702317433*x^20 + 2386178536*x^21 + 899736836*x^22 - 
             413722204*x^23 - 33415093*x^24 + 18736368*x^25 + 573656*x^26 - 
             294196*x^27 - 6693*x^28 + 980*x^29 + 140*x^30)*master3l9a[x])/
           (132300*(-9 + x^2)^7*(-1 + x^2)^13) + 
          (x^18*(173438783317044410 - 59428946642688000*Zeta[3]) + 
            x^32*(671916613 - 25482240*Zeta[3]) + 56*x^33*
             (-667409 + 40320*Zeta[3]) + 2688*x^31*(-946483 + 
              63000*Zeta[3]) + x^34*(-2764933 + 322560*Zeta[3]) - 
            560*x^29*(-515975939 + 76075776*Zeta[3]) + 
            4*x^30*(-6792743353 + 168698880*Zeta[3]) - 803538792*x*
             (13102384013 + 194624640*Zeta[3]) + 14348907*(-7061787209 + 
              1897620480*Zeta[3]) + 12*x^28*(20666601631 + 2530805760*Zeta[
                3]) + 119042784*x^3*(-669303309511 + 6578560800*Zeta[3]) + 
            224*x^27*(-43262869871 + 9758397600*Zeta[3]) - 
            3024*x^25*(-55701834683 + 17547429760*Zeta[3]) - 
            28*x^26*(-330601969003 + 89671357440*Zeta[3]) + 
            8817984*x^7*(-5127588698599 + 138242386800*Zeta[3]) + 
            896000*x^17*(-556118957203 + 177794521632*Zeta[3]) + 
            1594323*x^2*(6191069146433 + 304208593920*Zeta[3]) + 
            6613488*x^5*(-22673008042679 + 1232770855680*Zeta[3]) + 
            3360*x^19*(4646755791929 + 1532834745120*Zeta[3]) + 
            448*x^23*(-3712039192817 + 1565525127600*Zeta[3]) - 
            4490640*x^9*(-13524450485017 + 3047802339456*Zeta[3]) - 
            236196*x^4*(-196616860888793 + 3406113607680*Zeta[3]) - 
            161280*x^15*(-20375981797273 + 7054877646810*Zeta[3]) + 
            4*x^24*(-80358308251777 + 18313201105920*Zeta[3]) + 
            54432*x^11*(-24312098151563 + 37822995252000*Zeta[3]) - 
            112*x^21*(-70469654268803 + 42181076770560*Zeta[3]) - 
            12*x^22*(-392037541252943 + 97753054049280*Zeta[3]) - 
            15876*x^12*(-664116552286427 + 177878106408960*Zeta[3]) - 
            26244*x^6*(-1708835031204379 + 188771520107520*Zeta[3]) + 
            8748*x^8*(-2259291764202679 + 422563615810560*Zeta[3]) + 
            3024*x^13*(-3036770033233529 + 861956334731520*Zeta[3]) + 
            50*x^16*(-4001694600747757 + 2385543529829376*Zeta[3]) + 
            4*x^20*(-9693892808728313 + 2782369122140160*Zeta[3]) + 
            972*x^10*(-15367232141428709 + 3987518166051840*Zeta[3]) + 
            36*x^14*(-56088669834588407 + 11890495878589440*Zeta[3]))/
           (228614400*(-9 + x^2)^8*(-1 + x^2)^13))) + 
      CA*CF*((Pi^2*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 
           8564*x^6 + 8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + 
           x^12)*HPL[{-2}, x])/(945*(-1 + x^2)^10) + 
        lm^2*((-11*(1 + 7*x - 34*x^2 + 714*x^3 - 1133*x^4 + 3689*x^5 - 
             2708*x^6 + 3689*x^7 - 1133*x^8 + 714*x^9 - 34*x^10 + 7*x^11 + 
             x^12))/(630*(-1 + x^2)^10) + (22*x^3*(1 - 2*x + 10*x^2 - 
             10*x^3 + 20*x^4 - 10*x^5 + 10*x^6 - 2*x^7 + x^8)*HPL[{0}, x])/
           (3*(-1 + x^2)^11)) - (Pi^2*(1 + 7*x - 184*x^2 + 1596*x^3 - 
           3725*x^4 + 8687*x^5 - 8564*x^6 + 8687*x^7 - 3725*x^8 + 1596*x^9 - 
           184*x^10 + 7*x^11 + x^12)*HPL[{2}, x])/(945*(-1 + x^2)^10) + 
        (x*(-777 + 34314*x - 199773*x^2 + 685230*x^3 - 5015829*x^4 + 
           6063610*x^5 - 18221189*x^6 + 14049588*x^7 - 22526609*x^8 + 
           1299298*x^9 + 1068207*x^10 + 12732622*x^11 - 7692545*x^12 - 
           20124894*x^13 + 5942179*x^14 + 24183688*x^15 - 1871100*x^16 - 
           21150360*x^17 - 1630860*x^18 + 13420176*x^19 + 2585352*x^20 - 
           6034896*x^21 - 1704024*x^22 + 1827504*x^23 + 647052*x^24 - 
           334824*x^25 - 138180*x^26 + 28080*x^27 + 12960*x^28)*
          HPL[{-2, 0}, x])/(26460*(-1 + x^2)^12) + 
        ((-2721600 - 5896800*x + 24935400*x^2 + 61467840*x^3 - 97343820*x^4 - 
           289117080*x^5 + 201552960*x^6 + 808286640*x^7 - 201031950*x^8 - 
           1487812620*x^9 - 39351900*x^10 + (1884950269 + 11760*Pi^2)*x^11 + 
           (421184293 + 82320*Pi^2)*x^12 - (1684616201 + 2175600*Pi^2)*x^13 + 
           4*(-69082619 + 4671660*Pi^2)*x^14 + (456972129 - 41642160*Pi^2)*
            x^15 + (3031755557 + 83390160*Pi^2)*x^16 - 
           (2545543457 + 56906640*Pi^2)*x^17 + 4111181632*x^18 + 
           (-2545543457 + 56906640*Pi^2)*x^19 + (3031755557 - 83390160*Pi^2)*
            x^20 + (456972129 + 41642160*Pi^2)*x^21 - 
           4*(69082619 + 4671660*Pi^2)*x^22 + (-1684616201 + 2175600*Pi^2)*
            x^23 + (421184293 - 82320*Pi^2)*x^24 + (1884950269 - 11760*Pi^2)*
            x^25 - 39351900*x^26 - 1487812620*x^27 - 201031950*x^28 + 
           808286640*x^29 + 201552960*x^30 - 289117080*x^31 - 97343820*x^32 + 
           61467840*x^33 + 24935400*x^34 - 5896800*x^35 - 2721600*x^36)*
          HPL[{-1, 0}, x])/(11113200*x^11*(-1 + x^2)^11) + 
        (x*(-42143600793420 + 1852499758777920*x - 17134178891328450*x^2 - 
           49873137992266869*x^3 + 861530744204155557*x^4 - 
           702707753001668652*x^5 - 10303492716646609977*x^6 + 
           44204753995645430061*x^7 - 169381767709704593106*x^8 - 
           638739729846490893768*x^9 + 6260316272381890116972*x^10 + 
           2303993296585756701009*x^11 - 74769871845472342741503*x^12 + 
           34455839031011001383676*x^13 + 393899549375293095757527*x^14 - 
           434805198118323399059733*x^15 - 223370076322430654774148*x^16 + 
           1707476432439966412794264*x^17 - 7019264891497444776073728*x^18 + 
           175215624603396347355246*x^19 + 24112531864302795746169666*x^20 - 
           15787084857685966531565768*x^21 + 13262599305919561615090486*
            x^22 + 8913790837527002141953602*x^23 - 
           123061840027138501115274396*x^24 + 88291690744989032516695088*
            x^25 - 31425650124613618065445232*x^26 - 
           77727621660894856495838734*x^27 + 63330586805105843788686522*
            x^28 + 55663104881390659616691576*x^29 - 
           23663203836904263820822394*x^30 - 51267201301619195962966538*
            x^31 + 1654900577795034742782276*x^32 + 
           41709444198112970791222320*x^33 + 4434589301375998499599830*x^34 - 
           26054502374577942942362553*x^35 - 4708341889748176265451663*x^36 + 
           12543511605600042298860804*x^37 + 3017505769629802000732539*x^38 - 
           4686075707760358128947583*x^39 - 1360985119194985923767058*x^40 + 
           1353589664044882796425944*x^41 + 447728280314196543148692*x^42 - 
           299651710193414325783027*x^43 - 108704610789430322418939*x^44 + 
           50270924360402230278348*x^45 + 19503145689807581718723*x^46 - 
           6300757485565728741009*x^47 - 2569475884830062799780*x^48 + 
           578067100665379993080*x^49 + 244829265272433904860*x^50 - 
           37582792593467763600*x^51 - 16390354843445488920*x^52 + 
           1636988857515088560*x^53 + 730578550446075240*x^54 - 
           42803579344841280*x^55 - 19459821226078800*x^56 + 
           507675808785600*x^57 + 234311911747200*x^58)*HPL[{0, 0}, x])/
         (11113200*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        ((2721600 + 5896800*x - 24935400*x^2 - 61467840*x^3 + 97343820*x^4 + 
           289117080*x^5 - 201552960*x^6 - 808286640*x^7 + 201031950*x^8 + 
           1487812620*x^9 + 39351900*x^10 - (1884950269 + 11760*Pi^2)*x^11 - 
           (421184293 + 82320*Pi^2)*x^12 + (1684616201 + 2175600*Pi^2)*x^13 - 
           4*(-69082619 + 4671660*Pi^2)*x^14 + (-456972129 + 41642160*Pi^2)*
            x^15 - (3031755557 + 83390160*Pi^2)*x^16 + 
           (2545543457 + 56906640*Pi^2)*x^17 - 4111181632*x^18 + 
           (2545543457 - 56906640*Pi^2)*x^19 + (-3031755557 + 83390160*Pi^2)*
            x^20 - 3*(152324043 + 13880720*Pi^2)*x^21 + 
           4*(69082619 + 4671660*Pi^2)*x^22 + (1684616201 - 2175600*Pi^2)*
            x^23 + (-421184293 + 82320*Pi^2)*x^24 + 
           (-1884950269 + 11760*Pi^2)*x^25 + 39351900*x^26 + 
           1487812620*x^27 + 201031950*x^28 - 808286640*x^29 - 
           201552960*x^30 + 289117080*x^31 + 97343820*x^32 - 61467840*x^33 - 
           24935400*x^34 + 5896800*x^35 + 2721600*x^36)*HPL[{1, 0}, x])/
         (11113200*x^11*(-1 + x^2)^11) + 
        lm*(-(189389 + 1002290*x - 4670954*x^2 + 131272590*x^3 - 
             189903505*x^4 + 672764320*x^5 - 456628660*x^6 + 672764320*x^7 - 
             189903505*x^8 + 131272590*x^9 - 4670954*x^10 + 1002290*x^11 + 
             189389*x^12 + 2640*Pi^2*(-1 - 7*x + 4*x^2 - 105*x^3 + 65*x^4 - 
               140*x^5 + 140*x^7 - 65*x^8 + 105*x^9 - 4*x^10 + 7*x^11 + x^
                12))/(2721600*(-1 + x^2)^10) + 
          (x^2*(44 + 157688*x - 289020*x^2 + 1714787*x^3 - 1708198*x^4 + 
             4019394*x^5 - 2123998*x^6 + 2500187*x^7 - 579156*x^8 + 
             344336*x^9 - 9196*x^10 + 1848*x^11 + 264*x^12)*HPL[{0}, x])/
           (3780*(-1 + x^2)^11) + (11*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 
             252*x^5 - 68*x^6 + 112*x^7 - 3*x^8 + 7*x^9 + x^10)*
            HPL[{-1, 0}, x])/(945*(-1 + x^2)^9) - 
          (22*x^3*(630 - 1260*x + 12285*x^2 - 16310*x^3 + 58975*x^4 - 
             47040*x^5 + 83860*x^6 - 36344*x^7 + 34902*x^8 - 6356*x^9 + 
             3241*x^10 - 6*x^11 + 7*x^12 + x^13)*HPL[{0, 0}, x])/
           (945*(-1 + x^2)^12) - (11*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 
             252*x^5 - 68*x^6 + 112*x^7 - 3*x^8 + 7*x^9 + x^10)*
            HPL[{1, 0}, x])/(945*(-1 + x^2)^9)) - 
        (x*(-777 + 34314*x - 199773*x^2 + 685230*x^3 - 5015829*x^4 + 
           6063610*x^5 - 18221189*x^6 + 14049588*x^7 - 22526609*x^8 + 
           1299298*x^9 + 1068207*x^10 + 12732622*x^11 - 7692545*x^12 - 
           20124894*x^13 + 5942179*x^14 + 24183688*x^15 - 1871100*x^16 - 
           21150360*x^17 - 1630860*x^18 + 13420176*x^19 + 2585352*x^20 - 
           6034896*x^21 - 1704024*x^22 + 1827504*x^23 + 647052*x^24 - 
           334824*x^25 - 138180*x^26 + 28080*x^27 + 12960*x^28)*
          HPL[{2, 0}, x])/(26460*(-1 + x^2)^12) - 
        (4*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-2, -1, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*x^2*(-180 + 1491*x - 3660*x^2 + 8547*x^3 - 8564*x^4 + 8827*x^5 - 
           3790*x^6 + 1701*x^7 - 188*x^8 + 14*x^9 + 2*x^10)*
          HPL[{-2, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        (4*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-2, 1, 0}, x])/(315*(-1 + x^2)^10) + 
        (4*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-1, -2, 0}, x])/(315*(-1 + x^2)^10) - 
        ((3240 + 7020*x - 24825*x^2 - 62646*x^3 + 77568*x^4 + 247878*x^5 - 
           115587*x^6 - 570132*x^7 + 42048*x^8 + 838368*x^9 + 142758*x^10 - 
           814212*x^11 - 281232*x^12 + 518204*x^13 + 256895*x^14 - 
           205110*x^15 - 102040*x^16 + 19070*x^17 + 153270*x^18 + 
           19070*x^19 - 102040*x^20 - 205110*x^21 + 256895*x^22 + 
           518204*x^23 - 281232*x^24 - 814212*x^25 + 142758*x^26 + 
           838368*x^27 + 42048*x^28 - 570132*x^29 - 115587*x^30 + 
           247878*x^31 + 77568*x^32 - 62646*x^33 - 24825*x^34 + 7020*x^35 + 
           3240*x^36)*HPL[{-1, -1, 0}, x])/(13230*x^13*(-1 + x^2)^9) + 
        ((-3393 + 21210*x - 200559*x^2 + 4132160*x^3 - 10991413*x^4 + 
           33264764*x^5 - 43441835*x^6 + 64078752*x^7 - 45243635*x^8 + 
           26589914*x^9 - 7944733*x^10 + 20020760*x^11 - 4819719*x^12 - 
           25501140*x^13 + 5271687*x^14 + 29818800*x^15 - 4455000*x^16 - 
           25586550*x^17 + 2752200*x^18 + 16005000*x^19 - 1211760*x^20 - 
           7118100*x^21 + 360720*x^22 + 2136600*x^23 - 65160*x^24 - 
           388650*x^25 + 5400*x^26 + 32400*x^27)*HPL[{-1, 0, 0}, x])/
         (66150*(-1 + x)^12*(1 + x)^10) + 
        ((3240 + 7020*x - 24825*x^2 - 62646*x^3 + 77568*x^4 + 247878*x^5 - 
           115587*x^6 - 570132*x^7 + 42048*x^8 + 838368*x^9 + 142758*x^10 - 
           814212*x^11 - 281232*x^12 + 518204*x^13 + 256895*x^14 - 
           205110*x^15 - 102040*x^16 + 19070*x^17 + 153270*x^18 + 
           19070*x^19 - 102040*x^20 - 205110*x^21 + 256895*x^22 + 
           518204*x^23 - 281232*x^24 - 814212*x^25 + 142758*x^26 + 
           838368*x^27 + 42048*x^28 - 570132*x^29 - 115587*x^30 + 
           247878*x^31 + 77568*x^32 - 62646*x^33 - 24825*x^34 + 7020*x^35 + 
           3240*x^36)*HPL[{-1, 1, 0}, x])/(13230*x^13*(-1 + x^2)^9) - 
        (4*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-1, 2, 0}, x])/(315*(-1 + x^2)^10) - 
        (x*(-167236511085 + 7313207430690*x - 185326729952805*x^2 + 
           174111509096055*x^3 + 8082249315561918*x^4 - 28037957320006650*
            x^5 - 54547178362251606*x^6 + 913287111021017757*x^7 - 
           3125760228437912451*x^8 - 14798537541490171554*x^9 + 
           86145699913876336617*x^10 + 139210576423012885941*x^11 - 
           993116993622074602434*x^12 - 827285409688895053038*x^13 + 
           5691323975467949401518*x^14 + 3919895403647747045127*x^15 - 
           11799139255618616434986*x^16 - 22279675665745444953692*x^17 - 
           23768977077869560147178*x^18 + 122866956393546767772278*x^19 + 
           39519891010235612242396*x^20 - 390782818006332660187332*x^21 + 
           756225499808710986305348*x^22 + 421400712669008085818706*x^23 - 
           2232883068049867055697054*x^24 + 195107678956567009250796*x^25 + 
           200924107582929427052938*x^26 + 831773628501059222485562*x^27 + 
           142489788625858715752892*x^28 - 1826650865315183510480572*x^29 + 
           238447921906195634221676*x^30 + 2097173707073095307721758*x^31 - 
           194990885824346765264097*x^32 - 1857812032944017847469494*x^33 - 
           23397879183406243632105*x^34 + 1334712659652609317457891*x^35 + 
           145328952227286357643350*x^36 - 770202969808350131252802*x^37 - 
           142887287045011887888606*x^38 + 352931030663207384919681*x^39 + 
           86937096084837641519577*x^40 - 127200675724538763073434*x^41 - 
           37516745844002854433019*x^42 + 35704432894065443395137*x^43 + 
           11917354053470689702854*x^44 - 7721145593049489277878*x^45 - 
           2815512451653395935098*x^46 + 1270826026047196107147*x^47 + 
           494479702155672160200*x^48 - 156826819851176971440*x^49 - 
           64060823481092446680*x^50 + 14207710745463328800*x^51 + 
           6022961090260465680*x^52 - 914231933581871520*x^53 - 
           398905529283238320*x^54 + 39484484306431200*x^55 + 
           17625927025392120*x^56 - 1025176601172240*x^57 - 
           466118504332200*x^58 + 12087519256800*x^59 + 5578855041600*x^60)*
          HPL[{0, 0, 0}, x])/(132300*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) - 
        (4*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{1, -2, 0}, x])/(315*(-1 + x^2)^10) + 
        ((3240 + 7020*x - 24825*x^2 - 62646*x^3 + 77568*x^4 + 247878*x^5 - 
           115587*x^6 - 570132*x^7 + 42048*x^8 + 838368*x^9 + 142758*x^10 - 
           814212*x^11 - 281232*x^12 + 518204*x^13 + 256895*x^14 - 
           205110*x^15 - 102040*x^16 + 19070*x^17 + 153270*x^18 + 
           19070*x^19 - 102040*x^20 - 205110*x^21 + 256895*x^22 + 
           518204*x^23 - 281232*x^24 - 814212*x^25 + 142758*x^26 + 
           838368*x^27 + 42048*x^28 - 570132*x^29 - 115587*x^30 + 
           247878*x^31 + 77568*x^32 - 62646*x^33 - 24825*x^34 + 7020*x^35 + 
           3240*x^36)*HPL[{1, -1, 0}, x])/(13230*x^13*(-1 + x^2)^9) - 
        ((-3393 + 10998*x - 112623*x^2 + 4068168*x^3 - 1115333*x^4 + 
           13954336*x^5 + 9012349*x^6 + 16441856*x^7 + 15698149*x^8 + 
           17047486*x^9 - 13719653*x^10 - 8926512*x^11 + 16707057*x^12 + 
           27772968*x^13 - 11687913*x^14 - 36284400*x^15 - 426600*x^16 + 
           30753450*x^17 + 9057600*x^18 - 16715400*x^19 - 8937960*x^20 + 
           5302860*x^21 + 4456440*x^22 - 650040*x^23 - 1187760*x^24 - 
           107850*x^25 + 135000*x^26 + 32400*x^27)*HPL[{1, 0, 0}, x])/
         (66150*(-1 + x)^10*(1 + x)^12) - 
        ((3240 + 7020*x - 24825*x^2 - 62646*x^3 + 77568*x^4 + 247878*x^5 - 
           115587*x^6 - 570132*x^7 + 42048*x^8 + 838368*x^9 + 142758*x^10 - 
           814212*x^11 - 281232*x^12 + 518204*x^13 + 256895*x^14 - 
           205110*x^15 - 102040*x^16 + 19070*x^17 + 153270*x^18 + 
           19070*x^19 - 102040*x^20 - 205110*x^21 + 256895*x^22 + 
           518204*x^23 - 281232*x^24 - 814212*x^25 + 142758*x^26 + 
           838368*x^27 + 42048*x^28 - 570132*x^29 - 115587*x^30 + 
           247878*x^31 + 77568*x^32 - 62646*x^33 - 24825*x^34 + 7020*x^35 + 
           3240*x^36)*HPL[{1, 1, 0}, x])/(13230*x^13*(-1 + x^2)^9) + 
        (4*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{1, 2, 0}, x])/(315*(-1 + x^2)^10) + 
        (4*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{2, -1, 0}, x])/(315*(-1 + x^2)^10) - 
        (8*x^2*(-180 + 1491*x - 3660*x^2 + 8547*x^3 - 8564*x^4 + 8827*x^5 - 
           3790*x^6 + 1701*x^7 - 188*x^8 + 14*x^9 + 2*x^10)*
          HPL[{2, 0, 0}, x])/(315*(-1 + x^2)^10) - 
        (4*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{2, 1, 0}, x])/(315*(-1 + x^2)^10) - 
        (8*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*x^7 - 
           3*x^8 + 7*x^9 + x^10)*HPL[{-1, 0, 0, 0}, x])/(315*(-1 + x^2)^9) + 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-1, 1, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{1, -1, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 112*x^7 - 
           3*x^8 + 7*x^9 + x^10)*HPL[{1, 0, 0, 0}, x])/(315*(-1 + x^2)^9) - 
        ((2 + 29*x - 280*x^2 + 4357*x^3 - 9212*x^4 + 31801*x^5 - 30574*x^6 + 
           48320*x^7 - 20896*x^8 + 17619*x^9 - 2130*x^10 + 1179*x^11 + 
           90*x^12 + 15*x^13)*master3l10a[x])/(1260*(-1 + x^2)^11) + 
        (x*(15 + 90*x + 1179*x^2 - 2130*x^3 + 17619*x^4 - 20896*x^5 + 
           48320*x^6 - 30574*x^7 + 31801*x^8 - 9212*x^9 + 4357*x^10 - 
           280*x^11 + 29*x^12 + 2*x^13)*master3l10b[x])/
         (1260*(-1 + x^2)^11) + ((271922947911 - 12660402557421*x - 
           550340744696964*x^2 + 2056218772475907*x^3 - 4037520648360375*
            x^4 + 6128431669779390*x^5 - 3181823259032268*x^6 - 
           78116095252890*x^7 + 2113097863917195*x^8 - 1630528976949507*x^9 - 
           97406439629832*x^10 + 425633075726085*x^11 - 128086061710707*
            x^12 + 24477886201572*x^13 + 24047738874792*x^14 - 
           27312089410188*x^15 + 1268148303669*x^16 + 5145029604573*x^17 - 
           936786669332*x^18 - 453236790947*x^19 + 137417758347*x^20 + 
           16345592446*x^21 - 10109872028*x^22 + 304592070*x^23 + 
           391761337*x^24 - 43421453*x^25 - 6664608*x^26 + 999163*x^27 + 
           11743*x^28)*master3l8a[x])/(3175200*(-9 + x^2)^8*(-1 + x^2)^12) + 
        ((15540 - 694663*x + 209177*x^2 + 51041036*x^3 - 47887739*x^4 - 
           1757842377*x^5 + 1526603010*x^6 + 36973994084*x^7 - 
           23882889202*x^8 - 519435521763*x^9 + 234823270383*x^10 + 
           4981361236664*x^11 - 1943862879709*x^12 - 31822920577141*x^13 + 
           17318502436860*x^14 + 124014432106632*x^15 - 134953043202648*
            x^16 - 216418074905061*x^17 + 672538348847079*x^18 - 
           217489761737604*x^19 - 1654483180080357*x^20 + 1332370740861477*
            x^21 + 625977282434274*x^22 - 769587939964332*x^23 + 
           3129046939177974*x^24 - 813403672786161*x^25 + 
           689524119166257*x^26 + 53273459825280*x^27 + 2865463087581*x^28 - 
           705833895591*x^29)*master3l8b[x])/(3175200*x*(1 - 9*x^2)^8*
          (-1 + x^2)^12) + ((-54319824639 + 862548091389*x + 
           33528086937387*x^2 - 75831642062604*x^3 + 182842952747166*x^4 - 
           175058223040368*x^5 + 154328956920126*x^6 + 19665385089246*x^7 - 
           26226067178637*x^8 + 854253724869*x^9 - 9585303136947*x^10 + 
           13811876698374*x^11 - 5972367748236*x^12 - 7322620889304*x^13 + 
           4890108763076*x^14 + 1665852781580*x^15 - 1295047297481*x^16 - 
           208732606729*x^17 + 184891850613*x^18 + 15033047104*x^19 - 
           15948309938*x^20 - 564577080*x^21 + 843735902*x^22 + 
           5158710*x^23 - 25673995*x^24 + 325063*x^25 + 353203*x^26 - 
           7770*x^27)*master3l9a[x])/(1058400*(-9 + x^2)^7*(-1 + x^2)^12) + 
        ((-7770 + 353203*x + 325063*x^2 - 25673995*x^3 + 5158710*x^4 + 
           843735902*x^5 - 564577080*x^6 - 15948309938*x^7 + 
           15033047104*x^8 + 184891850613*x^9 - 208732606729*x^10 - 
           1295047297481*x^11 + 1665852781580*x^12 + 4890108763076*x^13 - 
           7322620889304*x^14 - 5972367748236*x^15 + 13811876698374*x^16 - 
           9585303136947*x^17 + 854253724869*x^18 - 26226067178637*x^19 + 
           19665385089246*x^20 + 154328956920126*x^21 - 175058223040368*
            x^22 + 182842952747166*x^23 - 75831642062604*x^24 + 
           33528086937387*x^25 + 862548091389*x^26 - 54319824639*x^27)*
          master3l9b[x])/(3175200*x*(-1 + x^2)^12*(-1 + 9*x^2)^7) + 
        (HPL[{1}, x]*(Pi^2*(3240 + 7020*x - 28065*x^2 - 69666*x^3 + 
             102393*x^4 + 310524*x^5 - 193155*x^6 - 818010*x^7 + 157635*x^8 + 
             1408500*x^9 + 100710*x^10 - 1652580*x^11 - 423990*x^12 + 
             1332416*x^13 + 538127*x^14 - 723314*x^15 - 358935*x^16 + 
             224180*x^17 + 255310*x^18 - 255310*x^20 - 224180*x^21 + 
             358935*x^22 + 723314*x^23 - 538127*x^24 - 1332416*x^25 + 
             423990*x^26 + 1652580*x^27 - 100710*x^28 - 1408500*x^29 - 
             157635*x^30 + 818010*x^31 + 193155*x^32 - 310524*x^33 - 
             102393*x^34 + 69666*x^35 + 28065*x^36 - 7020*x^37 - 3240*x^38) - 
           2016*x^13*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 
             8564*x^6 + 8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + 
             x^12)*Zeta[3]))/(158760*x^13*(-1 + x^2)^10) + 
        (HPL[{-1}, x]*(Pi^2*(-3240 - 7020*x + 28065*x^2 + 69666*x^3 - 
             102393*x^4 - 310524*x^5 + 193155*x^6 + 818010*x^7 - 157635*x^8 - 
             1408500*x^9 - 100710*x^10 + 1652580*x^11 + 423990*x^12 - 
             1332416*x^13 - 538127*x^14 + 723314*x^15 + 358935*x^16 - 
             224180*x^17 - 255310*x^18 + 255310*x^20 + 224180*x^21 - 
             358935*x^22 - 723314*x^23 + 538127*x^24 + 1332416*x^25 - 
             423990*x^26 - 1652580*x^27 + 100710*x^28 + 1408500*x^29 + 
             157635*x^30 - 818010*x^31 - 193155*x^32 + 310524*x^33 + 
             102393*x^34 - 69666*x^35 - 28065*x^36 + 7020*x^37 + 3240*x^38) + 
           2016*x^13*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 
             8564*x^6 + 8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + 
             x^12)*Zeta[3]))/(158760*x^13*(-1 + x^2)^10) + 
        (HPL[{0}, x]*(702935735241600 + 1523027426356800*x - 
           58027995810615600*x^2 - 127649224321345440*x^3 + 
           2162780231410854720*x^4 + 4847268879336789360*x^5 - 
           48094480791959622300*x^6 - 110335317316618910040*x^7 + 
           710618387823807045660*x^8 + 1679432303884430062800*x^9 + 
           173604060*(-42378253915954 + 80919*Pi^2)*x^10 - 
           10628820*(1700244117804175 + 58368114*Pi^2)*x^11 - 
           1470*(107015159997613586558329 + 13527640084644634123824*Pi^2)*
            x^33 + 8748*(2065812751089481257 + 37069967731613387690*Pi^2)*
            x^55 + 25515*(288341802840822579 + 4634588354060926780*Pi^2)*
            x^56 - 137781*(12189148211602593 + 387387904529570720*Pi^2)*
            x^57 - 918540*(773639022605229 + 22609954373830460*Pi^2)*x^58 + 
           49601160*(2224450341819 + 132793798244828*Pi^2)*x^59 + 
           8266860*(5817744680805 + 325462701219796*Pi^2)*x^60 - 
           6249746160*(775594521 + 95479694060*Pi^2)*x^61 - 
           4166497440*(519088338 + 60713913649*Pi^2)*x^62 + 
           48212327520*(2647647 + 796429942*Pi^2)*x^63 + 
           2678462640*(21664665 + 6255092746*Pi^2)*x^64 - 
           1446369825600*(1053 + 1146559*Pi^2)*x^65 - 24106163760*
            (29160 + 30709529*Pi^2)*x^66 + 43057417249234080*Pi^2*x^67 + 
           19576977181952400*Pi^2*x^68 - 507675808785600*Pi^2*x^69 - 
           234311911747200*Pi^2*x^70 + 2*x^32*(-120015669397011264149284211 + 
             41328394391280106384260*Pi^2 - 8463580468066899125798400*
              Zeta[3]) + x^38*(-205591290366292252388676014 + 
             24757756221159178027555080*Pi^2 - 4107533161061614286016000*
              Zeta[3]) + 6*x^29*(13743700333028991845691851 + 
             29049331598627379768120*Pi^2 - 871013124083493370022400*
              Zeta[3]) + 56*x^35*(-3410193436218278053584581 + 
             535970857354505598074910*Pi^2 - 171382977752863189824000*
              Zeta[3]) + 84*x^26*(-160038323959742740714577 + 
             4956437760128042230950*Pi^2 - 18395234987556282508800*Zeta[3]) - 
           48*x^27*(2897128722712639968929084 + 8824333122919647948405*Pi^2 - 
             16565906159404235020800*Zeta[3]) - 27*x^24*
            (-273701656804277890089871 + 4740001944944789035380*Pi^2 - 
             8683793051697027532800*Zeta[3]) + 36*x^42*
            (-350939868833646510726962 + 241522726761534327102525*Pi^2 - 
             6512844788772770649600*Zeta[3]) + 144*x^39*
            (946448549929494166099772 + 510170273181797019831095*Pi^2 - 
             5521968719801411673600*Zeta[3]) - 120*x^36*
            (-256941164611754166791393 + 223521095197611615293715*Pi^2 - 
             3069702677284231343040*Zeta[3]) + 
           9*x^22*(-1080017334151937841164509 + 2069379947649746842740*Pi^2 - 
             731073974743430035200*Zeta[3]) - 9*x^46*
            (760455545625939604135461 + 685570345846168515796700*Pi^2 - 
             343433759799601094400*Zeta[3]) + 27*x^48*
            (127534013969645880676043 + 222555690523104021375180*Pi^2 - 
             19231357231574208000*Zeta[3]) - 18*x^50*
            (66318949344466106400051 + 202880755189401377310110*Pi^2 - 
             2151268123987180800*Zeta[3]) + 243*x^16*
            (4925638650156014451391 + 6343239484155420*Pi^2 - 
             159353194369420800*Zeta[3]) - 2187*x^14*(136820067339792292499 + 
             63929037114180*Pi^2 - 670806087840000*Zeta[3]) - 
           81*x^54*(677607260966371623681 + 6179371339929883674460*Pi^2 - 
             283488485817600*Zeta[3]) + 39366*x^12*(1394293778351289551 + 
             65739142350*Pi^2 - 583309641600*Zeta[3]) + 
           59049*x^13*(2403347231669384933 + 555985934280*Pi^2 + 
             777746188800*Zeta[3]) - 26244*x^15*(31608746451130360961 + 
             24903961421850*Pi^2 + 120550659264000*Zeta[3]) - 
           6615*x^49*(554702354398855710153 + 2240565504675073818352*Pi^2 + 
             14168338823761920*Zeta[3]) + 5103*x^17*(717135638664583989091 + 
             1064991506075280*Pi^2 + 18366365141913600*Zeta[3]) - 
           756*x^19*(16310966700565285220587 + 18629284276675170*Pi^2 + 
             2037446913621772800*Zeta[3]) + 756*x^47*
            (16493139381265726296631 + 42757321247950804027750*Pi^2 + 
             2037446913621772800*Zeta[3]) + 54*x^18*
            (-64641531302933407255849 + 741750251071065390*Pi^2 + 
             9615678615787104000*Zeta[3]) - 108*x^20*
            (-66828775416064944305588 + 13038930314753498505*Pi^2 + 
             28619479983300091200*Zeta[3]) + 189*x^21*
            (170226638286832484192291 + 1442915519596959240*Pi^2 + 
             79015101644638656000*Zeta[3]) - 63*x^45*
            (529973077111222707221649 + 886423282080564941672680*Pi^2 + 
             237045304933915968000*Zeta[3]) + 18*x^44*
            (478243925888430685021817 + 68536796479494286044290*Pi^2 + 
             365536987371715017600*Zeta[3]) + 108*x^43*
            (673023205712075530589727 + 711379018854938731059770*Pi^2 + 
             745491366007515187200*Zeta[3]) - 36*x^23*
            (1839999995349849602572421 + 236600571970039520250*Pi^2 + 
             2236474098022545561600*Zeta[3]) - 30*x^30*
            (3979085800518144540544463 + 86462876546107523387940*Pi^2 + 
             12278810709136925372160*Zeta[3]) - 10*x^41*
            (12648986127029743078795589 + 8431870276931741450438208*Pi^2 + 
             14850534420377200742400*Zeta[3]) + 
           9*x^25*(12186788806617633585279727 + 10344849725145333998880*
              Pi^2 + 16500593800419111936000*Zeta[3]) + 
           56*x^31*(2061742124336580935882641 + 100289875573986570444210*
              Pi^2 + 171382977752863189824000*Zeta[3]) + 
           x^40*(67384151250300356006164798 - 18952154338454084768780760*
              Pi^2 + 1545199738954727730739200*Zeta[3]) + 
           x^28*(73430537138046424178993784 - 90114165750324177884520*Pi^2 + 
             4107533161061614286016000*Zeta[3]) + 
           4*x^34*(181488465784182737189461223 + 5446163651732043680269830*
              Pi^2 + 4231790234033449562899200*Zeta[3]) + 
           x^37*(26541939837698641151432974 - 50487520618532021177816880*
              Pi^2 + 5226078744500960220134400*Zeta[3]) - 
           243*x^53*(6171126633615089303080*Pi^2 + 243*(2403534298457862173 + 
               777746188800*Zeta[3])) + 36*x^52*(43769999599966937708705*
              Pi^2 - 11178*(-743306362778306681 + 3645685260000*Zeta[3])) + 
           36*x^51*(148398469245227284429150*Pi^2 + 
             729*(31625244176604051037 + 120550659264000*Zeta[3]))))/
         (133358400*x^9*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        (56448*Pi^4*x^11*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^8*
           (-3 - 21*x - 888*x^2 + 7140*x^3 - 18105*x^4 + 42315*x^5 - 
            42820*x^6 + 44555*x^7 - 19145*x^8 + 8820*x^9 - 952*x^10 + 
            91*x^11 + 13*x^12) + 24*Pi^2*(9 - 82*x^2 + 9*x^4)^8*
           (-2721600 - 5896800*x + 27657000*x^2 + 67364640*x^3 - 
            122279220*x^4 - 350584920*x^5 + 298896780*x^6 + 1097403720*x^7 - 
            402584910*x^8 - 2296099260*x^9 + 161680050*x^10 + 
            3372762889*x^11 + 460536193*x^12 - 3569566470*x^13 - 
            697514769*x^14 + 2141588330*x^15 + 3308086033*x^16 - 
            3002515586*x^17 + 1079426075*x^18 - 1079426075*x^20 + 
            3002515586*x^21 - 3308086033*x^22 - 2141588330*x^23 + 
            697514769*x^24 + 3569566470*x^25 - 460536193*x^26 - 
            3372762889*x^27 - 161680050*x^28 + 2296099260*x^29 + 
            402584910*x^30 - 1097403720*x^31 - 298896780*x^32 + 
            350584920*x^33 + 122279220*x^34 - 67364640*x^35 - 27657000*x^36 + 
            5896800*x^37 + 2721600*x^38) + x^2*(-4217614411449600 - 
            9138164558140800*x + 349573846334176800*x^2 + 768941400780786240*
             x^3 - 13092210178284928320*x^4 - 29337769454093659440*x^5 + 
            292849217107611165540*x^6 + 671611339334907011880*x^7 - 
            4358300557199751673560*x^8 + x^39*(956723958920709189770317608 - 
              5659531521320850078243195648*Zeta[3]) + 
            x^38*(653318949495411924327762224 - 957484930552885682674392960*
               Zeta[3]) + x^27*(535848870932137538045065128 - 
              343280075606497705447231488*Zeta[3]) - 3100134041944853760*x^67*
             Zeta[3] - 1409542357100572800*x^68*Zeta[3] + 36552658232563200*
             x^69*Zeta[3] + 16870457645798400*x^70*Zeta[3] + 
            26034656860800*x^65*(-351 + 4586236*Zeta[3]) + 1735643790720*x^66*
             (-2430 + 30709529*Zeta[3]) + 100442349*x^9*(-102483921209507 + 
              35396352*Zeta[3]) - 280600848*x^11*(-398136804500999 + 
              1259352360*Zeta[3]) - 7440174*x^10*(-6119286177152903 + 
              2792991456*Zeta[3]) - 867821895360*x^63*(-886059 + 
              3185719768*Zeta[3]) - 48212327520*x^64*(-7250715 + 
              25020370984*Zeta[3]) + 10713850560*x^62*(-1221989247 + 
              1699989582172*Zeta[3]) + 8035387920*x^61*(-3651070707 + 
              5346862867360*Zeta[3]) + 708588*x^13*(-1251715995033242563 + 
              29878237495008*Zeta[3]) - 118098*x^12*(2909258552906078251 + 
              32873478154272*Zeta[3]) - 3124873080*x^59*(-214924357611 + 
              151764340851232*Zeta[3]) - 520812180*x^60*(-562293334053 + 
              371957372822624*Zeta[3]) - 1417176*x^15*(-3712656036285162347 + 
              577977243212880*Zeta[3]) + 13122*x^14*(144988292748690795695 + 
              24410703217676832*Zeta[3]) - 71442*x^16*
             (109334303059685728849 + 138669261077588832*Zeta[3]) + 
            8266860*x^58*(-527201523837801 + 180879634990643680*Zeta[3]) + 
            1240029*x^57*(-8301164757658407 + 3099103239750322432*Zeta[3]) + 
            4374*x^17*(-5417634169326968644931 + 4669642112415944832*Zeta[
                3]) - 314928*x^55*(-354704652380890449 + 74139936928010572360*
               Zeta[3]) - 91854*x^56*(-495660569935897143 + 
              92691767235330756896*Zeta[3]) - 648*x^19*
             (-126515171507554317002365 + 517497743222952777936*Zeta[3]) + 
            162*x^18*(149330012401630803871109 + 1011395036481454326240*Zeta[
                3]) + 1134*x^22*(106858067030757047003669 + 
              6736132826434690537824*Zeta[3]) + 540*x^21*
             (-401969965876124444545501 + 6823622670126908036832*Zeta[3]) + 
            8748*x^53*(-101316009136274753733 + 12342256206320386236128*Zeta[
                3]) - 1152*x^23*(-362753800422585698797456 + 
              23440458404483299590327*Zeta[3]) + 1458*x^54*
             (-235629417418919042661 + 24717482594201839260448*Zeta[3]) + 
            1764*x^36*(159883235044572857031313 + 27886062970524849208384*
               Zeta[3]) - 54*x^20*(1096580662137263983053053 + 
              28750361658276016541664*Zeta[3]) - 1134*x^44*
             (-72152123868498688991939 + 70572142710803288425696*Zeta[3]) + 
            1134*x^50*(-6849521836386466430457 + 231855022851847616648224*
               Zeta[3]) - 18*x^24*(8955841192260813872011931 + 
              288793461682369479735648*Zeta[3]) + 824*x^29*
             (-2093794383270417317769605 + 386418095342452065971232*Zeta[
                3]) - 648*x^51*(-8092974627778576488129 + 
              593595278790382009518160*Zeta[3]) - 162*x^52*
             (-11734053194722124962845 + 700318030802342802973088*Zeta[3]) + 
            486*x^49*(-48219867429163781192739 + 2195798039127296803837568*
               Zeta[3]) - 162*x^48*(-145063091234011815461459 + 
              2669641811336418420065760*Zeta[3]) - 648*x^47*
             (-122937622824320084027125 + 3592139013525415812369456*Zeta[
                3]) - 252*x^30*(2511046284125110852668179 + 
              6765811790200960893314912*Zeta[3]) + 540*x^45*
             (-381911693691449285319115 + 7452826200656626073525472*Zeta[
                3]) + 54*x^46*(-971948860632403313143583 + 
              8196528103560338909017056*Zeta[3]) - 576*x^43*
             (-706118024808155576585357 + 9651408512939469355370634*Zeta[
                3]) - 8*x^26*(26587259715900234604372589 + 
              19191568429997397406530432*Zeta[3]) + 
            52*x^40*(-4654571854010579956867501 + 23803370983189921466058912*
               Zeta[3]) + 5*x^25*(-103360774254249321222730361 + 
              25434577665258369533243136*Zeta[3]) - 
            18*x^42*(2420131059082389093706751 + 35520608740064616804914208*
               Zeta[3]) + 16*x^31*(201098604761019124058735021 + 
              42662676428515112828609520*Zeta[3]) - 
            16*x^35*(-25833871551827530493446421 + 66589847935466295745176480*
               Zeta[3]) - 4*x^34*(338669078705167942671824251 + 
              100624120896884067899365824*Zeta[3]) + 
            8*x^28*(175397594818135662246034903 + 103579391112469590410326080*
               Zeta[3]) - 12*x^33*(-98819866758304446495327271 + 
              117586087937857501020269568*Zeta[3]) + 
            4*x^32*(-971365246290055926480918421 + 
              297262567972336039519946976*Zeta[3]) + 
            8*x^37*(-165601885130621468638333265 + 
              494712701014273459383417696*Zeta[3]) + 
            x^41*(-639725563757281328487513265 + 6203962668832339090907162880*
               Zeta[3])))/(3200601600*x^11*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^
           8)) + CF^2*((-2*Pi^2*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 
           8687*x^5 - 8564*x^6 + 8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 
           7*x^11 + x^12)*HPL[{-2}, x])/(945*(-1 + x^2)^10) + 
        lm^2*((4*(1 + 7*x - 34*x^2 + 714*x^3 - 1133*x^4 + 3689*x^5 - 
             2708*x^6 + 3689*x^7 - 1133*x^8 + 714*x^9 - 34*x^10 + 7*x^11 + 
             x^12))/(35*(-1 + x^2)^10) - (48*x^3*(1 - 2*x + 10*x^2 - 10*x^3 + 
             20*x^4 - 10*x^5 + 10*x^6 - 2*x^7 + x^8)*HPL[{0}, x])/
           (-1 + x^2)^11) + (2*Pi^2*(1 + 7*x - 184*x^2 + 1596*x^3 - 
           3725*x^4 + 8687*x^5 - 8564*x^6 + 8687*x^7 - 3725*x^8 + 1596*x^9 - 
           184*x^10 + 7*x^11 + x^12)*HPL[{2}, x])/(945*(-1 + x^2)^10) + 
        (x*(3885 - 171570*x + 2116485*x^2 - 5197710*x^3 + 39300765*x^4 - 
           44009210*x^5 + 111134065*x^6 - 100323020*x^7 + 198372405*x^8 + 
           54202778*x^9 - 157824429*x^10 - 338306598*x^11 + 351163155*x^12 + 
           750717122*x^13 - 417672179*x^14 - 1200229270*x^15 + 
           306409983*x^16 + 1396559571*x^17 - 72396907*x^18 - 
           1193428753*x^19 - 113201055*x^20 + 743691635*x^21 + 
           152925967*x^22 - 329628445*x^23 - 96331685*x^24 + 98644855*x^25 + 
           35691675*x^26 - 17895825*x^27 - 7497225*x^28 + 1488375*x^29 + 
           694575*x^30)*HPL[{-2, 0}, x])/(66150*(-1 + x^2)^12) + 
        ((-583443000 - 1250235000*x + 5422504500*x^2 + 13157140500*x^3 - 
           21604149000*x^4 - 62605036200*x^5 + 46277325150*x^6 + 
           177550290750*x^7 - 50257119780*x^8 - 332819218900*x^9 + 
           1242773630*x^10 + 431689118070*x^11 + 81981062800*x^12 - 
           (393444140807 + 235200*Pi^2)*x^13 - 14*(9536037521 + 117600*Pi^2)*
            x^14 + 15*(16677396721 + 2900800*Pi^2)*x^15 - 
           28*(-3918775303 + 13347600*Pi^2)*x^16 + 
           (-92504602863 + 832843200*Pi^2)*x^17 - 
           70*(1936953139 + 23825760*Pi^2)*x^18 + 
           15*(5819858729 + 75875520*Pi^2)*x^19 - 85853998720*x^20 - 
           15*(-5819858729 + 75875520*Pi^2)*x^21 + 
           70*(-1936953139 + 23825760*Pi^2)*x^22 - 
           3*(30834867621 + 277614400*Pi^2)*x^23 + 
           28*(3918775303 + 13347600*Pi^2)*x^24 + 
           (250160950815 - 43512000*Pi^2)*x^25 + 
           14*(-9536037521 + 117600*Pi^2)*x^26 + 
           (-393444140807 + 235200*Pi^2)*x^27 + 81981062800*x^28 + 
           431689118070*x^29 + 1242773630*x^30 - 332819218900*x^31 - 
           50257119780*x^32 + 177550290750*x^33 + 46277325150*x^34 - 
           62605036200*x^35 - 21604149000*x^36 + 13157140500*x^37 + 
           5422504500*x^38 - 1250235000*x^39 - 583443000*x^40)*
          HPL[{-1, 0}, x])/(111132000*x^13*(-1 + x^2)^11) + 
        (x*(421436007934200 - 18831664150052040*x + 373622141388027420*x^2 + 
           231582937803114870*x^3 - 19556936250812120790*x^4 + 
           23127402822736435020*x^5 + 318444928270990159590*x^6 - 
           804678428542871174040*x^7 + 405741298397305335570*x^8 + 
           9575066263004198464662*x^9 - 78782448658134441484026*x^10 - 
           10802711191826818212480*x^11 + 1054593699891237870519456*x^12 - 
           883921501618904153928654*x^13 - 5331419871381818314202844*x^14 + 
           9484165141220762423166915*x^15 - 4452646561023829008815226*x^16 - 
           39738881214757115815541778*x^17 + 166153445826592866537434910*
            x^18 + 38156435338244935656264126*x^19 - 
           612004219243375624990146018*x^20 + 138419192324899330156725770*
            x^21 + 333712386664961447318596078*x^22 + 
           267407007092549638192890368*x^23 + 1169475398010512986459461808*
            x^24 - 2815870577669851237799651920*x^25 + 
           1637944769410554968051426192*x^26 + 4309295473463828703348888096*
            x^27 - 2569323240191560287840400520*x^28 - 
           5740567326847862884269628604*x^29 + 1839449137068838085043278312*
            x^30 + 6786429079157260749989731970*x^31 - 
           816946468270590982513641452*x^32 - 6474986257253460079639688572*
            x^33 - 69040853594183648179445912*x^34 + 
           4896254313673273326300321370*x^35 + 533866847162119645591863222*
            x^36 - 2930956833308080291198887984*x^37 - 
           547837615345770839334772590*x^38 + 1383662956509097248623074212*
            x^39 + 344762447874238788904641474*x^40 - 
           511493062647807451011211290*x^41 - 152888210626755838990611114*
            x^42 + 146699679743487353762482536*x^43 + 
           49654000300346868947418576*x^44 - 32301223182612489166299990*
            x^45 - 11943771727603114762245036*x^46 + 
           5396154250416454255112307*x^47 + 2128325323696477078212270*x^48 - 
           674075648616550458464970*x^49 - 278975543259240058676130*x^50 + 
           61679121194779596846450*x^51 + 26478686821752730940130*x^52 - 
           4001478400807826919750*x^53 - 1767284598755527806150*x^54 + 
           173989679328117632700*x^55 + 78585416022407773500*x^56 - 
           4542962195991775500*x^57 - 2089163243540299500*x^58 + 
           53818517229435000*x^59 + 25115308040403000*x^60)*HPL[{0, 0}, x])/
         (55566000*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        ((583443000 + 1250235000*x - 5422504500*x^2 - 13157140500*x^3 + 
           21604149000*x^4 + 62605036200*x^5 - 46277325150*x^6 - 
           177550290750*x^7 + 50257119780*x^8 + 332819218900*x^9 - 
           1242773630*x^10 - 431689118070*x^11 - 81981062800*x^12 + 
           (393444140807 + 235200*Pi^2)*x^13 + 14*(9536037521 + 117600*Pi^2)*
            x^14 - 15*(16677396721 + 2900800*Pi^2)*x^15 + 
           28*(-3918775303 + 13347600*Pi^2)*x^16 + 
           (92504602863 - 832843200*Pi^2)*x^17 + 
           70*(1936953139 + 23825760*Pi^2)*x^18 - 
           15*(5819858729 + 75875520*Pi^2)*x^19 + 85853998720*x^20 + 
           15*(-5819858729 + 75875520*Pi^2)*x^21 - 
           70*(-1936953139 + 23825760*Pi^2)*x^22 + 
           (92504602863 + 832843200*Pi^2)*x^23 - 
           28*(3918775303 + 13347600*Pi^2)*x^24 + 
           15*(-16677396721 + 2900800*Pi^2)*x^25 - 
           14*(-9536037521 + 117600*Pi^2)*x^26 + (393444140807 - 235200*Pi^2)*
            x^27 - 81981062800*x^28 - 431689118070*x^29 - 1242773630*x^30 + 
           332819218900*x^31 + 50257119780*x^32 - 177550290750*x^33 - 
           46277325150*x^34 + 62605036200*x^35 + 21604149000*x^36 - 
           13157140500*x^37 - 5422504500*x^38 + 1250235000*x^39 + 
           583443000*x^40)*HPL[{1, 0}, x])/(111132000*x^13*(-1 + x^2)^11) + 
        lm*((6499 + 16090*x - 60214*x^2 + 4281090*x^3 - 5120255*x^4 + 
            21621020*x^5 - 12486860*x^6 + 21621020*x^7 - 5120255*x^8 + 
            4281090*x^9 - 60214*x^10 + 16090*x^11 + 6499*x^12 + 
            240*Pi^2*(-1 - 7*x + 4*x^2 - 105*x^3 + 65*x^4 - 140*x^5 + 
              140*x^7 - 65*x^8 + 105*x^9 - 4*x^10 + 7*x^11 + x^12))/
           (37800*(-1 + x^2)^10) - (2*x^2*(4 + 8083*x - 13770*x^2 + 
             93367*x^3 - 92768*x^4 + 240354*x^5 - 130568*x^6 + 164767*x^7 - 
             40146*x^8 + 25051*x^9 - 836*x^10 + 168*x^11 + 24*x^12)*
            HPL[{0}, x])/(105*(-1 + x^2)^11) - 
          (8*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 
             112*x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{-1, 0}, x])/
           (105*(-1 + x^2)^9) + (16*x^3*(630 - 1260*x + 12285*x^2 - 
             16310*x^3 + 58975*x^4 - 47040*x^5 + 83860*x^6 - 36344*x^7 + 
             34902*x^8 - 6356*x^9 + 3241*x^10 - 6*x^11 + 7*x^12 + x^13)*
            HPL[{0, 0}, x])/(105*(-1 + x^2)^12) + 
          (8*(1 + 7*x - 3*x^2 + 112*x^3 - 68*x^4 + 252*x^5 - 68*x^6 + 
             112*x^7 - 3*x^8 + 7*x^9 + x^10)*HPL[{1, 0}, x])/
           (105*(-1 + x^2)^9)) - (x*(3885 - 171570*x + 2116485*x^2 - 
           5197710*x^3 + 39300765*x^4 - 44009210*x^5 + 111134065*x^6 - 
           100323020*x^7 + 198372405*x^8 + 54202778*x^9 - 157824429*x^10 - 
           338306598*x^11 + 351163155*x^12 + 750717122*x^13 - 
           417672179*x^14 - 1200229270*x^15 + 306409983*x^16 + 
           1396559571*x^17 - 72396907*x^18 - 1193428753*x^19 - 
           113201055*x^20 + 743691635*x^21 + 152925967*x^22 - 
           329628445*x^23 - 96331685*x^24 + 98644855*x^25 + 35691675*x^26 - 
           17895825*x^27 - 7497225*x^28 + 1488375*x^29 + 694575*x^30)*
          HPL[{2, 0}, x])/(66150*(-1 + x^2)^12) + 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-2, -1, 0}, x])/(315*(-1 + x^2)^10) - 
        (16*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-2, 0, 0}, x])/(315*(-1 + x^2)^10) - 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-2, 1, 0}, x])/(315*(-1 + x^2)^10) - 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-1, -2, 0}, x])/(315*(-1 + x^2)^10) + 
        ((-694575 - 1488375*x + 4024350*x^2 + 10453950*x^3 - 8624175*x^4 - 
           31491355*x^5 + 6021560*x^6 + 52748420*x^7 + 7139958*x^8 - 
           53054610*x^9 - 18372830*x^10 + 31999828*x^11 + 16494002*x^12 - 
           10619406*x^13 - 7544068*x^14 + 1364485*x^15 + 1679734*x^16 + 
           87063*x^17 - 345912*x^18 + 87063*x^19 + 1679734*x^20 + 
           1364485*x^21 - 7544068*x^22 - 10619406*x^23 + 16494002*x^24 + 
           31999828*x^25 - 18372830*x^26 - 53054610*x^27 + 7139958*x^28 + 
           52748420*x^29 + 6021560*x^30 - 31491355*x^31 - 8624175*x^32 + 
           10453950*x^33 + 4024350*x^34 - 1488375*x^35 - 694575*x^36)*
          HPL[{-1, -1, 0}, x])/(132300*x^15*(-1 + x^2)^7) + 
        ((1665 - 95005*x + 878290*x^2 - 11582884*x^3 + 33059123*x^4 - 
           88999315*x^5 + 120496252*x^6 - 175032032*x^7 + 129603797*x^8 - 
           23151265*x^9 - 8262454*x^10 - 192548014*x^11 + 70456759*x^12 + 
           391677137*x^13 - 102292876*x^14 - 604788564*x^15 + 
           111652479*x^16 + 687893589*x^17 - 90880086*x^18 - 578530324*x^19 + 
           54511981*x^20 + 356305307*x^21 - 23430960*x^22 - 156517420*x^23 + 
           6837355*x^24 + 46511025*x^25 - 1214550*x^26 - 8390250*x^27 + 
           99225*x^28 + 694575*x^29)*HPL[{-1, 0, 0}, x])/
         (66150*(-1 + x)^12*(1 + x)^10) - 
        ((-694575 - 1488375*x + 4024350*x^2 + 10453950*x^3 - 8624175*x^4 - 
           31491355*x^5 + 6021560*x^6 + 52748420*x^7 + 7139958*x^8 - 
           53054610*x^9 - 18372830*x^10 + 31999828*x^11 + 16494002*x^12 - 
           10619406*x^13 - 7544068*x^14 + 1364485*x^15 + 1679734*x^16 + 
           87063*x^17 - 345912*x^18 + 87063*x^19 + 1679734*x^20 + 
           1364485*x^21 - 7544068*x^22 - 10619406*x^23 + 16494002*x^24 + 
           31999828*x^25 - 18372830*x^26 - 53054610*x^27 + 7139958*x^28 + 
           52748420*x^29 + 6021560*x^30 - 31491355*x^31 - 8624175*x^32 + 
           10453950*x^33 + 4024350*x^34 - 1488375*x^35 - 694575*x^36)*
          HPL[{-1, 1, 0}, x])/(132300*x^15*(-1 + x^2)^7) + 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-1, 2, 0}, x])/(315*(-1 + x^2)^10) - 
        (x*(-167236511085 + 7457844413250*x + 256272577331400*x^2 - 
           725523491462715*x^3 - 12398790818303757*x^4 + 19501688762266815*
            x^5 + 211719191865048396*x^6 + 31493088242884287*x^7 - 
           1056968837454611205*x^8 - 11651672368383965271*x^9 - 
           3569894920949575572*x^10 + 266033829584410850295*x^11 - 
           167335778524356470043*x^12 - 2987024720156682102819*x^13 + 
           5479508646695300052672*x^14 + 18244737715152732536013*x^15 - 
           59085657102447346909020*x^16 - 52066620103645608687095*x^17 + 
           304277779557250721174260*x^18 + 8563818965133253828714*x^19 - 
           689626880984291704527450*x^20 + 74820739377444863655422*x^21 + 
           375661426781858116140908*x^22 + 1711153649513576853601222*x^23 - 
           1555354863989435534707042*x^24 - 7445061754015431414914846*x^25 + 
           10391086711083323996741528*x^26 + 11631998777439842815187278*
            x^27 - 10663656744194199241860270*x^28 - 
           22643323511316924565314022*x^29 + 11259019894655463269696432*
            x^30 + 35817753934493185395121016*x^31 - 
           10695619430170801582995303*x^32 - 44298372785621475900673100*
            x^33 + 6608181471877798475938352*x^34 + 
           44175458492577789327666089*x^35 - 1185280258048641433736321*x^36 - 
           35766603540092743657146021*x^37 - 2567688596436244703152700*x^38 + 
           23464098035209598219039955*x^39 + 3551930011281576909748791*x^40 - 
           12415252662275599814041939*x^41 - 2682349110506705781643492*x^42 + 
           5263785226823373017909963*x^43 + 1415011044470060129487393*x^44 - 
           1773303845304465299226807*x^45 - 553001845855703427641376*x^46 + 
           469935151608099062330829*x^47 + 162964816206990663267090*x^48 - 
           96842403627396990225903*x^49 - 36312911148017491111404*x^50 + 
           15316198222758596247672*x^51 + 6089878506349904390712*x^52 - 
           1829177220240486476136*x^53 - 760539760495877190780*x^54 + 
           161318204828207697960*x^55 + 69433978520157873264*x^56 - 
           10153222805420909640*x^57 - 4490552764292332320*x^58 + 
           430539397629248160*x^59 + 194594346665242200*x^60 - 
           11008785647228400*x^61 - 5063895727621200*x^62 + 
           128139326736750*x^63 + 59798352477150*x^64)*HPL[{0, 0, 0}, x])/
         (66150*(-1 + x^2)^13*(9 - 82*x^2 + 9*x^4)^8) + 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{1, -2, 0}, x])/(315*(-1 + x^2)^10) - 
        ((-694575 - 1488375*x + 4024350*x^2 + 10453950*x^3 - 8624175*x^4 - 
           31491355*x^5 + 6021560*x^6 + 52748420*x^7 + 7139958*x^8 - 
           53054610*x^9 - 18372830*x^10 + 31999828*x^11 + 16494002*x^12 - 
           10619406*x^13 - 7544068*x^14 + 1364485*x^15 + 1679734*x^16 + 
           87063*x^17 - 345912*x^18 + 87063*x^19 + 1679734*x^20 + 
           1364485*x^21 - 7544068*x^22 - 10619406*x^23 + 16494002*x^24 + 
           31999828*x^25 - 18372830*x^26 - 53054610*x^27 + 7139958*x^28 + 
           52748420*x^29 + 6021560*x^30 - 31491355*x^31 - 8624175*x^32 + 
           10453950*x^33 + 4024350*x^34 - 1488375*x^35 - 694575*x^36)*
          HPL[{1, -1, 0}, x])/(132300*x^15*(-1 + x^2)^7) + 
        ((-1665 + 95065*x - 451110*x^2 + 10028344*x^3 - 3137127*x^4 + 
           27839499*x^5 + 19043508*x^6 + 37109656*x^7 + 59849323*x^8 + 
           25387989*x^9 - 148328030*x^10 - 80141718*x^11 + 298073037*x^12 + 
           337349471*x^13 - 374845212*x^14 - 669335996*x^15 + 
           236390745*x^16 + 835707503*x^17 + 38464690*x^18 - 686381216*x^19 - 
           217798369*x^20 + 363985533*x^21 + 202077800*x^22 - 
           112755900*x^23 - 97961155*x^24 + 13165275*x^25 + 25646850*x^26 + 
           2436750*x^27 - 2877525*x^28 - 694575*x^29)*HPL[{1, 0, 0}, x])/
         (66150*(-1 + x)^10*(1 + x)^12) + 
        ((-694575 - 1488375*x + 4024350*x^2 + 10453950*x^3 - 8624175*x^4 - 
           31491355*x^5 + 6021560*x^6 + 52748420*x^7 + 7139958*x^8 - 
           53054610*x^9 - 18372830*x^10 + 31999828*x^11 + 16494002*x^12 - 
           10619406*x^13 - 7544068*x^14 + 1364485*x^15 + 1679734*x^16 + 
           87063*x^17 - 345912*x^18 + 87063*x^19 + 1679734*x^20 + 
           1364485*x^21 - 7544068*x^22 - 10619406*x^23 + 16494002*x^24 + 
           31999828*x^25 - 18372830*x^26 - 53054610*x^27 + 7139958*x^28 + 
           52748420*x^29 + 6021560*x^30 - 31491355*x^31 - 8624175*x^32 + 
           10453950*x^33 + 4024350*x^34 - 1488375*x^35 - 694575*x^36)*
          HPL[{1, 1, 0}, x])/(132300*x^15*(-1 + x^2)^7) - 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{1, 2, 0}, x])/(315*(-1 + x^2)^10) - 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{2, -1, 0}, x])/(315*(-1 + x^2)^10) + 
        (16*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{2, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        (8*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{2, 1, 0}, x])/(315*(-1 + x^2)^10) - 
        (16*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{-1, 1, 0, 0}, x])/(315*(-1 + x^2)^10) - 
        (16*(1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
           8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*
          HPL[{1, -1, 0, 0}, x])/(315*(-1 + x^2)^10) + 
        ((2 + 29*x - 280*x^2 + 4357*x^3 - 9212*x^4 + 31801*x^5 - 30574*x^6 + 
           48320*x^7 - 20896*x^8 + 17619*x^9 - 2130*x^10 + 1179*x^11 + 
           90*x^12 + 15*x^13)*master3l10a[x])/(630*(-1 + x^2)^11) - 
        (x*(15 + 90*x + 1179*x^2 - 2130*x^3 + 17619*x^4 - 20896*x^5 + 
           48320*x^6 - 30574*x^7 + 31801*x^8 - 9212*x^9 + 4357*x^10 - 
           280*x^11 + 29*x^12 + 2*x^13)*master3l10b[x])/(630*(-1 + x^2)^11) + 
        ((-271922947911 + 12660402557421*x + 550340744696964*x^2 - 
           2056218772475907*x^3 + 4037520648360375*x^4 - 6128431669779390*
            x^5 + 3181823259032268*x^6 + 78116095252890*x^7 - 
           2113097863917195*x^8 + 1630528976949507*x^9 + 97406439629832*
            x^10 - 425633075726085*x^11 + 128086061710707*x^12 - 
           24477886201572*x^13 - 24047738874792*x^14 + 27312089410188*x^15 - 
           1268148303669*x^16 - 5145029604573*x^17 + 936786669332*x^18 + 
           453236790947*x^19 - 137417758347*x^20 - 16345592446*x^21 + 
           10109872028*x^22 - 304592070*x^23 - 391761337*x^24 + 
           43421453*x^25 + 6664608*x^26 - 999163*x^27 - 11743*x^28)*
          master3l8a[x])/(1587600*(-9 + x^2)^8*(-1 + x^2)^12) - 
        ((15540 - 694663*x + 209177*x^2 + 51041036*x^3 - 47887739*x^4 - 
           1757842377*x^5 + 1526603010*x^6 + 36973994084*x^7 - 
           23882889202*x^8 - 519435521763*x^9 + 234823270383*x^10 + 
           4981361236664*x^11 - 1943862879709*x^12 - 31822920577141*x^13 + 
           17318502436860*x^14 + 124014432106632*x^15 - 134953043202648*
            x^16 - 216418074905061*x^17 + 672538348847079*x^18 - 
           217489761737604*x^19 - 1654483180080357*x^20 + 1332370740861477*
            x^21 + 625977282434274*x^22 - 769587939964332*x^23 + 
           3129046939177974*x^24 - 813403672786161*x^25 + 
           689524119166257*x^26 + 53273459825280*x^27 + 2865463087581*x^28 - 
           705833895591*x^29)*master3l8b[x])/(1587600*x*(1 - 9*x^2)^8*
          (-1 + x^2)^12) - ((-54319824639 + 862548091389*x + 
           33528086937387*x^2 - 75831642062604*x^3 + 182842952747166*x^4 - 
           175058223040368*x^5 + 154328956920126*x^6 + 19665385089246*x^7 - 
           26226067178637*x^8 + 854253724869*x^9 - 9585303136947*x^10 + 
           13811876698374*x^11 - 5972367748236*x^12 - 7322620889304*x^13 + 
           4890108763076*x^14 + 1665852781580*x^15 - 1295047297481*x^16 - 
           208732606729*x^17 + 184891850613*x^18 + 15033047104*x^19 - 
           15948309938*x^20 - 564577080*x^21 + 843735902*x^22 + 
           5158710*x^23 - 25673995*x^24 + 325063*x^25 + 353203*x^26 - 
           7770*x^27)*master3l9a[x])/(529200*(-9 + x^2)^7*(-1 + x^2)^12) - 
        ((-7770 + 353203*x + 325063*x^2 - 25673995*x^3 + 5158710*x^4 + 
           843735902*x^5 - 564577080*x^6 - 15948309938*x^7 + 
           15033047104*x^8 + 184891850613*x^9 - 208732606729*x^10 - 
           1295047297481*x^11 + 1665852781580*x^12 + 4890108763076*x^13 - 
           7322620889304*x^14 - 5972367748236*x^15 + 13811876698374*x^16 - 
           9585303136947*x^17 + 854253724869*x^18 - 26226067178637*x^19 + 
           19665385089246*x^20 + 154328956920126*x^21 - 175058223040368*
            x^22 + 182842952747166*x^23 - 75831642062604*x^24 + 
           33528086937387*x^25 + 862548091389*x^26 - 54319824639*x^27)*
          master3l9b[x])/(1587600*x*(-1 + x^2)^12*(-1 + 9*x^2)^7) + 
        (HPL[{-1}, x]*(Pi^2*(-1 + x^2)^3*(694575 + 1488375*x - 4024350*x^2 - 
             10453950*x^3 + 8624175*x^4 + 31491355*x^5 - 6021560*x^6 - 
             52748420*x^7 - 7139958*x^8 + 53054610*x^9 + 18372830*x^10 - 
             31999828*x^11 - 16494002*x^12 + 10619406*x^13 + 7544068*x^14 - 
             1364485*x^15 - 1679734*x^16 - 87063*x^17 + 345912*x^18 - 
             87063*x^19 - 1679734*x^20 - 1364485*x^21 + 7544068*x^22 + 
             10619406*x^23 - 16494002*x^24 - 31999828*x^25 + 18372830*x^26 + 
             53054610*x^27 - 7139958*x^28 - 52748420*x^29 - 6021560*x^30 + 
             31491355*x^31 + 8624175*x^32 - 10453950*x^33 - 4024350*x^34 + 
             1488375*x^35 + 694575*x^36) - 40320*x^15*(1 + 7*x - 184*x^2 + 
             1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 8687*x^7 - 
             3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*Zeta[3]))/
         (1587600*x^15*(-1 + x^2)^10) + 
        (HPL[{1}, x]*(-(Pi^2*(-1 + x^2)^3*(694575 + 1488375*x - 4024350*x^2 - 
              10453950*x^3 + 8624175*x^4 + 31491355*x^5 - 6021560*x^6 - 
              52748420*x^7 - 7139958*x^8 + 53054610*x^9 + 18372830*x^10 - 
              31999828*x^11 - 16494002*x^12 + 10619406*x^13 + 7544068*x^14 - 
              1364485*x^15 - 1679734*x^16 - 87063*x^17 + 345912*x^18 - 
              87063*x^19 - 1679734*x^20 - 1364485*x^21 + 7544068*x^22 + 
              10619406*x^23 - 16494002*x^24 - 31999828*x^25 + 18372830*x^26 + 
              53054610*x^27 - 7139958*x^28 - 52748420*x^29 - 6021560*x^30 + 
              31491355*x^31 + 8624175*x^32 - 10453950*x^33 - 4024350*x^34 + 
              1488375*x^35 + 694575*x^36)) + 40320*x^15*(1 + 7*x - 184*x^2 + 
             1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 8687*x^7 - 
             3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12)*Zeta[3]))/
         (1587600*x^15*(-1 + x^2)^10) + (HPL[{0}, x]*(150691848242418000 + 
           322911103376610000*x - 12459633537120588000*x^2 - 
           27096317624262348000*x^3 + 465295237019906548500*x^4 + 
           1030416826415189339700*x^5 - 10372091997990963510900*x^6 - 
           23495906563478748018900*x^7 + 153724334359798955803680*x^8 + 
           358411521463837023243600*x^9 - 1597836372044243811144840*x^10 - 
           3867163898133705398336520*x^11 - 2066715*(-5798295351799999711 + 
             135943920*Pi^2)*x^12 + 531441*(57338932437124125329 + 
             23347245600*Pi^2)*x^13 + 840*(3749810731635657918704265 + 
             1587896714176514769141706*Pi^2)*x^35 - 
           2187*(13933361841847557909507 + 148538791187261450151680*Pi^2)*
            x^57 - 8505*(1408985776082446075953 + 13041617460863487154864*
              Pi^2)*x^58 + 918540*(4210120309284310167 + 76089435738117301528*
              Pi^2)*x^59 + 612360*(2609308857607034769 + 42412125358241849482*
              Pi^2)*x^60 - 99202320*(3612934873537605 + 115485492076853167*
              Pi^2)*x^61 - 11022480*(13946438039334066 + 411101338352323033*
              Pi^2)*x^62 + 223205220*(105265936717245 + 6313372808896532*
              Pi^2)*x^63 + 24800580*(418219735102605 + 23553548561050028*
              Pi^2)*x^64 - 3348078300*(307763658459 + 38031099287684*Pi^2)*
            x^65 - 223205220*(2084607326925 + 245118521172268*Pi^2)*x^66 + 
           3254332107600*(8326230 + 2512403017*Pi^2)*x^67 + 
           40176939600*(310119030 + 89922441793*Pi^2)*x^68 - 
           3254332107600*(99225 + 108321259*Pi^2)*x^69 - 1807962282000*
            (83349 + 88085803*Pi^2)*x^70 + 9139742909212986000*Pi^2*x^71 + 
           4203441795121002000*Pi^2*x^72 - 107637034458870000*Pi^2*x^73 - 
           50230616080806000*Pi^2*x^74 + 21*x^52*(67532409701404467045322000*
              Pi^2 + 81*(464011863752780566294291 - 455294841055488000*
                Zeta[3])) + 567*x^56*(623637744494067427519120*Pi^2 + 
             81*(1432662428590517009161 - 9999593856000*Zeta[3])) + 
           2*x^39*(9486844713387063626341398943 + 
             3592410332654067000983572680*Pi^2 - 52260787445009602201344000*
              Zeta[3]) - 14*x^37*(470734297463360825919201953 + 
             235144472535695069809726920*Pi^2 - 13710638220229055185920000*
              Zeta[3]) + 2*x^29*(14269878852198414413926687573 + 
             4135405242332409508217160*Pi^2 - 7951634956514032809984000*
              Zeta[3]) - 2*x^41*(14248357587168923049430786933 + 
             6299411126333451448784433720*Pi^2 - 7951634956514032809984000*
              Zeta[3]) + 70*x^30*(88715011865977382158731731 + 
             755655348242109787085016*Pi^2 - 1173580903160461224576000*
              Zeta[3]) - 70*x^40*(48173712959995869498947951 + 
             70414889078722565468103192*Pi^2 - 1173580903160461224576000*
              Zeta[3]) - 42*x^28*(100649385251071794238322959 + 
             494458988463719634969960*Pi^2 - 735809399502251300352000*
              Zeta[3]) + 42*x^42*(74859330179131935353627659 + 
             126384833944159700755059320*Pi^2 - 735809399502251300352000*
              Zeta[3]) - 14*x^32*(451634347434565146690298523 + 
             8391898121076186657428520*Pi^2 - 526234744677296801664000*
              Zeta[3]) + 14*x^38*(540096534465451696664912423 + 
             252025854292357357883126760*Pi^2 - 526234744677296801664000*
              Zeta[3]) + 105*x^26*(4919767209777507379888091 + 
             43009712004663249055344*Pi^2 - 44659507123013284454400*
              Zeta[3]) - 105*x^44*(4072901179581567270370031 + 
             38170685884964354183562864*Pi^2 - 44659507123013284454400*
              Zeta[3]) + 21*x^46*(-96091197820634616311745603 + 
             75506132315564766369710480*Pi^2 - 6266348354943686016000*
              Zeta[3]) + 189*x^23*(-75552032651517557963160227 + 
             111677859914391439200*Pi^2 - 1580302032892773120000*Zeta[3]) + 
           63*x^48*(39433456743903743874666103 + 9408705988829855796104880*
              Pi^2 - 981239313713145984000*Zeta[3]) - 
           189*x^24*(-10822612444316393494486567 + 2829420956062390601520*
              Pi^2 - 696260928327076224000*Zeta[3]) - 
           63*x^21*(-111412324441080473780898401 + 48629316694577280480*
              Pi^2 - 488987259269225472000*Zeta[3]) - 
           105*x^50*(16116407006617451501326791 + 14910957836197159211576368*
              Pi^2 - 98904122905238784000*Zeta[3]) + 
           945*x^20*(1791807851133722326681859 + 385227472863406320*Pi^2 - 
             10989346989470976000*Zeta[3]) - 1701*x^18*
            (464052781844500049744191 + 85727352461864400*Pi^2 - 
             455294841055488000*Zeta[3]) + 47628*x^19*
            (-56398758391819915424371 + 2522150498782800*Pi^2 - 
             39356496732672000*Zeta[3]) + 5103*x^16*
            (52118438173116421211027 + 1500878836674000*Pi^2 - 
             5749766467200000*Zeta[3]) - 45927*x^14*(1432663217134346051461 + 
             2886805882800*Pi^2 - 9999593856000*Zeta[3]) - 
           19683*x^15*(9088004493278697506111 + 26850161167200*Pi^2 + 
             46664771328000*Zeta[3]) + 32805*x^17*(24177643466539732041601 + 
             143985447033120*Pi^2 + 1928810548224000*Zeta[3]) + 
           63*x^22*(-39566196327719655734165803 + 463774980739985414640*
              Pi^2 + 981239313713145984000*Zeta[3]) - 
           21*x^49*(334372164871298231939810883 + 597012059216572590778258240*
              Pi^2 + 1466961777807676416000*Zeta[3]) + 
           21*x^47*(681157375011832160224512603 + 833365212915684454640894720*
              Pi^2 + 14222718296034958080000*Zeta[3]) + 
           48*x^43*(605577547546330069976830613 + 365816179968938350882912640*
              Pi^2 + 61877226751571669760000*Zeta[3]) - 
           12*x^27*(2393535161729730712101725957 + 161102727710392071111480*
              Pi^2 + 247508907006286679040000*Zeta[3]) + 
           3*x^25*(7597476742060630072982666233 + 26351040597135534473760*
              Pi^2 + 536753783525410934784000*Zeta[3]) - 
           3*x^45*(7641526064557318577566108633 + 
             6525035270321412596027949120*Pi^2 + 536753783525410934784000*
              Zeta[3]) - 14*x^33*(-578515552500217971271817153 + 
             23706333909631730820730440*Pi^2 + 13710638220229055185920000*
              Zeta[3]) + 14*x^34*(908847878847722380333771849 + 
             39692026475534634631312200*Pi^2 + 24181658480191140359424000*
              Zeta[3]) - 14*x^36*(1577776320267051025362813949 + 
             142276763147184824388622200*Pi^2 + 24181658480191140359424000*
              Zeta[3]) + 2*x^31*(-10575050447719322799590159743 + 
             11235982605394613167057320*Pi^2 + 52260787445009602201344000*
              Zeta[3]) - 63*x^54*(13254082464493104119591920*Pi^2 - 
             13041*(-323713982461770094807 + 35712835200000*Zeta[3])) + 
           81*x^55*(14379269612780664482490880*Pi^2 + 
             243*(9088016023276484500511 + 46664771328000*Zeta[3])) - 
           15*x^53*(217123774104687127635755392*Pi^2 + 
             6561*(8059305626132608105739 + 642936849408000*Zeta[3])) + 
           84*x^51*(85379847075495682299896360*Pi^2 + 
             81*(394821143040317510387707 + 275495477128704000*Zeta[3]))))/
         (1333584000*x^11*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8) + 
        (-11289600*Pi^4*x^13*(-1 + x^2)^2*(9 - 82*x^2 + 9*x^4)^8*
           (1 + 7*x - 184*x^2 + 1596*x^3 - 3725*x^4 + 8687*x^5 - 8564*x^6 + 
            8687*x^7 - 3725*x^8 + 1596*x^9 - 184*x^10 + 7*x^11 + x^12) + 
          48*Pi^2*(9 - 82*x^2 + 9*x^4)^8*(-583443000 - 1250235000*x + 
            6005947500*x^2 + 14407375500*x^3 - 27026653500*x^4 - 
            75762176700*x^5 + 67881474150*x^6 + 240155326950*x^7 - 
            96534444930*x^8 - 510369509650*x^9 + 51499893410*x^10 + 
            764508336970*x^11 + 80738289170*x^12 - 825133258877*x^13 - 
            215485588094*x^14 + 643605091622*x^15 + 243230233778*x^16 - 
            342665553678*x^17 - 245312428214*x^18 + 179802483798*x^19 + 
            49732721010*x^20 - 49732721010*x^22 - 179802483798*x^23 + 
            245312428214*x^24 + 342665553678*x^25 - 243230233778*x^26 - 
            643605091622*x^27 + 215485588094*x^28 + 825133258877*x^29 - 
            80738289170*x^30 - 764508336970*x^31 - 51499893410*x^32 + 
            510369509650*x^33 + 96534444930*x^34 - 240155326950*x^35 - 
            67881474150*x^36 + 75762176700*x^37 + 27026653500*x^38 - 
            14407375500*x^39 - 6005947500*x^40 + 1250235000*x^41 + 
            583443000*x^42) + x^2*(-1808302178909016000 - 3874933240519320000*
             x + 150118369838416728000*x^2 + 326447455904654616000*x^3 - 
            5633155340614997307000*x^4 - 12472902820824256553400*x^5 + 
            126307721050205709457800*x^6 + 286032170683555487238600*x^7 - 
            1885492738020040998365160*x^8 - 4393398662140891802301000*x^9 + 
            19773756625969034662390200*x^10 + 
            x^43*(414417428778208812081838674343 - 
              2533167712580785092939184047360*Zeta[3]) + 
            x^35*(136646527504045837932601408876 - 
              74492072153362932867029871360*Zeta[3]) + 
            x^27*(409500561078767423186884215943 - 
              4480509791967755920193514240*Zeta[3]) - 1316122978926669984000*
             x^71*Zeta[3] - 605295618497424288000*x^72*Zeta[3] + 
            15499732962077280000*x^73*Zeta[3] + 7233208715636064000*x^74*
             Zeta[3] - 4519905705*x^11*(-10576595578737857 + 46114560*Zeta[
                3]) + 1240029000*x^12*(-120940920927758411 + 53957664*Zeta[
                3]) + 65086642152000*x^70*(-27783 + 352343212*Zeta[3]) + 
            117155955873600*x^69*(-33075 + 433285036*Zeta[3]) - 
            117155955873600*x^67*(-2786435 + 10049612068*Zeta[3]) - 
            1446369825600*x^68*(-103789755 + 359689767172*Zeta[3]) + 
            12754584*x^13*(-29841630514077360289 + 1743581700000*Zeta[3]) + 
            1102248*x^14*(757757310072082899281 + 143051848109280*Zeta[3]) + 
            60265409400*x^65*(-206966200761 + 304248794301472*Zeta[3]) + 
            4017693960*x^66*(-1402086718575 + 1960948169378144*Zeta[3]) - 
            472392*x^15*(-4790400231856377800443 + 2419962689239200*Zeta[
                3]) - 4017693960*x^63*(-71193120613785 + 50506982471172256*
               Zeta[3]) + 472392*x^17*(-21573546198279040520861 + 
              77154506104324320*Zeta[3]) - 122472*x^16*
             (28072483767486729153073 + 89956990495954080*Zeta[3]) - 
            446410440*x^64*(-282940786622745 + 188428388488400224*Zeta[3]) + 
            367416*x^18*(28439845658462535626317 + 888591748476296160*Zeta[
                3]) + 446410440*x^61*(-9841612714391025 + 3695535746459301344*
               Zeta[3]) + 49601160*x^62*(-38013077476817901 + 
              13155242827274337056*Zeta[3]) - 1458*x^19*
             (-24121569061855147296846149 + 537498933378698148480*Zeta[3]) - 
            5511240*x^60*(-3587896127052205155 + 678594005731869591712*Zeta[
                3]) - 4536*x^20*(5107629193903763491715213 + 
              1172412767095722024480*Zeta[3]) + 68040*x^26*
             (62552481724869149790919 + 1466481166916654506912*Zeta[3]) - 
            2066715*x^59*(-23131013742052213419 + 4869723887391151428352*Zeta[
                3]) + 612360*x^58*(-244905355216229854275 + 
              26083234920570218571488*Zeta[3]) + 1512*x^22*
             (23863823867151195663783961 + 33159189152411028980640*Zeta[3]) + 
            216*x^21*(-435053661149999200999087813 + 54386951780064930959520*
               Zeta[3]) + 157464*x^57*(-2417169252405906210609 + 
              297077582579690235940960*Zeta[3]) - 360*x^23*
             (-544681892587698308914547669 + 344091478167896719782816*Zeta[
                3]) - 504*x^24*(68696089480361970190818563 + 
              485168292842582272978080*Zeta[3]) - 40824*x^56*
             (-20459418049994133572487 + 1247275484515441291424480*Zeta[3]) + 
            216*x^25*(-1484823116148651059471369491 + 
              4208900721376114056293280*Zeta[3]) + 22680*x^44*
             (-19825416196136194382963 + 25474027408371932183353888*Zeta[
                3]) + 4536*x^54*(-757942778125110502149471 + 
              26508162520420888445854880*Zeta[3]) - 5832*x^55*
             (-388018039592681528203683 + 28758539483471723482830560*Zeta[
                3]) + 168*x^28*(365906260934208253833296717 + 
              35466345671753829615369120*Zeta[3]) - 1512*x^48*
             (-23685778436429966135341861 + 56417752426030208592588000*Zeta[
                3]) - 1512*x^34*(-81235077120538941936152623 + 
              92753557020794119204867680*Zeta[3]) - 1512*x^52*
             (-6909726317315184122584131 + 135064611563413369848319520*Zeta[
                3]) + 1512*x^50*(-15304600776707209096247139 + 
              149106133974270284855427040*Zeta[3]) + 1512*x^36*
             (14283101714730689681222023 + 152382570490918075945423520*Zeta[
                3]) + 504*x^32*(212954304004521538824800589 + 
              180465554649949169701280800*Zeta[3]) - 168*x^30*
             (866245519101756373499531803 + 206122485210892018857150240*Zeta[
                3]) - 504*x^46*(65572554595758717969762863 + 
              453626736780746780912209440*Zeta[3]) - 504*x^38*
             (-140349725415779121787053189 + 863728347742194326252940320*Zeta[
                3]) + 8*x^33*(-44192781654734094278886691813 + 
              1488909979595670477450988320*Zeta[3]) + 
            8*x^29*(-51818258780765485560211051843 + 
              1706269729821974120089389600*Zeta[3]) + 
            216*x^53*(-47178153040807012791351807 + 
              2171237938520211924346584160*Zeta[3]) - 
            8*x^31*(-48406810646087373200664640187 + 
              2628951643025204246083121760*Zeta[3]) + 
            168*x^40*(-687706993137548427394646803 + 
              4061829706325293624115454240*Zeta[3]) - 
            168*x^42*(-372891893953576892148089417 + 
              4529676140648590545508001760*Zeta[3]) - 
            360*x^47*(-543478396256617799360964509 + 
              7000605527814935532625131744*Zeta[3]) + 
            216*x^49*(-434624355308011093042059013 + 
              8358223123873223078849863520*Zeta[3]) + 
            216*x^45*(-1482754894704702705230350291 + 
              13054278431974255984701241440*Zeta[3]) - 
            54*x^51*(-651088382235968559834655623 + 
              19125101130114890625681769600*Zeta[3]) + 
            8*x^37*(-30171602997998766793663603813 + 
              54630179170748810738973269280*Zeta[3]) - 
            8*x^39*(-46404453192238112596987198187 + 
              131414465910057140350386090720*Zeta[3]) + 
            8*x^41*(-53922634220708343818837314243 + 
              228573549271702984129347278880*Zeta[3])))/
         (64012032000*x^13*(-1 + x^2)^12*(9 - 82*x^2 + 9*x^4)^8)))

CbarLSeries["a", 2, -1, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 391*Pi^4 + 
            20*Pi^2*(-73 + 96*Log[2]^2) + 15*(869 + 936*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 144*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              128*Log[2]^4 - 156*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
              2712*Zeta[3]) - 10*lm*(-1233 + 44*Pi^2 + 648*Zeta[3])) + 
          2*(CF*(5670*lm^2 - 3240*lm^3 + 981*Pi^4 + 10*Pi^2*(259 + 
                576*Log[2]^2) + 15*(1025 + 2808*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 432*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                384*Log[2]^4 - 468*PolyGamma[2, 1] - 9216*PolyLog[4, 1/2] - 
                10464*Zeta[3]) + 135*lm*(95 + 8*Pi^2 - 144*Zeta[3])) - 
            15*(NL*(-219 - 162*lm - 84*lm^2 - 24*lm^3 + 28*Pi^2 + 
                8*lm*Pi^2 - 288*Zeta[3]) + NM*(-219 - 84*lm^2 - 24*lm^3 + 
                28*Pi^2 + 2*lm*(-81 + 4*Pi^2) + 8*PolyGamma[2, 1] - 
                272*Zeta[3]) - NH*(-837 + 162*lm + 84*lm^2 + 24*lm^3 - 
                8*lm*Pi^2 - 1296*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                216*PolyGamma[2, 1] + 2928*Zeta[3])))))/25920, 
      -(CF*NC*(-3*CA*(18240*lm^2 + 2640*lm^3 + 647*Pi^4 + 
            30*Pi^2*(5 + 128*Log[2]^2) + 30*(2255 + 216*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 216*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              128*Log[2]^4 - 36*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
              1540*Zeta[3]) - 180*lm*(-275 + 72*Zeta[3])) + 
          2*(CF*(1620*lm^2 - 6480*lm^3 + 1941*Pi^4 + 10*Pi^2*(59 + 
                1152*Log[2]^2) + 15*(1207 + 1296*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 1296*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                768*Log[2]^4 - 216*PolyGamma[2, 1] - 18432*PolyLog[4, 1/2] - 
                11784*Zeta[3]) - 270*lm*(-41 + 144*Zeta[3])) - 
            180*(NM*(-82 - 57*lm - 20*lm^2 - 4*lm^3 + 2*Pi^2 - 32*Zeta[3]) + 
              NL*(-82 - 57*lm - 20*lm^2 - 4*lm^3 + 2*Pi^2 - 32*Zeta[3]) - 
              NH*(178 + 57*lm + 20*lm^2 + 4*lm^3 - 216*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 36*PolyGamma[2, 1] + 
                200*Zeta[3])))))/25920, 
      -(CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 236*Pi^4 + 
            30*Pi^2*(51 + 64*Log[2]^2) + 15*(1523 + 1224*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 128*Log[2]^4 - 300*PolyGamma[2, 
                1] - 3072*PolyLog[4, 1/2] - 3968*Zeta[3]) + 
            10*lm*(1497 + 44*Pi^2 - 648*Zeta[3])) + 
          10*(CF*(1134*lm^2 - 648*lm^3 + 180*Pi^4 + 8*Pi^2*(-17 + 
                144*Log[2]^2) + 3*(1643 + 3672*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 384*Log[2]^4 - 900*PolyGamma[2, 1] - 
                9216*PolyLog[4, 1/2] - 13560*Zeta[3]) - 27*lm*(-47 + 8*Pi^2 + 
                144*Zeta[3])) + 3*(NM*(-1773 + 84*lm^2 + 24*lm^3 + 
                140*Pi^2 + lm*(210 + 8*Pi^2) - 40*PolyGamma[2, 1] + 
                16*Zeta[3]) + NL*(387 + 210*lm + 84*lm^2 + 24*lm^3 - 
                4*Pi^2 + 8*lm*Pi^2 + 96*Zeta[3]) + NH*(339 + 210*lm + 
                84*lm^2 + 24*lm^3 + 8*lm*Pi^2 - 3888*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 792*PolyGamma[2, 1] + 
                6768*Zeta[3])))))/25920, 
      (CF*NC*(-34875*CF + 82080*NM - 4320*NL - 351200*NH - 4380*CF*Pi^2 - 
         7200*NM*Pi^2 + 1440*NL*Pi^2 + 6300*Sqrt[3]*CF*Pi^3 + 
         8400*Sqrt[3]*NH*Pi^3 + 648*CF*Pi^4 - 64800*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] + 120960*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 51840*CF*Im[PolyLog[2, (-1)^(1/3)]]^
           2 + 233280*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         311040*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         4860*Sqrt[3]*CF*Pi*Log[3]^2 + 6480*Sqrt[3]*NH*Pi*Log[3]^2 - 
         2880*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
           4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         11520*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
         25920*CF*PolyGamma[2, 1] + 1440*NM*PolyGamma[2, 1] - 
         24480*NH*PolyGamma[2, 1] - 34560*CF*Zeta[3] - 83520*NM*Zeta[3] + 
         17280*NL*Zeta[3] - 198720*NH*Zeta[3] - 
         6*CA*(-430*Pi^2 + 525*Sqrt[3]*Pi^3 + 54*Pi^4 + 405*Sqrt[3]*Pi*
            Log[3]^2 - 120*(22 + 45*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             36*Im[PolyLog[2, (-1)^(1/3)]]^2 - 162*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] - 18*PolyGamma[2, 1] + 21*Zeta[3])) - 
         120*Log[x]*(-3*CA*(608*lm + 132*lm^2 + 3*(241 - 9*Pi^2 + 36*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 96*Zeta[3])) + 
           2*(135*NL + 120*lm*NL + 36*lm^2*NL - 889*NH + 120*lm*NH + 
             36*lm^2*NH - 12*NL*Pi^2 + 3*NM*(189 + 40*lm + 12*lm^2 - 4*
                Pi^2) + 432*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
             3*CF*(60 - 18*lm + 108*lm^2 + 29*Pi^2 - 108*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3])))))/25920, 
      (CF*NC*(-25083*CF - 3888*CF*lm - 21336*NM + 432*lm*NM - 504*NL + 
         432*lm*NL - 72184*NH + 432*lm*NH + 1728*CF*Pi^2 - 1632*NM*Pi^2 + 
         96*NL*Pi^2 + 980*Sqrt[3]*CF*Pi^3 + 1680*Sqrt[3]*NH*Pi^3 - 
         54864*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 65664*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 36288*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 62208*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 756*Sqrt[3]*CF*Pi*
          Log[3]^2 + 1296*Sqrt[3]*NH*Pi*Log[3]^2 - 
         576*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
           4*(2*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         2304*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
         15552*CF*PolyGamma[2, 1] - 3456*NM*PolyGamma[2, 1] - 
         16128*NH*PolyGamma[2, 1] + 109152*CF*Zeta[3] - 3456*NM*Zeta[3] + 
         3456*NL*Zeta[3] - 122112*NH*Zeta[3] - 
         2*CA*(1188*lm + 57*Pi^2 + 245*Sqrt[3]*Pi^3 + 189*Sqrt[3]*Pi*
            Log[3]^2 - 36*(381*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             4*(-4 + 63*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 27*
                PolyGamma[2, 1] + 179*Zeta[3]))) - 
         24*Log[x]*(3*CA*(-687 - 608*lm - 132*lm^2 + 61*Pi^2 - 
             84*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3]) + 
           2*(135*NL + 120*lm*NL + 36*lm^2*NL - 889*NH + 120*lm*NH + 
             36*lm^2*NH - 12*NL*Pi^2 + 3*NM*(-47 + 40*lm + 12*lm^2 + 20*
                Pi^2) + 432*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
             3*CF*(165 - 18*lm + 108*lm^2 + 71*Pi^2 - 84*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3])))))/10368, 
      (CF*NC*(-259200*(15*CA*(53 + 22*lm) + 2*(30*CF*(-2 + 9*lm) - 130*NM - 
             30*lm*NM - 45*NL - 30*lm*NL - 8*NH - 30*lm*NH))*Log[x]^2 + 
         5184000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 - 
         1080*Log[x]*(8*(25*NL*(3 + 40*lm + 12*lm^2 - 8*Pi^2) + 
             25*NM*(217 + 40*lm + 12*lm^2 + 16*Pi^2) + 
             NH*(-14923 + 1000*lm + 300*lm^2 + 8000*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) - 50*CF*(1317 - 72*lm + 
             432*lm^2 + 98*Pi^2 - 792*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             1152*Zeta[3]) + 25*CA*(-1851 - 2432*lm - 528*lm^2 + 106*Pi^2 - 
             792*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1152*Zeta[3])) - 
         225*CA*(-560*Pi^2 + 7700*Sqrt[3]*Pi^3 + 432*Pi^4 + 
           5940*Sqrt[3]*Pi*Log[3]^2 + 15*(-10411 - 4560*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 19008*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             2304*PolyGamma[2, 1] + 1216*Zeta[3])) + 
         2*(16*(2*NH*(87500*Sqrt[3]*Pi^3 + 67500*Sqrt[3]*Pi*Log[3]^2 + 9*
                (-324269 + 72000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                 360000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                 18750*PolyGamma[2, 1] - 175500*Zeta[3])) + 
             4500*NM*(-82 + 12*Pi^2 - 21*PolyGamma[2, 1] - 402*Zeta[3]) + 
             3375*NL*(-75 + 4*Pi^2 + 96*Zeta[3])) + 
           225*CF*(72*Pi^2 + 7700*Sqrt[3]*Pi^3 + 432*Pi^4 + 
             5940*Sqrt[3]*Pi*Log[3]^2 + 15*(-10821 - 4560*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^
                 2 + 19008*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               2304*PolyGamma[2, 1] + 1408*Zeta[3])))))/7776000, 
      (CF*NC*(-86400*(120*CA*(26 + 11*lm) + 5*CF*(-133 + 432*lm) - 
           2*(502*NM + 120*lm*NM + 195*NL + 120*lm*NL + 36*NH + 
             120*lm*NH))*Log[x]^2 + 3456000*(40*CA + 49*CF - 11*NM - 4*NL)*
          Log[x]^3 - 125*CA*(7920*lm + 78948*Pi^2 + 17920*Sqrt[3]*Pi^3 + 
           13824*Sqrt[3]*Pi*Log[3]^2 - 9*(207425 + 68224*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 73728*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] - 25920*PolyGamma[2, 1] - 
             220416*Zeta[3])) + 360*Log[x]*
          (-2*(2*(75*NL*(35 + 112*lm + 36*lm^2 - 20*Pi^2) + NM*
                (12521 + 8400*lm + 2700*lm^2 + 12300*Pi^2) + NH*
                (-134107 + 8400*lm + 2700*lm^2 + 73200*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]])) + 75*CF*(-8011 + 252*lm - 648*
                lm^2 + 112*Pi^2 + 1024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               1728*Zeta[3])) + 75*CA*(-3227 + 3472*lm + 792*lm^2 + 
             172*Pi^2 + 1024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             1728*Zeta[3])) + 8*(125*CF*(-511485 - 1620*lm + 21600*Pi^2 + 
             4480*Sqrt[3]*Pi^3 - 153504*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             165888*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             3456*Sqrt[3]*Pi*Log[3]^2 + 58320*PolyGamma[2, 1] + 
             525096*Zeta[3]) + 2*(NH*(11250*lm + 533750*Sqrt[3]*Pi^3 + 
               411750*Sqrt[3]*Pi*Log[3]^2 + 9*(-2131739 + 1238000*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] + 2196000*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 354000*PolyGamma[2, 
                   1] - 2592000*Zeta[3])) + 3*NM*(-1964849 + 3750*lm + 46500*
                Pi^2 - 468000*PolyGamma[2, 1] - 1746000*Zeta[3]) + 
             1125*NL*(-553 + 10*lm + 20*Pi^2 + 720*Zeta[3])))))/23328000, 
      (CF*NC*(-90542867625*CF - 64412699904*NM - 11113200000*NL - 
         213683340384*NH + 178737300*CF*Pi^2 + 5000940000*NM*Pi^2 + 
         333396000*NL*Pi^2 + 3727552500*Sqrt[3]*CF*Pi^3 + 
         7034930000*Sqrt[3]*NH*Pi^3 + 150028200*CF*Pi^4 - 
         33784128000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         32154192000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         12002256000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 138025944000*Sqrt[3]*
          CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 260493408000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2875540500*Sqrt[3]*CF*Pi*
          Log[3]^2 + 5426946000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         9525600*(35*CA*(637 + 264*lm) + 2*(35*CF*(-43 + 216*lm) - 
             2*(2583*NM + 420*lm*NM + 595*NL + 420*lm*NL + 153*NH + 420*
                lm*NH)))*Log[x]^2 + 3556224000*(22*CA + 86*CF - 
           3*(7*NM + NL))*Log[x]^3 + 18003384000*CF*PolyGamma[2, 1] - 
         5000940000*NM*PolyGamma[2, 1] - 11002068000*NH*PolyGamma[2, 1] + 
         21337344000*CF*Zeta[3] - 46008648000*NM*Zeta[3] + 
         12002256000*NL*Zeta[3] - 110020680000*NH*Zeta[3] - 
         7560*Log[x]*(-600642*NM + 882000*lm*NM + 264600*lm^2*NM - 
           815850*NL + 882000*lm*NL + 264600*lm^2*NL - 20925882*NH + 
           882000*lm*NH + 264600*lm^2*NH + 2381400*NM*Pi^2 - 
           264600*NL*Pi^2 + 11485600*Sqrt[3]*NH*
            Im[PolyLog[2, (-1)^(1/3)]] + 3675*CA*(-500 - 1824*lm - 396*lm^2 + 
             43*Pi^2 - 828*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             864*Zeta[3]) - 2450*CF*(5651 - 162*lm + 972*lm^2 + 123*Pi^2 - 
             2484*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 2592*Zeta[3])) - 
         77175*CA*(1692*Pi^2 + 24150*Sqrt[3]*Pi^3 + 972*Pi^4 + 
           18630*Sqrt[3]*Pi*Log[3]^2 + 5*(-116717 - 43776*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 15552*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 178848*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             23328*PolyGamma[2, 1] + 27216*Zeta[3]))))/6001128000, 
      (-2188945*CF^2*NC)/62208 - (7*CF^2*lm*NC)/288 - (136898029*CF*NM*NC)/
        16669800 + (7*CF*lm*NM*NC)/2592 - (3757*CF*NC*NL)/5184 + 
       (7*CF*lm*NC*NL)/2592 - (4452593609*CF*NC*NH)/222264000 + 
       (7*CF*lm*NC*NH)/2592 + (5273*CF^2*NC*Pi^2)/17280 + 
       (131*CF*NM*NC*Pi^2)/324 + (11*CF*NC*NL*Pi^2)/648 + 
       (123445*CF^2*NC*Pi^3)/(139968*Sqrt[3]) + (10535*CF*NC*NH*Pi^3)/
        (5832*Sqrt[3]) - (61829*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2592*Sqrt[3]) + (694*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27*Sqrt[3]) + (3527*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (108*Sqrt[3]) + (602*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9*Sqrt[3]) + (3527*CF^2*NC*Pi*Log[3]^2)/(5184*Sqrt[3]) + 
       (301*CF*NC*NH*Pi*Log[3]^2)/(216*Sqrt[3]) - 
       (CF*NC*(70*CA*(809 + 660*lm) + 35*CF*(2279 + 2160*lm) - 
          4*(5*(2861 + 420*lm)*NM + 12*(35*(8 + 5*lm)*NL + 
              (66 + 175*lm)*NH)))*Log[x]^2)/7560 + 
       (CF*NC*(345*CA + 4*(7*CF - 46*NM - 5*NL))*Log[x]^3)/27 + 
       (7*CF^2*NC*PolyGamma[2, 1])/2 - (43*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (76*CF*NC*NH*PolyGamma[2, 1])/27 - 
       (CA*CF*NC*(124740*lm + 1131003*Pi^2 + 1234450*Sqrt[3]*Pi^3 + 
          952290*Sqrt[3]*Pi*Log[3]^2 - 135*(1038271 + 247316*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 338592*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 108864*PolyGamma[2, 1] - 
            1107216*Zeta[3])))/8398080 - 
       (CF*NC*Log[x]*(2*(24*(3675*NL*(-26 + 55*lm + 18*lm^2 - 14*Pi^2) + 
              5*NM*(-154442 + 40425*lm + 13230*lm^2 + 177870*Pi^2) + 
              NH*(-5299507 + 202125*lm + 66150*lm^2 + 2949800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 1225*CF*(-362181 + 5184*lm - 
              11664*lm^2 + 23742*Pi^2 + 28216*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 31104*Zeta[3])) - 
          1225*CA*(-276525 + 61704*lm + 14256*lm^2 + 25758*Pi^2 + 
            28216*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 31104*Zeta[3])))/
        19051200 + (2675*CF^2*NC*Zeta[3])/72 - (131*CF*NM*NC*Zeta[3])/27 + 
       (7*CF*NC*NL*Zeta[3])/9 - (182*CF*NC*NH*Zeta[3])/9, 
      (CF*NC*(-7144200*(315*CA*(4057 + 1760*lm) + 
           2*(315*CF*(-101 + 1440*lm) - 8*(3*(-611 + 2100*lm)*NM + 210*
                (41 + 30*lm)*NL + 5*(527 + 1260*lm)*NH)))*Log[x]^2 + 
         4000752000*(1025*CA + 4010*CF - 24*(92*NM + 5*NL))*Log[x]^3 + 
         1890*Log[x]*(-2*(8*(27*NM*(-7993673 + 294000*lm + 88200*lm^2 + 
                 2704800*Pi^2) - 5*(26460*NL*(115 - 60*lm - 18*lm^2 + 
                   24*Pi^2) - NH*(-52968051 + 1587600*lm + 476280*lm^2 + 
                   29384320*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
             3675*CF*(-445737 + 7776*lm - 46656*lm^2 + 11484*Pi^2 + 150512*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 124416*Zeta[3])) + 
           3675*CA*(-106869 + 262656*lm + 57024*lm^2 + 11484*Pi^2 + 
             150512*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 124416*Zeta[3])) - 
         25725*CA*(-883791*Pi^2 + 3292450*Sqrt[3]*Pi^3 + 104976*Pi^4 + 
           2539890*Sqrt[3]*Pi*Log[3]^2 - 45*(685324*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 186624*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             3*(-599701 + 903072*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                    Sqrt[3])]] + 124416*PolyGamma[2, 1] + 230832*Zeta[3]))) + 
         2*(3675*CF*(-6583113*Pi^2 + 23047150*Sqrt[3]*Pi^3 + 734832*Pi^4 + 
             17779230*Sqrt[3]*Pi*Log[3]^2 - 1260*(448266 + 171331*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 46656*Im[PolyLog[2, (-1)^(1/3)]]^
                 2 - 677304*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
               93312*PolyGamma[2, 1] - 173124*Zeta[3])) - 
           2*(243*NM*(3415153639 + 144060000*Pi^2 + 284004000*PolyGamma[2, 
                 1] - 321048000*Zeta[3]) - 5*(NH*(17997896000*Sqrt[3]*Pi^3 + 
                 13884091200*Sqrt[3]*Pi*Log[3]^2 + 9*(-57474588853 + 
                   5860086400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                   74048486400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[
                         3])]] - 2733847200*PolyGamma[2, 1] - 28405339200*
                    Zeta[3])) + 4167450*NL*(-6883 + 144*Pi^2 + 
                 6912*Zeta[3]))))))/216040608000, 
      (-10864813831*CF^2*NC)/349920000 - (9*CF^2*lm*NC)/800 - 
       (21007793549*CF*NM*NC)/2000376000 + (CF*lm*NM*NC)/800 - 
       (43361*CF*NC*NL)/43200 + (CF*lm*NC*NL)/800 - (81967377167*CF*NC*NH)/
        3000564000 + (CF*lm*NC*NH)/800 - (280619*CF^2*NC*Pi^2)/60480 - 
       (47*CF*NM*NC*Pi^2)/180 + (19*CF*NC*NL*Pi^2)/1080 + 
       (31409*CF^2*NC*Pi^3)/(26244*Sqrt[3]) + (135905*CF*NC*NH*Pi^3)/
        (52488*Sqrt[3]) - (3073733*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (109350*Sqrt[3]) + (20102*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (729*Sqrt[3]) + (17948*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (405*Sqrt[3]) + (7766*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) + 
       (4487*CF^2*NC*Pi*Log[3]^2)/(4860*Sqrt[3]) + 
       (3883*CF*NC*NH*Pi*Log[3]^2)/(1944*Sqrt[3]) - 
       (CF*NC*(21*CA*(-161837 + 52800*lm) + 2*(21*CF*(270319 + 43200*lm) - 
            40*(18*(-31 + 140*lm)*NM + 5*(798*NL + 504*lm*NL + 205*NH + 
                504*lm*NH))))*Log[x]^2)/151200 - 
       (CF*NC*(-2889*CA + 2650*CF + 1920*NM + 80*NL)*Log[x]^3)/90 + 
       (9*CF^2*NC*PolyGamma[2, 1])/2 - (20*CF*NM*NC*PolyGamma[2, 1])/9 - 
       (31*CF*NC*NH*PolyGamma[2, 1])/9 - 
       (CF*NC*Log[x]*(80*(13230*NL*(-337 + 273*lm + 90*lm^2 - 90*Pi^2) + 
            9*NM*(-13448069 + 401310*lm + 132300*lm^2 + 4806900*Pi^2) + 
            NH*(-135717597 + 3611790*lm + 1190700*lm^2 + 76106800*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) + 98*CF*(-566753889 + 4082400*lm - 
            8748000*lm^2 + 70696800*Pi^2 + 28716800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3]) - 
          49*CA*(-501267117 + 46040400*lm + 10692000*lm^2 + 72640800*Pi^2 + 
            28716800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3])))/
        571536000 + (11579*CF^2*NC*Zeta[3])/180 - (13*CF*NM*NC*Zeta[3])/9 + 
       CF*NC*NL*Zeta[3] - (220*CF*NC*NH*Zeta[3])/9 - 
       (CA*CF*NC*(433026*lm - 147363705*Pi^2 + 12563600*Sqrt[3]*Pi^3 + 
          9691920*Sqrt[3]*Pi*Log[3]^2 + 12*(-75789849 - 24589864*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 38767680*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 11809800*
             PolyGamma[2, 1] + 163573020*Zeta[3])))/62985600, 
      (CF*NC*(-149057820133459083*CF + 171180111915149040*NM - 
         29827593233499600*NL - 523552088145198960*NH - 
         17467524420192000*CF*Pi^2 - 110866518987840000*NM*Pi^2 + 
         479250082080000*NL*Pi^2 + 8104245986760000*Sqrt[3]*CF*Pi^3 + 
         18920005812400000*Sqrt[3]*NH*Pi^3 + 215662536936000*CF*Pi^4 - 
         78248778123700800*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         34498993562880000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         17253002954880000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         300088651395456000*Sqrt[3]*CF*Im[PolyLog[3, 
            -((-1)^(5/6)/Sqrt[3])]] + 700580786653440000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6251846904072000*Sqrt[3]*CF*
          Pi*Log[3]^2 + 14595433055280000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         62240270400*(77*CA*(71629 + 39600*lm) + 16*(231*CF*(719 + 1350*lm) - 
             5*(11*(-23153 + 630*lm)*NM + 10*(231*(4 + 3*lm)*NL + 
                 (314 + 693*lm)*NH))))*Log[x]^2 + 63900010944000*
          (4049*CA + 8*(1579*CF - 45*(50*NM + NL)))*Log[x]^3 + 
         43132507387200000*CF*PolyGamma[2, 1] - 14856752544480000*NM*
          PolyGamma[2, 1] - 23483254021920000*NH*PolyGamma[2, 1] + 
         166320*Log[x]*(-20*(2401245*NL*(-3487 + 1200*lm + 360*lm^2 - 600*
                Pi^2) + 16335*NM*(-18167027 + 176400*lm + 52920*lm^2 + 
               5309640*Pi^2) + NH*(-125789175753 + 2881494000*lm + 864448200*
                lm^2 + 70204103200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
           17787*CF*(-146505813 + 1458000*lm - 8748000*lm^2 + 12873600*Pi^2 + 
             33812800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             23328000*Zeta[3]) + 71148*CA*(-10412301 + 6156000*lm + 
             1336500*lm^2 + 1609200*Pi^2 + 4226600*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 2916000*Zeta[3])) + 141346824208128000*CF*
          Zeta[3] + 367105562873280000*NM*Zeta[3] + 28755004924800000*NL*
          Zeta[3] - 250168542845760000*NH*Zeta[3] - 
         1565256*CA*(-5561996625*Pi^2 + 2588792500*Sqrt[3]*Pi^3 + 
           68890500*Pi^4 + 1997068500*Sqrt[3]*Pi*Log[3]^2 - 
           126*(198377150*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             43740000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 9*(-42122011 + 84532000*
                Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 12150000*
                PolyGamma[2, 1] + 39816000*Zeta[3])))))/8626501477440000, 
      (16299117387979*CF^2*NC)/288054144000 - (11*CF^2*lm*NC)/1800 + 
       (58127084691343*CF*NM*NC)/11981252052000 + (11*CF*lm*NM*NC)/16200 - 
       (496307*CF*NC*NL)/388800 + (11*CF*lm*NC*NL)/16200 - 
       (627562212403691*CF*NC*NH)/17971878078000 + (11*CF*lm*NC*NH)/16200 - 
       (9219307*CF^2*NC*Pi^2)/302400 - (1537*CF*NM*NC*Pi^2)/270 + 
       (29*CF*NC*NL*Pi^2)/1620 + (956165*CF^2*NC*Pi^3)/(629856*Sqrt[3]) + 
       (1621585*CF*NC*NH*Pi^3)/(472392*Sqrt[3]) - 
       (1703699*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(52488*Sqrt[3]) + 
       (564802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
       (27319*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(486*Sqrt[3]) + 
       (92662*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (729*Sqrt[3]) + (27319*CF^2*NC*Pi*Log[3]^2)/(23328*Sqrt[3]) + 
       (46331*CF*NC*NH*Pi*Log[3]^2)/(17496*Sqrt[3]) - 
       (CF*NC*(165*CA*(-2686829 + 129360*lm) + 
          4*(33*CF*(7376777 + 264600*lm) - 10*((-4076683 + 97020*lm)*NM + 
              13860*(11 + 7*lm)*NL + (40757 + 97020*lm)*NH)))*Log[x]^2)/
        2494800 - (CF*NC*(-28461*CA + 8*(5637*CF + 2230*NM + 35*NL))*
         Log[x]^3)/270 + (11*CF^2*NC*PolyGamma[2, 1])/2 - 
       (77*CF*NM*NC*PolyGamma[2, 1])/27 - (110*CF*NC*NH*PolyGamma[2, 1])/
        27 - (CF*NC*Log[x]*(5*(4*(7203735*NL*(-2159 + 1088*lm + 360*lm^2 - 
                440*Pi^2) + 45*NM*(-21561451811 + 174170304*lm + 
                57629880*lm^2 + 6025524120*Pi^2) + NH*(-390384828501 + 
                7837663680*lm + 2593344600*lm^2 + 219757199200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 363*CF*(-36001150329 + 
              122880240*lm - 257191200*lm^2 + 8261394120*Pi^2 + 
              1070904800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              685843200*Zeta[3])) - 363*CA*(-84964986417 + 3375237600*lm + 
            785862000*lm^2 + 20828121300*Pi^2 + 2677262000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1714608000*Zeta[3])))/
        311201352000 + CA*CF*NC*(-21329012024471/720135360000 - 
         (121*lm)/32400 + (865423*Pi^2)/56700 - (956165*Pi^3)/
          (1259712*Sqrt[3]) + (1703699*Im[PolyLog[2, (-1)^(1/3)]])/
          (104976*Sqrt[3]) - (27319*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (972*Sqrt[3]) - (27319*Pi*Log[3]^2)/(46656*Sqrt[3]) - 
         (11*PolyGamma[2, 1])/4 - (77227*Zeta[3])/1080) + 
       (78547*CF^2*NC*Zeta[3])/540 + (461*CF*NM*NC*Zeta[3])/27 + 
       (11*CF*NC*NL*Zeta[3])/9 - (86*CF*NC*NH*Zeta[3])/3, 
      (CF*NC*(-63111634185600*(1001*CA*(-64709 + 277200*lm) + 
           2*(1001*CF*(686599 + 226800*lm) - 40*(26*(-4919443 + 24255*lm)*
                NM + 7*(2145*(55 + 42*lm)*NL + 2*(21514 + 45045*lm)*NH))))*
          Log[x]^2 + 30323877993497088000*(1371*CA + 1783*CF - 11380*NM - 
           70*NL)*Log[x]^3 + 2162160*Log[x]*
          (-2*(80*(13689*NM*(-49882031113 + 160083000*lm + 48024900*lm^2 + 
                 18249462000*Pi^2) - 7*(626107482*NL*(1947 - 500*lm - 
                   150*lm^2 + 300*Pi^2) - NH*(-17056099700859 + 313053741000*
                    lm + 93916122300*lm^2 + 9555768622400*Sqrt[3]*
                    Im[PolyLog[2, (-1)^(1/3)]]))) + 9018009*CF*
              (-1786358067 + 8748000*lm - 52488000*lm^2 + 315981000*Pi^2 + 
               235314400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 139968000*
                Zeta[3])) + 9018009*CA*(-1407506217 + 295488000*lm + 
             64152000*lm^2 + 315981000*Pi^2 + 235314400*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 139968000*Zeta[3])) - 
         1289575287*CA*(-2921846288400*Pi^2 + 288260140000*Sqrt[3]*Pi^3 + 
           6613488000*Pi^4 + 222372108000*Sqrt[3]*Pi*Log[3]^2 - 
           21*(136031507200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             25194240000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             3*(58450855853 + 169426368000*Sqrt[3]*Im[PolyLog[3, 
                  -((-1)^(5/6)/Sqrt[3])]] + 25194240000*PolyGamma[2, 1] + 
               190084320000*Zeta[3]))) + 
         2*(-320*(533871*NM*(-538266941649491 + 158773777192800*Pi^2 + 
               4326563241000*PolyGamma[2, 1] - 446634451494000*Zeta[3]) - 
             7*(5*NH*(-2251539187836033519 + 83696588421446000*Sqrt[3]*
                  Pi^3 + 84439876691089920*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]] + 3099165102691257600*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 64565939639401200*
                  Sqrt[3]*Pi*Log[3]^2 - 96454299421279800*PolyGamma[2, 1] - 
                 1045767667409665200*Zeta[3]) + 22562409221352*NL*
                (-28751 + 375*Pi^2 + 27000*Zeta[3]))) + 1289575287*CF*
            (-2922889244400*Pi^2 + 288260140000*Sqrt[3]*Pi^3 + 
             6613488000*Pi^4 + 222372108000*Sqrt[3]*Pi*Log[3]^2 - 
             21*(136031507200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               25194240000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3*(58607564483 + 
                 169426368000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                 25194240000*PolyGamma[2, 1] + 190084320000*Zeta[3]))))))/
       682287254853684480000, (797195647130731*CF^2*NC)/1361055830400 - 
       (13*CF^2*lm*NC)/3528 + (1459954832124653173*CF*NM*NC)/
        13161405379122000 + (13*CF*lm*NM*NC)/31752 - 
       (21047903*CF*NC*NL)/13608000 + (13*CF*lm*NC*NL)/31752 - 
       (921366545631722017*CF*NC*NH)/21536845165836000 + 
       (13*CF*lm*NC*NH)/31752 - (320382179*CF^2*NC*Pi^2)/1905120 - 
       (4253*CF*NM*NC*Pi^2)/126 + (41*CF*NC*NL*Pi^2)/2268 + 
       (980020*CF^2*NC*Pi^3)/(531441*Sqrt[3]) + (6132245*CF*NC*NH*Pi^3)/
        (1417176*Sqrt[3]) - (1600466429*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (43401015*Sqrt[3]) + (8613718*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (295245*Sqrt[3]) + (3136064*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(45927*Sqrt[3]) + 
       (350414*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2187*Sqrt[3]) + (196004*CF^2*NC*Pi*Log[3]^2)/(137781*Sqrt[3]) + 
       (175207*CF*NC*NH*Pi*Log[3]^2)/(52488*Sqrt[3]) - 
       (CF*NC*(143*CA*(-159372823 + 1552320*lm) + 
          143*CF*(325055279 + 2540160*lm) - 
          28*((-325941659 + 1441440*lm)*NM + 385*(234*(25 + 16*lm)*NL + 
              (1597 + 3744*lm)*NH)))*Log[x]^2)/22702680 - 
       (CF*NC*(-169321*CA + 318332*CF + 88256*NM + 448*NL)*Log[x]^3)/378 + 
       (13*CF^2*NC*PolyGamma[2, 1])/2 - (94*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (127*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-32059870513395661/108884466432000 - (143*lm)/63504 + 
         (213637439*Pi^2)/2540160 - (490010*Pi^3)/(531441*Sqrt[3]) + 
         (1600466429*Im[PolyLog[2, (-1)^(1/3)]])/(86802030*Sqrt[3]) - 
         (1568032*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(45927*Sqrt[3]) - 
         (98002*Pi*Log[3]^2)/(137781*Sqrt[3]) - (13*PolyGamma[2, 1])/4 - 
         (62105*Zeta[3])/252) + (6941*CF^2*NC*Zeta[3])/14 + 
       (2617*CF*NM*NC*Zeta[3])/27 + (13*CF*NC*NL*Zeta[3])/9 - 
       (296*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((56782313976329*NM*NC)/
          292183491600 - (95*lm*NM*NC)/189 - (lm^2*NM*NC)/6 + 
         (14809*NC*NL)/10800 - (95*lm*NC*NL)/189 - (lm^2*NC*NL)/6 + 
         (7543006819409*NC*NH)/239059220400 - (95*lm*NC*NH)/189 - 
         (lm^2*NC*NH)/6 - (3211*NM*NC*Pi^2)/54 + (13*NC*NL*Pi^2)/54 - 
         (350414*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
         CA*NC*(-749520229441/3086294400 + (743*lm)/189 + (11*lm^2)/12 + 
           (82907*Pi^2)/756 + (1568032*Im[PolyLog[2, (-1)^(1/3)]])/
            (137781*Sqrt[3]) - 2*Zeta[3]) + CF*NC*(336265978891/675126900 - 
           (61*lm)/84 + (3*lm^2)/2 - (27575*Pi^2)/126 - 
           (3136064*Im[PolyLog[2, (-1)^(1/3)]])/(137781*Sqrt[3]) + 
           4*Zeta[3])), (25976928869179973*CF^2*NC)/136105583040000 + 
       (987721958435857643*CF*NM*NC)/584951350183200 - 
       (26782633*CF*NC*NL)/5292000 - (20730024426972390631*CF*NC*NH)/
        236905296824196000 - (88876727*CF^2*NC*Pi^2)/1587600 - 
       (19993*CF*NM*NC*Pi^2)/45 + (CF*NC*NL*Pi^2)/18 + 
       (7883069*CF^2*NC*Pi^3)/(2125764*Sqrt[3]) + (21209965*CF*NC*NH*Pi^3)/
        (2125764*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (65228707633*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1736040600*Sqrt[3]) + (221164*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (59049*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (31532276*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (229635*Sqrt[3]) + (2423996*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) + 
       (7883069*CF^2*NC*Pi*Log[3]^2)/(2755620*Sqrt[3]) + 
       (605999*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) - 
       (CF*NC*(143*CA*(-70707943 + 7761600*lm) + 
          4*(143*CF*(44058419 + 3175200*lm) - 140*(630*(-570937 + 572*lm)*
               NM + 15015*(31 + 24*lm)*NL + (178679 + 360360*lm)*NH)))*
         Log[x]^2)/37837800 - 
       (CF*NC*(-57649*CA + 8*(4376*CF + 90545*NM + 140*NL))*Log[x]^3)/315 + 
       7*CF^2*NC*PolyGamma[2, 1] - (47*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (65*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-12986649161482279/136105583040000 + (19749431*Pi^2)/
          705600 - (7883069*Pi^3)/(4251528*Sqrt[3]) - Pi^4/80 + 
         (65228707633*Im[PolyLog[2, (-1)^(1/3)]])/(3472081200*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (15766138*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(229635*Sqrt[3]) - 
         (7883069*Pi*Log[3]^2)/(5511240*Sqrt[3]) - (7*PolyGamma[2, 1])/2 - 
         (1157*Zeta[3])/14) + (1157*CF^2*NC*Zeta[3])/7 + 
       (10039*CF*NM*NC*Zeta[3])/9 + (14*CF*NC*NL*Zeta[3])/3 - 
       (119*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((15894510038087*NM*NC)/
          16232416200 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (205031*NC*NL)/37800 - (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + 
         (288255311502329*NC*NH)/3944477136600 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (5177*NM*NC*Pi^2)/9 + (7*NC*NL*Pi^2)/9 - 
         (2423996*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CA*NC*(-3080502264331/27005076000 + (76*lm)/9 + (11*lm^2)/6 + 
           (1391*Pi^2)/36 + (15766138*Im[PolyLog[2, (-1)^(1/3)]])/
            (688905*Sqrt[3]) - 4*Zeta[3]) + 
         CF*NC*(6745576831067/27005076000 - lm/2 + 3*lm^2 - (1391*Pi^2)/18 - 
           (31532276*Im[PolyLog[2, (-1)^(1/3)]])/(688905*Sqrt[3]) + 
           8*Zeta[3])), (9431281586988054657931*CF^2*NC)/
        2608654046777856000 - (15*CF^2*lm*NC)/6272 + 
       (95639596186170803321*CF*NM*NC)/140388324043968000 + 
       (5*CF*lm*NM*NC)/18816 - (7687021*CF*NC*NL)/4233600 + 
       (5*CF*lm*NC*NL)/18816 - (18074599182648023711*CF*NC*NH)/
        355357945236294000 + (5*CF*lm*NC*NH)/18816 - 
       (1380301583*CF^2*NC*Pi^2)/1451520 - (1338251*CF*NM*NC*Pi^2)/7560 + 
       (55*CF*NC*NL*Pi^2)/3024 + (1330809445*CF^2*NC*Pi^3)/
        (612220032*Sqrt[3]) + (22385825*CF*NC*NH*Pi^3)/(4251528*Sqrt[3]) - 
       (42186871637*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1020366720*Sqrt[3]) + (25772162*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) + 
       (38023127*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (472392*Sqrt[3]) + (1279190*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) + 
       (38023127*CF^2*NC*Pi*Log[3]^2)/(22674816*Sqrt[3]) + 
       (639595*CF*NC*NH*Pi*Log[3]^2)/(157464*Sqrt[3]) + 
       CF*((-26650826509*CF*NC)/2328480 + CA*(26546935249/4656960 - 11*lm)*
          NC - 18*CF*lm*NC - (229302977*NM*NC)/108108 + 2*lm*NM*NC + 
         (28*NC*NL)/9 + 2*lm*NC*NL + (38713*NC*NH)/45045 + 2*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-572213*CA + 16*(70510*CF + 15386*NM + 21*NL))*
         Log[x]^3)/252 + (15*CF^2*NC*PolyGamma[2, 1])/2 - 
       (37*CF*NM*NC*PolyGamma[2, 1])/9 - (16*CF*NC*NH*PolyGamma[2, 1])/3 + 
       CA*CF*NC*(-9440878302360171545341/5217308093555712000 - 
         (55*lm)/37632 + (51124349*Pi^2)/107520 - (1330809445*Pi^3)/
          (1224440064*Sqrt[3]) + (42186871637*Im[PolyLog[2, (-1)^(1/3)]])/
          (2040733440*Sqrt[3]) - 
         (38023127*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(944784*Sqrt[3]) - 
         (38023127*Pi*Log[3]^2)/(45349632*Sqrt[3]) - (15*PolyGamma[2, 1])/4 - 
         (2341573*Zeta[3])/2016) + (2344933*CF^2*NC*Zeta[3])/1008 + 
       (4183*CF*NM*NC*Zeta[3])/9 + (5*CF*NC*NL*Zeta[3])/3 - 
       (334*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((29108658290821*NM*NC)/
          48697248600 - (253*lm*NM*NC)/504 - (lm^2*NM*NC)/6 + 
         (26321*NC*NL)/15120 - (253*lm*NC*NL)/504 - (lm^2*NC*NL)/6 + 
         (60486399210323*NC*NH)/1577790854640 - (253*lm*NC*NH)/504 - 
         (lm^2*NC*NH)/6 - (491*NM*NC*Pi^2)/2 + (5*NC*NL*Pi^2)/18 - 
         (1279190*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CA*NC*(-173017545026353/294085277640 + (3959*lm)/1008 + 
           (11*lm^2)/12 + (759481*Pi^2)/1344 + 
           (38023127*Im[PolyLog[2, (-1)^(1/3)]])/(2834352*Sqrt[3]) - 
           2*Zeta[3]) + CF*NC*(11195734117734871/9410728884480 - (41*lm)/56 + 
           (3*lm^2)/2 - (2277323*Pi^2)/2016 - 
           (38023127*Im[PolyLog[2, (-1)^(1/3)]])/(1417176*Sqrt[3]) + 
           4*Zeta[3])), (1237087645615681639*CF^2*NC)/1088844664320000 + 
       (1381201167664216321127*CF*NM*NC)/140388324043968000 - 
       (868673371*CF*NC*NL)/148176000 - (152943961647297193529488559*CF*NC*
         NH)/1508434777393268332608000 - (163558708009*CF^2*NC*Pi^2)/
        558835200 - (268246*CF*NM*NC*Pi^2)/105 + (CF*NC*NL*Pi^2)/18 + 
       (93852211*CF^2*NC*Pi^3)/(22674816*Sqrt[3]) + 
       (168930020*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (1187181918493*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (27776649600*Sqrt[3]) - (269356144*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) + 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (93852211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (612360*Sqrt[3]) + (77225152*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) + 
       (93852211*CF^2*NC*Pi*Log[3]^2)/(29393280*Sqrt[3]) + 
       (4826572*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) + 
       CF*((-7421698933*CF*NC)/2116800 + CA*(7108378093/4233600 - 33*lm)*NC - 
         54*CF*lm*NC - (3313318565*NM*NC)/108108 + 6*lm*NM*NC + 
         (23*NC*NL)/3 + 6*lm*NC*NL + (208261*NC*NH)/68068 + 6*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-482913*CA + 767446*CF + 840*(9028*NM + 3*NL))*
         Log[x]^3)/630 + 8*CF^2*NC*PolyGamma[2, 1] - 
       (55*CF*NM*NC*PolyGamma[2, 1])/18 - (73*CF*NC*NH*PolyGamma[2, 1])/
        18 + CA*CF*NC*(-1237065858603656539/2177689328640000 + 
         (4956290953*Pi^2)/33868800 - (93852211*Pi^3)/(45349632*Sqrt[3]) - 
         Pi^4/80 + (1187181918493*Im[PolyLog[2, (-1)^(1/3)]])/
          (55553299200*Sqrt[3]) - Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (93852211*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1224720*Sqrt[3]) - 
         (93852211*Pi*Log[3]^2)/(58786560*Sqrt[3]) - 4*PolyGamma[2, 1] - 
         (752711*Zeta[3])/2016) + (752711*CF^2*NC*Zeta[3])/1008 + 
       (53813*CF*NM*NC*Zeta[3])/9 + (16*CF*NC*NL*Zeta[3])/3 - 
       45*CF*NC*NH*Zeta[3] + CF*Log[x]*((467658725140813*NM*NC)/
          194788994400 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (1725523*NC*NL)/264600 - (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + 
         (2119146828289999919*NC*NH)/24623004077511840 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (27088*NM*NC*Pi^2)/9 + (8*NC*NL*Pi^2)/9 - 
         (77225152*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CA*NC*(-99259606070099/288054144000 + (76*lm)/9 + (11*lm^2)/6 + 
           (246769*Pi^2)/1344 + (93852211*Im[PolyLog[2, (-1)^(1/3)]])/
            (3674160*Sqrt[3]) - 4*Zeta[3]) + 
         CF*NC*(102376997267579/144027072000 - lm/2 + 3*lm^2 - 
           (246769*Pi^2)/672 - (93852211*Im[PolyLog[2, (-1)^(1/3)]])/
            (1837080*Sqrt[3]) + 8*Zeta[3])), 
      (13271154288958771534191059*CF^2*NC)/614058529368316032000 - 
       (17*CF^2*lm*NC)/10368 + (298488495896649420669199*CF*NM*NC)/
        79583981080155552000 + (17*CF*lm*NM*NC)/93312 - 
       (8337740303*CF*NC*NL)/4000752000 + (17*CF*lm*NC*NL)/93312 - 
       (267609898454451710118586171*CF*NC*NH)/4525304332179804997824000 + 
       (17*CF*lm*NC*NH)/93312 - (407432416177*CF^2*NC*Pi^2)/71850240 - 
       (64494629*CF*NM*NC*Pi^2)/68040 + (71*CF*NC*NL*Pi^2)/3888 + 
       (323663900*CF^2*NC*Pi^3)/(129140163*Sqrt[3]) + 
       (6448947085*CF*NC*NH*Pi^3)/(1033121304*Sqrt[3]) - 
       (1096578581*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
       (14325583078*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (502211745*Sqrt[3]) + (147960640*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (368511262*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) + (9247540*CF^2*NC*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       (184255631*CF*NC*NH*Pi*Log[3]^2)/(38263752*Sqrt[3]) - 
       (CF*NC*(51*CA*(-1765274666509 + 634233600*lm) + 
          34*CF*(5299678078327 + 1556755200*lm) - 
          96*(104*(-3014261947 + 589050*lm)*NM + 
            45*(68068*(31 + 20*lm)*NL + (586983 + 1361360*lm)*NH)))*
         Log[x]^2)/2646483840 - (CF*NC*(-4155323*CA + 8285940*CF + 
          1523904*NM + 480*NL)*Log[x]^3)/324 + (17*CF^2*NC*PolyGamma[2, 1])/
        2 - (128*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (161*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-26547470654962169600071063/2456234117473264128000 - 
         (187*lm)/186624 + (7407912007*Pi^2)/2612736 - (161831950*Pi^3)/
          (129140163*Sqrt[3]) + (1096578581*Im[PolyLog[2, (-1)^(1/3)]])/
          (47829690*Sqrt[3]) - (73980320*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
         (4623770*Pi*Log[3]^2)/(4782969*Sqrt[3]) - (17*PolyGamma[2, 1])/4 - 
         (8349293*Zeta[3])/1296) + (8351741*CF^2*NC*Zeta[3])/648 + 
       (62753*CF*NM*NC*Zeta[3])/27 + (17*CF*NC*NL*Zeta[3])/9 - 
       (124*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((24237898398323971*NM*NC)/
          12990927549600 - (325*lm*NM*NC)/648 - (lm^2*NM*NC)/6 + 
         (3348547*NC*NL)/1587600 - (325*lm*NC*NL)/648 - (lm^2*NC*NL)/6 + 
         (50304016191669287587*NC*NH)/1108035183488032800 - 
         (325*lm*NC*NH)/648 - (lm^2*NC*NH)/6 - (63575*NM*NC*Pi^2)/54 + 
         (17*NC*NL*Pi^2)/54 - (368511262*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CA*NC*(-102492934161788597929/
            122689016856806400 + (5087*lm)/1296 + (11*lm^2)/12 + 
           (461293*Pi^2)/144 + (73980320*Im[PolyLog[2, (-1)^(1/3)]])/
            (4782969*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(103334087302961851123/61344508428403200 - (53*lm)/72 + 
           (3*lm^2)/2 - (1383743*Pi^2)/216 - 
           (147960640*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
           4*Zeta[3])), (11691438699770394343*CF^2*NC)/1837425371040000 + 
       (20266695258426189258461219*CF*NM*NC)/344863918014007392000 - 
       (17773683199*CF*NC*NL)/2667168000 - (5379812629449540599603099357017*
         CF*NC*NH)/46558593621631923720112224000 - 
       (676938452893*CF^2*NC*Pi^2)/419126400 - (2162163*CF*NM*NC*Pi^2)/140 + 
       (CF*NC*NL*Pi^2)/18 + (6285375307*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) + 
       (260630405*CF*NC*NH*Pi^3)/(19131876*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (8980049695609*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (187492384800*Sqrt[3]) - (11544469999*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1506635235*Sqrt[3]) + 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (6285375307*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (37200870*Sqrt[3]) + (29786332*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) + 
       (6285375307*CF^2*NC*Pi*Log[3]^2)/(1785641760*Sqrt[3]) + 
       (7446583*CF*NC*NH*Pi*Log[3]^2)/(708588*Sqrt[3]) + 
       CF*((-30759873601*CF*NC)/1587600 + CA*(30498792151/3175200 - 
           (110*lm)/3)*NC - 60*CF*lm*NC - (425733296543*NM*NC)/2297295 + 
         (20*lm*NM*NC)/3 + (76*NC*NL)/9 + (20*lm*NC*NL)/3 + 
         (30331346*NC*NH)/8729721 + (20*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-10958861*CA + 8*(2604659*CF + 1575*(15586*NM + NL)))*
         Log[x]^3)/2835 + 9*CF^2*NC*PolyGamma[2, 1] - 
       (7*CF*NM*NC*PolyGamma[2, 1])/2 - (9*CF*NC*NH*PolyGamma[2, 1])/2 + 
       CA*CF*NC*(-46765640330382369187/14699402968320000 + 
         (676937815753*Pi^2)/838252800 - (6285375307*Pi^3)/
          (2754990144*Sqrt[3]) - Pi^4/80 + 
         (8980049695609*Im[PolyLog[2, (-1)^(1/3)]])/(374984769600*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (6285375307*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74401740*Sqrt[3]) - (6285375307*Pi*Log[3]^2)/
          (3571283520*Sqrt[3]) - (9*PolyGamma[2, 1])/2 - 
         (322871*Zeta[3])/168) + (322871*CF^2*NC*Zeta[3])/84 + 
       34591*CF*NM*NC*Zeta[3] + 6*CF*NC*NL*Zeta[3] - 
       (151*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*((6847913712539657*NM*NC)/
          3752934625440 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (8063141*NC*NL)/1058400 - (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + 
         (1473224840628345757741*NC*NH)/14814840786636290400 - 
         (10*lm*NC*NH)/9 - (lm^2*NC*NH)/3 - (51955*NM*NC*Pi^2)/3 + 
         NC*NL*Pi^2 - (29786332*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (177147*Sqrt[3]) + CA*NC*(-18413160290415713/17499289248000 + 
           (76*lm)/9 + (11*lm^2)/6 + (8686045*Pi^2)/9072 + 
           (6285375307*Im[PolyLog[2, (-1)^(1/3)]])/(223205220*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(18602536652193953/8749644624000 - lm/2 + 
           3*lm^2 - (8686045*Pi^2)/4536 - 
           (6285375307*Im[PolyLog[2, (-1)^(1/3)]])/(111602610*Sqrt[3]) + 
           8*Zeta[3])), (1105113378050190113979711101*CF^2*NC)/
        8289790146472266432000 - (19*CF^2*lm*NC)/16200 + 
       (18612536241450591605263911781*CF*NM*NC)/887033105121778763148000 + 
       (19*CF*lm*NM*NC)/145800 - (12546276727*CF*NC*NL)/5334336000 + 
       (19*CF*lm*NC*NL)/145800 - (314635151822295437157920006509*CF*NC*NH)/
        4655859362163192372011222400 + (19*CF*lm*NC*NH)/145800 - 
       (39852315673*CF^2*NC*Pi^2)/1122660 - (362878219*CF*NM*NC*Pi^2)/
        68040 + (89*CF*NC*NL*Pi^2)/4860 + (11741221807*CF^2*NC*Pi^3)/
        (4132485216*Sqrt[3]) + (7493666215*CF*NC*NH*Pi^3)/
        (1033121304*Sqrt[3]) - (1138890086981*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22599528525*Sqrt[3]) + 
       (82894255321*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3013270470*Sqrt[3]) + (1677317401*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(15943230*Sqrt[3]) + 
       (428209498*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) + (1677317401*CF^2*NC*Pi*Log[3]^2)/
        (765275040*Sqrt[3]) + (214104749*CF*NC*NH*Pi*Log[3]^2)/
        (38263752*Sqrt[3]) - 
       (CF*NC*(323*CA*(-41445408955207 + 2616213600*lm) + 
          4*(323*CF*(20725352206759 + 1070269200*lm) - 
            30*((-33520210102381 + 1280359080*lm)*NM + 
              9*(12932920*(17 + 11*lm)*NL + (61415051 + 142262120*lm)*
                 NH))))*Log[x]^2)/62853991200 - 
       (CF*NC*(-62918603*CA + 40*(3144131*CF + 506424*NM + 33*NL))*
         Log[x]^3)/810 + (19*CF^2*NC*PolyGamma[2, 1])/2 - 
       (145*CF*NM*NC*PolyGamma[2, 1])/27 - (178*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-22103051936572918287449725537/
          331591605858890657280000 - (209*lm)/291600 + (637637733067*Pi^2)/
          35925120 - (11741221807*Pi^3)/(8264970432*Sqrt[3]) + 
         (1138890086981*Im[PolyLog[2, (-1)^(1/3)]])/(45199057050*Sqrt[3]) - 
         (1677317401*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (31886460*Sqrt[3]) - (1677317401*Pi*Log[3]^2)/
          (1530550080*Sqrt[3]) - (19*PolyGamma[2, 1])/4 - 
         (13993967*Zeta[3])/360) + (4664909*CF^2*NC*Zeta[3])/60 + 
       (336769*CF*NM*NC*Zeta[3])/27 + (19*CF*NC*NL*Zeta[3])/9 - 
       (410*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((135334072439665202657*NM*NC)/
          24386569196109120 - (203*lm*NM*NC)/405 - (lm^2*NM*NC)/6 + 
         (1048577*NC*NL)/423360 - (203*lm*NC*NL)/405 - (lm^2*NC*NL)/6 + 
         (8433896558829508446637*NC*NH)/160000280495671936320 - 
         (203*lm*NC*NH)/405 - (lm^2*NC*NH)/6 - (337705*NM*NC*Pi^2)/54 + 
         (19*NC*NL*Pi^2)/54 - (428209498*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CA*NC*(64879476896879392469/10954376505072000 + 
           (1589*lm)/405 + (11*lm^2)/12 + (125817073*Pi^2)/6480 + 
           (1677317401*Im[PolyLog[2, (-1)^(1/3)]])/(95659380*Sqrt[3]) - 
           2*Zeta[3]) + CF*NC*(-453603886594730245709/38340317767752000 - 
           (133*lm)/180 + (3*lm^2)/2 - (125814793*Pi^2)/3240 - 
           (1677317401*Im[PolyLog[2, (-1)^(1/3)]])/(47829690*Sqrt[3]) + 
           4*Zeta[3])), (8712529907884594412407*CF^2*NC)/238130328086784000 + 
       (432300689267173203540730968661*CF*NM*NC)/1182710806829038350864000 - 
       (716802637*CF*NC*NL)/96018048 - (1485007036190725135275677291183*CF*
         NC*NH)/11428018434400563094936636800 - (1136068605167*CF^2*NC*Pi^2)/
        121080960 - (277064201*CF*NM*NC*Pi^2)/2835 + (CF*NC*NL*Pi^2)/18 + 
       (7719229835*CF^2*NC*Pi^3)/(1549681956*Sqrt[3]) + 
       (18039985355*CF*NC*NH*Pi^3)/(1162261467*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (805494956957113*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15186883168800*Sqrt[3]) - 
       (583615586572*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (40679151345*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (6175383868*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (33480783*Sqrt[3]) + (8246850448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) + 
       (1543845967*CF^2*NC*Pi*Log[3]^2)/(401769396*Sqrt[3]) + 
       (515428153*CF*NC*NH*Pi*Log[3]^2)/(43046721*Sqrt[3]) + 
       CF*((-22342692101*CF*NC)/198450 + CA*(89227180169/1587600 - 
           (121*lm)/3)*NC - 66*CF*lm*NC - (51188868194333*NM*NC)/43648605 + 
         (22*lm*NM*NC)/3 + (83*NC*NL)/9 + (22*lm*NC*NL)/3 + 
         (2204663*NC*NH)/566865 + (22*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-60885269*CA + 4*(30121177*CF + 315*(956438*NM + 11*NL)))*
         Log[x]^3)/2835 + 10*CF^2*NC*PolyGamma[2, 1] - 
       (71*CF*NM*NC*PolyGamma[2, 1])/18 - (89*CF*NC*NH*PolyGamma[2, 1])/
        18 + CA*CF*NC*(-8712526937497682750881/476260656173568000 + 
         (262169644397*Pi^2)/55883520 - (7719229835*Pi^3)/
          (3099363912*Sqrt[3]) - Pi^4/80 + (805494956957113*
           Im[PolyLog[2, (-1)^(1/3)]])/(30373766337600*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (3087691934*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33480783*Sqrt[3]) - (1543845967*Pi*Log[3]^2)/(803538792*Sqrt[3]) - 
         5*PolyGamma[2, 1] - (60817447*Zeta[3])/5670) + 
       (60817447*CF^2*NC*Zeta[3])/2835 + (1912429*CF*NM*NC*Zeta[3])/9 + 
       (20*CF*NC*NL*Zeta[3])/3 - (167*CF*NC*NH*Zeta[3])/3 + 
       CF*Log[x]*((-114087406467310200917*NM*NC)/2540267624594700 - 
         (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + (8301673*NC*NL)/952560 - 
         (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + (462986820091944640069*NC*NH)/
          4090916262673430190 - (10*lm*NC*NH)/9 - (lm^2*NC*NH)/3 - 
         (956444*NM*NC*Pi^2)/9 + (10*NC*NL*Pi^2)/9 - 
         (8246850448*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CA*NC*(-429914282754869669/157493603232000 + (76*lm)/9 + 
           (11*lm^2)/6 + (30386831*Pi^2)/5670 + 
           (3087691934*Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(431618677417980389/78746801616000 - lm/2 + 
           3*lm^2 - (30386831*Pi^2)/2835 - 
           (6175383868*Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) + 
           8*Zeta[3])), (18772678005881945710169942797515463*CF^2*NC)/
        21992979054393852289424640000 - (21*CF^2*lm*NC)/24200 + 
       (288893496044904970861055127877*CF*NM*NC)/2365421613658076701728000 + 
       (7*CF*lm*NM*NC)/72600 - (2174001437191*CF*NC*NL)/829870272000 + 
       (7*CF*lm*NC*NL)/72600 - (95753622254599831985650248980183*CF*NC*NH)/
        1257082027784061940443030048000 + (7*CF*lm*NC*NH)/72600 - 
       (65984593299283*CF^2*NC*Pi^2)/285405120 - (7856440621*CF*NM*NC*Pi^2)/
        249480 + (109*CF*NC*NL*Pi^2)/5940 + (121892695295*CF^2*NC*Pi^3)/
        (38354628411*Sqrt[3]) + (77133964985*CF*NC*NH*Pi^3)/
        (9298091736*Sqrt[3]) - (811597559346683*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(14766531938235*Sqrt[3]) + 
       (303262542683*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (11622614670*Sqrt[3]) + (55722374992*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(473513931*Sqrt[3]) + 
       (4407655142*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) + (3482648437*CF^2*NC*Pi*Log[3]^2)/
        (1420541793*Sqrt[3]) + (2203827571*CF*NC*NH*Pi*Log[3]^2)/
        (344373768*Sqrt[3]) - 
       (CF*NC*(10944*CA*(-4868636775242 + 51476425*lm) + 
          19*CF*(5608789542587981 + 48518870400*lm) - 
          220*((-65977786931443 + 465585120*lm)*NM + 
            385*(50388*(37 + 24*lm)*NL + (522073 + 1209312*lm)*NH)))*
         Log[x]^2)/38410772400 - (CF*NC*(-489368405*CA + 
          176*(5560429*CF + 801745*NM + 10*NL))*Log[x]^3)/990 + 
       (21*CF^2*NC*PolyGamma[2, 1])/2 - 6*CF*NM*NC*PolyGamma[2, 1] - 
       (65*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-103250365373019977674613455970369773/
          241922769598332375183671040000 - (7*lm)/13200 + 
         (126893469413*Pi^2)/1097712 - (121892695295*Pi^3)/
          (76709256822*Sqrt[3]) + (811597559346683*
           Im[PolyLog[2, (-1)^(1/3)]])/(29533063876470*Sqrt[3]) - 
         (27861187496*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (473513931*Sqrt[3]) - (3482648437*Pi*Log[3]^2)/
          (2841083586*Sqrt[3]) - (21*PolyGamma[2, 1])/4 - 
         (97888393*Zeta[3])/396) + (97889317*CF^2*NC*Zeta[3])/198 + 
       71231*CF*NM*NC*Zeta[3] + (7*CF*NC*NL*Zeta[3])/3 - 
       (448*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*((486819467538865729013*NM*NC)/
          40644281993515200 - (248*lm*NM*NC)/495 - (lm^2*NM*NC)/6 + 
         (3405575*NC*NL)/1197504 - (248*lm*NC*NL)/495 - (lm^2*NC*NL)/6 + 
         (61970516842134034517029*NC*NH)/1028573231757891019200 - 
         (248*lm*NC*NH)/495 - (lm^2*NC*NH)/6 - (641429*NM*NC*Pi^2)/18 + 
         (7*NC*NL*Pi^2)/18 - (4407655142*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CA*NC*(604303801072088090300814941/
            6581728989918914832000 + (353*lm)/90 + (11*lm^2)/12 + 
           (24467753*Pi^2)/198 + (27861187496*Im[PolyLog[2, (-1)^(1/3)]])/
            (1420541793*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-604254058361228332395829763/3290864494959457416000 - 
           (163*lm)/220 + (3*lm^2)/2 - (8155892*Pi^2)/33 - 
           (55722374992*Im[PolyLog[2, (-1)^(1/3)]])/(1420541793*Sqrt[3]) + 
           4*Zeta[3])), (571641291421723119318810223*CF^2*NC)/
        2614849600138953408000 + (5583620407674685374750118660001*CF*NM*NC)/
        2365421613658076701728000 - (24010979218757*CF*NC*NL)/
        2904545952000 - (19898499025168750678933605234429374317*CF*NC*NH)/
        137654253288438134664333119346144000 - (379067607962611*CF^2*NC*Pi^2)/
        6659452800 - (7280849551*CF*NM*NC*Pi^2)/11340 + 
       (CF*NC*NL*Pi^2)/18 + (2207095956887*CF^2*NC*Pi^3)/
        (409116036384*Sqrt[3]) + (730732792195*CF*NC*NH*Pi^3)/
        (41841412812*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (320685066962980003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5512838590274400*Sqrt[3]) - (7910294803553*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) + 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (2207095956887*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (11048658390*Sqrt[3]) + (83512319108*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) + 
       (2207095956887*CF^2*NC*Pi*Log[3]^2)/(530335602720*Sqrt[3]) + 
       (20878079777*CF*NC*NH*Pi*Log[3]^2)/(1549681956*Sqrt[3]) + 
       CF*((-131214382678789*CF*NC)/192099600 + 
         CA*(131176476495859/384199200 - 44*lm)*NC - 72*CF*lm*NC - 
         (336294736512809*NM*NC)/43648605 + 8*lm*NM*NC + 10*NC*NL + 
         8*lm*NC*NL + (1440235306*NC*NH)/334639305 + 8*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-3949524763*CA + 8*(985306522*CF + 
            10395*(1024665*NM + 2*NL)))*Log[x]^3)/31185 + 
       11*CF^2*NC*PolyGamma[2, 1] - (79*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (97*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-1143282529402482809767511123/10459398400555813632000 + 
         (1137202804254373*Pi^2)/39956716800 - (2207095956887*Pi^3)/
          (818232072768*Sqrt[3]) - Pi^4/80 + (320685066962980003*
           Im[PolyLog[2, (-1)^(1/3)]])/(11025677180548800*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (2207095956887*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22097316780*Sqrt[3]) - 
         (2207095956887*Pi*Log[3]^2)/(1060671205440*Sqrt[3]) - 
         (11*PolyGamma[2, 1])/2 - (15794857151*Zeta[3])/249480) + 
       (15794857151*CF^2*NC*Zeta[3])/124740 + (12295487*CF*NM*NC*Zeta[3])/
        9 + (22*CF*NC*NL*Zeta[3])/3 - 61*CF*NC*NH*Zeta[3] + 
       CF*Log[x]*((-11633615997360355138781*NM*NC)/20322140996757600 - 
         (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + (205622009*NC*NL)/20956320 - 
         (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + (436122968371073459021224807*NC*
           NH)/3427926009479523399687840 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (6147997*NM*NC*Pi^2)/9 + (11*NC*NL*Pi^2)/9 - 
         (83512319108*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CA*NC*(-810579220173261169249/
            628871957705376000 + (76*lm)/9 + (11*lm^2)/6 + 
           (15792735311*Pi^2)/498960 + (2207095956887*
             Im[PolyLog[2, (-1)^(1/3)]])/(66291950340*Sqrt[3]) - 4*Zeta[3]) + 
         CF*NC*(817384986196954618369/314435978852688000 - lm/2 + 3*lm^2 - 
           (15792735311*Pi^2)/249480 - (2207095956887*
             Im[PolyLog[2, (-1)^(1/3)]])/(33145975170*Sqrt[3]) + 8*Zeta[3])), 
      (8435319185976749796369746822905411923997*CF^2*NC)/
        1493413449007465585246319697024000 - (23*CF^2*lm*NC)/34848 + 
       (4256479554517097769148782289674731*CF*NM*NC)/
        5756016954675563845984915200 + (23*CF*lm*NM*NC)/313632 - 
       (50316679953851*CF*NC*NL)/17427275712000 + (23*CF*lm*NC*NL)/313632 - 
       (922657079935349238011889552479478917*CF*NC*NH)/
        10867441049087221157710509422064000 + (23*CF*lm*NC*NH)/313632 - 
       (2662268459038477*CF^2*NC*Pi^2)/1712430720 - 
       (144978652039*CF*NM*NC*Pi^2)/748440 + (131*CF*NC*NL*Pi^2)/7128 + 
       (7062533480555*CF^2*NC*Pi^3)/(2008387814976*Sqrt[3]) + 
       (2351369083385*CF*NC*NH*Pi^3)/(251048476872*Sqrt[3]) - 
       (299007745816817*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5020969537440*Sqrt[3]) + (53395521054971*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2196674172630*Sqrt[3]) + 
       (201786670873*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1549681956*Sqrt[3]) + (134363947622*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) + 
       (201786670873*CF^2*NC*Pi*Log[3]^2)/(74384733888*Sqrt[3]) + 
       (67181973811*CF*NC*NH*Pi*Log[3]^2)/(9298091736*Sqrt[3]) + 
       CF*((-20474171336258273*CF*NC)/1097450640 + 
         CA*(61422302388488201/6584703840 - (143*lm)/9)*NC - 26*CF*lm*NC - 
         (1866877594297031*NM*NC)/803134332 + (26*lm*NM*NC)/9 + 
         (40*NC*NL)/9 + (26*lm*NC*NL)/9 + (158047699*NC*NH)/126810684 + 
         (26*lm*NC*NH)/9)*Log[x]^2 - 
       (4*CF*NC*(-242497472*CA + 484986279*CF + 63477535*NM + 143*NL)*
         Log[x]^3)/297 + (23*CF^2*NC*PolyGamma[2, 1])/2 - 
       (179*CF*NM*NC*PolyGamma[2, 1])/27 - (212*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-1687065567070391514597142712549425215233/
          597365379602986234098527878809600 - (23*lm)/57024 + 
         (42258230533331*Pi^2)/54362880 - (7062533480555*Pi^3)/
          (4016775629952*Sqrt[3]) + (299007745816817*
           Im[PolyLog[2, (-1)^(1/3)]])/(10041939074880*Sqrt[3]) - 
         (201786670873*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3099363912*Sqrt[3]) - (201786670873*Pi*Log[3]^2)/
          (148769467776*Sqrt[3]) - (23*PolyGamma[2, 1])/4 - 
         (7760113057*Zeta[3])/4752) + (7760125201*CF^2*NC*Zeta[3])/2376 + 
       (11540315*CF*NM*NC*Zeta[3])/27 + (23*CF*NC*NL*Zeta[3])/9 - 
       54*CF*NC*NH*Zeta[3] + CF*Log[x]*((-1481129253096210031697161*NM*NC)/
          64502475523708622400 - (595*lm*NM*NC)/1188 - (lm^2*NM*NC)/6 + 
         (403698833*NC*NL)/125737920 - (595*lm*NC*NL)/1188 - 
         (lm^2*NC*NL)/6 + (73600383153641163093542273*NC*NH)/
          1082502950361954757796160 - (595*lm*NC*NH)/1188 - 
         (lm^2*NC*NH)/6 - (11541479*NM*NC*Pi^2)/54 + (23*NC*NL*Pi^2)/54 - 
         (134363947622*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CA*NC*(478434629021524093398149297101/
            534600937206163857229200 + (847*lm)/216 + (11*lm^2)/12 + 
           (7759884575*Pi^2)/9504 + (201786670873*Im[PolyLog[2, (-1)^(1/3)]])/
            (9298091736*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-1913721593089873659204941652991/1069201874412327714458400 - 
           (49*lm)/66 + (3*lm^2)/2 - (7759880527*Pi^2)/4752 - 
           (201786670873*Im[PolyLog[2, (-1)^(1/3)]])/(4649045868*Sqrt[3]) + 
           4*Zeta[3])), (14158418842049395348636897249*CF^2*NC)/
        10459398400555813632000 + (45290666473631572392138206008860841*CF*NM*
         NC)/2878008477337781922992457600 - (3017970807529*CF*NC*NL)/
        332812557000 - (949174648718464354081315421873069691349*CF*NC*NH)/
        5956193651903573134514413817862000000 - 
       (595893116393269*CF^2*NC*Pi^2)/1664863200 - 
       (4304761859*CF*NM*NC*Pi^2)/990 + (CF*NC*NL*Pi^2)/18 + 
       (527712448861*CF^2*NC*Pi^3)/(90914674752*Sqrt[3]) + 
       (1830872948485*CF*NC*NH*Pi^3)/(94143178827*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (174457410482445239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2756419295137200*Sqrt[3]) - 
       (1065379495087414*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (36245123848395*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (527712448861*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2455257420*Sqrt[3]) + (836970490736*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) + 
       (527712448861*CF^2*NC*Pi*Log[3]^2)/(117852356160*Sqrt[3]) + 
       (52310655671*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) + 
       CF*((-206270348453821*CF*NC)/48024900 + CA*(8594170099709/4002075 - 
           (143*lm)/3)*NC - 78*CF*lm*NC - (104766708178475723*NM*NC)/
          2007835830 + (26*lm*NM*NC)/3 + (97*NC*NL)/9 + (26*lm*NC*NL)/3 + 
         (3643755277*NC*NH)/772244550 + (26*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-97276299457*CA + 194475620474*CF + 
          55440*(40949092*NM + 13*NL))*Log[x]^3)/124740 + 
       12*CF^2*NC*PolyGamma[2, 1] - (29*CF*NM*NC*PolyGamma[2, 1])/6 - 
       (35*CF*NC*NH*PolyGamma[2, 1])/6 + 
       CA*CF*NC*(-14158418752869337216927976257/20918796801111627264000 + 
         (5363038035302581*Pi^2)/29967537600 - (527712448861*Pi^3)/
          (181829349504*Sqrt[3]) - Pi^4/80 + (174457410482445239*
           Im[PolyLog[2, (-1)^(1/3)]])/(5512838590274400*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (527712448861*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4910514840*Sqrt[3]) - (527712448861*Pi*Log[3]^2)/
          (235704712320*Sqrt[3]) - 6*PolyGamma[2, 1] - (194545599667*Zeta[3])/
          498960) + (194545599667*CF^2*NC*Zeta[3])/249480 + 
       (27299215*CF*NM*NC*Zeta[3])/3 + 8*CF*NC*NL*Zeta[3] - 
       (199*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-4789620735231557345821963*NM*NC)/895867715607064200 - 
         (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + (209555729*NC*NL)/19209960 - 
         (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + (10499217928058273286712770533*
           NC*NH)/74161860782008919704785000 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - 4549900*NM*NC*Pi^2 + (4*NC*NL*Pi^2)/3 - 
         (836970490736*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CA*NC*(9389001089689243348393/
            139749323934528000 + (76*lm)/9 + (11*lm^2)/6 + 
           (194540965807*Pi^2)/997920 + (527712448861*
             Im[PolyLog[2, (-1)^(1/3)]])/(14731544520*Sqrt[3]) - 4*Zeta[3]) + 
         CF*NC*(-9387488663552795654233/69874661967264000 - lm/2 + 3*lm^2 - 
           (194540965807*Pi^2)/498960 - (527712448861*
             Im[PolyLog[2, (-1)^(1/3)]])/(7365772260*Sqrt[3]) + 8*Zeta[3])), 
      (1220760884761173518330677488530628843511427*CF^2*NC)/
        31768977006158813358876255373056000 - (25*CF^2*lm*NC)/48672 + 
       (1389347069639619810983966314847314393*CF*NM*NC)/
        299792549722685616978381000000 + (25*CF*lm*NM*NC)/438048 - 
       (817625476519723*CF*NC*NL)/259178444388864 + (25*CF*lm*NC*NL)/
        438048 - (2074154813083318630385863387703007392291*CF*NC*NH)/
        22123004992784700213910679894916000000 + (25*CF*lm*NC*NH)/438048 - 
       (10859238672343433*CF^2*NC*Pi^2)/1011890880 - 
       (11992630968821*CF*NM*NC*Pi^2)/9729720 + (155*CF*NC*NL*Pi^2)/8424 + 
       (56636164104625*CF^2*NC*Pi^3)/(14686335897012*Sqrt[3]) + 
       (7879910502485*CF*NC*NH*Pi^3)/(753145430616*Sqrt[3]) - 
       (2358065489381246003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (36752555582272530*Sqrt[3]) + (1608093181426357*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(72490247696790*Sqrt[3]) + 
       (6472704469100*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (45328197213*Sqrt[3]) + (450280600142*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) + 
       (1618176117275*CF^2*NC*Pi*Log[3]^2)/(543938366556*Sqrt[3]) + 
       (225140300071*CF*NC*NH*Pi*Log[3]^2)/(27894275208*Sqrt[3]) - 
       (CF*NC*(230*CA*(-438441725754534083 + 116512676280*lm) + 
          115*CF*(1753767845559363617 + 381314213280*lm) - 
          338*(9*(-7614806288726687 + 1601692400*lm)*NM + 
            514829700*(43 + 28*lm)*NL + (6212452331 + 14415231600*lm)*NH))*
         Log[x]^2)/1566111947400 - (CF*NC*(-31212796587*CA + 62425407902*CF + 
          7490845648*NM + 2912*NL)*Log[x]^3)/1404 + 
       (25*CF^2*NC*PolyGamma[2, 1])/2 - (196*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (229*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*(-110978280513888543787655306994660167562937/
          5776177637483420610704773704192000 - (275*lm)/876096 + 
         (10859238710394953*Pi^2)/2023781760 - (56636164104625*Pi^3)/
          (29372671794024*Sqrt[3]) + (2358065489381246003*
           Im[PolyLog[2, (-1)^(1/3)]])/(73505111164545060*Sqrt[3]) - 
         (3236352234550*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (45328197213*Sqrt[3]) - (1618176117275*Pi*Log[3]^2)/
          (1087876733112*Sqrt[3]) - (25*PolyGamma[2, 1])/4 - 
         (100041415*Zeta[3])/9) + (200082880*CF^2*NC*Zeta[3])/9 + 
       (72026203*CF*NM*NC*Zeta[3])/27 + (25*CF*NC*NL*Zeta[3])/9 - 
       (524*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((-11191934907169751210237537*NM*NC)/17720460308711160000 - 
         (703*lm*NM*NC)/1404 - (lm^2*NM*NC)/6 + (64318606241*NC*NL)/
          17980522560 - (703*lm*NC*NL)/1404 - (lm^2*NC*NL)/6 + 
         (585564026791961955267276552391*NC*NH)/
          7712833521328927649297640000 - (703*lm*NC*NH)/1404 - 
         (lm^2*NC*NH)/6 - (72027481*NM*NC*Pi^2)/54 + (25*NC*NL*Pi^2)/54 - 
         (450280600142*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CA*NC*(127637794895084006147588729717539/
            16541701726445268441868800 + (11009*lm)/2808 + (11*lm^2)/12 + 
           (10404258235*Pi^2)/1872 + (3236352234550*Im[PolyLog[2, (-1)^
                (1/3)]])/(135984591639*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-1404014238663981623071664146859849/
            90979359495448976430278400 - (29*lm)/39 + (3*lm^2)/2 - 
           (31212772105*Pi^2)/2808 - (6472704469100*Im[PolyLog[2, (-1)^
                (1/3)]])/(135984591639*Sqrt[3]) + 4*Zeta[3])), 
      (1254930976475510748175080322068467629*CF^2*NC)/
        145183206571081452267766272000 + 
       (387580682114654268834585224108344419557*CF*NM*NC)/
        3597510596672227403740572000000 - (53290677158054729*CF*NC*NL)/
        5399550924768000 - (242991055738358681272651231692006543579367*CF*NC*
         NH)/1393749314545436113476372833379708000000 - 
       (1806718791167570677*CF^2*NC*Pi^2)/779155977600 - 
       (753269498897*CF*NM*NC*Pi^2)/24948 + (CF*NC*NL*Pi^2)/18 + 
       (8026811781667363*CF^2*NC*Pi^3)/(1292397558937056*Sqrt[3]) + 
       (72760055686325*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (15485856622421048596781*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(226395742386798784800*Sqrt[3]) - 
       (12288050751590843*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (326206114635555*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (8026811781667363*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (34902711854010*Sqrt[3]) + (8315434935580*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) + 
       (8026811781667363*CF^2*NC*Pi*Log[3]^2)/(1675330168992480*Sqrt[3]) + 
       (2078858733895*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) + 
       CF*((-301119717551975657*CF*NC)/10821610800 + 
         CA*(301117226352845237/21643221600 - (154*lm)/3)*NC - 84*CF*lm*NC - 
         (1818712657025974019*NM*NC)/5019589575 + (28*lm*NM*NC)/3 + 
         (104*NC*NL)/9 + (28*lm*NC*NL)/3 + (11042158514*NC*NH)/
          2151252675 + (28*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-2014326031639*CA + 8*(503545618306*CF + 
            45045*(140295457*NM + 7*NL)))*Log[x]^3)/405405 + 
       13*CF^2*NC*PolyGamma[2, 1] - (95*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (113*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-313732743856712893339903271691071683/
          72591603285540726133883136000 + (1806718790630003647*Pi^2)/
          1558311955200 - (8026811781667363*Pi^3)/(2584795117874112*
           Sqrt[3]) - Pi^4/80 + (15485856622421048596781*
           Im[PolyLog[2, (-1)^(1/3)]])/(452791484773597569600*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (8026811781667363*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(69805423708020*Sqrt[3]) - 
         (8026811781667363*Pi*Log[3]^2)/(3350660337984960*Sqrt[3]) - 
         (13*PolyGamma[2, 1])/2 - (8057255281373*Zeta[3])/3243240) + 
       (8057255281373*CF^2*NC*Zeta[3])/1621620 + 
       (561181243*CF*NM*NC*Zeta[3])/9 + (26*CF*NC*NL*Zeta[3])/3 - 
       (215*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-12191955673125727028156455639*NM*NC)/268760314682119260000 - 
         (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + (35977343141*NC*NL)/
          2996753760 - (10*lm*NC*NL)/9 - (lm^2*NC*NL)/3 + 
         (37908374415382889884351317071*NC*NH)/242711544377483737215660000 - 
         (10*lm*NC*NH)/9 - (lm^2*NC*NH)/3 - (280590923*NM*NC*Pi^2)/9 + 
         (13*NC*NL*Pi^2)/9 - (8315434935580*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CA*NC*(278958730030655431062773001571/335736500932126790496000 + 
           (76*lm)/9 + (11*lm^2)/6 + (8057222627213*Pi^2)/6486480 + 
           (8026811781667363*Im[PolyLog[2, (-1)^(1/3)]])/(209416271124060*
             Sqrt[3]) - 4*Zeta[3]) + CF*NC*(-2179336691119395143888980397/
            1311470706766120275375 - lm/2 + 3*lm^2 - (8057222627213*Pi^2)/
            3243240 - (8026811781667363*Im[PolyLog[2, (-1)^(1/3)]])/
            (104708135562030*Sqrt[3]) + 8*Zeta[3])), 
      (965322761237629689476217031464099105371003587417*CF^2*NC)/
        3607642670183386633282842391823741952000 - (27*CF^2*lm*NC)/66248 + 
       (193674677209700578027020970465375954811*CF*NM*NC)/
        6475519074010009326733029600000 + (3*CF*lm*NM*NC)/66248 - 
       (4106121836154133*CF*NC*NL)/1199900205504000 + 
       (3*CF*lm*NC*NL)/66248 - (143172799918095402427880481500001233028509*
         CF*NC*NH)/1393749314545436113476372833379708000000 + 
       (3*CF*lm*NC*NH)/66248 - (357525010881681491*CF^2*NC*Pi^2)/
        4722157440 - (26165851753259*CF*NM*NC*Pi^2)/3243240 + 
       (181*CF*NC*NL*Pi^2)/9828 + (37935493821445*CF^2*NC*Pi^3)/
        (9037745167392*Sqrt[3]) + (78514052459885*CF*NC*NH*Pi^3)/
        (6778308875544*Sqrt[3]) - (34904048196398681*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(507431733877530*Sqrt[3]) + 
       (12882253197050653*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (652412229271110*Sqrt[3]) + (7587098764289*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(48814981614*Sqrt[3]) + 
       (4486517283422*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) + (7587098764289*CF^2*NC*Pi*Log[3]^2)/
        (2343119117472*Sqrt[3]) + (2243258641711*CF*NC*NH*Pi*Log[3]^2)/
        (251048476872*Sqrt[3]) + CF*((-13551293325220121831*CF*NC)/
          14915351880 + CA*(83001664842879085993/182713060530 - (55*lm)/3)*
          NC - 30*CF*lm*NC - (35342928216366209*NM*NC)/365061060 + 
         (10*lm*NM*NC)/3 + (46*NC*NL)/9 + (10*lm*NC*NL)/3 + 
         (86420704759*NC*NH)/60235074900 + (10*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-253991771913*CA + 56*(9071130379*CF + 1005660747*NM + 
            65*NL))*Log[x]^3)/1638 + (27*CF^2*NC*PolyGamma[2, 1])/2 - 
       (71*CF*NM*NC*PolyGamma[2, 1])/9 - (82*CF*NC*NH*PolyGamma[2, 1])/9 + 
       CA*CF*NC*(-120665348246421629937668014192924740624779225369/
          901910667545846658320710597955935488000 - (33*lm)/132496 + 
         (44690626382361031*Pi^2)/1180539360 - (37935493821445*Pi^3)/
          (18075490334784*Sqrt[3]) + (34904048196398681*
           Im[PolyLog[2, (-1)^(1/3)]])/(1014863467755060*Sqrt[3]) - 
         (7587098764289*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (97629963228*Sqrt[3]) - (7587098764289*Pi*Log[3]^2)/
          (4686238234944*Sqrt[3]) - (27*PolyGamma[2, 1])/4 - 
         (507983859235*Zeta[3])/6552) + (507983878891*CF^2*NC*Zeta[3])/3276 + 
       (154716617*CF*NM*NC*Zeta[3])/9 + 3*CF*NC*NL*Zeta[3] - 
       (562*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((-197091684878248082480481023*NM*NC)/29319307056231192000 - 
         (410*lm*NM*NC)/819 - (lm^2*NM*NC)/6 + (1125475189*NC*NL)/
          285405120 - (410*lm*NC*NL)/819 - (lm^2*NC*NL)/6 + 
         (5832581951332213508873437273987*NC*NH)/
          69415501691960348843678760000 - (410*lm*NC*NH)/819 - 
         (lm^2*NC*NH)/6 - (154717081*NM*NC*Pi^2)/18 + (NC*NL*Pi^2)/2 - 
         (4486517283422*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CA*NC*
          (3050093838227336307514918844804485691/
            48128081173092508531617273600 + (6421*lm)/1638 + (11*lm^2)/12 + 
           (507983489317*Pi^2)/13104 + (7587098764289*
             Im[PolyLog[2, (-1)^(1/3)]])/(292889889684*Sqrt[3]) - 
           2*Zeta[3]) + CF*NC*(-42701307919075849317640868790938680033/
            336896568211647559721320915200 - (271*lm)/364 + (3*lm^2)/2 - 
           (507983482765*Pi^2)/6552 - (7587098764289*Im[PolyLog[2, (-1)^
                (1/3)]])/(146444944842*Sqrt[3]) + 4*Zeta[3])), 
      (49363391623612831068304440491477057113*CF^2*NC)/
        871099239426488713606597632000 + 
       (12210274978883505862517340298376923965283*CF*NM*NC)/
        16188797685025023316832574000000 - (53502220916122679*CF*NC*NL)/
        5013868715856000 - (1932382509869290246063073287418898528229419269*CF*
         NC*NH)/10197645609734592411472577109989309523600000 - 
       (25507959100648121953*CF^2*NC*Pi^2)/1655706452400 - 
       (86792316146951*CF*NM*NC*Pi^2)/405405 + (CF*NC*NL*Pi^2)/18 + 
       (12822202237069477*CF^2*NC*Pi^3)/(1938596338405584*Sqrt[3]) + 
       (59794539973805*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (49921924769551111019623*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(679187227160396354400*Sqrt[3]) - 
       (590296417557925244*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12722038470786645*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 + (1831743176724211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7479152540145*Sqrt[3]) + (27334646845168*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) + 
       (1831743176724211*CF^2*NC*Pi*Log[3]^2)/(358999321926960*Sqrt[3]) + 
       (1708415427823*CF*NC*NH*Pi*Log[3]^2)/(94143178827*Sqrt[3]) + 
       CF*((-31755939033980999*CF*NC)/171771600 + 
         CA*(95267690001011897/1030629600 - 55*lm)*NC - 90*CF*lm*NC - 
         (12895602278186476183*NM*NC)/5019589575 + 10*lm*NM*NC + 
         (37*NC*NL)/3 + 10*lm*NC*NL + (161503790213*NC*NH)/29113619535 + 
         10*lm*NC*NH)*Log[x]^2 - (CF*NC*(-26401703696243*CA + 
          52802754239986*CF + 1081080*(655987222*NM + 5*NL))*Log[x]^3)/
        810810 + 14*CF^2*NC*PolyGamma[2, 1] - (103*CF*NM*NC*PolyGamma[2, 1])/
        18 - (121*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-49363391618214058590109637233635179527/
          1742198478852977427213195264000 + (6001872729334065491*Pi^2)/
          779155977600 - (12822202237069477*Pi^3)/(3877192676811168*
           Sqrt[3]) - Pi^4/80 + (49921924769551111019623*
           Im[PolyLog[2, (-1)^(1/3)]])/(1358374454320792708800*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (1831743176724211*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14958305080290*Sqrt[3]) - 
         (1831743176724211*Pi*Log[3]^2)/(717998643853920*Sqrt[3]) - 
         7*PolyGamma[2, 1] - (26401677598819*Zeta[3])/1621620) + 
       (26401677598819*CF^2*NC*Zeta[3])/810810 + 
       (3935922701*CF*NM*NC*Zeta[3])/9 + (28*CF*NC*NL*Zeta[3])/3 - 
       77*CF*NC*NH*Zeta[3] + CF*Log[x]*((-5326591271797365964638558649*NM*
           NC)/14397874000827817500 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (36459356321*NC*NL)/2782699920 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (187233555601190184965935206834653*NC*NH)/
          1094595692305099750828759446750 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (1967961676*NM*NC*Pi^2)/9 + (14*NC*NL*Pi^2)/9 - 
         (27334646845168*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CA*NC*(15518257070666107676535389238121/
            2014419005592760742976000 + (76*lm)/9 + (11*lm^2)/6 + 
           (26401660005529*Pi^2)/3243240 + (1831743176724211*
             Im[PolyLog[2, (-1)^(1/3)]])/(44874915240870*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-15518235268760835733170668055091/
            1007209502796380371488000 - lm/2 + 3*lm^2 - (26401660005529*Pi^2)/
            1621620 - (1831743176724211*Im[PolyLog[2, (-1)^(1/3)]])/
            (22437457620435*Sqrt[3]) + 8*Zeta[3])), 
      (202272062190318611587321577108138887966834663158317*CF^2*NC)/
        106431765838015121392741198185359520000000 - (29*CF^2*lm*NC)/88200 + 
       (175826788861413233056953054675764445058745971*CF*NM*NC)/
        888364320165169410767016706393500000 + (29*CF*lm*NM*NC)/793800 - 
       (1553833941721187149*CF*NC*NL)/421164972131904000 + 
       (29*CF*lm*NC*NL)/793800 - 
       (1005973490063742315894303338157670985459736829*CF*NC*NH)/
        8997922596824640363064038626461155462000000 + 
       (29*CF*lm*NC*NH)/793800 - (279994266547818689*CF^2*NC*Pi^2)/
        514594080 - (47839981884509*CF*NM*NC*Pi^2)/884520 + 
       (209*CF*NC*NL*Pi^2)/11340 + (11538960484093*CF^2*NC*Pi^3)/
        (2541865828329*Sqrt[3]) + (776341008915395*CF*NC*NH*Pi^3)/
        (61004779879896*Sqrt[3]) - (4670580095401235789*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(63610192353933225*Sqrt[3]) + 
       (259754910922719635*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15266446164943974*Sqrt[3]) + (26374766820784*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(156905298045*Sqrt[3]) + 
       (44362343366594*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) + (1648422926299*CF^2*NC*Pi*Log[3]^2)/
        (470715894135*Sqrt[3]) + (22181171683297*CF*NC*NH*Pi*Log[3]^2)/
        (2259436291848*Sqrt[3]) + CF*((-9176812182289817897647*CF*NC)/
          1405485081000 + CA*(2294203017781615387123/702742540500 - 
           (176*lm)/9)*NC - 32*CF*lm*NC - (261631449787988498147*NM*NC)/
          403111655100 + (32*lm*NM*NC)/9 + (49*NC*NL)/9 + 
         (32*lm*NC*NL)/9 + (471107126561*NC*NH)/308261853900 + 
         (32*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-1043083623234*CA + 5*(417233418081*CF + 43003883132*NM + 
            448*NL))*Log[x]^3)/945 + (29*CF^2*NC*PolyGamma[2, 1])/2 - 
       (230*CF*NM*NC*PolyGamma[2, 1])/27 - (263*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*(-8899970770975544351873867845339631317547482193650573/
          9365995393745330682561225440311637760000000 - (319*lm)/1587600 + 
         (197643011694421597*Pi^2)/726485760 - (11538960484093*Pi^3)/
          (5083731656658*Sqrt[3]) + (4670580095401235789*
           Im[PolyLog[2, (-1)^(1/3)]])/(127220384707866450*Sqrt[3]) - 
         (13187383410392*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (156905298045*Sqrt[3]) - (1648422926299*Pi*Log[3]^2)/
          (941431788270*Sqrt[3]) - (29*PolyGamma[2, 1])/4 - 
         (1043083721137*Zeta[3])/1890) + (1043083727227*CF^2*NC*Zeta[3])/
        945 + (3071704571*CF*NM*NC*Zeta[3])/27 + (29*CF*NC*NL*Zeta[3])/9 - 
       (200*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-726531015511186262450757328681331*NM*NC)/
          12205480930973764073640000 - (473*lm*NM*NC)/945 - 
         (lm^2*NM*NC)/6 + (719538439547*NC*NL)/166961995200 - 
         (473*lm*NC*NL)/945 - (lm^2*NC*NL)/6 + 
         (407472540272413203786584693065823*NC*NH)/
          4415175901734856137796676760000 - (473*lm*NC*NH)/945 - 
         (lm^2*NC*NH)/6 - (3071706077*NM*NC*Pi^2)/54 + 
         (29*NC*NL*Pi^2)/54 - (44362343366594*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CA*NC*(29698798127367637331192848128939527765983/
            58309021421246693028690158400000 + (3704*lm)/945 + (11*lm^2)/12 + 
           (2086167213029*Pi^2)/7560 + (13187383410392*
             Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) - 
           2*Zeta[3]) + CF*NC*(-2121342685929056528063721300232099122197/
            2082465050758810465310362800000 - (313*lm)/420 + (3*lm^2)/2 - 
           (2086167208969*Pi^2)/3780 - (26374766820784*
             Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) + 
           4*Zeta[3])), (2482854373020446051451701702439653655799*CF^2*NC)/
        6533244295698665352049482240000 + 
       (12749288292170970463415877766656343074774910691*CF*NM*NC)/
        2368971520440451762045377883716000000 - (2147421885961769*CF*NC*NL)/
        187184432058624 - 
       (5599501284799585910329505318598424319236102271938079*CF*NC*NH)/
        27341825432364291827716159021532236801581084000000 - 
       (277073062013661987413*CF^2*NC*Pi^2)/2649130323840 - 
       (167044862773043*CF*NM*NC*Pi^2)/108108 + (CF*NC*NL*Pi^2)/18 + 
       (81595161787869383*CF^2*NC*Pi^3)/(11631578030433504*Sqrt[3]) + 
       (2343639723637835*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (32028096941882667260849*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(407512336296237812640*Sqrt[3]) - 
       (6360811121607106481*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (114498346237079805*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 + (81595161787869383*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(314124406686090*Sqrt[3]) + 
       (267844539844324*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) + (81595161787869383*CF^2*NC*Pi*Log[3]^2)/
        (15077971520932320*Sqrt[3]) + (66961134961081*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) + CF*((-40746038270091120619*CF*NC)/
          32464832400 + CA*(40746029728955097199/64929664800 - (176*lm)/3)*
          NC - 96*CF*lm*NC - (8097370258195025898173*NM*NC)/436704293025 + 
         (32*lm*NM*NC)/3 + (118*NC*NL)/9 + (32*lm*NC*NL)/3 + 
         (11529979440794*NC*NH)/1933976154825 + (32*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-88592316314797*CA + 4*(44296066017851*CF + 
            180180*(3518653717*NM + 4*NL)))*Log[x]^3)/405405 + 
       15*CF^2*NC*PolyGamma[2, 1] - (37*CF*NM*NC*PolyGamma[2, 1])/6 - 
       (43*CF*NC*NH*PolyGamma[2, 1])/6 + 
       CA*CF*NC*(-1241427186492660825249888890337844876367/
          6533244295698665352049482240000 + (30785895779145084727*Pi^2)/
          588695627520 - (81595161787869383*Pi^3)/(23263156060867008*
           Sqrt[3]) - Pi^4/80 + (32028096941882667260849*
           Im[PolyLog[2, (-1)^(1/3)]])/(815024672592475625280*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (81595161787869383*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(628248813372180*Sqrt[3]) - 
         (81595161787869383*Pi*Log[3]^2)/(30155943041864640*Sqrt[3]) - 
         (15*PolyGamma[2, 1])/2 - (354369209715137*Zeta[3])/3243240) + 
       (354369209715137*CF^2*NC*Zeta[3])/1621620 + 
       (9383076353*CF*NM*NC*Zeta[3])/3 + 10*CF*NC*NL*Zeta[3] - 
       (247*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-6028964005475087711215614027073411*NM*NC)/
          2034246821828960678940000 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (184385278873*NC*NL)/12985932960 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (140986422502032928765714381282051581439*NC*NH)/
          757372651419744619593435236395260000 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (4691538293*NM*NC*Pi^2)/3 + (5*NC*NL*Pi^2)/3 - 
         (267844539844324*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CA*NC*(195898134582917398631368881523709/
            3021628508389141114464000 + (76*lm)/9 + (11*lm^2)/6 + 
           (354369171997457*Pi^2)/6486480 + (81595161787869383*
             Im[PolyLog[2, (-1)^(1/3)]])/(1884746440116540*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-97949050939674658761071776239847/
            755407127097285278616000 - lm/2 + 3*lm^2 - (354369171997457*Pi^2)/
            3243240 - (81595161787869383*Im[PolyLog[2, (-1)^(1/3)]])/
            (942373220058270*Sqrt[3]) + 8*Zeta[3])), 
      (180363732955748973799375944518012619700506178059432419*CF^2*NC)/
        13136720812006437840475485033164375040000000 - 
       (31*CF^2*lm*NC)/115200 + 
       (49821436788017855144607885870649195357159040974771*CF*NM*NC)/
        37225862276276834343609944193643968000000 + (31*CF*lm*NM*NC)/
        1036800 - (6665611044172040369*CF*NC*NL)/1684659888527616000 + 
       (31*CF*lm*NC*NL)/1036800 - 
       (26461497442643781855486404756374167200669423848358317*CF*NC*NH)/
        218734603458914334621729272172257894412648672000000 + 
       (31*CF*lm*NC*NH)/1036800 - (168216693614401429211*CF^2*NC*Pi^2)/
        42343741440 - (7201915572916327*CF*NM*NC*Pi^2)/19459440 + 
       (239*CF*NC*NL*Pi^2)/12960 + (85784143008121985*CF^2*NC*Pi^3)/
        (17569376605410048*Sqrt[3]) + (2541981074845975*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) - (13731330070163355212323*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(175869459820154580480*Sqrt[3]) + 
       (41664813905506237*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2973983019144930*Sqrt[3]) + (2450975514517771*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13556617751088*Sqrt[3]) + 
       (145256061419770*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) + (2450975514517771*CF^2*NC*Pi*Log[3]^2)/
        (650717652052224*Sqrt[3]) + (72628030709885*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((-1378325535421622638400299*CF*NC)/
          28912835952000 + CA*(1378325532991854972594709/57825671904000 - 
           (187*lm)/9)*NC - 34*CF*lm*NC - (1442976739166667536970179*NM*NC)/
          324907994010600 + (34*lm*NM*NC)/9 + (52*NC*NL)/9 + 
         (34*lm*NC*NL)/9 + (18815557559749*NC*NH)/11603856928950 + 
         (34*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-8633752445387*CA + 32*(539609521658*CF + 51978637790*NM + 
            85*NL))*Log[x]^3)/1080 + (31*CF^2*NC*PolyGamma[2, 1])/2 - 
       (247*CF*NM*NC*PolyGamma[2, 1])/27 - (280*CF*NC*NH*PolyGamma[2, 1])/
        27 + CA*CF*NC*
        (-1984001063657981641841250723203081425733354069173669609/
          289007857864141632490460670729616250880000000 - (341*lm)/2073600 + 
         (168216693615985590427*Pi^2)/84687482880 - (85784143008121985*Pi^3)/
          (35138753210820096*Sqrt[3]) + (13731330070163355212323*
           Im[PolyLog[2, (-1)^(1/3)]])/(351738919640309160960*Sqrt[3]) - 
         (2450975514517771*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27113235502176*Sqrt[3]) - (2450975514517771*Pi*Log[3]^2)/
          (1301435304104448*Sqrt[3]) - (31*PolyGamma[2, 1])/4 - 
         (11511670086911*Zeta[3])/2880) + (11511670096831*CF^2*NC*Zeta[3])/
        1440 + (20791453645*CF*NM*NC*Zeta[3])/27 + (31*CF*NC*NL*Zeta[3])/
        9 - (638*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((-443222372027841777676249270736826919*NM*NC)/
          902266705743522098059080000 - (1081*lm*NM*NC)/2160 - 
         (lm^2*NM*NC)/6 + (2732296003763*NC*NL)/584366983200 - 
         (1081*lm*NC*NL)/2160 - (lm^2*NC*NL)/6 + 
         (10895863787820184436094854144320758487*NC*NH)/
          108196093059963517084776462342180000 - (1081*lm*NC*NH)/2160 - 
         (lm^2*NC*NH)/6 - (20791455265*NM*NC*Pi^2)/54 + 
         (31*NC*NL*Pi^2)/54 - (145256061419770*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(47364761253477940389608200246759920229141/
            11683440284776702870312684800000 + (16931*lm)/4320 + 
           (11*lm^2)/12 + (34535009700563*Pi^2)/17280 + 
           (2450975514517771*Im[PolyLog[2, (-1)^(1/3)]])/(81339706506528*
             Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-7294173216204447044634541230200242213209889/
            899624901927806121014076729600000 - (179*lm)/240 + (3*lm^2)/2 - 
           (11511669896881*Pi^2)/2880 - (2450975514517771*
             Im[PolyLog[2, (-1)^(1/3)]])/(40669853253264*Sqrt[3]) + 
           4*Zeta[3])), (7336332198765315243294141903029893248427577*CF^2*NC)/
        2822361535741823432085376327680000 + 
       (2938529970976154162370844894641576596526018094510069*CF*NM*NC)/
        75278965936470931672633442702702246400000 - 
       (1723070395140088261*CF*NC*NL)/140388324043968000 - 
       (1889204285218561831365520608780241713705859044586243*CF*NC*NH)/
        8577827586624091553793304791068937035790144000000 - 
       (971027397075194181058097*CF^2*NC*Pi^2)/1342226030745600 - 
       (9181301259003317*CF*NM*NC*Pi^2)/810810 + (CF*NC*NL*Pi^2)/18 + 
       (18625805765066051675*CF^2*NC*Pi^3)/(2512420854573636864*Sqrt[3]) + 
       (634360742598380*CF*NC*NH*Pi^3)/(22876792454961*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (73655172889849360475987099*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(880226646399873675302400*Sqrt[3]) - 
       (2484848721959335334*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (38166115412359935*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 + (3725161153013210335*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13570174368839088*Sqrt[3]) + 
       (289993482330688*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) + (3725161153013210335*CF^2*NC*Pi*Log[3]^2)/
        (651368369704276224*Sqrt[3]) + (18124592645668*CF*NC*NH*Pi*Log[3]^2)/
        (847288609443*Sqrt[3]) + CF*((-4509415152368004764323*CF*NC)/
          519437318400 + CA*(4509415007169188521843/1038874636800 - 
           (187*lm)/3)*NC - 102*CF*lm*NC - (327034082429104577596921*NM*NC)/
          2406725881560 + (34*lm*NM*NC)/3 + (125*NC*NL)/9 + 
         (34*lm*NC*NL)/3 + (5803036854457*NC*NH)/910106425800 + 
         (34*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-1213579268549237*CA + 2427157710973174*CF + 
          360360*(102347157092*NM + 17*NL))*Log[x]^3)/810810 + 
       16*CF^2*NC*PolyGamma[2, 1] - (119*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (137*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-7336332198752027642204351173838739614417537/
          5644723071483646864170752655360000 + (51106705109189099969323*Pi^2)/
          141286950604800 - (18625805765066051675*Pi^3)/(5024841709147273728*
           Sqrt[3]) - Pi^4/80 + (73655172889849360475987099*
           Im[PolyLog[2, (-1)^(1/3)]])/(1760453292799747350604800*Sqrt[3]) - 
         Im[PolyLog[2, (-1)^(1/3)]]^2 - (3725161153013210335*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27140348737678176*
           Sqrt[3]) - (3725161153013210335*Pi*Log[3]^2)/(1302736739408552448*
           Sqrt[3]) - 8*PolyGamma[2, 1] - (19417267825645621*Zeta[3])/
          25945920) + (19417267825645621*CF^2*NC*Zeta[3])/12972960 + 
       (204694313461*CF*NM*NC*Zeta[3])/9 + (32*CF*NC*NL*Zeta[3])/3 - 
       (263*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-12281110678034333530729325072566948721*NM*NC)/
          521309652207368323323024000 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (1489700423573*NC*NL)/97394497200 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (5129003127239481491393258988296000963*NC*NH)/
          25457904249403180490535638198160000 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (102347157104*NM*NC*Pi^2)/9 + 
         (16*NC*NL*Pi^2)/9 - (289993482330688*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(1364864864723937517630805329852335167/
            2610687031248217922896896000 + (76*lm)/9 + (11*lm^2)/6 + 
           (19417267503663961*Pi^2)/51891840 + (3725161153013210335*
             Im[PolyLog[2, (-1)^(1/3)]])/(81421046213034528*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-1364864836467485222856402378413028047/
            1305343515624108961448448000 - lm/2 + 3*lm^2 - 
           (19417267503663961*Pi^2)/25945920 - (3725161153013210335*
             Im[PolyLog[2, (-1)^(1/3)]])/(40710523106517264*Sqrt[3]) + 
           8*Zeta[3])), 
      (1085577100111210297942500734065837144621000432356988189882123*CF^2*NC)/
        10784377347536281920459063306589654436349849600000 - 
       (33*CF^2*lm*NC)/147968 + 
       (1301624352503339365451321873892475402121476421960261*CF*NM*NC)/
        141148061130882996886187705067566712000000 + (11*CF*lm*NM*NC)/
        443904 - (62317482191187116063*CF*NC*NL)/14753536599529728000 + 
       (11*CF*lm*NC*NL)/443904 - 
       (34186304585340486670855152268773705447087248791966007*CF*NC*NH)/
        262481524150697201546075126606709473295178406400000 + 
       (11*CF*lm*NC*NH)/443904 - (13406375285032982206111*CF^2*NC*Pi^2)/
        455900949504 - (18951637912864141*CF*NM*NC*Pi^2)/7351344 + 
       (271*CF*NC*NL*Pi^2)/14688 + (54879966525810335*CF^2*NC*Pi^3)/
        (10500447736827099*Sqrt[3]) + (8275555744911035*CF*NC*NH*Pi^3)/
        (549043018919064*Sqrt[3]) - (147844329201929736598601*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1786861191375867436830*Sqrt[3]) + 
       (7383083447552713669*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (686990077422478830*Sqrt[3]) + (25087984697513296*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129635157244779*Sqrt[3]) + 
       (472888899709202*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (847288609443*Sqrt[3]) + (1567999043594581*CF^2*NC*Pi*Log[3]^2)/
        (388905471734337*Sqrt[3]) + (236444449854601*CF*NC*NH*Pi*Log[3]^2)/
        (20334926626632*Sqrt[3]) + CF*((-134130784756446630098513321*CF*NC)/
          380107416648960 + CA*(26826156944524550116277353/152042966659584 - 
           22*lm)*NC - 36*CF*lm*NC - (418803599497334153287774*NM*NC)/
          13537833083775 + 4*lm*NM*NC + (55*NC*NL)/9 + 4*lm*NC*NL + 
         (3852670911*NC*NH)/2247176360 + 4*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-71929189664327*CA + 136*(1057782199129*CF + 95654837120*NM + 
            24*NL))*Log[x]^3)/1224 + (33*CF^2*NC*PolyGamma[2, 1])/2 - 
       (88*CF*NM*NC*PolyGamma[2, 1])/9 - 11*CF*NC*NH*PolyGamma[2, 1] + 
       CA*CF*NC*
        (-155082442886056381911008262137665569267361249656017169809989/
          3081250670724651977274018087597044124671385600000 - 
         (121*lm)/887808 + (3527993496065794411321*Pi^2)/239947868160 - 
         (54879966525810335*Pi^3)/(21000895473654198*Sqrt[3]) + 
         (147844329201929736598601*Im[PolyLog[2, (-1)^(1/3)]])/
          (3573722382751734873660*Sqrt[3]) - 
         (12543992348756648*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (129635157244779*Sqrt[3]) - (1567999043594581*Pi*Log[3]^2)/
          (777810943468674*Sqrt[3]) - (33*PolyGamma[2, 1])/4 - 
         (143858379618113*Zeta[3])/4896) + (143858379636065*CF^2*NC*Zeta[3])/
        2448 + (47827418035*CF*NM*NC*Zeta[3])/9 + (11*CF*NC*NL*Zeta[3])/3 - 
       (676*CF*NC*NH*Zeta[3])/9 + CF*Log[x]*
        ((-30687992944697810980531934497640108477*NM*NC)/
          7819644783110524849845360000 - (1225*lm*NM*NC)/2448 - 
         (lm^2*NM*NC)/6 + (137974369751*NC*NL)/27367048800 - 
         (1225*lm*NC*NL)/2448 - (lm^2*NC*NL)/6 + 
         (198604896185110630219810415777306069173*NC*NH)/
          1817694363407387087024244567348624000 - (1225*lm*NC*NH)/2448 - 
         (lm^2*NC*NH)/6 - (15942472871*NM*NC*Pi^2)/6 + 
         (11*NC*NL*Pi^2)/18 - (472888899709202*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CA*NC*(85064258258991492088460055061518212367661101149/
            2645884228703007931639869600635904000 + (19187*lm)/4896 + 
           (11*lm^2)/12 + (23976396546697*Pi^2)/1632 + 
           (12543992348756648*Im[PolyLog[2, (-1)^(1/3)]])/(388905471734337*
             Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-595449807632971120231690621271687567994471730253/
            9260594800460527760739543602225664000 - (203*lm)/272 + 
           (3*lm^2)/2 - (71929189637099*Pi^2)/2448 - 
           (25087984697513296*Im[PolyLog[2, (-1)^(1/3)]])/(388905471734337*
             Sqrt[3]) + 4*Zeta[3])), 
      (1066004772882894108784584801913392329332035055223*CF^2*NC)/
        58931614456673208717800679066040320000 + 
       (162147110527926322206438103538001321813469362033633887*CF*NM*NC)/
        564592244523531987544750820270266848000000 - 
       (2121923770858544264477*CF*NC*NL)/162288902594827008000 - 
       (4178208282550277395287526735483292529813522948506138891*CF*NC*NH)/
        17717502880172061104360071045952889447424542432000000 - 
       (29015796168754861965454691*CF^2*NC*Pi^2)/5704460630668800 - 
       (272731976519776483*CF*NM*NC*Pi^2)/3243240 + (CF*NC*NL*Pi^2)/18 + 
       (83393261348425731475*CF^2*NC*Pi^3)/(10677788631937956672*Sqrt[3]) + 
       (221441698813151845*CF*NC*NH*Pi^3)/(7412080755407364*Sqrt[3]) + 
       (CF^2*NC*Pi^4)/40 - (5644369598415380314977127109*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(63596375202390873040598400*Sqrt[3]) - 
       (126525377540213926429*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1686248371855175310*Sqrt[3]) + 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 + (16678652269685146295*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(57673241067566124*Sqrt[3]) + 
       (25307622721503068*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (22876792454961*Sqrt[3]) + (16678652269685146295*CF^2*NC*Pi*Log[3]^2)/
        (2768315571243173952*Sqrt[3]) + (6326905680375767*CF*NC*NH*Pi*
         Log[3]^2)/(274521509459532*Sqrt[3]) + 
       CF*((-2290720749841587080987083*CF*NC)/37529346254400 + 
         CA*(2290720738733899707784663/75058692508800 - 66*lm)*NC - 
         108*CF*lm*NC - (27322307134999755624127799*NM*NC)/27075666167550 + 
         12*lm*NM*NC + (44*NC*NL)/3 + 12*lm*NC*NL + 
         (10214475243391*NC*NH)/1504203675975 + 12*lm*NC*NH)*Log[x]^2 - 
       (2*CF*NC*(-35956479371803996*CA + 71912954832846137*CF + 
          9189180*(125832373414*NM + 3*NL))*Log[x]^3)/6891885 + 
       17*CF^2*NC*PolyGamma[2, 1] - (127*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (145*CF*NC*NH*PolyGamma[2, 1])/18 + 
       CA*CF*NC*(-1066004772882649135173651308377572378311798163773/
          117863228913346417435601358132080640000 + 
         (29015796168752606564266651*Pi^2)/11408921261337600 - 
         (83393261348425731475*Pi^3)/(21355577263875913344*Sqrt[3]) - 
         Pi^4/80 + (5644369598415380314977127109*Im[PolyLog[2, (-1)^(1/3)]])/
          (127192750404781746081196800*Sqrt[3]) - Im[PolyLog[2, (-1)^(1/3)]]^
          2 - (16678652269685146295*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (115346482135132248*Sqrt[3]) - (16678652269685146295*Pi*Log[3]^2)/
          (5536631142486347904*Sqrt[3]) - (17*PolyGamma[2, 1])/2 - 
         (575303667832669733*Zeta[3])/110270160) + 
       (575303667832669733*CF^2*NC*Zeta[3])/55135080 + 
       (1509988480199*CF*NM*NC*Zeta[3])/9 + (34*CF*NC*NL*Zeta[3])/3 - 
       93*CF*NC*NH*Zeta[3] + CF*Log[x]*
        ((-1460418057650392152568241353484832270521*NM*NC)/
          7819644783110524849845360000 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (217125395491261*NC*NL)/13245651619200 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (53247787217487685977028400858389755301403*NC*NH)/
          245388739059997256748273016592064240000 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (754994240497*NM*NC*Pi^2)/9 + 
         (17*NC*NL*Pi^2)/9 - (25307622721503068*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CA*NC*(13241661327714305432786954602982508612799/
            3206576346130623663798112512000 + (76*lm)/9 + (11*lm^2)/6 + 
           (575303666378256773*Pi^2)/220540320 + (16678652269685146295*
             Im[PolyLog[2, (-1)^(1/3)]])/(346039446405396744*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-13241661293007674861282576131375933659799/
            1603288173065311831899056256000 - lm/2 + 3*lm^2 - 
           (575303666378256773*Pi^2)/110270160 - (16678652269685146295*
             Im[PolyLog[2, (-1)^(1/3)]])/(173019723202698372*Sqrt[3]) + 
           8*Zeta[3])), 
      (810647391694885791522040871621001552205945578621961352659359655183*
         CF^2*NC)/1084311176266530139586836348012316834182381996838400000 - 
       (35*CF^2*lm*NC)/187272 + 
       (4973319297638452068214136262080577962536752774501193*CF*NM*NC)/
        76989851525936180119738748218672752000000 + (35*CF*lm*NM*NC)/
        1685448 - (124947504048043781197*CF*NC*NL)/27820954730541772800 + 
       (35*CF*lm*NC*NL)/1685448 - 
       (77023540614868705180640678627137609046046673444315783*CF*NC*NH)/
        551756145057261418474881105237287214625677792000000 + 
       (35*CF*lm*NC*NH)/1685448 - (141240779455107417169853*CF^2*NC*Pi^2)/
        641110710240 - (223475669130450697*CF*NM*NC*Pi^2)/12252240 + 
       (305*CF*NC*NL*Pi^2)/16524 + (2973081702881764705*CF^2*NC*Pi^3)/
        (533669814389330208*Sqrt[3]) + (2171273899360646605*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) - (116740005016122999651521*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1335508710509298845520*Sqrt[3]) + 
       (2417607846178170142489*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (333877177627324711380*Sqrt[3]) + (84945191510907563*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(411782264189298*Sqrt[3]) + 
       (124072794249179806*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (205891132094649*Sqrt[3]) + (84945191510907563*CF^2*NC*Pi*Log[3]^2)/
        (19765548681086304*Sqrt[3]) + (62036397124589903*CF*NC*NH*Pi*
         Log[3]^2)/(4941387170271576*Sqrt[3]) + 
       CF*((-1347893352408410226843954979*CF*NC)/509855621370480 + 
         CA*(2695786704721034637163504643/2039422485481920 - (209*lm)/9)*NC - 
         38*CF*lm*NC - (71114210657960773974159703*NM*NC)/324907994010600 + 
         (38*lm*NM*NC)/9 + (58*NC*NL)/9 + (38*lm*NC*NL)/9 + 
         (4106084174191*NC*NH)/2272083874200 + (38*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-1205190939312391*CA + 24*(100432578250605*CF + 
            8559381724540*NM + 323*NL))*Log[x]^3)/2754 + 
       (35*CF^2*NC*PolyGamma[2, 1])/2 - (281*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (314*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*
        (-3242589566818529549466165569825049388376070512403985209371092542607/
          8674489410132241116694690784098534673459055974707200000 - 
         (385*lm)/3370896 + (564963117820525406917007*Pi^2)/5128885681920 - 
         (2973081702881764705*Pi^3)/(1067339628778660416*Sqrt[3]) + 
         (116740005016122999651521*Im[PolyLog[2, (-1)^(1/3)]])/
          (2671017421018597691040*Sqrt[3]) - 
         (84945191510907563*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (823564528378596*Sqrt[3]) - (84945191510907563*Pi*Log[3]^2)/
          (39531097362172608*Sqrt[3]) - (35*PolyGamma[2, 1])/4 - 
         (2410381879316383*Zeta[3])/11016) + 
       (2410381879359223*CF^2*NC*Zeta[3])/5508 + 
       (1006986083561*CF*NM*NC*Zeta[3])/27 + (35*CF*NC*NL*Zeta[3])/9 - 
       (238*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-1447922526181478749894049130474926020211*NM*NC)/
          46917868698663149099072160000 - (689*lm*NM*NC)/1377 - 
         (lm^2*NM*NC)/6 + (1364309895989*NC*NL)/252298126080 - 
         (689*lm*NC*NL)/1377 - (lm^2*NC*NL)/6 + 
         (520995793108570012029176323592063365444217*NC*NH)/
          4416997303079950621468914298657156320000 - (689*lm*NC*NH)/1377 - 
         (lm^2*NC*NH)/6 - (1006986085409*NM*NC*Pi^2)/54 + 
         (35*NC*NL*Pi^2)/54 - (124072794249179806*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(15308923736022046926888610593316510629939234527561483/
            60071163321887328451977234461737325952000 + (5396*lm)/1377 + 
           (11*lm^2)/12 + (803460626169971*Pi^2)/7344 + 
           (84945191510907563*Im[PolyLog[2, (-1)^(1/3)]])/(2470693585135788*
             Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-15308923735416538461026229088022848520174705038422233/
            30035581660943664225988617230868662976000 - (457*lm)/612 + 
           (3*lm^2)/2 - (267820208721737*Pi^2)/1224 - 
           (84945191510907563*Im[PolyLog[2, (-1)^(1/3)]])/(1235346792567894*
             Sqrt[3]) + 4*Zeta[3])), 
      (152529203173020134716714428468030653929903242668197*CF^2*NC)/
        1193365192747632476535463751087316480000 + 
       (603984392014789018308837408449378770310627232235645847*CF*NM*NC)/
        282296122261765993772375410135133424000000 - 
       (2126868122200011021697*CF*NC*NL)/153272852450669952000 - 
       (4112589570600883291072108538968375997734537846738790463149*CF*NC*NH)/
        16350206600210928542656591312177865147011251275856000000 - 
       (1862750963579932404485888999*CF^2*NC*Pi^2)/51340145676019200 - 
       (2902907432631322559*CF*NM*NC*Pi^2)/4594590 + (CF*NC*NL*Pi^2)/18 + 
       (7096193645302230083165*CF^2*NC*Pi^3)/(864900879186974490432*
         Sqrt[3]) + (534486167793774665*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) + (CF^2*NC*Pi^4)/40 - 
       (483301720230438059355260926669*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5151306391393660716288470400*Sqrt[3]) - 
       (121061101205397890224462*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1418978004916130023365*Sqrt[3]) + 2*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 + (1419238729060446016633*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) + (244336533848582704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (1419238729060446016633*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) + (15271033365536419*CF*NC*NH*Pi*Log[3]^2)/
        (617673396283947*Sqrt[3]) + CF*((-49019762198470414929615379*CF*NC)/
          112588038763200 + CA*(49019762163296105673509359/225176077526400 - 
           (209*lm)/3)*NC - 114*CF*lm*NC - (205280086086709926669460273*NM*
           NC)/27075666167550 + (38*lm*NM*NC)/3 + (139*NC*NL)/9 + 
         (38*lm*NC*NL)/3 + (379893465977227*NC*NH)/52726297273650 + 
         (38*lm*NC*NH)/3)*Log[x]^2 - (2*CF*NC*(-84860664494744807*CA + 
          169721327545512079*CF + 510510*(5639540532910*NM + 19*NL))*
         Log[x]^3)/2297295 + 18*CF^2*NC*PolyGamma[2, 1] - 
       (15*CF*NM*NC*PolyGamma[2, 1])/2 - (17*CF*NC*NH*PolyGamma[2, 1])/2 + 
       CA*CF*NC*(-305058406346031445343452890591967797625562930531639/
          4773460770990529906141855004349265920000 + 
         (1862750963579914353781417199*Pi^2)/102680291352038400 - 
         (7096193645302230083165*Pi^3)/(1729801758373948980864*Sqrt[3]) - 
         Pi^4/80 + (483301720230438059355260926669*
           Im[PolyLog[2, (-1)^(1/3)]])/(10302612782787321432576940800*
           Sqrt[3]) - Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (1419238729060446016633*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) - (1419238729060446016633*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) - 9*PolyGamma[2, 1] - 
         (4073311893517732823*Zeta[3])/110270160) + 
       (4073311893517732823*CF^2*NC*Zeta[3])/55135080 + 
       1253231229445*CF*NM*NC*Zeta[3] + 12*CF*NC*NL*Zeta[3] - 
       (295*CF*NC*NH*Zeta[3])/3 + CF*Log[x]*
        ((-723696361736592192880151284727217884647*NM*NC)/
          488727798944407803115335000 - (10*lm*NM*NC)/9 - (lm^2*NM*NC)/3 + 
         (24309100393829*NC*NL)/1389975787200 - (10*lm*NC*NL)/9 - 
         (lm^2*NC*NL)/3 + (578608122123089282212167432246349698260419*NC*
           NH)/2486377182531436020062065655781927221250 - (10*lm*NC*NH)/9 - 
         (lm^2*NC*NH)/3 - (1879846844308*NM*NC*Pi^2)/3 + 2*NC*NL*Pi^2 - 
         (244336533848582704*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CA*NC*(8387699000439286404445138374742501273093649/
            259732684036580516767647113472000 + (76*lm)/9 + (11*lm^2)/6 + 
           (4073311891977353983*Pi^2)/220540320 + (1419238729060446016633*
             Im[PolyLog[2, (-1)^(1/3)]])/(28029195158837136264*Sqrt[3]) - 
           4*Zeta[3]) + CF*NC*(-8387698997628001673683313576506347218798009/
            129866342018290258383823556736000 - lm/2 + 3*lm^2 - 
           (4073311891977353983*Pi^2)/110270160 - (1419238729060446016633*
             Im[PolyLog[2, (-1)^(1/3)]])/(14014597579418568132*Sqrt[3]) + 
           8*Zeta[3])), (7424868936628157280351635424427822834564943809196943\
675724677906763*CF^2*NC)/
        1322047851276838886768976937683466514404187675289600000 - 
       (37*CF^2*lm*NC)/233928 + 
       (271671483787898720742680163120857679126838282477967609579*CF*NM*NC)/
        591688778521044119278019240672065379001600000 + 
       (37*CF*lm*NM*NC)/2105352 - (28434896312523988059615449*CF*NC*NL)/
        5975801971346720088576000 + (37*CF*lm*NC*NL)/2105352 - 
       (37616988673159748625722823855811743112385355109551735905461*CF*NC*
         NH)/252406314390756209377261128381745793206986191571027000000 + 
       (37*CF*lm*NC*NH)/2105352 - (281240294095621743627229*CF^2*NC*Pi^2)/
        168596588160 - (274124184277650184837*CF*NM*NC*Pi^2)/2095133040 + 
       (341*CF*NC*NL*Pi^2)/18468 + (5623972674062722070*CF^2*NC*Pi^3)/
        (950599356880994433*Sqrt[3]) + (2333910961446246875*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) - (141525642188735787559329619*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1536753179324168815304295*Sqrt[3]) + 
       (361688661632908811401*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (103198400357536728972*Sqrt[3]) + (2570958936714387232*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11735794529394993*Sqrt[3]) + 
       (133366340654071250*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (205891132094649*Sqrt[3]) + (160684933544649202*CF^2*NC*Pi*Log[3]^2)/
        (35207383588184979*Sqrt[3]) + (66683170327035625*CF*NC*NH*Pi*
         Log[3]^2)/(4941387170271576*Sqrt[3]) + 
       CF*((-296575483613074274983617813217*CF*NC)/14815804526883360 + 
         CA*(74143870902902303619129724873/7407902263441680 - (220*lm)/9)*
          NC - 40*CF*lm*NC - (11833641990669891029852989*NM*NC)/
          7537050644760 + (40*lm*NM*NC)/9 + (61*NC*NL)/9 + 
         (40*lm*NC*NL)/9 + (1201997514602383*NC*NH)/632715567283800 + 
         (40*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-10145314200697205*CA + 152*(133490976320059*CF + 
            10758766704078*NM + 60*NL))*Log[x]^3)/3078 + 
       (37*CF^2*NC*PolyGamma[2, 1])/2 - (298*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (331*CF*NC*NH*PolyGamma[2, 1])/27 + 
       CA*CF*NC*
        (-2041838957576205242031786210888534924209915423090047380126291838906\
7/7271263182022613877229373157259065829223032214092800000 - 
         (407*lm)/4210704 + (478108499962567655577863*Pi^2)/573228399744 - 
         (2811986337031361035*Pi^3)/(950599356880994433*Sqrt[3]) + 
         (141525642188735787559329619*Im[PolyLog[2, (-1)^(1/3)]])/
          (3073506358648337630608590*Sqrt[3]) - 
         (1285479468357193616*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (11735794529394993*Sqrt[3]) - (80342466772324601*Pi*Log[3]^2)/
          (35207383588184979*Sqrt[3]) - (37*PolyGamma[2, 1])/4 - 
         (3381771400368739*Zeta[3])/2052) + (3381771400377175*CF^2*NC*
         Zeta[3])/1026 + (7172511134269*CF*NM*NC*Zeta[3])/27 + 
       (37*CF*NC*NL*Zeta[3])/9 - (752*CF*NC*NH*Zeta[3])/9 + 
       CF*Log[x]*((-106701616798934650141640257406848999767937*NM*NC)/
          442969394817033455976757152000 - (770*lm*NM*NC)/1539 - 
         (lm^2*NM*NC)/6 + (1829669133913763*NC*NL)/316914479481600 - 
         (770*lm*NC*NL)/1539 - (lm^2*NC*NL)/6 + 
         (766555278599716023346691540723841892404525811*NC*NH)/
          6046869307916452400790943674861647002080000 - 
         (770*lm*NC*NH)/1539 - (lm^2*NC*NH)/6 - (7172511136231*NM*NC*Pi^2)/
          54 + (37*NC*NL*Pi^2)/54 - (133366340654071250*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(3637817140110984102474700029865836530562025964171371/
            1798348901968265610169486535881842216000 + (12061*lm)/3078 + 
           (11*lm^2)/12 + (1268164275078721*Pi^2)/1539 + 
           (1285479468357193616*Im[PolyLog[2, (-1)^(1/3)]])/
            (35207383588184979*Sqrt[3]) - 2*Zeta[3]) + 
         CF*NC*(-15670596911166415697046631248886428541033042235398127/
            3873366865777802852672740231130121696000 - (511*lm)/684 + 
           (3*lm^2)/2 - (2536328550155333*Pi^2)/1539 - 
           (2570958936714387232*Im[PolyLog[2, (-1)^(1/3)]])/
            (35207383588184979*Sqrt[3]) + 4*Zeta[3]))}, 0, 39, 1]
 
CbarLSeries["a", 2, -1, "x1"] = SeriesData[x, 1, 
     {-(CF*NC*(20*(NM*(-25 + 5*lm + 8*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
            NH*(-25 + 5*lm + 8*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
            NL*(-1 + 5*lm + 8*lm^2 + 4*lm^3 + 32*Zeta[3])) + 
          CF*(2340*lm^2 - 720*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 + 
            lm*(3030 - 4320*Zeta[3]) - 15*(-51 + 64*Log[2]^4 + 
              1536*PolyLog[4, 1/2] + 576*Zeta[3])) - 
          2*CA*(860*lm^2 + 220*lm^3 - 5*lm*(-85 + 216*Zeta[3]) + 
            4*(11*Pi^4 + 60*Pi^2*Log[2]^2 - 10*(9 + 6*Log[2]^4 + 
                144*PolyLog[4, 1/2] + 28*Zeta[3])))))/720, 
      (CF*NC*(-20*(NM*(-66 - 11*lm - 4*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
           NH*(6 - 11*lm - 4*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
           NL*(-6 - 11*lm - 4*lm^2 + 4*lm^3 + 32*Zeta[3])) + 
         2*CA*(200*lm^2 + 220*lm^3 + 44*Pi^4 + 240*Pi^2*Log[2]^2 - 
           5*(157 + 48*Log[2]^4 + 1152*PolyLog[4, 1/2] + 8*Zeta[3]) - 
           5*lm*(259 + 216*Zeta[3])) + CF*(-4500*lm^2 + 720*lm^3 - 176*Pi^4 - 
           960*Pi^2*Log[2]^2 + 30*lm*(55 + 144*Zeta[3]) + 
           15*(151 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 288*Zeta[3]))))/
       720, -(CF*NC*(-2*CA*(-5340*lm^2 + 660*lm^3 + 132*Pi^4 + 
            720*Pi^2*Log[2]^2 - 5*(134 + 144*Log[2]^4 + 3456*PolyLog[4, 
                1/2] - 3693*Zeta[3]) - 15*lm*(587 + 216*Zeta[3])) + 
          3*CF*(10980*lm^2 - 720*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
            30*lm*(907 + 144*Zeta[3]) - 5*(-2761 + 192*Log[2]^4 + 
              4608*PolyLog[4, 1/2] + 516*Zeta[3])) + 
          10*(2*NL*(89 + 15*lm - 120*lm^2 + 12*lm^3 + 96*Zeta[3]) + 
            NM*(-1064 + 30*lm - 240*lm^2 + 24*lm^3 + 651*Zeta[3]) + 
            NH*(-200 + 30*lm - 240*lm^2 + 24*lm^3 + 651*Zeta[3]))))/8640, 
      -(CF*NC*(-182*NM + 512*lm*NM - 48*lm^2*NM - 20*NL + 512*lm*NL - 
          48*lm^2*NL + 142*NH + 512*lm*NH - 48*lm^2*NH + 
          2*CA*(-923 - 1240*lm + 132*lm^2 - 216*Zeta[3]) + 315*NM*Zeta[3] - 
          315*NH*Zeta[3] + 6*CF*(1411 - 1020*lm + 72*lm^2 + 144*Zeta[3])))/
       1728, (CF*NC*(74362*NM + 36480*lm*NM - 3456*lm^2*NM + 73632*NL + 
         36480*lm*NL - 3456*lm^2*NL + 132682*NH + 36480*lm*NH - 
         3456*lm^2*NH + 23625*NM*Zeta[3] - 89775*NH*Zeta[3] + 
         216*CF*(-42280 - 2024*lm + 144*lm^2 + 34945*Zeta[3]) + 
         12*CA*(-157534 - 14704*lm + 1584*lm^2 + 88695*Zeta[3])))/622080, 
      -(CF*NC*(58846*NM + 14592*lm*NM - 1728*lm^2*NM + 41712*NL + 
          14592*lm*NL - 1728*lm^2*NL + 84358*NH + 14592*lm*NH - 
          1728*lm^2*NH - 4725*NM*Zeta[3] - 61425*NH*Zeta[3] + 
          216*CF*(-42583 - 860*lm + 72*lm^2 + 34801*Zeta[3]) + 
          12*CA*(-136028 - 5680*lm + 792*lm^2 + 89991*Zeta[3])))/622080, 
      (CF*NC*(4*CA*(-1289563274 - 18855360*lm + 4276800*lm^2 + 
           956289375*Zeta[3]) + 3*(23963776*NL + 5890560*lm*NL - 
           1036800*lm^2*NL + 52003150*NH + 5890560*lm*NH - 
           1036800*lm^2*NH - 38863125*NH*Zeta[3] - 
           5*NM*(-8700470 - 1178112*lm + 207360*lm^2 + 2480625*Zeta[3]) + 
           40*CF*(-413430946 - 2141856*lm + 233280*lm^2 + 
             340898895*Zeta[3]))))/1741824000, 
      -(CF*NC*(210465970*NM + 13393920*lm*NM - 4147200*lm^2*NM + 
          91254272*NL + 13393920*lm*NL - 4147200*lm^2*NL + 208209950*NH + 
          13393920*lm*NH - 4147200*lm^2*NH - 88144875*NM*Zeta[3] - 
          156610125*NH*Zeta[3] + 480*CF*(-306006034 - 523296*lm + 
            77760*lm^2 + 253252215*Zeta[3]) + 16*CA*(-736696954 - 
            2789760*lm + 1425600*lm^2 + 577549575*Zeta[3])))/3483648000, 
      (CF*NC*(68447124410*NM + 1111326720*lm*NM - 1083801600*lm^2*NM + 
         22619447296*NL + 1111326720*lm*NL - 1083801600*lm^2*NL + 
         54250432810*NH + 1111326720*lm*NH - 1083801600*lm^2*NH - 
         35987088375*NM*Zeta[3] - 40849113375*NH*Zeta[3] + 
         80*CA*(-66627036362 + 18428928*lm + 74511360*lm^2 + 
           53778210255*Zeta[3]) + 224*CF*(-373194339074 - 197061120*lm + 
           43545600*lm^2 + 309564720675*Zeta[3])))/1365590016000, 
      -(CF*NC*(29348274480*NM - 377180160*lm*NM - 361267200*lm^2*NM + 
          7026018304*NL - 377180160*lm*NL - 361267200*lm^2*NL + 
          17977005830*NH - 377180160*lm*NH - 361267200*lm^2*NH - 
          18086733000*NM*Zeta[3] - 13540739625*NH*Zeta[3] + 
          40*CA*(-76864904054 + 115084032*lm + 49674240*lm^2 + 
            62991674865*Zeta[3]) + 336*CF*(-174043367914 - 23765760*lm + 
            9676800*lm^2 + 144556286175*Zeta[3])))/682795008000, 
      (CF*NC*(CA*(-83905321596007294 + 136102540492800*lm + 
           31652425728000*lm^2 + 69300386897356125*Zeta[3]) + 
         2*(9*CF*(-104934337820644594 - 1360532275200*lm + 2877493248000*
              lm^2 + 87219084379084875*Zeta[3]) - 
           140*(4096*(-88196026 + 15190245*lm + 5017950*lm^2)*NL + 
             126*NH*(-8015638046 + 493803520*lm + 163123200*lm^2 + 
               6041314125*Zeta[3]) + 63*NM*(-34835624842 + 987607040*lm + 
               326246400*lm^2 + 24017907375*Zeta[3])))))/16223209390080000, 
      -(CF*NC*(CA*(-23940468021259774 + 33260606668800*lm + 
            5364817920000*lm^2 + 19851326221348125*Zeta[3]) + 
          2*(9*CF*(-34818855030300274 + 695981260800*lm + 487710720000*lm^2 + 
              28952205820468875*Zeta[3]) - 35*(20480*(-10344155 + 
                3352356*lm + 680400*lm^2)*NL + 63*NH*(-10654723882 + 
                1089781760*lm + 221184000*lm^2 + 8038713375*Zeta[3]) + 
              45*NM*(-43510490610 + 1525694464*lm + 309657600*lm^2 + 
                32387337675*Zeta[3])))))/4055802347520000, 
      (CF*NC*(88*CF*(-233137819210741159334 + 5571787021516800*lm + 
           1728544333824000*lm^2 + 193898583153934745625*Zeta[3]) + 
         CA*(-682939434718039132024 + 743298036616396800*lm + 
           92957273063424000*lm^2 + 567390649832815000500*Zeta[3]) - 
         405*(65536*(-7872001343 + 4281289320*lm + 636774600*lm^2)*NL + 
           165*NM*(-45576511731102 + 1700476223488*lm + 252919152640*lm^2 + 
             35684556432525*Zeta[3]) + 33*NH*(-59269410399958 + 
             8502381117440*lm + 1264595763200*lm^2 + 44770339238625*
              Zeta[3]))))/102076433482383360000, 
      -(CF*NC*(20*CA*(-7688035440156200786 + 6296867016523776*lm + 
            651739540193280*lm^2 + 6393182828757732315*Zeta[3]) + 
          88*CF*(-59599877816739847154 + 1184984605163520*lm + 
            242382473625600*lm^2 + 49574557990020969675*Zeta[3]) - 
          3*(77*NM*(-2225614506434486 + 86066593136640*lm + 
              10259575603200*lm^2 + 1801374438488625*Zeta[3]) + 
            15*(196608*(-2449903843 + 2247154294*lm + 267872220*lm^2)*NL + 
              11*NH*(40164410130432*lm + 4787801948160*lm^2 + 
                605*(-358697165846 + 271243623105*Zeta[3]))))))/
       20415286696476672000, CA*CF*NC*(-8137948726789662553322093/
          966051366477276119040000 + (180677197*lm)/35416180800 + 
         (359*lm^2)/786240 + (201759841381*Zeta[3])/28789702656) + 
       CF^2*NC*(-12018004141308284908960799/37155821787587543040000 + 
         (1710689*lm)/357739200 + (359*lm^2)/480480 + 
         (11619178867409*Zeta[3])/43184553984) - 
       (CF*NC*(143*NM*(-1775705464457587286 + 76916144241377280*lm + 
            7769244775219200*lm^2 + 1472007539744366625*Zeta[3]) + 
          3*(6291456*(-334236296029 + 582748446280*lm + 58863004200*lm^2)*
             NL + 1001*NH*(-16149292585949822 + 3662673535303680*lm + 
              369964036915200*lm^2 + 12221071653916125*Zeta[3]))))/
        13382529752066162688000, 
      CA*CF*NC*(904759698559763296230907/96605136647727611904000 - 
         (12309719*lm)/2951348400 - (131*lm^2)/393120 - 
         (785225165737*Zeta[3])/100763959296) - 
       (CF*NC*(832*CF*(-2986248089576051290597298 + 31378572116573552640*lm + 
            4052125086724915200*lm^2 + 2484177698984925797728875*Zeta[3]) - 
          2079*(25165824*(-14975724971 + 80502341920*lm + 7159752600*lm^2)*
             NL + 1365*NM*(-22251607378379922 + 1484181515272192*lm + 
              132000786677760*lm^2 + 18991749073772475*Zeta[3]) + 
            143*NH*(-52873008634963114 + 14167187191234560*lm + 
              1260007509196800*lm^2 + 40022904548001375*Zeta[3]))))/
        6182728745454567161856000, 
      CA*CF*NC*(-906977100909448861666152731/87588657227273034792960000 + 
         (235975067*lm)/69470200800 + (829*lm^2)/3341520 + 
         (1012100973225191*Zeta[3])/117461986836480) + 
       CF^2*NC*((6987161*lm)/1929727800 + (829*lm^2)/2042040 + 
         (-25931095266594906712158877766 + 21571778268117618924386428425*
            Zeta[3])/52553194336363820875776000) - 
       (CF*NC*(91*NM*(21864207173250558286 + 5171026654742446080*lm + 
            416381483247206400*lm^2 - 14906907514060687125*Zeta[3]) + 
          11*(18790481920*(274112963 + 2276604369*lm + 183316770*lm^2)*NL + 
            13*NH*(-10692892861520395018 + 3290653325745192960*lm + 
              264970034793676800*lm^2 + 8092056379803771375*Zeta[3]))))/
        840011098283537596416000, 
      -(CF*NC*(20*CA*(-171032595217594654881416986 + 41572354174714537574400*
             lm + 2826426231823741747200*lm^2 + 142316812405933171385754375*
             Zeta[3]) + 24*CF*(-7501746787898003151522821162 + 
            38294444473278529536000*lm + 3854217588850556928000*lm^2 + 
            6240681662686851296302761375*Zeta[3]) - 
          5005*(16777216*(610871968823 + 1644531045300*lm + 122399877600*lm^
                2)*NL + NM*(1228024351299215092358 + 27590652565703884800*
               lm + 2053529184868761600*lm^2 - 997101733057969163625*Zeta[
                3]) + 7150*NH*(-11171764004241286 + 3858832526671872*lm + 
              287206879002624*lm^2 + 8448112640392425*Zeta[3]))))/
       300303967636364690718720000, 
      CA*CF*NC*((27109847893*lm)/11967399924480 + (2461*lm^2)/16930368 + 
         (-61691695627763332758642509706158 + 
           51332711950155908561117448745125*Zeta[3])/
          4946907258873835550209474560000) + 
       (CF*NC*(544*CF*(-104992698859425693075920518707506 + 
            374163319040096675561472000*lm + 34608269746804453539840000*
             lm^2 + 87343625574743061945099805000875*Zeta[3]) - 
          6435*(134217728*(20185617797366027 + 34662469473531900*lm + 
              2422020659058000*lm^2)*NL + 51*NM*
             (11192133136681246434191942 + 91221919600133485363200*lm + 
              6374080588780929024000*lm^2 - 9210700051087453172879625*Zeta[
                3]) + 21879*NH*(-559060526520734102994 + 
              212638507226418380800*lm + 14857996710445056000*lm^2 + 
              422274369803522110875*Zeta[3]))))/
        79150516141981368803351592960000, 
      -(CF*NC*(256*CA*(-8405453694767260232902424552954 + 
            1152513248743173031723008000*lm + 70534994413124623269888000*
             lm^2 + 6993847876325104151726374380375*Zeta[3]) + 
          8704*CF*(-15662304422122556857599369125798 + 
            39266420401250727100416000*lm + 3394732351433805398016000*lm^2 + 
            13029541689331621723576900217625*Zeta[3]) - 
          2145*(5368709120*(3276784331854547 + 4295440619149680*lm + 
              285091810043040*lm^2)*NL + 26775*NM*
             (229916192216429873679662 + 861287440763672592384*lm + 
              57164332422609764352*lm^2 - 190172902209989397864165*Zeta[3]) + 
            7293*NH*(-7671203627784077290634 + 3162069275530965811200*lm + 
              209869052600490393600*lm^2 + 5785943536738113123375*Zeta[3]))))/
       158301032283962737606703185920000, 
      (CF*NC*(60*CA*(-52463966020004461580681025793100906 + 
           5488627902400549455068349333504*lm + 
           322933752133721649735857602560*lm^2 + 
           43651969735329983919241304215676415*Zeta[3]) + 
         17*(152*CF*(-84198818097238673905920885167761774 + 
             149983866817211159539278151680*lm + 
             12270210114847290378367795200*lm^2 + 
             70045496849309303977563648096281925*Zeta[3]) - 
           91*(8589934592*(3833544852107046607 + 4168393386212175120*lm + 
               265107386849104800*lm^2)*NL + 969*NM*
              (19355335714681577542100593154 + 36951730176767780097884160*
                lm + 2350108475634521368166400*lm^2 - 
               16049371640689426206576283875*Zeta[3]) + 12597*NH*
              (-6447433535203056973892582 + 2842440782828290776760320*lm + 
               180777575048809336012800*lm^2 + 4855155404205621495605625*
                Zeta[3])))))/213347577910172713563807440437248000, 
      -(CF*NC*(44*CA*(-386715399717235399976292435987606842 + 
            31210719476312950156011818188800*lm + 
            1776043989657955010076475392000*lm^2 + 
            321753439803618141701710529891064375*Zeta[3]) + 
          51*(152*CF*(-165006668212532865232882884152125298 + 
              211153057795440315525287116800*lm + 
              16495764609826207523930112000*lm^2 + 
              137270155556388297643783195622884875*Zeta[3]) - 
            455*(77309411328*(136541669967220101 + 129100853719697860*lm + 
                7920083607836400*lm^2)*NL + 19*NM*(
                509193421890110564924133661982 + 525300579105898982874808320*
                 lm + 32226157967914446933196800*lm^2 - 
                422790012276214205956818610125*Zeta[3]) + 4199*NH*(
                -5095654526175947451507442 + 2376925697311760103505920*lm + 
                145819719311830076620800*lm^2 + 3830892752140654033708875*
                 Zeta[3])))))/1066737889550863567819037202186240000, 
      CA*CF*NC*((1427281133*lm)/1319933815200 + (174599*lm^2)/2920488480 + 
         (-20332129450156685052077322862558519502 + 
           16916293361590136111915301756750103125*Zeta[3])/
          1183704763405124923939545667338240000) + 
       (CF*NC*(224*CF*(-192889793358877916206303896515917671514 + 
            179354348784355968343763205488640*lm + 
            13470640481300330143453859020800*lm^2 + 
            160466395085374957384810067550479967975*Zeta[3]) - 
          46189*(8589934592*(16771252081088730647 + 14208503811441619680*lm + 
              845016788733717600*lm^2)*NL + 9405*NM*
             (22410366796620613341091435234 + 12977152407279767599972352*lm + 
              771785108385381891440640*lm^2 - 18621904924505977129228468275*
               Zeta[3]) + 12597*NH*(-19802927612291108046002974 + 
              9688824195480369475092480*lm + 576219651056959330713600*lm^2 + 
              14863707628166678958802125*Zeta[3]))))/
        30843964120727826589510447103213568000, 
      -(CF*NC*(1824*CA*(-21808410102882177117873113806376173534 + 
            1082651327683207500113815535616000*lm + 
            58359043437709542787978887168000*lm^2 + 
            18144229046856671570433847432920838125*Zeta[3]) + 
          13*(64*CF*(-4221524925143431643112156438099662458714 + 
              2884708521761111037511137755136000*lm + 
              209357967017797170980651532288000*lm^2 + 
              3511917618680826982083588955902357654375*Zeta[3]) - 
            124355*(34359738368*(7770219096268330489 + 6020440531827321600*
                 lm + 348428648911543200*lm^2)*NL + 3*NM*(
                206526948407792526807998008240714 + 
                68953587177896515710065049600*lm + 
                3990639072172117442376499200*lm^2 - 
                171690964481843535965034599175375*Zeta[3]) + 
              12597*NH*(-32223493229382697881478582 + 
                16421430621075616982630400*lm + 950378440622080838860800*
                 lm^2 + 24149379661137238779896625*Zeta[3])))))/
       2159077488450947861265731297224949760000, 
      (CF*NC*(8*CA*(-22479284030063019326667891257463770815531738 + 
           889546735067755606884720243100562227200*lm + 
           46875776456155621581774928967683276800*lm^2 + 
           18702107391586174563933251469295961720286375*Zeta[3]) + 
         3*(14352*CF*(-398702544684310223338433347113015525188962 + 
             202438868453996559957122609892556800*lm + 
             14252288372196905315224970801971200*lm^2 + 
             331683620808049842552175162915956483109875*Zeta[3]) - 
           124355*(1099511627776*(4092317746924697321443 + 
               2942806765678668989100*lm + 166223123500011898320*lm^2)*NL + 
             23*NM*(716365243483112805267886365262517638 + 
               140680445963546919546366669619200*lm + 
               7946272047543876551182217379840*lm^2 - 
               595692677698855316676928549440347625*Zeta[3]) + 
             37145*NH*(-165019942123055634142227902710 + 
               87108635271546080214468526080*lm + 
               4920292289500852353673199616*lm^2 + 
               123497054483011919108351377425*Zeta[3])))))/
       9137215931124411348876574849855987384320000, 
      -(CF*NC*(6072*CF*(-29531592328876297304614866043930338508034 + 
            11259565805886178903733485279641600*lm + 
            771322599913401360889169187962880*lm^2 + 
            24567553332763883802254903447432668790115*Zeta[3]) + 
          36*CA*(-48303683659192206793889286111035311875842 + 
            1540017187819666276485210343420723200*lm + 
            79503362798481332864983624077803520*lm^2 + 
            40186765845219336707452190668027308481635*Zeta[3]) - 
          2261*(1511828488192*(4083160186991730041461 + 
              2755158178512631830120*lm + 152237703090819265920*lm^2)*NL + 
            92*NM*(385957394323033673225722336009539926 + 
              45275289388593224335928454021120*lm + 
              2501709744669737570331965521920*lm^2 - 
              320994918407355416203177999702526625*Zeta[3]) + 
            52003*NH*(-147138134323424191808559333634 + 
              80097814044393143451443527680*lm + 4425846518654997913015418880*
               lm^2 + 109973705605149738030591787875*Zeta[3]))))/
       83065599373858284989787044089599885312000}, 0, 26, 1]
 
CbarLSeries["a", 2, 0, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(2*CA*(-5540*Pi^2 + 324*Pi^4 - 660*lm*(3 + 4*Pi^2) + 
            15*(-175 + 3024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1728*Im[PolyLog[2, (-1)^(1/3)]]^2 - 504*PolyGamma[2, 1] - 
              5616*Zeta[3])) + 15*(CF*(-484*Pi^2 + 16*Pi^4 - 
              9*(103 + 1344*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                768*Im[PolyLog[2, (-1)^(1/3)]]^2 - 224*PolyGamma[2, 1] - 
                3168*Zeta[3])) + 4*(NL*(4*lm*(3 + 4*Pi^2) + 
                3*(15 + 4*Pi^2 - 64*Zeta[3])) + NM*(45 + 12*Pi^2 + 
                4*lm*(3 + 4*Pi^2) + 16*PolyGamma[2, 1] - 160*Zeta[3]) + 
              NH*(-891 + 4*lm*(3 + 4*Pi^2) - 3024*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 504*PolyGamma[2, 1] + 6000*Zeta[3])))))/
       155520, -(CF*NC*(CF*(-51460*Pi^2 + 72*Pi^4 - 
            15*(10937 + 5184*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              24192*Im[PolyLog[2, (-1)^(1/3)]]^2 - 864*PolyGamma[2, 1] - 
              31968*Zeta[3])) + 12*CA*(-3860*Pi^2 + 189*Pi^4 - 
            1320*lm*(9 + Pi^2) + 30*(-1235 + 108*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 504*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              18*PolyGamma[2, 1] - 184*Zeta[3])) + 
          480*(3*NH*(541 + 2*lm*(9 + Pi^2) - 180*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 30*PolyGamma[2, 1] - 148*Zeta[3]) + 
            NL*(135 + 7*Pi^2 + 6*lm*(9 + Pi^2) - 72*Zeta[3]) + 
            NM*(135 + 7*Pi^2 + 6*lm*(9 + Pi^2) + 6*PolyGamma[2, 1] - 
              60*Zeta[3]))))/155520, 
      -(CF*NC*(CF*(-940*Pi^2 - 592*Pi^4 + 15*(3397 + 3840*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              128*PolyGamma[2, 1] - 10848*Zeta[3])) + 
          8*CA*(-1670*Pi^2 + 101*Pi^4 - 220*lm*(-21 + 2*Pi^2) - 
            15*(-681 + 240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              144*Im[PolyLog[2, (-1)^(1/3)]]^2 - 8*PolyGamma[2, 1] - 
              712*Zeta[3])) + 80*(NL*(-111 - 84*lm + 16*Pi^2 + 8*lm*Pi^2 - 
              96*Zeta[3]) + NM*(-471 + 40*Pi^2 + lm*(-84 + 8*Pi^2) + 
              32*PolyGamma[2, 1] - 32*Zeta[3]) + NH*(-927 - 84*lm + 
              8*lm*Pi^2 - 4608*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              852*PolyGamma[2, 1] + 9192*Zeta[3]))))/51840, 
      (CF*NC*(1545885*CF - 1766880*NM - 181440*lm*NM - 522720*NL - 
         181440*lm*NL - 20521440*NH - 181440*lm*NH + 20268*CF*Pi^2 + 
         7200*NM*Pi^2 - 8640*lm*NM*Pi^2 + 59040*NL*Pi^2 - 
         8640*lm*NL*Pi^2 - 8640*lm*NH*Pi^2 + 173600*Sqrt[3]*CF*Pi^3 + 
         548800*Sqrt[3]*NH*Pi^3 + 22680*CF*Pi^4 - 648000*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] + 2229120*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 5132160*CF*Im[PolyLog[2, (-1)^(1/3)]]^
           2 + 6428160*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         20321280*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         133920*Sqrt[3]*CF*Pi*Log[3]^2 + 423360*Sqrt[3]*NH*Pi*Log[3]^2 + 
         51840*(135*CF - 2*CA*(76 + 33*lm) + 4*(5*NM + 3*lm*NM + 5*NL + 
             3*lm*NL + 3*lm*NH))*Log[x]^2 + 207360*(11*CA + 36*CF - 
           2*(NM + NL))*Log[x]^3 + 361440*CF*PolyGamma[2, 1] - 
         8640*NM*PolyGamma[2, 1] - 175680*NH*PolyGamma[2, 1] - 
         6495840*CF*Zeta[3] - 1157760*NM*Zeta[3] + 725760*NL*Zeta[3] - 
         3392640*NH*Zeta[3] + 4320*Log[x]*(8*(NM*(-43 + 3*lm + 3*Pi^2) + 
             NL*(11 + 3*lm + 3*Pi^2) + NH*(355 + 3*lm - 196*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) - 4*CA*(145 + 33*lm + 12*Pi^2 - 
             62*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 108*Zeta[3]) + 
           CF*(1209 + 80*Pi^2 - 496*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             864*Zeta[3])) - 4*CA*(-64080*Pi^2 + 21700*Sqrt[3]*Pi^3 + 
           4563*Pi^4 - 11880*lm*(21 + Pi^2) + 16740*Sqrt[3]*Pi*Log[3]^2 - 
           180*(4854 + 450*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             3564*Im[PolyLog[2, (-1)^(1/3)]]^2 - 4464*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 251*PolyGamma[2, 1] + 
             2432*Zeta[3]))))/466560, 
      -(CF*NC*(-881415*CF - 184680*NM - 125280*lm*NM - 197640*NL - 
          125280*lm*NL + 1936440*NH - 125280*lm*NH - 214452*CF*Pi^2 + 
          171360*NM*Pi^2 + 5760*lm*NM*Pi^2 + 24480*NL*Pi^2 + 
          5760*lm*NL*Pi^2 + 5760*lm*NH*Pi^2 + 64400*Sqrt[3]*CF*Pi^3 - 
          100800*Sqrt[3]*NH*Pi^3 + 1008*CF*Pi^4 + 4011840*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] - 9705600*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 1555200*CF*Im[PolyLog[2, (-1)^(1/3)]]^
            2 + 2384640*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
          3732480*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          49680*Sqrt[3]*CF*Pi*Log[3]^2 - 77760*Sqrt[3]*NH*Pi*Log[3]^2 - 
          4320*(-(CA*(65 + 66*lm + 53*Pi^2 + 92*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]])) + CF*(237 + 114*Pi^2 + 184*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]]) + 4*((5 + 3*lm)*NL + 
              NM*(41 + 3*lm - 6*Pi^2) + NH*(125 + 3*lm - 72*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])))*Log[x] - 311040*(3*CF - NM)*
           Log[x]^2 - 468480*CF*PolyGamma[2, 1] + 191520*NM*
           PolyGamma[2, 1] + 1964640*NH*PolyGamma[2, 1] + 
          8*CA*(-11655*Pi^2 - 4025*Sqrt[3]*Pi^3 + 513*Pi^4 - 
            990*lm*(-87 + 4*Pi^2) - 3105*Sqrt[3]*Pi*Log[3]^2 - 
            30*(-11871 + 8358*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              3240*Im[PolyLog[2, (-1)^(1/3)]]^2 + 4968*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 976*PolyGamma[2, 1] - 
              22004*Zeta[3])) - 11136480*CF*Zeta[3] - 308160*NM*Zeta[3] - 
          69120*NL*Zeta[3] + 19688640*NH*Zeta[3]))/466560, 
      (CF*NC*(-554036625*CF - 300024000*NM - 24300000*lm*NM - 
         146934000*NL - 24300000*lm*NL - 5470465248*NH - 24300000*lm*NH - 
         47596500*CF*Pi^2 + 8964000*NM*Pi^2 - 648000*lm*NM*Pi^2 + 
         16740000*NL*Pi^2 - 648000*lm*NL*Pi^2 - 648000*lm*NH*Pi^2 + 
         62195000*Sqrt[3]*CF*Pi^3 + 182140000*Sqrt[3]*NH*Pi^3 + 
         6334200*CF*Pi^4 - 283788000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         226224000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         921456000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 2302992000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6744384000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 47979000*Sqrt[3]*CF*Pi*
          Log[3]^2 + 140508000*Sqrt[3]*NH*Pi*Log[3]^2 + 
         2332800*(1010*CF - 5*CA*(226 + 99*lm) + 330*NM + 90*lm*NM + 
           135*NL + 90*lm*NL + 8*NH + 90*lm*NH)*Log[x]^2 + 
         69984000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 + 
         152412000*CF*PolyGamma[2, 1] - 648000*NM*PolyGamma[2, 1] + 
         10632000*NH*PolyGamma[2, 1] - 1089996000*CF*Zeta[3] - 
         810000000*NM*Zeta[3] + 217728000*NL*Zeta[3] - 
         1388784000*NH*Zeta[3] - 25*CA*(-1661256*Pi^2 + 1243900*Sqrt[3]*
            Pi^3 + 147420*Pi^4 - 71280*lm*(75 + 2*Pi^2) + 959580*Sqrt[3]*Pi*
            Log[3]^2 - 15*(2292435 + 378384*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 1228608*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             3070656*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
             203216*PolyGamma[2, 1] + 878336*Zeta[3])) - 
         1080*Log[x]*(25*CA*(39441 + 7128*lm + 1230*Pi^2 - 14216*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 15552*Zeta[3]) - 
           2*(-4*(450*NM*(99 - 9*lm + Pi^2) - 675*NL*(35 + 6*lm + 6*Pi^2) - 
               2*NH*(234633 + 2025*lm - 130100*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) + 25*CF*(34725 + 510*Pi^2 - 14216*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 15552*Zeta[3])))))/34992000, 
      -(CF*NC*(412381935*CF + 86687280*NM - 4717440*lm*NM - 9272880*NL - 
          4717440*lm*NL + 335856240*NH - 4717440*lm*NH - 
          20975436*CF*Pi^2 + 11301120*NM*Pi^2 + 155520*lm*NM*Pi^2 + 
          984960*NL*Pi^2 + 155520*lm*NL*Pi^2 + 155520*lm*NH*Pi^2 + 
          4566800*Sqrt[3]*CF*Pi^3 - 12488000*Sqrt[3]*NH*Pi^3 + 
          408240*CF*Pi^4 + 283763520*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          557867520*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          92378880*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 169102080*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 462412800*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3522960*Sqrt[3]*CF*Pi*
           Log[3]^2 - 9633600*Sqrt[3]*NH*Pi*Log[3]^2 - 
          2160*(CA*(-124689 - 13464*lm + 4410*Pi^2 - 13048*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]]) - 4*(-810*NL - 612*lm*NL - 
              30768*NH - 612*lm*NH + 36*NL*Pi^2 - 12*NM*(796 + 51*lm - 
                213*Pi^2) + 17840*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
              7*CF*(-8925 + 261*Pi^2 - 932*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])))*Log[x] + 311040*(311*CF - 
            3*CA*(125 + 11*lm) + 122*NM + 6*lm*NM - 3*NL + 6*lm*NL + 
            6*lm*NH)*Log[x]^2 - 622080*(133*CA - 446*CF - 32*NM + 2*NL)*
           Log[x]^3 - 18771840*CF*PolyGamma[2, 1] + 38957760*NM*
           PolyGamma[2, 1] + 122728320*NH*PolyGamma[2, 1] - 
          2*CA*(-1911600*Pi^2 + 1141700*Sqrt[3]*Pi^3 + 39852*Pi^4 + 
            142560*lm*(-91 + 3*Pi^2) + 880740*Sqrt[3]*Pi*Log[3]^2 + 
            45*(1025661 + 1576464*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              513216*Im[PolyLog[2, (-1)^(1/3)]]^2 + 939456*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 104288*PolyGamma[2, 1] - 
              5723488*Zeta[3])) - 1093330080*CF*Zeta[3] + 
          36858240*NM*Zeta[3] + 1172355840*NH*Zeta[3]))/12597120, 
      (CF*NC*(-1072693063575*CF - 964025647200*NM - 21937456800*lm*NM - 
         264038518800*NL - 21937456800*lm*NL - 8338103974656*NH - 
         21937456800*lm*NH - 122886193500*CF*Pi^2 - 66679200*NM*Pi^2 - 
         400075200*lm*NM*Pi^2 + 22070815200*NL*Pi^2 - 
         400075200*lm*NL*Pi^2 - 400075200*lm*NH*Pi^2 + 
         101982475000*Sqrt[3]*CF*Pi^3 + 302285900000*Sqrt[3]*NH*Pi^3 + 
         8571611160*CF*Pi^4 - 505667887200*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] + 25436880000*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 1044196272000*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 3776265360000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 11193215040000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 78672195000*Sqrt[3]*CF*Pi*
          Log[3]^2 + 233191980000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         57153600*(21*CA*(3587 + 1606*lm) - 2*(32221*CF + 42*(230 + 73*lm)*
              NM + 4333*NL + 3066*lm*NL + 486*NH + 3066*lm*NH))*
          Log[x]^2 + 3200601600*(512*CA + 2179*CF - 472*NM - 73*NL)*
          Log[x]^3 + 190267039200*CF*PolyGamma[2, 1] - 160430155200*NM*
          PolyGamma[2, 1] + 50872113600*NH*PolyGamma[2, 1] - 
         1478948772000*CF*Zeta[3] - 1434669667200*NM*Zeta[3] + 
         355266777600*NL*Zeta[3] - 2365919606400*NH*Zeta[3] - 
         1715*CA*(-39354336*Pi^2 + 29732500*Sqrt[3]*Pi^3 + 2685636*Pi^4 - 
           213840*lm*(329 + 6*Pi^2) + 22936500*Sqrt[3]*Pi*Log[3]^2 - 
           15*(43851411 + 9828336*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             20295360*Im[PolyLog[2, (-1)^(1/3)]]^2 - 73396800*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
             3698096*PolyGamma[2, 1] + 18811520*Zeta[3])) - 
         7560*Log[x]*(245*CA*(899601 + 144936*lm + 15786*Pi^2 - 
             339800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 279936*Zeta[3]) - 
           2*(4*(13230*NM*(297 + 61*lm - 365*Pi^2) + 2205*NL*(3019 + 
                 366*lm + 438*Pi^2) + 2*NH*(55456053 + 403515*lm - 
                 30845500*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             245*CF*(747213 + 738*Pi^2 - 339800*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 279936*Zeta[3])))))/21604060800, 
      -(CF*NC*(16130043423*CF + 3185745984*NM - 74560500*lm*NM - 
          191797875*NL - 74560500*lm*NL + 12238254936*NH - 
          74560500*lm*NH + 707036850*CF*Pi^2 + 523584000*NM*Pi^2 + 
          1944000*lm*NM*Pi^2 + 16848000*NL*Pi^2 + 1944000*lm*NL*Pi^2 + 
          1944000*lm*NH*Pi^2 + 93957500*Sqrt[3]*CF*Pi^3 - 
          430570000*Sqrt[3]*NH*Pi^3 + 12490200*CF*Pi^4 + 
          6988101000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          12412752000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          1994544000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 3479112000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 15943392000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 72481500*Sqrt[3]*CF*Pi*
           Log[3]^2 - 332154000*Sqrt[3]*NH*Pi*Log[3]^2 - 
          540*(4579248*NM + 261000*lm*NM + 288450*NL + 261000*lm*NL + 
            17004492*NH + 261000*lm*NH - 2610000*NM*Pi^2 - 
            25200*NL*Pi^2 - 9841600*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            2*CA*(-12573864 - 717750*lm + 1444725*Pi^2 - 536900*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]]) + CF*(49402731 - 5409900*Pi^2 + 
              2147600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))*Log[x] + 
          194400*(109669*CF - 2*CA*(34106 + 1155*lm) + 21752*NM + 
            420*lm*NM - 285*NL + 420*lm*NL + 108*NH + 420*lm*NH)*
           Log[x]^2 - 3888000*(1757*CA - 5013*CF + 14*(-58*NM + NL))*
           Log[x]^3 + 3345472000*CF*PolyGamma[2, 1] + 3300426000*NM*
           PolyGamma[2, 1] + 2956262000*NH*PolyGamma[2, 1] - 
          CA*(5965037649 + 456643575*Pi^2 + 46978750*Sqrt[3]*Pi^3 + 
            4689900*Pi^4 + 222750*lm*(-1841 + 48*Pi^2) + 3494050500*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 997272000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 1739556000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 36240750*Sqrt[3]*Pi*
             Log[3]^2 + 1672736000*PolyGamma[2, 1] - 13884686000*Zeta[3]) - 
          29408164000*CF*Zeta[3] + 5142852000*NM*Zeta[3] + 
          58320000*NL*Zeta[3] + 27312076000*NH*Zeta[3]))/157464000, 
      -(CF*NC*(601806782263743*CF + 477568618024176*NM + 
          10435961592000*lm*NM + 216315659700000*NL + 10435961592000*lm*
           NL + 6061295364927984*NH + 10435961592000*lm*NH + 
          150934370328000*CF*Pi^2 + 213040044000000*NM*Pi^2 + 
          144027072000*lm*NM*Pi^2 - 13634562816000*NL*Pi^2 + 
          144027072000*lm*NL*Pi^2 + 144027072000*lm*NH*Pi^2 - 
          74977131460000*Sqrt[3]*CF*Pi^3 - 230270882240000*Sqrt[3]*NH*Pi^3 - 
          5411817230400*CF*Pi^4 + 398718047784000*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 144176565120000*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] - 598864565376000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 - 2776296067776000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 8526601810944000*Sqrt[3]*
           NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 57839501412000*Sqrt[3]*
           CF*Pi*Log[3]^2 - 177637537728000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          514382400*(147*CA*(39229 + 19360*lm) - 8*(526722*CF - 432831*NM + 
              64680*lm*NM + 88060*NL + 64680*lm*NL + 13801*NH + 
              64680*lm*NH))*Log[x]^2 - 192036096000*(7277*CA + 33270*CF - 
            15684*NM - 924*NL)*Log[x]^3 + 153395581920000*CF*
           PolyGamma[2, 1] + 728344903104000*NM*PolyGamma[2, 1] - 
          49531812288000*NH*PolyGamma[2, 1] - 15120*Log[x]*
           (8*(11907*NM*(886179 + 21500*lm - 488800*Pi^2) + 
              198450*NL*(13877 + 1290*lm + 1848*Pi^2) + NH*(42129362427 + 
                256000500*lm - 23497028800*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) - 49*CF*(-2294748393 + 90055800*Pi^2 + 
              1249098400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              839808000*Zeta[3]) + 49*CA*(-1452492759 - 229878000*lm + 
              18152100*Pi^2 + 624549200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              419904000*Zeta[3])) + 1460952105312000*CF*Zeta[3] + 
          1468788080256000*NM*Zeta[3] - 267890353920000*NL*Zeta[3] + 
          1791723776640000*NH*Zeta[3] + 196*CA*(-385820807850*Pi^2 + 
            191268192500*Sqrt[3]*Pi^3 + 14393521800*Pi^4 - 
            168399000*lm*(1739 + 24*Pi^2) + 147549748500*Sqrt[3]*Pi*
             Log[3]^2 - 21*(151491638049 + 48435137000*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 72748368000*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 337256568000*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 18634060000*PolyGamma[2, 1] + 
              138263780000*Zeta[3]))))/7777461888000, 
      (-59661745994021*CF^2*NC)/1440270720000 + (8307774667*CF*NM*NC)/
        1000188000 + (27697*CF*lm*NM*NC)/48600 + (47977*CF*NC*NL)/24300 + 
       (27697*CF*lm*NC*NL)/48600 - (4583418465211*CF*NC*NH)/27005076000 + 
       (27697*CF*lm*NC*NH)/48600 - (201176609*CF^2*NC*Pi^2)/2721600 - 
       (29546*CF*NM*NC*Pi^2)/1215 - (CF*lm*NM*NC*Pi^2)/81 - 
       (341*CF*NC*NL*Pi^2)/2430 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 - (706279*CF^2*NC*Pi^3)/(314928*Sqrt[3]) + 
       (1045660*CF*NC*NH*Pi^3)/(59049*Sqrt[3]) - (463*CF^2*NC*Pi^4)/3240 - 
       (298183147*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(1312200*Sqrt[3]) + 
       (7388984*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) - 
       (58*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (100897*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1215*Sqrt[3]) + (478016*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (100897*CF^2*NC*Pi*Log[3]^2)/(58320*Sqrt[3]) + 
       (29876*CF*NC*NH*Pi*Log[3]^2)/(2187*Sqrt[3]) - 
       (CF*NC*(3*CF*(-348412439793 + 99972230400*Pi^2 - 7910324800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]]) - 6*CA*(-88290882921 - 
            3603322800*lm + 25567901100*Pi^2 - 1977581200*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]]) + 
          400*(-27*NM*(3858755 + 363972*lm - 10360560*Pi^2) - 
            15876*NL*(548 + 619*lm - 80*Pi^2) + NH*(-811338963 - 
              9827244*lm + 468455680*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])))*
         Log[x])/2571912000 - (CF*NC*(120387151*CF - 
          3*CA*(21471713 + 246400*lm) + 40*(771733*NM + 3360*lm*NM - 
            2730*NL + 3360*lm*NL + 1521*NH + 3360*lm*NH))*Log[x]^2)/
        113400 + (2*CF*NC*(48644*CA - 5*(23665*CF + 5672*NM - 32*NL))*
         Log[x]^3)/405 - (49945715*CF^2*NC*PolyGamma[2, 1])/177147 - 
       (13193*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (11397653*CF*NC*NH*PolyGamma[2, 1])/354294 + 
       (CA*CF*NC*(841617679671 + 36786977866170*Pi^2 + 363380545500*Sqrt[3]*
           Pi^3 + 59861251800*Pi^4 + 110020680*lm*(-27697 + 600*Pi^2) + 
          36819654991560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          9397766448000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 13455462484800*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 280322135100*Sqrt[3]*Pi*
           Log[3]^2 + 137051041960000*PolyGamma[2, 1] - 11909876221600*
           Zeta[3]))/972182736000 + (39432772*CF^2*NC*Zeta[3])/885735 - 
       (21694*CF*NM*NC*Zeta[3])/81 - (28*CF*NC*NL*Zeta[3])/27 - 
       (51376013*CF*NC*NH*Zeta[3])/177147, 
      (CF*NC*(10669460301749949381*CF + 91265556454371834480*NM - 
         259422861930724800*lm*NM - 8326744129851285600*NL - 
         259422861930724800*lm*NL - 215061056422471129680*NH - 
         259422861930724800*lm*NH - 14515621993733968800*CF*Pi^2 - 
         43201423549003104000*NM*Pi^2 - 2875500492480000*lm*NM*Pi^2 + 
         414838871048448000*NL*Pi^2 - 2875500492480000*lm*NL*Pi^2 - 
         2875500492480000*lm*NH*Pi^2 + 2630374804021580000*Sqrt[3]*CF*Pi^3 + 
         8423333335648000000*Sqrt[3]*NH*Pi^3 + 167426016174648000*CF*Pi^4 - 
         14861701641963422400*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         9572436392534400000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         17442785987383680000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         97399021314627648000*Sqrt[3]*CF*Im[PolyLog[3, 
            -((-1)^(5/6)/Sqrt[3])]] + 311904000085708800000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2029146277388076000*Sqrt[3]*
          CF*Pi*Log[3]^2 + 6498000001785600000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         186720811200*(11*CA*(26370689 + 25872000*lm) + 
           4*(39197917*CF - 10*(165*(-399787 + 7840*lm)*NM + 7700*
                (223 + 168*lm)*NL + 3*(110823 + 431200*lm)*NH)))*Log[x]^2 + 
         766800131328000*(91401*CA + 318202*CF - 240*(1634*NM + 35*NL))*
          Log[x]^3 - 62590075693930400000*CF*PolyGamma[2, 1] - 
         140695363596553920000*NM*PolyGamma[2, 1] + 2008986395514560000*NH*
          PolyGamma[2, 1] + 166320*Log[x]*
          (-40*(-88209*NM*(143674959 + 1629740*lm - 125851600*Pi^2) - 
             5*(5762988*NL*(66458 + 4989*lm + 8400*Pi^2) + NH*
                (5591102651097 + 28751547132*lm - 3125541126400*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]]))) - 121*CF*(-1552880102523 + 
             593104339800*Pi^2 + 1613256752800*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 925888320000*Zeta[3]) + 
           605*CA*(-235909530519 - 52275540240*lm + 52263871380*Pi^2 + 
             161325675280*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             92588832000*Zeta[3])) - 5324*CA*(-739925065496817 - 
           1354204465799850*Pi^2 + 247029940272500*Sqrt[3]*Pi^3 + 
           16155786717000*Pi^4 - 4950930600*lm*(54131 + 600*Pi^2) - 
           1395727051273800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           1638127910160000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           9147165788376000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           190565953924500*Sqrt[3]*Pi*Log[3]^2 - 5878106282300000*
            PolyGamma[2, 1] - 12709608769396000*Zeta[3]) - 
         145801611469648288000*CF*Zeta[3] - 188051981207207040000*NM*
          Zeta[3] + 9696187660642560000*NL*Zeta[3] - 64579966957573760000*
          NH*Zeta[3]))/155277026593920000, 
      (34186341710056159*CF^2*NC)/23332385664000 + (13424669369843*CF*NM*NC)/
        27005076000 + (133*CF*lm*NM*NC)/200 + (1808981*CF*NC*NL)/583200 + 
       (133*CF*lm*NC*NL)/200 - (230166815828423*CF*NC*NH)/729137052000 + 
       (133*CF*lm*NC*NH)/200 - (1620810601*CF^2*NC*Pi^2)/2721600 - 
       (938903*CF*NM*NC*Pi^2)/4860 - (CF*lm*NM*NC*Pi^2)/81 - 
       (869*CF*NC*NL*Pi^2)/4860 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 - (54485501*CF^2*NC*Pi^3)/(25509168*Sqrt[3]) + 
       (52574270*CF*NC*NH*Pi^3)/(1594323*Sqrt[3]) - (241*CF^2*NC*Pi^4)/
        1080 - (37716555443*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (106288200*Sqrt[3]) + (292452133*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) - 
       (82*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (7783643*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (98415*Sqrt[3]) + (24033952*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (7783643*CF^2*NC*Pi*Log[3]^2)/(4723920*Sqrt[3]) + 
       (1502122*CF*NC*NH*Pi*Log[3]^2)/(59049*Sqrt[3]) - 
       (CF*NC*(CA*(8956803168786 + 884566267200*lm - 24649440366600*Pi^2 + 
            305118805600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
          5*(CF*(-3512869373541 + 9792349187040*Pi^2 - 122047522240*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
            16*(-535815*NL*(2459 + 3752*lm - 600*Pi^2) + 3240*NM*(
                63900071 - 620487*lm + 64853460*Pi^2) - 2*NH*(102191393163 + 
                1005188940*lm - 58883182400*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]]))))*Log[x])/69441624000 - 
       (CF*NC*(2538883653*CF - 15*CA*(86185063 + 277200*lm) + 
          40*((19484743 + 18900*lm)*NM + 1575*(-11 + 12*lm)*NL + 
            (11509 + 18900*lm)*NH))*Log[x]^2)/340200 + 
       (2*CF*NC*(286766*CA - 620261*CF + 60*(-3058*NM + 5*NL))*Log[x]^3)/
        405 - (4341896036*CF^2*NC*PolyGamma[2, 1])/1594323 - 
       (454153*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (323929897*CF*NC*NH*PolyGamma[2, 1])/6377292 - 
       (27010365191*CF^2*NC*Zeta[3])/7971615 - (386497*CF*NM*NC*Zeta[3])/
        162 - (56*CF*NC*NL*Zeta[3])/27 - (1433106313*CF*NC*NH*Zeta[3])/
        3188646 + (CA*CF*NC*(-199831616942324391 + 78455221348499100*Pi^2 + 
          93442634215000*Sqrt[3]*Pi^3 + 26694517626000*Pi^4 + 
          89116750800*lm*(-10773 + 200*Pi^2) + 15524134220338800*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 3587354295840000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 3460047255504000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 72084317823000*Sqrt[3]*Pi*
           Log[3]^2 + 357424881683520000*PolyGamma[2, 1] + 
          449182845374424000*Zeta[3]))/262489338720000, 
      (65434555321806637*CF^2*NC)/38887309440000 + 
       (118193755266491*CF*NM*NC)/18003384000 - (64831*CF*lm*NM*NC)/32400 - 
       (44867069*CF*NC*NL)/486000 - (64831*CF*lm*NC*NL)/32400 - 
       (3202569822974569294837*CF*NC*NH)/1421431780945176000 - 
       (64831*CF*lm*NC*NH)/32400 - (635453491*CF^2*NC*Pi^2)/1020600 - 
       (681151*CF*NM*NC*Pi^2)/324 - (CF*lm*NM*NC*Pi^2)/54 + 
       (3059*CF*NC*NL*Pi^2)/810 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (1377457781*CF^2*NC*Pi^3)/
        (17006112*Sqrt[3]) + (575283695*CF*NC*NH*Pi^3)/(2125764*Sqrt[3]) + 
       (667*CF^2*NC*Pi^4)/432 - (34171837157*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(70858800*Sqrt[3]) - 
       (367680923*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) + 
       (463*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (196779683*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (65610*Sqrt[3]) + (65746708*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) + 
       (196779683*CF^2*NC*Pi*Log[3]^2)/(3149280*Sqrt[3]) + 
       (16436677*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) - 
       (CF*NC*(2145*CA*(-33779803 + 8519280*lm) + 
          8*(24068726968*CF - 5*(143*(-141620947 + 580860*lm)*NM + 
              30030*(3605 + 2766*lm)*NL + (24279847 + 83062980*lm)*NH)))*
         Log[x]^2)/32432400 + (4*CF*NC*(169866*CA + 127340*CF - 1069590*NM - 
          6915*NL)*Log[x]^3)/405 - (77582342419*CF^2*NC*PolyGamma[2, 1])/
        19131876 - (49657*CF*NM*NC*PolyGamma[2, 1])/6 + 
       (216722747*CF*NC*NH*PolyGamma[2, 1])/9565938 + 
       (CF*NC*Log[x]*(-40*(-2191376187*NL*(755603 + 47460*lm + 92200*Pi^2) + 
            3312738*NM*(805750531 - 31394790*lm + 9397136700*Pi^2) - 
            2*NH*(11762046993426441 + 52001356917510*lm - 6587826716270800*
               Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
          20449*CF*(22486241396091 + 13716728260200*Pi^2 + 
            7713763573600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            3888730944000*Zeta[3]) + 204490*CA*(929760231291 - 
            111891031560*lm + 668658184110*Pi^2 + 385688178680*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 194436547200*Zeta[3])))/
        473337256392000 - (CA*CF*NC*(795768324383579823 - 
          326097202300619400*Pi^2 + 14174040566490000*Sqrt[3]*Pi^3 + 
          826112279916000*Pi^4 - 178233501600*lm*(64831 + 600*Pi^2) - 
          84390769042927200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          81021709218240000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          524844473547744000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          10934259865578000*Sqrt[3]*Pi*Log[3]^2 - 2128859475977360000*
           PolyGamma[2, 1] - 3821639580442768000*Zeta[3]))/1049957354880000 - 
       (706267186081*CF^2*NC*Zeta[3])/95659380 - 11887*CF*NM*NC*Zeta[3] + 
       (308*CF*NC*NL*Zeta[3])/3 - (3251106925*CF*NC*NH*Zeta[3])/4782969, 
      (45443277569120527767091*CF^2*NC)/3260817558472320000 + 
       (6731237749671353*CF*NM*NC)/1437750246240 + (1808381*CF*lm*NM*NC)/
        2381400 + (67064453*CF*NC*NL)/14288400 + (1808381*CF*lm*NC*NL)/
        2381400 - (308053712992797743*CF*NC*NH)/582288849727200 + 
       (1808381*CF*lm*NC*NH)/2381400 - (16757821229*CF^2*NC*Pi^2)/3810240 - 
       (2561488*CF*NM*NC*Pi^2)/1701 - (CF*lm*NM*NC*Pi^2)/81 - 
       (421*CF*NC*NL*Pi^2)/1890 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 - (87193985*CF^2*NC*Pi^3)/(76527504*Sqrt[3]) + 
       (531730675*CF*NC*NH*Pi^3)/(9565938*Sqrt[3]) - 
       (1037*CF^2*NC*Pi^4)/3240 - (1628332297099*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3124873080*Sqrt[3]) + 
       (6064294688*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) - 
       (110*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (17438797*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (413343*Sqrt[3]) + (121538440*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (17438797*CF^2*NC*Pi*Log[3]^2)/(19840464*Sqrt[3]) + 
       (15192305*CF*NC*NH*Pi*Log[3]^2)/(354294*Sqrt[3]) - 
       (CF*NC*(CF*(1071092781333908013 + 819817233898370400*Pi^2 - 
            827157019304000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) - 
          56*CA*(9562386080611083 - 56428029434700*lm + 7332298273047825*
             Pi^2 - 7385330529500*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
          560*(-27785835*NL*(15387 + 36924*lm - 7000*Pi^2) + 
            486*NM*(2118811926977 - 2111037390*lm + 1033479839700*Pi^2) - 
            2*NH*(62633721750069 + 512982085770*lm - 36030070538000*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]])))*Log[x])/176451166584000 - 
       (CF*NC*(1396057218023*CF - CA*(700983631021 + 533610000*lm) + 
          280*((1687209781 + 346500*lm)*NM + 346500*(-1 + lm)*NL + 
            (255601 + 346500*lm)*NH))*Log[x]^2)/26195400 + 
       (2*CF*NC*(13175510*CA - 26981003*CF - 8892800*NM + 3500*NL)*
         Log[x]^3)/2835 - (356429648249*CF^2*NC*PolyGamma[2, 1])/14348907 - 
       (674261*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (1083501634*CF*NC*NH*PolyGamma[2, 1])/14348907 - 
       (19766474796611*CF^2*NC*Zeta[3])/502211745 - 
       (591581*CF*NM*NC*Zeta[3])/27 - (32*CF*NC*NL*Zeta[3])/9 - 
       (9447036380*CF*NC*NH*Zeta[3])/14348907 + 
       CA*CF*NC*(-11426653914668875043137/1630408779236160000 + 
         (25152641573*Pi^2)/11430720 + (87193985*Pi^3)/(153055008*Sqrt[3]) + 
         (973*Pi^4)/6480 + (11*lm*(-1808381 + 29400*Pi^2))/4762800 + 
         (1628332297099*Im[PolyLog[2, (-1)^(1/3)]])/(6249746160*Sqrt[3]) + 
         (55*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (17438797*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(826686*Sqrt[3]) + 
         (17438797*Pi*Log[3]^2)/(39680928*Sqrt[3]) + 
         (356429648249*PolyGamma[2, 1])/28697814 + (39586946656027*Zeta[3])/
          2008846980), (434746525807015516694029*CF^2*NC)/
        29347358026250880000 + (1216506940417579663*CF*NM*NC)/
        23962504104000 - (3702319*CF*lm*NM*NC)/1587600 - 
       (249300073*CF*NC*NL)/1701000 - (3702319*CF*lm*NC*NL)/1587600 - 
       (35952297729488035212157*CF*NC*NH)/10466906750596296000 - 
       (3702319*CF*lm*NC*NH)/1587600 - (164536695551*CF^2*NC*Pi^2)/
        34927200 - (171802037*CF*NM*NC*Pi^2)/11340 - 
       (CF*lm*NM*NC*Pi^2)/54 + (28733*CF*NC*NL*Pi^2)/5670 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (166052118323*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) + 
       (72252612005*CF*NC*NH*Pi^3)/(172186884*Sqrt[3]) + 
       (1507*CF^2*NC*Pi^4)/720 - (30177429872077*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(40176939600*Sqrt[3]) - 
       (55959867667*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (71744535*Sqrt[3]) + 203*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (23721731189*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5314410*Sqrt[3]) + (8257441372*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) + 
       (23721731189*CF^2*NC*Pi*Log[3]^2)/(255091680*Sqrt[3]) + 
       (2064360343*CF*NC*NH*Pi*Log[3]^2)/(6377292*Sqrt[3]) - 
       (CF*NC*(1911*CA*(-3083969437 + 102656400*lm) + 
          4*(3075302301903*CF - 350*(13*(-2263352587 + 1959804*lm)*NM + 
              11*(3822*(779 + 606*lm)*NL + (744307 + 2316132*lm)*NH))))*
         Log[x]^2)/227026800 - (4*CF*NC*(-2338106*CA + 2809104*CF + 
          35*(444512*NM + 707*NL))*Log[x]^3)/945 - 
       (6408403369909*CF^2*NC*PolyGamma[2, 1])/172186884 - 
       (1344443*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (3109178963*CF*NC*NH*PolyGamma[2, 1])/86093442 - 
       (79533534350321*CF^2*NC*Zeta[3])/1205308188 - 
       (1056719*CF*NM*NC*Zeta[3])/9 + (472*CF*NC*NL*Zeta[3])/3 - 
       (44573833321*CF*NC*NH*Zeta[3])/43046721 + 
       CA*CF*NC*(-214036351585253688440153/29347358026250880000 + 
         (269100098453*Pi^2)/114307200 - (166052118323*Pi^3)/
          (2754990144*Sqrt[3]) - (917*Pi^4)/864 + 
         (11*lm*(3702319 + 29400*Pi^2))/3175200 + 
         (30177429872077*Im[PolyLog[2, (-1)^(1/3)]])/(80353879200*Sqrt[3]) - 
         (203*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
         (23721731189*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (10628820*Sqrt[3]) - (23721731189*Pi*Log[3]^2)/
          (510183360*Sqrt[3]) + (6408403369909*PolyGamma[2, 1])/344373768 + 
         (79350706954619*Zeta[3])/2410616376) + 
       CF*Log[x]*((-1215776661409*NM*NC)/61746300 + (7477*lm*NM*NC)/630 + 
         (44023*NC*NL)/200 + (7477*lm*NC*NL)/630 + 
         (6384845835277051*NC*NH)/2074692519900 + (7477*lm*NC*NH)/630 - 
         (444211*NM*NC*Pi^2)/27 + (707*NC*NL*Pi^2)/27 - 
         (8257441372*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CA*NC*(157056500426608501/26467674987600 - (82247*lm)/1260 + 
           (20624119*Pi^2)/9072 + (23721731189*Im[PolyLog[2, (-1)^(1/3)]])/
            (31886460*Sqrt[3]) - 112*Zeta[3]) + 
         CF*NC*(-6415739016278895199/529353499752000 - (6908815*Pi^2)/1512 - 
           (23721731189*Im[PolyLog[2, (-1)^(1/3)]])/(15943230*Sqrt[3]) + 
           224*Zeta[3])), (3485644802306015851416166019*CF^2*NC)/
        32238072791836591680000 + (47706783363485131531697*CF*NM*NC)/
        1263494916395712000 + (16256473*CF*lm*NM*NC)/19051200 + 
       (7820121367*CF*NC*NL)/1143072000 + (16256473*CF*lm*NC*NL)/19051200 - 
       (30348509958293215093661*CF*NC*NH)/36843511762098961920 + 
       (16256473*CF*lm*NC*NH)/19051200 - (4593901852963*CF^2*NC*Pi^2)/
        139708800 - (100448198*CF*NM*NC*Pi^2)/8505 - 
       (CF*lm*NM*NC*Pi^2)/81 - (2059*CF*NC*NL*Pi^2)/7560 - 
       (CF*lm*NC*NL*Pi^2)/81 - (CF*lm*NC*NH*Pi^2)/81 + 
       (1505254151*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) + 
       (15014218975*CF*NC*NH*Pi^3)/(172186884*Sqrt[3]) - 
       (281*CF^2*NC*Pi^4)/648 - (411265595475281*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(562477154400*Sqrt[3]) + 
       (14424261059*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (14348907*Sqrt[3]) - (142*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (1505254151*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (37200870*Sqrt[3]) + (1715910740*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) + 
       (1505254151*CF^2*NC*Pi*Log[3]^2)/(1785641760*Sqrt[3]) + 
       (428977685*CF*NC*NH*Pi*Log[3]^2)/(6377292*Sqrt[3]) - 
       (CF*NC*(-(CA*(38301352160277036416217 - 25668558743156128800*lm + 
             17780733387201577993200*Pi^2 + 2413225863289841600*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]])) + 
          2*(CF*(38296411941695539412841 + 17774252453487058729200*Pi^2 + 
              2413225863289841600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
            140*(-16904902014*NL*(168921 + 985980*lm - 215600*Pi^2) + 
              15309*NM*(7907805380450693 - 1088764471080*lm + 
                2935565994160800*Pi^2) - 5*NH*(478857857699514747 + 
                3333579057552744*lm - 275095084382518400*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]]))))*Log[x])/1073528897497056000 - 
       (CF*NC*(538555853487348*CF - 3*CA*(89837383672891 + 14243829600*lm) + 
          280*((689254179067 + 27747720*lm)*NM + 
            5*(126126*(-47 + 44*lm)*NL + (4694801 + 5549544*lm)*NH)))*
         Log[x]^2)/1362160800 + (CF*NC*(375488249*CA - 755379110*CF - 
          264951680*NM + 21560*NL)*Log[x]^3)/5670 - 
       (28939694197904*CF^2*NC*PolyGamma[2, 1])/129140163 - 
       (12112153*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (55367400031*CF*NC*NH*PolyGamma[2, 1])/516560652 - 
       (982567515259157*CF^2*NC*Zeta[3])/2582803260 - 
       (10857685*CF*NM*NC*Zeta[3])/54 - (50*CF*NC*NL*Zeta[3])/9 - 
       (238523226271*CF*NC*NH*Zeta[3])/258280326 + 
       CA*CF*NC*(-13956880837481020306586467103/257904582334692733440000 + 
         (3759034655017*Pi^2)/228614400 - (1505254151*Pi^3)/
          (2754990144*Sqrt[3]) + (149*Pi^4)/720 + 
         lm*(-178821203/38102400 + (11*Pi^2)/162) + 
         (411265595475281*Im[PolyLog[2, (-1)^(1/3)]])/(1124954308800*
           Sqrt[3]) + (71*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (1505254151*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74401740*Sqrt[3]) - (1505254151*Pi*Log[3]^2)/
          (3571283520*Sqrt[3]) + (14469847098952*PolyGamma[2, 1])/129140163 + 
         (982773374244917*Zeta[3])/5165606520), 
      (15313450295738148957375953531*CF^2*NC)/128952291167346366720000 + 
       (31443948633506973490999*CF*NM*NC)/84232994426380800 - 
       (16915051*CF*lm*NM*NC)/6350400 - (73019873527*CF*NC*NL)/333396000 - 
       (16915051*CF*lm*NC*NL)/6350400 - (683304692098894622478842647*CF*NC*
         NH)/137130434308478939328000 - (16915051*CF*lm*NC*NH)/6350400 - 
       (18673248719179*CF^2*NC*Pi^2)/502951680 - (315472427*CF*NM*NC*Pi^2)/
        2835 - (CF*lm*NM*NC*Pi^2)/54 + (148427*CF*NC*NL*Pi^2)/22680 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (156593499635*CF^2*NC*Pi^3)/(918330048*Sqrt[3]) + 
       (26563512325*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) + 
       (5887*CF^2*NC*Pi^4)/2160 - (248747855489531*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(224990861760*Sqrt[3]) - 
       (6295405865*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
       (775*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (31318699927*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4960116*Sqrt[3]) + (12143319920*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) + 
       (31318699927*CF^2*NC*Pi*Log[3]^2)/(238085568*Sqrt[3]) + 
       (758957495*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) - 
       (CF*NC*(17*CA*(-199247647836301 + 1140986246400*lm) + 
          14*(487536474041037*CF - 40*(17*(-2164621447543 + 370450080*lm)*
               NM + 11*(371280*(1961 + 1542*lm)*NL + (197892407 + 
                  572513760*lm)*NH))))*Log[x]^2)/15437822400 - 
       (CF*NC*(-412958787*CA + 753928222*CF + 1680*(1534567*NM + 514*NL))*
         Log[x]^3)/5670 - (520824388013539*CF^2*NC*PolyGamma[2, 1])/
        1549681956 - (4035257*CF*NM*NC*PolyGamma[2, 1])/6 + 
       (41768323067*CF*NC*NH*PolyGamma[2, 1])/774840978 - 
       (65241957822525521*CF^2*NC*Zeta[3])/108477736920 - 
       (3357439*CF*NM*NC*Zeta[3])/3 + (686*CF*NC*NL*Zeta[3])/3 - 
       (579883723801*CF*NC*NH*Zeta[3])/387420489 + 
       CA*CF*NC*(-1091024574675697636791603571/18421755881049480960000 + 
         (18671407721447*Pi^2)/1005903360 - (156593499635*Pi^3)/
          (1836660096*Sqrt[3]) - (5951*Pi^4)/4320 + 
         lm*(186065561/12700800 + (11*Pi^2)/108) + 
         (248747855489531*Im[PolyLog[2, (-1)^(1/3)]])/(449981723520*
           Sqrt[3]) - (775*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (31318699927*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9920232*Sqrt[3]) - (31318699927*Pi*Log[3]^2)/(476171136*Sqrt[3]) + 
         (520824388013539*PolyGamma[2, 1])/3099363912 + 
         (65218773719529341*Zeta[3])/216955473840) + 
       CF*Log[x]*((-130251168370820477*NM*NC)/584366983200 + 
         (19399*lm*NM*NC)/1260 + (43164403*NC*NL)/132300 + 
         (19399*lm*NC*NL)/1260 + (151756932498216165949*NC*NH)/
          33576823742061600 + (19399*lm*NC*NH)/1260 - (3068842*NM*NC*Pi^2)/
          27 + (1028*NC*NL*Pi^2)/27 - (12143319920*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CA*NC*(2554429492899781061473/47712395444313600 - (213389*lm)/2520 + 
           (1625289511*Pi^2)/90720 + (31318699927*Im[PolyLog[2, (-1)^(1/3)]])/
            (29760696*Sqrt[3]) - 144*Zeta[3]) + 
         CF*NC*(-12815045049884834506433/119280988610784000 - 
           (1626767771*Pi^2)/45360 - (31318699927*Im[PolyLog[2, (-1)^(1/3)]])/
            (14880348*Sqrt[3]) + 288*Zeta[3])), 
      (574728075548263212818071158359*CF^2*NC)/696342372303670380288000 + 
       (63129644300570186727989*CF*NM*NC)/210582486065952000 + 
       (81180941*CF*lm*NM*NC)/85730400 + (8260573819*CF*NC*NL)/857304000 + 
       (81180941*CF*lm*NC*NL)/85730400 - (274449091641196767139837*CF*NC*
         NH)/226085185812879993600 + (81180941*CF*lm*NC*NH)/85730400 - 
       (86568488805509*CF^2*NC*Pi^2)/342921600 - (4805034929*CF*NM*NC*Pi^2)/
        51030 - (CF*lm*NM*NC*Pi^2)/81 - (33449*CF*NC*NL*Pi^2)/102060 - 
       (CF*lm*NC*NL*Pi^2)/81 - (CF*lm*NC*NH*Pi^2)/81 + 
       (6774526489*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) + 
       (50185702840*CF*NC*NH*Pi^3)/(387420489*Sqrt[3]) - 
       (203*CF^2*NC*Pi^4)/360 - (15041144455156213*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15186883168800*Sqrt[3]) + 
       (17376968833408*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (13559717115*Sqrt[3]) - (178*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        3 + (6774526489*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (37200870*Sqrt[3]) + (22942035584*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) + 
       (6774526489*CF^2*NC*Pi*Log[3]^2)/(1785641760*Sqrt[3]) + 
       (1433877224*CF*NC*NH*Pi*Log[3]^2)/(14348907*Sqrt[3]) - 
       (CF*NC*(-9*CA*(350028953963052771634761 - 33000473955125476800*lm + 
            133355572631332683231600*Pi^2 + 10860931706407182400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]]) + 
          20*(9*CF*(35001506507327702328783 + 13334622067048951829160*Pi^2 + 
              1086093170640718240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]) + 
            28*(98415*NM*(48884436625661269 - 979829867016*lm + 
                15983597067197760*Pi^2) + 11*(9220855644*NL*(75283 - 
                  950710*lm + 235200*Pi^2) + NH*(-1456678693944580569 - 
                  8766359669307240*lm + 835925185352857600*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])))))*Log[x])/
        9661760077473504000 - 
       (CF*NC*(-3*CA*(2064323746299263 + 62154892800*lm) + 
          28*(442282681108783*CF + 60*((2748343578847 + 20180160*lm)*NM + 
              11*(229320*(-9 + 8*lm)*NL + (1721929 + 1834560*lm)*NH))))*
         Log[x]^2)/4086482400 + (CF*NC*(4225610095*CA - 8461964013*CF + 
          1680*(-1845103*NM + 28*NL))*Log[x]^3)/8505 - 
       (2345052174197831*CF^2*NC*PolyGamma[2, 1])/1162261467 - 
       (81727406*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (340959400739*CF*NC*NH*PolyGamma[2, 1])/2324522934 - 
       (575412637221490013*CF^2*NC*Zeta[3])/162716605380 - 
       (148711480*CF*NM*NC*Zeta[3])/81 - (220*CF*NC*NL*Zeta[3])/27 - 
       (1454549375195*CF*NC*NH*Zeta[3])/1162261467 + 
       CA*CF*NC*(-718539757410574082818591982191/1740855930759175950720000 + 
         (952268726484049*Pi^2)/7544275200 - (6774526489*Pi^3)/
          (2754990144*Sqrt[3]) + (1763*Pi^4)/6480 + 
         lm*(-892990351/171460800 + (11*Pi^2)/162) + 
         (15041144455156213*Im[PolyLog[2, (-1)^(1/3)]])/(30373766337600*
           Sqrt[3]) + (89*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (6774526489*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74401740*Sqrt[3]) - (6774526489*Pi*Log[3]^2)/
          (3571283520*Sqrt[3]) + (2345052174197831*PolyGamma[2, 1])/
          2324522934 + (575431009131545603*Zeta[3])/325433210760), 
      (3300299662475351381243495125417*CF^2*NC)/3481711861518351901440000 + 
       (167561261106818649003811*CF*NM*NC)/60166424590272000 - 
       (171208259*CF*lm*NM*NC)/57153600 - (3749034287431*CF*NC*NL)/
        12002256000 - (171208259*CF*lm*NC*NL)/57153600 - 
       (232998526138834726965010438159693*CF*NC*NH)/
        33522187407574985078480801280 - (171208259*CF*lm*NC*NH)/57153600 - 
       (3247139673321223*CF^2*NC*Pi^2)/10897286400 - 
       (2864724223*CF*NM*NC*Pi^2)/3402 - (CF*lm*NM*NC*Pi^2)/54 + 
       (558401*CF*NC*NL*Pi^2)/68040 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (1917007865677*CF^2*NC*Pi^3)/
        (8264970432*Sqrt[3]) + (224855555155*CF*NC*NH*Pi^3)/
        (258280326*Sqrt[3]) + (7433*CF^2*NC*Pi^4)/2160 - 
       (47306675181135323*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (30373766337600*Sqrt[3]) - (27972440620277*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(13559717115*Sqrt[3]) + 
       (961*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (1917007865677*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (223205220*Sqrt[3]) + (51395555464*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (1917007865677*CF^2*NC*Pi*Log[3]^2)/(10713850560*Sqrt[3]) + 
       (6424444433*CF*NC*NH*Pi*Log[3]^2)/(9565938*Sqrt[3]) + 
       ((-324285094296461*CF^2*NC)/90810720 + CA*CF*(11015789020537/6177600 - 
           (5258*lm)/3)*NC + CF*NC*((-16385199547909/1621620 + (956*lm)/3)*
            NM + (4*(904 + 717*lm)*NL)/9 + (61134332681*NH)/523783260 + 
           (956*lm*NH)/3))*Log[x]^2 - 
       (CF*NC*(-9757154405*CA + 19184440954*CF + 56869706880*NM + 
          3613680*NL)*Log[x]^3)/17010 - (42209867046212773*CF^2*NC*
         PolyGamma[2, 1])/13947137604 - (326881345*CF*NM*NC*PolyGamma[2, 1])/
        54 + (534337602563*CF*NC*NH*PolyGamma[2, 1])/6973568802 - 
       (5352206758859303783*CF^2*NC*Zeta[3])/976299632280 - 
       (281799847*CF*NM*NC*Zeta[3])/27 + (2870*CF*NC*NL*Zeta[3])/9 - 
       (7242999573949*CF*NC*NH*Zeta[3])/3486784401 + 
       CA*CF*NC*(-1649459390207584148408773206629/3481711861518351901440000 + 
         (749327346842533*Pi^2)/5029516800 - (1917007865677*Pi^3)/
          (16529940864*Sqrt[3]) - (833*Pi^4)/480 + 
         lm*(1883290849/114307200 + (11*Pi^2)/108) + 
         (47306675181135323*Im[PolyLog[2, (-1)^(1/3)]])/(60747532675200*
           Sqrt[3]) - (961*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (1917007865677*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (446410440*Sqrt[3]) - (1917007865677*Pi*Log[3]^2)/
          (21427701120*Sqrt[3]) + (42209867046212773*PolyGamma[2, 1])/
          27894275208 + (5351922167516494163*Zeta[3])/1952599264560) + 
       CF*Log[x]*((-1198380131621787281*NM*NC)/584366983200 + 
         (219671*lm*NM*NC)/11340 + (2200494809*NC*NL)/4762800 + 
         (219671*lm*NC*NL)/11340 + (509538178617524327719769*NC*NH)/
          80000140247835968160 + (219671*lm*NC*NH)/11340 - 
         (2507456*NM*NC*Pi^2)/3 + (478*NC*NL*Pi^2)/9 - 
         (51395555464*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CA*NC*(39109007158653672043327/85882311799764480 - 
           (2416381*lm)/22680 + (38917347811*Pi^2)/272160 + 
           (1917007865677*Im[PolyLog[2, (-1)^(1/3)]])/(1339231320*Sqrt[3]) - 
           180*Zeta[3]) + CF*NC*(-978254986953503683078027/
            1073528897497056000 - (38923504591*Pi^2)/136080 - 
           (1917007865677*Im[PolyLog[2, (-1)^(1/3)]])/(669615660*Sqrt[3]) + 
           360*Zeta[3])), (328562302842188653546921558357868341*CF^2*NC)/
        51316951126918988675324160000 + (71779457527762336534481993*CF*NM*
         NC)/29843992905058332000 + (89189893*CF*lm*NM*NC)/85730400 + 
       (158026039769*CF*NC*NL)/12002256000 + (89189893*CF*lm*NC*NL)/
        85730400 - (31416609813833050250585848027*CF*NC*NH)/
        18327482545328210241187200 + (89189893*CF*lm*NC*NH)/85730400 - 
       (19446871143694811*CF^2*NC*Pi^2)/9807557760 - 
       (77803568603*CF*NM*NC*Pi^2)/102060 - (CF*lm*NM*NC*Pi^2)/81 - 
       (1985*CF*NC*NL*Pi^2)/5103 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (398077129379*CF^2*NC*Pi^3)/
        (37192366944*Sqrt[3]) + (428635560535*CF*NC*NH*Pi^3)/
        (2324522934*Sqrt[3]) - (2303*CF^2*NC*Pi^4)/3240 - 
       (59418910888229531*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (45560649506400*Sqrt[3]) + (64533770116859*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40679151345*Sqrt[3]) - 
       (218*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (398077129379*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1004423490*Sqrt[3]) + (97973842408*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) + 
       (398077129379*CF^2*NC*Pi*Log[3]^2)/(48212327520*Sqrt[3]) + 
       (12246730301*CF*NC*NH*Pi*Log[3]^2)/(86093442*Sqrt[3]) - 
       (CF*NC*(-(CA*(23577907002921937540763353149 - 321624448110255778488000*
              lm + 8064194585251424901590509200*Pi^2 + 
             184439190424963924049600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          4*(CF*(11788846862247834661131995559 + 4032046754217630908712552600*
               Pi^2 + 92219595212481962024800*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]]) + 140*(6281378591202*NL*(5546027 - 
                16624300*lm + 4586400*Pi^2) + 11514555*NM*(
                3110915118644992957 - 9068828288520*lm + 948099544115724000*
                 Pi^2) + NH*(-19793465804537863088991 - 
                104423522113719408600*lm + 11348439060505711964800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]]))))*Log[x])/
        8376745987169527968000 - 
       (CF*NC*(-(CA*(826570182178614281 + 4415217206400*lm)) + 
          224*(7379878051752322*CF + 15*(156*(1212430055077 + 1531530*lm)*
               NM + 4594590*(-61 + 52*lm)*NL + (243421901 + 238918680*lm)*
               NH)))*Log[x]^2)/69470200800 - 
       (CF*NC*(-32750007841*CA + 65516565067*CF + 65520*(378902*NM - NL))*
         Log[x]^3)/8505 - (189961340651860220*CF^2*NC*PolyGamma[2, 1])/
        10460353203 - (2942007949*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (8153179442773*CF*NC*NH*PolyGamma[2, 1])/41841412812 - 
       (47545619311855186973*CF^2*NC*Zeta[3])/1464449448420 - 
       (2705625901*CF*NM*NC*Zeta[3])/162 - (308*CF*NC*NL*Zeta[3])/27 - 
       (34497772694773*CF*NC*NH*Zeta[3])/20920706406 + 
       CA*CF*NC*(-6571447262384204677877097779966039/
          2052678045076759547012966400 + (1495916799839597*Pi^2)/1508855040 - 
         (398077129379*Pi^3)/(74384733888*Sqrt[3]) + (2239*Pi^4)/6480 + 
         lm*(-981088823/171460800 + (11*Pi^2)/162) + 
         (59418910888229531*Im[PolyLog[2, (-1)^(1/3)]])/(91121299012800*
           Sqrt[3]) + (109*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (398077129379*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2008846980*Sqrt[3]) - (398077129379*Pi*Log[3]^2)/
          (96424655040*Sqrt[3]) + (94980670325930110*PolyGamma[2, 1])/
          10460353203 + (47545845243861757103*Zeta[3])/2928898896840), 
      (10582080613189049990053594662041237909*CF^2*NC)/
        1385557680426812694233752320000 + (44062483546593097116313035047*CF*
         NM*NC)/2069183508084044352000 - (38039191*CF*lm*NM*NC)/11430720 - 
       (10304121552199*CF*NC*NL)/24004512000 - (38039191*CF*lm*NC*NL)/
        11430720 - (127513308610420572502317823650296879*CF*NC*NH)/
        13576485900067868956784724518400 - (38039191*CF*lm*NC*NH)/11430720 - 
       (2397893980144723*CF^2*NC*Pi^2)/990662400 - 
       (222399568411*CF*NM*NC*Pi^2)/34020 - (CF*lm*NM*NC*Pi^2)/54 + 
       (684149*CF*NC*NL*Pi^2)/68040 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (614206387514381*CF^2*NC*Pi^3)/
        (2008387814976*Sqrt[3]) + (149104253771725*CF*NC*NH*Pi^3)/
        (125524238436*Sqrt[3]) + (3053*CF^2*NC*Pi^4)/720 - 
       (5212145270429226149*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2460275073345600*Sqrt[3]) - (672490971254302*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(219667417263*Sqrt[3]) + 
       389*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (614206387514381*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (54238868460*Sqrt[3]) + (17040486145340*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) + 
       (614206387514381*CF^2*NC*Pi*Log[3]^2)/(2603465686080*Sqrt[3]) + 
       (4260121536335*CF*NC*NH*Pi*Log[3]^2)/(4649045868*Sqrt[3]) + 
       ((-74718027632732137*CF^2*NC)/2572970400 + 
         CA*CF*(224105644927902841/15437822400 - 2365*lm)*NC + 
         CF*NC*((-2162591238702809/27567540 + 430*lm)*NM + 
           (5*(323 + 258*lm)*NL)/3 + (17295941269*NH)/104756652 + 
           430*lm*NH))*Log[x]^2 - (CF*NC*(-26217285275*CA + 52273330442*CF + 
          144843395760*NM + 1625400*NL)*Log[x]^3)/5670 - 
       (3419291705124444163*CF^2*NC*PolyGamma[2, 1])/125524238436 - 
       (2941968001*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (6581196594875*CF*NC*NH*PolyGamma[2, 1])/62762119218 - 
       (438106835159277068789*CF^2*NC*Zeta[3])/8786696690520 - 
       (2597174857*CF*NM*NC*Zeta[3])/27 + (3872*CF*NC*NL*Zeta[3])/9 - 
       (87571280323861*CF*NC*NH*Zeta[3])/31381059609 + 
       CA*CF*NC*(-21162748909019011643181934698166909/
          5542230721707250776935009280 + (79130288770331399*Pi^2)/
          65383718400 - (614206387514381*Pi^3)/(4016775629952*Sqrt[3]) - 
         (9223*Pi^4)/4320 + lm*(418431101/22861440 + (11*Pi^2)/108) + 
         (5212145270429226149*Im[PolyLog[2, (-1)^(1/3)]])/
          (4920550146691200*Sqrt[3]) - (389*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
         (614206387514381*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (108477736920*Sqrt[3]) - (614206387514381*Pi*Log[3]^2)/
          (5206931372160*Sqrt[3]) + (3419291705124444163*PolyGamma[2, 1])/
          251048476872 + (438103435846674075209*Zeta[3])/17573393381040) + 
       CF*Log[x]*((-93854463522622835443*NM*NC)/5277564317025 + 
         (269819*lm*NM*NC)/11340 + (2003657911*NC*NL)/3175200 + 
         (269819*lm*NC*NL)/11340 + (84388929408929764662668633*NC*NH)/
          9720017040112070131440 + (269819*lm*NC*NH)/11340 - 
         (57477493*NM*NC*Pi^2)/9 + (215*NC*NL*Pi^2)/3 - 
         (17040486145340*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CA*NC*(579427750264426791414273399311/
            150781427769051503424000 - (2968009*lm)/22680 + 
           (104819031019*Pi^2)/90720 + (614206387514381*
             Im[PolyLog[2, (-1)^(1/3)]])/(325433210760*Sqrt[3]) - 
           220*Zeta[3]) + CF*NC*(-579477267240488434028006102663/
            75390713884525751712000 - (104821790279*Pi^2)/45360 - 
           (614206387514381*Im[PolyLog[2, (-1)^(1/3)]])/(162716605380*
             Sqrt[3]) + 440*Zeta[3])), 
      (480724347773663829876578476597561158539431*CF^2*NC)/
        9503540130047508269749307162880000 + 
       (416024997671061879527560110832003*CF*NM*NC)/
        21288794522922690315552000 + (2351898449*CF*lm*NM*NC)/2074675680 + 
       (3635585361311*CF*NC*NL)/207467568000 + (2351898449*CF*lm*NC*NL)/
        2074675680 - (1556830425508575851969920049726977*CF*NC*NH)/
        665514014709209262587486496000 + (2351898449*CF*lm*NC*NH)/
        2074675680 - (1221374159974050781*CF^2*NC*Pi^2)/77059382400 - 
       (1753262600422*CF*NM*NC*Pi^2)/280665 - (CF*lm*NM*NC*Pi^2)/81 - 
       (512111*CF*NC*NL*Pi^2)/1122660 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (207917329693477*CF^2*NC*Pi^3)/
        (11046132982368*Sqrt[3]) + (5305869416645*CF*NC*NH*Pi^3)/
        (20920706406*Sqrt[3]) - (2833*CF^2*NC*Pi^4)/3240 - 
       (249751224229524948863*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (148846641937408800*Sqrt[3]) + (701513879763346*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) - 
       (262*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (207917329693477*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (298313776530*Sqrt[3]) + (1212770152376*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) + 
       (207917329693477*CF^2*NC*Pi*Log[3]^2)/(14319061273440*Sqrt[3]) + 
       (151596269047*CF*NC*NH*Pi*Log[3]^2)/(774840978*Sqrt[3]) - 
       (CF*NC*(-(CA*(21477129006385270311924449946435861 - 
             42097751401352283566044315200*lm + 
             6849440876781106296286074243562800*Pi^2 + 
             34776339832923252876204692800*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]])) + 4*(CF*(10738545227728427454824696842478769 + 
              3424713173658817384159702429943400*Pi^2 + 
              17388169916461626438102346400*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]]) + 4620*(3188646*NM*(
                310879759087671314718649 - 129893654532221580*lm + 
                90548086731393542050800*Pi^2) + 17*(381971639838789*NL*
                 (37701437 - 63784360*lm + 19404000*Pi^2) - 4*NH*
                 (1301707275753769317541707 + 6090954146316914885010*lm - 
                  745766340875220015551200*Sqrt[3]*Im[PolyLog[2, (-1)^
                      (1/3)]])))))*Log[x])/898129574506355280145056000 - 
       (CF*NC*(-9*CA*(153420594910199369323 + 138022708824000*lm) + 
          4*(690389342666145891641*CF + 4620*(21*(2804549313816641 + 
                581981400*lm)*NM + 17*(51351300*(-17 + 14*lm)*NL + 
                (782981813 + 718918200*lm)*NH))))*Log[x]^2)/14519271967200 + 
       (CF*NC*(2853918308697*CA - 5708105138461*CF - 2223144665280*NM + 
          970200*NL)*Log[x]^3)/93555 - (15387019179173692109*CF^2*NC*
         PolyGamma[2, 1])/94143178827 - (13238907593*CF*NM*NC*
         PolyGamma[2, 1])/162 - (23779461007273*CF*NC*NH*PolyGamma[2, 1])/
        94143178827 - (42968767684303221204769*CF^2*NC*Zeta[3])/
        144980495393580 - (12276545153*CF*NM*NC*Zeta[3])/81 - 
       (416*CF*NC*NL*Zeta[3])/27 - (199833770375018*CF*NC*NH*Zeta[3])/
        94143178827 + CA*CF*NC*(-165249821845421311989050987891713138102291/
          6533683839407661935452648674480000 + (1221374594543076331*Pi^2)/
          154118764800 - (207917329693477*Pi^3)/(22092265964736*Sqrt[3]) + 
         (923*Pi^4)/2160 + lm*(-2351898449/377213760 + (11*Pi^2)/162) + 
         (249751224229524948863*Im[PolyLog[2, (-1)^(1/3)]])/
          (297693283874817600*Sqrt[3]) + (131*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 - (207917329693477*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (596627553060*Sqrt[3]) - (207917329693477*Pi*Log[3]^2)/
          (28638122546880*Sqrt[3]) + (15387019179173692109*PolyGamma[2, 1])/
          188286357654 + (42968797365032417057119*Zeta[3])/289960990787160), 
      (19494194075621590778160502175598528289779859*CF^2*NC)/
        313616824291567772901727136375040000 + 
       (2361757611459676602846812279165111*CF*NM*NC)/
        14192529681948460210368000 - (5062511071*CF*lm*NM*NC)/1383117120 - 
       (237500285627579*CF*NC*NL)/414935136000 - (5062511071*CF*lm*NC*NL)/
        1383117120 - (6126469790933857596997594875103369603909*CF*NC*NH)/
        495555311838377284791599229646118400 - (5062511071*CF*lm*NC*NH)/
        1383117120 - (475866866626911689*CF^2*NC*Pi^2)/23974030080 - 
       (3874132220275*CF*NM*NC*Pi^2)/74844 - (CF*lm*NM*NC*Pi^2)/54 + 
       (9047719*CF*NC*NL*Pi^2)/748440 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (26055674551528867*CF^2*NC*Pi^3)/
        (66276797894208*Sqrt[3]) + (593767011462625*CF*NC*NH*Pi^3)/
        (376572715308*Sqrt[3]) + (2213*CF^2*NC*Pi^4)/432 - 
       (357278127694720546319*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (127582835946350400*Sqrt[3]) - (14349938453715296*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3295011258945*Sqrt[3]) + 
       (1393*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (3722239221646981*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (255697522740*Sqrt[3]) + (67859087024300*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) + 
       (3722239221646981*CF^2*NC*Pi*Log[3]^2)/(12273481091520*Sqrt[3]) + 
       (16964771756075*CF*NC*NH*Pi*Log[3]^2)/(13947137604*Sqrt[3]) - 
       (CF*NC*(23*CA*(-1152707284799642284813 + 30061345981867200*lm) + 
          2*(26513187467369817805109*CF - 9240*(161*(-46478442672580007 + 
                42251849640*lm)*NM + 14724129420*(575 + 462*lm)*NL + 
              (2716485695089 + 6802547792040*lm)*NH)))*Log[x]^2)/
        222628836830400 - (CF*NC*(-7060400820007*CA + 
          10*(1411325659889*CF + 8316*(450413132*NM + 847*NL)))*Log[x]^3)/
        187110 - (276966204243101076229*CF^2*NC*PolyGamma[2, 1])/
        1129718145924 - (26477760721*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (78632109457139*CF*NC*NH*PolyGamma[2, 1])/564859072962 - 
       (393708298188440069964169*CF^2*NC*Zeta[3])/869882972361480 - 
       (23775376897*CF*NM*NC*Zeta[3])/27 + (5084*CF*NC*NL*Zeta[3])/9 - 
       (1030960316904289*CF*NC*NH*Zeta[3])/282429536481 + 
       CA*CF*NC*(-2436748989338144281116759505444071684189017/
          78404206072891943225431784093760000 + (95173334191912393*Pi^2)/
          9589612032 - (26055674551528867*Pi^3)/(132553595788416*Sqrt[3]) - 
         (11129*Pi^4)/4320 + lm*(5062511071/251475840 + (11*Pi^2)/108) + 
         (357278127694720546319*Im[PolyLog[2, (-1)^(1/3)]])/
          (255165671892700800*Sqrt[3]) - (1393*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          6 - (3722239221646981*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (511395045480*Sqrt[3]) - (3722239221646981*Pi*Log[3]^2)/
          (24546962183040*Sqrt[3]) + (276966204243101076229*PolyGamma[2, 1])/
          2259436291848 + (393707861781039991355749*Zeta[3])/
          1739765944722960) + CF*Log[x]*((-57634137517015392075947*NM*NC)/
          381040143689205 + (3575329*lm*NM*NC)/124740 + 
         (1789764077*NC*NL)/2138400 + (3575329*lm*NC*NL)/124740 + 
         (888132703924270702502377454641*NC*NH)/77128335213289276492976400 + 
         (3575329*lm*NC*NH)/124740 - (450413143*NM*NC*Pi^2)/9 + 
         (847*NC*NL*Pi^2)/9 - (67859087024300*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3486784401*Sqrt[3]) + 
         CA*NC*(11657277613876606424373731154128393/
            359251829802542112058022400 - (3575329*lm)/22680 + 
           (28239429700373*Pi^2)/2993760 + (3722239221646981*
             Im[PolyLog[2, (-1)^(1/3)]])/(1534185136440*Sqrt[3]) - 
           264*Zeta[3]) + CF*NC*(-58287153720042092288422711003225021/
            898129574506355280145056000 - (28239548937953*Pi^2)/1496880 - 
           (3722239221646981*Im[PolyLog[2, (-1)^(1/3)]])/(767092568220*
             Sqrt[3]) + 528*Zeta[3])), 
      (286331760497068378954337230746036291427884161*CF^2*NC)/
        705637854656027489028886056843840000 + 
       (683263717241282354387229526523147*CF*NM*NC)/
        4257758904584538063110400 + (2545166699*CF*lm*NM*NC)/2074675680 + 
       (595932704330141*CF*NC*NL)/26140913568000 + (2545166699*CF*lm*NC*NL)/
        2074675680 - (2844802745530456515896933452623473179*CF*NC*NH)/
        916412798254581154582968904992000 + (2545166699*CF*lm*NC*NH)/
        2074675680 - (299858419784559523*CF^2*NC*Pi^2)/2335132800 - 
       (429673737985*CF*NM*NC*Pi^2)/8316 - (CF*lm*NM*NC*Pi^2)/81 - 
       (594221*CF*NC*NL*Pi^2)/1122660 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (8845028043282325*CF^2*NC*Pi^3)/
        (298245590523936*Sqrt[3]) + (1149240318557345*CF*NC*NH*Pi^3)/
        (3389154437772*Sqrt[3]) - (1139*CF^2*NC*Pi^4)/1080 - 
       (1701668144467632169237*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (803771866462007520*Sqrt[3]) + (9600519796820567*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) - 
       (310*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (1769005608656465*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1610894393262*Sqrt[3]) + (131341750692268*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) + 
       (1769005608656465*CF^2*NC*Pi*Log[3]^2)/(77322930876576*Sqrt[3]) + 
       (32835437673067*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) + 
       CF*((-576886986407703597497153*NM*NC)/3325441254014880 + 
         (955487*lm*NM*NC)/93555 - (8195732197*NC*NL)/943034400 + 
         (955487*lm*NC*NL)/93555 + (6394837318276427680268815429*NC*NH)/
          2624404600830258935488800 + (955487*lm*NC*NH)/93555 - 
         (3961817863*NM*NC*Pi^2)/81 - (275*NC*NL*Pi^2)/81 - 
         (131341750692268*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (-327094598677705258970204582114122871/
            808316617055719752130550400 - (18376045301419*Pi^2)/149688 - 
           (1769005608656465*Im[PolyLog[2, (-1)^(1/3)]])/(4832683179786*
             Sqrt[3])) + CA*NC*(233639075357491762862077636131516361/
            1154738024365313931615072000 - (955487*lm)/17010 + 
           (18376051624351*Pi^2)/299376 + (1769005608656465*
             Im[PolyLog[2, (-1)^(1/3)]])/(9665366359572*Sqrt[3])))*Log[x] - 
       (CF*NC*(-7*CA*(319619904037582383871 + 46477034604000*lm) + 
          6*(745779196774125154643*CF + 616*(12*(40594494671846611 + 
                1333707375*lm)*NM + 4001122125*(-5 + 4*lm)*NL + 
              4*(4606078088 + 4001122125*lm)*NH)))*Log[x]^2)/2903854393440 + 
       (CF*NC*(22970050042421*CA - 4*(11485120610441*CF + 
            28875*(158472260*NM - 11*NL)))*Log[x]^3)/93555 - 
       (1246350367079420719256*CF^2*NC*PolyGamma[2, 1])/847288609443 - 
       (79433327621*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (1087006889365963*CF*NC*NH*PolyGamma[2, 1])/3389154437772 - 
       (703677165053883037808117*CF^2*NC*Zeta[3])/260964891708444 - 
       (74150953721*CF*NM*NC*Zeta[3])/54 - (182*CF*NC*NL*Zeta[3])/9 - 
       (4540095005914699*CF*NC*NH*Zeta[3])/1694577218886 + 
       CA*CF*NC*(-40904569638979030478385276814846194264339887/
          201610815616007854008253159098240000 + (299858435041541003*Pi^2)/
          4670265600 - (8845028043282325*Pi^3)/(596491181047872*Sqrt[3]) + 
         (3353*Pi^4)/6480 + lm*(-2545166699/377213760 + (11*Pi^2)/162) + 
         (1701668144467632169237*Im[PolyLog[2, (-1)^(1/3)]])/
          (1607543732924015040*Sqrt[3]) + (155*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 - (1769005608656465*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3221788786524*Sqrt[3]) - (1769005608656465*Pi*Log[3]^2)/
          (154645861753152*Sqrt[3]) + (623175183539710359628*PolyGamma[2, 1])/
          847288609443 + (703677234248240805984065*Zeta[3])/521929783416888), 
      (1152444507876145507309435950548223937807366421*CF^2*NC)/
        2258041134899287964892435381900288000 + 
       (18778964369103658684907659138063997*CF*NM*NC)/
        14192529681948460210368000 - (5522482891*CF*lm*NM*NC)/1383117120 - 
       (2548227725293757*CF*NC*NL)/3423214872000 - (5522482891*CF*lm*NC*NL)/
        1383117120 - (333622764162973231053263325037738405302979*CF*NC*NH)/
        20958636308953926518441696742552000000 - (5522482891*CF*lm*NC*NH)/
        1383117120 - (8428140899153396693*CF^2*NC*Pi^2)/51372921600 - 
       (4325523777929*CF*NM*NC*Pi^2)/10395 - (CF*lm*NM*NC*Pi^2)/54 + 
       (10708609*CF*NC*NL*Pi^2)/748440 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (26834082699908549*CF^2*NC*Pi^3)/
        (54226471004352*Sqrt[3]) + (3466011023822375*CF*NC*NH*Pi^3)/
        (1694577218886*Sqrt[3]) + (13151*CF^2*NC*Pi^4)/2160 - 
       (2641199959513617259441*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (730701696783643200*Sqrt[3]) - (279093711385676353*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(46600873519365*Sqrt[3]) + 
       (1639*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (26834082699908549*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1464449448420*Sqrt[3]) + (792231091159400*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) + 
       (26834082699908549*CF^2*NC*Pi*Log[3]^2)/(70293573524160*Sqrt[3]) + 
       (99028886394925*CF*NC*NH*Pi*Log[3]^2)/(62762119218*Sqrt[3]) - 
       (CF*NC*(69*CA*(-3175970125945905250553 + 12863716462396800*lm) + 
          2*(219143122542400884545677*CF - 1848*(115*(-2615453262249631103 + 
                379684665360*lm)*NM + 19*(234834600*(12119 + 9786*lm)*NL + 
                (948651287989 + 2298091395600*lm)*NH))))*Log[x]^2)/
        222628836830400 - (CF*NC*(-29067411388457*CA + 58129621806637*CF + 
          27720*(5390670770*NM + 1631*NL))*Log[x]^3)/93555 - 
       (22434305036391740476339*CF^2*NC*PolyGamma[2, 1])/10167463313316 - 
       (238299910721*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (916380876779003*CF*NC*NH*PolyGamma[2, 1])/5083731656658 - 
       (32116438224092111431139593*CF^2*NC*Zeta[3])/7828946751253320 - 
       (216737349863*CF*NM*NC*Zeta[3])/27 + (6526*CF*NC*NL*Zeta[3])/9 - 
       (11870898816934753*CF*NC*NH*Zeta[3])/2541865828329 + 
       CA*CF*NC*(-180069170799124268983624148969102941047877031/
          705637854656027489028886056843840000 + (8428140386522455343*Pi^2)/
          102745843200 - (26834082699908549*Pi^3)/(108452942008704*Sqrt[3]) - 
         (881*Pi^4)/288 + lm*(5522482891/251475840 + (11*Pi^2)/108) + 
         (2641199959513617259441*Im[PolyLog[2, (-1)^(1/3)]])/
          (1461403393567286400*Sqrt[3]) - (1639*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          6 - (26834082699908549*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2928898896840*Sqrt[3]) - (26834082699908549*Pi*Log[3]^2)/
          (140587147048320*Sqrt[3]) + (22434305036391740476339*
           PolyGamma[2, 1])/20334926626632 + (32116433230818869580850813*
           Zeta[3])/15657893502506640) + CF*Log[x]*
        ((-25988209820290226730644723*NM*NC)/20322140996757600 + 
         (4238299*lm*NM*NC)/124740 + (267599090981*NC*NL)/246985200 + 
         (4238299*lm*NC*NL)/124740 + (27266313837037848128836229564501*NC*
           NH)/1826723728735798653781020000 + (4238299*lm*NC*NH)/124740 - 
         (10781341814*NM*NC*Pi^2)/27 + (3262*NC*NL*Pi^2)/27 - 
         (792231091159400*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CA*NC*
          (4439437642752107132026707197016450673/
            16166332341114395042611008000 - (4238299*lm)/22680 + 
           (232536498725309*Pi^2)/2993760 + (26834082699908549*
             Im[PolyLog[2, (-1)^(1/3)]])/(8786696690520*Sqrt[3]) - 
           312*Zeta[3]) + CF*NC*(-554930800213359106745223966921061439/
            1010395771319649690163188000 - (232536651457889*Pi^2)/1496880 - 
           (26834082699908549*Im[PolyLog[2, (-1)^(1/3)]])/(4393348345260*
             Sqrt[3]) + 624*Zeta[3])), 
      (217936568727382499173485909328771785231409371062197*CF^2*NC)/
        66140115620028754943518777183435269120000 + 
       (344256734285170714030460735892458455991*CF*NM*NC)/
        259020762960400373069321184000 + (462765024461*CF*lm*NM*NC)/
        350620189920 + (3211279383675169*CF*NC*NL)/110445359824800 + 
       (462765024461*CF*lm*NC*NL)/350620189920 - 
       (8974413459902602865435849373594080873897*CF*NC*NH)/
        2229998903272697781562196533407532800 + (462765024461*CF*lm*NC*NH)/
        350620189920 - (737329518428452229333*CF^2*NC*Pi^2)/701240379840 - 
       (3141686545262527*CF*NM*NC*Pi^2)/7297290 - (CF*lm*NM*NC*Pi^2)/81 - 
       (8879873*CF*NC*NL*Pi^2)/14594580 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (56337730993069829*CF^2*NC*Pi^3)/
        (1292397558937056*Sqrt[3]) + (375146869432300*CF*NC*NH*Pi^3)/
        (847288609443*Sqrt[3]) - (811*CF^2*NC*Pi^4)/648 - 
       (66089455789873047592397*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (25155082487422087200*Sqrt[3]) + (171684439015340824*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(65241222927111*Sqrt[3]) - 
       (362*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (56337730993069829*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (34902711854010*Sqrt[3]) + (171495711740480*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) + 
       (56337730993069829*CF^2*NC*Pi*Log[3]^2)/(1675330168992480*Sqrt[3]) + 
       (10718481983780*CF*NC*NH*Pi*Log[3]^2)/(31381059609*Sqrt[3]) + 
       CF*((-71444790240087059952821531051*NM*NC)/48376856642781466800 + 
         (29318287*lm*NM*NC)/2432430 - (10276481291*NC*NL)/766215450 + 
         (29318287*lm*NC*NL)/2432430 + (441946407893120023072482469259*NC*
           NH)/138831003383920697687357520 + (29318287*lm*NC*NH)/2432430 - 
         (32895387752*NM*NC*Pi^2)/81 - (352*NC*NL*Pi^2)/81 - 
         (171495711740480*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (-63441516963102758642719133634618698998321/
            18529311251640615784672650336000 - (1390086649995961*Pi^2)/
            1389960 - (56337730993069829*Im[PolyLog[2, (-1)^(1/3)]])/
            (104708135562030*Sqrt[3])) + 
         CA*NC*(31720760254296358559644109276264682090191/
            18529311251640615784672650336000 - (29318287*lm)/442260 + 
           (1390086724972291*Pi^2)/2779920 + (56337730993069829*
             Im[PolyLog[2, (-1)^(1/3)]])/(209416271124060*Sqrt[3])))*Log[x] - 
       (CF*NC*(-(CA*(27388115829408268431345383 + 622569173927500800*lm)) + 
          2*(27388112518134405333255133*CF + 360360*
             (3*(10373150614853881193 + 52352460160*lm)*NM + 
              5*(981608628*(-41 + 32*lm)*NL + (37897550011 + 31411476096*lm)*
                 NH))))*Log[x]^2)/4341262318192800 + 
       (2*CF*NC*(1216325757716146*CA - 65*(37425460803641*CF + 
            40656*(373811059*NM - 4*NL)))*Log[x]^3)/1216215 - 
       (100954401015557762864891*CF^2*NC*PolyGamma[2, 1])/7625597484987 - 
       (536174843123*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (6102788908832369*CF*NC*NH*PolyGamma[2, 1])/15251194969974 - 
       (533836638028796054319527071*CF^2*NC*Zeta[3])/21809208807062820 - 
       (1006559009482*CF*NM*NC*Zeta[3])/81 - (700*CF*NC*NL*Zeta[3])/27 - 
       (25356951842530409*CF*NC*NH*Zeta[3])/7625597484987 + 
       CA*CF*NC*(-121616403650650201411253672772819173796221002093/
          73817093325924949713748635249369720000 + 
         (1474659047377488385519*Pi^2)/2804961519360 - 
         (56337730993069829*Pi^3)/(2584795117874112*Sqrt[3]) + 
         (3991*Pi^4)/6480 + lm*(-462765024461/63749125440 + (11*Pi^2)/162) + 
         (66089455789873047592397*Im[PolyLog[2, (-1)^(1/3)]])/
          (50310164974844174400*Sqrt[3]) + (181*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 - (56337730993069829*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (69805423708020*Sqrt[3]) - (56337730993069829*Pi*Log[3]^2)/
          (3350660337984960*Sqrt[3]) + (100954401015557762864891*
           PolyGamma[2, 1])/15251194969974 + (533836645366787069421830341*
           Zeta[3])/43618417614125640), 
      (67857005484540786198010461558057535286699950689031459*CF^2*NC)/
        16072048095666987451275062855574770396160000 + 
       (141677119017708596111013099921620373817*CF*NM*NC)/
        13283116049251301183042112000 - (1011061526659*CF*lm*NM*NC)/
        233746793280 - (7677988501437812821*CF*NC*NL)/8099326387152000 - 
       (1011061526659*CF*lm*NC*NL)/233746793280 - 
       (100924461476278736905217454896554892856724153*CF*NC*NH)/
        5017497532363570008514942200166948800000 - 
       (1011061526659*CF*lm*NC*NH)/233746793280 - 
       (36160948700108201776759*CF^2*NC*Pi^2)/26491303238400 - 
       (304968286006607*CF*NM*NC*Pi^2)/90090 - (CF*lm*NM*NC*Pi^2)/54 + 
       (162607597*CF*NC*NL*Pi^2)/9729720 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (42706161216251003525*CF^2*NC*Pi^3)/
        (69789468182601024*Sqrt[3]) + (19840081642179575*CF*NC*NH*Pi^3)/
        (7625597484987*Sqrt[3]) + (571*CF^2*NC*Pi^4)/80 - 
       (11180846105957366313972617*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2445074017777426875840*Sqrt[3]) - (4703357416623226861*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(587171006343999*Sqrt[3]) + 
       635*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (8541232243250200705*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (376949288023308*Sqrt[3]) + (9069751607853520*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) + 
       (8541232243250200705*CF^2*NC*Pi*Log[3]^2)/(18093565825118784*
         Sqrt[3]) + (566859475490845*CF*NC*NH*Pi*Log[3]^2)/
        (282429536481*Sqrt[3]) - 
       (CF*NC*(5*CA*(-948138525696281465541727 + 581253219657766656*lm) + 
          6*(1580232171023546880712185*CF - 8008*((-489371611847546167483 + 
                10997586119520*lm)*NM + 3*(3866943080*(1169 + 948*lm)*NL + 
                (1556886970399 + 3665862039840*lm)*NH))))*Log[x]^2)/
        578834975759040 - (CF*NC*(-1044716156734438*CA + 
          7*(298485996715367*CF + 17160*(43602140393*NM + 2054*NL)))*
         Log[x]^3)/405405 - (1817179201037928351555349*CF^2*NC*
         PolyGamma[2, 1])/91507169819844 - (2144699279201*CF*NM*NC*
         PolyGamma[2, 1])/54 + (10459486628114339*CF*NC*NH*PolyGamma[2, 1])/
        45753584909922 - (6803893119708575431995019655*CF^2*NC*Zeta[3])/
        183197353979327688 - (1970290871855*CF*NM*NC*Zeta[3])/27 + 
       (8218*CF*NC*NL*Zeta[3])/9 - (134142176613865813*CF*NC*NH*Zeta[3])/
        22876792454961 + CA*CF*NC*
        (-302932989230246373056384045735756804626130946845633/
          143500429425598102243527346924774735680000 + 
         (2127114610792019680417*Pi^2)/3116623910400 - 
         (42706161216251003525*Pi^3)/(139578936365202048*Sqrt[3]) - 
         (15481*Pi^4)/4320 + lm*(1011061526659/42499416960 + (11*Pi^2)/108) + 
         (11180846105957366313972617*Im[PolyLog[2, (-1)^(1/3)]])/
          (4890148035554853751680*Sqrt[3]) - 
         (635*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
         (8541232243250200705*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (753898576046616*Sqrt[3]) - (8541232243250200705*Pi*Log[3]^2)/
          (36187131650237568*Sqrt[3]) + (1817179201037928351555349*
           PolyGamma[2, 1])/183014339639688 + (6803892973690106679694223003*
           Zeta[3])/366394707958655376) + CF*Log[x]*
        ((-116133939380672506805409101563*NM*NC)/10750412587284770400 + 
         (64439527*lm*NM*NC)/1621620 + (15442810620553*NC*NL)/11237826600 + 
         (64439527*lm*NC*NL)/1621620 + (1185444015178490969669908072625951*
           NC*NH)/62473951522764313959310884000 + (64439527*lm*NC*NH)/
          1621620 - (87204281384*NM*NC*Pi^2)/27 + (4108*NC*NL*Pi^2)/27 - 
         (9069751607853520*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (282429536481*Sqrt[3]) + CA*NC*
          (2331330425758051195957242613437158418949463/
            1000582807588593252372323118144000 - (64439527*lm)/294840 + 
           (1671542801313569*Pi^2)/2594592 + (8541232243250200705*
             Im[PolyLog[2, (-1)^(1/3)]])/(2261695728139848*Sqrt[3]) - 
           364*Zeta[3]) + CF*NC*(-233133110272997536953496540458022494004577/
            50029140379429662618616155907200 - (1671542967715805*Pi^2)/
            1297296 - (8541232243250200705*Im[PolyLog[2, (-1)^(1/3)]])/
            (1130847864069924*Sqrt[3]) + 728*Zeta[3])), 
      (172343288849316689323324667317787886044575571500760977*CF^2*NC)/
        6377796863359915655267882085545543808000000 + 
       (179436830689667652303805862957672735889473*CF*NM*NC)/
        16188797685025023316832574000000 + (495372951461*CF*lm*NM*NC)/
        350620189920 + (451860337268089*CF*NC*NL)/12396928143600 + 
       (495372951461*CF*lm*NC*NL)/350620189920 - 
       (16040643305431412399877784273800798089574781*CF*NC*NH)/
        3135935957727231255321838875104343000000 + 
       (495372951461*CF*lm*NC*NH)/350620189920 - 
       (10563392853324980362321*CF^2*NC*Pi^2)/1216437393600 - 
       (10534734058674877*CF*NM*NC*Pi^2)/2918916 - (CF*lm*NM*NC*Pi^2)/81 - 
       (5061409*CF*NC*NL*Pi^2)/7297290 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (21506863650735053*CF^2*NC*Pi^3)/
        (352472061528288*Sqrt[3]) + (4320679188501305*CF*NC*NH*Pi^3)/
        (7625597484987*Sqrt[3]) - (4747*CF^2*NC*Pi^4)/3240 - 
       (198446442160880654921641*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (61744293378217850400*Sqrt[3]) + (8826931972406733277*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2935855031719995*Sqrt[3]) - 
       (418*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (21506863650735053*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9518921414730*Sqrt[3]) + (1975167629029168*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) + 
       (21506863650735053*CF^2*NC*Pi*Log[3]^2)/(456908227907040*Sqrt[3]) + 
       (123447976814323*CF*NC*NH*Pi*Log[3]^2)/(282429536481*Sqrt[3]) + 
       CF*((-5633532489690886116093946499*NM*NC)/447271233753526875 + 
         (34156417*lm*NM*NC)/2432430 - (1302920303093*NC*NL)/67426959600 + 
         (34156417*lm*NC*NL)/2432430 + (5683473855646432195665161102759*NC*
           NH)/1394507846490274865163189375 + (34156417*lm*NC*NH)/2432430 - 
         (274976297456*NM*NC*Pi^2)/81 - (442*NC*NL*Pi^2)/81 - 
         (1975167629029168*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (282429536481*Sqrt[3]) + CF*NC*
          (-8064353724788044256257445574678290929361779/
            277939668774609236770089755040000 - (80035436841419603*Pi^2)/
            9729720 - (21506863650735053*Im[PolyLog[2, (-1)^(1/3)]])/
            (28556764244190*Sqrt[3])) + 
         CA*NC*(366561536291779472441086787793499427275477/
            25267242615873566979099068640000 - (34156417*lm)/442260 + 
           (80035437499226753*Pi^2)/19459440 + (21506863650735053*
             Im[PolyLog[2, (-1)^(1/3)]])/(57113528488380*Sqrt[3])))*Log[x] - 
       (CF*NC*(-3*CA*(75397981590069621657385553 + 260582930753745600*lm) + 
          2*(226193940628302130033902929*CF + 144144*
             ((652187825966190230799 + 493035242700*lm)*NM + 
              7250518275*(-89 + 68*lm)*NL + 4*(154821073109 + 123258810675*
                 lm)*NH)))*Log[x]^2)/4341262318192800 - 
       (2*CF*NC*(-10004429521960779*CA + 20008863680391101*CF + 
          60060*(137488139576*NM - 221*NL))*Log[x]^3)/1216215 - 
       (8177306726649775256119124*CF^2*NC*PolyGamma[2, 1])/68630377364883 - 
       (19302293735441*CF*NM*NC*PolyGamma[2, 1])/324 - 
       (134986076068871041*CF*NC*NH*PolyGamma[2, 1])/274521509459532 - 
       (304814978694563443239637178677*CF^2*NC*Zeta[3])/1373980154844957660 - 
       (18202388799977*CF*NM*NC*Zeta[3])/162 - (880*CF*NC*NL*Zeta[3])/27 - 
       (558305021964344929*CF*NC*NH*Zeta[3])/137260754729766 + 
       CA*CF*NC*(-75400190257080541560507234406989895496690201861262979/
          5580572255439926198359396824852350832000000 + 
         (8699264711296343722357*Pi^2)/2003543942400 - 
         (21506863650735053*Pi^3)/(704944123056576*Sqrt[3]) + 
         (1561*Pi^4)/2160 + lm*(-495372951461/63749125440 + (11*Pi^2)/162) + 
         (198446442160880654921641*Im[PolyLog[2, (-1)^(1/3)]])/
          (123488586756435700800*Sqrt[3]) + 
         (209*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (21506863650735053*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (19037842829460*Sqrt[3]) - (21506863650735053*Pi*Log[3]^2)/
          (913816455814080*Sqrt[3]) + (4088653363324887628059562*
           PolyGamma[2, 1])/68630377364883 + (304814979271049894504863210207*
           Zeta[3])/2747960309689915320), 
      (2492421528679323376084307349978410560687985106262634257*CF^2*NC)/
        70906094539707297579154689068712222336000000 + 
       (1876378387548722910352893536783754881048663*CF*NM*NC)/
        21585063580033364422443432000000 - (1088844614899*CF*lm*NM*NC)/
        233746793280 - (49941649730237216059*CF*NC*NL)/42116497213190400 - 
       (1088844614899*CF*lm*NC*NL)/233746793280 - 
       (45905555894425684893481403413609276687484730724337*CF*NC*NH)/
        1835576209752226634065063879798075714248000000 - 
       (1088844614899*CF*lm*NC*NH)/233746793280 - 
       (23275952206766806561897*CF^2*NC*Pi^2)/2037792556800 - 
       (9017427100010215*CF*NM*NC*Pi^2)/324324 - (CF*lm*NM*NC*Pi^2)/54 + 
       (187807057*CF*NC*NL*Pi^2)/9729720 - (CF*lm*NC*NL*Pi^2)/54 - 
       (CF*lm*NC*NH*Pi^2)/54 + (156043449734891732461*CF^2*NC*Pi^3)/
        (209368404547803072*Sqrt[3]) + (297791855598500725*CF*NC*NH*Pi^3)/
        (91507169819844*Sqrt[3]) + (17863*CF^2*NC*Pi^4)/2160 - 
       (29793838296011025587450111*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5239444323808771876800*Sqrt[3]) - (1198457304240800394394*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(114498346237079805*Sqrt[3]) + 
       (2191*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (22291921390698818923*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (807748474335660*Sqrt[3]) + (34033354925542940*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (22291921390698818923*CF^2*NC*Pi*Log[3]^2)/(38771926768111680*
         Sqrt[3]) + (8508338731385735*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) - 
       (CF*NC*(5423*CA*(-1060673683289372998510859 + 96264418027377600*lm) + 
          2*(5752034083557633864427926637*CF - 
            24024*(29*(-20097139671493890779867 + 68119176925800*lm)*NM + 
              452878526100*(5359 + 4362*lm)*NL + (859897721616173 + 
                1975456130848200*lm)*NH)))*Log[x]^2)/83931071485060800 - 
       (CF*NC*(-26155605679208372*CA + 52311091354424323*CF + 
          180180*(712972337614*NM + 5089*NL))*Log[x]^3)/1216215 - 
       (147191520892931727407213875*CF^2*NC*PolyGamma[2, 1])/
        823564528378596 - (19302293617217*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (117292412815563323*CF*NC*NH*PolyGamma[2, 1])/411782264189298 - 
       (251771232612706050086065762691*CF^2*NC*Zeta[3])/749443720824522360 - 
       (17876349133349*CF*NM*NC*Zeta[3])/27 + (10180*CF*NC*NL*Zeta[3])/9 - 
       (1491586646956933885*CF*NC*NH*Zeta[3])/205891132094649 + 
       CA*CF*NC*(-178030103098092382885121038851128329729641894074959763/
          10129442077101042511307812724101746048000000 + 
         (23275952178067385244407*Pi^2)/4075585113600 - 
         (156043449734891732461*Pi^3)/(418736809095606144*Sqrt[3]) - 
         (17927*Pi^4)/4320 + lm*(1088844614899/42499416960 + (11*Pi^2)/108) + 
         (29793838296011025587450111*Im[PolyLog[2, (-1)^(1/3)]])/
          (10478888647617543753600*Sqrt[3]) - 
         (2191*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (22291921390698818923*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1615496948671320*Sqrt[3]) - (22291921390698818923*Pi*Log[3]^2)/
          (77543853536223360*Sqrt[3]) + (147191520892931727407213875*
           PolyGamma[2, 1])/1647129056757192 + 
         (251771231877265823971023829751*Zeta[3])/1498887441649044720) + 
       CF*Log[x]*((-12278080962637378116910823524723*NM*NC)/
          134380157341059630000 + (74503867*lm*NM*NC)/1621620 + 
         (1000889675967121*NC*NL)/584366983200 + (74503867*lm*NC*NL)/
          1621620 + (9347307512202574642088302601574479563*NC*NH)/
          394054449229835910298353400830000 + (74503867*lm*NC*NH)/1621620 - 
         (712972338629*NM*NC*Pi^2)/27 + (5089*NC*NL*Pi^2)/27 - 
         (34033354925542940*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CA*NC*
          (1590791869154632578332731844005135041594767/
            80260653015127800992432335680000 - (74503867*lm)/294840 + 
           (19022253522084823*Pi^2)/3538080 + (22291921390698818923*
             Im[PolyLog[2, (-1)^(1/3)]])/(4846490846013960*Sqrt[3]) - 
           420*Zeta[3]) + CF*NC*(-336513678756208123525215240728810625934951/
            8489107530446209720353420120000 - (19022253802777963*Pi^2)/
            1769040 - (22291921390698818923*Im[PolyLog[2, (-1)^(1/3)]])/
            (2423245423006980*Sqrt[3]) + 840*Zeta[3])), 
      (64804703340021114533236869917200521089044001092320676597*CF^2*NC)/
        290070386753348035551087364372004545920000000 + 
       (81274485131942489620201859002699532683392211*CF*NM*NC)/
        874195074991351259108958996000000 + (2639808769393*CF*lm*NM*NC)/
        1753100949600 + (364527842164427723*CF*NC*NL)/8099326387152000 + 
       (2639808769393*CF*lm*NC*NL)/1753100949600 - 
       (166527509269072722810441761569129399554404633*CF*NC*NH)/
        26052391033426228890366046039328388000000 + 
       (2639808769393*CF*lm*NC*NH)/1753100949600 - 
       (287019730838208923994463*CF^2*NC*Pi^2)/3973695485760 - 
       (110951394473014024*CF*NM*NC*Pi^2)/3648645 - (CF*lm*NM*NC*Pi^2)/81 - 
       (2290801*CF*NC*NL*Pi^2)/2918916 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (77565672549903418835*CF^2*NC*Pi^3)/
        (942157820465113824*Sqrt[3]) + (293449694073906965*CF*NC*NH*Pi^3)/
        (411782264189298*Sqrt[3]) - (1831*CF^2*NC*Pi^4)/1080 - 
       (640838770755600032829544519*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (165042496199976314119200*Sqrt[3]) + (697692878106209459938*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(206097023226743649*Sqrt[3]) - 
       (478*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (15513134509980683767*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5088815388314658*Sqrt[3]) + (67074215788321592*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) + 
       (15513134509980683767*CF^2*NC*Pi*Log[3]^2)/(244263138639103584*
         Sqrt[3]) + (8384276973540199*CF*NC*NH*Pi*Log[3]^2)/
        (15251194969974*Sqrt[3]) + 
       CF*((-53258482180387174491253839218321*NM*NC)/494763306573901365000 + 
         (7871351*lm*NM*NC)/486486 - (22098988757*NC*NL)/832431600 + 
         (7871351*lm*NC*NL)/486486 + (10812564615443441711187271827691409*NC*
           NH)/2108495863893295596126742335000 + (7871351*lm*NC*NH)/
          486486 - (85604576474*NM*NC*Pi^2)/3 - (182*NC*NL*Pi^2)/27 - 
         (67074215788321592*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7625597484987*Sqrt[3]) + 
         CF*NC*(-699281870876919268144127033271489997059580601/
            2837787374463447249375286154400000 - (663475303288031537*Pi^2)/
            9729720 - (15513134509980683767*Im[PolyLog[2, (-1)^(1/3)]])/
            (15266446164943974*Sqrt[3])) + 
         CA*NC*(188268196276070759553312769138011081692850607/
            1528039355480317749663615621600000 - (7871351*lm)/88452 + 
           (663475304099412107*Pi^2)/19459440 + (15513134509980683767*
             Im[PolyLog[2, (-1)^(1/3)]])/(30532892329887948*Sqrt[3])))*
        Log[x] - (CF*NC*(-17*CA*(553357162470674213420763817 + 
            284026377811176000*lm) + 2*(9407071736507087866408235499*CF + 
            40040*((98910949110745125841031 + 10962783631800*lm)*NM + 
              11*(332205564600*(-4 + 3*lm)*NL + (1296387748549 + 
                  996616693800*lm)*NH))))*Log[x]^2)/21706311590964000 + 
       (2*CF*NC*(82934412801289972*CA - 11*(15078984702402749*CF + 
            16380*(385220590360*NM - 91*NL)))*Log[x]^3)/1216215 - 
       (662361847613906959823038145*CF^2*NC*PolyGamma[2, 1])/
        617673396283947 - (86860321415891*CF*NM*NC*PolyGamma[2, 1])/162 - 
       (368307958452642544*CF*NC*NH*PolyGamma[2, 1])/617673396283947 - 
       (24834503051881956380225075758327*CF^2*NC*Zeta[3])/
        12365821393604618940 - (82237674446891*CF*NM*NC*Zeta[3])/81 - 
       (1088*CF*NC*NL*Zeta[3])/27 - (3034360951081567928*CF*NC*NH*Zeta[3])/
        617673396283947 + CA*CF*NC*
        (-178212934667822676282945201568274398073838149816851327673/
          1595387127143414195530980504046025002560000000 + 
         (574039461753179042543971*Pi^2)/15894781943040 - 
         (77565672549903418835*Pi^3)/(1884315640930227648*Sqrt[3]) + 
         (5429*Pi^4)/6480 + lm*(-2639808769393/318745627200 + 
           (11*Pi^2)/162) + (640838770755600032829544519*
           Im[PolyLog[2, (-1)^(1/3)]])/(330084992399952628238400*Sqrt[3]) + 
         (239*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (15513134509980683767*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (10177630776629316*Sqrt[3]) - (15513134509980683767*Pi*Log[3]^2)/
          (488526277278207168*Sqrt[3]) + (662361847613906959823038145*
           PolyGamma[2, 1])/1235346792567894 + 
         (24834503058255163328473411864237*Zeta[3])/24731642787209237880), 
      (5320741450532694010583337696952956213965566508535108423059*CF^2*NC)/
        18081054107625360882684445712521616695680000000 + 
       (416643580607820941182292077543523895758110951*CF*NM*NC)/
        582796716660900839405972664000000 - (5833223910719*CF*lm*NM*NC)/
        1168733966400 - (27960078034662400751*CF*NC*NL)/19143862369632000 - 
       (5833223910719*CF*lm*NC*NL)/1168733966400 - 
       (5029554329506519376526657612124741399484109155298277771*CF*NC*NH)/
        164050952594185750966296954129193420809486504000000 - 
       (5833223910719*CF*lm*NC*NH)/1168733966400 - 
       (4143896451017012066002253*CF^2*NC*Pi^2)/43142979559680 - 
       (1119760579286320351*CF*NM*NC*Pi^2)/4864860 - 
       (CF*lm*NM*NC*Pi^2)/54 + (214810033*CF*NC*NL*Pi^2)/9729720 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (51157213885686414475*CF^2*NC*Pi^3)/(57100473967582656*Sqrt[3]) + 
       (1101194234924647325*CF*NC*NH*Pi^3)/(274521509459532*Sqrt[3]) + 
       (20489*CF^2*NC*Pi^4)/2160 - (69687892174884915763101551*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10002575527271291764800*Sqrt[3]) - 
       (921213366572939508424*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (68699007742247883*Sqrt[3]) + 
       (2497*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (10231442777137282895*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (308413053837252*Sqrt[3]) + (125850769705673980*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) + 
       (10231442777137282895*CF^2*NC*Pi*Log[3]^2)/(14803826584188096*
         Sqrt[3]) + (31462692426418495*CF*NC*NH*Pi*Log[3]^2)/
        (10167463313316*Sqrt[3]) + ((-8339591462437115996964391523*CF^2*NC)/
          7235437196988000 + CA*CF*(102957917469072460990327163/
            178652770296000 - (68365*lm)/9)*NC + 
         CF*NC*((-499122080235440329681331/180705224700 + (12430*lm)/9)*NM + 
           (5*(9133 + 7458*lm)*NL)/27 + (99794193508741799*NH)/
            162453997005300 + (12430*lm*NH)/9))*Log[x]^2 - 
       (CF*NC*(-219437171836068875*CA + 438874188247712281*CF + 
          180180*(5880256349912*NM + 6215*NL))*Log[x]^3)/1216215 - 
       (11922513255050315977241607445*CF^2*NC*PolyGamma[2, 1])/
        7412080755407364 - (57906880894843*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (1295477726635994771*CF*NC*NH*PolyGamma[2, 1])/3706040377703682 - 
       (225301999929824965757808760043887*CF^2*NC*Zeta[3])/
        74194928361627713640 - (17995570024301*CF*NM*NC*Zeta[3])/3 + 
       (4144*CF*NC*NL*Zeta[3])/3 - (16355431767083534233*CF*NC*NH*Zeta[3])/
        1853020188851841 + CA*CF*NC*
        (-2660370712177071387211655834513089442512103091157450475467/
          18081054107625360882684445712521616695680000000 + 
         (12829400774955812443069*Pi^2)/267139192320 - 
         (51157213885686414475*Pi^3)/(114200947935165312*Sqrt[3]) - 
         (6851*Pi^4)/1440 + lm*(5833223910719/212497084800 + (11*Pi^2)/108) + 
         (69687892174884915763101551*Im[PolyLog[2, (-1)^(1/3)]])/
          (20005151054542583529600*Sqrt[3]) - 
         (2497*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (10231442777137282895*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (616826107674504*Sqrt[3]) - (10231442777137282895*Pi*Log[3]^2)/
          (29607653168376192*Sqrt[3]) + (11922513255050315977241607445*
           PolyGamma[2, 1])/14824161510814728 + 
         (225301999841353009607187091358827*Zeta[3])/148389856723255427280) + 
       CF*Log[x]*((-2809714779148555775817564297570571*NM*NC)/
          3628264248208610010000 + (85290643*lm*NM*NC)/1621620 + 
         (111715047275317*NC*NL)/53124271200 + (85290643*lm*NC*NL)/
          1621620 + (33200793791706008006157445512915057364409*NC*NH)/
          1136058977129616929390152854592890000 + (85290643*lm*NC*NH)/
          1621620 - (5880256351447*NM*NC*Pi^2)/27 + (6215*NC*NL*Pi^2)/27 - 
         (125850769705673980*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (2541865828329*Sqrt[3]) + 
         CA*NC*(38053580186997080301838632808527580245211857989/
            225131131707433481783772701582400000 - (85290643*lm)/294840 + 
           (1755497305429851059*Pi^2)/38918880 + (10231442777137282895*
             Im[PolyLog[2, (-1)^(1/3)]])/(1850478323023512*Sqrt[3]) - 
           480*Zeta[3]) + CF*NC*
          (-19026790207172172932586125482205054213815431757/
            56282782926858370445943175395600000 - (1755497309196153599*Pi^2)/
            19459440 - (10231442777137282895*Im[PolyLog[2, (-1)^(1/3)]])/
            (925239161511756*Sqrt[3]) + 960*Zeta[3])), 
      (29522250625983403552816830673030147439175993684089308596729369821*CF^2*
         NC)/15875237830711497356440474073376829545273822720000000 + 
       (38188941119101121870193795665790662389019041597819*CF*NM*NC)/
        48733128420489293390647773607872000000 + 
       (22421401113473*CF*lm*NM*NC)/14024807596800 + 
       (69288009228531793241*CF*NC*NL)/1263494916395712000 + 
       (22421401113473*CF*lm*NC*NL)/14024807596800 - 
       (3120714852253780932449035074535160037495397619003791*CF*NC*NH)/
        396484461306480952958053798036384354277568000000 + 
       (22421401113473*CF*lm*NC*NH)/14024807596800 - 
       (8596239263734212472061413*CF^2*NC*Pi^2)/14222960294400 - 
       (834560286315701021*CF*NM*NC*Pi^2)/3243240 - (CF*lm*NM*NC*Pi^2)/81 - 
       (51494693*CF*NC*NL*Pi^2)/58378320 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (610069020843007395445*CF^2*NC*Pi^3)/
        (5652946922790682944*Sqrt[3]) + (2181398075505603535*CF*NC*NH*Pi^3)/
        (2470693585135788*Sqrt[3]) - (6293*CF^2*NC*Pi^4)/3240 - 
       (9188583573312401733045401407*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1980509954399715769430400*Sqrt[3]) + 
       (1056986023535357502889*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (281041395309195885*Sqrt[3]) - 
       (542*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (122013804168601479089*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (30532892329887948*Sqrt[3]) + (249302637200640404*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) + 
       (122013804168601479089*CF^2*NC*Pi*Log[3]^2)/(1465578831834621504*
         Sqrt[3]) + (62325659300160101*CF*NC*NH*Pi*Log[3]^2)/
        (91507169819844*Sqrt[3]) + 
       CF*((-6137720420004243794499848934575262847*NM*NC)/
          6657535053258416767440000 + (179676247*lm*NM*NC)/9729720 - 
         (61720640717261*NC*NL)/1753100949600 + (179676247*lm*NC*NL)/
          9729720 + (540965286537628997553604283796847036409*NC*NH)/
          85115761033644556624444334579280000 + (179676247*lm*NC*NH)/
          9729720 - (19519021892125*NM*NC*Pi^2)/81 - (665*NC*NL*Pi^2)/81 - 
         (249302637200640404*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (22876792454961*Sqrt[3]) + 
         CF*NC*(-21151842013769360080222106837002733566508142173633/
            10082943999370201323203405788622400000 - 
           (11072120934389233091*Pi^2)/19459440 - (122013804168601479089*
             Im[PolyLog[2, (-1)^(1/3)]])/(91598676989663844*Sqrt[3])) + 
         CA*NC*(1021331800317976780052045436445799534177489508268747/
            973724306224893727783643187586963200000 - (179676247*lm)/
            1769040 + (11072120936363285171*Pi^2)/38918880 + 
           (122013804168601479089*Im[PolyLog[2, (-1)^(1/3)]])/
            (183197353979327688*Sqrt[3])))*Log[x] - 
       (CF*NC*(-(CA*(9130903867148256579301215766267 + 682173097681355280000*
              lm)) + 2*(9130903863557518028161186700187*CF + 
            40040*((97091191423528985791102727 + 1548844559262000*lm)*NM + 
              20379533674500*(-103 + 76*lm)*NL + (2077544621073893 + 
                1548844559262000*lm)*NH)))*Log[x]^2)/2517932144551824000 - 
       (CF*NC*(-5536060466067590471*CA + 4*(2768030248916568767*CF + 
            300300*(3903804372904*NM - 133*NL)))*Log[x]^3)/4864860 - 
       (53651309687302892517995199776*CF^2*NC*PolyGamma[2, 1])/
        5559060566555523 - (521161928166641*CF*NM*NC*PolyGamma[2, 1])/108 - 
       (15892725762889493047*CF*NC*NH*PolyGamma[2, 1])/22236242266222092 - 
       (4043102264371710546730162498187309*CF^2*NC*Zeta[3])/
        222584785084883140920 - (495136565776733*CF*NM*NC*Zeta[3])/54 - 
       (442*CF*NC*NL*Zeta[3])/9 - (65231927615032260343*CF*NC*NH*Zeta[3])/
        11118121133111046 + CA*CF*NC*
        (-29522250637563676430845362422672052747720248086037198943759957071/
          31750475661422994712880948146753659090547645440000000 + 
         (3167035518274715142361489*Pi^2)/10480076006400 - 
         (610069020843007395445*Pi^3)/(11305893845581365888*Sqrt[3]) + 
         (6229*Pi^4)/6480 + lm*(-22421401113473/2549965017600 + 
           (11*Pi^2)/162) + (9188583573312401733045401407*
           Im[PolyLog[2, (-1)^(1/3)]])/(3961019908799431538860800*Sqrt[3]) + 
         (271*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (122013804168601479089*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (61065784659775896*Sqrt[3]) - (122013804168601479089*Pi*Log[3]^2)/
          (2931157663669243008*Sqrt[3]) + (26825654843651446258997599888*
           PolyGamma[2, 1])/5559060566555523 + 
         (4043102264510784818003569112532509*Zeta[3])/445169570169766281840), 
      (176838362777585920112913807375797532687867753623578031060961374581*
         CF^2*NC)/71438570238201738103982133330195732953732202240000000 + 
       (134716271685387349168229685075869726665044738234893*CF*NM*NC)/
        22742126596228336915635627683673600000 - 
       (24889178546051*CF*lm*NM*NC)/4674935865600 - 
       (1494991936697252358151*CF*NC*NL)/842329944263808000 - 
       (24889178546051*CF*lm*NC*NL)/4674935865600 - 
       (112748657941171442062069428276418879936134282996237675299*CF*NC*NH)/
        3037286208029496189318869322163352476701350131200000 - 
       (24889178546051*CF*lm*NC*NH)/4674935865600 - 
       (1633192656564934758408394441*CF^2*NC*Pi^2)/2013339046118400 - 
       (3732570767775662083*CF*NM*NC*Pi^2)/1945944 - 
       (CF*lm*NM*NC*Pi^2)/54 + (487232621*CF*NC*NL*Pi^2)/19459440 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (108334628246011013737595*CF^2*NC*Pi^3)/(101753044610232292992*
         Sqrt[3]) + (27135609746709301390*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) + (1553*CF^2*NC*Pi^4)/144 - 
       (300374604279614883073723368161*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (35649179179194883849747200*Sqrt[3]) - 
       (469894223082737945803111*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) + 941*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 + (21666925649202202747519*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(549592061937983064*
         Sqrt[3]) + (12404850169924252064*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (21666925649202202747519*CF^2*NC*Pi*Log[3]^2)/(26380418973023187072*
         Sqrt[3]) + (775303135620265754*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + 
       ((-209488365235825659258795711311*CF^2*NC)/21520787560272000 + 
         CA*CF*(742731474867139431768694839419/152601948154656000 - 
           (82456*lm)/9)*NC + CF*NC*((-48248926721737981732245589/
              2096180606520 + (14992*lm)/9)*NM + (8*(6865 + 5622*lm)*NL)/
            27 + (49071111646742657*NH)/64981598802120 + (14992*lm*NH)/9))*
        Log[x]^2 - (CF*NC*(-2466004812387618111*CA + 
          280*(17614319144884217*CF + 1716*(24424818258223*NM + 3748*NL)))*
         Log[x]^3)/1621620 - (965723574350248727394627334339*CF^2*NC*
         PolyGamma[2, 1])/66708726798666276 - 
       (173720642702137*CF*NM*NC*PolyGamma[2, 1])/6 + 
       (14120573605566410747*CF*NC*NH*PolyGamma[2, 1])/33354363399333138 - 
       (36636657846848471968136731538259959*CF^2*NC*Zeta[3])/
        1335508710509298845520 - (488595503856293*CF*NM*NC*Zeta[3])/9 + 
       1666*CF*NC*NL*Zeta[3] - (177158053062061160425*CF*NC*NH*Zeta[3])/
        16677181699666569 + CA*CF*NC*
        (-88419181327155485291001463095352732015160466093607841753675220353/
          71438570238201738103982133330195732953732202240000000 + 
         (4899577969581166805915539043*Pi^2)/12080034276710400 - 
         (108334628246011013737595*Pi^3)/(203506089220464585984*Sqrt[3]) - 
         (23359*Pi^4)/4320 + lm*(24889178546051/849988339200 + 
           (11*Pi^2)/108) + (300374604279614883073723368161*
           Im[PolyLog[2, (-1)^(1/3)]])/(71298358358389767699494400*Sqrt[3]) - 
         (941*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
         (21666925649202202747519*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1099184123875966128*Sqrt[3]) - (21666925649202202747519*Pi*
           Log[3]^2)/(52760837946046374144*Sqrt[3]) + 
         (965723574350248727394627334339*PolyGamma[2, 1])/
          133417453597332552 + (36636657844935701983331181871382879*Zeta[3])/
          2671017421018597691040) + CF*Log[x]*
        ((-32121111814381597813609939886206341397*NM*NC)/
          4882192372389505629456000 + (193599281*lm*NM*NC)/3243240 + 
         (1489089285418733*NC*NL)/584366983200 + (193599281*lm*NC*NL)/
          3243240 + (5233769970574054338113224235538419226254557*NC*NH)/
          147233243435998354048963809955238544000 + (193599281*lm*NC*NH)/
          3243240 - (48849636518614*NM*NC*Pi^2)/27 + (7496*NC*NL*Pi^2)/27 - 
         (12404850169924252064*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CA*NC*(177276226588990454727142002184646400059562617088765551/
            122689262584336609700739041635957363200000 - (193599281*lm)/
            589680 + (3288006397948584283*Pi^2)/8648640 + 
           (21666925649202202747519*Im[PolyLog[2, (-1)^(1/3)]])/
            (3297552371627898384*Sqrt[3]) - 544*Zeta[3]) + 
         CF*NC*(-177276226737612010653332580888145165027598350570688501/
            61344631292168304850369520817978681600000 - 
           (9864019196871135209*Pi^2)/12972960 - (21666925649202202747519*
             Im[PolyLog[2, (-1)^(1/3)]])/(1648776185813949192*Sqrt[3]) + 
           1088*Zeta[3])), (1942349916957461414891419298148234136619341867831\
3519531732313477300647*CF^2*NC)/
        1247581020049191574398187568230263391973062504408320000000 + 
       (3806223555459416878526491307480622311536816589036833*CF*NM*NC)/
        573837402677785193439046570573958400000 + 
       (3428092108845661*CF*lm*NM*NC)/2026584697737600 + 
       (24111649922356910330999*CF*NC*NL)/365150030838360768000 + 
       (3428092108845661*CF*lm*NC*NL)/2026584697737600 - 
       (101711474803269333350546045377453597879575298951686612719*CF*NC*NH)/
        10630501728103236662616042627571733668454725459200000 + 
       (3428092108845661*CF*lm*NC*NH)/2026584697737600 - 
       (8603541786052846913641297327*CF^2*NC*Pi^2)/1692532275033600 - 
       (446323347568195675*CF*NM*NC*Pi^2)/204204 - (CF*lm*NM*NC*Pi^2)/81 - 
       (488988623*CF*NC*NL*Pi^2)/496215720 - (CF*lm*NC*NL*Pi^2)/81 - 
       (CF*lm*NC*NH*Pi^2)/81 + (119526011708821439772755*CF^2*NC*Pi^3)/
        (864900879186974490432*Sqrt[3]) + (6001106569794365120*CF*NC*NH*
         Pi^3)/(5559060566555523*Sqrt[3]) - (7147*CF^2*NC*Pi^4)/3240 - 
       (5655671215882513821801004326293*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1030261278278732143257694080*Sqrt[3]) + 
       (114816830163654266854432*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) - 
       (610*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (23905202341764287954551*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) + (2743363003334566912*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (23905202341764287954551*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) + (171460187708410432*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + 
       CF*((-220089430576058569992996120345982070609*NM*NC)/
          27816918200788428319608000 + (1728666817*lm*NM*NC)/82702620 - 
         (676861243895801*NC*NL)/14901358071600 + (1728666817*lm*NC*NL)/
          82702620 + (572248326899373438472109231602881024482791*NC*NH)/
          73616621717999177024481904977619272000 + (1728666817*lm*NC*NH)/
          82702620 - (165501992364508*NM*NC*Pi^2)/81 - 
         (800*NC*NL*Pi^2)/81 - (2743363003334566912*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-23793910865259124717324887971195117438147469420888373927/
            1329160797639461003104093980906256924800000 - 
           (315855024003612355555*Pi^2)/66162096 - 
           (23905202341764287954551*Im[PolyLog[2, (-1)^(1/3)]])/
            (14014597579418568132*Sqrt[3])) + 
         CA*NC*(309320841258509868029267105419917082922872156446703189351/
            34558180738625986080706443503562680044800000 - 
           (1728666817*lm)/15036840 + (315855024011678617759*Pi^2)/
            132324192 + (23905202341764287954551*Im[PolyLog[2, (-1)^(1/3)]])/
            (28029195158837136264*Sqrt[3])))*Log[x] - 
       (CF*NC*(-87*CA*(465186334839586486102461301410259 + 
            4971120525148377600000*lm) + 
          22*(3679201011706722171877832039902793*CF + 
            618800*(253*(10104800352239782282599431 + 22830601248000*lm)*
               NM + 722017764468000*(-11 + 8*lm)*NL + (7961358297424079 + 
                5776142115744000*lm)*NH)))*Log[x]^2)/
        1326950240178811248000 + (CF*NC*(394818779992475018643*CA - 
          34*(23224634137473261763*CF + 1201200*(8275099616563*NM - 
              40*NL)))*Log[x]^3)/41351310 - (4345756085006230043253361193999*
         CF^2*NC*PolyGamma[2, 1])/50031545098999707 - 
       (1172614338273608*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (84843028993607126783*CF*NC*NH*PolyGamma[2, 1])/100063090197999414 - 
       (1118195952206536975019094078840713813*CF^2*NC*Zeta[3])/
        6811094423597424112152 - (2234894015052196*CF*NM*NC*Zeta[3])/27 - 
       (532*CF*NC*NL*Zeta[3])/9 - (347117035830111566135*CF*NC*NH*Zeta[3])/
        50031545098999707 + CA*CF*NC*(-24279373963325638922750212674603684294\
26056629049568620502821243712159/
          311895255012297893599546892057565847993265626102080000000 + 
         (1229077398010478398476160741*Pi^2)/483580650009600 - 
         (119526011708821439772755*Pi^3)/(1729801758373948980864*Sqrt[3]) + 
         (787*Pi^4)/720 + lm*(-3428092108845661/368469945043200 + 
           (11*Pi^2)/162) + (5655671215882513821801004326293*
           Im[PolyLog[2, (-1)^(1/3)]])/(2060522556557464286515388160*
           Sqrt[3]) + (305*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (23905202341764287954551*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) - (23905202341764287954551*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) + 
         (4345756085006230043253361193999*PolyGamma[2, 1])/
          100063090197999414 + (1118195952211636845034451757528244217*
           Zeta[3])/13622188847194848224304), 
      (809139991427909793493160054371873132041974466837307059644725547017639*
         CF^2*NC)/38695026290295781451922395164361110553175200671488000000 + 
       (8806870863427340811420099548132221646525639600837605579*CF*NM*NC)/
        178292287744273259224658153769557952000000 - 
       (7642805317543139*CF*lm*NM*NC)/1351056465158400 - 
       (37060706978281294580933*CF*NC*NL)/17388096706588608000 - 
       (7642805317543139*CF*lm*NC*NL)/1351056465158400 - 
       (50816395431143474337332833971561683733723079560266892463*CF*NC*NH)/
        1143064701946584587378069099738896093382228544000000 - 
       (7642805317543139*CF*lm*NC*NH)/1351056465158400 - 
       (706118528156840570724685052797*CF^2*NC*Pi^2)/102680291352038400 - 
       (2658846437951415598321*CF*NM*NC*Pi^2)/165405240 - 
       (CF*lm*NM*NC*Pi^2)/54 + (9323674237*CF*NC*NL*Pi^2)/330810480 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (2166610046180524340876605*CF^2*NC*Pi^3)/(1729801758373948980864*
         Sqrt[3]) + (7255085410369211905*CF*NC*NH*Pi^3)/
        (1235346792567894*Sqrt[3]) + (26281*CF^2*NC*Pi^4)/2160 - 
       (103792482596665673849277334564247*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (10302612782787321432576940800*Sqrt[3]) - 
       (27766484433157693877734*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1324909435029066315*Sqrt[3]) + 
       (3169*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (433322009236104868175321*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9343065052945712088*
         Sqrt[3]) + (1658305236655819864*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) + 
       (433322009236104868175321*CF^2*NC*Pi*Log[3]^2)/(448467122541394180224*
         Sqrt[3]) + (207288154581977483*CF*NC*NH*Pi*Log[3]^2)/
        (45753584909922*Sqrt[3]) - 
       (CF*NC*(5*CA*(-1460041279641223513968368325012593 + 
            386730309702128094743040*lm) + 
          26*(561554338523612134357350754011001*CF - 
            20944*(133*(-471231152543331122329249793 + 4854348007423200*lm)*
               NM + 31*(26396348378400*(961 + 789*lm)*NL + 
                (9602853454608949 + 20826718870557600*lm)*NH))))*Log[x]^2)/
        176926698690508166400 - (CF*NC*(-1064297866651137262897*CA + 
          352*(6047146921479402461*CF + 69615*(204148706425096*NM + 
              4471*NL)))*Log[x]^3)/82702620 - 
       (78223609529889346138939230880069*CF^2*NC*PolyGamma[2, 1])/
        600378541187996484 - (4690457353021483*CF*NM*NC*PolyGamma[2, 1])/
        18 + (152138458658421800003*CF*NC*NH*PolyGamma[2, 1])/
        300189270593998242 - (50615692626673694792612409033768767881*CF^2*NC*
         Zeta[3])/204332832707922723364560 - 
       (1472753025966823*CF*NM*NC*Zeta[3])/3 + (5962*CF*NC*NL*Zeta[3])/3 - 
       (1898309913194449747501*CF*NC*NH*Zeta[3])/150094635296999121 + 
       CA*CF*NC*(-18913647297783487338860551688520528653828689620970233197893\
611910205321/1808992479071327782877371973933881918360940631392064000000 + 
         (235372842718213949403712617719*Pi^2)/68453527568025600 - 
         (2166610046180524340876605*Pi^3)/(3459603516747897961728*Sqrt[3]) - 
         (5269*Pi^4)/864 + lm*(7642805317543139/245646630028800 + 
           (11*Pi^2)/108) + (103792482596665673849277334564247*
           Im[PolyLog[2, (-1)^(1/3)]])/(20605225565574642865153881600*
           Sqrt[3]) - (3169*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (433322009236104868175321*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (18686130105891424176*Sqrt[3]) - (433322009236104868175321*Pi*
           Log[3]^2)/(896934245082788360448*Sqrt[3]) + 
         (78223609529889346138939230880069*PolyGamma[2, 1])/
          1200757082375992968 + (50615692626325795441279091939160230641*
           Zeta[3])/408665665415845446729120) + 
       CF*Log[x]*((-760280993867279035158711747584618569901*NM*NC)/
          13567920387120633053520000 + (3707043217*lm*NM*NC)/55135080 + 
         (60645686186305601*NC*NL)/19868477428800 + (3707043217*lm*NC*NL)/
          55135080 + (112804414661905492120120355349013207793059*NC*NH)/
          2638588592042981255357774371957680000 + (3707043217*lm*NC*NH)/
          55135080 - (408297412853116*NM*NC*Pi^2)/27 + (8942*NC*NL*Pi^2)/
          27 - (1658305236655819864*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (22876792454961*Sqrt[3]) + 
         CA*NC*(64449407517298790580501383943285542214413178994819380349/
            5206167487896901799171360320017234915840000 - 
           (3707043217*lm)/10024560 + (4257191463214847740277*Pi^2)/
            1323241920 + (433322009236104868175321*Im[PolyLog[2, (-1)^
                (1/3)]])/(56058390317674272528*Sqrt[3]) - 612*Zeta[3]) + 
         CF*NC*(-4962604379408532941338793793044145367125592920999768139703/
            200437448284030719268097372320663544259840000 - 
           (4257191463398751820637*Pi^2)/661620960 - 
           (433322009236104868175321*Im[PolyLog[2, (-1)^(1/3)]])/
            (28029195158837136264*Sqrt[3]) + 1224*Zeta[3])), 
      (3367357841614137712951520771345319346349533592576545662000932837528116\
183*CF^2*NC)/25706735228908342177731075419060427260918630025045120000000 + 
       (502333503351443732465364094826158863122527627815979673*CF*NM*NC)/
        8914614387213662961232907688477897600000 + 
       (133934452644743*CF*lm*NM*NC)/75058692508800 + 
       (3591147744571935647399*CF*NC*NL)/45643753854795096000 + 
       (133934452644743*CF*lm*NC*NL)/75058692508800 - 
       (103139388497466993028639851257950405845406077314963994041*CF*NC*NH)/
        8969485833087105934082285967013650282758674606200000 + 
       (133934452644743*CF*lm*NC*NH)/75058692508800 - 
       (6613966539646362557116554256469*CF^2*NC*Pi^2)/154020437028057600 - 
       (171158796730052109689*CF*NM*NC*Pi^2)/9189180 - 
       (CF*lm*NM*NC*Pi^2)/81 - (543292873*CF*NC*NL*Pi^2)/496215720 - 
       (CF*lm*NC*NL*Pi^2)/81 - (CF*lm*NC*NH*Pi^2)/81 + 
       (368452496904671307573415*CF^2*NC*Pi^3)/(2122938521640755567424*
         Sqrt[3]) + (391620776588355859475*CF*NC*NH*Pi^3)/
        (300189270593998242*Sqrt[3]) - (179*CF^2*NC*Pi^4)/72 - 
       (81411430906086294309855981961949*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (12644115687966258121798972800*Sqrt[3]) + 
       (672339549389990922977848*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (150244729932296120121*Sqrt[3]) - 
       (682*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (73690499380934261514683*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11466488928615192108*
         Sqrt[3]) + (89513320363052767880*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) + 
       (73690499380934261514683*CF^2*NC*Pi*Log[3]^2)/(550391468573529221184*
         Sqrt[3]) + (11189165045381595985*CF*NC*NH*Pi*Log[3]^2)/
        (11118121133111046*Sqrt[3]) + 
       CF*((-44921031223150539698937442966076419607*NM*NC)/
          660257088357207276936000 + (1942380317*lm*NM*NC)/82702620 - 
         (427061015786089*NC*NL)/7450679035800 + (1942380317*lm*NC*NL)/
          82702620 + (2668154831240868658799579545120903717187789*NC*NH)/
          283949826626568254237287347770817192000 + (1942380317*lm*NC*NH)/
          82702620 - (1408228353125234*NM*NC*Pi^2)/81 - 
         (952*NC*NL*Pi^2)/81 - (89513320363052767880*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CF*NC*(-109030894614283637196695993333607735329215551014304136019153/
            712080408377477555294556454297094170396800000 - 
           (211329356742067485329*Pi^2)/5250960 - (73690499380934261514683*
             Im[PolyLog[2, (-1)^(1/3)]])/(34399466785845576324*Sqrt[3])) + 
         CA*NC*(8386991893446583231179932091326663158237464406660436426981/
            109550832058073470045316377584168333907200000 - 
           (1942380317*lm)/15036840 + (633988070228485991527*Pi^2)/31505760 + 
           (73690499380934261514683*Im[PolyLog[2, (-1)^(1/3)]])/
            (68798933571691152648*Sqrt[3])))*Log[x] - 
       (CF*NC*(-19*CA*(53983020846243534541401659516861729 + 
            81262122310833399936000*lm) + 
          14*(146525342295791960109792968272160303*CF + 
            17503200*(38*(95554361879589213024233077 + 30147408411120*lm)*
               NM + 40914339986520*(-39 + 28*lm)*NL + (1617765155561837 + 
                1145601519622560*lm)*NH)))*Log[x]^2)/
        3980850720536433744000 - (CF*NC*(-3328437368672696083587*CA + 
          10*(665687473821247473377*CF + 11435424*(25146934876529*NM - 
              17*NL)))*Log[x]^3)/41351310 - 
       (352006242889124478330866259265004*CF^2*NC*PolyGamma[2, 1])/
        450283905890997363 - (126642348532070549*CF*NM*NC*PolyGamma[2, 1])/
        324 - (1795133749079179240621*CF*NC*NH*PolyGamma[2, 1])/
        1801135623563989452 - (64933796035449710647409569715586872119*CF^2*NC*
         Zeta[3])/43785607008840583578120 - (121009435120159013*CF*NM*NC*
         Zeta[3])/162 - (1900*CF*NC*NL*Zeta[3])/27 - 
       (7323063576461991311821*CF*NC*NH*Zeta[3])/900567811781994726 + 
       CA*CF*NC*(-67347156832811867619652256667359913729450554087559594140774\
13782497673741/102826940915633368710924301676241709043674520100180480000000 + 
         (6613966539648434476354849582889*Pi^2)/308040874056115200 - 
         (368452496904671307573415*Pi^3)/(4245877043281511134848*Sqrt[3]) + 
         (7991*Pi^4)/6480 + lm*(-133934452644743/13647035001600 + 
           (11*Pi^2)/162) + (81411430906086294309855981961949*
           Im[PolyLog[2, (-1)^(1/3)]])/(25288231375932516243597945600*
           Sqrt[3]) + (341*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (73690499380934261514683*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (22932977857230384216*Sqrt[3]) - (73690499380934261514683*Pi*
           Log[3]^2)/(1100782937147058442368*Sqrt[3]) + 
         (176003121444562239165433129632502*PolyGamma[2, 1])/
          450283905890997363 + (64933796035488597942345439818324336139*
           Zeta[3])/87571214017681167156240), 
      (1731974346548848985442296595708862526964420296148867969529194227796459\
83471*CF^2*NC)/976855938698517002753780865924296235914907940951714560000000 + 
       (1500471871139571614438919751329908651523701651459154349*CF*NM*NC)/
        3623051836514643770340646974996364800000 - 
       (8092694147333539*CF*lm*NM*NC)/1351056465158400 - 
       (1397586447961286872922947*CF*NC*NL)/551782268822411827200 - 
       (8092694147333539*CF*lm*NC*NL)/1351056465158400 - 
       (1532997067283367567763273419403231866757450873646026907386705931*CF*
         NC*NH)/
        29077207417815115320260481989577115377444809268982310400000 - 
       (8092694147333539*CF*lm*NC*NH)/1351056465158400 - 
       (18019058438125309591800046316489*CF^2*NC*Pi^2)/308040874056115200 - 
       (1243919797963373974603*CF*NM*NC*Pi^2)/9189180 - 
       (CF*lm*NM*NC*Pi^2)/54 + (1158410573*CF*NC*NL*Pi^2)/36756720 - 
       (CF*lm*NC*NL*Pi^2)/54 - (CF*lm*NC*NH*Pi^2)/54 + 
       (68204464150406782764118105*CF^2*NC*Pi^3)/(46704647476096622483328*
         Sqrt[3]) + (4199501018383246167025*CF*NC*NH*Pi^3)/
        (600378541187996484*Sqrt[3]) + (29447*CF^2*NC*Pi^4)/2160 - 
       (13538319366790335262543350290167*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1135389980143908892569703680*Sqrt[3]) - 
       (131125965618942482899695617*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5108320817698068084114*Sqrt[3]) + 
       (3535*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (1948698975725908078974803*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(36037536632790603768*
         Sqrt[3]) + (479942973529513847660*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) + 
       (1948698975725908078974803*CF^2*NC*Pi*Log[3]^2)/
        (1729801758373948980864*Sqrt[3]) + (119985743382378461915*CF*NC*NH*
         Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) + 
       ((-103494464251981984965464978565672949*CF^2*NC)/
          147438915575423472000 + CA*CF*(310483392740566395773953049463796007/
            884633493452540832000 - (38731*lm)/3)*NC + 
         CF*NC*((-6209238454979077384321663693/3822446988360 + (7042*lm)/3)*
            NM + ((25673 + 21126*lm)*NL)/9 + (2642046835557395179*NH)/
            2404319155678440 + (7042*lm*NH)/3))*Log[x]^2 - 
       (CF*NC*(-3012951136393771755791*CA + 48*(125539630536979309181*CF + 
            255255*(1143505570121738*NM + 3521*NL)))*Log[x]^3)/27567540 - 
       (6336112372001918158139983375121059*CF^2*NC*PolyGamma[2, 1])/
        5403406870691968356 - (126642348531808513*CF*NM*NC*PolyGamma[2, 1])/
        54 + (1622443269785558967227*CF*NC*NH*PolyGamma[2, 1])/
        2701703435345984178 - (822374967039584199809596733119202425643*CF^2*
         NC*Zeta[3])/367799098874260902056208 - 
       (119781315111476881*CF*NM*NC*Zeta[3])/27 + (21128*CF*NC*NL*Zeta[3])/
        9 - (20146482128969609547301*CF*NC*NH*Zeta[3])/1350851717672992089 + 
       CA*CF*NC*(-86598717326275576219652674463010219420076413810519869397830\
007931423529923/
          976855938698517002753780865924296235914907940951714560000000 + 
         (18019058438117864805154649295569*Pi^2)/616081748112230400 - 
         (68204464150406782764118105*Pi^3)/(93409294952193244966656*
           Sqrt[3]) - (1093*Pi^4)/160 + 
         lm*(8092694147333539/245646630028800 + (11*Pi^2)/108) + 
         (13538319366790335262543350290167*Im[PolyLog[2, (-1)^(1/3)]])/
          (2270779960287817785139407360*Sqrt[3]) - 
         (3535*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (1948698975725908078974803*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (72075073265581207536*Sqrt[3]) - (1948698975725908078974803*Pi*
           Log[3]^2)/(3459603516747897961728*Sqrt[3]) + 
         (6336112372001918158139983375121059*PolyGamma[2, 1])/
          10806813741383936712 + (822374967038846619583370944464673373411*
           Zeta[3])/735598197748521804112416) + 
       CF*Log[x]*((-6166408081121064985773035085066350894183*NM*NC)/
          12889524367764601400844000 + (1382481059*lm*NM*NC)/18378360 + 
         (488947161988427767*NC*NL)/135105646515840 + (1382481059*lm*NC*NL)/
          18378360 + (69252185862807525521614613110441631804477437993*NC*NH)/
          1360545594281201790177962326843870575468000 + 
         (1382481059*lm*NC*NH)/18378360 - (1143505570123009*NM*NC*Pi^2)/9 + 
         (3521*NC*NL*Pi^2)/9 - (479942973529513847660*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CA*NC*(5751883504970541806228164022219592565436790849870182570104861/
            54118111036688294202386290526579156950156800000 - 
           (1382481059*lm)/3341520 + (2410360908848026851581*Pi^2)/88216128 + 
           (1948698975725908078974803*Im[PolyLog[2, (-1)^(1/3)]])/
            (216225219796743622608*Sqrt[3]) - 684*Zeta[3]) + 
         CF*NC*(-575188350506209740623835517152686376189409320821750449383591\
1/27059055518344147101193145263289578475078400000 - 
           (2410360908862499333605*Pi^2)/44108064 - 
           (1948698975725908078974803*Im[PolyLog[2, (-1)^(1/3)]])/
            (108112609898371811304*Sqrt[3]) + 1368*Zeta[3])), 
      (1932033284033312556246651630139813480483290700984812238773560014190502\
95641*CF^2*NC)/174547926350518712090800969773306850931503926753127680000000 + 
       (2440366149955144891964692323847867444744216924914537520969*CF*NM*NC)/
        5081330200711787887902757382432401632000000 + 
       (1373358268819874021*CF*lm*NM*NC)/731597075883273600 + 
       (14546985309481797771233*CF*NC*NL)/156647844483242112000 + 
       (1373358268819874021*CF*lm*NC*NL)/731597075883273600 - 
       (58898544888458743803096206737802606397845087020436689621357*CF*NC*
         NH)/4305353199881810848359497264166552135724163810976000000 + 
       (1373358268819874021*CF*lm*NC*NH)/731597075883273600 - 
       (355236791871902386640346634086599*CF^2*NC*Pi^2)/975462767844364800 - 
       (5685228505223245783508*CF*NM*NC*Pi^2)/35712495 - 
       (CF*lm*NM*NC*Pi^2)/81 - (3803940919*CF*NC*NL*Pi^2)/3142699560 - 
       (CF*lm*NC*NL*Pi^2)/81 - (CF*lm*NC*NH*Pi^2)/81 + 
       (285398365630096337203314475*CF^2*NC*Pi^3)/(1331082453068753740774848*
         Sqrt[3]) + (1405104545947444928845*CF*NC*NH*Pi^3)/
        (900567811781994726*Sqrt[3]) - (9017*CF^2*NC*Pi^4)/3240 - 
       (1128603485255516999191365043456562123*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(150629350190742033004991162966400*
         Sqrt[3]) + (183822976050859150813082777*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(38312406132735510630855*Sqrt[3]) - 
       (758*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (57079673126019267440662895*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7189488558241725451716*
         Sqrt[3]) + (321166753359415983736*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) + 
       (57079673126019267440662895*CF^2*NC*Pi*Log[3]^2)/
        (345095450795602821682368*Sqrt[3]) + (40145844169926997967*CF*NC*NH*
         Pi*Log[3]^2)/(33354363399333138*Sqrt[3]) + 
       CF*((-1473174564012653058588024260596321931752909*NM*NC)/
          2513457251714097273164580000 + (13733098601*lm*NM*NC)/523783260 - 
         (430081864816649*NC*NL)/6056166916800 + (13733098601*lm*NC*NL)/
          523783260 + (167571157287712985159698147802634572041848889*NC*NH)/
          14907365897894833347457585757967902580000 + (13733098601*lm*NC*NH)/
          523783260 - (445168065819626*NM*NC*Pi^2)/3 - 
         (374*NC*NL*Pi^2)/27 - (321166753359415983736*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CF*NC*
          (-34903243525150424792227934090076836200458249912804706335879083/
            26592520078372696289103608275991482294473600000 - 
           (101970005514489492368827*Pi^2)/299304720 - 
           (57079673126019267440662895*Im[PolyLog[2, (-1)^(1/3)]])/
            (21568465674725176355148*Sqrt[3])) + 
         CA*NC*(4986177646453483253937398773532099025846392544147710400952469/
            7597862879535056082601030935997566369849600000 - 
           (13733098601*lm)/95233320 + (33990001838180197086509*Pi^2)/
            199536480 + (57079673126019267440662895*Im[PolyLog[2, (-1)^
                (1/3)]])/(43136931349450352710296*Sqrt[3])))*Log[x] - 
       (CF*NC*(-29*CA*(5698886233625513322028075457656615483 + 
            1192211407745022528864000*lm) + 
          14*(23609671539279899964298718946513412391*CF + 
            11085360*(7*(133003354405103824436776150193 + 5786456655236400*
                 lm)*NM + 1841145299393400*(-31 + 22*lm)*NL + 
              (58458987237038639 + 40505196586654800*lm)*NH)))*Log[x]^2)/
        75636163690192241136000 + (CF*NC*(178447509650242085994479*CA - 
          418*(853815835663414321097*CF + 185640*(2003256296180528*NM - 
              187*NL)))*Log[x]^3)/261891630 - 
       (28512505674057818530375416521366741*CF^2*NC*PolyGamma[2, 1])/
        4052555153018976267 - (569890568393428637*CF*NM*NC*PolyGamma[2, 1])/
        162 - (4708676262004734057367*CF*NC*NH*PolyGamma[2, 1])/
        4052555153018976267 - (100255413036527024310434820982777766403751*
         CF^2*NC*Zeta[3])/7487338798511739791858520 - 
       (545851492839520853*CF*NM*NC*Zeta[3])/81 - (2240*CF*NC*NL*Zeta[3])/
        27 - (38315973225552490875590*CF*NC*NH*Zeta[3])/
        4052555153018976267 + CA*CF*NC*(-408699348545953998107494740736071947\
74351964518723656019176434747031440513/
          73847199609834839730723487211783667701790122857092480000000 + 
         (118412263957305629312405920470953*Pi^2)/650308511896243200 - 
         (285398365630096337203314475*Pi^3)/(2662164906137507481549696*
           Sqrt[3]) + (8953*Pi^4)/6480 + 
         lm*(-1373358268819874021/133017650160595200 + (11*Pi^2)/162) + 
         (1128603485255516999191365043456562123*Im[PolyLog[2, (-1)^(1/3)]])/
          (301258700381484066009982325932800*Sqrt[3]) + 
         (379*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (57079673126019267440662895*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14378977116483450903432*
           Sqrt[3]) - (57079673126019267440662895*Pi*Log[3]^2)/
          (690190901591205643364736*Sqrt[3]) + 
         (28512505674057818530375416521366741*PolyGamma[2, 1])/
          8105110306037952534 + (100255413036534839844250667487163834722211*
           Zeta[3])/14974677597023479583717040)}, 0, 39, 1]
 
CbarLSeries["a", 2, 0, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(224*NM - 672*lm*NM + 800*NL - 672*lm*NL + 224*NH - 
         672*lm*NH + 756*NM*Zeta[3] + 756*NH*Zeta[3] + 
         6*CF*(-802 + 1317*Zeta[3]) + CA*(-6770 + 3696*lm + 2961*Zeta[3])))/
       5184, -(CF*NC*(1232*CA - 224*NL + 226*NH - 315*NH*Zeta[3] + 
          NM*(-674 + 315*Zeta[3])))/1728, 
      (CF*NC*(-510002*NM + 20352*lm*NM - 170112*NL + 20352*lm*NL + 
         461998*NH + 20352*lm*NH - 12*CA*(2213386 + 9328*lm - 
           1925433*Zeta[3]) + 222075*NM*Zeta[3] - 458325*NH*Zeta[3] + 
         72*CF*(-2104538 + 1742829*Zeta[3])))/3732480, 
      -(CF*NC*(-488762*NM + 20352*lm*NM - 69120*NL + 20352*lm*NL + 
          642742*NH + 20352*lm*NH - 12*CA*(2259674 + 9328*lm - 
            1925433*Zeta[3]) + 324135*NM*Zeta[3] - 560385*NH*Zeta[3] + 
          72*CF*(-2104538 + 1742829*Zeta[3])))/3732480, 
      (CF*NC*(-77369410*NM + 3816960*lm*NM - 4061952*NL + 3816960*lm*NL + 
         92206430*NH + 3816960*lm*NH + 58774275*NM*Zeta[3] - 
         79346925*NH*Zeta[3] + 30*CF*(-3174359810 + 2639400579*Zeta[3]) + 
         CA*(-9112850978 - 20993280*lm + 7612421715*Zeta[3])))/522547200, 
      -(CF*NC*(-86197090*NM + 4784640*lm*NM - 212224*NL + 4784640*lm*NL + 
          90783690*NH + 4784640*lm*NH - 6*CA*(2403290246 + 4385920*lm - 
            1998352665*Zeta[3]) + 69887475*NM*Zeta[3] - 
          77957775*NH*Zeta[3] + 60*CF*(-2820797426 + 2346605307*Zeta[3])))/
       522547200, (CF*NC*(-1569323003430*NM + 79112355840*lm*NM + 
         45121970176*NL + 79112355840*lm*NL + 1292364020570*NH + 
         79112355840*lm*NH + 1329399185625*NM*Zeta[3] - 
         1105502934375*NH*Zeta[3] + 28*CF*(-188067016254038 + 
           156464881358625*Zeta[3]) + CA*(-350661833498444 - 
           435117957120*lm + 291226084326450*Zeta[3])))/8193540096000, 
      -(CF*NC*(-970893625660*NM + 36058767360*lm*NM + 38560231424*NL + 
          36058767360*lm*NL + 559363498890*NH + 36058767360*lm*NH + 
          839687924250*NM*Zeta[3] - 475319667375*NH*Zeta[3] + 
          378*CF*(-12340515297382 + 10266620698425*Zeta[3]) + 
          CA*(-258272705492146 - 198323220480*lm + 214512984650475*Zeta[3])))/
       4096770048000, (CF*NC*(CA*(-8706966182930402722 - 3838825834905600*
            lm + 7234744411728673875*Zeta[3]) + 
         2*(9*CF*(-10362378954256751342 + 8620688731536181125*Zeta[3]) + 
           20*(8192*(3300474143 + 2130030315*lm)*NL + 
             63*NH*(4344437604682 + 276971560960*lm - 3663956055375*
                Zeta[3]) + 126*NM*(-5941963225534 + 138485780480*lm + 
               5146713928125*Zeta[3])))))/97339256340480000, 
      -(CF*NC*(CA*(-2996550618794061202 - 714284347392000*lm + 
            2490892614976066875*Zeta[3]) + 
          2*(9*CF*(-4163844119425957502 + 3463941908498140125*Zeta[3]) + 
            40*(2*(512*(3273631253 + 1585325700*lm)*NL + 315*NH*
                 (43141659554 + 2576783360*lm - 36115816275*Zeta[3])) + 
              63*NM*(-1980302527578 + 25767833600*lm + 1701614982375*
                 Zeta[3])))))/24334814085120000, 
      (CF*NC*(-11*CA*(9204447885107482634366 + 1123928234724556800*lm - 
           7653551977926904636125*Zeta[3]) + 
         1078*CF*(-2707874883573087707426 + 2252694589092399337875*Zeta[3]) + 
         5*(65536*(18335719516229 + 6859913542020*lm)*NL + 
           99*NH*(85085224519713154 + 4541124180705280*lm - 
             70756642557475875*Zeta[3]) + 99*NM*(-685627920837577982 + 
             4541124180705280*lm + 583309588781044125*Zeta[3]))))/
       612458600894300160000, -(CF*NC*(-92440374883258275258*NM + 
          285962178735636480*lm*NM + 991531482272432128*NL + 
          285962178735636480*lm*NL + 6331913402905083510*NH + 
          285962178735636480*lm*NH - 77*CA*(345635082160047680354 + 
            20425869909688320*lm - 287455183563262713075*Zeta[3]) + 
          77991015668855664375*NM*Zeta[3] - 5235814843014380625*NH*
           Zeta[3] + 22*CF*(-39773103172671578214482 + 
            33087406023310055830875*Zeta[3])))/122491720178860032000, 
      (CF*NC*(-2*CA*(650061331624066658016330982 + 17282347802223150366720*
            lm - 540704725526495926115544825*Zeta[3]) + 
         52*CF*(-928912294061862215931504386 + 772766345446535389563288675*
            Zeta[3]) + 7*(8388608*(498127181024591 + 107024228741430*lm)*
            NL + 1287*NH*(19630712554888369506 + 697579099777925120*lm - 
             16157042101499173875*Zeta[3]) + 2145*NM*
            (418547459866755072*lm + 1573*(-203065759299032746 + 
               170321200289870175*Zeta[3])))))/4637046559090925371392000, 
      -(CF*NC*(-8*CA*(2064000876393572500631338666 + 21902987858908623667200*
             lm - 1716908224938510208335105375*Zeta[3]) + 
          208*CF*(-3306918030603839726361115438 + 
            2751042659942976372433585125*Zeta[3]) + 
          35*(4194304*(1483515566158741 + 217021475050380*lm)*NL + 
            6435*NH*(5719762070385621830 + 141453619407880192*lm - 
              4690281377072716425*Zeta[3]) + 3003*NM*
             (-629188833172433380006 + 303114898731171840*lm + 
              525782906035483721625*Zeta[3]))))/46370465590909253713920000, 
      (CF*NC*(54*CF*(-9663964318949278898497625161246 + 
           8039509853358416775891249826125*Zeta[3]) + 
         CA*(-11249094324788315543348814590678 - 36081173094907665973248000*
            lm + 9357773381232416130082554086625*Zeta[3]) + 
         35*(201326592*(12047307764341937 + 930998054286300*lm)*NL + 
           143*NH*(101149105886392511854478 + 1310731926070571827200*lm - 
             82709258953859968555125*Zeta[3]) + 143*NM*
            (-9969557016088685038281778 + 1310731926070571827200*lm + 
             8313166902212384602264875*Zeta[3]))))/
       25225533281454634020372480000, 
      -(CF*NC*(CA*(-1987578435768593363435870314454 - 
            110950352418243398860800*lm + 1653442186401255048605940758625*
             Zeta[3]) + 2*CF*(-51037203805998280386497484857386 + 
            42458181583804810746922714089375*Zeta[3]) + 
          10*(33554432*(25021768375271441 + 60119603123580*lm)*NL + 
            286*NH*(18202061377809314962814 + 7053423548521512960*lm - 
              14852969451887245804125*Zeta[3]) + 715*NM*
             (-1390593421124353376857330 + 2821369419408605184*lm + 
              1158189425988655918732875*Zeta[3]))))/
       3603647611636376288624640000, 
      (CF*NC*(5*CA*(-448512458484607755700309494656890022 + 
           486815984511484016434190745600*lm + 
           373116528592013560205419370572995225*Zeta[3]) + 
         2*(17*CF*(-3730250473331788948789116544822922914 + 
             3103220875331630355536882143358737875*Zeta[3]) - 
           105*(805306368*(-30661992579934000631 + 2616927654021380700*lm)*
              NL + 2431*NM*(25191578299206743738376344462 + 
               866897780493096950169600*lm - 20968598713630125680040043125*
                Zeta[3]) + 12155*NH*(173379556098619390033920*lm + 2431*
                (-5573303824637828893598 + 4541342165167492810125*
                  Zeta[3]))))))/3324321677963217489740766904320000, 
      -(CF*NC*(40*CA*(-67885455479455266449856837206266238 + 
            90739221994818455976416378880*lm + 
            56474116738373501452856535634194525*Zeta[3]) + 
          272*CF*(-618861567777383425191945755664206314 + 
            514835302452510326649044492127693375*Zeta[3]) - 
          105*(10737418240*(-2969186366131736255 + 585333235302647832*lm)*
             NL + 17017*NM*(10139945820789299366082583994 + 
              369334651067571413975040*lm - 8437584934825353261980400375*Zeta[
                3]) + 2431*NH*(-98005884355553095698976342 + 
              2585342557472999897825280*lm + 79786798694591025851438625*Zeta[
                3]))))/3324321677963217489740766904320000, 
      (CF*NC*(12*CA*(-522745509792838695920803332100002417778 + 
           645517503164541304742959959244800*lm + 
           434874961319252569652966187126690196875*Zeta[3]) + 
         152*CF*(-2792538171907615969457826962725960692718 + 
           2323132564868180216392842893566682533125*Zeta[3]) - 
         35*(8589934592*(-13228378709024467159231 + 4684558620830305777560*
              lm)*NL + 4199*NM*(9583246521867600705072660480*lm + 
             323*(1039640881502044717520461980838 - 
               864975077981127695336371241625*Zeta[3])) + 
           4199*NH*(9583246521867600705072660480*lm + 
             4199*(-56903585708478974657056226 + 46302510340333999018141875*
                Zeta[3])))))/6400427337305181406914223213117440000, 
      -(CF*NC*(152*CF*(-3613568697088843579059984320804836047358 + 
            3006154040723904073717895355254607652125*Zeta[3]) + 
          CA*(-7464138590543347358853128195182213712024 + 
            7643237281138747304396664392908800*lm + 
            6209468859090563488341886057407414598500*Zeta[3]) - 
          35*(8589934592*(-7644697301241843163273 + 4622285339653992290280*
               lm)*NL + 4199*NM*(476874212335956219732979504756354 + 
              9455853473014598162700042240*lm - 
              396730880362306161768046070995875*Zeta[3]) + 
            4199*NH*(9455853473014598162700042240*lm + 
              4199*(-41939858281725891363001714 + 34120057120346661065476875*
                 Zeta[3])))))/6400427337305181406914223213117440000, 
      (CF*NC*(CA*(-26758340059540109981156313660677225322090604 + 
           21574131933173705974775413691803238400*lm + 
           22260464702018836270167999158259382256033250*Zeta[3]) + 
         4*CF*(-533560147489540740601335951896118610643138506 + 
           443872586159353211867880147267830057910063375*Zeta[3]) - 
         1155*(618475290624*(-5027625494373674715839 + 5491187879087778908040*
              lm)*NL + 4199*NM*(62511035098775707179041760908605414 + 
             808803052962562570173064151040*lm - 
             52004024372315512746503456414837625*Zeta[3]) + 
           29393*NH*(115543293280366081453294878720*lm + 
             4199*(-411654188123730771704059258 + 334904994410732251671540375*
                Zeta[3])))))/19431697396058530751391581675024547840000, 
      -(CF*NC*(10*CA*(-1568632371020083746435953718895652009053838 + 
            969801341510578169771542778939965440*lm + 
            1304957433722083557519931646481271185902325*Zeta[3]) + 
          7*(4*CF*(-48288491454606319103026310713549434503965814 + 
              40171550261518593042396905839853167491596625*Zeta[3]) - 
            165*(68719476736*(-8783804298751901974447 + 
                22215611035054520843760*lm)*NL + 4199*NM*(
                44665955348170734208610326309672846 + 
                363573509335426059922455920640*lm - 
                37157996139712575930587279981611125*Zeta[3]) + 
              4199*NH*(363573509335426059922455920640*lm + 
                4199*(-1092099761037427441945959814 + 
                  888605390279872838655707625*Zeta[3]))))))/
       9715848698029265375695790837512273920000, 
      (CF*NC*(42*CA*(-2454517280599532542793181335159090483189924966 + 
           1148881013207411488664656928532804403200*lm + 
           2041932088519469788475504351704785236870420025*Zeta[3]) + 
         276*CF*(-34701189962896712580757398544931757980246754362 + 
           28868175027203197279435514140915401887748590775*Zeta[3]) - 
         385*(1649267441664*(-31318175519006063512067 + 
             13816875298904520198075720*lm)*NL + 7429*NM*
            (612339644528637933765387781553445182042 + 
             3067401073632356081422231425515520*lm - 
             509408917768753476760321413057703398375*Zeta[3]) + 
           7429*NH*(3067401073632356081422231425515520*lm + 
             7429*(-4547663311708152302497527137902 + 
               3700955612146246640420858749125*Zeta[3])))))/
       54823295586746468093259449099135924305920000, 
      -(CF*NC*(506*CF*(-3212616753420859587793250536110493891740509182 + 
            2672599523168264601637614153054197805718045725*Zeta[3]) + 
          5*CA*(-3254140522949059906568040512411981674393127218 + 
            1147918317328116195434307882369197015040*lm + 
            2707144835989778519321077637256269924043193515*Zeta[3]) - 
          105*(3573412790272*(860110871163403028396237 + 
              2781287053421289751162440*lm)*NL + 148580*NM*
             (21986239944067958414362142513767454366 + 
              66891147732625926326762493444096*lm - 
              18290469726596410189867072309020288525*Zeta[3]) + 
            22287*NH*(445940984884172842178416622960640*lm + 
              126293*(-34880921926471188462381424166 + 
                28391779923827070847961489625*Zeta[3])))))/
       7475903943647245649080833968063989678080000}, 0, 24, 1]
 
CbarLSeries["a", 2, 1, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(15*CA*(4665 + 15840*lm^2 - 10732*Pi^2 + 432*Pi^4 - 
            80*lm*(-483 + 44*Pi^2) - 244512*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 34560*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            40752*PolyGamma[2, 1] + 434496*Zeta[3]) + 
          2*(CF*(-194400*lm^2 - 72892*Pi^2 + 1200*Pi^4 + 43200*lm*(-6 + 
                Pi^2) + 15*(-16097 + 244512*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 34560*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                40752*PolyGamma[2, 1] - 396480*Zeta[3])) + 
            60*(NL*(15 - 420*lm - 360*lm^2 + 52*Pi^2 + 80*lm*Pi^2 - 
                960*Zeta[3]) + NM*(15 - 360*lm^2 + 52*Pi^2 + 
                20*lm*(-21 + 4*Pi^2) + 80*PolyGamma[2, 1] - 800*Zeta[3]) + 
              NH*(-10593 - 420*lm - 360*lm^2 + 80*lm*Pi^2 - 68976*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 11496*PolyGamma[2, 1] + 
                132432*Zeta[3])))))/6220800, 
      (CF*NC*(-5*CA*(-619125 + 63360*lm^2 - 59860*Pi^2 + 2376*Pi^4 - 
           1280*lm*(3 + 11*Pi^2) - 396960*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 190080*Im[PolyLog[2, (-1)^(1/3)]]^
             2 + 66400*PolyGamma[2, 1] + 688160*Zeta[3]) + 
         2*(-1600*(NH*(4101 - 18*lm^2 + 4*lm*(6 + Pi^2) - 504*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 84*PolyGamma[2, 1] - 2520*
                Zeta[3]) + NL*(147 - 18*lm^2 + 4*Pi^2 + 4*lm*(6 + Pi^2) - 48*
                Zeta[3]) + NM*(147 - 18*lm^2 + 4*Pi^2 + 4*lm*(6 + Pi^2) + 4*
                PolyGamma[2, 1] - 40*Zeta[3])) + 
           CF*(259200*lm^2 + 160436*Pi^2 + 1640*Pi^4 - 14400*lm*
              (21 + 4*Pi^2) + 5*(191133 - 396960*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 190080*Im[PolyLog[2, (-1)^(1/3)]]^2 + 66400*
                PolyGamma[2, 1] + 485216*Zeta[3])))))/2073600, 
      -(CF*NC*(CF*(171495 + 19440*lm^2 + 12236*Pi^2 - 1572*Pi^4 + 
            2160*lm*(-45 + 2*Pi^2) + 479616*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 181440*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
            87880*PolyGamma[2, 1] - 1124816*Zeta[3]) + 
          CA*(227865 - 11880*lm^2 - 17228*Pi^2 + 1170*Pi^4 - 
            60*lm*(-771 + 44*Pi^2) - 239808*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 90720*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            43940*PolyGamma[2, 1] + 532888*Zeta[3]) + 
          2*(3*NL*(-5185 + 360*lm^2 + 404*Pi^2 + 20*lm*(-93 + 4*Pi^2) - 
              960*Zeta[3]) + 3*NM*(-10585 + 360*lm^2 + 884*Pi^2 + 
              20*lm*(-93 + 4*Pi^2) + 240*PolyGamma[2, 1] - 480*Zeta[3]) + 
            NH*(-252363 + 1080*lm^2 + 60*lm*(-93 + 4*Pi^2) - 
              632016*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 113000*PolyGamma[2, 
                1] + 1360720*Zeta[3]))))/103680, 
      (CF*NC*(6220800*(27*CF*(5 + 2*lm) - CA*(76 + 33*lm) + 
           2*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         12441600*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         5*CA*(11975040*lm^2 - 4793796*Pi^2 + 1118600*Sqrt[3]*Pi^3 + 
           289440*Pi^4 - 34560*lm*(-639 + 22*Pi^2) + 862920*Sqrt[3]*Pi*
            Log[3]^2 + 15*(-2473281 - 2605440*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 3608064*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             2761344*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             586592*PolyGamma[2, 1] + 2492512*Zeta[3])) - 
         10800*Log[x]*(CA*(57531 + 29016*lm + 4752*lm^2 + 978*Pi^2 - 
             6392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 10368*Zeta[3]) - 
           2*(24*(3*NM*(-14 + 29*lm + 6*lm^2 + 6*Pi^2) + 3*NL*(58 + 29*lm + 
                 6*lm^2 + 6*Pi^2) + NH*(3296 + 87*lm + 18*lm^2 - 
                 1864*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
             CF*(37803 + 19440*lm + 3888*lm^2 + 426*Pi^2 - 6392*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 10368*Zeta[3]))) + 
         4*(-2400*(9*NL*(366 - 126*lm^2 - 95*Pi^2 + 8*lm*(-9 + Pi^2) - 744*
                Zeta[3]) + 9*NM*(1851 - 126*lm^2 - 59*Pi^2 + 8*lm*
                (-9 + Pi^2) - 34*PolyGamma[2, 1] + 484*Zeta[3]) - 
             NH*(-276921 + 1134*lm^2 + 8155*Sqrt[3]*Pi^3 - 72*lm*
                (-9 + Pi^2) - 12420*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               301968*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6291*
                Sqrt[3]*Pi*Log[3]^2 + 6012*PolyGamma[2, 1] + 8136*Zeta[3])) + 
           CF*(24494400*lm^2 - 668124*Pi^2 + 2796500*Sqrt[3]*Pi^3 + 
             447120*Pi^4 - 194400*lm*(-93 + 8*Pi^2) + 2157300*Sqrt[3]*Pi*
              Log[3]^2 + 15*(5916141 - 6513600*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 9020160*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
               6903360*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               1466480*PolyGamma[2, 1] + 1047712*Zeta[3])))))/27993600, 
      -(CF*NC*(9331200*(9*CF*(19 + 12*lm) - 2*CA*(76 + 33*lm) + 
            4*(8*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          37324800*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          15*CA*(-10692000*lm^2 - 1508652*Pi^2 - 2921800*Sqrt[3]*Pi^3 + 
            99576*Pi^4 - 2160*lm*(-6273 + 308*Pi^2) - 2253960*Sqrt[3]*Pi*
             Log[3]^2 - 3*(-63932355 + 32300448*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 31259520*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              36063360*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              4502128*PolyGamma[2, 1] - 99376064*Zeta[3])) + 
          10800*Log[x]*(3*CA*(-49305 - 20304*lm - 4752*lm^2 + 2886*Pi^2 + 
              16696*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 10368*Zeta[3]) + 
            2*(8*(9*NM*(-241 + 54*lm + 18*lm^2 + 48*Pi^2) + 
                2*(9*NL*(55 + 27*lm + 9*lm^2 + 9*Pi^2) + NH*(3894 + 
                    243*lm + 81*lm^2 - 2128*Sqrt[3]*Im[PolyLog[2, (-1)^
                        (1/3)]]))) + CF*(73161 + 36936*lm + 11664*lm^2 - 
                10026*Pi^2 - 50088*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                31104*Zeta[3]))) + 2*(-3*CF*(-43740000*lm^2 + 16860492*Pi^2 - 
              14609000*Sqrt[3]*Pi^3 + 14040*Pi^4 - 388800*lm*(-267 + 
                7*Pi^2) - 11269800*Sqrt[3]*Pi*Log[3]^2 - 15*(-4917897 + 
                32300448*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 31259520*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 + 36063360*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 4502128*PolyGamma[2, 
                  1] - 112617728*Zeta[3])) + 20*(81*NM*(-215955 + 
                9000*lm^2 + 32732*Pi^2 + 20*lm*(-1143 + 28*Pi^2) + 
                16424*PolyGamma[2, 1] - 112112*Zeta[3]) + 81*NL*(-83475 + 
                9000*lm^2 + 12092*Pi^2 + 20*lm*(-1143 + 28*Pi^2) + 
                45120*Zeta[3]) + NH*(-117074403 + 729000*lm^2 + 
                1489600*Sqrt[3]*Pi^3 + 1620*lm*(-1143 + 28*Pi^2) - 
                237080016*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 55157760*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                1149120*Sqrt[3]*Pi*Log[3]^2 + 46277952*PolyGamma[2, 1] + 
                491775744*Zeta[3])))))/167961600, 
      (CF*NC*(-97977600*(5*CA*(1733 + 792*lm) - 2*(5*CF*(1535 + 648*lm) + 
             4*(280*NM + 90*lm*NM + 135*NL + 90*lm*NL + 4*NH + 90*lm*
                NH)))*Log[x]^2 + 23514624000*(13*CA + 46*CF - 
           2*(2*NM + NL))*Log[x]^3 - 60480*Log[x]*
          (2*(-4*(225*NM*(211 + 582*lm + 108*lm^2 + 18*Pi^2) + 450*NL*
                (704 + 291*lm + 54*lm^2 + 72*Pi^2) + NH*(5403273 + 
                 130950*lm + 24300*lm^2 - 3046600*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) + 25*CF*(-420204 - 194400*lm - 34992*
                lm^2 + 3951*Pi^2 + 95012*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               93312*Zeta[3])) + 25*CA*(653961 + 284904*lm + 42768*lm^2 + 
             3969*Pi^2 - 95012*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             93312*Zeta[3])) - 175*CA*(261740160*lm^2 - 136594188*Pi^2 + 
           66508400*Sqrt[3]*Pi^3 + 10026504*Pi^4 - 466560*lm*
            (-1143 + 22*Pi^2) + 51306480*Sqrt[3]*Pi*Log[3]^2 + 
           15*(-107735355 - 64453056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             104789376*Im[PolyLog[2, (-1)^(1/3)]]^2 + 164180736*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 19401184*
              PolyGamma[2, 1] + 36275168*Zeta[3])) + 
         2*(5*CF*(7495286400*lm^2 - 3455464644*Pi^2 + 2327794000*Sqrt[3]*
              Pi^3 + 298672920*Pi^4 - 73483200*lm*(-95 + 4*Pi^2) + 
             1795726800*Sqrt[3]*Pi*Log[3]^2 - 105*(34067727 + 322265280*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 523946880*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 820903680*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 97005920*
                PolyGamma[2, 1] + 79047584*Zeta[3])) - 
           448*(30375*NL*(1577 - 306*lm^2 - 404*Pi^2 + 6*lm*(-39 + 2*Pi^2) - 
               3600*Zeta[3]) + 60750*NM*(3538 - 153*lm^2 - 109*Pi^2 + 3*lm*
                (-39 + 2*Pi^2) - 84*PolyGamma[2, 1] + 4296*Zeta[3]) - 
             2*NH*(4647375*lm^2 + 66644375*Sqrt[3]*Pi^3 - 91125*lm*
                (-39 + 2*Pi^2) + 51411375*Sqrt[3]*Pi*Log[3]^2 - 3*
                (603107289 + 50055000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                 822582000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                 18490000*PolyGamma[2, 1] + 76258000*Zeta[3]))))))/
       5878656000, -(CF*NC*(-5443200*(165*CA*(449 + 142*lm) - 
            2*(53495*CF + 19170*CF*lm + 10610*NM + 2130*lm*NM + 2940*NL + 
              2130*lm*NL + 108*NH + 2130*lm*NH))*Log[x]^2 + 
          108864000*(277*CA + 5008*CF - 122*NM - 142*NL)*Log[x]^3 - 
          525*CA*(24698520*lm^2 - 2770686*Pi^2 + 13515250*Sqrt[3]*Pi^3 + 
            675540*Pi^4 + 5940*lm*(-3779 + 156*Pi^2) + 10426050*Sqrt[3]*Pi*
             Log[3]^2 + 3*(-105761025 + 75336936*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 89346240*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              166816800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              3537052*PolyGamma[2, 1] - 343143320*Zeta[3])) - 
          3780*Log[x]*(75*CA*(472503 + 324096*lm + 71280*lm^2 + 24834*Pi^2 - 
              308920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 155520*Zeta[3]) - 
            2*(8*(225*NL*(2467 + 884*lm + 270*lm^2 + 374*Pi^2) + 
                150*NM*(-5797 + 1326*lm + 405*lm^2 + 1896*Pi^2) + 
                NH*(3280119 + 198900*lm + 60750*lm^2 - 1755200*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 75*CF*(66033 + 200664*lm + 
                58320*lm^2 + 13530*Pi^2 - 308920*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 155520*Zeta[3]))) + 
          2*(30*CF*(353637900*lm^2 - 221113773*Pi^2 + 236516875*Sqrt[3]*Pi^
                3 + 14180670*Pi^4 + 170100*lm*(-4189 + 78*Pi^2) + 
              182455875*Sqrt[3]*Pi*Log[3]^2 + 105*(14797671 + 37668468*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 44673120*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 + 83408400*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1768526*PolyGamma[2, 
                  1] - 193056748*Zeta[3])) + 7*(675*NM*(-1783505 + 
                249480*lm^2 + 1630068*Pi^2 + 60*lm*(-9071 + 156*Pi^2) + 
                1491624*PolyGamma[2, 1] - 7911792*Zeta[3]) + 
              2025*NL*(-1017875 + 83160*lm^2 + 149596*Pi^2 + 
                20*lm*(-9071 + 156*Pi^2) + 1039680*Zeta[3]) + 
              NH*(-28637153091 + 168399000*lm^2 + 614320000*Sqrt[3]*Pi^3 + 
                40500*lm*(-9071 + 156*Pi^2) - 57284869200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 22747392000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 473904000*Sqrt[3]*Pi*
                 Log[3]^2 + 12003491200*PolyGamma[2, 1] + 112976086400*
                 Zeta[3])))))/4408992000, 
      (CF*NC*(-89201849280075*CF + 19791720144000*CF*lm + 
         20091776544000*CF*lm^2 - 104528203164000*NM + 
         1827010080000*lm*NM + 2232419616000*lm^2*NM - 23352722820000*NL + 
         1827010080000*lm*NL + 2232419616000*lm^2*NL - 
         1324047636376992*NH + 1827010080000*lm*NH + 2232419616000*lm^2*
          NH - 21356960068080*CF*Pi^2 - 576108288000*CF*lm*Pi^2 - 
         5182307424000*NM*Pi^2 - 64012032000*lm*NM*Pi^2 + 
         4126108896000*NL*Pi^2 - 64012032000*lm*NL*Pi^2 - 
         64012032000*lm*NH*Pi^2 + 11446671460000*Sqrt[3]*CF*Pi^3 + 
         52695419280000*Sqrt[3]*NH*Pi^3 + 1251035150400*CF*Pi^4 - 
         114863532672000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         133550040960000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         184066598016000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         423853891776000*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         1951236096768000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         8830289412000*Sqrt[3]*CF*Pi*Log[3]^2 + 40650752016000*Sqrt[3]*NH*Pi*
          Log[3]^2 - 57153600*(105*CA*(68659 + 32384*lm) - 
           8*(35*CF*(45589 + 19872*lm) + 81830*NM + 77280*lm*NM + 
             109200*NL + 77280*lm*NL + 7047*NH + 77280*lm*NH))*Log[x]^2 + 
         16003008000*(10217*CA + 44492*CF - 9160*NM - 1472*NL)*Log[x]^3 + 
         39462613736000*CF*PolyGamma[2, 1] - 11470155984000*NM*
          PolyGamma[2, 1] + 44300063472000*NH*PolyGamma[2, 1] - 
         4900*CA*(2505777120*lm^2 - 2212471260*Pi^2 + 1168027700*Sqrt[3]*
            Pi^3 + 138107592*Pi^4 - 272160*lm*(-19253 + 264*Pi^2) + 
           901049940*Sqrt[3]*Pi*Log[3]^2 - 35*(718443873 + 334879104*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 536637312*Im[PolyLog[2, 
                 (-1)^(1/3)]]^2 - 1235725632*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] - 115051352*PolyGamma[2, 1] - 
             84512656*Zeta[3])) - 65810777782400*CF*Zeta[3] - 
         134801337888000*NM*Zeta[3] + 44744410368000*NL*Zeta[3] - 
         248295197472000*NH*Zeta[3] - 15120*Log[x]*
          (48*(-7350*NM*(9529 + 4614*lm + 810*lm^2 - 4893*Pi^2) - 
             11025*NL*(8959 + 3076*lm + 540*lm^2 + 916*Pi^2) - 
             2*NH*(796018473 + 16956450*lm + 2976750*lm^2 - 448090300*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
           1225*CF*(-27102543 - 12309408*lm - 2099520*lm^2 + 452088*Pi^2 + 
             7627936*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 5598720*Zeta[3]) + 
           1225*CA*(21710685 + 8941536*lm + 1283040*lm^2 + 45576*Pi^2 - 
             3813968*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 2799360*Zeta[3]))))/
       648121824000, (-99114591437*CF^2*NC)/839808000 + 
       (11599*CF^2*lm*NC)/576 - (171*CF^2*lm^2*NC)/16 + 
       (11231011*CF*NM*NC)/1944000 + (12625*CF*lm*NM*NC)/5184 - 
       (19*CF*lm^2*NM*NC)/16 + (455965*CF*NC*NL)/20736 + 
       (12625*CF*lm*NC*NL)/5184 - (19*CF*lm^2*NC*NL)/16 + 
       (3934889615567*CF*NC*NH)/18003384000 + (12625*CF*lm*NC*NH)/5184 - 
       (19*CF*lm^2*NC*NH)/16 - (14568857*CF^2*NC*Pi^2)/604800 - 
       (7*CF^2*lm*NC*Pi^2)/24 - (263183*CF*NM*NC*Pi^2)/12960 - 
       (7*CF*lm*NM*NC*Pi^2)/216 - (35023*CF*NC*NL*Pi^2)/12960 - 
       (7*CF*lm*NC*NL*Pi^2)/216 - (7*CF*lm*NC*NH*Pi^2)/216 - 
       (21003955*CF^2*NC*Pi^3)/(629856*Sqrt[3]) - (5909365*CF*NC*NH*Pi^3)/
        (314928*Sqrt[3]) - (293*CF^2*NC*Pi^4)/360 - 
       (430088161*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(1049760*Sqrt[3]) + 
       (368081923*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(262440*Sqrt[3]) - 
       170*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (600113*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(486*Sqrt[3]) - 
       (168839*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (243*Sqrt[3]) - (600113*CF^2*NC*Pi*Log[3]^2)/(23328*Sqrt[3]) - 
       (168839*CF*NC*NH*Pi*Log[3]^2)/(11664*Sqrt[3]) - 
       (CF*NC*(14*CF*(1094339 + 210060*lm) - 7*CA*(1331149 + 256740*lm) + 
          3302264*NM + 326760*lm*NM + 407190*NL + 326760*lm*NL + 
          35568*NH + 326760*lm*NH)*Log[x]^2)/15120 + 
       (CF*NC*(9063*CA - 131149*CF - 804*NM + 2334*NL)*Log[x]^3)/162 - 
       (414309997*CF^2*NC*PolyGamma[2, 1])/9447840 - 
       (673*CF*NM*NC*PolyGamma[2, 1])/36 - 
       (489629663*CF*NC*NH*PolyGamma[2, 1])/4723920 + 
       (CA*CF*NC*(12341241000*lm^2 + 28453362075*Pi^2 + 10501977500*Sqrt[3]*
           Pi^3 + 719960400*Pi^4 + 182250*lm*(-52691 + 1848*Pi^2) + 
          8101525500*Sqrt[3]*Pi*Log[3]^2 + 4*(-25463331981 + 
            32256612075*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            40153320000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 97218306000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10357749925*
             PolyGamma[2, 1] - 196033914850*Zeta[3])))/1889568000 + 
       (4336619453*CF^2*NC*Zeta[3])/4723920 + (361*CF*NM*NC*Zeta[3])/6 - 
       (236*CF*NC*NL*Zeta[3])/9 - (2084127623*CF*NC*NH*Zeta[3])/2361960 - 
       (CF*NC*Log[x]*(-49*CA*(234517053 + 226516500*lm + 48114000*lm^2 + 
            115352100*Pi^2 - 240045200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            104976000*Zeta[3]) + 2*(2665878075*NL + 736249500*lm*NL + 
            214326000*lm^2*NL + 12547352976*NH + 736249500*lm*NH + 
            214326000*lm^2*NH + 380230200*NL*Pi^2 + 
            2646*NM*(1008703 + 278250*lm + 81000*lm^2 + 668100*Pi^2) - 
            6618488800*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            98*CF*(-31906461 + 70895250*lm + 19683000*lm^2 + 50758650*Pi^2 - 
              120022600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 52488000*Zeta[
                3]))))/171460800, 
      (CF*NC*(-2057529600*(7*CA*(23096021 + 12392160*lm) - 
           2*(21*CF*(6698077 + 3379680*lm) + 8*(7*(-1578721 + 140820*lm)*
                NM + 6*(35*(6395 + 4694*lm)*NL + (22037 + 164290*lm)*
                  NH))))*Log[x]^2 + 1152216576000*(145155*CA + 691790*CF - 
           8*(37985*NM + 2347*NL))*Log[x]^3 + 15120*Log[x]*
          (2*(-96*(-1323*NM*(10355119 + 4771500*lm + 810000*lm^2 - 
                 20756400*Pi^2) - 4*(99225*NL*(54664 + 15905*lm + 
                   2700*lm^2 + 5594*Pi^2) + NH*(84570564867 + 1578173625*
                    lm + 267907500*lm^2 - 47576040400*Sqrt[3]*Im[PolyLog[2, 
                      (-1)^(1/3)]]))) - 49*CF*(-219732297639 - 114458832000*
                lm - 18895680000*lm^2 + 9835619400*Pi^2 + 84289900000*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 50388480000*Zeta[3])) + 
           49*CA*(-381963188139 - 165438288000*lm - 23094720000*lm^2 + 
             4125702600*Pi^2 + 84289900000*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 50388480000*Zeta[3])) - 
         49*CA*(142586801280000*lm^2 - 269796543120000*Pi^2 + 
           103255127500000*Sqrt[3]*Pi^3 + 10377664920000*Pi^4 - 
           489888000*lm*(-613991 + 6600*Pi^2) + 79653955500000*Sqrt[3]*Pi*
            Log[3]^2 - 7*(267876081257823 + 123210522696000*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 183099139200000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 - 546198552000000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 34723831648000*
              PolyGamma[2, 1] + 764694496000*Zeta[3])) + 
         2*(49*CF*(-824739767280261 + 116661928320000*lm^2 - 
             281023253928000*Pi^2 + 103255127500000*Sqrt[3]*Pi^3 + 
             9907372440000*Pi^4 - 4408992000*lm*(-26551 + 600*Pi^2) - 
             862473658872000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             1281693974400000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             3823389864000000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             79653955500000*Sqrt[3]*Pi*Log[3]^2 + 243066821536000*
              PolyGamma[2, 1] - 717687244960000*Zeta[3]) - 
           192*(4*(-(NH*(-705018573246879 + 827030452500*lm^2 + 
                  29140324745000*Sqrt[3]*Pi^3 - 31255875*lm*(-22141 + 
                    600*Pi^2) - 79622313918000*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]] + 1079024596272000*Sqrt[3]*Im[PolyLog[3, 
                     -((-1)^(5/6)/Sqrt[3])]] + 22479679089000*Sqrt[3]*Pi*
                   Log[3]^2 + 24265186512000*PolyGamma[2, 1] - 
                  152507414976000*Zeta[3])) + 31255875*NL*(492766 - 
                 26460*lm^2 - 62540*Pi^2 + lm*(-22141 + 600*Pi^2) - 
                 812736*Zeta[3])) + 83349*NM*(1401542231 - 39690000*lm^2 + 
               1198632000*Pi^2 + 1500*lm*(-22141 + 600*Pi^2) + 1943640000*
                PolyGamma[2, 1] + 4309344000*Zeta[3])))))/186659085312000, 
      (21358890452612021*CF^2*NC)/51849745920000 + (1566019*CF^2*lm*NC)/
        43200 - (319*CF^2*lm^2*NC)/16 + (461267142181*CF*NM*NC)/2000376000 + 
       (1709569*CF*lm*NM*NC)/388800 - (319*CF*lm^2*NM*NC)/144 + 
       (477933497*CF*NC*NL)/7776000 + (1709569*CF*lm*NC*NL)/388800 - 
       (319*CF*lm^2*NC*NL)/144 + (13121743702957*CF*NC*NH)/30380710500 + 
       (1709569*CF*lm*NC*NH)/388800 - (319*CF*lm^2*NC*NH)/144 - 
       (2475727717*CF^2*NC*Pi^2)/5443200 - (31*CF^2*lm*NC*Pi^2)/72 - 
       (6414839*CF*NM*NC*Pi^2)/38880 - (31*CF*lm*NM*NC*Pi^2)/648 - 
       (237583*CF*NC*NL*Pi^2)/38880 - (31*CF*lm*NC*NL*Pi^2)/648 - 
       (31*CF*lm*NC*NH*Pi^2)/648 - (1955936857*CF^2*NC*Pi^3)/
        (22674816*Sqrt[3]) - (390297845*CF*NC*NH*Pi^3)/(8503056*Sqrt[3]) - 
       (11461*CF^2*NC*Pi^4)/5184 - (83932534171*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(94478400*Sqrt[3]) + 
       (4379940079*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1417176*Sqrt[3]) - 
       (1481*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (279419551*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (87480*Sqrt[3]) - (11151367*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (279419551*CF^2*NC*Pi*Log[3]^2)/(4199040*Sqrt[3]) - 
       (11151367*CF*NC*NH*Pi*Log[3]^2)/(314928*Sqrt[3]) - 
       (CF*NC*(-(CA*(942320693 + 79949100*lm)) + 
          5*(CF*(346318729 + 26165160*lm) + 8*(11092432 + 363405*lm)*NM + 
            6*(566069*NL + 484540*lm*NL + 78224*NH + 484540*lm*NH)))*
         Log[x]^2)/226800 + (CF*NC*(734891*CA - 3477689*CF - 273620*NM + 
          34610*NL)*Log[x]^3)/810 - (51934316639*CF^2*NC*PolyGamma[2, 1])/
        85030560 - (179603*CF*NM*NC*PolyGamma[2, 1])/1620 - 
       (30512261197*CF*NC*NH*PolyGamma[2, 1])/127545840 + 
       (CA*CF*NC*(-81917060747340699 + 2274259480416000*lm^2 + 
          43712162890522560*Pi^2 + 2683545367804000*Sqrt[3]*Pi^3 + 
          199193041252800*Pi^4 + 2640496320*lm*(-613369 + 18600*Pi^2) + 
          27637304851826880*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          34555263168384000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          99367851333542400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          2070163569448800*Sqrt[3]*Pi*Log[3]^2 + 57003105942966400*
           PolyGamma[2, 1] - 191757313651993600*Zeta[3]))/186659085312000 + 
       (24146318863*CF^2*NC*Zeta[3])/10628820 + (163537*CF*NM*NC*Zeta[3])/
        810 - (2030*CF*NC*NL*Zeta[3])/27 - (119708531317*CF*NC*NH*Zeta[3])/
        63772920 - (CF*NC*Log[x]*(-3*CA*(42590590301361 + 9535287535200*lm + 
            1980372240000*lm^2 + 18030934416600*Pi^2 - 10953246399200*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 4320812160000*Zeta[3]) + 
          10*(8*(35721*NL*(6010531 + 1338940*lm + 378000*lm^2 + 
                818200*Pi^2) + 486*NM*(4213070419 + 98412090*lm + 
                27783000*lm^2 + 675538500*Pi^2) + 4*NH*(209357905647 + 
                11957068935*lm + 3375634500*lm^2 - 109283396600*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 3*CF*(5808770692359 + 
              1201888769760*lm + 324060912000*lm^2 + 3461704487640*Pi^2 - 
              2190649279840*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              864162432000*Zeta[3]))))/185177664000, 
      (CF*NC*(-373441622400*(121*CA*(60664693 + 101001600*lm) - 
           4*(11*CF*(196553353 + 454507200*lm) + 360*(264*(-354391 + 5845*lm)*
                NM + 770*(2665 + 2004*lm)*NL + (264967 + 1543080*lm)*NH)))*
          Log[x]^2 + 2300400393984000*(2604373*CA + 
           4*(2339453*CF - 360*(7397*NM + 167*NL)))*Log[x]^3 + 
         166320*Log[x]*(4*(-40*(-194500845*NL*(301943 + 75908*lm + 
                 12600*lm^2 + 30920*Pi^2) + 264627*NM*(988684013 - 
                 55792380*lm - 9261000*lm^2 + 847278600*Pi^2) - NH*
                (897389697845163 + 14764170142260*lm + 2450710647000*lm^2 - 
                 504804683952800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
             121*CF*(-11941028507847 - 45141685041600*lm - 7291370520000*
                lm^2 + 14925498323400*Pi^2 + 38109129816800*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 19443654720000*Zeta[3])) + 
           605*CA*(-31793531912319 - 26012009338560*lm - 3564670032000*lm^2 + 
             4949598921120*Pi^2 + 15243651926720*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 7777461888000*Zeta[3])) - 
         1331*CA*(91112966017920000*lm^2 - 611246077791375600*Pi^2 + 
           93367368051160000*Sqrt[3]*Pi^3 + 8276299651872000*Pi^4 - 
           259248729600*lm*(-743519 + 6600*Pi^2) + 72026255353752000*Sqrt[3]*
            Pi*Log[3]^2 - 3*(239414153676321369 + 236170336858489600*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 318409289694720000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 - 1152420085660032000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 48450541447840000*
              PolyGamma[2, 1] + 66804609822272000*Zeta[3])) + 
         4*(1331*CF*(34355922344187921 + 37273486098240000*lm^2 - 
             312815973277458000*Pi^2 + 46683684025580000*Sqrt[3]*Pi^3 + 
             4013710435728000*Pi^4 - 2333238566400*lm*(-16127 + 300*Pi^2) - 
             354255505287734400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             477613934542080000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             1728630128490048000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] + 36013127676876000*Sqrt[3]*Pi*Log[3]^2 - 
             72675812171760000*PolyGamma[2, 1] - 391159819598016000*
              Zeta[3]) - 160*(-(NH*(-40233026266212196899 + 
                34452090275526000*lm^2 + 1700560779065995000*Sqrt[3]*Pi^3 - 
                1078312684680*lm*(-26929 + 600*Pi^2) - 4931581128493404000*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 62969336276272272000*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                1311861172422339000*Sqrt[3]*Pi*Log[3]^2 + 1395349056326302000*
                 PolyGamma[2, 1] - 9306676234235380000*Zeta[3])) + 
             89859390390*NL*(11355227 - 383400*lm^2 - 1101420*Pi^2 + 12*lm*
                (-26929 + 600*Pi^2) - 16783200*Zeta[3]) + 523961460*NM*
              (-65753100*lm^2 + 2058*lm*(-26929 + 600*Pi^2) + 5*
                (-4512192031 + 2621461878*Pi^2 + 4146211440*PolyGamma[2, 1] + 
                 4019767920*Zeta[3]))))))/1863324319127040000, 
      (825595842668823881*CF^2*NC)/77774618880000 + (2559707*CF^2*lm*NC)/
        43200 - (533*CF^2*lm^2*NC)/16 + (367580370939347*CF*NM*NC)/
        108020304000 + (2799557*CF*lm*NM*NC)/388800 - 
       (533*CF*lm^2*NM*NC)/144 + (3440524271*CF*NC*NL)/23328000 + 
       (2799557*CF*lm*NC*NL)/388800 - (533*CF*lm^2*NC*NL)/144 + 
       (1233904340402677021*CF*NC*NH)/1663682427792000 + 
       (2799557*CF*lm*NC*NH)/388800 - (533*CF*lm^2*NC*NH)/144 - 
       (53035099351*CF^2*NC*Pi^2)/10886400 - (43*CF^2*lm*NC*Pi^2)/72 - 
       (13003195*CF*NM*NC*Pi^2)/7776 - (43*CF*lm*NM*NC*Pi^2)/648 - 
       (155597*CF*NC*NL*Pi^2)/12960 - (43*CF*lm*NC*NL*Pi^2)/648 - 
       (43*CF*lm*NC*NH*Pi^2)/648 - (12708230717*CF^2*NC*Pi^3)/
        (68024448*Sqrt[3]) - (7261083305*CF*NC*NH*Pi^3)/(76527504*Sqrt[3]) - 
       (125257*CF^2*NC*Pi^4)/25920 - (486262422401*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(283435200*Sqrt[3]) + 
       (77708868487*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12754584*Sqrt[3]) - (8491*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (1815461531*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (262440*Sqrt[3]) - (207459523*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (1815461531*CF^2*NC*Pi*Log[3]^2)/(12597120*Sqrt[3]) - 
       (207459523*CF*NC*NH*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (CF*NC*(66*CF*(28922527957 + 635115600*lm) - 
          33*CA*(29679111911 + 776252400*lm) + 
          40*(110*(136583165 + 1058526*lm)*NM + 
            7*(99*(187727 + 168020*lm)*NL + 2*(1722641 + 8316990*lm)*NH)))*
         Log[x]^2)/29937600 + (CF*NC*(2947351*CA - 8162912*CF - 1617400*NM + 
          33604*NL)*Log[x]^3)/324 - (177645976307*CF^2*NC*PolyGamma[2, 1])/
        28343520 - (1972909*CF*NM*NC*PolyGamma[2, 1])/2160 - 
       (281503339567*CF*NC*NH*PolyGamma[2, 1])/573956280 + 
       (CA*CF*NC*(3562442113230000*lm^2 + 428540739566434425*Pi^2 + 
          5448653919913750*Sqrt[3]*Pi^3 + 413532104422500*Pi^4 + 
          225042300*lm*(-10647727 + 283800*Pi^2) + 4203247309647750*Sqrt[3]*
           Pi*Log[3]^2 + 12*(-83771453821840536 + 4169700272088575*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 5159252257110000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 16812989238591000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 45699427404975750*
             PolyGamma[2, 1] - 15111598766523000*Zeta[3])))/174992892480000 + 
       (18005710307*CF^2*NC*Zeta[3])/7085880 + (1321571*CF*NM*NC*Zeta[3])/
        1080 - (1603*CF*NC*NL*Zeta[3])/9 - (1033113259987*CF*NC*NH*Zeta[3])/
        286978140 - (CF*NC*Log[x]*(-1089*CA*(871959239468823 + 
            29061191048400*lm + 5941116720000*lm^2 + 226523739172500*Pi^2 - 
            35583046007600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            12962436480000*Zeta[3]) + 
          4*(10*(117612*NM*(218911370203 + 904872465*lm + 250047000*lm^2 + 
                29713455450*Pi^2) + 7*(5557167*NL*(14715861 + 2735820*lm + 
                  756000*lm^2 + 1932200*Pi^2) + 2*NH*(135758555351169 + 
                  7601704310970*lm + 2100609126000*lm^2 - 70287286392400*
                   Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
            1089*CF*(413697101676279 + 9200436499800*lm + 2430456840000*lm^
                2 + 111953330770050*Pi^2 - 17791523003800*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 6481218240000*Zeta[3]))))/
        100829238048000, 
      (CF*NC*(-1136009415340800*(429*CA*(-14100262123 + 2451372000*lm) - 
           8*(3861*CF*(-408877549 + 55713000*lm) + 
             10*(572*(-1121485313 + 4178475*lm)*NM + 3153150*(991 + 758*lm)*
                NL + (488071709 + 2390087700*lm)*NH)))*Log[x]^2 + 
         545829803882947584000*(6874243*CA + 4527179*CF - 38820260*NM - 
           265300*NL)*Log[x]^3 + 2162160*Log[x]*
          (2*(-480*(24845535*NM*(287345234039 - 1714433364*lm - 280052640*
                  lm^2 + 102081992040*Pi^2) - 2*(13148257122*NL*(7335549 + 
                   1619835*lm + 264600*lm^2 + 751450*Pi^2) + 
                 NH*(1455803786370006267 + 21298007075214870*lm + 
                   3479028834481200*lm^2 - 819117445210464400*Sqrt[3]*
                    Im[PolyLog[2, (-1)^(1/3)]]))) - 20449*CF*
              (80501301136574511 - 9243707890435200*lm - 1469940296832000*
                lm^2 + 15845156393761800*Pi^2 + 8741143189032800*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 3919840791552000*Zeta[3])) + 
           20449*CA*(65978663329929921 - 13285006711804800*lm - 
             1796593696128000*lm^2 + 15259284356236200*Pi^2 + 
             8741143189032800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             3919840791552000*Zeta[3])) - 2924207*CA*(457687996109486284851 + 
           7842131483598720000*lm^2 - 288909890357675428800*Pi^2 + 
           10707900406565180000*Sqrt[3]*Pi^3 + 855576708187320000*Pi^4 - 
           388873094400*lm*(-42685411 + 323400*Pi^2) - 77257119579498398400*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 93951234072017280000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 396498255054527808000*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 8260380313635996000*
            Sqrt[3]*Pi*Log[3]^2 - 217558721329876640000*PolyGamma[2, 1] - 
           56966767479664672000*Zeta[3]) + 
         10*(-192*(-5*NH*(-668843101074314691322047 + 434318480667798526800*
                lm^2 + 28697779692948620254000*Sqrt[3]*Pi^3 - 236905296824196*
                lm*(-1547201 + 29400*Pi^2) - 87531826547008868344320*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 1062637785201754624262400*
                Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               22138287191703221338800*Sqrt[3]*Pi*Log[3]^2 + 
               23173103877994644173600*PolyGamma[2, 1] - 
               160224218668936980958400*Zeta[3]) + 78968432274732*NL*
              (1194685678 - 23208015*lm - 27499500*lm^2 - 92906100*Pi^2 + 
               441000*lm*Pi^2 - 1628424000*Zeta[3]) + 42634938060*NM*
              (-151867108147535 - 50934573900*lm^2 + 59971979835180*Pi^2 + 
               27783*lm*(-1547201 + 29400*Pi^2) + 98101989707400*
                PolyGamma[2, 1] + 83562806854800*Zeta[3])) + 
           265837*CF*(14115836670477696000*lm^2 - 639584106696590176800*
              Pi^2 + 23557380894443396000*Sqrt[3]*Pi^3 + 1842025059218836800*
              Pi^4 - 7699687269120*lm*(-1852751 + 29400*Pi^2) + 
             18172836689999191200*Sqrt[3]*Pi*Log[3]^2 - 
             11*(-107563538688358714317 + 15451423915899679680*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 18790246814403456000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 79299651010905561600*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 43511744265975328000*
                PolyGamma[2, 1] + 24007037177930912000*Zeta[3])))))/
       221061070572593771520000, (4667533080458079058547953*CF^2*NC)/
        39129810701667840000 + (63755639*CF^2*lm*NC)/705600 - 
       (825*CF^2*lm^2*NC)/16 + (1923231734716947679*CF*NM*NC)/
        47925008208000 + (69819389*CF*lm*NM*NC)/6350400 - 
       (275*CF*lm^2*NM*NC)/48 + (23923325371*CF*NC*NL)/76204800 + 
       (69819389*CF*lm*NC*NL)/6350400 - (275*CF*lm^2*NC*NL)/48 + 
       (3501690318417174810727*CF*NC*NH)/3070292646841580160 + 
       (69819389*CF*lm*NC*NH)/6350400 - (275*CF*lm^2*NC*NH)/48 - 
       (118500321961729*CF^2*NC*Pi^2)/2514758400 - (19*CF^2*lm*NC*Pi^2)/24 - 
       (1607860481*CF*NM*NC*Pi^2)/90720 - (19*CF*lm*NM*NC*Pi^2)/216 - 
       (215417*CF*NC*NL*Pi^2)/10080 - (19*CF*lm*NC*NL*Pi^2)/216 - 
       (19*CF*lm*NC*NH*Pi^2)/216 - (329125485407*CF^2*NC*Pi^3)/
        (918330048*Sqrt[3]) - (40076015945*CF*NC*NH*Pi^3)/
        (229582512*Sqrt[3]) - (19931*CF^2*NC*Pi^4)/2160 - 
       (569594236622849*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (187492384800*Sqrt[3]) + (2112215594579*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(191318760*Sqrt[3]) - 
       1233*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (329125485407*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (24800580*Sqrt[3]) - (1145029027*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (329125485407*CF^2*NC*Pi*Log[3]^2)/(1190427840*Sqrt[3]) - 
       (1145029027*CF*NC*NH*Pi*Log[3]^2)/(8503056*Sqrt[3]) - 
       (CF*NC*(26*CF*(20141958666923 + 103541684400*lm) - 
          13*CA*(20266783348223 + 126550947600*lm) + 
          280*(26*(26541330803 + 41087970*lm)*NM + 
            7*(9009*(18317 + 16940*lm)*NL + 2*(18817319 + 76306230*lm)*
               NH)))*Log[x]^2)/908107200 + 
       (CF*NC*(322169793*CA - 28*(25292159*CF + 7870730*NM - 29645*NL))*
         Log[x]^3)/3780 - (415351735121299*CF^2*NC*PolyGamma[2, 1])/
        6887475360 - (1343395*CF*NM*NC*PolyGamma[2, 1])/144 - 
       (527799656831*CF*NC*NH*PolyGamma[2, 1])/573956280 - 
       (111393166239695*CF^2*NC*Zeta[3])/4821232752 + 
       (831245*CF*NM*NC*Zeta[3])/72 - (1111*CF*NC*NL*Zeta[3])/3 - 
       (1832668001771*CF*NC*NH*Zeta[3])/286978140 + 
       CA*CF*NC*(-4727481645107790788862649/78259621403335680000 + 
         (3025*lm^2)/96 + (3594412021441*Pi^2)/152409600 + 
         (329125485407*Pi^3)/(1836660096*Sqrt[3]) + (19627*Pi^4)/4320 + 
         (11*lm*(-23514389 + 558600*Pi^2))/12700800 + 
         (569594236622849*Im[PolyLog[2, (-1)^(1/3)]])/(374984769600*
           Sqrt[3]) + (1233*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (329125485407*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (49601160*Sqrt[3]) + (329125485407*Pi*Log[3]^2)/
          (2380855680*Sqrt[3]) + (415351735121299*PolyGamma[2, 1])/
          13774950720 + (579042300610927*Zeta[3])/48212327520) + 
       CF*Log[x]*((-45259537515407*NM*NC)/432224100 - (194567*lm*NM*NC)/
          2520 - 21*lm^2*NM*NC - (24447589*NC*NL)/50400 - 
         (194567*lm*NC*NL)/2520 - 21*lm^2*NC*NL - 
         (297501636723980609*NC*NH)/213001765376400 - (194567*lm*NC*NH)/
          2520 - 21*lm^2*NC*NH - (1605527*NM*NC*Pi^2)/108 - 
         (6685*NC*NL*Pi^2)/108 + (1145029027*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-29243236029109640873/141160933267200 - (203387*lm)/280 - 
           189*lm^2 - (981276179*Pi^2)/22680 + 
           (329125485407*Im[PolyLog[2, (-1)^(1/3)]])/(74401740*Sqrt[3]) - 
           504*Zeta[3]) + CA*NC*(21077796564051277327/201658476096000 + 
           (2881117*lm)/5040 + (231*lm^2)/2 + (7288709*Pi^2)/336 - 
           (329125485407*Im[PolyLog[2, (-1)^(1/3)]])/(148803480*Sqrt[3]) + 
           252*Zeta[3])), 
      (CF*NC*(-2556021184516800*(13*CA*(-5522387959043 + 140147330400*lm) - 
           4*(52*CF*(-694821680029 + 14333249700*lm) + 
             35*(637*(-4586495231 + 3714480*lm)*NM + 17657640*(173 + 134*lm)*
                NL + (549722869 + 2366123760*lm)*NH)))*Log[x]^2 + 
         153514632342079008000*(389399227*CA - 8*(61854031*CF + 
             70*(3907177*NM + 6566*NL)))*Log[x]^3 + 3243240*Log[x]*
          (2*(-280*(-8452451007*NL*(100056279 + 19672920*lm + 3175200*lm^2 + 
                 10250800*Pi^2) + 739206*NM*(248218049707379 - 224950003740*
                  lm - 36306824400*lm^2 + 62473415281200*Pi^2) - NH*
                (12673427011045365549 + 166284392464630440*lm + 
                 26838222437426400*lm^2 - 7133472654990281600*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]])) - 507*CF*
              (51224321903013930633 - 848735152730942400*lm - 
               133397081937504000*lm^2 + 8521121409761129400*Pi^2 + 
               884542375282042400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               355725551833344000*Zeta[3])) + 507*CA*(49828610041506226167 - 
             1217676056697777600*lm - 163040877923616000*lm^2 + 
             8461373737710108600*Pi^2 + 884542375282042400*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 355725551833344000*Zeta[3])) - 
         30758*CA*(1226828233559915759869821 + 2196335312286025680000*lm^2 - 
           531610779630885941378700*Pi^2 + 3831174162940346145000*Sqrt[3]*
            Pi^3 + 280013973501064572000*Pi^4 - 23766891825600*lm*
            (-195505909 + 1293600*Pi^2) - 26953946623440715863600*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 29601003049192048320000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 141862906147733960112000*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2955477211411124169000*
            Sqrt[3]*Pi*Log[3]^2 - 457796228060850394100000*PolyGamma[2, 1] - 
           42804875813474783008000*Zeta[3]) + 
         5*(2197*CF*(7019078641338878933369409 + 10063209067201426752000*
              lm^2 - 2980702658254020814144800*Pi^2 + 21454575312465938412000*
              Sqrt[3]*Pi^3 + 1543035172756894185600*Pi^4 - 2395702696020480*
              lm*(-4240597 + 58800*Pi^2) - 150942101091268008836160*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 165765617075475470592000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 794432274427310176627200*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 16550672383902295346400*
              Sqrt[3]*Pi*Log[3]^2 - 2563658877140762206960000*
              PolyGamma[2, 1] - 362205818219252320544000*Zeta[3]) - 
           168*(-5*NH*(-5761174791573514460278647 + 2924453746116605102400*
                lm^2 + 249921214467584515856000*Sqrt[3]*Pi^3 - 
               348105742272288*lm*(-7081019 + 117600*Pi^2) - 
               796604975673042477701760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               9254225541428272358553600*Sqrt[3]*Im[PolyLog[3, 
                  -((-1)^(5/6)/Sqrt[3])]] + 192796365446422340803200*Sqrt[3]*
                Pi*Log[3]^2 + 198613481807692011060000*PolyGamma[2, 1] - 
               1406529029168753100811200*Zeta[3]) + 116035247424096*NL*
              (7574499631 - 126015750*lm^2 - 489182400*Pi^2 + 15*lm*
                (-7081019 + 117600*Pi^2) - 9708174000*Zeta[3]) + 
             504508095*NM*(-562587070795405631 - 28983219249600*lm^2 + 
               206028554825126880*Pi^2 + 3449952*lm*(-7081019 + 
                 117600*Pi^2) + 349064726033469600*PolyGamma[2, 1] + 
               314716606400750400*Zeta[3])))))/435213982689793987680000, 
      (860744959793190391047383609*CF^2*NC)/732683472541740720000 + 
       (1107296837*CF^2*lm*NC)/8467200 - (1207*CF^2*lm^2*NC)/16 + 
       (2221420943106321801899557*CF*NM*NC)/5053979665582848000 + 
       (1213754237*CF*lm*NM*NC)/76204800 - (1207*CF*lm^2*NM*NC)/144 + 
       (22254690193*CF*NC*NL)/36578304 + (1213754237*CF*lm*NC*NL)/
        76204800 - (1207*CF*lm^2*NC*NL)/144 + 
       (320536170222871480976323*CF*NC*NH)/200964609611448883200 + 
       (1213754237*CF*lm*NC*NH)/76204800 - (1207*CF*lm^2*NC*NH)/144 - 
       (2261879019950929*CF^2*NC*Pi^2)/5029516800 - (73*CF^2*lm*NC*Pi^2)/72 - 
       (50491183469*CF*NM*NC*Pi^2)/272160 - (73*CF*lm*NM*NC*Pi^2)/648 - 
       (801761*CF*NC*NL*Pi^2)/22680 - (73*CF*lm*NC*NL*Pi^2)/648 - 
       (73*CF*lm*NC*NH*Pi^2)/648 - (3467902410007*CF^2*NC*Pi^3)/
        (5509980288*Sqrt[3]) - (101468624075*CF*NC*NH*Pi^3)/
        (344373768*Sqrt[3]) - (207931*CF^2*NC*Pi^4)/12960 - 
       (1617683043524539*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (321415516800*Sqrt[3]) + (32251081176671*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1721868840*Sqrt[3]) - 
       (4011*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (495414630001*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (21257640*Sqrt[3]) - (5798207090*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (495414630001*CF^2*NC*Pi*Log[3]^2)/(1020366720*Sqrt[3]) - 
       (2899103545*CF*NC*NH*Pi*Log[3]^2)/(12754584*Sqrt[3]) - 
       (CF*NC*(-11*CA*(335897819509729 + 429963534000*lm) + 
          11*CF*(670940130708593 + 703576692000*lm) + 
          70*((43326687540119 + 12284672400*lm)*NM + 
            11*(22932*(51353 + 48700*lm)*NL + (313666819 + 1116788400*lm)*
               NH)))*Log[x]^2)/1362160800 + 
       (CF*NC*(9095801765*CA - 18603364197*CF - 7129729880*NM + 4772600*NL)*
         Log[x]^3)/11340 - (35392445467767413*CF^2*NC*PolyGamma[2, 1])/
        61987278240 - (107487869*CF*NM*NC*PolyGamma[2, 1])/1080 - 
       (149515284320203*CF*NC*NH*PolyGamma[2, 1])/92980917360 - 
       (34364683716539203*CF^2*NC*Zeta[3])/108477736920 + 
       (63246421*CF*NM*NC*Zeta[3])/540 - (12599*CF*NC*NL*Zeta[3])/18 - 
       (495532289149843*CF*NC*NH*Zeta[3])/46490458680 + 
       CA*CF*NC*(-6900907473620126312089990933/11722935560667851520000 + 
         (13277*lm^2)/288 + (754085422078427*Pi^2)/3353011200 + 
         (3467902410007*Pi^3)/(11019960576*Sqrt[3]) + (41119*Pi^4)/5184 + 
         lm*(-4408875007/152409600 + (803*Pi^2)/1296) + 
         (1617683043524539*Im[PolyLog[2, (-1)^(1/3)]])/(642831033600*
           Sqrt[3]) + (4011*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (495414630001*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (42515280*Sqrt[3]) + (495414630001*Pi*Log[3]^2)/
          (2040733440*Sqrt[3]) + (35392445467767413*PolyGamma[2, 1])/
          123974556480 + (34544562102554041*Zeta[3])/216955473840) + 
       CF*Log[x]*((-7348509095479639639*NM*NC)/7012403798400 - 
         (1969633*lm*NM*NC)/15120 - 35*lm^2*NM*NC - (283441049*NC*NL)/
          302400 - (1969633*lm*NC*NL)/15120 - 35*lm^2*NC*NL - 
         (157474654065184579*NC*NH)/66390160636800 - (1969633*lm*NC*NH)/
          15120 - 35*lm^2*NC*NH - (12776387*NM*NC*Pi^2)/81 - 
         (18935*NC*NL*Pi^2)/162 + (5798207090*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(-137180180918753109806173/65062357424064000 - 
           (2057833*lm)/1680 - 315*lm^2 - (7300315991*Pi^2)/18144 + 
           (495414630001*Im[PolyLog[2, (-1)^(1/3)]])/(63772920*Sqrt[3]) - 
           840*Zeta[3]) + CA*NC*(17175043850308565430719/16265589356016000 + 
           (29074763*lm)/30240 + (385*lm^2)/2 + (7304433223*Pi^2)/36288 - 
           (495414630001*Im[PolyLog[2, (-1)^(1/3)]])/(127545840*Sqrt[3]) + 
           420*Zeta[3])), (30057979097820180148892783789*CF^2*NC)/
        16119036395918295840000 + (85842101*CF^2*lm*NC)/235200 + 
       (1449*CF^2*lm^2*NC)/4 + (4923153813341505294313*CF*NM*NC)/
        981736531776000 + (71641901*CF*lm*NM*NC)/2116800 + 
       (161*CF*lm^2*NM*NC)/4 - (1424443451639*CF*NC*NL)/444528000 + 
       (71641901*CF*lm*NC*NL)/2116800 + (161*CF*lm^2*NC*NL)/4 - 
       (134355102719833275355268455007*CF*NC*NH)/1357591299653941499347200 + 
       (71641901*CF*lm*NC*NH)/2116800 + (161*CF*lm^2*NC*NH)/4 - 
       (98029010646306811*CF^2*NC*Pi^2)/130767436800 - 
       (9*CF^2*lm*NC*Pi^2)/2 - (2297395417*CF*NM*NC*Pi^2)/1260 - 
       (CF*lm*NM*NC*Pi^2)/2 + (148217*CF*NC*NL*Pi^2)/840 - 
       (CF*lm*NC*NL*Pi^2)/2 - (CF*lm*NC*NH*Pi^2)/2 + 
       (31616555624197*CF^2*NC*Pi^3)/(11019960576*Sqrt[3]) + 
       (559184981425*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) + 
       (551459*CF^2*NC*Pi^4)/8640 - (89875357899632507*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4499817235200*Sqrt[3]) - 
       (64862643527587*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1506635235*Sqrt[3]) + (26521*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        4 + (31616555624197*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (297606960*Sqrt[3]) + (255627420080*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) + 
       (31616555624197*CF^2*NC*Pi*Log[3]^2)/(14285134080*Sqrt[3]) + 
       (15976713755*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) + 
       CF*((-48479790825852481*CF*NC)/5448643200 + 
         CA*(48423833388828421/10897286400 - 19514*lm)*NC + 31932*CF*lm*NC - 
         (82672002809*NM*NC)/3780 + 3548*lm*NM*NC + (13610*NC*NL)/3 + 
         3548*lm*NC*NL + (837269231*NC*NH)/918918 + 3548*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-29816792965*CA + 6*(9173692417*CF + 
            10080*(2514400*NM + 887*NL)))*Log[x]^3)/22680 - 
       (12065250433815779*CF^2*NC*PolyGamma[2, 1])/18596183472 - 
       (18879781*CF*NM*NC*PolyGamma[2, 1])/6 + 
       (7876676252731*CF*NC*NH*PolyGamma[2, 1])/2324522934 - 
       (18274159766505571*CF^2*NC*Zeta[3])/1301732843040 - 
       2963909*CF*NM*NC*Zeta[3] + 3914*CF*NC*NL*Zeta[3] - 
       (28367285334197*CF*NC*NH*Zeta[3])/1162261467 + 
       CA*CF*NC*(-479296460830059466691957415791/515809164669385466880000 - 
         (1771*lm^2)/8 + (2513022649888613*Pi^2)/6706022400 - 
         (31616555624197*Pi^3)/(22039921152*Sqrt[3]) - (558371*Pi^4)/17280 + 
         lm*(-1980877711/4233600 + (11*Pi^2)/4) + 
         (89875357899632507*Im[PolyLog[2, (-1)^(1/3)]])/(8999634470400*
           Sqrt[3]) - (26521*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 - 
         (31616555624197*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (595213920*Sqrt[3]) - (31616555624197*Pi*Log[3]^2)/
          (28570268160*Sqrt[3]) + (12065250433815779*PolyGamma[2, 1])/
          37192366944 + (11278941563206483*Zeta[3])/2603465686080) + 
       CF*Log[x]*((-10511885125572463*NM*NC)/1362160800 + 
         (157597*lm*NM*NC)/140 + 180*lm^2*NM*NC + (841153127*NC*NL)/
          132300 + (157597*lm*NC*NL)/140 + 180*lm^2*NC*NL + 
         (17527273000254630966553*NC*NH)/184672530581338800 + 
         (157597*lm*NC*NH)/140 + 180*lm^2*NC*NH - (5027858*NM*NC*Pi^2)/3 + 
         (1954*NC*NL*Pi^2)/3 - (255627420080*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CA*NC*(1111699200396884710754069/572548745331763200 - 
           (2086367*lm)/280 - 990*lm^2 + (117693455731*Pi^2)/362880 + 
           (31616555624197*Im[PolyLog[2, (-1)^(1/3)]])/(1785641760*Sqrt[3]) - 
           2160*Zeta[3]) + CF*NC*(-797723043873997065885763/
            204481694761344000 + (1456173*lm)/140 + 1620*lm^2 - 
           (39279920201*Pi^2)/60480 - (31616555624197*
             Im[PolyLog[2, (-1)^(1/3)]])/(892820880*Sqrt[3]) + 
           4320*Zeta[3])), (3747617594852288955444204372029*CF^2*NC)/
        331591605858890657280000 + (1978257073*CF^2*lm*NC)/10886400 - 
       (1691*CF^2*lm^2*NC)/16 + (4689625331517233182128643*CF*NM*NC)/
        1010795933116569600 + (2170016473*CF*lm*NM*NC)/97977600 - 
       (1691*CF*lm^2*NM*NC)/144 + (105101238545003*CF*NC*NL)/96018048000 + 
       (2170016473*CF*lm*NC*NL)/97977600 - (1691*CF*lm^2*NC*NL)/144 + 
       (54306655654362501490108859231*CF*NC*NH)/26658156429568305805363200 + 
       (2170016473*CF*lm*NC*NH)/97977600 - (1691*CF*lm^2*NC*NH)/144 - 
       (1687164298236170177*CF^2*NC*Pi^2)/392302310400 - 
       (91*CF^2*lm*NC*Pi^2)/72 - (1555597954277*CF*NM*NC*Pi^2)/816480 - 
       (91*CF*lm*NM*NC*Pi^2)/648 - (1611271*CF*NC*NL*Pi^2)/29160 - 
       (91*CF*lm*NC*NL*Pi^2)/648 - (91*CF*lm*NC*NH*Pi^2)/648 - 
       (102473955018695*CF^2*NC*Pi^3)/(99179645184*Sqrt[3]) - 
       (4326022284115*CF*NC*NH*Pi^3)/(9298091736*Sqrt[3]) - 
       (674731*CF^2*NC*Pi^4)/25920 - (64084591473062911*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8099671023360*Sqrt[3]) + 
       (1401180500579783*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (46490458680*Sqrt[3]) - (37105*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        12 - (20494791003739*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (535692528*Sqrt[3]) - (247201273378*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (20494791003739*CF^2*NC*Pi*Log[3]^2)/(25713241344*Sqrt[3]) - 
       (123600636689*CF*NC*NH*Pi*Log[3]^2)/(344373768*Sqrt[3]) - 
       (CF*NC*(-51*CA*(281468534113606531 + 67213857110400*lm) + 
          2*(17*CF*(844203700324279369 + 164979467452800*lm) + 
            840*(51*(148304124699527 + 7274226960*lm)*NM + 
              11*(167076*(208667 + 201860*lm)*NL + (10482214517 + 
                  33725961360*lm)*NH))))*Log[x]^2)/555761606400 + 
       (CF*NC*(519039019151*CA - 48*(21727946033*CF + 9270216165*NM - 
            1059765*NL))*Log[x]^3)/68040 - (1000231792005807373*CF^2*NC*
         PolyGamma[2, 1])/185961834720 - (3399911831*CF*NM*NC*
         PolyGamma[2, 1])/3240 - (2225142873245987*CF*NC*NH*PolyGamma[2, 1])/
        836828256240 - (4020588728670379781*CF^2*NC*Zeta[3])/1301732843040 + 
       (1902056299*CF*NM*NC*Zeta[3])/1620 - (66407*CF*NC*NL*Zeta[3])/54 - 
       (7087843392519707*CF*NC*NH*Zeta[3])/418414128120 + 
       CA*CF*NC*(-23431045969790461419730981361/4144895073236133216000 + 
         (18601*lm^2)/288 + (5191415111244389*Pi^2)/2414168064 + 
         (102473955018695*Pi^3)/(198359290368*Sqrt[3]) + (74323*Pi^4)/5760 + 
         lm*(-7762391603/195955200 + (1001*Pi^2)/1296) + 
         (64084591473062911*Im[PolyLog[2, (-1)^(1/3)]])/(16199342046720*
           Sqrt[3]) + (37105*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (20494791003739*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1071385056*Sqrt[3]) + (20494791003739*Pi*Log[3]^2)/
          (51426482688*Sqrt[3]) + (1000231792005807373*PolyGamma[2, 1])/
          371923669440 + (804853125472998865*Zeta[3])/520693137216) + 
       CF*Log[x]*((-24274746779382162967*NM*NC)/2337467932800 - 
         (4018477*lm*NM*NC)/19440 - 55*lm^2*NM*NC - (31955144213*NC*NL)/
          19051200 - (4018477*lm*NC*NL)/19440 - 55*lm^2*NC*NL - 
         (13659662096063756478281*NC*NH)/3626296964142652800 - 
         (4018477*lm*NC*NH)/19440 - 55*lm^2*NC*NH - (4907795*NM*NC*Pi^2)/
          3 - (11083*NC*NL*Pi^2)/54 + (247201273378*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(-265475303836574410924114801/12882346769964672000 - 
           (4196677*lm)/2160 - 495*lm^2 - (2077459352861*Pi^2)/544320 + 
           (20494791003739*Im[PolyLog[2, (-1)^(1/3)]])/(1607077584*Sqrt[3]) - 
           1320*Zeta[3]) + CA*NC*(265548817527109927959320203/
            25764693539929344000 + (59172047*lm)/38880 + (605*lm^2)/2 + 
           (2077677717077*Pi^2)/1088640 - (20494791003739*
             Im[PolyLog[2, (-1)^(1/3)]])/(3214155168*Sqrt[3]) + 
           660*Zeta[3])), (2410328302011265993955322896201*CF^2*NC)/
        127899619402714967808000 + (95265361*CF^2*lm*NC)/190512 + 
       (995*CF^2*lm^2*NC)/2 + (527313386177901257472133*CF*NM*NC)/
        11486317421779200 + (79468741*CF*lm*NM*NC)/1714608 + 
       (995*CF*lm^2*NM*NC)/18 - (45098120743129*CF*NC*NL)/8001504000 + 
       (79468741*CF*lm*NC*NL)/1714608 + (995*CF*lm^2*NC*NL)/18 - 
       (949840709166461798259415937497459*CF*NC*NH)/
        5714009217200281547468318400 + (79468741*CF*lm*NC*NH)/1714608 + 
       (995*CF*lm^2*NC*NH)/18 - (14570344747768213*CF^2*NC*Pi^2)/
        1961511552 - (50*CF^2*lm*NC*Pi^2)/9 - (428442543064*CF*NM*NC*Pi^2)/
        25515 - (50*CF*lm*NM*NC*Pi^2)/81 + (5511455*CF*NC*NL*Pi^2)/20412 - 
       (50*CF*lm*NC*NL*Pi^2)/81 - (50*CF*lm*NC*NH*Pi^2)/81 + 
       (265734523678325*CF^2*NC*Pi^3)/(55788550416*Sqrt[3]) + 
       (102150127306745*CF*NC*NH*Pi^3)/(4649045868*Sqrt[3]) + 
       (64175*CF^2*NC*Pi^4)/648 - (180970521300949147*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5467277940768*Sqrt[3]) - 
       (3067332783798802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (40679151345*Sqrt[3]) + (30050*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        3 + (53146904735665*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (301327047*Sqrt[3]) + (11674300263628*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) + 
       (53146904735665*CF^2*NC*Pi*Log[3]^2)/(14463698256*Sqrt[3]) + 
       (2918575065907*CF*NC*NH*Pi*Log[3]^2)/(172186884*Sqrt[3]) + 
       CF*((-1817877611097761*CF*NC)/20432412 + 
         CA*(24233505759006667/544864320 - (300278*lm)/9)*NC + 
         54596*CF*lm*NC - (1485158908276*NM*NC)/7371 + (54596*lm*NM*NC)/9 + 
         (69280*NC*NL)/9 + (54596*lm*NC*NL)/9 + (120561174257*NC*NH)/
          71424990 + (54596*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-88288405205*CA + 48*(3624820603*CF + 8604319836*NM + 
            573258*NL))*Log[x]^3)/6804 - (1590974456927775289*CF^2*NC*
         PolyGamma[2, 1])/251048476872 - (4705373533*CF*NM*NC*
         PolyGamma[2, 1])/162 + (59079955204948*CF*NC*NH*PolyGamma[2, 1])/
        10460353203 + CA*CF*NC*(-236084362524388277019559784405569/
          25068325402932133690368000 - (10945*lm^2)/36 + 
         (3642458491778137*Pi^2)/980755776 - (265734523678325*Pi^3)/
          (111577100832*Sqrt[3]) - (21605*Pi^4)/432 + 
         lm*(-2201072231/3429216 + (275*Pi^2)/81) + 
         (180970521300949147*Im[PolyLog[2, (-1)^(1/3)]])/
          (10934555881536*Sqrt[3]) - (15025*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (53146904735665*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (602654094*Sqrt[3]) - (53146904735665*Pi*Log[3]^2)/
          (28927396512*Sqrt[3]) + (1590974456927775289*PolyGamma[2, 1])/
          502096953744 - (112938848652849649*Zeta[3])/878669669052) + 
       (218090999921032895*CF^2*NC*Zeta[3])/878669669052 - 
       (2250235651*CF*NM*NC*Zeta[3])/81 + (178838*CF*NC*NL*Zeta[3])/27 - 
       (430931148649804*CF*NC*NH*Zeta[3])/10460353203 + 
       CF*Log[x]*((-3961020459492284263*NM*NC)/53124271200 + 
         (5894495*lm*NM*NC)/3402 + 275*lm^2*NM*NC + (34183153601*NC*NL)/
          3175200 + (5894495*lm*NC*NL)/3402 + 275*lm^2*NC*NL + 
         (52514973411664910478677057*NC*NH)/327273301013874415200 + 
         (5894495*lm*NC*NH)/3402 + 275*lm^2*NC*NH - (45524333*NM*NC*Pi^2)/
          3 + (29773*NC*NL*Pi^2)/27 - (11674300263628*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CA*NC*(220699829324138257035122491/11594112092968204800 - 
           (77937145*lm)/6804 - (3025*lm^2)/2 + (88086088493*Pi^2)/27216 + 
           (53146904735665*Im[PolyLog[2, (-1)^(1/3)]])/(1807962282*Sqrt[3]) - 
           3300*Zeta[3]) + CF*NC*(-110432942982260519449301843/
            2898528023242051200 + (3025210*lm)/189 + 2475*lm^2 - 
           (44052272791*Pi^2)/6804 - (53146904735665*Im[PolyLog[2, (-1)^
                (1/3)]])/(903981141*Sqrt[3]) + 6600*Zeta[3])), 
      (1214866386413090517235610397245476687*CF^2*NC)/
        11196425700418688438252544000 + (248323153*CF^2*lm*NC)/1016064 - 
       (2289*CF^2*lm^2*NC)/16 + (79157703229197847045714337339*CF*NM*NC)/
        1655346806467235481600 + (272549929*CF*lm*NM*NC)/9144576 - 
       (763*CF*lm^2*NM*NC)/48 + (19786289662637*CF*NC*NL)/10668672000 + 
       (272549929*CF*lm*NC*NL)/9144576 - (763*CF*lm^2*NC*NL)/48 + 
       (126688494550823078094393885820567*CF*NC*NH)/
        53778910279532061623231232000 + (272549929*CF*lm*NC*NH)/9144576 - 
       (763*CF*lm^2*NC*NH)/48 - (5387619391308780523*CF^2*NC*Pi^2)/
        130767436800 - (37*CF^2*lm*NC*Pi^2)/24 - 
       (1048123276099*CF*NM*NC*Pi^2)/54432 - (37*CF*lm*NM*NC*Pi^2)/216 - 
       (561733*CF*NC*NL*Pi^2)/6804 - (37*CF*lm*NC*NL*Pi^2)/216 - 
       (37*CF*lm*NC*NH*Pi^2)/216 - (1435607162516111*CF^2*NC*Pi^3)/
        (892616806656*Sqrt[3]) - (6475251148415*CF*NC*NH*Pi^3)/
        (9298091736*Sqrt[3]) - (69185*CF^2*NC*Pi^4)/1728 - 
       (13037255422590720301*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1093455588153600*Sqrt[3]) + (3022446656896925*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(65086642152*Sqrt[3]) - 
       (18271*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (1435607162516111*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (24106163760*Sqrt[3]) - (370014351338*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (1435607162516111*CF^2*NC*Pi*Log[3]^2)/(1157095860480*Sqrt[3]) - 
       (185007175669*CF*NC*NH*Pi*Log[3]^2)/(344373768*Sqrt[3]) + 
       CF*((-4163694643051099811*CF*NC)/8420630400 - 16887*CF*lm*NC + 
         CA*(1387956511028929601/5613753600 + (61919*lm)/6)*NC - 
         (404444403798143*NM*NC)/1750320 - (5629*lm*NM*NC)/3 - 
         (38171*NC*NL)/20 - (5629*lm*NC*NL)/3 - (202513085*NC*NH)/320112 - 
         (5629*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(165457188518*CA - 331212011671*CF - 
          504*(299716481*NM - 5629*NL))*Log[x]^3)/2268 - 
       (50754522693684575381*CF^2*NC*PolyGamma[2, 1])/1004193907488 - 
       (7815909841*CF*NM*NC*PolyGamma[2, 1])/720 - 
       (2636147296123951*CF*NC*NH*PolyGamma[2, 1])/627621192180 - 
       (986413265242398099791*CF^2*NC*Zeta[3])/35146786762080 + 
       (4174330019*CF*NM*NC*Zeta[3])/360 - (36707*CF*NC*NL*Zeta[3])/18 - 
       (8114896757571241*CF*NC*NH*Zeta[3])/313810596090 + 
       CA*CF*NC*(-173562373682421499231082032433668759/
          3198978771548196696643584000 + (8393*lm^2)/96 + 
         (1077528392350695991*Pi^2)/52306974720 + (1435607162516111*Pi^3)/
          (1785233613312*Sqrt[3]) + (38173*Pi^4)/1920 + 
         lm*(-963000035/18289152 + (407*Pi^2)/432) + 
         (13037255422590720301*Im[PolyLog[2, (-1)^(1/3)]])/
          (2186911176307200*Sqrt[3]) + (18271*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          8 + (1435607162516111*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (48212327520*Sqrt[3]) + (1435607162516111*Pi*Log[3]^2)/
          (2314191720960*Sqrt[3]) + (50754522693684575381*PolyGamma[2, 1])/
          2008387814976 + (986574148617415246559*Zeta[3])/70293573524160) + 
       CF*Log[x]*((-2554981101043638328067*NM*NC)/25019564169600 - 
         (14177197*lm*NM*NC)/45360 - (165*lm^2*NM*NC)/2 - 
         (298978079*NC*NL)/105840 - (14177197*lm*NC*NL)/45360 - 
         (165*lm^2*NC*NL)/2 - (436604017382781056361239*NC*NH)/
          77005482591499862400 - (14177197*lm*NC*NH)/45360 - 
         (165*lm^2*NC*NH)/2 - 16652531*NM*NC*Pi^2 - (3062*NC*NL*Pi^2)/9 + 
         (370014351338*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(-604815882217870077898071200897/
            3046089449879828352000 - (14800897*lm)/5040 - (1485*lm^2)/2 - 
           (6619032460363*Pi^2)/181440 + (1435607162516111*
             Im[PolyLog[2, (-1)^(1/3)]])/(72318491280*Sqrt[3]) - 
           1980*Zeta[3]) + CA*NC*(604843741739633355606398240399/
            6092178899759656704000 + (208339967*lm)/90720 + (1815*lm^2)/4 + 
           (6619153721699*Pi^2)/362880 - (1435607162516111*
             Im[PolyLog[2, (-1)^(1/3)]])/(144636982560*Sqrt[3]) + 
           990*Zeta[3])), (1557889398502402581243091520503875092387*CF^2*NC)/
        8313346082560876165402513920000 + (2531853161*CF^2*lm*NC)/3810240 + 
       (2651*CF^2*lm^2*NC)/4 + (1317635688968509462679408009081*CF*NM*NC)/
        3103775262126066528000 + (2110980401*CF*lm*NM*NC)/34292160 + 
       (2651*CF*lm^2*NM*NC)/36 - (22477244804629*CF*NC*NL)/2400451200 + 
       (2110980401*CF*lm*NC*NL)/34292160 + (2651*CF*lm^2*NC*NL)/36 - 
       (951348621735075420839322005831419993*CF*NC*NH)/
        3572759447386281304417032768000 + (2110980401*CF*lm*NC*NH)/
        34292160 + (2651*CF*lm^2*NC*NH)/36 - 
       (9547156659650553467*CF^2*NC*Pi^2)/130767436800 - 
       (121*CF^2*lm*NC*Pi^2)/18 - (15937681936147*CF*NM*NC*Pi^2)/102060 - 
       (121*CF*lm*NM*NC*Pi^2)/162 + (80936339*CF*NC*NL*Pi^2)/204120 - 
       (121*CF*lm*NC*NL*Pi^2)/162 - (121*CF*lm*NC*NH*Pi^2)/162 + 
       (181374534625754119*CF^2*NC*Pi^3)/(24100653779712*Sqrt[3]) + 
       (4444201559974855*CF*NC*NH*Pi^3)/(125524238436*Sqrt[3]) + 
       (1270907*CF^2*NC*Pi^4)/8640 - (1549458210418732070851*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(29523300880147200*Sqrt[3]) - 
       (137709851700285413*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1098337086315*Sqrt[3]) + (174691*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/12 + (181374534625754119*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(650866421520*Sqrt[3]) + 
       (507908749711412*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) + (181374534625754119*CF^2*NC*Pi*Log[3]^2)/
        (31241588232960*Sqrt[3]) + (126977187427853*CF*NC*NH*Pi*Log[3]^2)/
        (4649045868*Sqrt[3]) + 
       (CF*NC*(CA*(243369199918801495687 - 30096837535564800*lm) + 
          6*(19*CF*(-4269778308470379823 + 432012022041600*lm) + 
            1120*(84*(-1844953984422061 + 9694147320*lm)*NM + 
              808647840*(1270 + 1007*lm)*NL + (241995115169 + 814308374880*
                 lm)*NH)))*Log[x]^2)/555761606400 - 
       (CF*NC*(-8698231611295*CA + 17350756032718*CF + 
          20160*(1891993397*NM + 22154*NL))*Log[x]^3)/68040 - 
       (277165267930677835867*CF^2*NC*PolyGamma[2, 1])/4518872583696 - 
       (21693665522*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (281650865599397*CF*NC*NH*PolyGamma[2, 1])/31381059609 + 
       CA*CF*NC*(-311551541822759356052482031791552372243/
          3325338433024350466161005568000 - (29161*lm^2)/72 + 
         (867918614426798177*Pi^2)/23775897600 - (181374534625754119*Pi^3)/
          (48201307559424*Sqrt[3]) - (3843697*Pi^4)/51840 + 
         lm*(-58574096251/68584320 + (1331*Pi^2)/324) + 
         (1549458210418732070851*Im[PolyLog[2, (-1)^(1/3)]])/
          (59046601760294400*Sqrt[3]) - (174691*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          24 - (181374534625754119*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1301732843040*Sqrt[3]) - (181374534625754119*Pi*Log[3]^2)/
          (62483176465920*Sqrt[3]) + (277165267930677835867*PolyGamma[2, 1])/
          9037745167392 - (1612533223914848917567*Zeta[3])/632642161717440) + 
       (1608108186640864446871*CF^2*NC*Zeta[3])/316321080858720 - 
       (20688701368*CF*NM*NC*Zeta[3])/81 + (287870*CF*NC*NL*Zeta[3])/27 - 
       (2074320494873402*CF*NC*NH*Zeta[3])/31381059609 + 
       CF*Log[x]*((-119829762389971117764559*NM*NC)/168882058144800 + 
         (86979299*lm*NM*NC)/34020 + (1210*lm^2*NM*NC)/3 + 
         (10322103599*NC*NL)/595350 + (86979299*lm*NC*NL)/34020 + 
         (1210*lm^2*NC*NL)/3 + (330536839881678576904743773*NC*NH)/
          1278949610541061859400 + (86979299*lm*NC*NH)/34020 + 
         (1210*lm^2*NC*NH)/3 - (420441695*NM*NC*Pi^2)/3 + 
         (47938*NC*NL*Pi^2)/27 - (507908749711412*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CA*NC*(333543783166378455630811207972339/1809377133228618041088000 - 
           (1148871889*lm)/68040 - (6655*lm^2)/3 + (34779765693721*Pi^2)/
            1088640 + (181374534625754119*Im[PolyLog[2, (-1)^(1/3)]])/
            (3905198529120*Sqrt[3]) - 4840*Zeta[3]) + 
         CF*NC*(-9530958932961289208881347158009/25848244760408829158400 + 
           (89266199*lm)/3780 + 3630*lm^2 - (6956189693765*Pi^2)/108864 - 
           (181374534625754119*Im[PolyLog[2, (-1)^(1/3)]])/
            (1952599264560*Sqrt[3]) + 9680*Zeta[3])), 
      (9139005227877987930659263314867665655896447*CF^2*NC)/
        8772498581582315325922437381120000 + (16862002783*CF^2*lm*NC)/
        52690176 - (3013*CF^2*lm^2*NC)/16 + 
       (11787473611463848283398965437441623*CF*NM*NC)/
        24330050883340217503488000 + (18515705911*CF*lm*NM*NC)/474211584 - 
       (3013*CF*lm^2*NM*NC)/144 + (11584826465194049*CF*NC*NL)/
        3872727936000 + (18515705911*CF*lm*NC*NL)/474211584 - 
       (3013*CF*lm^2*NC*NL)/144 + (5833534110555020793739514184153834349*CF*
         NC*NH)/2443767462012216412221250413312000 + 
       (18515705911*CF*lm*NC*NH)/474211584 - (3013*CF*lm^2*NC*NH)/144 - 
       (851470288398681234391*CF^2*NC*Pi^2)/2157662707200 - 
       (133*CF^2*lm*NC*Pi^2)/72 - (1725962164172941*CF*NM*NC*Pi^2)/8981280 - 
       (133*CF*lm*NM*NC*Pi^2)/648 - (9534311*CF*NC*NL*Pi^2)/80190 - 
       (133*CF*lm*NC*NL*Pi^2)/648 - (133*CF*lm*NC*NH*Pi^2)/648 - 
       (317868433995424717*CF^2*NC*Pi^3)/(132553595788416*Sqrt[3]) - 
       (2253593256569795*CF*NC*NH*Pi^3)/(2259436291848*Sqrt[3]) - 
       (764791*CF^2*NC*Pi^4)/12960 - (30996829418187498469477*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1786159703248905600*Sqrt[3]) + 
       (1091350512352914701*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15816054042936*Sqrt[3]) - (13031*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 - (317868433995424717*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3579765318360*Sqrt[3]) - 
       (128776757518274*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (317868433995424717*CF^2*NC*Pi*Log[3]^2)/
        (171828735281280*Sqrt[3]) - (64388378759137*CF*NC*NH*Pi*Log[3]^2)/
        (83682825624*Sqrt[3]) - 
       (CF*NC*(-13*CA*(10578180358972939616927 + 73486626990638400*lm) + 
          2*(13*CF*(10578106121649012512449 + 60125422083249600*lm) + 
            4620*(15*(966309468220960921 + 1253215467504*lm)*NM + 
              384107724*(49119 + 48940*lm)*NL + (6777441342877 + 
                18798232012560*lm)*NH)))*Log[x]^2)/58077087868800 + 
       (CF*NC*(522925392775125*CA - 176*(5943302264894*CF + 
            3465*(820313827*NM - 2447*NL)))*Log[x]^3)/748440 - 
       (21421557223254223028507*CF^2*NC*PolyGamma[2, 1])/45188725836960 - 
       (715746209809*CF*NM*NC*PolyGamma[2, 1])/6480 - 
       (108220216492773823*CF*NC*NH*PolyGamma[2, 1])/16945772188860 - 
       (27107787874819997733187*CF^2*NC*Zeta[3])/108735371545185 + 
       (367088603531*CF*NM*NC*Zeta[3])/3240 - (174239*CF*NC*NL*Zeta[3])/
        54 - (323375351194595713*CF*NC*NH*Zeta[3])/8472886094430 + 
       CA*CF*NC*(-100529962375306385878273746916249783901283409/
          192994968794810937170293622384640000 + (33143*lm^2)/288 + 
         (851470821976950540319*Pi^2)/4315325414400 + 
         (317868433995424717*Pi^3)/(265107191576832*Sqrt[3]) + 
         (152107*Pi^4)/5184 + (lm*(-5887427479 + 97330464*Pi^2))/86220288 + 
         (30996829418187498469477*Im[PolyLog[2, (-1)^(1/3)]])/
          (3572319406497811200*Sqrt[3]) + (13031*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/4 + (317868433995424717*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (7159530636720*Sqrt[3]) + (317868433995424717*Pi*Log[3]^2)/
          (343657470562560*Sqrt[3]) + (21421557223254223028507*
           PolyGamma[2, 1])/90377451673920 + (21686849369309849241695*
           Zeta[3])/173976594472296) + CF*Log[x]*
        ((-48638483037732081988322779*NM*NC)/48773138392218240 - 
         (97182929*lm*NM*NC)/213840 - (715*lm^2*NM*NC)/6 - 
         (158177678599*NC*NL)/34927200 - (97182929*lm*NC*NL)/213840 - 
         (715*lm^2*NC*NL)/6 - (28575977808609369198109827749*NC*NH)/
          3499206134440345247318400 - (97182929*lm*NC*NH)/213840 - 
         (715*lm^2*NC*NH)/6 - (1503931693*NM*NC*Pi^2)/9 - 
         (14531*NC*NL*Pi^2)/27 + (128776757518274*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-18758087711688366429765028780331809/
            9869555763806101979616000 - (101430029*lm)/23760 - 
           (2145*lm^2)/2 - (69724717069505*Pi^2)/199584 + 
           (317868433995424717*Im[PolyLog[2, (-1)^(1/3)]])/
            (10739295955080*Sqrt[3]) - 2860*Zeta[3]) + 
         CA*NC*(37516453013648631980577725936094449/
            39478223055224407918464000 + (129615329*lm)/38880 + 
           (7865*lm^2)/12 + (348624644340229*Pi^2)/1995840 - 
           (317868433995424717*Im[PolyLog[2, (-1)^(1/3)]])/
            (21478591910160*Sqrt[3]) + 1430*Zeta[3])), 
      (19074568495182811150357669807539551637439687*CF^2*NC)/
        10339016185436300205551444056320000 + (551406871*CF^2*lm*NC)/640332 + 
       861*CF^2*lm^2*NC + (445750485795221915752724252670059*CF*NM*NC)/
        112639124459908414368000 + (459519229*CF*lm*NM*NC)/5762988 + 
       (287*CF*lm^2*NM*NC)/3 - (47917816751237*CF*NC*NL)/3227273280 + 
       (459519229*CF*lm*NC*NL)/5762988 + (287*CF*lm^2*NC*NL)/3 - 
       (60260527442592072290896643270421338717*CF*NC*NH)/
        146967647545882780494958053792000 + (459519229*CF*lm*NC*NH)/
        5762988 + (287*CF*lm^2*NC*NH)/3 - (192146046630852297391*CF^2*NC*
         Pi^2)/269707838400 - 8*CF^2*lm*NC*Pi^2 - 
       (91093874214439*CF*NM*NC*Pi^2)/62370 - (8*CF*lm*NM*NC*Pi^2)/9 + 
       (17553743*CF*NC*NL*Pi^2)/31185 - (8*CF*lm*NC*NL*Pi^2)/9 - 
       (8*CF*lm*NC*NH*Pi^2)/9 + (51589893465041399*CF^2*NC*Pi^3)/
        (4518872583696*Sqrt[3]) + (30953273880532955*CF*NC*NH*Pi^3)/
        (564859072962*Sqrt[3]) + (341501*CF^2*NC*Pi^4)/1620 - 
       (4880982614069426814601*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (60891808065303600*Sqrt[3]) - (1973746884436648094*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9885033776835*Sqrt[3]) + 
       (61468*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (51589893465041399*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (122037454035*Sqrt[3]) + (7075034029836104*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3486784401*Sqrt[3]) + 
       (51589893465041399*CF^2*NC*Pi*Log[3]^2)/(5857797793680*Sqrt[3]) + 
       (884379253729513*CF*NC*NH*Pi*Log[3]^2)/(20920706406*Sqrt[3]) + 
       CF*((-2386928096767455955831*CF*NC)/279216768600 + 
         CA*(30998898511182928901/7252383600 - 84216*lm)*NC + 
         137808*CF*lm*NC - (1530009756288469751*NM*NC)/87297210 + 
         15312*lm*NM*NC + (57640*NC*NL)/3 + 15312*lm*NC*NL + 
         (15396247273*NC*NH)/3202290 + 15312*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-117050412351571*CA + 233995081152956*CF + 
          5488560*(89096551*NM + 174*NL))*Log[x]^3)/93555 - 
       (2000928582942569536213*CF^2*NC*PolyGamma[2, 1])/3389154437772 - 
       (44422481149*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (23232210070612813*CF*NC*NH*PolyGamma[2, 1])/1694577218886 + 
       CA*CF*NC*(-16690031860592815275217145144733492384826523/
          18093278324513525359715027098560000 - (3157*lm^2)/6 + 
         (192145890396191888641*Pi^2)/539415676800 - (51589893465041399*Pi^3)/
          (9037745167392*Sqrt[3]) - (68761*Pi^4)/648 + 
         lm*(-1161206677/1047816 + (44*Pi^2)/9) + 
         (4880982614069426814601*Im[PolyLog[2, (-1)^(1/3)]])/
          (121783616130607200*Sqrt[3]) - (30734*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 - (51589893465041399*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (244074908070*Sqrt[3]) - (51589893465041399*Pi*Log[3]^2)/
          (11715595587360*Sqrt[3]) + (2000928582942569536213*PolyGamma[2, 1])/
          6778308875544 - (11457062466565740734543*Zeta[3])/
          326206114635555) + (22907182515529802401963*CF^2*NC*Zeta[3])/
        326206114635555 - (20901910177*CF*NM*NC*Zeta[3])/9 + 
       (49400*CF*NC*NL*Zeta[3])/3 - (86206599306767531*CF*NC*NH*Zeta[3])/
        847288609443 + CF*Log[x]*((-8523593323295826415809343*NM*NC)/
          1270133812297350 + (37881796*lm*NM*NC)/10395 + 572*lm^2*NM*NC + 
         (233921193281*NC*NL)/8731800 + (37881796*lm*NC*NL)/10395 + 
         572*lm^2*NC*NL + (2213276643836528787290160109*NC*NH)/
          5535526450714541375094 + (37881796*lm*NC*NH)/10395 + 
         572*lm^2*NC*NH - 1306749026*NM*NC*Pi^2 + (8228*NC*NL*Pi^2)/3 - 
         (7075034029836104*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (10460353203*Sqrt[3]) + CA*NC*(45987584709948238881526578222752773/
            25907583879991017696492000 - (22724678*lm)/945 - 3146*lm^2 + 
           (234086733306407*Pi^2)/748440 + (51589893465041399*
             Im[PolyLog[2, (-1)^(1/3)]])/(732224724210*Sqrt[3]) - 
           6864*Zeta[3]) + CF*NC*(-9197685602854024868269534639593851/
            2590758387999101769649200 + (38872786*lm)/1155 + 5148*lm^2 - 
           (46817596893325*Pi^2)/74844 - (51589893465041399*
             Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) + 
           13728*Zeta[3])), (1446470449072548897956465057207548815530614349*
         CF^2*NC)/144746226596108202877720216788480000 + 
       (755738431673*CF^2*lm*NC)/1844156160 - (3875*CF^2*lm^2*NC)/16 + 
       (48535026683624368661040944435614469*CF*NM*NC)/
        10018256246081266030848000 + (830177026673*CF*lm*NM*NC)/
        16597405440 - (3875*CF*lm^2*NM*NC)/144 + 
       (242116819883689489*CF*NC*NL)/52281827136000 + 
       (830177026673*CF*lm*NC*NL)/16597405440 - (3875*CF*lm^2*NC*NL)/144 + 
       (11334376418176289391107976263746994697971*CF*NC*NH)/
        5946663742060527417499190755753420800 + (830177026673*CF*lm*NC*NH)/
        16597405440 - (3875*CF*lm^2*NC*NH)/144 - 
       (4072010602736564647693*CF^2*NC*Pi^2)/1078831353600 - 
       (157*CF^2*lm*NC*Pi^2)/72 - (17053176137629781*CF*NM*NC*Pi^2)/
        8981280 - (157*CF*lm*NM*NC*Pi^2)/648 - (745751563*CF*NC*NL*Pi^2)/
        4490640 - (157*CF*lm*NC*NL*Pi^2)/648 - (157*CF*lm*NC*NH*Pi^2)/648 - 
       (686080412285781143*CF^2*NC*Pi^3)/(198830393682624*Sqrt[3]) - 
       (691034001996835*CF*NC*NH*Pi^3)/(502096953744*Sqrt[3]) - 
       (544333*CF^2*NC*Pi^4)/6480 - (32868847117328048898649*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1339619777436679200*Sqrt[3]) + 
       (7863211836636984617*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (79080270214680*Sqrt[3]) - (27079*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (686080412285781143*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5369647977540*Sqrt[3]) - 
       (19743828628481*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) - (686080412285781143*CF^2*NC*Pi*Log[3]^2)/
        (257743102921920*Sqrt[3]) - (19743828628481*CF*NC*NH*Pi*Log[3]^2)/
        (18596183472*Sqrt[3]) - 
       (CF*NC*(-6279*CA*(2408910949675410358411 + 2679341458978800*lm) + 
          20*(299*CF*(5058707292464579674693 + 4603595779518120*lm) + 
            693*(391*(2808090041363906491 + 564437513640*lm)*NM + 
              490804314*(446249 + 449660*lm)*NL + (84172949611511 + 
                220695067833240*lm)*NH)))*Log[x]^2)/667886510491200 + 
       (CF*NC*(5004576887399011*CA - 168*(59579975700888*CF + 
            605*(48842131690*NM - 22483*NL)))*Log[x]^3)/748440 - 
       (120350651241641725186099*CF^2*NC*PolyGamma[2, 1])/27113235502176 - 
       (898282724119*CF*NM*NC*PolyGamma[2, 1])/810 - 
       (5735303267051302121*CF*NC*NH*PolyGamma[2, 1])/610047798798960 - 
       (11434403688536310597502573*CF^2*NC*Zeta[3])/5219297834168880 + 
       (444879475706*CF*NM*NC*Zeta[3])/405 - (132587*CF*NC*NL*Zeta[3])/27 - 
       (16696209057248411201*CF*NC*NH*Zeta[3])/305023899399480 + 
       CA*CF*NC*(-2892944850354013994077455539317033908982572193/
          578984906384432811510880867153920000 + (42625*lm^2)/288 + 
         (4072010973832701694867*Pi^2)/2157662707200 + 
         (686080412285781143*Pi^3)/(397660787365248*Sqrt[3]) + 
         (180607*Pi^4)/4320 + lm*(-261736846673/3017710080 + 
           (1727*Pi^2)/1296) + (32868847117328048898649*
           Im[PolyLog[2, (-1)^(1/3)]])/(2679239554873358400*Sqrt[3]) + 
         (27079*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 + 
         (686080412285781143*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (10739295955080*Sqrt[3]) + (686080412285781143*Pi*Log[3]^2)/
          (515486205843840*Sqrt[3]) + (120350651241641725186099*
           PolyGamma[2, 1])/54226471004352 + (11434459449919585408487113*
           Zeta[3])/10438595668337760) + CF*Log[x]*
        ((-41655465747792349879894711*NM*NC)/4303512211078080 - 
         (957759377*lm*NM*NC)/1496880 - (1001*lm^2*NM*NC)/6 - 
         (26295063092581*NC*NL)/3772137600 - (957759377*lm*NC*NL)/1496880 - 
         (1001*lm^2*NC*NL)/6 - (72854419735262603230647306271*NC*NH)/
          6427361267774106374414700 - (957759377*lm*NC*NH)/1496880 - 
         (1001*lm^2*NC*NH)/6 - (537264708871*NM*NC*Pi^2)/324 - 
         (265331*NC*NL*Pi^2)/324 + (19743828628481*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CF*NC*(-7510634466438097593743960272432202957/
            414521342079856283143872000 - (999380957*lm)/166320 - 
           (3003*lm^2)/2 - (2502296207108393*Pi^2)/748440 + 
           (686080412285781143*Im[PolyLog[2, (-1)^(1/3)]])/
            (16108943932620*Sqrt[3]) - 4004*Zeta[3]) + 
         CA*NC*(150212862507011658118952943503212321/
            16580853683194251325754880 + (1275596897*lm)/272160 + 
           (11011*lm^2)/12 + (2502297419206973*Pi^2)/1496880 - 
           (686080412285781143*Im[PolyLog[2, (-1)^(1/3)]])/
            (32217887865240*Sqrt[3]) + 2002*Zeta[3])), 
      (222007205440171811685027740890666558690364743117*CF^2*NC)/
        12316588008541570717595102083092480000 + (503826932117*CF^2*lm*NC)/
        461039040 + (4381*CF^2*lm^2*NC)/4 + 
       (92833523471890415990246260518049457*CF*NM*NC)/
        2504564061520316507712000 + (419668097357*CF*lm*NM*NC)/4149351360 + 
       (4381*CF*lm^2*NM*NC)/36 - (6512217660598867673*CF*NC*NL)/
        287550049248000 + (419668097357*CF*lm*NC*NL)/4149351360 + 
       (4381*CF*lm^2*NC*NL)/36 - 
       (40527516117912232359950613955168976791501121*CF*NC*NH)/
        66369014978354100641732039684748000000 + (419668097357*CF*lm*NC*NH)/
        4149351360 + (4381*CF*lm^2*NC*NH)/36 - 
       (506888704608304930583473*CF^2*NC*Pi^2)/73360532044800 - 
       (169*CF^2*lm*NC*Pi^2)/18 - (15380383339316203*CF*NM*NC*Pi^2)/
        1122660 - (169*CF*lm*NM*NC*Pi^2)/162 + (1744019251*CF*NC*NL*Pi^2)/
        2245320 - (169*CF*lm*NC*NL*Pi^2)/162 - (169*CF*lm*NC*NH*Pi^2)/162 + 
       (119827376563101037049*CF^2*NC*Pi^3)/(7157894172574464*Sqrt[3]) + 
       (46307266793310775*CF*NC*NH*Pi^3)/(564859072962*Sqrt[3]) + 
       (7600489*CF^2*NC*Pi^4)/25920 - (11436699102649404580053181*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(96452623975440902400*Sqrt[3]) - 
       (33336969544492769737*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (108735371545185*Sqrt[3]) + (112281*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + (119827376563101037049*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(193307327191440*Sqrt[3]) + 
       (10584518124185320*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) + (119827376563101037049*CF^2*NC*Pi*Log[3]^2)/
        (9278751705189120*Sqrt[3]) + (1323064765523165*CF*NC*NH*Pi*Log[3]^2)/
        (20920706406*Sqrt[3]) + CF*((-4815406282675458606907097*CF*NC)/
          58077087868800 + CA*(4815402210973855865739169/116154175737600 - 
           (3411551*lm)/27)*NC + (620282*CF*lm*NC)/3 - 
         (562807934947233113*NM*NC)/3423420 + (620282*lm*NM*NC)/27 + 
         (775021*NC*NL)/27 + (620282*lm*NC*NL)/27 + (10840816056853*NC*NH)/
          1434168450 + (620282*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-9105781484609805*CA + 22*(827736253080991*CF + 
            1680*(991462257605*NM + 310141*NL)))*Log[x]^3)/748440 - 
       (2071134913690349066068301*CF^2*NC*PolyGamma[2, 1])/366028679279376 - 
       (1841005282306*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (154468655484725197*CF*NC*NH*PolyGamma[2, 1])/7625597484987 + 
       CA*CF*NC*(-2442074537994202060222729091049324626363590613771/
          270964936187914555787092245828034560000 - (48191*lm^2)/72 + 
         (2293613776947385712093*Pi^2)/663896217600 - 
         (119827376563101037049*Pi^3)/(14315788345148928*Sqrt[3]) - 
         (7643753*Pi^4)/51840 + lm*(-1062335562797/754427520 + 
           (1859*Pi^2)/324) + (11436699102649404580053181*
           Im[PolyLog[2, (-1)^(1/3)]])/(192905247950881804800*Sqrt[3]) - 
         (112281*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 - 
         (119827376563101037049*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (386614654382880*Sqrt[3]) - (119827376563101037049*Pi*Log[3]^2)/
          (18557503410378240*Sqrt[3]) + (2071134913690349066068301*
           PolyGamma[2, 1])/732057358558752 - (34199065601686382525251273*
           Zeta[3])/80526309441462720) + (34197802446535958959338529*CF^2*NC*
         Zeta[3])/40263154720731360 - (1699098494822*CF*NM*NC*Zeta[3])/81 + 
       (663208*CF*NC*NL*Zeta[3])/27 - (1153449690530220502*CF*NC*NH*
         Zeta[3])/7625597484987 + CF*Log[x]*
        ((-680731951786768752662687179*NM*NC)/10758780527695200 + 
         (1888343431*lm*NM*NC)/374220 + (2366*lm^2*NM*NC)/3 + 
         (414712726464613*NC*NL)/10373378400 + (1888343431*lm*NC*NL)/
          374220 + (2366*lm^2*NC*NL)/3 + (17646486440972114610905447685569*
           NC*NH)/29513393576513753760067500 + (1888343431*lm*NC*NH)/
          374220 + (2366*lm^2*NC*NH)/3 - (991462239652*NM*NC*Pi^2)/81 + 
         (331435*NC*NL*Pi^2)/81 - (10584518124185320*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CA*NC*(1650857068948913256314529257768954802709/
            96997994046686370255666048000 - (2263969591*lm)/68040 - 
           (13013*lm^2)/3 + (64237720076719*Pi^2)/21120 + 
           (119827376563101037049*Im[PolyLog[2, (-1)^(1/3)]])/
            (1159843963148640*Sqrt[3]) - 9464*Zeta[3]) + 
         CF*NC*(-330172320814289723197359452826893737823/
            9699799404668637025566604800 + (1937532571*lm)/41580 + 
           7098*lm^2 - (346883971948417*Pi^2)/57024 - 
           (119827376563101037049*Im[PolyLog[2, (-1)^(1/3)]])/
            (579921981574320*Sqrt[3]) + 18928*Zeta[3])), 
      (410096756917779685292832112139909558264116872378154039*CF^2*NC)/
        4285879492177863320340016761486605438976000 + 
       (53496502729457*CF^2*lm*NC)/103887463680 - (4887*CF^2*lm^2*NC)/16 + 
       (2547432065065533533192591557105374242447*CF*NM*NC)/
        53132464197005204732168448000 + (58785023927417*CF*lm*NM*NC)/
        934987173120 - (543*CF*lm^2*NM*NC)/16 + 
       (17257898137693368833*CF*NC*NL)/2492100426816000 + 
       (58785023927417*CF*lm*NC*NL)/934987173120 - (543*CF*lm^2*NC*NL)/16 + 
       (110177683579191125902907607580881150238391*CF*NC*NH)/
        178876917374815330071833946530016000000 + 
       (58785023927417*CF*lm*NC*NH)/934987173120 - (543*CF*lm^2*NC*NH)/16 - 
       (3817684543183608925001063*CF^2*NC*Pi^2)/105965212953600 - 
       (61*CF^2*lm*NC*Pi^2)/24 - (724173288809350673*CF*NM*NC*Pi^2)/
        38918880 - (61*CF*lm*NM*NC*Pi^2)/216 - (4398556531*CF*NC*NL*Pi^2)/
        19459440 - (61*CF*lm*NC*NL*Pi^2)/216 - (61*CF*lm*NC*NH*Pi^2)/216 - 
       (448406618202958547489*CF^2*NC*Pi^3)/(93052624243468032*Sqrt[3]) - 
       (74795158231164665*CF*NC*NH*Pi^3)/(40669853253264*Sqrt[3]) - 
       (111511*CF^2*NC*Pi^4)/960 - (78817927892411840531252621*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2328641921692787500800*Sqrt[3]) + 
       (1092600607774665767209*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (7828946751253320*Sqrt[3]) - 
       (48797*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (64058088314708363927*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (358999321926960*Sqrt[3]) - (2137004520890419*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (64058088314708363927*CF^2*NC*Pi*Log[3]^2)/(17231967452494080*
         Sqrt[3]) - (2137004520890419*CF*NC*NH*Pi*Log[3]^2)/
        (1506290861232*Sqrt[3]) - 
       (CF*NC*(-(CA*(2502493972861498845698088331 + 431755259443573665600*
              lm)) + 6*(CF*(834164511409132788210054941 + 
              117751434393701908800*lm) + 24024*(15*(1195529660781362468487 + 
                36306728578120*lm)*NM + 17*(170600430*(184571 + 187780*lm)*
                 NL + (12818543752967 + 32035348745400*lm)*NH))))*Log[x]^2)/
        11576699515180800 + (CF*NC*(103592919338419090*CA - 
          39*(5312482350007163*CF + 1540*(1761262268042*NM - 122057*NL)))*
         Log[x]^3)/1621620 - (151904813693132560841066863*CF^2*NC*
         PolyGamma[2, 1])/3660286792793760 - 
       (495682766024*CF*NM*NC*PolyGamma[2, 1])/45 - 
       (24637496224835938691*CF*NC*NH*PolyGamma[2, 1])/1830143396396880 - 
       (14010194362782394376893906973*CF^2*NC*Zeta[3])/732789415917310752 + 
       (476353561067*CF*NM*NC*Zeta[3])/45 - (65093*CF*NC*NL*Zeta[3])/9 - 
       (70085413296015282011*CF*NC*NH*Zeta[3])/915071698198440 + 
       CA*CF*NC*(-2050484200678525456192834453221695036348789636372754281/
          42858794921778633203400167614866054389760000 + (5973*lm^2)/32 + 
         (224569681919293728880091*Pi^2)/12466495641600 + 
         (448406618202958547489*Pi^3)/(186105248486936064*Sqrt[3]) + 
         (199939*Pi^4)/3456 + lm*(-18399952961177/169997667840 + 
           (671*Pi^2)/432) + (78817927892411840531252621*
           Im[PolyLog[2, (-1)^(1/3)]])/(4657283843385575001600*Sqrt[3]) + 
         (48797*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (64058088314708363927*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (717998643853920*Sqrt[3]) + (64058088314708363927*Pi*Log[3]^2)/
          (34463934904988160*Sqrt[3]) + (151904813693132560841066863*
           PolyGamma[2, 1])/7320573585587520 + (70051028844184607680628706337*
           Zeta[3])/7327894159173107520) + CF*Log[x]*
        ((-6028002053257737080747029254799*NM*NC)/64502475523708622400 - 
         (5686836893*lm*NM*NC)/6486480 - (455*lm^2*NM*NC)/2 - 
         (143408620127219*NC*NL)/13831171200 - (5686836893*lm*NC*NL)/
          6486480 - (455*lm^2*NC*NL)/2 - (93354051548848956873769027597973*
           NC*NH)/6124897208114148427383420000 - (5686836893*lm*NC*NH)/
          6486480 - (455*lm^2*NC*NH)/2 - (1761262886335*NM*NC*Pi^2)/108 - 
         (130247*NC*NL*Pi^2)/108 + (2137004520890419*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(-28714619853559514003738951520660821290066057/
            166763801264765542062053853024000 - (5932782593*lm)/720720 - 
           (4095*lm^2)/2 - (828743758194594353*Pi^2)/25945920 + 
           (64058088314708363927*Im[PolyLog[2, (-1)^(1/3)]])/
            (1076997965780880*Sqrt[3]) - 5460*Zeta[3]) + 
         CA*NC*(7178656219656985114526478071921346593810047/
            83381900632382771031026926512000 + (7564967693*lm)/1179360 + 
           (5005*lm^2)/4 + (828743820218532329*Pi^2)/51891840 - 
           (64058088314708363927*Im[PolyLog[2, (-1)^(1/3)]])/
            (2153995931561760*Sqrt[3]) + 2730*Zeta[3])), 
      (1205428200822613194008990832350646043354031124792612091*CF^2*NC)/
        6888020612428708907689312652389187312640000 + 
       (541579849913*CF^2*lm*NC)/397528560 + (2737*CF^2*lm^2*NC)/2 + 
       (45071659625230972645122414533360438207333*CF*NM*NC)/
        129510381480200186534660592000 + (450910210853*CF*lm*NM*NC)/
        3577757040 + (2737*CF*lm^2*NM*NC)/18 - 
       (232073523164941000349*CF*NC*NL)/6942279760416000 + 
       (450910210853*CF*lm*NC*NL)/3577757040 + (2737*CF*lm^2*NC*NL)/18 - 
       (11085688416032976056660358481185772851337523533*CF*NC*NH)/
        12543743830908925021287355500417372000000 + 
       (450910210853*CF*lm*NC*NH)/3577757040 + (2737*CF*lm^2*NC*NH)/18 - 
       (81094037897591305515713*CF^2*NC*Pi^2)/1216437393600 - 
       (98*CF^2*lm*NC*Pi^2)/9 - (187778322407020777*CF*NM*NC*Pi^2)/1459458 - 
       (98*CF*lm*NM*NC*Pi^2)/81 + (2181476423*CF*NC*NL*Pi^2)/2084940 - 
       (98*CF*lm*NC*NL*Pi^2)/81 - (98*CF*lm*NC*NH*Pi^2)/81 + 
       (312096334704527273327*CF^2*NC*Pi^3)/(13085525284237692*Sqrt[3]) + 
       (3633822642826497695*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) + 
       (1288609*CF^2*NC*Pi^4)/3240 - (446964565732643728204174331*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2619722161904385938400*Sqrt[3]) - 
       (1339593985743853015256*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2935855031719995*Sqrt[3]) + 
       (112742*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (178340762688301299044*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (201937118583915*Sqrt[3]) + (415294016323028308*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) + 
       (44585190672075324761*CF^2*NC*Pi*Log[3]^2)/(2423245423006980*
         Sqrt[3]) + (103823504080757077*CF*NC*NH*Pi*Log[3]^2)/
        (1129718145924*Sqrt[3]) + 
       (CF*NC*(-6*CA*(-20672195652988297046568473 + 9503612768666016000*lm) + 
          CF*(-248066379765184847922158797 + 93308198092357248000*lm) + 
          10296*(5*(-9300033971740754820839 + 201390395606400*lm)*NM + 
            2*(507536279250*(1235 + 992*lm)*NL + (172467634979203 + 
                503475989016000*lm)*NH)))*Log[x]^2)/310090165585200 - 
       (CF*NC*(-40882670063536339*CA + 81764352519417426*CF + 
          34320*(4653059828593*NM + 225680*NL))*Log[x]^3)/347490 - 
       (88992045606409432273502051*CF^2*NC*PolyGamma[2, 1])/
        1647129056757192 - (16946054802325*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (1331053506164259683*CF*NC*NH*PolyGamma[2, 1])/45753584909922 + 
       CA*CF*NC*(-2410855716584824968718278937567855149920788004136148871/
          27552082449714835630757250609556749250560000 - (30107*lm^2)/36 + 
         (2270633023034596363916159*Pi^2)/68120494041600 - 
         (312096334704527273327*Pi^3)/(26171050568475384*Sqrt[3]) - 
         (431627*Pi^4)/2160 + lm*(-1143296545493/650501280 + (539*Pi^2)/81) + 
         (446964565732643728204174331*Im[PolyLog[2, (-1)^(1/3)]])/
          (5239444323808771876800*Sqrt[3]) - 
         (56371*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (89170381344150649522*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (201937118583915*Sqrt[3]) - (44585190672075324761*Pi*Log[3]^2)/
          (4846490846013960*Sqrt[3]) + (88992045606409432273502051*
           PolyGamma[2, 1])/3294258113514384 - (706172962533023687050387739*
           Zeta[3])/147212159447674035) + (5649357199902201257452991899*CF^2*
         NC*Zeta[3])/588848637790696140 - (15279888449972*CF*NM*NC*Zeta[3])/
        81 + (960442*CF*NC*NL*Zeta[3])/27 - (4994917353469916641*CF*NC*NH*
         Zeta[3])/22876792454961 + CF*Log[x]*
        ((-2304060373151812587949383788135*NM*NC)/3870148531422517344 + 
         (2369043803*lm*NM*NC)/347490 + (3185*lm^2*NM*NC)/3 + 
         (1115789504825899*NC*NL)/19264845600 + (2369043803*lm*NC*NL)/
          347490 + (3185*lm^2*NC*NL)/3 + 
         (271306031649167613593985062039268247*NC*NH)/
          312369757613821569796554420000 + (2369043803*lm*NC*NH)/347490 + 
         (3185*lm^2*NC*NH)/3 - (9306119668561*NM*NC*Pi^2)/81 + 
         (480025*NC*NL*Pi^2)/81 - (415294016323028308*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CA*NC*(218895292710930200745909724338801988402681/
            1346377404245696235531271296000 - (2838576503*lm)/63180 - 
           (35035*lm^2)/6 + (81765225614218529*Pi^2)/2779920 + 
           (89170381344150649522*Im[PolyLog[2, (-1)^(1/3)]])/
            (605811355751745*Sqrt[3]) - 12740*Zeta[3]) + 
         CF*NC*(-6338016253940698775617953035965012442716711/
            19491872875102465955304995808000 + (1215265114*lm)/19305 + 
           9555*lm^2 - (10220654449746199*Pi^2)/173745 - 
           (178340762688301299044*Im[PolyLog[2, (-1)^(1/3)]])/
            (605811355751745*Sqrt[3]) + 25480*Zeta[3])), 
      (169522806578264189228403212034289482927157087270236173749*CF^2*NC)/
        185446708796157547514712263718170427648000000 + 
       (198424791093887*CF^2*lm*NC)/311662391040 - (6061*CF^2*lm^2*NC)/16 + 
       (6414064739290158218707491918429711751082497*CF*NM*NC)/
        13632671734757914372069536000000 + (218101726011527*CF*lm*NM*NC)/
        2804961519360 - (6061*CF*lm^2*NM*NC)/144 + 
       (5551542687843974077*CF*NC*NL)/552226799124000 + 
       (218101726011527*CF*lm*NC*NL)/2804961519360 - (6061*CF*lm^2*NC*NL)/
        144 - (1680333960449625872744250525437795701782628139*CF*NC*NH)/
        903149555825442601532689596030050784000000 + 
       (218101726011527*CF*lm*NC*NH)/2804961519360 - (6061*CF*lm^2*NC*NH)/
        144 - (327212056313092737432871153*CF^2*NC*Pi^2)/953686916582400 - 
       (211*CF^2*lm*NC*Pi^2)/72 - (21145261182784211939*CF*NM*NC*Pi^2)/
        116756640 - (211*CF*lm*NM*NC*Pi^2)/648 - (3513569627*CF*NC*NL*Pi^2)/
        11675664 - (211*CF*lm*NC*NL*Pi^2)/648 - (211*CF*lm*NC*NH*Pi^2)/
        648 - (5494090716350689037525*CF^2*NC*Pi^3)/(837473618191212288*
         Sqrt[3]) - (2623430469347657935*CF*NC*NH*Pi^3)/
        (1098086037838128*Sqrt[3]) - (4062341*CF^2*NC*Pi^4)/25920 - 
       (268269382680699013397250875*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5868177642665824502016*Sqrt[3]) + (40469780579745197606027*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(211381562283839640*Sqrt[3]) - 
       (64565*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (1098818143270137807505*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4523391456279696*Sqrt[3]) - (74955156267075941*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (1098818143270137807505*CF^2*NC*Pi*Log[3]^2)/(217122789901425408*
         Sqrt[3]) - (74955156267075941*CF*NC*NH*Pi*Log[3]^2)/
        (40669853253264*Sqrt[3]) - 
       (CF*NC*(-7*CA*(10213691695424902965985881851 + 266208456376488225600*
             lm) + 2*(CF*(71495839970914045755417427297 + 
              1524648431974432564800*lm) + 72072*
             (57*(9186441275873996466457 + 41236877481800*lm)*NM + 
              20301451170*(112859 + 115780*lm)*NL + (980303548493683 + 
                2350502016462600*lm)*NH)))*Log[x]^2)/34730098545542400 - 
       (CF*NC*(-2962626816009888939*CA + 7*(846465446285793119*CF + 
            8580*(51580395324842*NM - 526799*NL)))*Log[x]^3)/4864860 - 
       (2552852912916038651717227453*CF^2*NC*PolyGamma[2, 1])/
        6588516227028768 - (702724193417339*CF*NM*NC*PolyGamma[2, 1])/6480 - 
       (464971463978798341661*CF*NC*NH*PolyGamma[2, 1])/24706935851357880 - 
       (5472446887479519778228254366149*CF^2*NC*Zeta[3])/
        32975523716278983840 + (328883763806461*CF*NM*NC*Zeta[3])/3240 - 
       (279674*CF*NC*NL*Zeta[3])/27 - (1295748434970644746001*CF*NC*NH*
         Zeta[3])/12353467925678940 + CA*CF*NC*
        (-550949137679999154726581650791095739129516131355402838603/
          1205403607175024058845629714168107779712000000 + (66671*lm^2)/288 + 
         (327212056903870039579939189*Pi^2)/1907373833164800 + 
         (5494090716350689037525*Pi^3)/(1674947236382424576*Sqrt[3]) + 
         (4048837*Pi^4)/51840 + lm*(-67841495731367/509993003520 + 
           (2321*Pi^2)/1296) + (268269382680699013397250875*
           Im[PolyLog[2, (-1)^(1/3)]])/(11736355285331649004032*Sqrt[3]) + 
         (64565*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (1098818143270137807505*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9046782912559392*Sqrt[3]) + (1098818143270137807505*Pi*Log[3]^2)/
          (434245579802850816*Sqrt[3]) + (2552852912916038651717227453*
           PolyGamma[2, 1])/13177032454057536 + 
         (1094489523231426430251531236977*Zeta[3])/13190209486511593536) + 
       CF*Log[x]*((-114337938281218751318506781781743*NM*NC)/
          127307517481003860000 - (22842708563*lm*NM*NC)/19459440 - 
         (910*lm^2*NM*NC)/3 - (146899680041993*NC*NL)/9807557760 - 
         (22842708563*lm*NC*NL)/19459440 - (910*lm^2*NC*NL)/3 - 
         (112088518080006531604582546499916781*NC*NH)/
          5622655637048788256337979560000 - (22842708563*lm*NC*NH)/
          19459440 - (910*lm^2*NC*NH)/3 - (51580397978857*NM*NC*Pi^2)/324 - 
         (559559*NC*NL*Pi^2)/324 + (74955156267075941*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(-48986852359343757602155430559469720345998389189/
            30017484227657797571169693544320000 - (23826491363*lm)/2162160 - 
           2730*lm^2 - (7900338762558823793*Pi^2)/25945920 + 
           (1098818143270137807505*Im[PolyLog[2, (-1)^(1/3)]])/
            (13570174368839088*Sqrt[3]) - 7280*Zeta[3]) + 
         CA*NC*(48986853631708108771323307880436202563950364449/
            60034968455315595142339387088640000 + (30355231763*lm)/3538080 + 
           (5005*lm^2)/3 + (1580067770309270885*Pi^2)/10378368 - 
           (1098818143270137807505*Im[PolyLog[2, (-1)^(1/3)]])/
            (27140348737678176*Sqrt[3]) + 3640*Zeta[3])), 
      (24446105205105158705536816835055515901129405496460274865537*CF^2*NC)/
        14464843286100288706147556570017293356544000000 + 
       (2896109606185*CF^2*lm*NC)/1731457728 + (6735*CF^2*lm^2*NC)/4 + 
       (82283114791373112257523810175535401679419*CF*NM*NC)/
        25157416759945646180004000000 + (2410219281265*CF*lm*NM*NC)/
        15583119552 + (2245*CF*lm^2*NM*NC)/12 - 
       (3367719532123393864141*CF*NC*NL)/70194162021984000 + 
       (2410219281265*CF*lm*NC*NL)/15583119552 + (2245*CF*lm^2*NC*NL)/12 - 
       (6870993957901137520474597393781679458709252967556699*CF*NC*NH)/
        5506728629256679902195191639394227142744000000 + 
       (2410219281265*CF*lm*NC*NH)/15583119552 + (2245*CF*lm^2*NC*NH)/12 - 
       (464096722494532262786522275*CF^2*NC*Pi^2)/724802056602624 - 
       (25*CF^2*lm*NC*Pi^2)/2 - (35634631451205019*CF*NM*NC*Pi^2)/29484 - 
       (25*CF*lm*NM*NC*Pi^2)/18 + (895461755*CF*NC*NL*Pi^2)/648648 - 
       (25*CF*lm*NC*NL*Pi^2)/18 - (25*CF*lm*NC*NH*Pi^2)/18 + 
       (83286028461431655480575*CF^2*NC*Pi^3)/(2512420854573636864*Sqrt[3]) + 
       (46345460346446912455*CF*NC*NH*Pi^3)/(274521509459532*Sqrt[3]) + 
       (2736605*CF^2*NC*Pi^4)/5184 - (4218945583012280543670294535*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(17604532927997473506048*Sqrt[3]) - 
       (227042243514222115316353*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (343495038711239415*Sqrt[3]) + 
       (591875*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
       (16657205692286331096115*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13570174368839088*Sqrt[3]) + 
       (5296624039593932852*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (847288609443*Sqrt[3]) + (16657205692286331096115*CF^2*NC*Pi*
         Log[3]^2)/(651368369704276224*Sqrt[3]) + 
       (1324156009898483213*CF*NC*NH*Pi*Log[3]^2)/(10167463313316*Sqrt[3]) + 
       CF*((-133427785371732404835121018867*CF*NC)/17365049272771200 + 
         CA*(133427782816412826045771321667/34730098545542400 - 
           (782089*lm)/3)*NC + 426594*CF*lm*NC - 
         (2206080627988886132858*NM*NC)/152108775 + (142198*lm*NM*NC)/3 + 
         (529445*NC*NL)/9 + (142198*lm*NC*NL)/3 + (890157457881649*NC*NH)/
          52933853700 + (142198*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-2203312133308318565*CA + 4406615909565569242*CF + 
          864864*(9712142070971*NM + 71099*NL))*Log[x]^3)/1945944 - 
       (1693852291449668078975618887*CF^2*NC*PolyGamma[2, 1])/
        3294258113514384 - (34646108505847*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (50362796966810804263*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 + 
       CA*CF*NC*(-24446104201011505659305299846889651063043110988571579545787/
          28929686572200577412295113140034586713088000000 - (24695*lm^2)/24 + 
         (24426143232123363057420325*Pi^2)/76294953326592 - 
         (83286028461431655480575*Pi^3)/(5024841709147273728*Sqrt[3]) - 
         (2748125*Pi^4)/10368 + lm*(-6120654489745/2833294464 + 
           (275*Pi^2)/36) + (4218945583012280543670294535*
           Im[PolyLog[2, (-1)^(1/3)]])/(35209065855994947012096*Sqrt[3]) - 
         (591875*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 - 
         (16657205692286331096115*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27140348737678176*Sqrt[3]) - (16657205692286331096115*Pi*Log[3]^2)/
          (1302736739408552448*Sqrt[3]) + (1693852291449668078975618887*
           PolyGamma[2, 1])/6588516227028768 - 
         (685178214432531784122674368543*Zeta[3])/13190209486511593536) + 
       (685177798659541823295230655775*CF^2*NC*Zeta[3])/6595104743255796768 - 
       (15221827230199*CF*NM*NC*Zeta[3])/9 + 50216*CF*NC*NL*Zeta[3] - 
       (189795482546124277637*CF*NC*NH*Zeta[3])/617673396283947 + 
       CF*Log[x]*((-1503061437812924872579227999744359*NM*NC)/
          268760314682119260000 + (974981195*lm*NM*NC)/108108 + 
         1400*lm^2*NM*NC + (15932101421375837*NC*NL)/194788994400 + 
         (974981195*lm*NC*NL)/108108 + 1400*lm^2*NC*NL + 
         (1454488944255704866632683325038624795551*NC*NH)/
          1182163347689507730895060202490000 + (974981195*lm*NC*NH)/108108 + 
         1400*lm^2*NC*NH - (9712142077999*NM*NC*Pi^2)/9 + 
         (75299*NC*NL*Pi^2)/9 - (5296624039593932852*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CA*NC*(10722835644896561174320171623663903943585961327/
            6927111744844107131808390817920000 - (1167609995*lm)/19656 - 
           7700*lm^2 + (8813246713755491753*Pi^2)/31135104 + 
           (16657205692286331096115*Im[PolyLog[2, (-1)^(1/3)]])/
            (81421046213034528*Sqrt[3]) - 16800*Zeta[3]) + 
         CF*NC*(-4978459694708885324391426622581774954575240567/
            1608079512195953441312662154160000 + (1000206395*lm)/12012 + 
           12600*lm^2 - (8813246871282565457*Pi^2)/15567552 - 
           (16657205692286331096115*Im[PolyLog[2, (-1)^(1/3)]])/
            (40710523106517264*Sqrt[3]) + 33600*Zeta[3])), 
      (27395072755515365932417973705934297909588498533832984948679*CF^2*NC)/
        3144531149152236675249468819568976816640000000 + 
       (1209512524176601*CF^2*lm*NC)/1558311955200 - (7409*CF^2*lm^2*NC)/16 + 
       (32063208367479385679954757197746076899366143503*CF*NM*NC)/
        6993560599930810072871671968000000 + (1329778495802401*CF*lm*NM*NC)/
        14024807596800 - (7409*CF*lm^2*NM*NC)/144 + 
       (1123296695277765214249*CF*NC*NL)/78968432274732000 + 
       (1329778495802401*CF*lm*NC*NL)/14024807596800 - 
       (7409*CF*lm^2*NC*NL)/144 - 
       (1187815667427948290958142698977316240689482716286213*CF*NC*NH)/
        198242230653240476479026899018192177138784000000 + 
       (1329778495802401*CF*lm*NC*NH)/14024807596800 - 
       (7409*CF*lm^2*NC*NH)/144 - (29534076500425049475908897251*CF^2*NC*
         Pi^2)/9060025707532800 - (241*CF^2*lm*NC*Pi^2)/72 - 
       (1948763052039144145*CF*NM*NC*Pi^2)/1111968 - (241*CF*lm*NM*NC*Pi^2)/
        648 - (22945025377*CF*NC*NL*Pi^2)/58378320 - (241*CF*lm*NC*NL*Pi^2)/
        648 - (241*CF*lm*NC*NH*Pi^2)/648 - (5487663996903095962255*CF^2*NC*
         Pi^3)/(628105213643409216*Sqrt[3]) - 
       (29907202745081351725*CF*NC*NH*Pi^3)/(9882774340543152*Sqrt[3]) - 
       (134173*CF^2*NC*Pi^4)/648 - (952922806361442087620547367*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15718332971426315630400*Sqrt[3]) + 
       (578822360482256738414743*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2248331162473567080*Sqrt[3]) - 
       (62902*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (156790399911517027493*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (484649084601396*Sqrt[3]) - (854491507002324335*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (156790399911517027493*CF^2*NC*Pi*Log[3]^2)/(23263156060867008*
         Sqrt[3]) - (854491507002324335*CF*NC*NH*Pi*Log[3]^2)/
        (366028679279376*Sqrt[3]) - 
       (CF*NC*(-2001*CA*(12305865400558465679691569207 + 47377916570666682000*
             lm) + 4*(5336*CF*(2307349753545745880922661556 + 
              7268203110272729625*lm) + 5005*
             (29*(45603686268859865165896183 + 29689185754027800*lm)*NM + 
              407590673490*(2044193 + 2112380*lm)*NL + (372311654599148861 + 
                860986386866806200*lm)*NH)))*Log[x]^2)/1258966072275912000 + 
       (CF*NC*(56354252590693887445*CA - 12*(9392376550876726601*CF + 
            10010*(500399906031346*NM - 739333*NL)))*Log[x]^3)/9729720 - 
       (119018144272138531762202030539*CF^2*NC*PolyGamma[2, 1])/
        32942581135143840 - (2289131416889657*CF*NM*NC*PolyGamma[2, 1])/
        2160 - (5728558733570207499757*CF*NC*NH*PolyGamma[2, 1])/
        222362422662220920 - (2149138364654347210561168304677*CF^2*NC*
         Zeta[3])/1498887441649044720 + (1046867978351263*CF*NM*NC*Zeta[3])/
        1080 - (130322*CF*NC*NL*Zeta[3])/9 - 
       (15672113508915247182217*CF*NC*NH*Zeta[3])/111181211331110460 + 
       CA*CF*NC*(-27395072871786535133217755411564985690120236581859113791679/
          6289062298304473350498937639137953633280000000 + (81499*lm^2)/288 + 
         (1554425079354629517603827593*Pi^2)/953686916582400 + 
         (5487663996903095962255*Pi^3)/(1256210427286818432*Sqrt[3]) + 
         (222979*Pi^4)/2160 + lm*(-411383803387201/2549965017600 + 
           (2651*Pi^2)/1296) + (952922806361442087620547367*
           Im[PolyLog[2, (-1)^(1/3)]])/(31436665942852631260800*Sqrt[3]) + 
         (31451*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (156790399911517027493*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (969298169202792*Sqrt[3]) + (156790399911517027493*Pi*Log[3]^2)/
          (46526312121734016*Sqrt[3]) + (119018144272138531762202030539*
           PolyGamma[2, 1])/65885162270287680 + 
         (429827682125034461461032739397*Zeta[3])/599554976659617888) + 
       CF*Log[x]*((-93569087947099670919221231268519497*NM*NC)/
          10884792744625830030000 - (29980940537*lm*NM*NC)/19459440 - 
         (1190*lm^2*NM*NC)/3 - (5918119812626353*NC*NL)/280496151936 - 
         (29980940537*lm*NC*NL)/19459440 - (1190*lm^2*NC*NL)/3 - 
         (1082718673060862977220195225479544388463*NC*NH)/
          42557880516822278312222167289640000 - (29980940537*lm*NC*NH)/
          19459440 - (1190*lm^2*NC*NH)/3 - (500399909737475*NM*NC*Pi^2)/
          324 - (782173*NC*NL*Pi^2)/324 + (854491507002324335*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-302068971552205686068998066354269017778827101759/
            19576620148472476676849800137600000 - (31267425737*lm)/2162160 - 
           3570*lm^2 - (5123113928497425173*Pi^2)/1769040 + 
           (156790399911517027493*Im[PolyLog[2, (-1)^(1/3)]])/
            (1453947253804188*Sqrt[3]) - 9520*Zeta[3]) + 
         CA*NC*(302068972694224372523717848308237663704292106909/
            39153240296944953353699600275200000 + (39805009337*lm)/3538080 + 
           (6545*lm^2)/3 + (5123113936991573381*Pi^2)/3538080 - 
           (156790399911517027493*Im[PolyLog[2, (-1)^(1/3)]])/
            (2907894507608376*Sqrt[3]) + 4760*Zeta[3])), 
      (1982738281859835511938826740738504346483040188139381121028199*CF^2*NC)/
        122047115226471185958120008559520912695840000000 + 
       (12335437922989*CF^2*lm*NC)/6087156075 + 2044*CF^2*lm^2*NC + 
       (13437007904108021768561984636701427317137330827*CF*NM*NC)/
        437097537495675629554479498000000 + (10261746753439*CF*lm*NM*NC)/
        54784404675 + (2044*CF*lm^2*NM*NC)/9 - 
       (1061380851136886598037*CF*NC*NL)/15793686454946400 + 
       (10261746753439*CF*lm*NC*NL)/54784404675 + (2044*CF*lm^2*NC*NL)/9 - 
       (127261369551024718168279785732868529148461642968032101041*CF*NC*NH)/
        73822928667383587934833629358137039364268926800000 + 
       (10261746753439*CF*lm*NC*NH)/54784404675 + (2044*CF*lm^2*NC*NH)/9 - 
       (578124235637911925200011479*CF^2*NC*Pi^2)/94375267786800 - 
       (128*CF^2*lm*NC*Pi^2)/9 - (4600962788774287336*CF*NM*NC*Pi^2)/
        405405 - (128*CF*lm*NM*NC*Pi^2)/81 + (6527134616*CF*NC*NL*Pi^2)/
        3648645 - (128*CF*lm*NC*NL*Pi^2)/81 - (128*CF*lm*NC*NH*Pi^2)/81 + 
       (95595796099725999910135*CF^2*NC*Pi^3)/(2119855096046506104*Sqrt[3]) + 
       (144560348276313607960*CF*NC*NH*Pi^3)/(617673396283947*Sqrt[3]) + 
       (92833*CF^2*NC*Pi^4)/135 - (122381636245467856617373578023*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(371345616449946706768200*Sqrt[3]) - 
       (2890946811839186854598464*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3091455348401154735*Sqrt[3]) + 
       (190864*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (38238318439890399964054*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22899669247415961*Sqrt[3]) + 
       (66084730640600506496*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7625597484987*Sqrt[3]) + (19119159219945199982027*CF^2*NC*Pi*
         Log[3]^2)/(549592061937983064*Sqrt[3]) + 
       (4130295665037531656*CF*NC*NH*Pi*Log[3]^2)/(22876792454961*Sqrt[3]) + 
       CF*((-16621071372316997873716231928*CF*NC)/226107412405875 + 
         CA*(199452855910574686027103167081/5426577897741000 - 
           (9754096*lm)/27)*NC + (1773472*CF*lm*NC)/3 - 
         (18457498364419037186606347*NM*NC)/135528918525 + 
         (1773472*lm*NM*NC)/27 + (2195120*NC*NL)/27 + (1773472*lm*NC*NL)/
          27 + (585646332850983659*NC*NH)/24368099550795 + 
         (1773472*lm*NC*NH)/27)*Log[x]^2 - 
       (4*CF*NC*(-3299318321991553165*CA + 4*(1649658680660120281*CF + 
            30030*(102615459028877*NM + 110842*NL)))*Log[x]^3)/1216215 - 
       (81367659111666061301927429237*CF^2*NC*PolyGamma[2, 1])/
        16677181699666569 - (477901415301862*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (310868647893087334954*CF*NC*NH*PolyGamma[2, 1])/5559060566555523 + 
       CA*CF*NC*(-9532395530107486270172854953617190819709588457714860541903/
          1173529954100684480366538543841547237460000000 - (11242*lm^2)/9 + 
         (46249938836236266920349137*Pi^2)/15100042845888 - 
         (95595796099725999910135*Pi^3)/(4239710192093012208*Sqrt[3]) - 
         (279523*Pi^4)/810 + lm*(-26097206593639/9960800850 + 
           (704*Pi^2)/81) + (122381636245467856617373578023*
           Im[PolyLog[2, (-1)^(1/3)]])/(742691232899893413536400*Sqrt[3]) - 
         (95432*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (19119159219945199982027*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (22899669247415961*Sqrt[3]) - (19119159219945199982027*Pi*Log[3]^2)/
          (1099184123875966128*Sqrt[3]) + (81367659111666061301927429237*
           PolyGamma[2, 1])/33354363399333138 - 
         (91243537778966886472439041020503*Zeta[3])/166938588813662355690) + 
       (91243530559854148209124683940892*CF^2*NC*Zeta[3])/
        83469294406831177845 - (408520394384300*CF*NM*NC*Zeta[3])/27 + 
       (623968*CF*NC*NL*Zeta[3])/9 - (2351499756910383961804*CF*NC*NH*
         Zeta[3])/5559060566555523 + CF*Log[x]*
        ((-285508561025297698210881736905407509*NM*NC)/
          5442396372312915015000 + (14245979752*lm*NM*NC)/1216215 + 
         (5440*lm^2*NM*NC)/3 + (707265684961559*NC*NL)/6261074820 + 
         (14245979752*lm*NC*NL)/1216215 + (5440*lm^2*NC*NL)/3 + 
         (1743363462005310689005708455883680959591893*NC*NH)/
          1022453079416655236451137569133601000 + (14245979752*lm*NC*NH)/
          1216215 + (5440*lm^2*NC*NH)/3 - (820923672376928*NM*NC*Pi^2)/81 + 
         (935696*NC*NL*Pi^2)/81 - (66084730640600506496*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CA*NC*(858861713077434299606974501901594574357414561829/
            58447505347122153924633297526200000 - (8526428276*lm)/110565 - 
           (29920*lm^2)/3 + (13197272893799494231*Pi^2)/4864860 + 
           (19119159219945199982027*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) - 21760*Zeta[3]) + 
         CF*NC*(-22330404722816083640968324201342088810443424339879/
            759817569512588001020232867840600000 + (14613546952*lm)/135135 + 
           16320*lm^2 - (13197272927723550397*Pi^2)/2432430 - 
           (38238318439890399964054*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) + 43520*Zeta[3])), 
      (2254074726553519810980022927704286933257473466854604269417550774209*
         CF^2*NC)/27214693424076852611040812697217422077612267520000000 + 
       (21340620910669*CF^2*lm*NC)/22832409600 - (8943*CF^2*lm^2*NC)/16 + 
       (20199556424920282825402658747784676555870785228327743*CF*NM*NC)/
        454842531924566738312712553673472000000 + 
       (23467602567469*CF*lm*NM*NC)/205491686400 - (2981*CF*lm^2*NM*NC)/
        48 + (4144729954517419069553*CF*NC*NL)/210582486065952000 + 
       (23467602567469*CF*lm*NC*NL)/205491686400 - (2981*CF*lm^2*NC*NL)/
        48 - (350014492171373687621743911886740759334419535255623215191*CF*NC*
         NH)/28348004608275297766976113673524623115879267891200000 + 
       (23467602567469*CF*lm*NC*NH)/205491686400 - (2981*CF*lm^2*NC*NH)/
        48 - (124427534131080713039133740189*CF^2*NC*Pi^2)/4026678092236800 - 
       (91*CF^2*lm*NC*Pi^2)/24 - (6841169991367648663*CF*NM*NC*Pi^2)/
        405405 - (91*CF*lm*NM*NC*Pi^2)/216 - (431801737*CF*NC*NL*Pi^2)/
        855360 - (91*CF*lm*NC*NL*Pi^2)/216 - (91*CF*lm*NC*NH*Pi^2)/216 - 
       (774311873073135600165485*CF^2*NC*Pi^3)/(67835363073488195328*
         Sqrt[3]) - (27765556154771891575*CF*NC*NH*Pi^3)/
        (7412080755407364*Sqrt[3]) - (1160347*CF^2*NC*Pi^4)/4320 - 
       (1880248328241353053098667367173*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (23766119452796589233164800*Sqrt[3]) + 
       (25235716227628905542881559*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (74194928361627713640*Sqrt[3]) - 
       (53601*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (154862374614627120033097*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(366394707958655376*
         Sqrt[3]) - (3173206417688216180*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (154862374614627120033097*CF^2*NC*Pi*Log[3]^2)/(17586945982015458048*
         Sqrt[3]) - (793301604422054045*CF*NC*NH*Pi*Log[3]^2)/
        (274521509459532*Sqrt[3]) + 
       CF*((-622448740541807755554740281228069*CF*NC)/1678621429701216000 - 
         169238*CF*lm*NC + CA*(207482913632130371341940379834833/
            1119080953134144000 + (930809*lm)/9)*NC - 
         (8489482584240720767962435627*NM*NC)/41923612130400 - 
         (169238*lm*NM*NC)/9 - (1627313*NC*NL)/90 - (169238*lm*NC*NL)/9 - 
         (2182050290615893979*NC*NH)/259926395208480 - (169238*lm*NC*NH)/9)*
        Log[x]^2 - (CF*NC*(-356493296358685476765*CA + 712986605764291210628*
           CF + 480480*(804797145159281*NM - 169238*NL))*Log[x]^3)/
        6486480 - (89782113529808131774376116385797*CF^2*NC*PolyGamma[2, 1])/
        2668349071946651040 - (3705135589936897*CF*NM*NC*PolyGamma[2, 1])/
        360 - (15395945785615870203263*CF*NC*NH*PolyGamma[2, 1])/
        444724845324441840 - (6589234563858179581697587587549461*CF^2*NC*
         Zeta[3])/534203484203719538208 + (1660178715672113*CF*NM*NC*
         Zeta[3])/180 - (118915*CF*NC*NL*Zeta[3])/6 - 
       (41425205079383707726823*CF*NC*NH*Zeta[3])/222362422662220920 + 
       CA*CF*NC*
        (-2254074727906293282658013832940288873941618821417344573574484877709/
          54429386848153705222081625394434844155224535040000000 + 
         (32791*lm^2)/96 + (373282602405740580256364295863*Pi^2)/
          24160068553420800 + (774311873073135600165485*Pi^3)/
          (135670726146976390656*Sqrt[3]) + (231487*Pi^4)/1728 + 
         lm*(-7225197188269/37362124800 + (1001*Pi^2)/432) + 
         (1880248328241353053098667367173*Im[PolyLog[2, (-1)^(1/3)]])/
          (47532238905593178466329600*Sqrt[3]) + 
         (53601*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (154862374614627120033097*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (732789415917310752*Sqrt[3]) + (154862374614627120033097*Pi*
           Log[3]^2)/(35173891964030916096*Sqrt[3]) + 
         (89782113529808131774376116385797*PolyGamma[2, 1])/
          5336698143893302080 + (32946172930750471409842485403968529*Zeta[3])/
          5342034842037195382080) + CF*Log[x]*
        ((-8005242746747452002300381192873314575807*NM*NC)/
          97643847447790112589120000 - (283311439*lm*NM*NC)/142560 - 
         510*lm^2*NM*NC - (33980274905919191*NC*NL)/1168733966400 - 
         (283311439*lm*NC*NL)/142560 - 510*lm^2*NC*NL - 
         (6234178226943976660771558228745528477448001*NC*NH)/
          196310991247997805398618413273651392000 - (283311439*lm*NC*NH)/
          142560 - 510*lm^2*NC*NH - (804797146003735*NM*NC*Pi^2)/54 - 
         (89209*NC*NL*Pi^2)/27 + (3173206417688216180*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-2976742417754883400280988797132912015890820852533676231/
            20448210430722768283456506939326227200000 - (295429039*lm)/
            15840 - 4590*lm^2 - (712986593866320698621*Pi^2)/25945920 + 
           (154862374614627120033097*Im[PolyLog[2, (-1)^(1/3)]])/
            (1099184123875966128*Sqrt[3]) - 12240*Zeta[3]) + 
         CA*NC*(5953484838730688693711864422533692801874344752644051937/
            81792841722891073133826027757304908800000 + (375845839*lm)/
            25920 + 2805*lm^2 + (237662198012347590047*Pi^2)/17297280 - 
           (154862374614627120033097*Im[PolyLog[2, (-1)^(1/3)]])/
            (2198368247751932256*Sqrt[3]) + 6120*Zeta[3])), 
      (12698371484774311728582532993180252786775125848839788373031789202813*
         CF^2*NC)/81644080272230557833122438091652266232836802560000000 + 
       (3781532954683741*CF^2*lm*NC)/1558311955200 + (9809*CF^2*lm^2*NC)/4 + 
       (98520878172243002784511224737176387440135670200345833*CF*NM*NC)/
        341131898943425053734534415255104000000 + 
       (3144637872660541*CF*lm*NM*NC)/14024807596800 + 
       (9809*CF*lm^2*NM*NC)/36 - (33267238961521549812403*CF*NC*NL)/
        360998547541632000 + (3144637872660541*CF*lm*NC*NL)/14024807596800 + 
       (9809*CF*lm^2*NC*NL)/36 - 
       (2258112422231565513863509021076996332909657165672200406391*CF*NC*NH)/
        966409248009385151146912966142884878950429587200000 + 
       (3144637872660541*CF*lm*NC*NH)/14024807596800 + 
       (9809*CF*lm^2*NC*NH)/36 - (4232907387780383416658846837497*CF^2*NC*
         Pi^2)/72480205660262400 - (289*CF^2*lm*NC*Pi^2)/18 - 
       (1036155994198697135063*CF*NM*NC*Pi^2)/9729720 - 
       (289*CF*lm*NM*NC*Pi^2)/162 + (133206691529*CF*NC*NL*Pi^2)/58378320 - 
       (289*CF*lm*NC*NL*Pi^2)/162 - (289*CF*lm*NC*NH*Pi^2)/162 + 
       (24502790047220324220296815*CF^2*NC*Pi^3)/(407012178440929171968*
         Sqrt[3]) + (1769057191103245395310*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) + (22839721*CF^2*NC*Pi^4)/25920 - 
       (63424594521730837047440779245949*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (142596716716779535398988800*Sqrt[3]) - 
       (36052336845072892514907439*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) + 
       (323289*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
       (4900558009444064844059363*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2198368247751932256*
         Sqrt[3]) + (808711858790055037856*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (4900558009444064844059363*CF^2*NC*Pi*Log[3]^2)/(105521675892092748288*
         Sqrt[3]) + (50544491174378439866*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + 
       CF*((-7058373044835323688250559914365791*CF*NC)/10071728578207296000 + 
         CA*(2352791014002639772854877575136637/6714485718804864000 - 
           (13249324*lm)/27)*NC + (2408968*CF*lm*NC)/3 - 
         (40181487033193338831174647257*NM*NC)/31442709097800 + 
         (2408968*lm*NM*NC)/27 + (2974660*NC*NL)/27 + (2408968*lm*NC*NL)/
          27 + (3270204834825430727*NC*NH)/97472398203180 + 
         (2408968*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-252022323706131942039*CA + 20*(25202231265908155421*CF + 
            12012*(3852798507206585*NM + 602242*NL)))*Log[x]^3)/2432430 - 
       (110884682413519215100598900243185*CF^2*NC*PolyGamma[2, 1])/
        2401514164751985936 - (8785446484137407*CF*NM*NC*PolyGamma[2, 1])/
        54 + (836908698568022681509*CF*NC*NH*PolyGamma[2, 1])/
        11118121133111046 + CA*CF*NC*
        (-6837584640028220942895408951217665626833112510861900763384105212707/
          87924394139325216127978010252548594404593479680000000 - 
         (107899*lm^2)/72 + (248994552211620048952960144889*Pi^2)/
          8527083018854400 - (24502790047220324220296815*Pi^3)/
          (814024356881858343936*Sqrt[3]) - (4582741*Pi^4)/10368 + 
         lm*(-8008200317201341/2549965017600 + (3179*Pi^2)/324) + 
         (63424594521730837047440779245949*Im[PolyLog[2, (-1)^(1/3)]])/
          (285193433433559070797977600*Sqrt[3]) - 
         (323289*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 - 
         (4900558009444064844059363*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4396736495503864512*Sqrt[3]) - (4900558009444064844059363*Pi*
           Log[3]^2)/(211043351784185496576*Sqrt[3]) + 
         (110884682413519215100598900243185*PolyGamma[2, 1])/
          4803028329503971872 - (541536792430654527062010118460188801*
           Zeta[3])/96156627156669516877440) + 
       (541536786830454811078027059337383169*CF^2*NC*Zeta[3])/
        48078313578334758438720 - (3648381824092937*CF*NM*NC*Zeta[3])/27 + 
       (844798*CF*NC*NL*Zeta[3])/9 - (3175083705256232056235*CF*NC*NH*
         Zeta[3])/5559060566555523 + CF*Log[x]*
        ((-35988892954734523253101312159525253373217*NM*NC)/
          73232885585842584441840000 + (145661093489*lm*NM*NC)/9729720 + 
         2312*lm^2*NM*NC + (268206707013756113*NC*NL)/1753100949600 + 
         (145661093489*lm*NC*NL)/9729720 + 2312*lm^2*NC*NL + 
         (170621152901370268209557856520248984018195029*NC*NH)/
          73616621717999177024481904977619272000 + (145661093489*lm*NC*NH)/
          9729720 + 2312*lm^2*NC*NH - (7705597014682382*NM*NC*Pi^2)/81 + 
         (1266908*NC*NL*Pi^2)/81 - (808711858790055037856*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(68275083240650020732246570765064117853669967772436407143/
            490757050337346438802956166543829452800000 - (174291236849*lm)/
            1769040 - 12716*lm^2 + (2688238108105450838761*Pi^2)/103783680 + 
           (4900558009444064844059363*Im[PolyLog[2, (-1)^(1/3)]])/
            (13190209486511593536*Sqrt[3]) - 27744*Zeta[3]) + 
         CF*NC*(-68275083318570651651809324434655960491425233858350545943/
            245378525168673219401478083271914726400000 + (149410278929*lm)/
            1081080 + 20808*lm^2 - (2688238109083876943417*Pi^2)/51891840 - 
           (4900558009444064844059363*Im[PolyLog[2, (-1)^(1/3)]])/
            (6595104743255796768*Sqrt[3]) + 55488*Zeta[3])), 
      (1136873946563232674512723862518323556402872702180399412818016995539242\
44589*CF^2*NC)/144719398325706222630189757914710553468875250511365120000000 + 
       (2005616651353822327*CF^2*lm*NC)/1801408620211200 - 
       (10675*CF^2*lm^2*NC)/16 + 
       (3479627431527815566749394028697689223131891055063262245973*CF*NM*NC)/
        8130128321138860620644411811891842611200000 + 
       (2205929536986682327*CF*lm*NM*NC)/16212677581900800 - 
       (10675*CF*lm^2*NM*NC)/144 + (1392945769619807672212429*CF*NC*NL)/
        52164290119765824000 + (2205929536986682327*CF*lm*NC*NL)/
        16212677581900800 - (10675*CF*lm^2*NC*NL)/144 - 
       (5512680525398516074953297493779758822082142165797785386153*CF*NC*NH)/
        255132041474477679902785023061721608042913411020800000 + 
       (2205929536986682327*CF*lm*NC*NH)/16212677581900800 - 
       (10675*CF*lm^2*NC*NH)/144 - (360131336871191182679984734528733*CF^2*
         NC*Pi^2)/1232163496224460800 - (307*CF^2*lm*NC*Pi^2)/72 - 
       (49555597549301449171*CF*NM*NC*Pi^2)/306306 - (307*CF*lm*NM*NC*Pi^2)/
        648 - (2536195517579*CF*NC*NL*Pi^2)/3969725760 - 
       (307*CF*lm*NC*NL*Pi^2)/648 - (307*CF*lm*NC*NH*Pi^2)/648 - 
       (101460630308675469926661145*CF^2*NC*Pi^3)/(6919207033495795923456*
         Sqrt[3]) - (302789555350183334965*CF*NC*NH*Pi^3)/
        (66708726798666276*Sqrt[3]) - (8887967*CF^2*NC*Pi^4)/25920 - 
       (4194715496938529035362093138928717*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(41210451131149285730307763200*
         Sqrt[3]) + (295392973689516582446587253*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(667754355254649422760*Sqrt[3]) - 
       (135087*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 - 
       (20292126061735093985332229*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37372260211782848352*
         Sqrt[3]) - (34604520611449523996*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (20292126061735093985332229*CF^2*NC*Pi*Log[3]^2)/
        (1793868490165576720896*Sqrt[3]) - (8651130152862380999*CF*NC*NH*Pi*
         Log[3]^2)/(2470693585135788*Sqrt[3]) - 
       (CF*NC*(6*CF*(6205363045227857696530058264042192711 + 
            403500208544897527679616000*lm) - 
          CA*(18616089137196260521091882231303623073 + 
            1479500764664624268158592000*lm) + 13613600*
           ((1513875281602398127497646166393 + 19759662325169807040*lm)*NM + 
            7*(7013886854832*(384797 + 402460*lm)*NL + 
              5*(259285254421893229 + 564561780719137344*lm)*NH)))*Log[x]^2)/
        10615601921430489984000 + (CF*NC*(172133971404882460575273*CA - 
          68*(5062763878794179724737*CF + 120120*(23191464619024049*NM - 
              684182*NL)))*Log[x]^3)/330810480 - 
       (7516799977975818492365630345234231*CF^2*NC*PolyGamma[2, 1])/
        24015141647519859360 - (107367500376373579*CF*NM*NC*PolyGamma[2, 1])/
        1080 - (329687028271582159863347*CF*NC*NH*PolyGamma[2, 1])/
        7204542494255957808 - (86363241257891757954373823111445806471*CF^2*NC*
         Zeta[3])/817331330831690893458240 + 
       (47242263767297591*CF*NM*NC*Zeta[3])/540 - (479275*CF*NC*NL*Zeta[3])/
        18 - (873803473750068039129131*CF*NC*NH*Zeta[3])/
        3602271247127978904 + CA*CF*NC*(-113687394665847704296873912004034128\
401713624247447700466854330816241104089/
          289438796651412445260379515829421106937750501022730240000000 + 
         (117425*lm^2)/288 + (360131336872801813801697803552301*Pi^2)/
          2464326992448921600 + (101460630308675469926661145*Pi^3)/
          (13838414066991591846912*Sqrt[3]) + (8868319*Pi^4)/51840 + 
         lm*(-676267501244842327/2947759560345600 + (3377*Pi^2)/1296) + 
         (4194715496938529035362093138928717*Im[PolyLog[2, (-1)^(1/3)]])/
          (82420902262298571460615526400*Sqrt[3]) + 
         (135087*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (20292126061735093985332229*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74744520423565696704*Sqrt[3]) + (20292126061735093985332229*Pi*
           Log[3]^2)/(3587736980331153441792*Sqrt[3]) + 
         (7516799977975818492365630345234231*PolyGamma[2, 1])/
          48030283295039718720 + (86363241303485196781557285728494845863*
           Zeta[3])/1634662661663381786916480) + 
       CF*Log[x]*((-3989211866244191465850841688530964498100097*NM*NC)/
          5118312948945070810807872000 - (1670285915021*lm*NM*NC)/
          661620960 - 646*lm^2*NM*NC - (2342390220763774327*NC*NL)/
          59605432286400 - (1670285915021*lm*NC*NL)/661620960 - 
         646*lm^2*NC*NL - (5279234762057432651101512261942292320150331*NC*
           NH)/135907609325536942199043516881758656000 - 
         (1670285915021*lm*NC*NH)/661620960 - 646*lm^2*NC*NH - 
         (23191464622423471*NM*NC*Pi^2)/162 - (359533*NC*NL*Pi^2)/81 + 
         (34604520611449523996*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CF*NC*(-549471270331015371091610501350854429742333749925966956996404\
9/4008748965680614385361947446413270885196800000 - (1741520438381*lm)/
            73513440 - 5814*lm^2 - (45902392385231045470201*Pi^2)/176432256 + 
           (20292126061735093985332229*Im[PolyLog[2, (-1)^(1/3)]])/
            (112116780635348545056*Sqrt[3]) - 15504*Zeta[3]) + 
         CA*NC*(5494712703729217673867613302877416970342239488895093700422399/
            8017497931361228770723894892826541770393600000 + 
           (2214258638861*lm)/120294720 + 3553*lm^2 + 
           (8500443034591163904247*Pi^2)/65345280 - 
           (20292126061735093985332229*Im[PolyLog[2, (-1)^(1/3)]])/
            (224233561270697090112*Sqrt[3]) + 7752*Zeta[3])), 
      (5964599672239324769634529541408867984968775653695723806053591496628853\
039*CF^2*NC)/4019983286825172850838604386519737596357645847537920000000 + 
       (3997744339513181*CF^2*lm*NC)/1389975787200 + (5823*CF^2*lm^2*NC)/2 + 
       (306137948220321942765241674675305315679891285649117508677*CF*NM*NC)/
        112918448904706397508950164054053369600000 + 
       (3323258588774381*CF*lm*NM*NC)/12509782084800 + 
       (647*CF*lm^2*NM*NC)/2 - (958448362382510836473463*CF*NC*NL)/
        7728042980706048000 + (3323258588774381*CF*lm*NC*NL)/
        12509782084800 + (647*CF*lm^2*NC*NL)/2 - 
       (62064535251586733322921141886601507197553907174629905316197*CF*NC*
         NH)/19932190740193568742405079926697000628352610236000000 + 
       (3323258588774381*CF*lm*NC*NH)/12509782084800 + 
       (647*CF*lm^2*NC*NH)/2 - (28495758894836651126155460004829*CF^2*NC*
         Pi^2)/51340145676019200 - 18*CF^2*lm*NC*Pi^2 - 
       (201632307667090054639*CF*NM*NC*Pi^2)/201960 - 2*CF*lm*NM*NC*Pi^2 + 
       (2197739263*CF*NC*NL*Pi^2)/765765 - 2*CF*lm*NC*NL*Pi^2 - 
       2*CF*lm*NC*NH*Pi^2 + (843991681733752867470175*CF^2*NC*Pi^3)/
        (10677788631937956672*Sqrt[3]) + (28373018677495713247495*CF*NC*NH*
         Pi^3)/(66708726798666276*Sqrt[3]) + (1201901*CF^2*NC*Pi^4)/1080 - 
       (337887126435094483477519128986507*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (572367376821517857365385600*Sqrt[3]) - 
       (42034914094835506730036597*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (23848369830523193670*Sqrt[3]) + 101294*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 + (168798336346750573494035*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(57673241067566124*Sqrt[3]) + 
       (3242630705999510085428*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (168798336346750573494035*CF^2*NC*Pi*Log[3]^2)/(2768315571243173952*
         Sqrt[3]) + (810657676499877521357*CF*NC*NH*Pi*Log[3]^2)/
        (2470693585135788*Sqrt[3]) + 
       CF*((-259944179287231662491086138944179173*CF*NC)/
          39027948240553272000 + CA*(2209525523816484684851317825550878363/
            663475120089405624000 - 654874*lm)*NC + 1071612*CF*lm*NC - 
         (64876162220927429656176241339*NM*NC)/5415133233510 + 
         119068*lm*NM*NC + (440164*NC*NL)/3 + 119068*lm*NC*NL + 
         (2484467696024525359*NC*NH)/54151332335100 + 119068*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-5436599427285834728487*CA + 
          8*(1359149848007636666837*CF + 1837836*(1338317762631868*NM + 
              29767*NL)))*Log[x]^3)/5513508 - 
       (1570277848753194123868754580400303*CF^2*NC*PolyGamma[2, 1])/
        3602271247127978904 - (2989555825760235*CF*NM*NC*PolyGamma[2, 1])/
        2 + (44868793586482694633483*CF*NC*NH*PolyGamma[2, 1])/
        450283905890997363 + CA*CF*NC*(-1704171334731110492581161552932975080\
255880721318494067033636840359759279/
          2297133306757241629050631078011278626490083341450240000000 - 
         (7117*lm^2)/4 + (9498586298224167056486794504897*Pi^2)/
          34226763784012800 - (843991681733752867470175*Pi^3)/
          (21355577263875913344*Sqrt[3]) - (1205357*Pi^4)/2160 + 
         lm*(-8473877048961581/2274505833600 + 11*Pi^2) + 
         (337887126435094483477519128986507*Im[PolyLog[2, (-1)^(1/3)]])/
          (1144734753643035714730771200*Sqrt[3]) - 
         50647*Im[PolyLog[2, (-1)^(1/3)]]^2 - (168798336346750573494035*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(115346482135132248*
           Sqrt[3]) - (168798336346750573494035*Pi*Log[3]^2)/
          (5536631142486347904*Sqrt[3]) + (1570277848753194123868754580400303*
           PolyGamma[2, 1])/7204542494255957808 - 
         (35009673132010837870773477783645222323*Zeta[3])/
          612998498123768170093680) + (35009673084714444376097231840367201557*
         CF^2*NC*Zeta[3])/306499249061884085046840 - 
       (3615396429162299*CF*NM*NC*Zeta[3])/3 + 124906*CF*NC*NL*Zeta[3] - 
       (341358820920204794100878*CF*NC*NH*Zeta[3])/450283905890997363 + 
       CF*Log[x]*((-7190505146412737815508405111441976657158911*NM*NC)/
          1563928956622104969969072000 + (4815117746*lm*NM*NC)/255255 + 
         2907*lm^2*NM*NC + (899120747212111013*NC*NL)/4415217206400 + 
         (4815117746*lm*NC*NL)/255255 + 2907*lm^2*NC*NL + 
         (621749692876048253025125967668569932704731453*NC*NH)/
          200772604685452300975859740848052560000 + (4815117746*lm*NC*NH)/
          255255 + 2907*lm^2*NC*NH - (2676635525280209*NM*NC*Pi^2)/3 + 
         (62441*NC*NL*Pi^2)/3 - (3242630705999510085428*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(2032152068003346860347564172806064117006401504151424496571/
            1546585249105175302994578490128576730400000 - 
           (2879757418*lm)/23205 - (31977*lm^2)/2 + 
           (18121998080148036184237*Pi^2)/73513440 + 
           (168798336346750573494035*Im[PolyLog[2, (-1)^(1/3)]])/
            (346039446405396744*Sqrt[3]) - 34884*Zeta[3]) + 
         CF*NC*(-16257216546580697641961482667650166443560778666384659894193/
            6186340996420701211978313960514306921600000 + (29632732761*lm)/
            170170 + 26163*lm^2 - (54365994243207384454097*Pi^2)/110270160 - 
           (168798336346750573494035*Im[PolyLog[2, (-1)^(1/3)]])/
            (173019723202698372*Sqrt[3]) + 69768*Zeta[3])), 
      (3227568989384272420438296876315069849170164640276450576653720603462616\
373617*CF^2*NC)/
        434158194977118667890569273744131660406625751534095360000000 + 
       (338013039978073469*CF^2*lm*NC)/257344088601600 - 
       (12617*CF^2*lm^2*NC)/16 + 
       (33385830735930614575290054696770498561596797115493007435539*CF*NM*
         NC)/8130128321138860620644411811891842611200000 + 
       (371835022956056669*CF*lm*NM*NC)/2316096797414400 - 
       (12617*CF*lm^2*NM*NC)/144 + (3851844732069957179471729*CF*NC*NL)/
        108192601729884672000 + (371835022956056669*CF*lm*NC*NL)/
        2316096797414400 - (12617*CF*lm^2*NC*NL)/144 - 
       (108258493098995028592928525475099836306553927490252265837087*CF*NC*
         NH)/3131165963550407889715998010302947007799391862528000000 + 
       (371835022956056669*CF*lm*NC*NH)/2316096797414400 - 
       (12617*CF*lm^2*NC*NH)/144 - (3399246644766900733480876530198257*CF^2*
         NC*Pi^2)/1232163496224460800 - (343*CF^2*lm*NC*Pi^2)/72 - 
       (255583686503246969240707*CF*NM*NC*Pi^2)/165405240 - 
       (343*CF*lm*NM*NC*Pi^2)/648 - (150853019467*CF*NC*NL*Pi^2)/
        189034560 - (343*CF*lm*NC*NL*Pi^2)/648 - (343*CF*lm*NC*NH*Pi^2)/
        648 - (128406431109447967779017125*CF^2*NC*Pi^3)/
        (6919207033495795923456*Sqrt[3]) - (9707634513125076975545*CF*NC*NH*
         Pi^3)/(1801135623563989452*Sqrt[3]) - (11187307*CF^2*NC*Pi^4)/
        25920 - (15987069396103582179505659384939491*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(123631353393447857190923289600*
         Sqrt[3]) + (10228415872497428976347290543*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(18029367591875534414520*Sqrt[3]) - 
       (504241*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (25681286221889593555803425*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37372260211782848352*
         Sqrt[3]) - (1109443944357151654348*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (25681286221889593555803425*CF^2*NC*Pi*Log[3]^2)/
        (1793868490165576720896*Sqrt[3]) - (277360986089287913587*CF*NC*NH*
         Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) + 
       CF*((-527146671571572148068400511172836293279*CF*NC)/
          15923402882145734976000 - 302192*CF*lm*NC + 
         CA*(527146671577591346755242268735284614899/
            31846805764291469952000 + (1662056*lm)/9)*NC - 
         (14458949831643549864313464998959*NM*NC)/779779185625440 - 
         (302192*lm*NM*NC)/9 - (2874683*NC*NL)/90 - (302192*lm*NC*NL)/9 - 
         (61668626626515539849*NC*NH)/3898895928127200 - 
         (302192*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-542084236906198033308125*CA + 
          8*(135521059281748173986681*CF + 1021020*(73956975126257257*NM - 
              302192*NL)))*Log[x]^3)/110270160 - 
       (209553716468689668627638558116642387*CF^2*NC*PolyGamma[2, 1])/
        72045424942559578080 - (6193602358123599853*CF*NM*NC*
         PolyGamma[2, 1])/6480 - (1207752865154942295741071*CF*NC*NH*
         PolyGamma[2, 1])/20262775765094881335 - 
       (2209985949233510780188719714992292941161*CF^2*NC*Zeta[3])/
        2451993992495072680374720 + (2681234657150050607*CF*NM*NC*Zeta[3])/
        3240 - (1900019*CF*NC*NL*Zeta[3])/54 - 
       (6314807506432036390980697*CF*NC*NH*Zeta[3])/20262775765094881335 + 
       CA*CF*NC*(-24827453764781413685093312701298825627077212054779036491058\
8584708416309009/
          66793568458018256598549119037558716985634731005245440000000 + 
         (138787*lm^2)/288 + (3399246644768909556558752138896961*Pi^2)/
          2464326992448921600 + (128406431109447967779017125*Pi^3)/
          (13838414066991591846912*Sqrt[3]) + (248119*Pi^4)/1152 + 
         lm*(-113558062033275869/421108508620800 + (3773*Pi^2)/1296) + 
         (15987069396103582179505659384939491*Im[PolyLog[2, (-1)^(1/3)]])/
          (247262706786895714381846579200*Sqrt[3]) + 
         (504241*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (25681286221889593555803425*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74744520423565696704*Sqrt[3]) + (25681286221889593555803425*Pi*
           Log[3]^2)/(3587736980331153441792*Sqrt[3]) + 
         (209553716468689668627638558116642387*PolyGamma[2, 1])/
          144090849885119156160 + (2209985949413499717058893626308324496521*
           Zeta[3])/4903987984990145360749440) + 
       CF*Log[x]*((-415976510753055694850616171830774674703902321*NM*NC)/
          56301442438395778918886592000 - (99679161589*lm*NM*NC)/31505760 - 
         (1615*lm^2*NM*NC)/2 - (2489850714749839271*NC*NL)/47684345829120 - 
         (99679161589*lm*NC*NL)/31505760 - (1615*lm^2*NC*NL)/2 - 
         (11121032567349542761024381314249738659216129947*NC*NH)/
          238517854366317333559321372127486441280000 - 
         (99679161589*lm*NC*NH)/31505760 - (1615*lm^2*NC*NH)/2 - 
         (24652325042584283*NM*NC*Pi^2)/18 - (316727*NC*NL*Pi^2)/54 + 
         (1109443944357151654348*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*
          (-51641060810760794954838282021811435147081197760162512455727149/
            4008748965680614385361947446413270885196800000 - 
           (103919311789*lm)/3500640 - (14535*lm^2)/2 - 
           (2168336947695380678143321*Pi^2)/882161280 + 
           (25681286221889593555803425*Im[PolyLog[2, (-1)^(1/3)]])/
            (112116780635348545056*Sqrt[3]) - 19380*Zeta[3]) + 
         CA*NC*(5164106081130865830705841050039744911677221412333842055886129\
9/8017497931361228770723894892826541770393600000 + (132058490389*lm)/
            5728320 + (17765*lm^2)/4 + (2168336947705705164043049*Pi^2)/
            1764322560 - (25681286221889593555803425*Im[PolyLog[2, (-1)^
                (1/3)]])/(224233561270697090112*Sqrt[3]) + 9690*Zeta[3])), 
      (1417666640926047892132894612487906198178549129218192101648038434206409\
41055389*CF^2*NC)/
        10047661083756174885467460335221332712267624535503349760000000 + 
       (1521120446125657061*CF^2*lm*NC)/450352155052800 + 
       (13699*CF^2*lm^2*NC)/4 + 
       (1359995836816768449706239579040657246649345195938354151353*CF*NM*NC)/
        53487686323281977767397446130867385600000 + 
       (1264063188956144261*CF*lm*NM*NC)/4053169395475200 + 
       (13699*CF*lm^2*NM*NC)/36 - (75482837509422667005228763*CF*NC*NL)/
        459818557352009856000 + (1264063188956144261*CF*lm*NC*NL)/
        4053169395475200 + (13699*CF*lm^2*NC*NL)/36 - 
       (93818032054111531792174963630702134206094608624380059315461535371*CF*
         NC*NH)/
        22955690066696143673889854202297722666403796791301824000000 + 
       (1264063188956144261*CF*lm*NC*NH)/4053169395475200 + 
       (13699*CF*lm^2*NC*NH)/36 - (149076579268899747853452244057483831*CF^2*
         NC*Pi^2)/28339760413162598400 - (361*CF^2*lm*NC*Pi^2)/18 - 
       (35149473128851728636251*CF*NM*NC*Pi^2)/3759210 - 
       (361*CF*lm*NM*NC*Pi^2)/162 + (1179373120139*CF*NC*NL*Pi^2)/
        330810480 - (361*CF*lm*NC*NL*Pi^2)/162 - (361*CF*lm*NC*NH*Pi^2)/
        162 + (171923344192952561889713702245*CF^2*NC*Pi^3)/
        (1681367309139478409399808*Sqrt[3]) + 
       (1008266842188769231345445*CF*NC*NH*Pi^3)/(1801135623563989452*
         Sqrt[3]) + (35964017*CF^2*NC*Pi^4)/25920 - 
       (7729463972154320336178152850705488447*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10014139624869276432464786457600*
         Sqrt[3]) - (180704653438038288044361235103*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(76624812265471021261710*Sqrt[3]) + 
       (1505123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
       (34384668838590512377942740449*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9081459231463232149536*
         Sqrt[3]) + (115230496250145055010908*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) + 
       (34384668838590512377942740449*CF^2*NC*Pi*Log[3]^2)/
        (435910043110235143177728*Sqrt[3]) + (28807624062536263752727*CF*NC*
         NH*Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) + 
       CF*((-3478023652780235831136363363822631027*CF*NC)/
          55098279869016384000 + CA*(1005148835645567038399450537889131657603/
            31846805764291469952000 - (7742614*lm)/9)*NC + 1407748*CF*lm*NC - 
         (287807119729878368953140143317*NM*NC)/2565063110610 + 
         (1407748*lm*NM*NC)/9 + (1731470*NC*NL)/9 + (1407748*lm*NC*NL)/9 + 
         (116942354747922776047*NC*NH)/1898146701851400 + 
         (1407748*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-128971549350401869576483*CA + 5*(51588619691430974008421*CF + 
            15519504*(5939820471201874*NM + 18523*NL)))*Log[x]^3)/
        13783770 - (798795666747543465325372416215178659*CF^2*NC*
         PolyGamma[2, 1])/194522647344910860816 - 
       (1111954448868075035*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (526639528416254678692690*CF*NC*NH*PolyGamma[2, 1])/
        4052555153018976267 + CA*CF*NC*(-992366648632691866021785291283498832\
839029674757015803367531170395931129527723/
          140667255172586448396544444693098657971746743497046896640000000 - 
         (150689*lm^2)/72 + (341136336999511349036083802677979*Pi^2)/
          129701420655206400 - (171923344192952561889713702245*Pi^3)/
          (3362734618278956818799616*Sqrt[3]) - (12018811*Pi^4)/17280 + 
         lm*(-3227045880068787461/736939890086400 + (3971*Pi^2)/324) + 
         (7729463972154320336178152850705488447*Im[PolyLog[2, (-1)^(1/3)]])/
          (20028279249738552864929572915200*Sqrt[3]) - 
         (1505123*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 - 
         (34384668838590512377942740449*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(18162918462926464299072*Sqrt[3]) - 
         (34384668838590512377942740449*Pi*Log[3]^2)/
          (871820086220470286355456*Sqrt[3]) + 
         (798795666747543465325372416215178659*PolyGamma[2, 1])/
          389045294689821721632 - (75729770711798294762761995220171219415113*
           Zeta[3])/132407675594733924740234880) + 
       (15145954139692538703167152888180131337637*CF^2*NC*Zeta[3])/
        13240767559473392474023488 - (869629830387635794*CF*NM*NC*Zeta[3])/
        81 + (4418906*CF*NC*NL*Zeta[3])/27 - 
       (4015997343196479751384648*CF*NC*NH*Zeta[3])/4052555153018976267 + 
       CF*Log[x]*((-31827358723520186922764872682315560212044119*NM*NC)/
          740808453136786564722192000 + (1294062254699*lm*NM*NC)/55135080 + 
         3610*lm^2*NM*NC + (135226312051621998719*NC*NL)/506646174434400 + 
         (1294062254699*lm*NC*NL)/55135080 + 3610*lm^2*NC*NL + 
         (795766864775936853943213413314081056483038386281*NC*NH)/
          195293625973378247393965884235962283560000 + 
         (1294062254699*lm*NC*NH)/55135080 + 3610*lm^2*NC*NH - 
         8359747329848145*NM*NC*Pi^2 + (736364*NC*NL*Pi^2)/27 - 
         (115230496250145055010908*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CA*NC*
          (2193132277226925009181757589356413647883893014745950682699493319/
            177113817938252599207809678086986331836876800000 - 
           (1547382885899*lm)/10024560 - 19855*lm^2 + 
           (4127089578872129020325873*Pi^2)/1764322560 + 
           (34384668838590512377942740449*Im[PolyLog[2, (-1)^(1/3)]])/
            (54488755388779392897216*Sqrt[3]) - 43320*Zeta[3]) + 
         CF*NC*
          (-24124455050011952745585255182739136203340412959032136176108133909/
            974125998660389295642953229478424825102822400000 + 
           (1327235194499*lm)/6126120 + 32490*lm^2 - 
           (1375696526300354644212059*Pi^2)/294053760 - 
           (34384668838590512377942740449*Im[PolyLog[2, (-1)^(1/3)]])/
            (27244377694389696448608*Sqrt[3]) + 86640*Zeta[3])), 
      (9381307334960637427327358615646009622228841216308173619676228172777752\
2253374259*CF^2*NC)/
        1336338924139571259767172224584437250731594063221945518080000000 + 
       (332999936395921593707*CF^2*lm*NC)/216769503965414400 - 
       (14781*CF^2*lm^2*NC)/16 + 
       (531805155983857676032220981753437297903440361439672226723019*CF*NM*
         NC)/13550213868564767701074019686486404352000000 + 
       (366375665959596492107*CF*lm*NM*NC)/1950925535688729600 - 
       (4927*CF*lm^2*NM*NC)/48 + (31029386780711461416622359689*CF*NC*NL)/
        663977996816302232064000 + (366375665959596492107*CF*lm*NC*NL)/
        1950925535688729600 - (4927*CF*lm^2*NC*NL)/48 - 
       (13005946499194945396783054032231766810069423416903978406186473997*CF*
         NC*NH)/
        249233206438415274173661274196375274663812650876991232000000 + 
       (366375665959596492107*CF*lm*NC*NH)/1950925535688729600 - 
       (4927*CF*lm^2*NC*NH)/48 - (2332317527593068065342714670607932667*CF^2*
         NC*Pi^2)/89742574641681561600 - (127*CF^2*lm*NC*Pi^2)/24 - 
       (15408203155690112617885111*CF*NM*NC*Pi^2)/1047566520 - 
       (127*CF*lm*NM*NC*Pi^2)/216 - (8256208357231*CF*NC*NL*Pi^2)/
        8380532160 - (127*CF*lm*NC*NL*Pi^2)/216 - (127*CF*lm*NC*NH*Pi^2)/
        216 - (370177496017577606176066351115*CF^2*NC*Pi^3)/
        (15972989436825044889298176*Sqrt[3]) - 
       (11303825472154773681305*CF*NC*NH*Pi^3)/(1801135623563989452*
         Sqrt[3]) - (2317571*CF^2*NC*Pi^4)/4320 - 
       (58719207812773394548320061991746079617*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(361510440457780879211978791119360*
         Sqrt[3]) + (220198259500048384691460378317*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(306499249061884085046840*Sqrt[3]) - 
       (103385*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (74035499203515521235213270223*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(86273862698900705420592*
         Sqrt[3]) - (1291865768246259849292*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (74035499203515521235213270223*CF^2*NC*Pi*Log[3]^2)/
        (4141145409547233860188416*Sqrt[3]) - 
       (322966442061564962323*CF*NC*NH*Pi*Log[3]^2)/(66708726798666276*
         Sqrt[3]) + CF*((-15725650929869427157687996863315069570149*CF*NC)/
          50424109126794827424000 - 394440*CF*lm*NC + 
         CA*(15725650929894327682056435195968693833319/
            100848218253589654848000 + (723140*lm)/3)*NC - 
         (229388699988189092522689141688711*NM*NC)/1299631976042400 - 
         (131480*lm*NM*NC)/3 - (415017*NC*NL)/10 - (131480*lm*NC*NL)/3 - 
         (59746975554102199477*NC*NH)/2828610771386400 - 
         (131480*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(97111612206375064756937949*CA - 
          2128*(91270312229448276422291*CF + 218790*(235010926166159221*NM - 
              131480*NL)))*Log[x]^3)/2095133040 - 
       (52525381546384104632805449297029819051*CF^2*NC*PolyGamma[2, 1])/
        1945226473449108608160 - (6589359697082322829*CF*NM*NC*
         PolyGamma[2, 1])/720 - (9314443417834946636878571*CF*NC*NH*
         PolyGamma[2, 1])/121576654590569288010 - 
       (4813463840065226341409951067111566399091683*CF^2*NC*Zeta[3])/
        628936459074986142516115680 + (937025783193458797*CF*NM*NC*Zeta[3])/
        120 - (824663*CF*NC*NL*Zeta[3])/18 - 
       (24046960581689777293761026*CF*NC*NH*Zeta[3])/60788327295284644005 + 
       CA*CF*NC*(-93813073349754458520799855995827541631877222479934914229845\
967308252144710365759/
          2672677848279142519534344449168874501463188126443891036160000000 + 
         (54197*lm^2)/96 + (101405109895358628392316283148306989*Pi^2)/
          7803702142754918400 + (370177496017577606176066351115*Pi^3)/
          (31945978873650089778596352*Sqrt[3]) + (771169*Pi^4)/2880 + 
         lm*(-111506458382442722507/354713733761587200 + (1397*Pi^2)/432) + 
         (58719207812773394548320061991746079617*Im[PolyLog[2, (-1)^(1/3)]])/
          (723020880915561758423957582238720*Sqrt[3]) + 
         (103385*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (74035499203515521235213270223*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(172547725397801410841184*Sqrt[3]) + 
         (74035499203515521235213270223*Pi*Log[3]^2)/
          (8282290819094467720376832*Sqrt[3]) + 
         (52525381546384104632805449297029819051*PolyGamma[2, 1])/
          3890452946898217216320 + 
         (4813463840125124284928166711210685655182379*Zeta[3])/
          1257872918149972285032231360) + CF*Log[x]*
        ((-45840830674701660638939013922340946896583007*NM*NC)/
          656193967813470616770240000 - (5471638811473*lm*NM*NC)/
          1396755360 - (1995*lm^2*NM*NC)/2 - (1753923563514212158283*NC*NL)/
          25670072838009600 - (5471638811473*lm*NC*NL)/1396755360 - 
         (1995*lm^2*NC*NL)/2 - 
         (17950930045682234985705376408616104306015282817257*NC*NH)/
          326530942627488429642710958442528938112320000 - 
         (5471638811473*lm*NC*NH)/1396755360 - (1995*lm^2*NC*NH)/2 - 
         (78336975388935859*NM*NC*Pi^2)/6 - (137465*NC*NL*Pi^2)/18 + 
         (1291865768246259849292*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*
          (-50840742608452746517719886940549266847538289291644253166273558563/
            420645317603349923118547985456592538112582400000 - 
           (5703849390073*lm)/155195040 - (17955*lm^2)/2 - 
           (194223224413629668518772051*Pi^2)/8380532160 + 
           (74035499203515521235213270223*Im[PolyLog[2, (-1)^(1/3)]])/
            (258821588096702116261776*Sqrt[3]) - 23940*Zeta[3]) + 
         CA*NC*
          (65793902199270090198774238824306537939642190025709629631143537183/
            1088729057326317448071535962358239510409036800000 + 
           (7244883229873*lm)/253955520 + (21945*lm^2)/4 + 
           (12948214960917165033582781*Pi^2)/1117404288 - 
           (74035499203515521235213270223*Im[PolyLog[2, (-1)^(1/3)]])/
            (517643176193404232523552*Sqrt[3]) + 11970*Zeta[3]))}, 0, 39, 1]
 
CbarLSeries["a", 2, 1, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(2366*NM - 182784*lm*NM + 82944*lm^2*NM + 270336*NL - 
         182784*lm*NL + 82944*lm^2*NL + 2366*NH - 182784*lm*NH + 
         82944*lm^2*NH - 6*CA*(2914894 - 70784*lm + 76032*lm^2 - 
           2429433*Zeta[3]) + 169155*NM*Zeta[3] + 169155*NH*Zeta[3] + 
         108*CF*(-768802 - 14080*lm + 6912*lm^2 + 672143*Zeta[3])))/14929920, 
      (CF*NC*(278834*NM + 8448*lm*NM - 41472*lm^2*NM - 43776*NL + 
         8448*lm*NL - 41472*lm^2*NL - 98416*NH + 8448*lm*NH - 
         41472*lm^2*NH + 3*CA*(2844110 + 81280*lm + 76032*lm^2 - 
           2429433*Zeta[3]) - 267435*NM*Zeta[3] + 98280*NH*Zeta[3] - 
         54*CF*(-782882 - 256*lm + 6912*lm^2 + 672143*Zeta[3])))/7464960, 
      (CF*NC*(-4*CA*(62761324642 + 164897280*lm + 68428800*lm^2 - 
           52306685955*Zeta[3]) + 5*(8*CF*(-62575014278 + 14598144*lm + 
             11197440*lm^2 + 52081756569*Zeta[3]) + 
           3*(12288*(98 + 307*lm + 270*lm^2)*NL + NH*(31696762 + 3772416*
                lm + 3317760*lm^2 - 30911895*Zeta[3]) + 
             NM*(-52807238 + 3772416*lm + 3317760*lm^2 + 51008265*
                Zeta[3])))))/16721510400, 
      -(CF*NC*(-16*CA*(60332488562 + 16028160*lm + 4561920*lm^2 - 
            50265962235*Zeta[3]) + 5*(-18079744*NL + 5947392*lm*NL + 
            2654208*lm^2*NL + 389231114*NH + 5947392*lm*NH + 
            2654208*lm^2*NH - 330492015*NH*Zeta[3] + 
            NM*(-467516570 + 5947392*lm + 2654208*lm^2 + 420085575*Zeta[
                3]) + 32*CF*(-61390513334 + 1797120*lm + 746496*lm^2 + 
              51065476353*Zeta[3]))))/33443020800, 
      -(CF*NC*(6960511587610*NM + 181566013440*lm*NM + 
          78033715200*lm^2*NM + 478506450944*NL + 181566013440*lm*NL + 
          78033715200*lm^2*NL - 5748414670390*NH + 181566013440*lm*NH + 
          78033715200*lm^2*NH + 210*CF*(333441881166718 + 8338784256*lm + 
            3344302080*lm^2 - 277365763283805*Zeta[3]) - 5659729338375*NM*
           Zeta[3] + 4701245936625*NH*Zeta[3] - 3*CA*(514949693440*lm + 
            143061811200*lm^2 + 27*(-58037419710898 + 48327327552875*Zeta[
                3]))))/65548320768000, 
      (CF*NC*(-(CA*(-9412606779993974 + 2398086512640*lm + 
            643778150400*lm^2 + 7834687704054225*Zeta[3])) + 
         2*(35*CF*(2316036455411950 + 39413661696*lm + 15049359360*lm^2 - 
             1926635002084485*Zeta[3]) + 3*(35*NM*(47382944558 + 1366867968*
                lm + 557383680*lm^2 - 36599703525*Zeta[3]) + 
             4*(4096*(7070998 + 2919945*lm + 1190700*lm^2)*NL + 105*NH*
                (-3035929470 + 113905664*lm + 46448640*lm^2 + 2485266525*
                  Zeta[3]))))))/65548320768000, 
      -(CF*NC*(-(CA*(-104305457362766308106 + 12710730048307200*lm + 
             3714599927808000*lm^2 + 86794294622130939375*Zeta[3])) + 
          2*(63*CF*(17174438884804199818 + 111716329881600*lm + 
              48241557504000*lm^2 - 14287314742708179375*Zeta[3]) + 
            10*(40960*(5266449941 + 1771807842*lm + 824440680*lm^2)*NL + 
              63*NM*(65693525288258 + 1151956336640*lm + 536017305600*lm^2 - 
                50709562855875*Zeta[3]) + 126*NH*(-21176817655406 + 
                575978168320*lm + 268008652800*lm^2 + 17491339837125*
                 Zeta[3])))))/389357025361920000, 
      (CF*NC*(504*CF*(8784246511787200318 + 14668863897600*lm + 
           9614868480000*lm^2 - 7307654538298960125*Zeta[3]) - 
         4*CA*(-45552232963541860286 + 1948368818995200*lm + 
           740344872960000*lm^2 + 37898571802899016125*Zeta[3]) + 
         5*(131072*(5303241691 + 1116512460*lm + 821583000*lm^2)*NL + 
           63*NM*(377161345022898 + 2322913034240*lm + 1709309952000*lm^2 - 
             298416539680875*Zeta[3]) + 63*NH*(-182691078089842 + 
             2322913034240*lm + 1709309952000*lm^2 + 152056029076875*
              Zeta[3]))))/389357025361920000, 
      -(CF*NC*(1232*CF*(43395739948603480776914 + 1177302623846400*lm + 
            17233021403136000*lm^2 - 36101246700112336078875*Zeta[3]) - 
          2376*CA*(-800237857520905021158 + 6412885973401600*lm + 
            5460669333504000*lm^2 + 665732872466425157625*Zeta[3]) + 
          15*(5242880*(166262754079 - 2950141194*lm + 29996352540*lm^2)*NL + 
            99*NM*(751135382543319202 - 156234709729280*lm + 
              1588558351564800*lm^2 - 609650022636529875*Zeta[3]) + 
            99*NH*(-243665009192831798 - 156234709729280*lm + 
              1588558351564800*lm^2 + 203743670009504625*Zeta[3]))))/
       2449834403577200640000, 
      (CF*NC*(2464*CF*(3946141846186699998578 - 1321665126359040*lm + 
           531392879001600*lm^2 - 3282827373027750638475*Zeta[3]) - 
         7920*CA*(-38155274681747410090 - 139533961814016*lm + 
           101030251069440*lm^2 + 31741250055154430175*Zeta[3]) + 
         3*(77*NM*(742812247001707462 - 1671384422154240*lm + 
             629798967705600*lm^2 - 612723510461687625*Zeta[3]) + 
           2*(32768*(1967395216817 - 1963754280180*lm + 739967659200*lm^2)*
              NL + 33*NH*(-172194655159724098 - 1949948492513280*lm + 
               734765462323200*lm^2 + 144276227308087875*Zeta[3])))))/
       244983440357720064000, 
      -(CF*NC*(208*CF*(7031525315686857767407122754 - 2139271706390864855040*
             lm + 290798525307735244800*lm^2 - 5849581537253954651540263875*
             Zeta[3]) - 264*CA*(-151906237487912138580425446 - 
            875155624896925532160*lm + 140014104777798451200*lm^2 + 
            126369676207762974906744825*Zeta[3]) + 
          3*(16777216*(-632667232949159 - 1004557985891460*lm + 
              133527855661200*lm^2)*NL + 143*NM*(-117857946250531307520*
               lm + 15665913821292134400*lm^2 + 1859*(29125885979835659986 - 
                24206494455845422875*Zeta[3])) + 429*NH*
             (-2053439021722976638894 - 39285982083510435840*lm + 
              5221971273764044800*lm^2 + 1720969806097185769125*Zeta[3]))))/
       21197927127272801697792000, CA*CF*NC*((71314171*lm)/5312427120 - 
         (19*lm^2)/26208 + (62785410037441275086202154 - 
           52230856900848729353625375*Zeta[3])/22304216253443604480000) + 
       (CF*NC*(832*CF*(29403899126846325774963258334 - 5931018551892639744000*
             lm + 302252296545239040000*lm^2 - 24461329078643120797862854125*
             Zeta[3]) + 15*(134217728*(-374460481654013 - 274651566789600*
               lm + 13878715851000*lm^2)*NL + 429*NM*
             (56869994678937798125554 - 85927993673986867200*lm + 
              4342120533983232000*lm^2 - 47381909816906250460875*Zeta[3]) + 
            1287*NH*(-1177571204427229151254 - 28642664557995622400*lm + 
              1447373511327744000*lm^2 + 986093358272544146625*Zeta[3]))))/
        211979271272728016977920000, 
      (CF*NC*(CA*(-1646929141311389368320593946496714 - 
           5345933100729551150697676800*lm + 44690786536130693038080000*
            lm^2 + 1370077669552541713836198342591375*Zeta[3]) + 
         CF*(-75363305912670218704436423711220332 + 
           8828777158643502062921318400*lm - 73130377968213861335040000*
            lm^2 + 62695299556477962606506419921025250*Zeta[3]) - 
         70*(268435456*(-98833954496431159 - 52278036842811780*lm + 
             432431567568000*lm^2)*NL + 143*NM*
            (109869933980675562176949154 - 98134815794999863541760*lm + 
             811748007195181056000*lm^2 - 91564180783538228692801875*
              Zeta[3]) + 143*NH*(-3594242814044718371103854 - 
             98134815794999863541760*lm + 811748007195181056000*lm^2 + 
             3005488777840400083357125*Zeta[3]))))/
       403608532503274144325959680000, 
      -(CF*NC*(-(CA*(333372120980938421560823724156106 + 
             665674341086475017256960000*lm + 12509969204129248051200000*
              lm^2 - 277332761629417191191685463647375*Zeta[3])) + 
          2*(CF*(-8460118730347317376213808212302646 + 
              533321637518255157411840000*lm + 10235429348833021132800000*lm^
                2 + 7038035510738448173283851796896625*Zeta[3]) + 
            10*(134217728*(104119404886266883 + 44009398472539500*lm + 
                847332125640000*lm^2)*NL + 286*NM*(
                -43337797475223483968047006 + 20653291865842384896000*lm + 
                397646827848990720000*lm^2 + 36101939326430225253130125*
                 Zeta[3]) + 143*NH*(41306583731684769792000*lm + 
                795293655697981440000*lm^2 - 2431*(-597698383563760489882 + 
                  498936507969807282375*Zeta[3]))))))/
       57658361786182020617994240000, 
      (CF*NC*(-(CA*(7626871080642766519325607826370333594 + 
            8773184468313116096953791283200*lm + 
            342326722843853349747425280000*lm^2 - 
            6344822539069264546579589274131538375*Zeta[3])) + 
         2*(17*CF*(-12557979122296404523808932462616425478 + 
             404015793005151459310200422400*lm + 
             16475617676976899185704960000*lm^2 + 
             10447075483329452644893909413026931625*Zeta[3]) + 
           45*(17017*NM*(-4201909750572942857826177314 + 
               989799969723252819886080*lm + 40639897576440594432000*lm^2 + 
               3498640753836094912372201875*Zeta[3]) + 
             4*(704643072*(17075781603014361791 + 5975871598713665220*lm + 
                 245361504476088000*lm^2)*NL + 12155*NH*
                (346429989403138486960128*lm + 14223964151754208051200*lm^2 - 
                 2431*(-5085647654174459064026 + 4237768163693655966375*
                    Zeta[3])))))))/949806193703776425640219115520000, 
      -(CF*NC*(-(CA*(2601354042461296773933619563408801298 + 
             1639882862207654336175852748800*lm + 
             93994921867275454887493632000*lm^2 - 
             2164079998500558741314120874544954875*Zeta[3])) + 
          34*CF*(-4701023926251903611947585470894616846 + 
            73921224800238753996708249600*lm + 4523819769013257187098624000*
             lm^2 + 3910816425402996354385390939879315125*Zeta[3]) + 
          15*(8589934592*(7336693518050821006 + 2145221064106114995*lm + 
              132635746415472300*lm^2)*NL + 109395*NH*
             (6397709947282094763559094 + 168447448476184165220352*lm + 
              10414848816399337390080*lm^2 - 5321990449682139999791025*Zeta[
                3]) + 7293*NM*(-23144275343175950147992579402 + 
              2526711727142762478305280*lm + 156222732245990060851200*lm^2 + 
              19263615520329151647932631375*Zeta[3]))))/
       237451548425944106410054778880000, 
      (CF*NC*(-40*CA*(28245736503664990221213624987167159408614 + 
           9337410292068975973190518796451840*lm + 
           719251763155020962186924969164800*lm^2 - 
           23497801484419329332022778604942397864825*Zeta[3]) + 
         304*CF*(-249514992966965361535484354698126665497014 + 
           1839159527728042248774234616627200*lm + 
           154862819818066714346467098624000*lm^2 + 
           207573359615417269535107864488630238904625*Zeta[3]) + 
         105*(2748779069440*(875561065383098925889 + 212218553900882069541*
              lm + 18123793394433346620*lm^2)*NL + 113373*NH*
            (5145333713578798277438996480*lm + 439419473256183689222553600*
              lm^2 - 4199*(-52002583238541303957496378 + 
               43191712041319603306920375*Zeta[3])) + 113373*NM*
            (5145333713578798277438996480*lm + 439419473256183689222553600*
              lm^2 + 323*(-334705767618636195945882967054 + 
               278520469018091467805003491125*Zeta[3])))))/
       76805128047662176882970678557409280000, 
      -(CF*NC*(-4*CA*(62312474006836699661266828093767772367162 + 
            10319324510934155249685988009574400*lm + 
            1050962861392522850727257702400000*lm^2 - 
            51838163438300438900828380243912675128375*Zeta[3]) + 
          3*(456*CF*(-13312096526513511704971876892940222275666 + 
              43812899002464845467318065561600*lm + 
              5028530437284798328838553600000*lm^2 + 
              11074431125589324480511107465684542614875*Zeta[3]) + 
            35*(17179869184*(18490782155264929636481 + 3621165779591154554760*
                 lm + 423716639782395960000*lm^2)*NL + 4199*NH*(
                744756752142099273362894786054 + 
                14815707165266352049131356160*lm + 
                1733602391651729654415360000*lm^2 - 
                617738245462335900944083667625*Zeta[3]) + 33592*NM*(
                -95430390457006287274152348448778 + 
                1851963395658294006141419520*lm + 216700298956466206801920000*
                 lm^2 + 79400463552945870758196810411375*Zeta[3])))))/
       12800854674610362813828446426234880000, 
      CA*CF*NC*((-1333459448423*lm)/668576475894600 - (268091*lm^2)/
          973496160 + (-1977440718301312825896542596744050038178976858 + 
           1645046767309908889289023288549257534333510375*Zeta[3])/
          77726789584234123005566326700098191360000) + 
       (CF*NC*(4*CF*(-78330215317325083129715186213380290535471311782 + 
            107467171782218322840303657976804147200*lm + 
            17513322545696084665339104706166784000*lm^2 + 
            65163483100241654558279076167263751279123897625*Zeta[3]) + 
          15015*(13*(687194767360*(2309555330160271610101 + 
                346406363118023858496*lm + 58027985701367663520*lm^2)*NL + 
              969*NH*(15877987586702085840991632547298 + 
                245664231284741062602774282240*lm + 
                41152247816739688303873228800*lm^2 - 
                13155259665823939564875409309875*Zeta[3])) + 
            969*NM*(-440279413068951060160894030712956406 + 
              3193635006701633813836065669120*lm + 
              534979221617615947950351974400*lm^2 + 
              366297338902763745265859776893812625*Zeta[3]))))/
        155453579168468246011132653400196382720000, 
      -(CF*NC*(-56*CA*(182381576024951840048199775352920598207824526 + 
            6215162430935130430198483884441600000*lm + 
            1248127555464537975022066102960128000*lm^2 - 
            151724541252902418274463981228519731423099125*Zeta[3]) + 
          16*CF*(-54654206727916552900325778227002503243332873758 + 
            27689403251028735787381286479331328000*lm + 
            7148366908569626584217287680589824000*lm^2 + 
            45467237273156081897490006541969211256187810125*Zeta[3]) + 
          1155*(769658139443200*(517379488258730946923 + 52992067242113791506*
               lm + 14295668147429124456*lm^2)*NL + 88179*NM*
             (-196872929191310799105243851933566666 + 
              462533889914993903292697804800*lm + 
              124777751487856719696809164800*lm^2 + 
              163785535643432418454620176535615375*Zeta[3]) + 
            12597*NH*(3237737229404957323048884633600*lm + 
              873444260414997037877664153600*lm^2 - 4199*(
                -73836799686959326742516682746 + 
                61121447944225632233683788375*Zeta[3])))))/
       310907158336936492022265306800392765440000, 
      (CF*NC*(-5*CA*(2208441999754908351681119141215424383871272492894 + 
           27730684111336611956018526948581286346752*lm + 
           9508330389896209813070479664389432541184*lm^2 - 
           1837218954499411958399051713907753713837766551341*Zeta[3]) + 
         46*CF*(-22145099736394537101796280031178142157338480981606 + 
           3061759880216833649145915638984736768000*lm + 
           1691205010060590678214116936353851637760*lm^2 + 
           18422671672416955641516492767493050636339434545465*Zeta[3]) + 
         693*(1649267441664*(246119345310877445544909071 + 
             12431369774991421656281880*lm + 7562880853834556665134720*lm^2)*
            NL + 7429*NM*(-5152404877272629269374977592182117252858 + 
             2759813356465106652658810308526080*lm + 
             1678989521794772808644821537259520*lm^2 + 
             4286390419831583174063412111235485276375*Zeta[3]) + 
           7429*NH*(2759813356465106652658810308526080*lm + 
             1678989521794772808644821537259520*lm^2 - 
             7429*(-75003535562694535493460218108062 + 
               62046863913141233863087187962125*Zeta[3])))))/
       263151818816383046847645355675852436668416000, 
      -(CF*NC*(-25*CA*(84638709775040415390127768110083240287532101258 + 
            231508446764024885525657324438597664768*lm + 
            229713700722223626536321979372659539968*lm^2 - 
            70411562384319173017614342729014232548625422127*Zeta[3]) + 
          2*(23*CF*(-4559675740313087206993386811468156476619014393194 - 
              20071092341403372607682192075862835200*lm + 
              204290840563242355615306108137740697600*lm^2 + 
              3793227856543334050367600978390906413116318971775*Zeta[3]) + 
            35*(7429*NM*(-12064895543572086211101997972138748045558 - 
                531913762529956576508918146007040*lm + 
                2007871055710279184385533521428480*lm^2 + 
                10036946130619876360733895263515766084625*Zeta[3]) + 
              2*(687194767360*(311980097779918608399036317 - 
                  2875158200793555738989928*lm + 10853163310728024269919936*
                   lm^2)*NL + 81719*NH*(-24177898296816208023132643000320*
                   lm + 91266866168649053835706069155840*lm^2 - 
                  7429*(-3855699429024960275199942415934 + 
                    3188249341572079828535951584125*Zeta[3])))))))/
       39871487699451976795097781163007944949760000}, 0, 22, 1]
 
CbarLSeries["a", 2, 2, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(4*CA*(59400*lm^2 - 24777*Pi^2 + 810*Pi^4 - 
            150*lm*(-1285 + 44*Pi^2) + 10*(16688 + 6294*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 6480*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              1049*PolyGamma[2, 1] - 17506*Zeta[3])) + 
          CF*(-1296625 - 777600*lm^2 - 39668*Pi^2 + 1200*Pi^4 + 
            86400*lm*(-11 + Pi^2) - 503520*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] - 518400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            83920*PolyGamma[2, 1] + 2015360*Zeta[3]) + 
          20*(NL*(-2365 - 2160*lm^2 - 12*Pi^2 + 60*lm*(-71 + 4*Pi^2) - 
              2880*Zeta[3]) + NM*(-2365 - 2160*lm^2 - 12*Pi^2 + 
              60*lm*(-71 + 4*Pi^2) + 240*PolyGamma[2, 1] - 2400*Zeta[3]) + 
            NH*(-33577 - 2160*lm^2 + 60*lm*(-71 + 4*Pi^2) - 
              598704*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 99784*PolyGamma[2, 
                1] + 1103888*Zeta[3]))))/7776000, 
      (CF*NC*(-3*CA*(1188000*lm^2 - 705684*Pi^2 + 25920*Pi^4 - 
           600*lm*(-3411 + 220*Pi^2) + 5*(-1150623 - 352032*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 414720*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 60112*PolyGamma[2, 1] + 519680*Zeta[3])) + 
         2*(-50*(NH*(1707363 - 6480*lm^2 + 36*lm*(-81 + 20*Pi^2) + 176208*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 29368*PolyGamma[2, 1] - 
               1734896*Zeta[3]) + 9*NL*(3219 - 720*lm^2 + 20*Pi^2 + 4*lm*
                (-81 + 20*Pi^2) - 960*Zeta[3]) + 9*NM*(3219 - 720*lm^2 + 20*
                Pi^2 + 4*lm*(-81 + 20*Pi^2) + 80*PolyGamma[2, 1] - 800*
                Zeta[3])) + 3*CF*(1944000*lm^2 + 200372*Pi^2 + 6720*Pi^4 - 
             21600*lm*(27 + 10*Pi^2) + 5*(601715 - 352032*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 414720*Im[PolyLog[2, 
                   (-1)^(1/3)]]^2 + 60112*PolyGamma[2, 1] + 79616*
                Zeta[3])))))/23328000, 
      -(CF*NC*(CF*(55987200*lm^2 + 11486484*Pi^2 - 1175040*Pi^4 + 
            777600*lm*(-121 + 4*Pi^2) + 5*(20635227 + 24276288*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 29859840*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 2882624*PolyGamma[2, 1] - 76519072*Zeta[3])) + 
          10*CA*(15306165 - 1710720*lm^2 - 915408*Pi^2 + 72576*Pi^4 - 
            2160*lm*(271 + 44*Pi^2) - 6069072*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 7464960*Im[PolyLog[2, (-1)^(1/3)]]^
              2 + 720656*PolyGamma[2, 1] + 16373824*Zeta[3]) + 
          240*(3*NL*(-28955 + 4320*lm^2 + 2508*Pi^2 + 60*lm*(-67 + 4*Pi^2) - 
              2880*Zeta[3]) + 3*NM*(-48935 + 4320*lm^2 + 4668*Pi^2 + 
              60*lm*(-67 + 4*Pi^2) + 600*PolyGamma[2, 1] - 1680*Zeta[3]) + 
            NH*(-2644341 + 12960*lm^2 + 180*lm*(-67 + 4*Pi^2) - 
              5906352*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1034284*PolyGamma[
                2, 1] + 12903128*Zeta[3]))))/69984000, 
      (CF*NC*(97977600*(-10*CA*(76 + 33*lm) + 9*CF*(227 + 120*lm) + 
           20*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         1959552000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         75600*Log[x]*(16*(-2*(27*NM*(122 + 204*lm + 45*lm^2 + 30*Pi^2) + 27*
                NL*(392 + 204*lm + 45*lm^2 + 30*Pi^2) + NH*(214710 + 
                 5508*lm + 1215*lm^2 - 122200*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) + 3*CF*(-68361 - 55161*lm - 14580*lm^2 + 
               351*Pi^2 + 5080*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 9720*
                Zeta[3])) + 3*CA*(767505 + 413856*lm + 71280*lm^2 + 
             4356*Pi^2 - 40640*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             77760*Zeta[3])) - 21*CA*(1122660000*lm^2 - 256264884*Pi^2 + 
           35560000*Sqrt[3]*Pi^3 + 12457800*Pi^4 - 243000*lm*
            (-13789 + 132*Pi^2) + 27432000*Sqrt[3]*Pi*Log[3]^2 + 
           15*(33966009 - 139877184*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             193622400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 87782400*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 27676976*
              PolyGamma[2, 1] + 172955584*Zeta[3])) + 
         10*(3*CF*(2571912000*lm^2 - 132966900*Pi^2 + 49784000*Sqrt[3]*Pi^3 + 
             10909080*Pi^4 - 24494400*lm*(-101 + 3*Pi^2) + 38404800*Sqrt[3]*
              Pi*Log[3]^2 + 21*(204458643 - 139877184*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 193622400*
                Im[PolyLog[2, (-1)^(1/3)]]^2 + 87782400*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 27676976*
                PolyGamma[2, 1] + 66434752*Zeta[3])) - 
           70*(729*NL*(465 - 8400*lm^2 - 4452*Pi^2 + 20*lm*(-719 + 
                 12*Pi^2) - 25920*Zeta[3]) + 729*NM*(51201 - 8400*lm^2 - 
               3492*Pi^2 + 20*lm*(-719 + 12*Pi^2) - 1520*PolyGamma[2, 1] + 
               5600*Zeta[3]) - NH*(-1045783521 + 6123600*lm^2 + 34216000*
                Sqrt[3]*Pi^3 - 14580*lm*(-719 + 12*Pi^2) - 206235504*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 1266969600*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 26395200*Sqrt[3]*Pi*
                Log[3]^2 + 52498008*PolyGamma[2, 1] + 212771376*Zeta[3])))))/
       4408992000, (CF*NC*(-11128678785*CF + 2608653600*CF*lm - 
         34610587200*CF*lm^2 + 18777594150*NM - 1297182600*lm*NM - 
         1922810400*lm^2*NM + 4665757950*NL - 1297182600*lm*NL - 
         1922810400*lm^2*NL + 249079771710*NH - 1297182600*lm*NH - 
         1922810400*lm^2*NH + 2541011472*CF*Pi^2 - 220449600*CF*lm*Pi^2 - 
         2436580440*NM*Pi^2 - 12247200*lm*NM*Pi^2 - 1371074040*NL*Pi^2 - 
         12247200*lm*NL*Pi^2 - 12247200*lm*NH*Pi^2 - 2029678000*Sqrt[3]*CF*
          Pi^3 - 5198900000*Sqrt[3]*NH*Pi^3 + 35789040*CF*Pi^4 - 
         19317401040*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
         304115202720*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
         87885907200*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 - 75156076800*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 192507840000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1565751600*Sqrt[3]*CF*Pi*
          Log[3]^2 - 4010580000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         97977600*(36*CF*(22 + 15*lm) - 5*CA*(76 + 33*lm) + 
           5*(13*NM + 6*lm*NM + 10*NL + 6*lm*NL + 6*lm*NH))*Log[x]^2 - 
         979776000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
         97868680*CF*PolyGamma[2, 1] - 968753520*NM*PolyGamma[2, 1] - 
         58509514560*NH*PolyGamma[2, 1] - 14*CA*(-755389800*lm^2 + 
           27013581*Pi^2 - 72488500*Sqrt[3]*Pi^3 + 1978020*Pi^4 - 
           36450*lm*(40357 + 132*Pi^2) - 55919700*Sqrt[3]*Pi*Log[3]^2 - 
           10*(-356372451 + 68990718*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             313878240*Im[PolyLog[2, (-1)^(1/3)]]^2 + 268414560*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             349531*PolyGamma[2, 1] - 414247738*Zeta[3])) + 
         153464982160*CF*Zeta[3] + 5557779360*NM*Zeta[3] - 
         5731689600*NL*Zeta[3] - 607984782720*NH*Zeta[3] - 
         37800*Log[x]*(CA*(-2123301 - 1059804*lm - 213840*lm^2 + 45576*Pi^2 + 
             331376*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 233280*Zeta[3]) + 
           2*(2*(27*NL*(2479 + 1326*lm + 360*lm^2 + 240*Pi^2) + 27*NM*
                (-371 + 1326*lm + 360*lm^2 + 420*Pi^2) + NH*(748479 + 
                 35802*lm + 9720*lm^2 - 424400*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) + CF*(1277391 + 1026432*lm + 349920*lm^2 - 
               61452*Pi^2 - 331376*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
               233280*Zeta[3])))))/2204496000, 
      (CF*NC*(524248263315*CF + 805081939200*CF*lm + 740710656000*CF*lm^2 - 
         407984850000*NM + 75589718400*lm*NM + 41150592000*lm^2*NM - 
         23594230800*NL + 75589718400*lm*NL + 41150592000*lm^2*NL - 
         9455055935472*NH + 75589718400*lm*NH + 41150592000*lm^2*NH - 
         121276922112*CF*Pi^2 - 13226976000*CF*lm*Pi^2 + 
         18064620000*NM*Pi^2 - 734832000*lm*NM*Pi^2 + 
         32944968000*NL*Pi^2 - 734832000*lm*NL*Pi^2 - 
         734832000*lm*NH*Pi^2 + 42816249000*Sqrt[3]*CF*Pi^3 + 
         386006320000*Sqrt[3]*NH*Pi^3 + 6784132320*CF*Pi^4 - 
         1011266645760*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         1901006486400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         1493766489600*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         1585424534400*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         14293262592000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         33029677800*Sqrt[3]*CF*Pi*Log[3]^2 + 297776304000*Sqrt[3]*NH*Pi*
          Log[3]^2 + 220449600*(-(CA*(6971 + 3300*lm)) + 
           3*CF*(6371 + 3600*lm) + 4*(400*NM + 150*lm*NM + 225*NL + 
             150*lm*NL + 4*NH + 150*lm*NH))*Log[x]^2 + 
         44089920000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 + 
         249099426240*CF*PolyGamma[2, 1] + 11236806000*NM*PolyGamma[2, 1] + 
         519160686800*NH*PolyGamma[2, 1] - 12*CA*(18860688000*lm^2 - 
           5546652876*Pi^2 + 1784010375*Sqrt[3]*Pi^3 + 331660980*Pi^4 - 
           2041200*lm*(-28733 + 165*Pi^2) + 1376236575*Sqrt[3]*Pi*Log[3]^2 - 
           70*(202234743 + 601944432*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             889146720*Im[PolyLog[2, (-1)^(1/3)]]^2 - 943705080*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 148273468*
              PolyGamma[2, 1] - 674201012*Zeta[3])) + 
         15120*Log[x]*(2*(2025*NL*(7493 + 3522*lm + 720*lm^2 + 600*Pi^2) + 
             405*NM*(23131 + 17610*lm + 3600*lm^2 + 840*Pi^2) + 
             NH*(277562649 + 7132050*lm + 1458000*lm^2 - 157553600*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) - 135*CF*(-2070665 - 
             1610280*lm - 388800*lm^2 + 34794*Pi^2 + 258904*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 259200*Zeta[3]) + 
           135*CA*(-1495069 - 732330*lm - 118800*lm^2 + 1257*Pi^2 + 
             129452*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 129600*Zeta[3])) + 
         397688531520*CF*Zeta[3] - 383153652000*NM*Zeta[3] + 
         229267584000*NL*Zeta[3] - 302012194400*NH*Zeta[3]))/6613488000, 
      (CF*NC*(-24494400*(-21*CA*(10083 + 3520*lm) + 
           4*(5*CF*(22919 + 12096*lm) + 4*(3493*NM + 840*lm*NM + 1200*NL + 
               840*lm*NL + 27*NH + 840*lm*NH)))*Log[x]^2 - 
         7838208000*(109*CA + 844*CF - 38*NM - 28*NL)*Log[x]^3 - 
         3*CF*(539660620800*lm^2 - 62610256368*Pi^2 + 63522816000*Sqrt[3]*
            Pi^3 + 3757440960*Pi^4 + 195955200*lm*(341 + 6*Pi^2) + 
           49003315200*Sqrt[3]*Pi*Log[3]^2 + 35*(2567427705 + 
             5233640256*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             45853516800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 67204546560*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2745879104*
              PolyGamma[2, 1] - 94714878848*Zeta[3])) + 
         24*CA*(20612037600*lm^2 - 1843751079*Pi^2 + 3970176000*Sqrt[3]*
            Pi^3 + 228308220*Pi^4 + 340200*lm*(130055 + 132*Pi^2) + 
           3062707200*Sqrt[3]*Pi*Log[3]^2 + 140*(-660954546 + 
             81775629*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             716461200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1050071040*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 42904361*
              PolyGamma[2, 1] - 1157591174*Zeta[3])) + 
         15120*Log[x]*(-16*(405*NL*(9279 + 4343*lm + 1080*lm^2 + 920*Pi^2) + 
             135*NM*(7858 + 13029*lm + 3240*lm^2 + 4800*Pi^2) + 
             NH*(38344449 + 1758915*lm + 437400*lm^2 - 21604400*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) + 45*CF*(-10787961 - 
             9157536*lm - 2799360*lm^2 + 109512*Pi^2 + 3457024*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 1866240*Zeta[3]) + 
           180*CA*(2292009 + 1132074*lm + 213840*lm^2 + 9108*Pi^2 - 
             432128*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 233280*Zeta[3])) - 
         224*(1215*NM*(-2948630 + 330480*lm^2 + 666204*Pi^2 + 
             60*lm*(4813 + 12*Pi^2) + 428661*PolyGamma[2, 1] - 
             3557718*Zeta[3]) + 14580*NL*(-85790 + 27540*lm^2 + 25852*Pi^2 + 
             5*lm*(4813 + 12*Pi^2) + 164880*Zeta[3]) + 
           NH*(-61544736774 + 401533200*lm^2 + 1890385000*Sqrt[3]*Pi^3 + 
             72900*lm*(4813 + 12*Pi^2) - 55920236880*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 69998256000*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] + 1458297000*Sqrt[3]*Pi*Log[3]^2 + 
             11635066295*PolyGamma[2, 1] + 97775098990*Zeta[3]))))/
       19840464000, (CF*NC*(128595600*(-21*CA*(412451 + 203500*lm) + 
           35*CF*(693263 + 399600*lm) - 455084*NM + 777000*lm*NM + 
           1098300*NL + 777000*lm*NL + 46332*NH + 777000*lm*NH)*
          Log[x]^2 + 90016920000*(5129*CA + 22472*CF - 4504*NM - 740*NL)*
          Log[x]^3 + 3780*Log[x]*(2*(39302089785*NL + 16507269450*lm*NL + 
             3214890000*lm^2*NL + 682391437737*NH + 16507269450*lm*NH + 
             3214890000*lm^2*NH + 3274425000*NL*Pi^2 + 
             19845*NM*(1236659 + 831810*lm + 162000*lm^2 - 452280*Pi^2) - 
             386534814400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
             735*CF*(-442791984 - 345210660*lm - 78732000*lm^2 + 9591453*
                Pi^2 + 73162220*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 52488000*
                Zeta[3])) + 735*CA*(-653669490 - 308283570*lm - 
             48114000*lm^2 + 2301129*Pi^2 + 73162220*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 52488000*Zeta[3])) - 
         735*CA*(127309644000*lm^2 - 57893623209*Pi^2 + 22405929875*Sqrt[3]*
            Pi^3 + 3230199000*Pi^4 - 2041200*lm*(-196552 + 825*Pi^2) + 
           17284574475*Sqrt[3]*Pi*Log[3]^2 + 14*(-23332084785 - 
             24557531610*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             36374184000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 59261398200*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 7030525364*
              PolyGamma[2, 1] + 24299403748*Zeta[3])) + 
         2*(-2*(-(NH*(-1354887135169821 + 4253299470000*lm^2 + 
                59188143455000*Sqrt[3]*Pi^3 - 750141000*lm*(-10652 + 
                  75*Pi^2) - 266973965827800*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 2191652397648000*Sqrt[3]*Im[PolyLog[3, 
                   -((-1)^(5/6)/Sqrt[3])]] + 45659424951000*Sqrt[3]*Pi*
                 Log[3]^2 + 74485885187875*PolyGamma[2, 1] - 170804336232250*
                 Zeta[3])) + 18753525*NL*(514729 - 226800*lm^2 - 238900*
                Pi^2 + 40*lm*(-10652 + 75*Pi^2) - 2016000*Zeta[3]) + 
             6251175*NM*(12488993 - 680400*lm^2 + 961446*Pi^2 + 120*lm*
                (-10652 + 75*Pi^2) + 1227249*PolyGamma[2, 1] + 14490018*
                Zeta[3])) + 735*CF*(208324872000*lm^2 - 62651889315*Pi^2 + 
             22405929875*Sqrt[3]*Pi^3 + 2985255000*Pi^4 - 18370800*lm*
              (-12799 + 150*Pi^2) + 17284574475*Sqrt[3]*Pi*Log[3]^2 + 
             28*(-2328658650 - 12278765805*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 18187092000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
               29630699100*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
               3515262682*PolyGamma[2, 1] + 2912076314*Zeta[3])))))/
       729137052000, (CF*NC*(-771573600*(-21*CA*(1220673 + 295130*lm) + 
           7*CF*(7742231 + 2897640*lm) + 7940744*NM + 1126860*lm*NM + 
           1485645*NL + 1126860*lm*NL + 80568*NH + 1126860*lm*NH)*
          Log[x]^2 - 108020304000*(4805*CA + 240545*CF - 10876*NM - 
           5366*NL)*Log[x]^3 - 49*CF*(48480173784000*lm^2 + 
           10010590551270*Pi^2 + 8991238952500*Sqrt[3]*Pi^3 + 
           672343723800*Pi^4 + 413343000*lm*(22927 + 120*Pi^2) + 
           6936098620500*Sqrt[3]*Pi*Log[3]^2 + 7*(-114651937197 + 
             1703672100600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             23919096528000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 47561819112000*
              Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             4630680773000*PolyGamma[2, 1] - 61545443841200*Zeta[3])) + 
         49*CA*(14813386434000*lm^2 + 7128624094875*Pi^2 + 
           4495619476250*Sqrt[3]*Pi^3 + 333967365900*Pi^4 + 
           57408750*lm*(572371 + 264*Pi^2) + 3468049310250*Sqrt[3]*Pi*
            Log[3]^2 + 7*(-10362876613911 + 851836050300*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 11959548264000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 23780909556000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2315340386500*
              PolyGamma[2, 1] - 25112733553000*Zeta[3])) - 
         3780*Log[x]*(6*(297675*NL*(313339 + 128180*lm + 30240*lm^2 + 31544*
                Pi^2) + 15876*NM*(10336246 + 2403375*lm + 567000*lm^2 + 
               793650*Pi^2) + 2*NH*(445996251453 + 19077990750*lm + 
               4500846000*lm^2 - 250204682000*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]])) - 98*CA*(39507304866 + 16706310750*lm + 
             3031182000*lm^2 + 1785528765*Pi^2 - 7339786900*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 3306744000*Zeta[3]) + 
           49*CF*(98810016189 + 69218550000*lm + 19840464000*lm^2 + 
             5289784380*Pi^2 - 29359147600*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 13226976000*Zeta[3])) - 
         3*(500094*NM*(-951597133 + 87966000*lm^2 + 368040900*Pi^2 + 
             750*lm*(110893 + 120*Pi^2) + 194575680*PolyGamma[2, 1] - 
             1840400640*Zeta[3]) + 18753525*NL*(-11918541 + 2345760*lm^2 + 
             2746360*Pi^2 + 20*lm*(110893 + 120*Pi^2) + 22682880*Zeta[3]) + 
           2*NH*(-4234161912808941 + 21995634402000*lm^2 + 
             153250367725000*Sqrt[3]*Pi^3 + 187535250*lm*(110893 + 120*
                Pi^2) - 3236024624120400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             5674642187760000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             118221712245000*Sqrt[3]*Pi*Log[3]^2 + 713118481856760*
              PolyGamma[2, 1] + 4939957418993520*Zeta[3]))))/8749644624000, 
      (CF*NC*(-18517766400*(7*CA*(18958169 + 10959300*lm) - 
           2*(14*CF*(14010481 + 8966700*lm) + 126*(-821201 + 55350*lm)*NM + 
             15*(634347*NL + 464940*lm*NL + 43228*NH + 464940*lm*NH)))*
          Log[x]^2 + 5184974592000*(256388*CA + 1234411*CF - 
           54*(9652*NM + 615*NL))*Log[x]^3 - 
         147*CA*(1032299341920000*lm^2 - 912941305019280*Pi^2 + 
           282644930120000*Sqrt[3]*Pi^3 + 34632632160000*Pi^4 - 
           54561276000*lm*(-59977 + 200*Pi^2) + 218040374664000*Sqrt[3]*Pi*
            Log[3]^2 - 21*(221302340452527 + 160790440544000*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 230829626880000*
              Im[PolyLog[2, (-1)^(1/3)]]^2 - 498377999232000*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 45990205828480*
              PolyGamma[2, 1] - 145200892194560*Zeta[3])) + 
         45360*Log[x]*(2*(-36*(23814*NM*(7644757 - 3343350*lm - 
                 630000*lm^2 + 7784700*Pi^2) - 5*(11907*NL*(3555217 + 
                   1337340*lm + 252000*lm^2 + 305400*Pi^2) + 2*NH*
                  (356838317403 + 7961853690*lm + 1500282000*lm^2 - 
                   201843649840*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) - 
             49*CF*(-1015224495753 - 904111048800*lm - 198404640000*lm^2 + 
               40859166960*Pi^2 + 230730555200*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] - 132269760000*Zeta[3])) + 
           49*CA*(-1594641165573 - 797762487600*lm - 121247280000*lm^2 + 
             19874347920*Pi^2 + 230730555200*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 132269760000*Zeta[3])) + 
         2*(147*CF*(-2179811921179977 + 1689217104960000*lm^2 - 
             1000773954745200*Pi^2 + 282644930120000*Sqrt[3]*Pi^3 + 
             33045395040000*Pi^4 - 89282088000*lm*(-21707 + 200*Pi^2) - 
             3376599251424000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             4847422164480000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             10465937983872000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] + 218040374664000*Sqrt[3]*Pi*Log[3]^2 + 
             965794322398080*PolyGamma[2, 1] + 421023895676160*Zeta[3]) - 
           8*(5*(-2*NH*(-74291576715049671 + 172440912798000*lm^2 + 
                 3337989359229000*Sqrt[3]*Pi^3 - 9114213150*lm*(-35897 + 
                   200*Pi^2) - 14407505454741840*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]] + 123600977416022400*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2575020362833800*
                  Sqrt[3]*Pi*Log[3]^2 + 4015659976768160*PolyGamma[2, 1] - 
                 12717587307817280*Zeta[3]) + 101269035*NL*(16960223 - 
                 3405600*lm^2 - 4432200*Pi^2 + 180*lm*(-35897 + 200*Pi^2) - 
                 44409600*Zeta[3])) + 243045684*NM*(116915037 - 7095000*
                lm^2 + 97677650*Pi^2 + 375*lm*(-35897 + 200*Pi^2) + 110414100*
                PolyGamma[2, 1] + 256108200*Zeta[3])))))/419982941952000, 
      (7444505831470526257*CF^2*NC)/3499857849600000 - 
       (244021*CF^2*lm*NC)/1500 - (3532*CF^2*lm^2*NC)/5 + 
       (111315380891*CF*NM*NC)/138915000 - (1038721*CF*lm*NM*NC)/27000 - 
       (1766*CF*lm^2*NM*NC)/45 + (171286871*CF*NC*NL)/540000 - 
       (1038721*CF*lm*NC*NL)/27000 - (1766*CF*lm^2*NC*NL)/45 + 
       (3453048386484353*CF*NC*NH)/364568526000 - (1038721*CF*lm*NC*NH)/
        27000 - (1766*CF*lm^2*NC*NH)/45 - (1784814317*CF^2*NC*Pi^2)/
        1008000 - (2*CF^2*lm*NC*Pi^2)/5 - (1634401*CF*NM*NC*Pi^2)/2700 - 
       (CF*lm*NM*NC*Pi^2)/45 - (148801*CF*NC*NL*Pi^2)/2700 - 
       (CF*lm*NC*NL*Pi^2)/45 - (CF*lm*NC*NH*Pi^2)/45 - 
       (13246683296*CF^2*NC*Pi^3)/(23914845*Sqrt[3]) - 
       (3591053669*CF*NC*NH*Pi^3)/(3188646*Sqrt[3]) - 
       (4681*CF^2*NC*Pi^4)/324 - (289910829199*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(797161500*Sqrt[3]) + 
       (51590556071*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) - 
       (41804*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (30278133248*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1476225*Sqrt[3]) - (4104061336*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(98415*Sqrt[3]) - 
       (1892383328*CF^2*NC*Pi*Log[3]^2)/(4428675*Sqrt[3]) - 
       (513007667*CF*NC*NH*Pi*Log[3]^2)/(590490*Sqrt[3]) - 
       (CF*NC*(-10*CA*(2091576439 + 252640080*lm) + 
          CF*(43033198193 + 8268220800*lm) + 
          240*(18*(1936967 + 106330*lm)*NM + 21*(114493 + 91140*lm)*NL + 
            620*(338 + 3087*lm)*NH))*Log[x]^2)/1134000 + 
       (CF*NC*(4676770*CA - 39740287*CF + 2520*(40*NM + 217*NL))*Log[x]^3)/
        2025 - (2768900851949*CF^2*NC*PolyGamma[2, 1])/1434890700 - 
       (134483*CF*NM*NC*PolyGamma[2, 1])/900 - 
       (35547899993*CF*NC*NH*PolyGamma[2, 1])/23914845 + 
       (CA*CF*NC*(-6958423154774594997 + 679882385863296000*lm^2 + 
          2915414962592766480*Pi^2 + 290791191713792000*Sqrt[3]*Pi^3 + 
          22697939210486400*Pi^4 + 58330964160*lm*(26260331 + 6600*Pi^2) + 
          190923675677293440*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          4389241726340352000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          10767582413173555200*Sqrt[3]*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]] + 224324633607782400*Sqrt[3]*Pi*
           Log[3]^2 + 3039145575099222400*PolyGamma[2, 1] - 
          11831630197325612800*Zeta[3]))/3149872064640000 + 
       (12847241498831*CF^2*NC*Zeta[3])/1434890700 + 
       (700717*CF*NM*NC*Zeta[3])/450 - (8312*CF*NC*NL*Zeta[3])/15 - 
       (207999253114*CF*NC*NH*Zeta[3])/23914845 - 
       (CF*NC*Log[x]*(480*(964467*NL*(4091833 + 1475340*lm + 336000*lm^2 + 
              415800*Pi^2) + 13122*NM*(2132039807 + 108437490*lm + 
              24696000*lm^2 + 81099900*Pi^2) + 10*NH*(3594545907945 + 
              142291674378*lm + 32406091200*lm^2 - 2010990054640*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) - 10*CA*(2146059920310321 + 
            484534486789920*lm + 85552080768000*lm^2 + 205972832756880*Pi^2 - 
            237380564664320*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            93329542656000*Zeta[3]) + CF*(33806176011704193 + 
            10194085956499200*lm + 2799886279680000*lm^2 + 3804641638182000*
             Pi^2 - 4747611293286400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            1866590853120000*Zeta[3])))/2083248720000, 
      (CF*NC*(-50414619024000*(11*CA*(766464137 + 2631598200*lm) - 
           2*(11*CF*(2959286699 + 4306251600*lm) + 
             90*(22*(-90804121 + 1329090*lm)*NM + 385*(101287 + 75948*lm)*
                NL + 4*(907048 + 7309995*lm)*NH)))*Log[x]^2 + 
         310554053187840000*(6191218*CA + 22424969*CF - 
           90*(269744*NM + 6329*NL))*Log[x]^3 + 166320*Log[x]*
          (2*(-100*(-1750507605*NL*(11311465 + 3834684*lm + 705600*lm^2 + 
                 994680*Pi^2) + 71449290*NM*(2670634471 - 93949758*lm - 
                 17287200*lm^2 + 768671820*Pi^2) - 2*NH*
                (164024394077081271 + 3356321752385910*lm + 617579083044000*
                  lm^2 - 92698379732882000*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) - 363*CF*(-6890873788028283 - 
               28692272133252000*lm - 6124751236800000*lm^2 + 
               3713825689421400*Pi^2 + 8434707848610400*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 4083167491200000*Zeta[3])) + 
           363*CA*(-26067051944743443 - 25105039360254000*lm - 
             3742903533600000*lm^2 + 2978791757587800*Pi^2 + 
             8434707848610400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             4083167491200000*Zeta[3])) - 3993*CA*(-124812240116398945371 + 
           26713102519303200000*lm^2 - 77023314392705503200*Pi^2 + 
           10332517114547740000*Sqrt[3]*Pi^3 + 1119138364465128000*Pi^4 - 
           2187411156000*lm*(-38829107 + 107800*Pi^2) - 105445910417889115200*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 143973302373210240000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 382598348012967744000*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 7970798916936828000*
            Sqrt[3]*Pi*Log[3]^2 + 9678443132008784000*PolyGamma[2, 1] + 
           107158553162715712000*Zeta[3]) + 
         2*(363*CF*(480835845347457600000*lm^2 - 884690192643146971200*Pi^2 + 
             113657688260025140000*Sqrt[3]*Pi^3 + 11933237332929528000*Pi^4 - 
             433107408888000*lm*(-1284287 + 9800*Pi^2) + 87678788086305108000*
              Sqrt[3]*Pi*Log[3]^2 - 11*(47957175159134314761 + 
               105445910417889115200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               143973302373210240000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
               382598348012967744000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                    Sqrt[3])]] - 9678443132008784000*PolyGamma[2, 1] - 
               22528105517174656000*Zeta[3])) - 
           200*(-2*NH*(-13708495089910587580011 + 24242140536267654000*
                lm^2 + 624555333450292475000*Sqrt[3]*Pi^3 - 21835831864770*lm*
                (-2116937 + 9800*Pi^2) - 2637934550371445463600*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 23126391775759401360000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 481799828661654195000*
                Sqrt[3]*Pi*Log[3]^2 + 725858919782265623200*PolyGamma[2, 1] - 
               2677210873412082145600*Zeta[3]) + 3639305310795*NL*
              (115651209 - 13322400*lm^2 - 20618360*Pi^2 + 12*lm*
                (-2116937 + 9800*Pi^2) - 240134400*Zeta[3]) + 
             8488175652*NM*(-516147484988 - 5711979000*lm^2 + 464378113150*
                Pi^2 + 5145*lm*(-2116937 + 9800*Pi^2) + 501398874900*
                PolyGamma[2, 1] + 376902325800*Zeta[3])))))/
       125774391541075200000, (50921182200694591379*CF^2*NC)/
        1259948825856000 - (21162199*CF^2*lm*NC)/54000 - 
       (15673*CF^2*lm^2*NC)/10 + (568985006080079*CF*NM*NC)/67512690000 - 
       (84637849*CF*lm*NM*NC)/972000 - (15673*CF*lm^2*NM*NC)/180 + 
       (61290059027*CF*NC*NL)/58320000 - (84637849*CF*lm*NC*NL)/972000 - 
       (15673*CF*lm^2*NC*NL)/180 + (680853101121399003967*CF*NC*NH)/
        26202998237724000 - (84637849*CF*lm*NC*NH)/972000 - 
       (15673*CF*lm^2*NC*NH)/180 - (690936091609*CF^2*NC*Pi^2)/27216000 - 
       (49*CF^2*lm*NC*Pi^2)/90 - (800507099*CF*NM*NC*Pi^2)/97200 - 
       (49*CF*lm*NM*NC*Pi^2)/1620 - (1540651*CF*NC*NL*Pi^2)/10800 - 
       (49*CF*lm*NC*NL*Pi^2)/1620 - (49*CF*lm*NC*NH*Pi^2)/1620 - 
       (5582327987467*CF^2*NC*Pi^3)/(3443737680*Sqrt[3]) - 
       (1127093280523*CF*NC*NH*Pi^3)/(344373768*Sqrt[3]) - 
       (341509*CF^2*NC*Pi^4)/8100 - (735205745747*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1793613375*Sqrt[3]) + 
       (14146876168927*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (286978140*Sqrt[3]) - (34804*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (797475426781*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (13286025*Sqrt[3]) - (322026651578*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (797475426781*CF^2*NC*Pi*Log[3]^2)/(637729200*Sqrt[3]) - 
       (161013325789*CF*NC*NH*Pi*Log[3]^2)/(63772920*Sqrt[3]) - 
       (CF*NC*(-33*CA*(200905338427 + 8070724200*lm) + 
          33*CF*(405711112253 + 26413279200*lm) + 
          20*(22*(8484828217 + 110055330*lm)*NM + 693*(4250969 + 3493820*lm)*
             NL + 10*(34895983 + 242121726*lm)*NH))*Log[x]^2)/37422000 + 
       (CF*NC*(79947627*CA - 272553236*CF - 32716900*NM + 1746910*NL)*
         Log[x]^3)/2025 - (1082820423146239*CF^2*NC*PolyGamma[2, 1])/
        51656065200 - (3285113*CF*NM*NC*PolyGamma[2, 1])/1800 - 
       (10044082229951*CF*NC*NH*PolyGamma[2, 1])/2582803260 + 
       (CA*CF*NC*(-816674280927724158327 + 16970231048754060000*lm^2 + 
          453647925261805724100*Pi^2 + 9573692498505905000*Sqrt[3]*Pi^3 + 
          746163131301252000*Pi^4 + 18228426300*lm*(2115895139 + 
            323400*Pi^2) + 2420885479595721600*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 123331665754946880000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 354500156516104368000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 7385419927418841000*
           Sqrt[3]*Pi*Log[3]^2 + 371407405139159977000*PolyGamma[2, 1] - 
          448163148151852126000*Zeta[3]))/35436060727200000 + 
       (151078549505821*CF^2*NC*Zeta[3])/5165606520 + 
       (9389287*CF*NM*NC*Zeta[3])/900 - (75854*CF*NC*NL*Zeta[3])/45 - 
       (25362522555419*CF*NC*NH*Zeta[3])/1291401630 + 
       CF*Log[x]*((-4457914855621*NM*NC)/53581500 - (2383241*lm*NM*NC)/
          2700 - 196*lm^2*NM*NC - (445404307*NC*NL)/162000 - 
         (2383241*lm*NC*NL)/2700 - 196*lm^2*NC*NL - 
         (45580467425855557*NC*NH)/1890548213400 - (2383241*lm*NC*NH)/
          2700 - 196*lm^2*NC*NH - (3910913*NM*NC*Pi^2)/810 - 
         (227611*NC*NL*Pi^2)/810 + (322026651578*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-1123490185908627121/6249746160000 - (1986341*lm)/150 - 
           3528*lm^2 - (357662623*Pi^2)/16200 + 
           (797475426781*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) - 
           2352*Zeta[3]) + CA*NC*(300155735043860053/3124873080000 + 
           (33624451*lm)/5400 + 1078*lm^2 + (15215209*Pi^2)/1350 - 
           (797475426781*Im[PolyLog[2, (-1)^(1/3)]])/(79716150*Sqrt[3]) + 
           1176*Zeta[3])), 
      (CF*NC*(-170401412301120*(4719*CA*(-5874363331 + 851361000*lm) - 
           50*(429*CF*(-2271398483 + 612979920*lm) + 
             2*(143*(-14662055621 + 51081660*lm)*NM + 45045*(212915 + 
                 162164*lm)*NL + (1112290547 + 7304677380*lm)*NH)))*
          Log[x]^2 + 10234308822805267200*(213607773*CA + 137757830*CF - 
           1132896200*NM - 8108200*NL)*Log[x]^3 + 1945944*Log[x]*
          (-20*(10*(-6574128561*NL*(114185121 + 35135940*lm + 6350400*lm^2 + 
                 10225000*Pi^2) + 4969107*NM*(8144318842357 - 46484848620*
                  lm - 8401579200*lm^2 + 1487651583600*Pi^2) - 20*NH*
                (615389070053760546 + 11549409333579117*lm + 2087417300688720*
                  lm^2 - 347611155987215120*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]])) + 20449*CF*(7848974194364103 - 
               1757633472982800*lm - 367485074208000*lm^2 + 1064181153451500*
                Pi^2 + 579644576075600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               244990049472000*Zeta[3])) + 20449*CA*(66268928715569673 - 
             15283617279966000*lm - 2245742120160000*lm^2 + 10147130109030600*
              Pi^2 + 5796445760756000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             2449900494720000*Zeta[3])) - 
         5*(-797511*CF*(29832438324205440000*lm^2 - 280476091198335926880*
              Pi^2 + 9372852795142452000*Sqrt[3]*Pi^3 + 897443466058339200*
              Pi^4 - 1924921817280*lm*(-18008549 + 117600*Pi^2) + 
             7230486441967034400*Sqrt[3]*Pi*Log[3]^2 - 
             11*(-23760246534648008517 + 7841962330263458880*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 10080850555673856000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 31551213564947059200*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 9253370636688174080*
                PolyGamma[2, 1] - 10580124666367370240*Zeta[3])) + 
           32*(-(NH*(-29838630183781086504493929 + 41305030764540633090000*
                 lm^2 + 1370087645626359194535000*Sqrt[3]*Pi^3 - 
                2665184589272205*lm*(-29632049 + 117600*Pi^2) - 
                5735133855853858279824000*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 50732388249478900460496000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                1056924755197477092927000*Sqrt[3]*Pi*Log[3]^2 + 
                1547978993774714211460750*PolyGamma[2, 1] - 
                6238396888922457605846500*Zeta[3])) + 888394863090735*NL*
              (621578591 - 46494000*lm^2 - 83357820*Pi^2 + lm*(-88896147 + 
                 352800*Pi^2) - 1108533600*Zeta[3]) + 95928610635*NM*
              (-359340395928842 - 430580934000*lm^2 + 196010418587760*Pi^2 + 
               27783*lm*(-29632049 + 117600*Pi^2) + 202238731234890*
                PolyGamma[2, 1] + 79313543143380*Zeta[3])) + 
           6380088*CA*(1139433408216180000*lm^2 - 17339768200630396647*Pi^2 + 
             585803299696403250*Sqrt[3]*Pi^3 + 57347832215935800*Pi^4 - 
             6683756310*lm*(-542924539 + 1293600*Pi^2) + 451905402622939650*
              Sqrt[3]*Pi*Log[3]^2 - 44*(122530661410366545*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 157513289932404000*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 4*(70155194045088591 + 
                 123246927988074450*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                      Sqrt[3])]] - 36145979049563180*PolyGamma[2, 1] + 
                 66573422961627575*Zeta[3]))))))/20724475366180666080000, 
      (764200015574245470609559*CF^2*NC)/1375657407480510000 - 
       (134825431*CF^2*lm*NC)/165375 - (15536*CF^2*lm^2*NC)/5 + 
       (1612276644670089383*CF*NM*NC)/11232423798750 - 
       (520215331*CF*lm*NM*NC)/2976750 - (7768*CF*lm^2*NM*NC)/45 + 
       (131240574347*CF*NC*NL)/44651250 - (520215331*CF*lm*NC*NL)/2976750 - 
       (7768*CF*lm^2*NC*NL)/45 + (50133009967390772047979*CF*NC*NH)/
        799555376781661500 - (520215331*CF*lm*NC*NH)/2976750 - 
       (7768*CF*lm^2*NC*NH)/45 - (41121421314371*CF^2*NC*Pi^2)/130977000 - 
       (32*CF^2*lm*NC*Pi^2)/45 - (5012171228*CF*NM*NC*Pi^2)/42525 - 
       (16*CF*lm*NM*NC*Pi^2)/405 - (4581926*CF*NC*NL*Pi^2)/14175 - 
       (16*CF*lm*NC*NL*Pi^2)/405 - (16*CF*lm*NC*NH*Pi^2)/405 - 
       (872759944408*CF^2*NC*Pi^3)/(215233605*Sqrt[3]) - 
       (353813377316*CF*NC*NH*Pi^3)/(43046721*Sqrt[3]) - 
       (209404*CF^2*NC*Pi^4)/2025 + (91836333888053*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(527322332250*Sqrt[3]) + 
       (896636394352*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (7971615*Sqrt[3]) - (76736*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (13964159110528*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (93002175*Sqrt[3]) - (808716291008*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (872759944408*CF^2*NC*Pi*Log[3]^2)/(279006525*Sqrt[3]) - 
       (50544768188*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-39*CA*(21287635628689 + 209395678800*lm) + 
          39*CF*(42677635390469 + 685294948800*lm) + 
          280*(13*(165793341169 + 407913660*lm)*NM + 
            19*(9009*(36851 + 30980*lm)*NL + 5*(9778247 + 55819764*lm)*
               NH)))*Log[x]^2)/425675250 + 
       (4*CF*NC*(1787641761*CA - 56*(74644408*CF + 20557025*NM - 
            147155*NL))*Log[x]^3)/14175 - (2266551560616953*CF^2*NC*
         PolyGamma[2, 1])/9685512225 - (48821033*CF*NM*NC*PolyGamma[2, 1])/
        1350 - (175677196163659*CF*NC*NH*PolyGamma[2, 1])/19371024450 + 
       CA*CF*NC*(-488576012229959143318597/1719571759350637500 + 
         (42724*lm^2)/45 + (2745816583159*Pi^2)/17463600 + 
         (436379972204*Pi^3)/(215233605*Sqrt[3]) + (104638*Pi^4)/2025 + 
         lm*(12916313441/5953500 + (88*Pi^2)/405) - 
         (91836333888053*Im[PolyLog[2, (-1)^(1/3)]])/(1054644664500*
           Sqrt[3]) + (38368*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (6982079555264*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (93002175*Sqrt[3]) + (436379972204*Pi*Log[3]^2)/
          (279006525*Sqrt[3]) + (2266551560616953*PolyGamma[2, 1])/
          19371024450 - (3698775126228673*Zeta[3])/67798585575) + 
       (8046376890753854*CF^2*NC*Zeta[3])/67798585575 + 
       (71608567*CF*NM*NC*Zeta[3])/675 - (197264*CF*NC*NL*Zeta[3])/45 - 
       (389788907955019*CF*NC*NH*Zeta[3])/9685512225 + 
       CF*Log[x]*((-240578948191102*NM*NC)/231548625 - (3238876*lm*NM*NC)/
          1575 - 448*lm^2*NM*NC - (504902984*NC*NL)/70875 - 
         (3238876*lm*NC*NL)/1575 - 448*lm^2*NC*NL - 
         (2420472254551633577*NC*NH)/39937831008075 - (3238876*lm*NC*NH)/
          1575 - 448*lm^2*NC*NH - (33720784*NM*NC*Pi^2)/405 - 
         (295928*NC*NL*Pi^2)/405 + (808716291008*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CF*NC*(-177244996451434349857/82711484336250 - (5419352*lm)/175 - 
           8064*lm^2 - (733931728*Pi^2)/2835 + 
           (13964159110528*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) - 
           5376*Zeta[3]) + CA*NC*(5135045572236882143/4726370533500 + 
           (22753018*lm)/1575 + 2464*lm^2 + (614467262*Pi^2)/4725 - 
           (6982079555264*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) + 
           2688*Zeta[3])), (36565427443281367995525307*CF^2*NC)/
        36684197532813600000 + (185146061*CF^2*lm*NC)/14700 + 
       10812*CF^2*lm^2*NC + (934306748628926429*CF*NM*NC)/285267906000 + 
       (304348361*CF*lm*NM*NC)/264600 + (1802*CF*lm^2*NM*NC)/3 - 
       (4540491691*CF*NC*NL)/396900 + (304348361*CF*lm*NC*NL)/264600 + 
       (1802*CF*lm^2*NC*NL)/3 - (28062317713126610093165941*CF*NC*NH)/
        51811188415451665200 + (304348361*CF*lm*NC*NH)/264600 + 
       (1802*CF*lm^2*NC*NH)/3 - (6666759337359493*CF^2*NC*Pi^2)/
        10216206000 - 72*CF^2*lm*NC*Pi^2 - (505880374*CF*NM*NC*Pi^2)/315 - 
       4*CF*lm*NM*NC*Pi^2 + (771037*CF*NC*NL*Pi^2)/630 - 
       4*CF*lm*NC*NL*Pi^2 - 4*CF*lm*NC*NH*Pi^2 + 
       (22359348263929*CF^2*NC*Pi^3)/(1721868840*Sqrt[3]) + 
       (9682133200985*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) + 
       (516019*CF^2*NC*Pi^4)/1350 - (9799637872924003*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(87887055375*Sqrt[3]) - 
       (40472319839648*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (129140163*Sqrt[3]) + (223816*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 + (44718696527858*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (93002175*Sqrt[3]) + (4426118034736*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (22359348263929*CF^2*NC*Pi*Log[3]^2)/(2232052200*Sqrt[3]) + 
       (276632377171*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       CF*((-16889556498539*CF*NC)/2338875 + CA*(24095505049069/6548850 - 
           81994*lm)*NC + 268344*CF*lm*NC - (28552926791*NM*NC)/1485 + 
         14908*lm*NM*NC + (58063*NC*NL)/3 + 14908*lm*NC*NL + 
         (119243431*NC*NH)/45045 + 14908*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-15351583085*CA + 6*(3278761727*CF + 
            6300*(2106959*NM + 3727*NL)))*Log[x]^3)/14175 - 
       (9555017984798656*CF^2*NC*PolyGamma[2, 1])/29056536675 - 
       (282918019*CF*NM*NC*PolyGamma[2, 1])/180 + 
       (384454765416799*CF*NC*NH*PolyGamma[2, 1])/13947137604 + 
       CA*CF*NC*(-4441879139429774602794299/9171049383203400000 - 
         (9911*lm^2)/3 + (10661829599849*Pi^2)/32744250 - 
         (22359348263929*Pi^3)/(3443737680*Sqrt[3]) - (524659*Pi^4)/2700 + 
         lm*(-5572941571/529200 + 22*Pi^2) + 
         (9799637872924003*Im[PolyLog[2, (-1)^(1/3)]])/(175774110750*
           Sqrt[3]) - (111908*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (22359348263929*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (93002175*Sqrt[3]) - (22359348263929*Pi*Log[3]^2)/
          (4464104400*Sqrt[3]) + (4777508992399328*PolyGamma[2, 1])/
          29056536675 - (70403221164152383*Zeta[3])/406791513450) + 
       (64035366174034342*CF^2*NC*Zeta[3])/203395756725 - 
       (39030739*CF*NM*NC*Zeta[3])/90 + 18316*CF*NC*NL*Zeta[3] - 
       (820577923568801*CF*NC*NH*Zeta[3])/6973568802 + 
       CF*Log[x]*((-1347949377013739*NM*NC)/144074700 + 
         (989717*lm*NM*NC)/105 + 1680*lm^2*NM*NC + (8445845*NC*NL)/252 + 
         (989717*lm*NC*NL)/105 + 1680*lm^2*NC*NL + 
         (130890632783108690977*NC*NH)/239626986048450 + 
         (989717*lm*NC*NH)/105 + 1680*lm^2*NC*NH - (4207852*NM*NC*Pi^2)/
          3 + (9134*NC*NL*Pi^2)/3 - (4426118034736*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CA*NC*(2950180402614257169353/1323383749380000 - (13356487*lm)/210 - 
           9240*lm^2 + (14374088033*Pi^2)/56700 + 
           (22359348263929*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) - 
           10080*Zeta[3]) + CF*NC*(-1510209399113886551023/330845937345000 + 
           (5144502*lm)/35 + 30240*lm^2 - (4834081657*Pi^2)/9450 - 
           (44718696527858*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) + 
           20160*Zeta[3])), (121028584147003597885252285958749*CF^2*NC)/
        17408559307591759507200000 - (1802314099*CF^2*lm*NC)/1176000 - 
       (56631*CF^2*lm^2*NC)/10 + (3264012602986231582866857*CF*NM*NC)/
        1403883240439680000 - (6797168299*CF*lm*NM*NC)/21168000 - 
       (18877*CF*lm^2*NM*NC)/60 + (9170469045347*CF*NC*NL)/1270080000 - 
       (6797168299*CF*lm*NC*NL)/21168000 - (18877*CF*lm^2*NC*NL)/60 + 
       (454434997462315622228370311*CF*NC*NH)/3315916058588906572800 - 
       (6797168299*CF*lm*NC*NH)/21168000 - (18877*CF*lm^2*NC*NH)/60 - 
       (55376231470872283*CF^2*NC*Pi^2)/14859936000 - 
       (9*CF^2*lm*NC*Pi^2)/10 - (40246208561*CF*NM*NC*Pi^2)/25200 - 
       (CF*lm*NM*NC*Pi^2)/20 - (2783911*CF*NC*NL*Pi^2)/4200 - 
       (CF*lm*NC*NL*Pi^2)/20 - (CF*lm*NC*NH*Pi^2)/20 - 
       (223950160778345*CF^2*NC*Pi^3)/(24794911296*Sqrt[3]) - 
       (9556273156843*CF*NC*NH*Pi^3)/(516560652*Sqrt[3]) - 
       (2423291*CF^2*NC*Pi^4)/10800 + (78051594008818001*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(30373766337600*Sqrt[3]) + 
       (608915722713671*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2582803260*Sqrt[3]) - 30797*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (44790032155669*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (133923132*Sqrt[3]) - (5460727518196*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) - 
       (44790032155669*CF^2*NC*Pi*Log[3]^2)/(6428310336*Sqrt[3]) - 
       (1365181879549*CF*NC*NH*Pi*Log[3]^2)/(95659380*Sqrt[3]) - 
       (CF*NC*(-7*CA*(43816485793503611 + 88751003140800*lm) + 
          8*(CF*(76717120582519889 + 254150599903200*lm) + 
            315*((103642706566759 + 44823738960*lm)*NM + 36036*(1454947 + 
                1243860*lm)*NL + 5*(1819083025 + 8964747792*lm)*NH)))*
         Log[x]^2)/13621608000 + (CF*NC*(342619746637*CA - 711030714486*CF - 
          273692185200*NM + 313452720*NL)*Log[x]^3)/56700 - 
       (3678842719249523147*CF^2*NC*PolyGamma[2, 1])/1394713760400 - 
       (550933099*CF*NM*NC*PolyGamma[2, 1])/900 - 
       (13470053280989543*CF*NC*NH*PolyGamma[2, 1])/697356880200 + 
       CA*CF*NC*(-48595521627529114807704444678913/
          13926847446073407605760000 + (207647*lm^2)/120 + 
         (15623325218945401*Pi^2)/8382528000 + (223950160778345*Pi^3)/
          (49589822592*Sqrt[3]) + (2422427*Pi^4)/21600 + 
         lm*(168006129689/42336000 + (11*Pi^2)/40) - 
         (78051594008818001*Im[PolyLog[2, (-1)^(1/3)]])/(60747532675200*
           Sqrt[3]) + (30797*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (44790032155669*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (267846264*Sqrt[3]) + (44790032155669*Pi*Log[3]^2)/
          (12856620672*Sqrt[3]) + (3678842719249523147*PolyGamma[2, 1])/
          2789427520800 - (2286099002131308569*Zeta[3])/4881498161400) + 
       (467484335610677293*CF^2*NC*Zeta[3])/488149816140 + 
       (551957651*CF*NM*NC*Zeta[3])/450 - (50699*CF*NC*NL*Zeta[3])/5 - 
       (26648843074385183*CF*NC*NH*Zeta[3])/348678440100 + 
       CF*Log[x]*((-24766413539097335579*NM*NC)/1947889944000 - 
         (18081409*lm*NM*NC)/4200 - 924*lm^2*NM*NC - (12429601759*NC*NL)/
          756000 - (18081409*lm*NC*NL)/4200 - 924*lm^2*NC*NL - 
         (209303099856561213821*NC*NH)/1533612710710080 - 
         (18081409*lm*NC*NH)/4200 - 924*lm^2*NC*NH - (18171928*NM*NC*Pi^2)/
          15 - (25351*NC*NL*Pi^2)/15 + (5460727518196*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
         CF*NC*(-57741174987607561951138739/2300419066065120000 - 
           (45512427*lm)/700 - 16632*lm^2 - (229655955751*Pi^2)/75600 + 
           (44790032155669*Im[PolyLog[2, (-1)^(1/3)]])/(401769396*Sqrt[3]) - 
           11088*Zeta[3]) + CA*NC*(405240884982845142191196371/
            32205866924911680000 + (253226699*lm)/8400 + 5082*lm^2 + 
           (137920818619*Pi^2)/90720 - (44790032155669*
             Im[PolyLog[2, (-1)^(1/3)]])/(803538792*Sqrt[3]) + 
           5544*Zeta[3])), (19349366688661218386991149938373*CF^2*NC)/
        1392684744607340760576000 + (207999941*CF^2*lm*NC)/9408 + 
       (37905*CF^2*lm^2*NC)/2 + (4087171492381946835073*CF*NM*NC)/
        110498484096000 + (341728781*CF*lm*NM*NC)/169344 + 
       (12635*CF*lm^2*NM*NC)/12 - (1925499885661*CF*NC*NL)/71124480 + 
       (341728781*CF*lm*NC*NL)/169344 + (12635*CF*lm^2*NC*NL)/12 - 
       (170378802516735997977653687088523*CF*NC*NH)/
        146619860362625681929497600 + (341728781*CF*lm*NC*NH)/169344 + 
       (12635*CF*lm^2*NC*NH)/12 - (1995030479867219*CF^2*NC*Pi^2)/
        251475840 - (225*CF^2*lm*NC*Pi^2)/2 - (2543121029*CF*NM*NC*Pi^2)/
        144 - (25*CF*lm*NM*NC*Pi^2)/4 + (605435*CF*NC*NL*Pi^2)/252 - 
       (25*CF*lm*NC*NL*Pi^2)/4 - (25*CF*lm*NC*NH*Pi^2)/4 + 
       (21786720684905*CF^2*NC*Pi^3)/(774840978*Sqrt[3]) + 
       (750337362503575*CF*NC*NH*Pi^3)/(4649045868*Sqrt[3]) + 
       (20789*CF^2*NC*Pi^4)/27 - (34981531224456311*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(151868831688*Sqrt[3]) - 
       (110133385210136129*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (162716605380*Sqrt[3]) + 86480*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (34858753095848*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (33480783*Sqrt[3]) + (85752841428980*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) + 
       (4357344136981*CF^2*NC*Pi*Log[3]^2)/(200884698*Sqrt[3]) + 
       (21438210357245*CF*NC*NH*Pi*Log[3]^2)/(172186884*Sqrt[3]) + 
       CF*((-15978803808975691*CF*NC)/170270100 + 
         CA*(64124714306095033/1362160800 - 183205*lm)*NC + 599580*CF*lm*NC - 
         (2313194434573*NM*NC)/10920 + 33310*lm*NM*NC + (257285*NC*NL)/6 + 
         33310*lm*NC*NL + (17511868139*NC*NH)/2625480 + 33310*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-145120418371*CA + 84*(3194590877*CF + 
            8057789820*NM + 2997900*NL))*Log[x]^3)/11340 - 
       (999406995431535347*CF^2*NC*PolyGamma[2, 1])/232452293400 - 
       (734563892*CF*NM*NC*PolyGamma[2, 1])/45 + 
       (24311638566561431*CF*NC*NH*PolyGamma[2, 1])/418414128120 + 
       CA*CF*NC*(-96333273079802347746104730152941/
          13926847446073407605760000 - (138985*lm^2)/24 + 
         (43210506660899261*Pi^2)/10897286400 - (21786720684905*Pi^3)/
          (1549681956*Sqrt[3]) - (21059*Pi^4)/54 + 
         lm*(-6255288271/338688 + (275*Pi^2)/8) + 
         (34981531224456311*Im[PolyLog[2, (-1)^(1/3)]])/
          (303737663376*Sqrt[3]) - 43240*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (17429376547924*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33480783*Sqrt[3]) - (4357344136981*Pi*Log[3]^2)/
          (401769396*Sqrt[3]) + (999406995431535347*PolyGamma[2, 1])/
          464904586800 - (408348507137332922*Zeta[3])/203395756725) + 
       (1606612835436224423*CF^2*NC*Zeta[3])/406791513450 - 
       (136360669*CF*NM*NC*Zeta[3])/45 + 39985*CF*NC*NL*Zeta[3] - 
       (54015904631630689*CF*NC*NH*Zeta[3])/209207064060 + 
       CF*Log[x]*((-114915010109673037*NM*NC)/1073217600 + 
         (1048497*lm*NM*NC)/56 + 3300*lm^2*NM*NC + (15320716913*NC*NL)/
          211680 + (1048497*lm*NC*NL)/56 + 3300*lm^2*NC*NL + 
         (23454360794338474200039997*NC*NH)/19944633302784590400 + 
         (1048497*lm*NC*NH)/56 + 3300*lm^2*NC*NH - 14918394*NM*NC*Pi^2 + 
         (19955*NC*NL*Pi^2)/3 - (85752841428980*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CA*NC*(22286479792519187117117579/805146673122792000 - 
           (14120667*lm)/112 - 18150*lm^2 + (143362413589*Pi^2)/45360 + 
           (17429376547924*Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) - 
           19800*Zeta[3]) + CF*NC*(-178997418180637623929313907/
            3220586692491168000 + (8189073*lm)/28 + 59400*lm^2 - 
           (47861375003*Pi^2)/7560 - (34858753095848*Im[PolyLog[2, (-1)^
                (1/3)]])/(100442349*Sqrt[3]) + 39600*Zeta[3])), 
      (3160430250113982894088873997904547*CF^2*NC)/
        37602488104398200535552000 - (2545606691*CF^2*lm*NC)/952560 - 
       9668*CF^2*lm^2*NC + (21246127870244307815481457*CF*NM*NC)/
        631747458197856000 - (9452619251*CF*lm*NM*NC)/17146080 - 
       (4834*CF*lm^2*NM*NC)/9 + (64113704795459*CF*NC*NL)/4000752000 - 
       (9452619251*CF*lm*NC*NL)/17146080 - (4834*CF*lm^2*NC*NL)/9 + 
       (456674366664408920172902730321181*CF*NC*NH)/
        1649473429079538921706848000 - (9452619251*CF*lm*NC*NH)/17146080 - 
       (4834*CF*lm^2*NC*NH)/9 - (2127395996492297677*CF^2*NC*Pi^2)/
        49037788800 - (10*CF^2*lm*NC*Pi^2)/9 - (2087687950483*CF*NM*NC*Pi^2)/
        102060 - (5*CF*lm*NM*NC*Pi^2)/81 - (6416710*CF*NC*NL*Pi^2)/5103 - 
       (5*CF*lm*NC*NL*Pi^2)/81 - (5*CF*lm*NC*NH*Pi^2)/81 - 
       (1539384416889257*CF^2*NC*Pi^3)/(83682825624*Sqrt[3]) - 
       (399845675596325*CF*NC*NH*Pi^3)/(10460353203*Sqrt[3]) - 
       (359741*CF^2*NC*Pi^4)/810 + (232821203909408579*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(25627865347350*Sqrt[3]) + 
       (168846741578590891*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (366112362105*Sqrt[3]) - (172216*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (3078768833778514*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4519905705*Sqrt[3]) - 
       (182786594558320*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) - (1539384416889257*CF^2*NC*Pi*Log[3]^2)/
        (108477736920*Sqrt[3]) - (11424162159895*CF*NC*NH*Pi*Log[3]^2)/
        (387420489*Sqrt[3]) - 
       (CF*NC*(-306*CA*(59171173985765377 + 22341354235200*lm) + 
          5*(17*CF*(426072325711794131 + 263221773534720*lm) + 
            336*(459*(22115906497809 + 1611930320*lm)*NM + 9189180*(92969 + 
                80516*lm)*NL + 5*(33699345499 + 147975203376*lm)*NH)))*
         Log[x]^2)/69470200800 + (CF*NC*(1203862749080*CA - 
          21*(115534371079*CF + 51893738400*NM - 9661920*NL))*Log[x]^3)/
        17010 - (11183966729403298019*CF^2*NC*PolyGamma[2, 1])/376572715308 - 
       (18154552802*CF*NM*NC*PolyGamma[2, 1])/2025 - 
       (359932051116995611*CF*NC*NH*PolyGamma[2, 1])/9414317882700 + 
       CA*CF*NC*(-395295865906402124378101634363789/
          9400622026099550133888000 + (26587*lm^2)/9 + 
         (16621050632707349*Pi^2)/766215450 + (1539384416889257*Pi^3)/
          (167365651248*Sqrt[3]) + (119887*Pi^4)/540 + 
         lm*(232909712881/34292160 + (55*Pi^2)/162) - 
         (232821203909408579*Im[PolyLog[2, (-1)^(1/3)]])/
          (51255730694700*Sqrt[3]) + (86108*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1539384416889257*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4519905705*Sqrt[3]) + (1539384416889257*Pi*Log[3]^2)/
          (216955473840*Sqrt[3]) + (11183966729403298019*PolyGamma[2, 1])/
          753145430616 - (77334466859638683641*Zeta[3])/13180045035780) + 
       (155232310912355726683*CF^2*NC*Zeta[3])/13180045035780 + 
       (28718165096*CF*NM*NC*Zeta[3])/2025 - (578116*CF*NC*NL*Zeta[3])/27 - 
       (642633556781273611*CF*NC*NH*Zeta[3])/4707158941350 + 
       CF*Log[x]*((-14790774642282256307*NM*NC)/97394497200 - 
         (28233145*lm*NM*NC)/3402 - 1760*lm^2*NM*NC - (27522285353*NC*NL)/
          793800 - (28233145*lm*NC*NL)/3402 - 1760*lm^2*NC*NL - 
         (12656643785103592760851823*NC*NH)/44875424931265328400 - 
         (28233145*lm*NC*NH)/3402 - 1760*lm^2*NC*NH - 
         (144237896*NM*NC*Pi^2)/9 - (96356*NC*NL*Pi^2)/27 + 
         (182786594558320*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(-24971983589064565717517709617/
            86955840697261536000 - (23742505*lm)/189 - 31680*lm^2 - 
           (2410206173617*Pi^2)/68040 + (3078768833778514*
             Im[PolyLog[2, (-1)^(1/3)]])/(13559717115*Sqrt[3]) - 
           21120*Zeta[3]) + CA*NC*(6245841639006391090848491717/
            43477920348630768000 + (394389875*lm)/6804 + 9680*lm^2 + 
           (602652483973*Pi^2)/34020 - (1539384416889257*
             Im[PolyLog[2, (-1)^(1/3)]])/(13559717115*Sqrt[3]) + 
           10560*Zeta[3])), (949183116330507308878509801955169*CF^2*NC)/
        5371784014914028647936000 + (27914158381*CF^2*lm*NC)/762048 + 
       (62755*CF^2*lm^2*NC)/2 + (1040252033121731817737309273*CF*NM*NC)/
        2526989832791424000 + (45847529221*CF*lm*NM*NC)/13716864 + 
       (62755*CF*lm^2*NM*NC)/36 - (20686540414553*CF*NC*NL)/355622400 + 
       (45847529221*CF*lm*NC*NL)/13716864 + (62755*CF*lm^2*NC*NL)/36 - 
       (314396608264604607785769852872424808907*CF*NC*NH)/
        135764859000678689567847245184000 + (45847529221*CF*lm*NC*NH)/
        13716864 + (62755*CF*lm^2*NC*NH)/36 - 
       (264416832486963929*CF^2*NC*Pi^2)/2802159360 - (3025*CF^2*lm*NC*Pi^2)/
        18 - (79247972220479*CF*NM*NC*Pi^2)/408240 - 
       (3025*CF*lm*NM*NC*Pi^2)/324 + (89871925*CF*NC*NL*Pi^2)/20412 - 
       (3025*CF*lm*NC*NL*Pi^2)/324 - (3025*CF*lm*NC*NH*Pi^2)/324 + 
       (37588713070093255*CF^2*NC*Pi^3)/(669462604992*Sqrt[3]) + 
       (40474845169647385*CF*NC*NH*Pi^3)/(125524238436*Sqrt[3]) + 
       (1866557*CF^2*NC*Pi^4)/1296 - (298247773128793267*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(669462604992*Sqrt[3]) - 
       (5977261346884258331*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (4393348345260*Sqrt[3]) + (469315*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 + (1073963230574093*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(516560652*Sqrt[3]) + 
       (4625696590816844*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) + (1073963230574093*CF^2*NC*Pi*Log[3]^2)/
        (24794911296*Sqrt[3]) + (1156424147704211*CF*NC*NH*Pi*Log[3]^2)/
        (4649045868*Sqrt[3]) + CF*((-659421557673741767*CF*NC)/583783200 + 
         CA*(513170864036549263/908107200 - (3389815*lm)/9)*NC + 
         1232660*CF*lm*NC - (7554355806262049*NM*NC)/3243240 + 
         (616330*lm*NM*NC)/9 + (1576487*NC*NL)/18 + (616330*lm*NC*NL)/9 + 
         (47474668968131*NC*NH)/3142699560 + (616330*lm*NC*NH)/9)*
        Log[x]^2 - (CF*NC*(-5196450977057*CA + 84*(121957068131*CF + 
            300*(877265317*NM + 61633*NL)))*Log[x]^3)/34020 - 
       (990831131383432855637*CF^2*NC*PolyGamma[2, 1])/18828635765400 - 
       (68739246356*CF*NM*NC*PolyGamma[2, 1])/405 + 
       (1287069072061405451*CF*NC*NH*PolyGamma[2, 1])/11297181459240 + 
       CA*CF*NC*(-33199313088618879363689963025826063/
          376024881043982005355520000 - (690305*lm^2)/72 + 
         (120182748179381231*Pi^2)/2547417600 - (37588713070093255*Pi^3)/
          (1338925209984*Sqrt[3]) - (628639*Pi^4)/864 + 
         lm*(-839079077111/27433728 + (33275*Pi^2)/648) + 
         (298247773128793267*Im[PolyLog[2, (-1)^(1/3)]])/
          (1338925209984*Sqrt[3]) - (469315*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (1073963230574093*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1033121304*Sqrt[3]) - (1073963230574093*Pi*Log[3]^2)/
          (49589822592*Sqrt[3]) + (990831131383432855637*PolyGamma[2, 1])/
          37657271530800 - (887099495048940881471*Zeta[3])/37657271530800) + 
       (884667280849361961251*CF^2*NC*Zeta[3])/18828635765400 - 
       (6080103577*CF*NM*NC*Zeta[3])/405 + (2178715*CF*NC*NL*Zeta[3])/27 - 
       (2945031254917837069*CF*NC*NH*Zeta[3])/5648590729620 + 
       CF*Log[x]*((-55542150926891669977*NM*NC)/46749358656 + 
         (471395419*lm*NM*NC)/13608 + 6050*lm^2*NM*NC + 
         (6128190049*NC*NL)/42336 + (471395419*lm*NC*NL)/13608 + 
         6050*lm^2*NC*NL + (456724686273119250204634496203*NC*NH)/
          194400340802241402628800 + (471395419*lm*NC*NH)/13608 + 
         6050*lm^2*NC*NH - 162451382*NM*NC*Pi^2 + (362615*NC*NL*Pi^2)/27 - 
         (4625696590816844*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CA*NC*(55801256610812507697121888651/
            173911681394523072000 - (6337947209*lm)/27216 - 33275*lm^2 + 
           (1481588079673*Pi^2)/38880 + (1073963230574093*
             Im[PolyLog[2, (-1)^(1/3)]])/(3099363912*Sqrt[3]) - 
           36300*Zeta[3]) + CF*NC*(-997104012315022134259758179/
            1552782869593956000 + (409649119*lm)/756 + 108900*lm^2 - 
           (1481968761097*Pi^2)/19440 - (1073963230574093*
             Im[PolyLog[2, (-1)^(1/3)]])/(1549681956*Sqrt[3]) + 
           72600*Zeta[3])), (41339975753191213359428592633970445026873*CF^2*
         NC)/41566730412804380827012569600000 - (83742405679*CF^2*lm*NC)/
        19051200 - (156629*CF^2*lm^2*NC)/10 + 
       (27820741160908139227445083148791*CF*NM*NC)/62075505242521330560000 - 
       (307540186039*CF*lm*NM*NC)/342921600 - (156629*CF*lm^2*NM*NC)/180 + 
       (2623927824162797*CF*NC*NL)/80015040000 - (307540186039*CF*lm*NC*NL)/
        342921600 - (156629*CF*lm^2*NC*NL)/180 + 
       (27389823158067019932040874749617000289*CF*NC*NH)/
        52217253461799495987633555840000 - (307540186039*CF*lm*NC*NH)/
        342921600 - (156629*CF*lm^2*NC*NH)/180 - 
       (30471917311320024521*CF^2*NC*Pi^2)/61297236000 - 
       (121*CF^2*lm*NC*Pi^2)/90 - (512214480301289*CF*NM*NC*Pi^2)/2041200 - 
       (121*CF*lm*NM*NC*Pi^2)/1620 - (2287211069*CF*NC*NL*Pi^2)/1020600 - 
       (121*CF*lm*NC*NL*Pi^2)/1620 - (121*CF*lm*NC*NH*Pi^2)/1620 - 
       (525514087377859013*CF^2*NC*Pi^3)/(15062908612320*Sqrt[3]) - 
       (4627329199681349*CF*NC*NH*Pi^3)/(62762119218*Sqrt[3]) - 
       (2650967*CF^2*NC*Pi^4)/3240 + (62675031197437069781*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2636009007156000*Sqrt[3]) + 
       (3743015586903457427*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (4393348345260*Sqrt[3]) - (1512434*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/15 - (75073441053979859*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(58113073350*Sqrt[3]) - 
       (5288376228207256*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1937102445*Sqrt[3]) - (75073441053979859*CF^2*NC*Pi*Log[3]^2)/
        (2789427520800*Sqrt[3]) - (661047028525907*CF*NC*NH*Pi*Log[3]^2)/
        (11622614670*Sqrt[3]) - 
       (CF*NC*(-57*CA*(345426368813860908631 + 22759114473295200*lm) + 
          10*(19*CF*(207259221928525035961 + 22345312391962560*lm) + 
            42*(399*(118591542146805293 + 1407490072560*lm)*NM + 
              13*(29546748*(1670947 + 1462060*lm)*NL + (10800854149369 + 
                  43199118380880*lm)*NH))))*Log[x]^2)/6599669076000 + 
       (CF*NC*(138784574846615*CA - 72*(3860757714979*CF + 
            70*(27043982639*NM - 804133*NL)))*Log[x]^3)/170100 - 
       (112665042844539144397219*CF^2*NC*PolyGamma[2, 1])/338915443777200 - 
       (1941359358883*CF*NM*NC*PolyGamma[2, 1])/16200 - 
       (502987418242750318*CF*NC*NH*PolyGamma[2, 1])/7060738412025 + 
       CA*CF*NC*(-5906275875389198140202584838642999248261/
          11876208689372680236289305600000 + (1722919*lm^2)/360 + 
         (2770194409793976673*Pi^2)/11144952000 + (525514087377859013*Pi^3)/
          (30125817224640*Sqrt[3]) + (4417633*Pi^4)/10800 + 
         (11*lm*(687318237559 + 25613280*Pi^2))/685843200 - 
         (62675031197437069781*Im[PolyLog[2, (-1)^(1/3)]])/
          (5272018014312000*Sqrt[3]) + (756217*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          15 + (75073441053979859*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (116226146700*Sqrt[3]) + (75073441053979859*Pi*Log[3]^2)/
          (5578855041600*Sqrt[3]) + (112665042844539144397219*
           PolyGamma[2, 1])/677830887554400 - (180011370073489168817459*
           Zeta[3])/2372408106440400) + (36021612831265800008797*CF^2*NC*
         Zeta[3])/237240810644040 + (1305172543937*CF*NM*NC*Zeta[3])/8100 - 
       (5674097*CF*NC*NL*Zeta[3])/135 - (1637269390899798146*CF*NC*NH*
         Zeta[3])/7060738412025 + CF*Log[x]*
        ((-2989930786648218170463581*NM*NC)/1688820581448000 - 
         (5096549821*lm*NM*NC)/340200 - 3146*lm^2*NM*NC - 
         (1079676206471*NC*NL)/15876000 - (5096549821*lm*NC*NL)/340200 - 
         3146*lm^2*NC*NL - (5810313759159138918927731993*NC*NH)/
          10681337406716560584000 - (5096549821*lm*NC*NH)/340200 - 
         3146*lm^2*NC*NH - (9015521681*NM*NC*Pi^2)/45 - 
         (945703*NC*NL*Pi^2)/135 + (5288376228207256*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5811307335*Sqrt[3]) + 
         CF*NC*(-3646300269599824601350332159269729/
            1130860708267886275680000 - (4293847921*lm)/18900 - 56628*lm^2 - 
           (13880986888463*Pi^2)/34020 + (75073441053979859*
             Im[PolyLog[2, (-1)^(1/3)]])/(174339220050*Sqrt[3]) - 
           37752*Zeta[3]) + CA*NC*(1823288725941098290400491222416667/
            1130860708267886275680000 + (71045816831*lm)/680400 + 
           17303*lm^2 + (17351729579953*Pi^2)/85050 - 
           (75073441053979859*Im[PolyLog[2, (-1)^(1/3)]])/(348678440100*
             Sqrt[3]) + 18876*Zeta[3])), 
      (33523203391215807524202674842770058951229*CF^2*NC)/
        15587523904801642810129713600000 + (6129156101*CF^2*lm*NC)/105840 + 
       49588*CF^2*lm^2*NC + (32143712053253652742544045153*CF*NM*NC)/
        7038039143143008000 + (10065451541*CF*lm*NM*NC)/1905120 + 
       (24794*CF*lm^2*NM*NC)/9 - (1389417103470251*CF*NC*NL)/12002256000 + 
       (10065451541*CF*lm*NC*NL)/1905120 + (24794*CF*lm^2*NC*NL)/9 - 
       (3979735990592927599300793612599566768949*CF*NC*NH)/
        916412798254581154582968904992000 + (10065451541*CF*lm*NC*NH)/
        1905120 + (24794*CF*lm^2*NC*NH)/9 - (134489220819229137479*CF^2*NC*
         Pi^2)/122594472000 - 242*CF^2*lm*NC*Pi^2 - 
       (689114127281*CF*NM*NC*Pi^2)/324 - (121*CF*lm*NM*NC*Pi^2)/9 + 
       (86521919*CF*NC*NL*Pi^2)/11340 - (121*CF*lm*NC*NL*Pi^2)/9 - 
       (121*CF*lm*NC*NH*Pi^2)/9 + (1186434484633477807*CF^2*NC*Pi^3)/
        (11297181459240*Sqrt[3]) + (513391419209849285*CF*NC*NH*Pi^3)/
        (847288609443*Sqrt[3]) + (20555579*CF^2*NC*Pi^4)/8100 - 
       (3224929713307402379123*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (3954013510734000*Sqrt[3]) - (76416661815801463501*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(29655101330505*Sqrt[3]) + 
       (4022788*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (338981281323850802*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (87169610025*Sqrt[3]) + (234693220210216816*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) + 
       (169490640661925401*CF^2*NC*Pi*Log[3]^2)/(2092070640600*Sqrt[3]) + 
       (14668326263138551*CF*NC*NH*Pi*Log[3]^2)/(31381059609*Sqrt[3]) + 
       CF*((-1142696757056440794443*CF*NC)/86837751000 + 
         CA*(228560493583878352801/34735100400 - (2171224*lm)/3)*NC + 
         2368608*CF*lm*NC - (117264928924085051*NM*NC)/4594590 + 
         (394768*lm*NM*NC)/3 + (1506791*NC*NL)/9 + (394768*lm*NC*NL)/3 + 
         (2744612680969*NC*NH)/87297210 + (394768*lm*NC*NH)/3)*Log[x]^2 - 
       (CF*NC*(-76136309894771*CA + 4*(37970877046531*CF + 
            9450*(8002841965*NM + 98692*NL)))*Log[x]^3)/42525 - 
       (26407759689676869359797*CF^2*NC*PolyGamma[2, 1])/42364430472150 - 
       (382133796415*CF*NM*NC*PolyGamma[2, 1])/216 + 
       (2377964794947250861*CF*NC*NH*PolyGamma[2, 1])/11297181459240 + 
       CA*CF*NC*(-67039553381416673790261947901293856734911/
          62350095619206571240518854400000 - (136367*lm^2)/9 + 
         (940476019855008997*Pi^2)/1714608000 - (1186434484633477807*Pi^3)/
          (22594362918480*Sqrt[3]) - (20729819*Pi^4)/16200 + 
         lm*(-184197481831/3810240 + (1331*Pi^2)/18) + 
         (3224929713307402379123*Im[PolyLog[2, (-1)^(1/3)]])/
          (7908027021468000*Sqrt[3]) - (2011394*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          15 - (169490640661925401*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (87169610025*Sqrt[3]) - (169490640661925401*Pi*Log[3]^2)/
          (4184141281200*Sqrt[3]) + (26407759689676869359797*PolyGamma[2, 1])/
          84728860944300 - (80504965276933498527917*Zeta[3])/
          296551013305050) + (80469488996074881380333*CF^2*NC*Zeta[3])/
        148275506652525 + (1903494881*CF*NM*NC*Zeta[3])/108 + 
       152724*CF*NC*NL*Zeta[3] - (5564425742034988499*CF*NC*NH*Zeta[3])/
        5648590729620 + CF*Log[x]*((-10137245810955619865077*NM*NC)/
          781861380300 + (57175822*lm*NM*NC)/945 + (31460*lm^2*NM*NC)/3 + 
         (258995817229*NC*NL)/952560 + (57175822*lm*NC*NL)/945 + 
         (31460*lm^2*NC*NL)/3 + (5792720164721281712373288342887*NC*NH)/
          1312202300415129467744400 + (57175822*lm*NC*NH)/945 + 
         (31460*lm^2*NC*NH)/3 - (16005623474*NM*NC*Pi^2)/9 + 
         (228844*NC*NL*Pi^2)/9 - (234693220210216816*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CA*NC*(877728151493537284171968944189531/242327294628832773360000 - 
           (383836321*lm)/945 - (173030*lm^2)/3 + (19027513606484*Pi^2)/
            42525 + (169490640661925401*Im[PolyLog[2, (-1)^(1/3)]])/
            (261508830075*Sqrt[3]) - 62920*Zeta[3]) + 
         CF*NC*(-1536185630486654084051374894904909/
            212036382800228676690000 + (99486794*lm)/105 + 188760*lm^2 - 
           (38056594042939*Pi^2)/42525 - (338981281323850802*
             Im[PolyLog[2, (-1)^(1/3)]])/(261508830075*Sqrt[3]) + 
           125840*Zeta[3])), (352833986915730316499897102144404453715293013*
         CF^2*NC)/30547093275152705152765630166400000 - 
       (22089345263*CF^2*lm*NC)/3201660 - (121544*CF^2*lm^2*NC)/5 + 
       (16698772454517546500148221545359079*CF*NM*NC)/
        2956777017072595877160000 - (80460729719*CF*lm*NM*NC)/57629880 - 
       (60772*CF*lm^2*NM*NC)/45 + (14249601117847853*CF*NC*NL)/
        226917652500 - (80460729719*CF*lm*NC*NL)/57629880 - 
       (60772*CF*lm^2*NC*NL)/45 + (1079237384822837130591997583423480925641*
         CF*NC*NH)/1145515997818226443228711131240000 - 
       (80460729719*CF*lm*NC*NH)/57629880 - (60772*CF*lm^2*NC*NH)/45 - 
       (3784149949211188960807*CF^2*NC*Pi^2)/674269596000 - 
       (8*CF^2*lm*NC*Pi^2)/5 - (464590367378579*CF*NM*NC*Pi^2)/155925 - 
       (4*CF*lm*NM*NC*Pi^2)/45 - (591665933*CF*NC*NL*Pi^2)/155925 - 
       (4*CF*lm*NC*NL*Pi^2)/45 - (4*CF*lm*NC*NH*Pi^2)/45 - 
       (7757968040088363583*CF^2*NC*Pi^3)/(124268996051640*Sqrt[3]) - 
       (113852807024165426*CF*NC*NH*Pi^3)/(847288609443*Sqrt[3]) - 
       (5762077*CF^2*NC*Pi^4)/4050 + (89187047229317762745157*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1674524721795849000*Sqrt[3]) + 
       (44475341375517090964*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29655101330505*Sqrt[3]) - (2529592*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (15515936080176727166*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6712059971925*Sqrt[3]) - 
       (260234987483806688*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (52301766015*Sqrt[3]) - (7757968040088363583*CF^2*NC*Pi*Log[3]^2)/
        (161089439326200*Sqrt[3]) - (16264686717737918*CF*NC*NH*Pi*Log[3]^2)/
        (156905298045*Sqrt[3]) - 
       (CF*NC*(-(CA*(611163060736236735362749 + 6691187127054830400*lm)) + 
          2*(CF*(611164733406659432310553 + 10949215298816995200*lm) + 
            83160*((3901638839135202807 + 7314691424040*lm)*NM + 
              21339318*(388501 + 342780*lm)*NL + (1975875438227 + 
                7314691424040*lm)*NH)))*Log[x]^2)/18149089959000 - 
       (4*CF*NC*(-1083656858836037*CA + 11*(197080255114151*CF + 
            219240*(467548091*NM - 2167*NL)))*Log[x]^3)/467775 - 
       (1407338662779175413803057*CF^2*NC*PolyGamma[2, 1])/381279874249350 - 
       (1358155106803*CF*NM*NC*PolyGamma[2, 1])/900 - 
       (32073006028232493319*CF*NC*NH*PolyGamma[2, 1])/254186582832900 + 
       CA*CF*NC*(-679215304982289941629381373258582247197895487/
          117606309109337914838147676140640000 + (334246*lm^2)/45 + 
         (151366163780632317373*Pi^2)/53941567680 + 
         (7757968040088363583*Pi^3)/(248537992103280*Sqrt[3]) + 
         (5761501*Pi^4)/8100 + lm*(179515200311/10478160 + (22*Pi^2)/45) - 
         (89187047229317762745157*Im[PolyLog[2, (-1)^(1/3)]])/
          (3349049443591698000*Sqrt[3]) + (1264796*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/15 + (7757968040088363583*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(6712059971925*Sqrt[3]) + 
         (7757968040088363583*Pi*Log[3]^2)/(322178878652400*Sqrt[3]) + 
         (1407338662779175413803057*PolyGamma[2, 1])/762559748498700 - 
         (13839751764756713064589918*Zeta[3])/14679275158599975) + 
       (27681666782107879030120826*CF^2*NC*Zeta[3])/14679275158599975 + 
       (811396162157*CF*NM*NC*Zeta[3])/450 - (388544*CF*NC*NL*Zeta[3])/5 - 
       (47987209983686370439*CF*NC*NH*Zeta[3])/127093291416450 + 
       CF*Log[x]*((-256545436724162675651876563*NM*NC)/12701338122973500 - 
         (1332235852*lm*NM*NC)/51975 - (16016*lm^2*NM*NC)/3 - 
         (4115540740237*NC*NL)/32744250 - (1332235852*lm*NC*NL)/51975 - 
         (16016*lm^2*NC*NL)/3 - (406460837934122287605525275566*NC*NH)/
          410063218879727958670125 - (1332235852*lm*NC*NH)/51975 - 
         (16016*lm^2*NC*NH)/3 - (108472731344*NM*NC*Pi^2)/45 - 
         (582824*NC*NL*Pi^2)/45 + (260234987483806688*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(156905298045*Sqrt[3]) + 
         CF*NC*(-12006757490172845250168283141624978333/
            336798590439883230054396000 - (2248255904*lm)/5775 - 96096*lm^2 - 
           (4334760016706159*Pi^2)/935550 + (15515936080176727166*
             Im[PolyLog[2, (-1)^(1/3)]])/(20136179915775*Sqrt[3]) - 
           64064*Zeta[3]) + CA*NC*(60034519048491675287808144733226056721/
            3367985904398832300543960000 + (842694326*lm)/4725 + 
           (88088*lm^2)/3 + (4334780208446189*Pi^2)/1871100 - 
           (7757968040088363583*Im[PolyLog[2, (-1)^(1/3)]])/
            (20136179915775*Sqrt[3]) + 32032*Zeta[3])), 
      (2757783903404189759822216542097792591100812239*CF^2*NC)/
        108559669947081152158290162591360000 + (1127773239101*CF^2*lm*NC)/
        12806640 + 75400*CF^2*lm^2*NC + (119303488273825733347519166035756913*
         CF*NM*NC)/2365421613658076701728000 + (1851988731101*CF*lm*NM*NC)/
        230519520 + (37700*CF*lm^2*NM*NC)/9 - (314307629691399349*CF*NC*NL)/
        1452272976000 + (1851988731101*CF*lm*NC*NL)/230519520 + 
       (37700*CF*lm^2*NC*NL)/9 - 
       (36984409294692350643095592416404216758766121*CF*NC*NH)/
        4778569078441495246204706857301856000 + (1851988731101*CF*lm*NC*NH)/
        230519520 + (37700*CF*lm^2*NC*NH)/9 - 
       (26587578119594195081*CF^2*NC*Pi^2)/2126638800 - 338*CF^2*lm*NC*Pi^2 - 
       (963207160891711*CF*NM*NC*Pi^2)/41580 - (169*CF*lm*NM*NC*Pi^2)/9 + 
       (1574451853*CF*NC*NL*Pi^2)/124740 - (169*CF*lm*NC*NL*Pi^2)/9 - 
       (169*CF*lm*NC*NH*Pi^2)/9 + (27753421400139480875*CF^2*NC*Pi^3)/
        (149122795261968*Sqrt[3]) + (2749714832312521955*CF*NC*NH*Pi^3)/
        (2541865828329*Sqrt[3]) + (1723891*CF^2*NC*Pi^4)/405 - 
       (1431996255329141194018709*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1004714833077509400*Sqrt[3]) - (412962202998372131827*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(88965303991515*Sqrt[3]) + 
       (1318928*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (5550684280027896175*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (805447196631*Sqrt[3]) + (1257012494771438608*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) + 
       (5550684280027896175*CF^2*NC*Pi*Log[3]^2)/(38661465438288*Sqrt[3]) + 
       (78563280923214913*CF*NC*NH*Pi*Log[3]^2)/(94143178827*Sqrt[3]) + 
       CF*((-837741259129321318969*CF*NC)/5584335372 + 
         CA*(52359601162811597619421/698041921500 - 1315028*lm)*NC + 
         4303728*CF*lm*NC - (24266987211561533591*NM*NC)/87297210 + 
         239096*lm*NM*NC + (908765*NC*NL)/3 + 239096*lm*NC*NL + 
         (5840876293277*NC*NH)/95611230 + 239096*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-9619874659950247*CA + 100*(192313236355787*CF + 
            12474*(29113601147*NM + 59774*NL)))*Log[x]^3)/467775 - 
       (549934570675983505896859*CF^2*NC*PolyGamma[2, 1])/76255974849870 - 
       (3988129390697*CF*NM*NC*PolyGamma[2, 1])/216 + 
       (338602733338937498507*CF*NC*NH*PolyGamma[2, 1])/915071698198440 + 
       CA*CF*NC*(-13788706820750401241202368161840378911257341247/
          1085596699470811521582901625913600000 - (207350*lm^2)/9 + 
         (601528155511630397*Pi^2)/96228000 - (27753421400139480875*Pi^3)/
          (298245590523936*Sqrt[3]) - (1736059*Pi^4)/810 + 
         lm*(-3080960475101/41912640 + (1859*Pi^2)/18) + 
         (1431996255329141194018709*Im[PolyLog[2, (-1)^(1/3)]])/
          (2009429666155018800*Sqrt[3]) - (659464*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/3 - (5550684280027896175*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1610894393262*Sqrt[3]) - 
         (5550684280027896175*Pi*Log[3]^2)/(77322930876576*Sqrt[3]) + 
         (549934570675983505896859*PolyGamma[2, 1])/152511949699740 - 
         (36054691163602269121331897*Zeta[3])/11743420126879980) + 
       (36052212832827610451005733*CF^2*NC*Zeta[3])/5871710063439990 + 
       (204047618551*CF*NM*NC*Zeta[3])/108 + (822068*CF*NC*NL*Zeta[3])/3 - 
       (806356937167707392053*CF*NC*NH*Zeta[3])/457535849099220 + 
       CF*Log[x]*((-710554037350562207993751763*NM*NC)/5080535249189400 + 
         (1047323264*lm*NM*NC)/10395 + (52052*lm^2*NM*NC)/3 + 
         (25394329629173*NC*NL)/52390800 + (1047323264*lm*NC*NL)/10395 + 
         (52052*lm^2*NC*NL)/3 + (2344360283373544341719942068206137*NC*NH)/
          297495007251258637901480400 + (1047323264*lm*NC*NH)/10395 + 
         (52052*lm^2*NC*NH)/3 - (174681542818*NM*NC*Pi^2)/9 + 
         (410696*NC*NL*Pi^2)/9 - (1257012494771438608*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CA*NC*(567892692133833546548037884468588219/
            14131409389086009652632000 - (638436292*lm)/945 - 
           (286286*lm^2)/3 + (3847739387965159*Pi^2)/748440 + 
           (5550684280027896175*Im[PolyLog[2, (-1)^(1/3)]])/
            (4832683179786*Sqrt[3]) - 104104*Zeta[3]) + 
         CF*NC*(-12493843092868971029475350687293378247/
            155445503279946106178952000 + (1824106258*lm)/1155 + 
           312312*lm^2 - (3847764009869851*Pi^2)/374220 - 
           (5550684280027896175*Im[PolyLog[2, (-1)^(1/3)]])/
            (2416341589893*Sqrt[3]) + 208208*Zeta[3])), 
      (11164109188278454528388537519476591356407188322261*CF^2*NC)/
        84676542558723298683466326821260800000 - (24020190706003*CF^2*lm*NC)/
        2305195200 - (363987*CF^2*lm^2*NC)/10 + 
       (29112796172236790177068767211195608901*CF*NM*NC)/
        425775890458453806311040000 - (86949772100683*CF*lm*NM*NC)/
        41493513600 - (40443*CF*lm^2*NM*NC)/20 + 
       (193166076940149149*CF*NC*NL)/1697461920000 - 
       (86949772100683*CF*lm*NC*NL)/41493513600 - (40443*CF*lm^2*NC*NL)/
        20 + (3246614071172322722030028072880032401906875673*CF*NC*NH)/
        2006999012945428003405976880066779520000 - 
       (86949772100683*CF*lm*NC*NH)/41493513600 - (40443*CF*lm^2*NC*NH)/
        20 - (1909938434655161900663347*CF^2*NC*Pi^2)/30566888352000 - 
       (169*CF^2*lm*NC*Pi^2)/90 - (774317723377707011*CF*NM*NC*Pi^2)/
        22453200 - (169*CF*lm*NM*NC*Pi^2)/1620 - 
       (34553255243*CF*NC*NL*Pi^2)/5613300 - (169*CF*lm*NC*NL*Pi^2)/1620 - 
       (169*CF*lm*NC*NH*Pi^2)/1620 - (952316701049155885499*CF^2*NC*Pi^3)/
        (8947367715718080*Sqrt[3]) - (14247034337312170247*CF*NC*NH*Pi^3)/
        (61004779879896*Sqrt[3]) - (25476893*CF^2*NC*Pi^4)/10800 + 
       (265074770067475137115759*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2460526121822472000*Sqrt[3]) + (540937387641615818485*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(213516729579636*Sqrt[3]) - 
       (4060693*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (136045243007022269357*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (34519165569900*Sqrt[3]) - (4070581239232048642*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) - 
       (136045243007022269357*CF^2*NC*Pi*Log[3]^2)/(1656919947355200*
         Sqrt[3]) - (2035290619616024321*CF*NC*NH*Pi*Log[3]^2)/
        (11297181459240*Sqrt[3]) - 
       (CF*NC*(-253*CA*(4948506331886869439621237 + 8661755086711927200*lm) + 
          6*(23*CF*(18144531182067760771773733 + 51970530520271563200*lm) + 
            4620*(23*(2167574179868381961811 + 624946254452520*lm)*NM + 
              6380456082*(2535701 + 2252780*lm)*NL + (4144384587779123 + 
                14373763852407960*lm)*NH)))*Log[x]^2)/3339432552456000 + 
       (CF*NC*(194139433016422613*CA - 8*(48537048976436476*CF + 
            1155*(22831389837986*NM - 16107377*NL)))*Log[x]^3)/1871100 - 
       (371708265868237101864003287*CF^2*NC*PolyGamma[2, 1])/
        9150716981984400 - (73808214453737*CF*NM*NC*PolyGamma[2, 1])/4050 - 
       (2938436497279993831403*CF*NC*NH*PolyGamma[2, 1])/13726075472976600 + 
       CA*CF*NC*(-446565333709674671930358227277181512951496544051/
          6774123404697863894677306145700864000 + (444873*lm^2)/40 + 
         (8642256746442360473303*Pi^2)/276623424000 + 
         (952316701049155885499*Pi^3)/(17894735431436160*Sqrt[3]) + 
         (76425271*Pi^4)/64800 + lm*(193739364770443/7544275200 + 
           (1859*Pi^2)/3240) - (265074770067475137115759*
           Im[PolyLog[2, (-1)^(1/3)]])/(4921052243644944000*Sqrt[3]) + 
         (4060693*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (136045243007022269357*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (69038331139800*Sqrt[3]) + (136045243007022269357*Pi*Log[3]^2)/
          (3313839894710400*Sqrt[3]) + (371708265868237101864003287*
           PolyGamma[2, 1])/18301433963968800 - (3966545802915271738516517893*
           Zeta[3])/352302603806399400) + (991647663246291353969576977*CF^2*
         NC*Zeta[3])/44037825475799925 + (40349741699683*CF*NM*NC*Zeta[3])/
        2025 - (18449548*CF*NC*NL*Zeta[3])/135 - 
       (4070688228198313208483*CF*NC*NH*Zeta[3])/6863037736488300 + 
       CF*Log[x]*((-103433241142401868825300280363*NM*NC)/
          457248172427046000 - (156962849069*lm*NM*NC)/3742200 - 
         (26026*lm^2*NM*NC)/3 - (3866823044729*NC*NL)/17496000 - 
         (156962849069*lm*NC*NL)/3742200 - (26026*lm^2*NC*NL)/3 - 
         (107593944924391002493964178988647847*NC*NH)/
          62473951522764313959310884000 - (156962849069*lm*NC*NH)/3742200 - 
         (26026*lm^2*NC*NH)/3 - (22831439126797*NM*NC*Pi^2)/810 - 
         (18449717*NC*NL*Pi^2)/810 + (4070581239232048642*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(-11791729908549703797385914406731517609681/
            30311873139589490704895640000 - (132614224769*lm)/207900 - 
           156156*lm^2 - (388280778247856863*Pi^2)/7484400 + 
           (136045243007022269357*Im[PolyLog[2, (-1)^(1/3)]])/
            (103557496709700*Sqrt[3]) - 104104*Zeta[3]) + 
         CA*NC*(47167008826875960894534720108562300692691/
            242494985116715925639165120000 + (198281726669*lm)/680400 + 
           (143143*lm^2)/3 + (388281062521160023*Pi^2)/14968800 - 
           (136045243007022269357*Im[PolyLog[2, (-1)^(1/3)]])/
            (207114993419400*Sqrt[3]) + 52052*Zeta[3])), 
      (21271889496827408892510482787641885869520736240919*CF^2*NC)/
        72579893621762827442971137275366400000 + (1219414334933*CF^2*lm*NC)/
        9408960 + (221949*CF^2*lm^2*NC)/2 + 
       (47099672862227724248615789194788876541*CF*NM*NC)/
        85155178091690761262208000 + (2002530308573*CF*lm*NM*NC)/169361280 + 
       (24661*CF*lm^2*NM*NC)/4 - (6903677492774085523*CF*NC*NL)/
        17971878078000 + (2002530308573*CF*lm*NC*NL)/169361280 + 
       (24661*CF*lm^2*NC*NL)/4 - 
       (1988326731497332816529618628838103387469291617303*CF*NC*NH)/
        150524925970907100255448266005008464000000 + 
       (2002530308573*CF*lm*NC*NH)/169361280 + (24661*CF*lm^2*NC*NH)/4 - 
       (25484665202710401955913*CF^2*NC*Pi^2)/181945764000 - 
       (8281*CF^2*lm*NC*Pi^2)/18 - (224934998436724861*CF*NM*NC*Pi^2)/
        898128 - (8281*CF*lm*NM*NC*Pi^2)/324 + (6440305781*CF*NC*NL*Pi^2)/
        320760 - (8281*CF*lm*NC*NL*Pi^2)/324 - (8281*CF*lm*NC*NH*Pi^2)/
        324 + (1057580764064292999209*CF^2*NC*Pi^3)/(3355262893394280*
         Sqrt[3]) + (338422306919034574985*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) + (6165341*CF^2*NC*Pi^4)/900 - 
       (30913039078652839836903671*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (12917762139567978000*Sqrt[3]) - (282220228583793962021269*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(35230260380639940*Sqrt[3]) + 
       (10409308*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (302165932589797999774*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (25889374177425*Sqrt[3]) + (19338417538230547142*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (151082966294898999887*CF^2*NC*Pi*Log[3]^2)/(621344980258200*
         Sqrt[3]) + (9669208769115273571*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + 
       (CF*NC*(-23*CA*(-1743137812945596045340799 + 4728035634565042800*lm) + 
          12*(46*CF*(-145261152684254972246809 + 644732131986142200*lm) + 
            33*(6325*(-57242529297688826249 + 7893873669864*lm)*NM + 
              14501036550*(4347067 + 3443116*lm)*NL + 3*(4502882269191429 + 
                16642916987296600*lm)*NH)))*Log[x]^2)/47706179320800 - 
       (CF*NC*(-62013672052002337*CA + 8*(15502294405887356*CF + 
            825*(34096258233248*NM + 11190127*NL)))*Log[x]^3)/267300 - 
       (1123290664448805829487984587*CF^2*NC*PolyGamma[2, 1])/
        13726075472976600 - (624166266482933*CF*NM*NC*PolyGamma[2, 1])/
        3240 + (2567764470124749759113*CF*NC*NH*PolyGamma[2, 1])/
        4117822641892980 + CA*CF*NC*
        (-21271840873787635687072428880015956780673638281017/
          145159787243525654885942274550732800000 - (271271*lm^2)/8 + 
         (3920717008292921732453*Pi^2)/55983312000 - 
         (1057580764064292999209*Pi^3)/(6710525786788560*Sqrt[3]) - 
         (55819309*Pi^4)/16200 + lm*(-3331454385053/30792960 + 
           (91091*Pi^2)/648) + (30913039078652839836903671*
           Im[PolyLog[2, (-1)^(1/3)]])/(25835524279135956000*Sqrt[3]) - 
         (5204654*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
         (151082966294898999887*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (25889374177425*Sqrt[3]) - (151082966294898999887*Pi*Log[3]^2)/
          (1242689960516400*Sqrt[3]) + (1123290664448805829487984587*
           PolyGamma[2, 1])/27452150945953200 - (257905625923131841697655647*
           Zeta[3])/7549341510137130) + (2579029301091185344318469519*CF^2*NC*
         Zeta[3])/37746707550685650 + (57754148134387*CF*NM*NC*Zeta[3])/
        1620 + (12688988*CF*NC*NL*Zeta[3])/27 - 
       (6201638424096250932547*CF*NC*NH*Zeta[3])/2058911320946490 + 
       CF*Log[x]*((-273286421944197289380925778113*NM*NC)/
          182899268970818400 + (17232814417*lm*NM*NC)/106920 + 
         (82810*lm^2*NM*NC)/3 + (3430341843643571*NC*NL)/4149351360 + 
         (17232814417*lm*NC*NL)/106920 + (82810*lm^2*NC*NL)/3 + 
         (12621374837242870358888541916625594813*NC*NH)/
          937109272841464709389663260000 + (17232814417*lm*NC*NH)/106920 + 
         (82810*lm^2*NC*NH)/3 - (34096257495667*NM*NC*Pi^2)/162 + 
         (12680707*NC*NL*Pi^2)/162 - (19338417538230547142*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(45688127244265148067483402568829421465823/
            103926422192878253845356480000 - (20989076017*lm)/19440 - 
           (455455*lm^2)/3 + (62013149746531747*Pi^2)/1069200 + 
           (151082966294898999887*Im[PolyLog[2, (-1)^(1/3)]])/
            (77668122532275*Sqrt[3]) - 165620*Zeta[3]) + 
         CF*NC*(-22844119971771315185614035911898280739741/
            25981605548219563461339120000 + (15019303117*lm)/5940 + 
           496860*lm^2 - (62013209838547423*Pi^2)/534600 - 
           (302165932589797999774*Im[PolyLog[2, (-1)^(1/3)]])/
            (77668122532275*Sqrt[3]) + 331240*Zeta[3])), 
      (27827643021096184581341598967557718474628746698748304531*CF^2*NC)/
        18785510761169206111879943597425056307200000 - 
       (30286638511027*CF^2*lm*NC)/1987642800 - (264348*CF^2*lm^2*NC)/5 + 
       (1040146335003065356029748938247451580030167*CF*NM*NC)/
        1295103814802001865346605920000 - (109101048345187*CF*lm*NM*NC)/
        35777570400 - (14686*CF*lm^2*NM*NC)/5 + 
       (5978416919396261879431*CF*NC*NL)/30372473951820000 - 
       (109101048345187*CF*lm*NC*NL)/35777570400 - (14686*CF*lm^2*NC*NL)/
        5 + (5915549544367695502790264612010254422726009321*CF*NC*NH)/
        2213601852513339709638945088308948000000 - 
       (109101048345187*CF*lm*NC*NH)/35777570400 - (14686*CF*lm^2*NC*NH)/
        5 - (1559604025225463736829487*CF^2*NC*Pi^2)/2270683134720 - 
       (98*CF^2*lm*NC*Pi^2)/45 - (28528424786103039293*CF*NM*NC*Pi^2)/
        72972900 - (49*CF*lm*NM*NC*Pi^2)/405 - (50191541869*CF*NC*NL*Pi^2)/
        5212350 - (49*CF*lm*NC*NL*Pi^2)/405 - (49*CF*lm*NC*NH*Pi^2)/405 - 
       (27352783495222227410179*CF^2*NC*Pi^3)/(157026303410852304*Sqrt[3]) - 
       (17835039985564337291*CF*NC*NH*Pi^3)/(45753584909922*Sqrt[3]) - 
       (10147249*CF^2*NC*Pi^4)/2700 + (794570685759983718843874889*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3929583242856578907600*Sqrt[3]) + 
       (7274942086513444477187*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1761513019031997*Sqrt[3]) - (1258964*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (3907540499317461058597*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(605811355751745*Sqrt[3]) - 
       (20382902840644956904*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1412147682405*Sqrt[3]) - (3907540499317461058597*CF^2*NC*Pi*
         Log[3]^2)/(29078945076083760*Sqrt[3]) - 
       (2547862855080619613*CF*NC*NH*Pi*Log[3]^2)/(8472886094430*Sqrt[3]) - 
       (CF*NC*(-(CA*(1277901724127660328578671213 + 346524276202594570080*
              lm)) + 9*(CF*(283978180284864748415949037 + 
              126008827710034389120*lm) + 1144*(3*(47097261991135697680511 + 
                2039769938326120*lm)*NM + 17*(34120086*(11805961 + 
                  10549780*lm)*NL + (109748601832913 + 359959400881080*lm)*
                 NH))))*Log[x]^2)/310090165585200 + 
       (CF*NC*(996025959134128271*CA - 1430*(1393053718152475*CF + 
            783010820956272*NM - 82288284*NL))*Log[x]^3)/868725 - 
       (27362153045074540925172753161*CF^2*NC*PolyGamma[2, 1])/
        61767339628394700 - (1727929468502233*CF*NM*NC*PolyGamma[2, 1])/
        8100 - (1201027564199094917039*CF*NC*NH*PolyGamma[2, 1])/
        3431518868244150 + CA*CF*NC*
        (-76526042480713375123944459510910116433526687484856837909/
          103320309186430633615339689785837809689600000 + (80773*lm^2)/5 + 
         (4873762690485989872226797*Pi^2)/14191769592000 + 
         (27352783495222227410179*Pi^3)/(314052606821704608*Sqrt[3]) + 
         (30440179*Pi^4)/16200 + lm*(242846713518307/6505012800 + 
           (539*Pi^2)/810) - (794570685759983718843874889*
           Im[PolyLog[2, (-1)^(1/3)]])/(7859166485713157815200*Sqrt[3]) + 
         (629482*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (3907540499317461058597*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1211622711503490*Sqrt[3]) + (3907540499317461058597*Pi*Log[3]^2)/
          (58157890152167520*Sqrt[3]) + (27362153045074540925172753161*
           PolyGamma[2, 1])/123534679256789400 - 
         (575379116182210437464500949539*Zeta[3])/4416364783430221050) + 
       (2301520201780200608030155344763*CF^2*NC*Zeta[3])/
        8832729566860442100 + (882109969183127*CF*NM*NC*Zeta[3])/4050 - 
       (31098352*CF*NC*NL*Zeta[3])/135 - (1550038926239429550119*CF*NC*NH*
         Zeta[3])/1715759434122075 + CF*Log[x]*
        ((-301586336395636683825692110225279*NM*NC)/120942141606953667000 - 
         (114841240451*lm*NM*NC)/1737450 - (40768*lm^2*NM*NC)/3 - 
         (125598996095521733*NC*NL)/337134798000 - (114841240451*lm*NC*NL)/
          1737450 - (40768*lm^2*NC*NL)/3 - 
         (39600826442429990055586001134801381*NC*NH)/
          13781018718256833961612695000 - (114841240451*lm*NC*NH)/1737450 - 
         (40768*lm^2*NC*NH)/3 - (130501844585894*NM*NC*Pi^2)/405 - 
         (15549274*NC*NL*Pi^2)/405 + (20382902840644956904*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) + 
         CF*NC*(-26992444829946248088528156441273091900324703243/
            6432318048783813765250648616640000 - (97133150051*lm)/96525 - 
           244608*lm^2 - (3984106891806948677*Pi^2)/6949800 + 
           (3907540499317461058597*Im[PolyLog[2, (-1)^(1/3)]])/
            (1817434067255235*Sqrt[3]) - 163072*Zeta[3]) + 
         CA*NC*(613464830404579465001010698900265773736426283/
            292378093126536989329574937120000 + (144891333251*lm)/315900 + 
           (224224*lm^2)/3 + (1992053668488451453*Pi^2)/6949800 - 
           (3907540499317461058597*Im[PolyLog[2, (-1)^(1/3)]])/
            (3634868134510470*Sqrt[3]) + 81536*Zeta[3])), 
      (13704753107519871792107252565831843822909100268683718797*CF^2*NC)/
        4132812367457225344613587591433512387584000 + 
       (6554042730745*CF^2*lm*NC)/35335872 + (317695*CF^2*lm^2*NC)/2 + 
       (76948155913231300214373153892146166012207*CF*NM*NC)/
        12791148788167919657744256000 + (10763803926385*CF*lm*NM*NC)/
        636045696 + (317695*CF*lm^2*NM*NC)/36 - 
       (44042789021158866023*CF*NC*NL)/67494386559600 + 
       (10763803926385*CF*lm*NC*NL)/636045696 + (317695*CF*lm^2*NC*NL)/36 - 
       (9808204698359766069556929549635504874405302117537*CF*NC*NH)/
        451574777912721300766344798015025392000000 + 
       (10763803926385*CF*lm*NC*NH)/636045696 + (317695*CF*lm^2*NC*NH)/36 - 
       (200129128027745677179387427*CF^2*NC*Pi^2)/129428938679040 - 
       (1225*CF^2*lm*NC*Pi^2)/2 - (1936223770475812877*CF*NM*NC*Pi^2)/
        720720 - (1225*CF*lm*NM*NC*Pi^2)/36 + (2862186985*CF*NC*NL*Pi^2)/
        92664 - (1225*CF*lm*NC*NL*Pi^2)/36 - (1225*CF*lm*NC*NH*Pi^2)/36 + 
       (29327402294454105482165*CF^2*NC*Pi^3)/(57100473967582656*Sqrt[3]) + 
       (1671817367289855555035*CF*NC*NH*Pi^3)/(549043018919064*Sqrt[3]) + 
       (13794361*CF^2*NC*Pi^4)/1296 - (221823258826227866595347719*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(57157574441550238656*Sqrt[3]) - 
       (1407959946471516767847487*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (105690781141919820*Sqrt[3]) + 
       (3181255*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (837925779841545870919*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (44059007691036*Sqrt[3]) + (95532420987991746002*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) + 
       (837925779841545870919*CF^2*NC*Pi*Log[3]^2)/(2114832369169728*
         Sqrt[3]) + (47766210493995873001*CF*NC*NH*Pi*Log[3]^2)/
        (20334926626632*Sqrt[3]) + CF*((-2301481541409251870588300761*CF*NC)/
          124036066234080 + CA*(11507411672511555152693976839/
            1240360662340800 - (7591155*lm)/2)*NC + 12421890*CF*lm*NC - 
         (258915701684848415155439*NM*NC)/8031343320 + 690105*lm*NM*NC + 
         (3474965*NC*NL)/4 + 690105*lm*NC*NL + (23634576234556171*NC*NH)/
          120470149800 + 690105*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-1790722176059672191*CA + 4*(895350662563257917*CF + 
            115830*(13590524736716*NM + 690105*NL)))*Log[x]^3)/694980 - 
       (37614995503030086918479619991*CF^2*NC*PolyGamma[2, 1])/
        41178226418929800 - (48167240176405*CF*NM*NC*PolyGamma[2, 1])/24 + 
       (37555181065764128314471*CF*NC*NH*PolyGamma[2, 1])/
        37060403777036820 + CA*CF*NC*
        (-68523742715798114118706166684624190361300558086941712719/
          41328123674572253446135875914335123875840000 - (3494645*lm^2)/72 + 
         (52665558652323224578133201*Pi^2)/68120494041600 - 
         (29327402294454105482165*Pi^3)/(114200947935165312*Sqrt[3]) - 
         (13864921*Pi^4)/2592 + lm*(-17907641106865/115644672 + 
           (13475*Pi^2)/72) + (221823258826227866595347719*
           Im[PolyLog[2, (-1)^(1/3)]])/(114315148883100477312*Sqrt[3]) - 
         (3181255*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
         (837925779841545870919*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (88118015382072*Sqrt[3]) - (837925779841545870919*Pi*Log[3]^2)/
          (4229664738339456*Sqrt[3]) + (37614995503030086918479619991*
           PolyGamma[2, 1])/82356452837859600 - 
         (4414672399165122521147756900729*Zeta[3])/11776972755813922800) + 
       (4414665535410423239486637267749*CF^2*NC*Zeta[3])/
        5888486377906961400 + (6194799895187*CF*NM*NC*Zeta[3])/12 + 
       (2326340*CF*NC*NL*Zeta[3])/3 - (91753348504404574415309*CF*NC*NH*
         Zeta[3])/18530201888518410 + CF*Log[x]*
        ((-34030200880921150981841319890887*NM*NC)/2150082517456954080 + 
         (7695702329*lm*NM*NC)/30888 + (127400*lm^2*NM*NC)/3 + 
         (8136679345426991*NC*NL)/5993507520 + (7695702329*lm*NC*NL)/
          30888 + (127400*lm^2*NC*NL)/3 + 
         (62339342404043463984315814005343425977*NC*NH)/
          2811327818524394128168989780000 + (7695702329*lm*NC*NH)/30888 + 
         (127400*lm^2*NC*NH)/3 - (40771574281115*NM*NC*Pi^2)/18 + 
         (2325115*NC*NL*Pi^2)/18 - (95532420987991746002*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CA*NC*(1527976375719589380217742776057259771887718089/
            321615902439190688262532430832000 - (9365151929*lm)/5616 - 
           (700700*lm^2)/3 + (3581439822122057321*Pi^2)/5559840 + 
           (837925779841545870919*Im[PolyLog[2, (-1)^(1/3)]])/
            (264354046146216*Sqrt[3]) - 254800*Zeta[3]) + 
         CF*NC*(-6111907729941266019416944175233078554074456611/
            643231804878381376525064861664000 + (6711919529*lm)/1716 + 
           764400*lm^2 - (3581440336068738569*Pi^2)/2779920 - 
           (837925779841545870919*Im[PolyLog[2, (-1)^(1/3)]])/
            (132177023073108*Sqrt[3]) + 509600*Zeta[3])), 
      (97093043389374883195472088920313756724273339076957219310751*CF^2*NC)/
        5917435889768299925242182233188892736768000000 - 
       (187674693048047*CF^2*lm*NC)/8657288640 - (149629*CF^2*lm^2*NC)/2 + 
       (132536327719633741173973375533849804551230601*CF*NM*NC)/
        14390042386688909614962288000000 - (673442733766007*CF*lm*NM*NC)/
        155831195520 - (149629*CF*lm^2*NM*NC)/36 + 
       (588880735588785990893*CF*NC*NL)/1799850308256000 - 
       (673442733766007*CF*lm*NC*NL)/155831195520 - (149629*CF*lm^2*NC*NL)/
        36 + (5784287481016232065340402741422220998130149225957*CF*NC*NH)/
        1354724333738163902299034394045076176000000 - 
       (673442733766007*CF*lm*NC*NH)/155831195520 - (149629*CF*lm^2*NC*NH)/
        36 - (6761487274196966506066830389*CF^2*NC*Pi^2)/906002570753280 - 
       (5*CF^2*lm*NC*Pi^2)/2 - (28254312177448543187*CF*NM*NC*Pi^2)/
        6486480 - (5*CF*lm*NM*NC*Pi^2)/36 - (4735186847*CF*NC*NL*Pi^2)/
        324324 - (5*CF*lm*NC*NL*Pi^2)/36 - (5*CF*lm*NC*NH*Pi^2)/36 - 
       (389022791584011885436267*CF^2*NC*Pi^3)/(1413236730697670736*
         Sqrt[3]) - (1034975639840916879595*CF*NC*NH*Pi^3)/
        (1647129056757192*Sqrt[3]) - (4687789*CF^2*NC*Pi^4)/810 + 
       (3545250987264316052292216737*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (9902549771998578847152*Sqrt[3]) + (2069338947064565045487977*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(317072343425759460*Sqrt[3]) - 
       (1893784*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (389022791584011885436267*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(38166115412359935*Sqrt[3]) - 
       (59141465133766678834*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2541865828329*Sqrt[3]) - (389022791584011885436267*CF^2*NC*Pi*
         Log[3]^2)/(1831973539793276880*Sqrt[3]) - 
       (29570732566883339417*CF*NC*NH*Pi*Log[3]^2)/(61004779879896*
         Sqrt[3]) - (CF*NC*(-1001*CA*(194198587468821625999983217 + 
            7946267219897806800*lm) + 4*(CF*(97196394030991493513808915913 + 
              6507992853096303769200*lm) + 
            9009*(9*(699670955970470889330983 + 4459184747417400*lm)*NM + 
              43503109650*(1027273 + 922524*lm)*NL + (12843271942680037 + 
                40132662726756600*lm)*NH)))*Log[x]^2)/4341262318192800 + 
       (CF*NC*(60897320861586525083*CA - 308*(395437623649720997*CF + 
            45630*(5006236822462*NM - 76877*NL)))*Log[x]^3)/4864860 - 
       (425875842452535452692046145119*CF^2*NC*PolyGamma[2, 1])/
        88944969064888368 - (4386497003868781*CF*NM*NC*PolyGamma[2, 1])/
        1800 - (102673556156149608677767*CF*NC*NH*PolyGamma[2, 1])/
        185302018885184100 + CA*CF*NC*
        (-267005881437253492423125807908058671626791494717433874669559/
          32545897393725649588832002282538910052224000000 + 
         (1645919*lm^2)/72 + (177933876207330315938481601*Pi^2)/
          47684345829120 + (389022791584011885436267*Pi^3)/
          (2826473461395341472*Sqrt[3]) + (4687609*Pi^4)/1620 + 
         lm*(1497776378620727/28332944640 + (55*Pi^2)/72) - 
         (3545250987264316052292216737*Im[PolyLog[2, (-1)^(1/3)]])/
          (19805099543997157694304*Sqrt[3]) + 
         (946892*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (389022791584011885436267*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (76332230824719870*Sqrt[3]) + (389022791584011885436267*Pi*
           Log[3]^2)/(3663947079586553760*Sqrt[3]) + 
         (425875842452535452692046145119*PolyGamma[2, 1])/
          177889938129776736 - (50366429281959872645835991154623*Zeta[3])/
          34243813089982021680) + (50366440919231776939693815293683*CF^2*NC*
         Zeta[3])/17121906544991010840 + (2121612071422619*CF*NM*NC*Zeta[3])/
        900 - (1123156*CF*NC*NL*Zeta[3])/3 - 
       (124108573081825374094267*CF*NC*NH*Zeta[3])/92651009442592050 + 
       CF*Log[x]*((-3644080400346439269347353773065419*NM*NC)/
          134380157341059630000 - (21805498277*lm*NM*NC)/216216 - 
         (61880*lm^2*NM*NC)/3 - (123451463101123*NC*NL)/203860800 - 
         (21805498277*lm*NC*NL)/216216 - (61880*lm^2*NC*NL)/3 - 
         (39051531232421514650490398637884517397*NC*NH)/
          8433983455573182384506969340000 - (21805498277*lm*NC*NH)/216216 - 
         (61880*lm^2*NC*NH)/3 - (21693693876413*NM*NC*Pi^2)/6 - 
         (374387*NC*NL*Pi^2)/6 + (59141465133766678834*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(-18157363796356574408369679434244530086788832459361/
            405236037073380267210790862848320000 - (18460636757*lm)/12012 - 
           371280*lm^2 - (2342204920573954243*Pi^2)/374220 + 
           (389022791584011885436267*Im[PolyLog[2, (-1)^(1/3)]])/
            (114498346237079805*Sqrt[3]) - 247520*Zeta[3]) + 
         CA*NC*(4539341140376051604267399063286078184937793072199/
            202618018536690133605395431424160000 + (27481626917*lm)/39312 + 
           (340340*lm^2)/3 + (936881983819016743*Pi^2)/299376 - 
           (389022791584011885436267*Im[PolyLog[2, (-1)^(1/3)]])/
            (228996692474159610*Sqrt[3]) + 123760*Zeta[3])), 
      (13055485512345256507416613556081072266097802402614812672451*CF^2*NC)/
        353759754279626625965565242201509891872000000 + 
       (28039993996195*CF^2*lm*NC)/108216108 + 221960*CF^2*lm^2*NC + 
       (29170858790033426229352373257337884604295317*CF*NM*NC)/
        449688824584028425467571500000 + (46054729494955*CF*lm*NM*NC)/
        1947889944 + (110980*CF*lm^2*NM*NC)/9 - 
       (45416977558376852159*CF*NC*NL)/42541916376960 + 
       (46054729494955*CF*lm*NC*NL)/1947889944 + (110980*CF*lm^2*NC*NL)/9 - 
       (128519193266181228235852702988647217288531184512518343*CF*NC*NH)/
        3717041824748258933981754356591103321352200000 + 
       (46054729494955*CF*lm*NC*NH)/1947889944 + (110980*CF*lm^2*NC*NH)/9 - 
       (136312016684524694042655601*CF^2*NC*Pi^2)/8089308667440 - 
       800*CF^2*lm*NC*Pi^2 - (11591849313499179247*CF*NM*NC*Pi^2)/405405 - 
       (400*CF*lm*NM*NC*Pi^2)/9 + (3742732745*CF*NC*NL*Pi^2)/81081 - 
       (400*CF*lm*NC*NL*Pi^2)/9 - (400*CF*lm*NC*NH*Pi^2)/9 + 
       (52001410097112681273035*CF^2*NC*Pi^3)/(64238033213530488*Sqrt[3]) + 
       (8994264644105016209920*CF*NC*NH*Pi^3)/(1853020188851841*Sqrt[3]) + 
       (1299571*CF^2*NC*Pi^4)/81 - (13740151521573631528152543371*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2250579493636040647080*Sqrt[3]) - 
       (15300656615055187166630764*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (713412772707958785*Sqrt[3]) + 
       (4726480*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (20800564038845072509214*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(693929371133817*Sqrt[3]) + 
       (4111663837305150267392*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) + 
       (10400282019422536254607*CF^2*NC*Pi*Log[3]^2)/(16654304907211608*
         Sqrt[3]) + (256978989831571891712*CF*NC*NH*Pi*Log[3]^2)/
        (68630377364883*Sqrt[3]) + CF*((-1192729884124434412199094383*CF*NC)/
          5898454236675 + CA*(954183955843730106455471323/9437526778680 - 
           (18313460*lm)/3)*NC + 19978320*CF*lm*NC - 
         (191368550892394591374598*NM*NC)/557732175 + (3329720*lm*NM*NC)/
          3 + (12543694*NC*NL)/9 + (3329720*lm*NC*NL)/3 + 
         (3197382156688696*NC*NH)/9704539845 + (3329720*lm*NC*NH)/3)*
        Log[x]^2 - (4*CF*NC*(-8583420151114660618*CA + 17166808997258951951*
           CF + 540540*(54421001215213*NM + 416215*NL))*Log[x]^3)/1216215 - 
       (1396935608734727688928984512644*CF^2*NC*PolyGamma[2, 1])/
        138976514163888075 - (1877223359858641*CF*NM*NC*PolyGamma[2, 1])/
        90 + (266094728389620740366473*CF*NC*NH*PolyGamma[2, 1])/
        166771816996665690 + CA*CF*NC*
        (-1631935611062528771063749343938606572966357894529485424147/
          88439938569906656491391310550377472968000000 - (610390*lm^2)/9 + 
         (1363120161988826924260190077*Pi^2)/161786173348800 - 
         (52001410097112681273035*Pi^3)/(128476066427060976*Sqrt[3]) - 
         (1305331*Pi^4)/162 + lm*(-76625189735275/354161808 + 
           (2200*Pi^2)/9) + (13740151521573631528152543371*
           Im[PolyLog[2, (-1)^(1/3)]])/(4501158987272081294160*Sqrt[3]) - 
         (2363240*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (10400282019422536254607*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (693929371133817*Sqrt[3]) - (10400282019422536254607*Pi*Log[3]^2)/
          (33308609814423216*Sqrt[3]) + (698467804367363844464492256322*
           PolyGamma[2, 1])/138976514163888075 - 
         (1130556424825482602406930129857347*Zeta[3])/
          278230981356103926150) + (1130556168379953080477108984700262*CF^2*
         NC*Zeta[3])/139115490678051963075 + 
       (299616332270639*CF*NM*NC*Zeta[3])/45 + (3712120*CF*NC*NL*Zeta[3])/
        3 - (656364812145084743354807*CF*NC*NH*Zeta[3])/83385908498332845 + 
       CF*Log[x]*((-11177244030031015050760510958849293*NM*NC)/
          67190078670529815000 + (10105727134*lm*NM*NC)/27027 + 
         (190400*lm^2*NM*NC)/3 + (1273353983744809*NC*NL)/590269680 + 
         (10105727134*lm*NC*NL)/27027 + (190400*lm^2*NC*NL)/3 + 
         (8677078688291470076715448503529162374601*NC*NH)/
          245526233750897759493589426671000 + (10105727134*lm*NC*NH)/27027 + 
         (190400*lm^2*NC*NH)/3 - (72561335022368*NM*NC*Pi^2)/3 + 
         206140*NC*NL*Pi^2 - (4111663837305150267392*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CA*NC*(13983741953482665384025476461147018347986454061/
            275296220837894203268200314435000 - (6144426767*lm)/2457 - 
           (1047200*lm^2)/3 + (34333674221037194071*Pi^2)/4864860 + 
           (10400282019422536254607*Im[PolyLog[2, (-1)^(1/3)]])/
            (2081788113401451*Sqrt[3]) - 380800*Zeta[3]) + 
         CF*NC*(-223739883062582465712306749221022346322741979891/
            2202369766703153626145602515480000 + (17638483868*lm)/3003 + 
           1142400*lm^2 - (34333674936708760681*Pi^2)/2432430 - 
           (20800564038845072509214*Im[PolyLog[2, (-1)^(1/3)]])/
            (2081788113401451*Sqrt[3]) + 761600*Zeta[3])), 
      (3284935613248293403100813720674197549370913404855599879899201*CF^2*NC)/
        18307067283970677893718001283928136904376000000 - 
       (916703907361061*CF^2*lm*NC)/30435780375 - (517472*CF^2*lm^2*NC)/5 + 
       (2829487870147608989046019971556835628788334053*CF*NM*NC)/
        27318596093479726847154968625000 - (3279153528692861*CF*lm*NM*NC)/
        547844046750 - (258736*CF*lm^2*NM*NC)/45 + 
       (207466745336231190852533*CF*NC*NL)/394842161373660000 - 
       (3279153528692861*CF*lm*NC*NL)/547844046750 - (258736*CF*lm^2*NC*NL)/
        45 + (11543926120924906917616512037672458603984809779766357*CF*NC*
         NH)/1742363355350746375303947354652079681883843750 - 
       (3279153528692861*CF*lm*NC*NH)/547844046750 - (258736*CF*lm^2*NC*NH)/
        45 - (5163439195878311456818849859*CF^2*NC*Pi^2)/64346773491000 - 
       (128*CF^2*lm*NC*Pi^2)/45 - (96938956766401826924*CF*NM*NC*Pi^2)/
        2027025 - (64*CF*lm*NM*NC*Pi^2)/405 - (393038234588*CF*NC*NL*Pi^2)/
        18243225 - (64*CF*lm*NC*NL*Pi^2)/405 - (64*CF*lm*NC*NH*Pi^2)/405 - 
       (51610182974764200618277*CF^2*NC*Pi^3)/(122299332464221506*Sqrt[3]) - 
       (5462262484037082159520*CF*NC*NH*Pi^3)/(5559060566555523*Sqrt[3]) - 
       (3505148*CF^2*NC*Pi^4)/405 + (32381899521730927534402325111*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(53559463911050005783875*Sqrt[3]) + 
       (1396026703271995124233033904*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (139115490678051963075*Sqrt[3]) - 
       (4625088*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (412881463798113604946216*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(26422695285479955*Sqrt[3]) - 
       (2497034278416951844352*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (51610182974764200618277*CF^2*NC*Pi*Log[3]^2)/(158536171712879730*
         Sqrt[3]) - (156064642401059490272*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) - 
       (CF*NC*(-145*CA*(65317507159604454314675719493 + 394390673899610628240*
             lm) + 2*(29*CF*(326587536296423729685647922467 + 
              3226832786451359685600*lm) + 20020*
             (145*(1944430678662759859018651 + 1790893987374492*lm)*NM + 
              5822723907*(49449919 + 44597620*lm)*NL + (86705485117706269 + 
                259679628169301340*lm)*NH)))*Log[x]^2)/19671344879311125 - 
       (16*CF*NC*(-51378764772907461258*CA + 102757548873577572211*CF + 
          60060*(1010897733123797*NM - 2229881*NL))*Log[x]^3)/6081075 - 
       (64180174723476554027054448099286*CF^2*NC*PolyGamma[2, 1])/
        1250788627474992675 - (18424312903545293*CF*NM*NC*PolyGamma[2, 1])/
        675 - (1066609437641601287037757*CF*NC*NH*PolyGamma[2, 1])/
        1250788627474992675 + CA*CF*NC*
        (-205308477147517860650295253190222689902515695382982353621831/
          2288383410496334736714750160491017113047000000 + 
         (1423048*lm^2)/45 + (516343919815626850007363921*Pi^2)/
          12869354698200 + (51610182974764200618277*Pi^3)/
          (244598664928443012*Sqrt[3]) + (8762614*Pi^4)/2025 + 
         lm*(7288158946710461/99608008500 + (352*Pi^2)/405) - 
         (32381899521730927534402325111*Im[PolyLog[2, (-1)^(1/3)]])/
          (107118927822100011567750*Sqrt[3]) + 
         (2312544*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (206440731899056802473108*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (26422695285479955*Sqrt[3]) + (51610182974764200618277*Pi*Log[3]^2)/
          (317072343425759460*Sqrt[3]) + (32090087361738277013527224049643*
           PolyGamma[2, 1])/1250788627474992675 - 
         (20383107815720786642548778583829012*Zeta[3])/
          1252039416102467667675) + (8153243391709718215417913497544068*CF^2*
         NC*Zeta[3])/250407883220493533535 + 
       (17065921371483494*CF*NM*NC*Zeta[3])/675 - 
       (26527072*CF*NC*NL*Zeta[3])/45 - (2426359355906551818343034*CF*NC*NH*
         Zeta[3])/1250788627474992675 + CF*Log[x]*
        ((-396523955898528590999997171993748429*NM*NC)/
          1360599093078228753750 - (909912309304*lm*NM*NC)/6081075 - 
         30464*lm^2*NM*NC - (1044972814266137623*NC*NL)/1095688093500 - 
         (909912309304*lm*NC*NL)/6081075 - 30464*lm^2*NC*NL - 
         (86629455444093232064058205764924426445151*NC*NH)/
          11969403895356265775312484550211250 - (909912309304*lm*NC*NH)/
          6081075 - 30464*lm^2*NC*NH - (3234872766598400*NM*NC*Pi^2)/81 - 
         (39790736*NC*NL*Pi^2)/405 + (2497034278416951844352*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-54030815106121729191414431691360184800393978330833/
            113972635426888200153034930176090000 - (1541943815408*lm)/
            675675 - 548352*lm^2 - (45670013916418852742*Pi^2)/675675 + 
           (412881463798113604946216*Im[PolyLog[2, (-1)^(1/3)]])/
            (79268085856439865*Sqrt[3]) - 365568*Zeta[3]) + 
         CA*NC*(1039054142991439149544723564552498602626491852991/
            4383562901034161544347497314465000 + (572844980252*lm)/552825 + 
           167552*lm^2 + (13701004208176289639*Pi^2)/405405 - 
           (206440731899056802473108*Im[PolyLog[2, (-1)^(1/3)]])/
            (79268085856439865*Sqrt[3]) + 182784*Zeta[3])), 
      (49418408188969779104245693136645519265751494858645748223452507*CF^2*
         NC)/122047115226471185958120008559520912695840000000 + 
       (8629665085916131*CF^2*lm*NC)/24348624300 + 303688*CF^2*lm^2*NC + 
       (6590762262092936168260761801519462100991999929*CF*NM*NC)/
        9502120380340774555532163000000 + (14175453848229931*CF*lm*NM*NC)/
        438275237400 + (151844*CF*lm^2*NM*NC)/9 - 
       (534026718894569413842247*CF*NC*NL)/315873729098928000 + 
       (14175453848229931*CF*lm*NC*NL)/438275237400 + 
       (151844*CF*lm^2*NC*NL)/9 - 
       (555374841930629062386689142581955173285061943791398604911*CF*NC*NH)/
        10381349343850817053335979128488021160600317831250 + 
       (14175453848229931*CF*lm*NC*NH)/438275237400 + 
       (151844*CF*lm^2*NC*NH)/9 - (16064306808489396786367419151*CF^2*NC*
         Pi^2)/88476813550125 - (9248*CF^2*lm*NC*Pi^2)/9 - 
       (367351053946136605361*CF*NM*NC*Pi^2)/1216215 - 
       (4624*CF*lm*NM*NC*Pi^2)/81 + (245412277933*CF*NC*NL*Pi^2)/3648645 - 
       (4624*CF*lm*NC*NL*Pi^2)/81 - (4624*CF*lm*NC*NH*Pi^2)/81 + 
       (2627369220905706671552927*CF^2*NC*Pi^3)/(2119855096046506104*
         Sqrt[3]) + (41803775011558340009600*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) + (47697631*CF^2*NC*Pi^4)/2025 - 
       (17359294871601977363407794520061*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1856728082249733533841000*Sqrt[3]) - 
       (186736124856195257351742676*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5564619627122078523*Sqrt[3]) + 
       (11419376*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (5254738441811413343105854*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(114498346237079805*
         Sqrt[3]) + (19110297148140955432960*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (2627369220905706671552927*CF^2*NC*Pi*Log[3]^2)/(2747960309689915320*
         Sqrt[3]) + (1194393571758809714560*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + 
       CF*((-2955832358957209138090577234251*CF*NC)/1356644474435250 + 
         CA*(5911664761482827509437202805611/5426577897741000 - 
           (257179604*lm)/27)*NC + (93519856*CF*lm*NC)/3 - 
         (21357790253446538457708028*NM*NC)/5892561675 + 
         (46759928*lm*NM*NC)/27 + (58592642*NC*NL)/27 + 
         (46759928*lm*NC*NL)/27 + (169019928916659566*NC*NH)/316468825335 + 
         (46759928*lm*NC*NH)/27)*Log[x]^2 - 
       (4*CF*NC*(-464610510443584614255*CA + 7*(132745823048253955979*CF + 
            42900*(5190290108849801*NM + 5844991*NL)))*Log[x]^3)/6081075 - 
       (45541173831658624024820225676668*CF^2*NC*PolyGamma[2, 1])/
        416929542491664225 - (58350328970341397*CF*NM*NC*PolyGamma[2, 1])/
        270 + (1222571383593880116189277*CF*NC*NH*PolyGamma[2, 1])/
        500315450989997070 + CA*CF*NC*
        (-6177300981860318937357878145094765587670733159452060388162279/
          30511778806617796489530002139880228173960000000 - (835142*lm^2)/9 + 
         (30238695154234658898019133017*Pi^2)/333089180424000 - 
         (2627369220905706671552927*Pi^3)/(4239710192093012208*Sqrt[3]) - 
         (47882591*Pi^4)/4050 + lm*(-23586489323671531/79686406800 + 
           (25432*Pi^2)/81) + (17359294871601977363407794520061*
           Im[PolyLog[2, (-1)^(1/3)]])/(3713456164499467067682000*Sqrt[3]) - 
         (5709688*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (2627369220905706671552927*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (114498346237079805*Sqrt[3]) - (2627369220905706671552927*Pi*
           Log[3]^2)/(5495920619379830640*Sqrt[3]) + 
         (22770586915829312012410112838334*PolyGamma[2, 1])/
          416929542491664225 - (36372144332200059426706271460484453*Zeta[3])/
          834692944068311778450) + (36372143148817837209327144384752854*CF^2*
         NC*Zeta[3])/417346472034155889225 + 
       (10853537473658923*CF*NM*NC*Zeta[3])/135 + 
       (17257448*CF*NC*NL*Zeta[3])/9 - (3040092935493451238372003*CF*NC*NH*
         Zeta[3])/250157725494998535 + CF*Log[x]*
        ((-37343440696540556059357033630458851*NM*NC)/21511448111908755000 + 
         (665091228446*lm*NM*NC)/1216215 + 92480*lm^2*NM*NC + 
         (2919515149614999389*NC*NL)/876550474800 + (665091228446*lm*NC*NL)/
          1216215 + 92480*lm^2*NC*NL + 
         (503744623018946049540522505859905215979034957*NC*NH)/
          9202077714749897128060238122202409000 + (665091228446*lm*NC*NH)/
          1216215 + 92480*lm^2*NC*NH - (20761160440179808*NM*NC*Pi^2)/81 + 
         (25876924*NC*NL*Pi^2)/81 - (19110297148140955432960*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(204367479164583030180148880351905346936341364713543/
            379908784756294000510116433920300000 - (404120972623*lm)/110565 - 
           508640*lm^2 + (123896132794638529289*Pi^2)/1621620 + 
           (2627369220905706671552927*Im[PolyLog[2, (-1)^(1/3)]])/
            (343495038711239415*Sqrt[3]) - 554880*Zeta[3]) + 
         CF*NC*(-817469922799292925466668535416838544504782558676647/
            759817569512588001020232867840600000 + (1161469112092*lm)/
            135135 + 1664640*lm^2 - (619480665817430527931*Pi^2)/4054050 - 
           (5254738441811413343105854*Im[PolyLog[2, (-1)^(1/3)]])/
            (343495038711239415*Sqrt[3]) + 1109760*Zeta[3])), 
      (639640691280995784217542090295688058342499678777898642106889226293391*
         CF^2*NC)/329716478022469560479917538447057229017225548800000000 - 
       (319388450793928259*CF^2*lm*NC)/7791559776000 - 
       (1403503*CF^2*lm^2*NC)/10 + 
       (12026519442833006415782345790472114712571331779060641*CF*NM*NC)/
        10496366121336155499524135854003200000 - 
       (1139549264816077859*CF*lm*NM*NC)/140248075968000 - 
       (1403503*CF*lm^2*NM*NC)/180 + (940556534893193957552399*CF*NC*NL)/
        1148631742177920000 - (1139549264816077859*CF*lm*NC*NL)/
        140248075968000 - (1403503*CF*lm^2*NC*NL)/180 + 
       (227223259848136341091562956003236596400176135420820009097*CF*NC*NH)/
        22678403686620238213580890938819698492703414312960 - 
       (1139549264816077859*CF*lm*NC*NH)/140248075968000 - 
       (1403503*CF*lm^2*NC*NH)/180 - (541481766394045209535074546259*CF^2*NC*
         Pi^2)/633568231296000 - (289*CF^2*lm*NC*Pi^2)/90 - 
       (25220073518062058887529*CF*NM*NC*Pi^2)/48648600 - 
       (289*CF*lm*NM*NC*Pi^2)/1620 - (18122717593069*CF*NC*NL*Pi^2)/
        583783200 - (289*CF*lm*NC*NL*Pi^2)/1620 - (289*CF*lm*NC*NH*Pi^2)/
        1620 - (14793011342813691325489297*CF^2*NC*Pi^3)/
        (23481471833130529152*Sqrt[3]) - (5544437506659946140085*CF*NC*NH*
         Pi^3)/(3706040377703682*Sqrt[3]) - (408761821*CF^2*NC*Pi^4)/32400 + 
       (40374219360799856488142001924599*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (41133668283686404442016000*Sqrt[3]) + 
       (2793404092677985290183827993*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (185487320904069284100*Sqrt[3]) - 
       (6623149*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (14793011342813691325489297*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(634144686851518920*
         Sqrt[3]) - (1267300001522273403448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (14793011342813691325489297*CF^2*NC*Pi*Log[3]^2)/
        (30438944968872908160*Sqrt[3]) - (158412500190284175431*CF*NC*NH*Pi*
         Log[3]^2)/(137260754729766*Sqrt[3]) - 
       (CF*NC*(-31*CA*(129117681281314418586948453914873923 + 
            112852796223080384767296000*lm) + 
          26*(31*CF*(9932129331530699329473037807282871 + 
              14205247077031097383296000*lm) + 
            15400*(31*(391207525894954269610391323997 + 51245480075869759680*
                 lm)*NM + 49097207983824*(35743639 + 32356420*lm)*NL + 
              (550712130515040345629 + 1588609882351962550080*lm)*NH)))*
         Log[x]^2)/780558964811065440000 + 
       (CF*NC*(70322646404756449213785*CA - 364*(386388178180062143351*CF + 
            1320*(176258304555727163*NM - 55005914*NL)))*Log[x]^3)/
        48648600 - (10915976029639588106027575361435041*CF^2*NC*
         PolyGamma[2, 1])/20012618039599882800 - 
       (90228421004606419*CF*NM*NC*PolyGamma[2, 1])/300 - 
       (38424652746804784671053179*CF*NC*NH*PolyGamma[2, 1])/
        30018927059399824200 + CA*CF*NC*(-83153289941257814219525673454318922\
67771693798964215283686369881921333/
          8572628428584208572477855999623487954447864268800000000 + 
         (15438533*lm^2)/360 + (31851868613319436712654132903*Pi^2)/
          74537438976000 + (14793011342813691325489297*Pi^3)/
          (46962943666261058304*Sqrt[3]) + (408752573*Pi^4)/64800 + 
         lm*(2531337312853665059/25499650176000 + (3179*Pi^2)/3240) - 
         (40374219360799856488142001924599*Im[PolyLog[2, (-1)^(1/3)]])/
          (82267336567372808884032000*Sqrt[3]) + 
         (6623149*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (14793011342813691325489297*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1268289373703037840*Sqrt[3]) + (14793011342813691325489297*Pi*
           Log[3]^2)/(60877889937745816320*Sqrt[3]) + 
         (10915976029639588106027575361435041*PolyGamma[2, 1])/
          40025236079199765600 - (546448835480782674745919472872770481*
           Zeta[3])/3081943178098381951200) + 
       (546448837962179262396838402945214537*CF^2*NC*Zeta[3])/
        1540971589049190975600 + (40333286550049891*CF*NM*NC*Zeta[3])/150 - 
       (40624033*CF*NC*NL*Zeta[3])/45 - (41294005515388067216877139*CF*NC*
         NH*Zeta[3])/15009463529699912100 + 
       CF*Log[x]*((-90800599081488478465273250053711685302237*NM*NC)/
          29293154234337033776736000 - (21077889574831*lm*NM*NC)/97297200 - 
         43928*lm^2*NM*NC - (582083244692758703*NC*NL)/398432034000 - 
         (21077889574831*lm*NC*NL)/97297200 - 43928*lm^2*NC*NL - 
         (216236064138158267798379285234332908445302973*NC*NH)/
          19631099124799780539861841327365139200 - (21077889574831*lm*NC*NH)/
          97297200 - 43928*lm^2*NC*NH - (35251660942391861*NM*NC*Pi^2)/81 - 
         (60936194*NC*NL*Pi^2)/405 + (1267300001522273403448*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-176057435248629245831857405979453692136155236438617960417/
            35391133437789406644443954318064624000000 - (17872336023631*lm)/
            5405400 - 790704*lm^2 - (3606289568208952701677*Pi^2)/4989600 + 
           (14793011342813691325489297*Im[PolyLog[2, (-1)^(1/3)]])/
            (1902434060554556760*Sqrt[3]) - 527136*Zeta[3]) + 
         CA*NC*(416135756403099863894373003375186465885854473689712764797/
            167303539887731740501007784049032768000000 + (26517616813231*lm)/
            17690400 + 241604*lm^2 + (400698841051412213257*Pi^2)/1108800 - 
           (14793011342813691325489297*Im[PolyLog[2, (-1)^(1/3)]])/
            (3804868121109113520*Sqrt[3]) + 263568*Zeta[3])), 
      (171406299859189439741917312663922965615497106564806294152487635251*
         CF^2*NC)/39064153240301702312498774206532184800400384000000 + 
       (9154947517920461*CF^2*lm*NC)/19238419200 + (815745*CF^2*lm^2*NC)/2 + 
       (19230978617487925941481782711477581461952545127428601*CF*NM*NC)/
        2614037539796360565015589388928000000 + 
       (15040064119284461*CF*lm*NM*NC)/346291545600 + 
       (271915*CF*lm^2*NM*NC)/12 - (60883503257845877502913*CF*NC*NL)/
        23398054007328000 + (15040064119284461*CF*lm*NC*NL)/346291545600 + 
       (271915*CF*lm^2*NC*NL)/12 - 
       (4982337910844808655622476902726629991966999497775411434668253*CF*NC*
         NH)/61725493905115567718415731385900389042640341376000000 + 
       (15040064119284461*CF*lm*NC*NH)/346291545600 + 
       (271915*CF*lm^2*NC*NH)/12 - (835544467656496633427818038871*CF^2*NC*
         Pi^2)/431429795596800 - (2601*CF^2*lm*NC*Pi^2)/2 - 
       (856220123547117473461*CF*NM*NC*Pi^2)/270270 - 
       (289*CF*lm*NM*NC*Pi^2)/4 + (15350819919*CF*NC*NL*Pi^2)/160160 - 
       (289*CF*lm*NC*NL*Pi^2)/4 - (289*CF*lm*NC*NH*Pi^2)/4 + 
       (23528230615973464746181075*CF^2*NC*Pi^3)/(12719130576279036624*
         Sqrt[3]) + (1136767419500658189257615*CF*NC*NH*Pi^3)/
        (100063090197999414*Sqrt[3]) + (9122659*CF^2*NC*Pi^4)/270 - 
       (8898978043707766039472194429249*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (636592485342765783031200*Sqrt[3]) - (51277041662186687712534890911*
         CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1001631532881974134140*
         Sqrt[3]) + 3239656*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
       (672235160456384707033745*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9814143963178269*Sqrt[3]) + 
       (259832553028721871830312*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) + 
       (672235160456384707033745*CF^2*NC*Pi*Log[3]^2)/(471078910232556912*
         Sqrt[3]) + (32479069128590233978789*CF*NC*NH*Pi*Log[3]^2)/
        (3706040377703682*Sqrt[3]) + 
       CF*((-3142715173375230258959499379613*CF*NC)/135227290255200 + 
         CA*(1539930436570893735137839656357461/132522744450096000 - 
           14471930*lm)*NC + 47362680*CF*lm*NC - 
         (9159637387494348424818949309*NM*NC)/240940299600 + 
         2631260*lm*NM*NC + (9873005*NC*NL)/3 + 2631260*lm*NC*NL + 
         (651708569850535031*NC*NH)/776363187600 + 2631260*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-53085327985382246493783*CA + 
          30800*(3447099075199188601*CF + 702*(8089271011505929*NM + 
              1315630*NL)))*Log[x]^3)/16216200 - 
       (105721757589169955723632897327606307*CF^2*NC*PolyGamma[2, 1])/
        90056781178199472600 - (133885175917180073*CF*NM*NC*PolyGamma[2, 1])/
        60 + (39463578656719563116456231*CF*NC*NH*PolyGamma[2, 1])/
        10806813741383936712 + CA*CF*NC*
        (-1015252698207223710482410989632760739131577504398544453189333108559/
          462759969154343242778831632908150496866281472000000 - 
         (2991065*lm^2)/24 + (81916124274697825030430861593*Pi^2)/
          84594077568000 - (23528230615973464746181075*Pi^3)/
          (25438261152558073248*Sqrt[3]) - (9153871*Pi^4)/540 + 
         lm*(-25026928654932461/62962099200 + (3179*Pi^2)/8) + 
         (8898978043707766039472194429249*Im[PolyLog[2, (-1)^(1/3)]])/
          (1273184970685531566062400*Sqrt[3]) - 
         1619828*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
         (672235160456384707033745*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (19628287926356538*Sqrt[3]) - (672235160456384707033745*Pi*
           Log[3]^2)/(942157820465113824*Sqrt[3]) + 
         (105721757589169955723632897327606307*PolyGamma[2, 1])/
          180113562356398945200 - (2384274095956513400956073315696558591*
           Zeta[3])/5151247883393009832720) + 
       (11921370424980588853268857785484234663*CF^2*NC*Zeta[3])/
        12878119708482524581800 + (9300081248759679*CF*NM*NC*Zeta[3])/10 + 
       2895695*CF*NC*NL*Zeta[3] - (98809224925806958675798849*CF*NC*NH*
         Zeta[3])/5403406870691968356 + CF*Log[x]*
        ((-10099424082597097545049989180008300339449*NM*NC)/
          561171537056265014880000 + (187824046321*lm*NM*NC)/240240 + 
         131784*lm^2*NM*NC + (325521601326642989*NC*NL)/64929664800 + 
         (187824046321*lm*NC*NL)/240240 + 131784*lm^2*NC*NL + 
         (35343955541147830758636293247978764488693746037*NC*NH)/
          427451351910962963367959448257144160000 + (187824046321*lm*NC*NH)/
          240240 + 131784*lm^2*NC*NH - (8089271011870783*NM*NC*Pi^2)/3 + 
         (1447414*NC*NL*Pi^2)/3 - (259832553028721871830312*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CA*NC*(70144738995194362198952910661772243650298020277249483/
            12417941557119090050682089234408640000 - (228118322161*lm)/
            43680 - 724812*lm^2 + (2527872751581982174889*Pi^2)/3088800 + 
           (672235160456384707033745*Im[PolyLog[2, (-1)^(1/3)]])/
            (58884863779069614*Sqrt[3]) - 790704*Zeta[3]) + 
         CF*NC*(-1042150409026428861253605179925064170053966167130137759/
            92247565852884668947924091455607040000 + (492237615603*lm)/
            40040 + 2372112*lm^2 - (1516723651584557052119*Pi^2)/926640 - 
           (672235160456384707033745*Im[PolyLog[2, (-1)^(1/3)]])/
            (29442431889534807*Sqrt[3]) + 1581408*Zeta[3])), 
      (4055922485776962844639838825270028242318953910176093236957459733046108\
5465837*CF^2*NC)/
        1953711877397034005507561731848592471829815881903429120000000 - 
       (380740256184564019*CF^2*lm*NC)/6949878936000 - 
       (935076*CF^2*lm^2*NC)/5 + 
       (15509490657621021903801606554869890967407977297362309849*CF*NM*NC)/
        1240862075875894478120331473121465600000 - 
       (1355540005578434419*CF*lm*NM*NC)/125097820848000 - 
       (155846*CF*lm^2*NM*NC)/15 + (428753217084450348455539*CF*NC*NL)/
        345001918781520000 - (1355540005578434419*CF*lm*NC*NL)/
        125097820848000 - (155846*CF*lm^2*NC*NL)/15 + 
       (1416829228222754068382907916061405071282475962732041041055461*CF*NC*
         NH)/95674515552929129963544383648145603016092529132800000 - 
       (1355540005578434419*CF*lm*NC*NH)/125097820848000 - 
       (155846*CF*lm^2*NC*NH)/15 - (1158326336820257591764746305634859*CF^2*
         NC*Pi^2)/128350364190048000 - (18*CF^2*lm*NC*Pi^2)/5 - 
       (5803272741854408279174*CF*NM*NC*Pi^2)/1044225 - 
       (CF*lm*NM*NC*Pi^2)/5 - (1341608001857*CF*NC*NL*Pi^2)/30630600 - 
       (CF*lm*NC*NL*Pi^2)/5 - (CF*lm*NC*NH*Pi^2)/5 - 
       (243794392929665603345911885*CF^2*NC*Pi^3)/(265367315205094445928*
         Sqrt[3]) - (111299422701980664170810*CF*NC*NH*Pi^3)/
        (50031545098999707*Sqrt[3]) - (12137953*CF^2*NC*Pi^4)/675 + 
       (108727103058603170811476961926344*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (70558681294454565411824625*Sqrt[3]) + 
       (2129991322802620372753552453*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (96310724315574435975*Sqrt[3]) - 
       (9292976*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (13931108167409463048337822*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(409517461736256861*
         Sqrt[3]) - (50879736092334017906656*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (6965554083704731524168911*CF^2*NC*Pi*Log[3]^2)/(9828419081670164664*
         Sqrt[3]) - (3179983505770876119166*CF*NC*NH*Pi*Log[3]^2)/
        (1853020188851841*Sqrt[3]) + 
       CF*((-71852141031626650571301935593393350923*CF*NC)/
          663475120089405624000 - (110243232*CF*lm*NC)/5 + 
         CA*(160384243369102044222494784079064111/2961942500399132250 + 
           (33685432*lm)/5)*NC - (3611347564544154365591758269307*NM*NC)/
          54151332335100 - (6124624*lm*NM*NC)/5 - (101155372*NC*NL)/75 - 
         (6124624*lm*NC*NL)/5 - (23776773960290535059*NC*NH)/
          54151332335100 - (6124624*lm*NC*NH)/5)*Log[x]^2 - 
       (CF*NC*(-1055783417038045919266821*CA + 
          17*(124209814305538885116793*CF + 4324320*(17576811222447601*NM - 
              765578*NL)))*Log[x]^3)/68918850 - 
       (259113963933100696882579107957253199*CF^2*NC*PolyGamma[2, 1])/
        45028390589099736300 - (294156719583240979*CF*NM*NC*PolyGamma[2, 1])/
        90 - (253835736333100120166598391*CF*NC*NH*PolyGamma[2, 1])/
        135085171767299208900 + CA*CF*NC*
        (-1843601130127638741493121440574484938004188530464112665625862259216\
505995421/177610170672457636864323793804417497439074171082129920000000 + 
         (857153*lm^2)/15 + (38610877894317671585576894449441*Pi^2)/
          8556690946003200 + (243794392929665603345911885*Pi^3)/
          (530734630410188891856*Sqrt[3]) + (12137737*Pi^4)/1350 + 
         lm*(3009745640913487219/22745058336000 + (11*Pi^2)/10) - 
         (54363551529301585405738480963172*Im[PolyLog[2, (-1)^(1/3)]])/
          (70558681294454565411824625*Sqrt[3]) + 
         (4646488*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (6965554083704731524168911*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (409517461736256861*Sqrt[3]) + (6965554083704731524168911*Pi*
           Log[3]^2)/(19656838163340329328*Sqrt[3]) + 
         (259113963933100696882579107957253199*PolyGamma[2, 1])/
          90056781178199472600 - (14598216451729537495711331032071763348*
           Zeta[3])/7662481226547102126171) + 
       (2919643292177225291477556081208913042591*CF^2*NC*Zeta[3])/
        766248122654710212617100 + (127686749967197249*CF*NM*NC*Zeta[3])/
        45 - (6744772*CF*NC*NL*Zeta[3])/5 - (258681619682874091227626311*CF*
         NC*NH*Zeta[3])/67542585883649604450 + 
       CF*Log[x]*((-1965004960189050655198607143826219478125777*NM*NC)/
          60151113716234806537272000 - (522315693941*lm*NM*NC)/1701700 - 
         62016*lm^2*NM*NC - (3012953427988461689*NC*NL)/1379755377000 - 
         (522315693941*lm*NC*NL)/1701700 - 62016*lm^2*NC*NL - 
         (10847170798129498749538863586813238227417947229*NC*NH)/
          662549595461992593220337144798573448000 - (522315693941*lm*NC*NH)/
          1701700 - 62016*lm^2*NC*NH - (14061448979671436*NM*NC*Pi^2)/3 - 
         (3372392*NC*NL*Pi^2)/15 + (50879736092334017906656*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*
          (-701011997245302845606079210066210546989818304482175128003642193/
            13529527759172073550596572631644789237539200000 - 
           (3988496011869*lm)/850850 - 1116288*lm^2 - 
           (2111566834826610223435691*Pi^2)/275675400 + 
           (13931108167409463048337822*Im[PolyLog[2, (-1)^(1/3)]])/
            (1228552385208770583*Sqrt[3]) - 744192*Zeta[3]) + 
         CA*NC*
          (175252999332622284296252409065966341700586707456576420599087277/
            6764763879586036775298286315822394618769600000 + 
           (656629946741*lm)/309400 + 341088*lm^2 + 
           (70385561164338002639467*Pi^2)/18378360 - 
           (6965554083704731524168911*Im[PolyLog[2, (-1)^(1/3)]])/
            (1228552385208770583*Sqrt[3]) + 372096*Zeta[3])), 
      (8792971963223182875203334908192339789192574911925168195386725698770446\
69357*CF^2*NC)/18695807439206067038349873032043947098849912745487360000000 + 
       (3494309629600206101*CF^2*lm*NC)/5559903148800 + 
       (1077699*CF^2*lm^2*NC)/2 + 
       (11659346769123605464704004361035354382958781247837330432641*CF*NM*
         NC)/150557931872941863345266885405404492800000 + 
       (5741272903434685301*CF*lm*NM*NC)/100078256678400 + 
       (359233*CF*lm^2*NM*NC)/12 - (7545288368838596805089693*CF*NC*NL)/
        1932010745176512000 + (5741272903434685301*CF*lm*NC*NL)/
        100078256678400 + (359233*CF*lm^2*NC*NL)/12 - 
       (2050871145301282571447334709313283917293290459188496386690647759*CF*
         NC*NH)/17221412799527243393437989056666208542896655243904000000 + 
       (5741272903434685301*CF*lm*NC*NH)/100078256678400 + 
       (359233*CF*lm^2*NC*NH)/12 - (241741719504444294048082240812944491*
         CF^2*NC*Pi^2)/11808233505484416000 - (3249*CF^2*lm*NC*Pi^2)/2 - 
       (3888562510309904820683*CF*NM*NC*Pi^2)/117810 - 
       (361*CF*lm*NM*NC*Pi^2)/4 + (3281248936607*CF*NC*NL*Pi^2)/24504480 - 
       (361*CF*lm*NC*NL*Pi^2)/4 - (361*CF*lm*NC*NH*Pi^2)/4 + 
       (126064955917783288634053805245*CF^2*NC*Pi^3)/(46704647476096622483328*
         Sqrt[3]) + (15112877945586985363972585*CF*NC*NH*Pi^3)/
        (900567811781994726*Sqrt[3]) + (512799607*CF^2*NC*Pi^4)/10800 - 
       (4064907109295675609835482315725372309*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(198693246525184056199698144000*
         Sqrt[3]) - (688264193871802769861344158143*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9014683795937767207260*Sqrt[3]) + 
       (22537781*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (3601855883365236818115823007*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(36037536632790603768*
         Sqrt[3]) + (3454372101848453797479448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) + 
       (3601855883365236818115823007*CF^2*NC*Pi*Log[3]^2)/
        (1729801758373948980864*Sqrt[3]) + (431796512731056724684931*CF*NC*
         NH*Pi*Log[3]^2)/(33354363399333138*Sqrt[3]) + 
       CF*((-686292017990635984220079790422164843*CF*NC)/
          2793579453008023680 + CA*(3431460090459119874078068625286299433/
            27935794530080236800 - 21474332*lm)*NC + 70279632*CF*lm*NC - 
         (5719605216459318663485484092789*NM*NC)/14440355289360 + 
         3904424*lm*NM*NC + (14626409*NC*NL)/3 + 3904424*lm*NC*NL + 
         (278124618282906301133*NC*NH)/216605329340400 + 3904424*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-9575797804460983150066155*CA + 
          88*(217631766935057283966511*CF + 4176900*(84519241014485535*NM + 
              1952212*NL)))*Log[x]^3)/275675400 - 
       (3375370760246588902643709244909557791*CF^2*NC*PolyGamma[2, 1])/
        270170343534598417800 - (275457948586484179*CF*NM*NC*
         PolyGamma[2, 1])/12 + (173100792600593500562527811*CF*NC*NH*
         PolyGamma[2, 1])/32420441224151810136 + 
       CA*CF*NC*(-96722691582842967755964713431036459593195872413808628546485\
73615814742655227/
          411307763662533474843697206704966836174698080400721920000000 - 
         (3951563*lm^2)/24 + (184394904273337520054119063079141*Pi^2)/
          18014086202112000 - (126064955917783288634053805245*Pi^3)/
          (93409294952193244966656*Sqrt[3]) - (514359127*Pi^4)/21600 + 
         lm*(-9554301489335619701/18196046668800 + (3971*Pi^2)/8) + 
         (4064907109295675609835482315725372309*Im[PolyLog[2, (-1)^(1/3)]])/
          (397386493050368112399396288000*Sqrt[3]) - 
         (22537781*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
         (3601855883365236818115823007*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (72075073265581207536*Sqrt[3]) - (3601855883365236818115823007*Pi*
           Log[3]^2)/(3459603516747897961728*Sqrt[3]) + 
         (3375370760246588902643709244909557791*PolyGamma[2, 1])/
          540340687069196835600 - (17927980537085102714659255533469285912643*
           Zeta[3])/3677990988742609020562080) + 
       (89639902627979388430317088212618585745351*CF^2*NC*Zeta[3])/
        9194977471856522551405200 + (62619015302928227*CF*NM*NC*Zeta[3])/6 + 
       4273727*CF*NC*NL*Zeta[3] - (435989136754174645708923973*CF*NC*NH*
         Zeta[3])/16210220612075905068 + CF*Log[x]*
        ((-27621542436339388632344580873168154399314617*NM*NC)/
          148945614916390949520864000 + (4473880787017*lm*NM*NC)/4084080 + 
         184110*lm^2*NM*NC + (1017959466227792201*NC*NL)/137975537700 + 
         (4473880787017*lm*NC*NL)/4084080 + 184110*lm^2*NC*NL + 
         (2080538421847215576945046086172091130450998000873*NC*NH)/
          17036989597594095254237240866249031520000 + 
         (4473880787017*lm*NC*NH)/4084080 + 184110*lm^2*NC*NH - 
         28173080338385361*NM*NC*Pi^2 + (2136322*NC*NL*Pi^2)/3 - 
         (3454372101848453797479448*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CA*NC*
          (167657516403966258800923433674279715544349710541073305375803133/
            2848321633509910221178225817188376681587200000 - 
           (5430869838217*lm)/742560 - 1012605*lm^2 + 
           (1276773039914386207852693*Pi^2)/147026880 + 
           (3601855883365236818115823007*Im[PolyLog[2, (-1)^(1/3)]])/
            (216225219796743622608*Sqrt[3]) - 1104660*Zeta[3]) + 
         CF*NC*
          (-41914379107101461011143244068007111534550847232682888175748597/
            356040204188738777647278227148547085198400000 + 
           (11729822431251*lm)/680680 + 3313980*lm^2 - 
           (19151595599829863119859419*Pi^2)/1102701600 - 
           (3601855883365236818115823007*Im[PolyLog[2, (-1)^(1/3)]])/
            (108112609898371811304*Sqrt[3]) + 2209320*Zeta[3])), 
      (1658756607619345247153583744607948465459280049092015241749785668266737\
0799751691*CF^2*NC)/
        75357458128171311641005952514159995342007184016275123200000000 - 
       (162229106088046220539*CF^2*lm*NC)/2251760775264000 - 
       (2453261*CF^2*lm^2*NC)/10 + 
       (391134031458561416816251819523114085126013251977421186940067*CF*NM*
         NC)/2903617257549593078801575647104229504000000 - 
       (576540872934416413339*CF*lm*NM*NC)/40531693954752000 - 
       (2453261*CF*lm^2*NM*NC)/180 + (747470507935017434840327911*CF*NC*NL)/
        405722256487067520000 - (576540872934416413339*CF*lm*NC*NL)/
        40531693954752000 - (2453261*CF*lm^2*NC*NL)/180 + 
       (132946478863588464747220348004242430229333884777423399618271721*CF*NC*
         NH)/6199708607829807621637676060399835075442795887805440000 - 
       (576540872934416413339*CF*lm*NC*NH)/40531693954752000 - 
       (2453261*CF*lm^2*NC*NH)/180 - (418697408436482579571006372690201313*
         CF^2*NC*Pi^2)/4428087564556656000 - (361*CF^2*lm*NC*Pi^2)/90 - 
       (6098757648315286656392809*CF*NM*NC*Pi^2)/103378275 - 
       (361*CF*lm*NM*NC*Pi^2)/1620 - (200635172470519*CF*NC*NL*Pi^2)/
        3308104800 - (361*CF*lm*NC*NL*Pi^2)/1620 - (361*CF*lm*NC*NH*Pi^2)/
        1620 - (75210237707197285283737565597*CF^2*NC*Pi^3)/
        (57319340084300400320448*Sqrt[3]) - (52501125552348205954968845*CF*NC*
         NH*Pi^3)/(16210220612075905068*Sqrt[3]) - (407026189*CF^2*NC*Pi^4)/
        16200 + (802326021617884714685044326481008811*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(341391123575088969288572265600*
         Sqrt[3]) + (12920724810066513540539167259689*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(405660770817199524326700*Sqrt[3]) - 
       (7682422*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (75210237707197285283737565597*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1547976005363050934580*
         Sqrt[3]) - (6000128634554080680567868*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (75210237707197285283737565597*CF^2*NC*Pi*Log[3]^2)/
        (74302848257426444859840*Sqrt[3]) - (1500032158638520170141967*CF*NC*
         NH*Pi*Log[3]^2)/(600378541187996484*Sqrt[3]) - 
       (CF*NC*(-17*CA*(332125561946864186350000671249664268779 + 
            5796436232525196993422688000*lm) + 
          CF*(11292269106243495902058431328240280029991 + 
            322492634027765505452244096000*lm) + 
          5105100*((1380082306174370180594421309744829 + 
              3509482173901974990720*lm)*NM + 2798540855077968*
             (1376803 + 1254040*lm)*NL + (1296327796306602999151 + 
              3509482173901974990720*lm)*NH))*Log[x]^2)/
        9952126801341084360000 + (CF*NC*(44393136840651730577188031*CA - 
          120*(739885614481937642300333*CF + 68068*(6744689436921273649*NM - 
              40505492*NL)))*Log[x]^3)/275675400 - 
       (879436982359444650136245195552113234411*CF^2*NC*PolyGamma[2, 1])/
        14589198550868314561200 - (22742789131984583503*CF*NM*NC*
         PolyGamma[2, 1])/648 - (4931241742842550644218810537*CF*NC*NH*
         PolyGamma[2, 1])/1823649818858539320150 + 
       CA*CF*NC*(-11611296253532721770015368609100421626206561538385788611400\
6447414678628032521837/
          1055004413794398362974083335198239934788100576227851724800000000 + 
         (26985871*lm^2)/360 + (958117639443767047281647766984809*Pi^2)/
          20265846977376000 + (75210237707197285283737565597*Pi^3)/
          (114638680168600800640896*Sqrt[3]) + (135673471*Pi^4)/10800 + 
         lm*(1279615386370680982939/7369398900864000 + (3971*Pi^2)/3240) - 
         (802326021617884714685044326481008811*Im[PolyLog[2, (-1)^(1/3)]])/
          (682782247150177938577144531200*Sqrt[3]) + 
         (3841211*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (75210237707197285283737565597*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3095952010726101869160*Sqrt[3]) + 
         (75210237707197285283737565597*Pi*Log[3]^2)/
          (148605696514852889719680*Sqrt[3]) + 
         (879436982359444650136245195552113234411*PolyGamma[2, 1])/
          29178397101736629122400 - 
         (5024135926795836136093345176839740986374011*Zeta[3])/
          248264391740126108887940400) + 
       (5024135927227066811285973938058754681526713*CF^2*NC*Zeta[3])/
        124132195870063054443970200 + (48158600837235083857*CF*NM*NC*
         Zeta[3])/1620 - (266230451*CF*NC*NL*Zeta[3])/135 - 
       (4780931080839807611293928867*CF*NC*NH*Zeta[3])/
        911824909429269660075 + CF*Log[x]*
        ((-48064165929534116711103087524379898419329814301*NM*NC)/
          140753606095989447297216480000 - (235210840699621*lm*NM*NC)/
          551350800 - 85918*lm^2*NM*NC - (475864953529201451623*NC*NL)/
          149013580716000 - (235210840699621*lm*NC*NL)/551350800 - 
         85918*lm^2*NC*NL - 
         (1022907075011705977442790652917633378024614509439*NC*NH)/
          42933213785937120040677846982947559430400 - 
         (235210840699621*lm*NC*NH)/551350800 - 85918*lm^2*NC*NH - 
         (149881987489622258*NM*NC*Pi^2)/3 - (44371802*NC*NL*Pi^2)/135 + 
         (6000128634554080680567868*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*
          (
           -19580857282108965912373199262435298750967989644924015928986258615\
23/3652972494976459858661074610544093094135584000000 - (199682622173821*lm)/
            30630600 - 1546524*lm^2 - (22196568421433778062561809*Pi^2)/
            275675400 + (75210237707197285283737565597*
             Im[PolyLog[2, (-1)^(1/3)]])/(4643928016089152803740*Sqrt[3]) - 
           1031016*Zeta[3]) + CA*NC*
          (122380358015237539261302010945789977629616527725965094211770367603/
            456621561872057482332634326318011636766948000000 + 
           (295501150925221*lm)/100245600 + 472549*lm^2 + 
           (22196568421585158545703697*Pi^2)/551350800 - 
           (75210237707197285283737565597*Im[PolyLog[2, (-1)^(1/3)]])/
            (9287856032178305607480*Sqrt[3]) + 515508*Zeta[3])), 
      (2633592224918429223513170198542146611912228387617800111966309386041617\
631512143*CF^2*NC)/
        5275022068971991814870416675991199673940502881139258624000000 + 
       (3683465542121966285*CF^2*lm*NC)/4503521550528 + 701480*CF^2*lm^2*NC + 
       (822597828443268636391071097752680651190681784250610503512343*CF*NM*
         NC)/1016266040142357577580551476486480326400000 + 
       (6052813265070252365*CF*lm*NM*NC)/81063387909504 + 
       (350740*CF*lm^2*NM*NC)/9 - (63255309353703658407658223*CF*NC*NL)/
        11035645376448236544 + (6052813265070252365*CF*lm*NC*NL)/
        81063387909504 + (350740*CF*lm^2*NC*NL)/9 - 
       (101395557875584377158461313433530953385252666777976243732799018386230\
9*CF*NC*NH)/5888134502107560852352747602889365863932573876968917856000000 + 
       (6052813265070252365*CF*lm*NC*NH)/81063387909504 + 
       (350740*CF*lm^2*NC*NH)/9 - (76042037810019155408867822360145961*CF^2*
         NC*Pi^2)/354247005164532480 - (18050*CF^2*lm*NC*Pi^2)/9 - 
       (28264544811930755902070977*CF*NM*NC*Pi^2)/82702620 - 
       (9025*CF*lm*NM*NC*Pi^2)/81 + (6080015147275*CF*NC*NL*Pi^2)/
        33081048 - (9025*CF*lm*NC*NL*Pi^2)/81 - (9025*CF*lm*NC*NH*Pi^2)/
        81 + (1216864806619316312958364512545*CF^2*NC*Pi^3)/
        (315256370463652201762464*Sqrt[3]) + (295373692017831488164760755*CF*
         NC*NH*Pi^3)/(12157665459056928801*Sqrt[3]) + 
       (21226553*CF^2*NC*Pi^4)/324 - (11028610979535746096845179495988869593*
         CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(375530235932597866217429492160*
         Sqrt[3]) - (16487678235717150562572948516197*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(147776423654836969576155*Sqrt[3]) + 
       (18492700*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
       (243372961323863262591672902509*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1702773605899356028038*
         Sqrt[3]) + (135027973493865823161033488*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) + (243372961323863262591672902509*CF^2*NC*Pi*Log[3]^2)/
        (81733133083169089345824*Sqrt[3]) + (8439248343366613947564593*CF*NC*
         NH*Pi*Log[3]^2)/(450283905890997363*Sqrt[3]) + 
       CF*((-14648955425405173015095596411061473873*CF*NC)/
          5686929600766333920 + CA*(39439495376896802365256460378332027089/
            30621928619511028800 - (280797770*lm)/9)*NC + 
         102108280*CF*lm*NC - (79949475852609518694738561009449*NM*NC)/
          19494479640636 + (51054140*lm*NM*NC)/9 + (63660260*NC*NL)/9 + 
         (51054140*lm*NC*NL)/9 + (4939029330106287110047*NC*NH)/
          2576056238226900 + (51054140*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-5037458771020301759621633*CA + 
          12*(839576461080581000900757*CF + 340340*(3948498629512922312*NM + 
              12763535*NL)))*Log[x]^3)/13783770 - 
       (240346143946746618889581326300058250769*CF^2*NC*PolyGamma[2, 1])/
        1823649818858539320150 - (762170755697241319123*CF*NM*NC*
         PolyGamma[2, 1])/3240 + (33504840630069909023976167351*CF*NC*NH*
         PolyGamma[2, 1])/4376759565260494368360 + 
       CA*CF*NC*(-22131027099760588531635389642929640026690063157652282390919\
993827183916323997/
          88655833091966248989418767663717641578831981195617792000000 - 
         (1929070*lm^2)/9 + (20011062581561135660600933576766911*Pi^2)/
          186445792191859200 - (1216864806619316312958364512545*Pi^3)/
          (630512740927304403524928*Sqrt[3]) - (7094771*Pi^4)/216 + 
         lm*(-10073524552497646925/14738797801728 + (99275*Pi^2)/162) + 
         (11028610979535746096845179495988869593*Im[PolyLog[2, (-1)^(1/3)]])/
          (751060471865195732434858984320*Sqrt[3]) - 
         (9246350*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
         (243372961323863262591672902509*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3405547211798712056076*Sqrt[3]) - 
         (243372961323863262591672902509*Pi*Log[3]^2)/
          (163466266166338178691648*Sqrt[3]) + 
         (240346143946746618889581326300058250769*PolyGamma[2, 1])/
          3647299637717078640300 - (53134325911949784863261112075109636668077*
           Zeta[3])/1043127696387084491125800) + 
       (53134325907259427558012436004783686314357*CF^2*NC*Zeta[3])/
        521563848193542245562900 + (185468915319631024397*CF*NM*NC*Zeta[3])/
        1620 + (166844320*CF*NC*NL*Zeta[3])/27 - 
       (84825098700912622179619437769*CF*NC*NH*Zeta[3])/
        2188379782630247184180 + CF*Log[x]*
        ((-6686553017219869856268092870260881220433244041*NM*NC)/
          3518840152399736182430412000 + (8311659684397*lm*NM*NC)/5513508 + 
         252700*lm^2*NM*NC + (431253298224109375757*NC*NL)/40531693954752 + 
         (8311659684397*lm*NC*NL)/5513508 + 252700*lm^2*NC*NL + 
         (17709337336290549734450942339376130188532723549618073*NC*NH)/
          100185630124343040913104498613048651466280000 + 
         (8311659684397*lm*NC*NH)/5513508 + 252700*lm^2*NC*NH - 
         (2632332419678717666*NM*NC*Pi^2)/9 + (27801370*NC*NL*Pi^2)/27 - 
         (135027973493865823161033488*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CA*NC*
          (44503310884030100222205664649176007633136780234054270421206352567/
            73059449899529197173221492210881861882711680000 - 
           (10084904102797*lm)/1002456 - 1389850*lm^2 + 
           (84663172615956145990919*Pi^2)/926640 + 
           (243372961323863262591672902509*Im[PolyLog[2, (-1)^(1/3)]])/
            (10216641635396136168228*Sqrt[3]) - 1516200*Zeta[3]) + 
         CF*NC*
          (-22251655442458622493018280416114530912274880653391333753106447411/
            18264862474882299293305373052720465470677920000 + 
           (7266712080697*lm)/306306 + 4548600*lm^2 - 
           (84663172616632011429167*Pi^2)/463320 - 
           (243372961323863262591672902509*Im[PolyLog[2, (-1)^(1/3)]])/
            (5108320817698068084114*Sqrt[3]) + 3032400*Zeta[3])), 
      (2609737559668650486653005270878305182887971828990413750187050765263013\
919472916741*CF^2*NC)/
        1127535967242763250428551564493118930304782490843516530880000000 - 
       (189791154259545622099*CF^2*lm*NC)/2032214099675760 - 
       317336*CF^2*lm^2*NC + 
       (62923282658223461738612843638869432768198338609030990177047*CF*NM*
         NC)/43804570695791274895713425710624152000000 - 
       (673462174410575853619*CF*lm*NM*NC)/36579853794163680 - 
       (158668*CF*lm^2*NM*NC)/9 + (16647732652528182141378081851*CF*NC*NL)/
        6224793720152833425600 - (673462174410575853619*CF*lm*NC*NL)/
        36579853794163680 - (158668*CF*lm^2*NC*NL)/9 + 
       (44874645122819104301113927781736353294377750361677862148442183110749*
         CF*NC*NH)/
        1472033625526890213088186900722341465983143469242229464000000 - 
       (673462174410575853619*CF*lm*NC*NH)/36579853794163680 - 
       (158668*CF*lm^2*NC*NH)/9 - (662067417532723173778570565618672411*CF^2*
         NC*Pi^2)/673069309812611712 - (40*CF^2*lm*NC*Pi^2)/9 - 
       (243868391253599674325676866*CF*NM*NC*Pi^2)/392837445 - 
       (20*CF*lm*NM*NC*Pi^2)/81 - (12976605935071*CF*NC*NL*Pi^2)/
        157134978 - (20*CF*lm*NC*NL*Pi^2)/81 - (20*CF*lm*NC*NH*Pi^2)/81 - 
       (49580448831045817157217537303749*CF^2*NC*Pi^3)/
        (26954419674642263250690672*Sqrt[3]) - 
       (56250090946886212956447910*CF*NC*NH*Pi^3)/(12157665459056928801*
         Sqrt[3]) - (27934097*CF^2*NC*Pi^4)/810 + 
       (1522868565962121342483480089256618490579*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(435749191623218024050153007152800*
         Sqrt[3]) + (46623108606386576113302287952848*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1034434965583858787033085*Sqrt[3]) - 
       (10413592*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (7082921261577973879602505329107*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(103990816645996385998035*
         Sqrt[3]) - (25714327290005125922947616*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) - (7082921261577973879602505329107*CF^2*NC*Pi*Log[3]^2)/
        (4991559199007826527905680*Sqrt[3]) - 
       (1607145455625320370184226*CF*NC*NH*Pi*Log[3]^2)/
        (450283905890997363*Sqrt[3]) + 
       CF*((-111599739068831855761703485091488831408043*CF*NC)/
          9454520461274030142000 - 46673728*CF*lm*NC + 
         CA*(10145430824433014682574333311106926237073/
            1719003720231641844000 + (128352752*lm)/9)*NC - 
         (31298069333499488762687065916963*NM*NC)/4201396474275 - 
         (23336864*lm*NM*NC)/9 - (25555304*NC*NL)/9 - (23336864*lm*NC*NL)/
          9 - (4436467636957733175499*NC*NH)/4508098416897075 - 
         (23336864*lm*NC*NH)/9)*Log[x]^2 + 
       (2*CF*NC*(110013576080417880808414525*CA - 
          912*(241257842303919310438053*CF + 170170*(890432188364436977*NM - 
              729277*NL)))*Log[x]^3)/130945815 - 
       (411833270025029183681343893814600424319*CF^2*NC*PolyGamma[2, 1])/
        656513934789074155254 - (3021121245038488654841*CF*NM*NC*
         PolyGamma[2, 1])/8100 - (41818757211784282812021134149*CF*NC*NH*
         PolyGamma[2, 1])/10941898913151235920900 + 
       CA*CF*NC*(-26097375596746588484376480158954942580630396665491616667590\
49285933882061742200741/
          2255071934485526500857103128986237860609564981687033061760000000 + 
         (872674*lm^2)/9 + (16551685438320377594387186816847732539*Pi^2)/
          33653465490630585600 + (49580448831045817157217537303749*Pi^3)/
          (53908839349284526501381344*Sqrt[3]) + (3103753*Pi^4)/180 + 
         lm*(1494237238909293822259/6650882508029760 + (110*Pi^2)/81) - 
         (1522868565962121342483480089256618490579*
           Im[PolyLog[2, (-1)^(1/3)]])/(871498383246436048100306014305600*
           Sqrt[3]) + (5206796*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (7082921261577973879602505329107*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(207981633291992771996070*Sqrt[3]) + 
         (7082921261577973879602505329107*Pi*Log[3]^2)/
          (9983118398015653055811360*Sqrt[3]) + 
         (411833270025029183681343893814600424319*PolyGamma[2, 1])/
          1313027869578148310508 - 
         (26576038529179919176842526361407524093305237*Zeta[3])/
          124862385257534013587758260) + 
       (26576038529489303295848458903765697295604721*CF^2*NC*Zeta[3])/
        62431192628767006793879130 + (1252953259150075827559*CF*NM*NC*
         Zeta[3])/4050 - (76330672*CF*NC*NL*Zeta[3])/27 - 
       (38684154431585940897211838149*CF*NC*NH*Zeta[3])/
        5470949456575617960450 + CF*Log[x]*
        ((-1074860624829752894959073968871982460590292313*NM*NC)/
          303348288999977257106070000 - (15263771497753*lm*NM*NC)/26189163 - 
         117040*lm^2*NM*NC - (314879703310405791587*NC*NL)/68759123673240 - 
         (15263771497753*lm*NC*NL)/26189163 - 117040*lm^2*NC*NL - 
         (1171658476245662358796457170235162358516652373742551*NC*NH)/
          34438810355242920313879671398235473941533750 - 
         (15263771497753*lm*NC*NH)/26189163 - 117040*lm^2*NC*NH - 
         (4748971671287585936*NM*NC*Pi^2)/9 - (12721792*NC*NL*Pi^2)/27 + 
         (25714327290005125922947616*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CF*NC*
          (-86065201726253366747138464719905476740503034868627126132360017870\
553/15616457416024365895776093960075997977429621600000 - (25929773539226*lm)/
            2909907 - 2106720*lm^2 - (25885547313218539935357881*Pi^2)/
            30810780 + (7082921261577973879602505329107*
             Im[PolyLog[2, (-1)^(1/3)]])/(311972449937989157994105*Sqrt[3]) - 
           1404480*Zeta[3]) + CA*NC*(8606520172645102489469470240378719594682\
7475239159760467247639870253/
            31232914832048731791552187920151995954859243200000 + 
           (19164909218233*lm)/4761666 + 643720*lm^2 + 
           (25885547313242797727352317*Pi^2)/61621560 - 
           (7082921261577973879602505329107*Im[PolyLog[2, (-1)^(1/3)]])/
            (623944899875978315988210*Sqrt[3]) + 702240*Zeta[3]))}, 0, 39, 1]
 
CbarLSeries["a", 2, 2, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-224725550*NM - 42639360*lm*NM + 132710400*lm^2*NM + 
         349876224*NL - 42639360*lm*NL + 132710400*lm^2*NL - 
         224725550*NH - 42639360*lm*NH + 132710400*lm^2*NH - 
         10*CA*(10595581994 + 69445632*lm + 72990720*lm^2 - 
           8820968607*Zeta[3]) + 237313125*NM*Zeta[3] + 
         237313125*NH*Zeta[3] + 20*CF*(-44800916438 - 127954944*lm + 
           119439360*lm^2 + 37472842593*Zeta[3])))/83607552000, 
      -(CF*NC*(-931880990*NM + 360284160*lm*NM + 530841600*lm^2*NM + 
          1314226176*NL + 360284160*lm*NL + 530841600*lm^2*NL - 
          1036480850*NH + 360284160*lm*NH + 530841600*lm^2*NH - 
          40*CA*(10630304810 + 142436352*lm + 72990720*lm^2 - 
            8820968607*Zeta[3]) + 1257346125*NM*Zeta[3] + 
          641158875*NH*Zeta[3] + 80*CF*(-44864893910 - 8515584*lm + 
            119439360*lm^2 + 37472842593*Zeta[3])))/167215104000, 
      (CF*NC*(-4957342668950*NM + 3357011804160*lm*NM + 
         2341011456000*lm^2*NM + 6605353353216*NL + 3357011804160*lm*NL + 
         2341011456000*lm^2*NL - 5982421296950*NH + 3357011804160*lm*NH + 
         2341011456000*lm^2*NH - 8*CA*(2108074664760166 + 4356330639360*lm + 
           1609445376000*lm^2 - 1752328464816825*Zeta[3]) + 
         9143580938625*NM*Zeta[3] + 3104945888625*NH*Zeta[3] + 
         560*CF*(-455409967564190 + 51468853248*lm + 75246796800*lm^2 + 
           378945683572365*Zeta[3])))/655483207680000, 
      -(CF*NC*(-5877341790040*NM + 1796155146240*lm*NM + 
          910393344000*lm^2*NM + 3158573563904*NL + 1796155146240*lm*NL + 
          910393344000*lm^2*NL - 1506827549850*NH + 1796155146240*lm*NH + 
          910393344000*lm^2*NH - 12*CA*(1933874476968886 + 
            1354300559360*lm + 417263616000*lm^2 - 1608252644235825*
             Zeta[3]) + 8636479834500*NM*Zeta[3] + 433635906375*NH*
           Zeta[3] + 280*CF*(-1303403430393482 + 71573151744*lm + 
            58525286400*lm^2 + 1084375071086895*Zeta[3])))/327741603840000, 
      (CF*NC*(-11243855495366550*NM + 815010793390080*lm*NM + 
         365197787136000*lm^2*NM + 1593723308474368*NL + 
         815010793390080*lm*NL + 365197787136000*lm^2*NL + 
         2291968956848130*NH + 815010793390080*lm*NH + 
         365197787136000*lm^2*NH - CA*(52816032263425498258 + 
           7038943873597440*lm + 2008587829248000*lm^2 - 43935897435896914875*
            Zeta[3]) + 12217118396954625*NM*Zeta[3] - 2151616792507875*NH*
          Zeta[3] + 126*CF*(-8604544214170755346 + 77301779005440*lm + 
           52171112448000*lm^2 + 7158214256685630075*Zeta[3])))/
       259571350241280000, (CF*NC*(11238537400380990*NM + 
         34102880501760*lm*NM - 9364045824000*lm^2*NM - 
         96598915088384*NL + 34102880501760*lm*NL - 9364045824000*lm^2*
          NL - 4148087377649670*NH + 34102880501760*lm*NH - 
         9364045824000*lm^2*NH + 10*CA*(6352206323916300938 - 
           12201752199168*lm + 5150225203200*lm^2 - 5284618931266102575*
            Zeta[3]) - 10177861713760125*NM*Zeta[3] + 3370163898803625*NH*
          Zeta[3] - 756*CF*(-1984672511908096102 - 979188449280*lm + 
           222953472000*lm^2 + 1651058387896224825*Zeta[3])))/
       129785675120640000, 
      -(CF*NC*(-11*CA*(-2386257968963069442953554 + 51425062300562227200*lm + 
            10763970674688000000*lm^2 + 1985220879236139343750875*Zeta[3]) + 
          5*(22636797011421298688*NL + 15090185304020090880*lm*NL + 
            4305588269875200000*lm^2*NL - 294726820829804394570*NH + 
            15090185304020090880*lm*NH + 4305588269875200000*lm^2*NH + 
            154*CF*(939030159186174740138618 + 1386349959928872960*lm + 
              503250576998400000*lm^2 - 781184085602579744829975*Zeta[3]) + 
            3465*NM*(217610191350480566 + 4355031833772032*lm + 
              1242594017280000*lm^2 - 180676427649743025*Zeta[3]) + 
            237783798459615783375*NH*Zeta[3])))/24498344035772006400000, 
      (CF*NC*(1286102772961960813398*NM + 22005448542954455040*lm*NM + 
         6680460115574784000*lm^2*NM + 41038937561537708032*NL + 
         22005448542954455040*lm*NL + 6680460115574784000*lm^2*NL - 
         435869517923492882922*NH + 22005448542954455040*lm*NH + 
         6680460115574784000*lm^2*NH + 154*CF*(2181119981636609599068466 + 
           1986440663720263680*lm + 780833000521728000*lm^2 - 
           1814487458395172258018475*Zeta[3]) - 1039286514845496542625*NM*
          Zeta[3] + 354489648881918925375*NH*Zeta[3] - 
         11*CA*(-966263442337365890895778 + 15253926163206635520*lm + 
           3340230057787392000*lm^2 + 803861955968533857947475*Zeta[3])))/
       4899668807154401280000, 
      -(CF*NC*(104*CF*(5283117984579253180599627702034 + 
            2183295667133345483980800*lm + 938360813976236851200000*lm^2 - 
            4395062614112200851142986538875*Zeta[3]) - 
          44*CA*(-347719725312913335521033389058 + 2947637100215630875852800*
             lm + 677705032316171059200000*lm^2 + 
            289274475949520125166775547875*Zeta[3]) + 
          385*(33554432*(2831599758377251 + 1291239987857820*lm + 
              419681742480000*lm^2)*NL + 1287*NM*(3358908795928046930894 + 
              33664976199111147520*lm + 10941866736353280000*lm^2 - 
              2719744742603682919125*Zeta[3]) + 1287*NH*
             (-846399274942003562546 + 33664976199111147520*lm + 
              10941866736353280000*lm^2 + 694275789461884504875*Zeta[3]))))/
       3709637247272740297113600000, 
      (CF*NC*(416*CF*(5371632965088213572583989560342 + 
           823942482521263335014400*lm + 420777618165926461440000*lm^2 - 
           4468700418432316555772925266625*Zeta[3]) - 
         176*CA*(-313789619088367960550624895974 + 1209766166944620635750400*
            lm + 303894946453169111040000*lm^2 + 
           261045463425584845329598901625*Zeta[3]) + 
         385*(134217728*(1330768396032373 + 509652707824260*lm + 
             188192730726000*lm^2)*NL + 273*NM*(54967273314846210719282 + 
             250565672209597071360*lm + 92523079648935936000*lm^2 - 
             44953547492727543544875*Zeta[3]) + 1287*NH*
            (-1940489991956982728782 + 53150294105066045440*lm + 
             19626107804319744000*lm^2 + 1602369142619319199125*Zeta[3]))))/
       7419274494545480594227200000, 
      -(CF*NC*(-44*CA*(-84252082098239428950780184398734 + 
            126977619136159795485081600*lm + 37525985991947578245120000*
             lm^2 + 70090081026281687555107697899125*Zeta[3]) + 
          5*(419747108208018613325529088*NL + 126747637325162422531522560*lm*
             NL + 60041577587116125192192000*lm^2*NL - 
            7908442791900160118997626238*NH + 126747637325162422531522560*lm*
             NH + 60041577587116125192192000*lm^2*NH + 
            616*CF*(54463954096080508718703531927526 + 
              2387818464978662200442880*lm + 1754461682740406255616000*lm^2 - 
              45308964139347010658147987420025*Zeta[3]) + 
            1287*NM*(61301559660421554837683086 + 98483012684663886970880*
               lm + 46652352437541666816000*lm^2 - 50559013386264949708267125*
               Zeta[3]) + 6560786736520532757288172125*NH*Zeta[3])))/
       288291808930910103089971200000, 
      (CF*NC*(4*CF*(38766310750102716868691378121780746 + 
           202838375056900747375411200*lm + 485018172798839228989440000*
            lm^2 - 32249980224104195312590285419339375*Zeta[3]) - 
         6050*CA*(-509785292616017206913480453654 + 239171285039487255576576*
            lm + 97983469252290753331200*lm^2 + 
           424094347869733366721394928065*Zeta[3]) + 
         5*(429*NM*(162425943123778573913693566 + 58700026382391107911680*
              lm + 50247932949892694016000*lm^2 - 134633067334415260257772125*
              Zeta[3]) + 4*(67108864*(502681392248708941 + 93811420045963620*
                lm + 80303710831344000*lm^2)*NL + 429*NH*
              (-2292210482730589564666666 + 14675006595597776977920*lm + 
               12561983237473173504000*lm^2 + 1907306021476494921657375*
                Zeta[3])))))/144145904465455051544985600000, 
      -(CF*NC*(34*CF*(7486580068330687188374535525896678538934 - 
            38107041860846988438214488883200*lm + 
            34141411078636102068731904000000*lm^2 - 
            6228141263716347905550721888321069160625*Zeta[3]) - 
          CA*(-4583019356785137160465741365122843809258 + 
            321553995139762153863985181491200*lm + 
            354691326205830615936270336000000*lm^2 + 
            3812647044490904940101353832758712589375*Zeta[3]) + 
          105*(6442450944*(415316301613793107937 - 34906811141940918180*lm + 
              95333921822739600000*lm^2)*NL + 2431*NH*
             (-92507370791208139169464320*lm + 252646694628601783910400000*lm^
                2 + 46189*(-1454698267111554819609826 + 
                1212571705084559710765875*Zeta[3])) + 
            2431*NM*(-92507370791208139169464320*lm + 
              252646694628601783910400000*lm^2 - 
              323*(-6883212532047357880367075002 + 
                5719126063798292339820000375*Zeta[3])))))/
       132972867118528699589630676172800000, 
      (CF*NC*(-4*CA*(-896968031034936029384083528725354132826 - 
           47366698835353937156321889484800*lm + 
           25315347268083109860181278720000*lm^2 + 
           746194096878838822473226984968863286375*Zeta[3]) + 
         5*(136*CF*(322065331537516216103949239932120247822 - 
             1897657068572422465333430845440*lm + 
             487354278957749708538249216000*lm^2 - 
             267928527003303022823485821229386383925*Zeta[3]) + 
           21*(38654705664*(-360748541170158347 - 14260789654888296520*lm + 
               4536172081769328000*lm^2)*NL + 2431*NM*
              (1955870238644222037173575645154 - 226757147941556248777850880*
                lm + 72128505414252371116032000*lm^2 - 
               1626664656695403887659956733875*Zeta[3]) + 
             17017*NH*(-4352059181776946624273464318 - 
               32393878277365178396835840*lm + 10304072202036053016576000*
                lm^2 + 3630928087228178270789380125*Zeta[3])))))/
       66486433559264349794815338086400000, 
      -(CF*NC*(CA*(31643622778958269252553179943891786755339748 + 
            2252961877251477942394717151114035200*lm - 
            268417426976429318123008850657280000*lm^2 - 
            26324555897897397751551778978252580744025750*Zeta[3]) + 
          5*(76*CF*(5560578714050141743763026113618359698070962 - 
              24079496789902243345037800809431040*lm + 
              2311729036160635275700554694656000*lm^2 - 
              4625886459828093709322404901796063560397675*Zeta[3]) + 
            21*(1133871366144*(-5009692715806861911707 - 
                3962342096383396263720*lm + 409916058578234208000*lm^2)*NL + 
              4199*NM*(-1069965764695432827611979448320*lm + 
                110691136304945546970267648000*lm^2 + 323*
                 (35449400859564887982479799585442 - 
                  29491839469061714473121856337875*Zeta[3])) + 
              4199*NH*(-89206336020959974917102530017594 - 
                1069965764695432827611979448320*lm + 
                110691136304945546970267648000*lm^2 + 
                74446463089496138408597615160375*Zeta[3])))))/
       384025640238310884414853392787046400000, 
      (CF*NC*(684*CF*(1675111678755485962058135948902602934985822 - 
           4539934247053772339106473941401600*lm + 
           95312960614626009571078963200000*lm^2 - 
           1393537760218698116996386921114359417790125*Zeta[3]) - 
         6*CA*(-2625051874981571397427154081400589422028562 - 
           151425450589067545554513237010022400*lm + 
           3320068128076139333392583884800000*lm^2 + 
           2183799563387276146038981973530962141866875*Zeta[3]) + 
         35*(34359738368*(-263856799267123774390831 - 
             141196054348694250065160*lm + 3011741295719476320000*lm^2)*NL + 
           4199*NM*(19935967837195260596550912527599246 - 
             1155384492978100279748717445120*lm + 
             24644592272689336669962240000*lm^2 - 
             16586541504013690384923924062011125*Zeta[3]) + 
           29393*NH*(-165054927568300039964102492160*lm + 
             3520656038955619524280320000*lm^2 + 
             71383*(-151854494615084303728093634 + 
               126714347670455412600607875*Zeta[3])))))/
       128008546746103628138284464262348800000, 
      (CF*NC*(-20*CA*(2332921386708713637708302328687525537285748874 + 
           92034509472094108490490021157766430720*lm + 
           2188299647411935993841805837729792000*lm^2 - 
           1940774235103591384942804115530962484923401775*Zeta[3]) + 
         104*CF*(-35420987148631299879193052600019244925871143174 + 
           55138012926529412319082584078915993600*lm + 
           1377251526343176499620716960808960000*lm^2 + 
           29466980397059981130446586196473046429813283625*Zeta[3]) + 
         385*(137438953472*(14174577558536802665037209 + 
             6133410696858209670545640*lm + 150384656261646110304000*lm^2)*
            NL + 4199*NH*(11589711863457452603449098801373594 + 
             200754833862863199688340715601920*lm + 
             4922293349570634249154854912000*lm^2 - 
             9667389660339596135686960419570375*Zeta[3]) + 
           4199*NM*(-6351703415716550716683123250371829286 + 
             200754833862863199688340715601920*lm + 
             4922293349570634249154854912000*lm^2 + 
             5284466612876629042072034895517073625*Zeta[3]))))/
       259089298614113743351887755666993971200000, 
      -(CF*NC*(-16*CA*(8383570624612772140335957891218080526180021198 + 
            207077330895560036655780241332397670400*lm + 
            10928523760296014003656166064783360000*lm^2 - 
            6974353606073238393194830493697863738693095125*Zeta[3]) + 
          32*CF*(-357949088657641117984756750540306909195645488178 + 
            302681303729936641730414820453462835200*lm + 
            17883038880484386551437362651463680000*lm^2 + 
            297780486023442945965071999852076609093003800875*Zeta[3]) + 
          385*(549755813888*(7185845967131282166145097 + 
              2654988180346548531444960*lm + 150206329474399562364000*lm^2)*
             NL + 20995*NM*(-4375890321629918315985029183450096758 + 
              69521085398877681057214343675904*lm + 
              3933165177962734682902206873600*lm^2 + 
              3640530649898844355875320910367782225*Zeta[3]) + 
            230945*NH*(6320098672625243732474031243264*lm + 
              357560470723884971172927897600*lm^2 - 4199*(
                -81656539618752032754150729182 + 
                68077173935750589081229682925*Zeta[3])))))/
       518178597228227486703775511333987942400000, 
      (CF*NC*(-8*CA*(200683614940827504463183808082794237988856720574194 + 
           2935025408968468938655834569075513203097600*lm + 
           221071113810518157364542449208539480064000*lm^2 - 
           166950170043556677658345357655301093337528819948875*Zeta[3]) + 
         5*(368*CF*(-80333461946222241768036143037731607210332979963194 + 
             35400362910143322158056485358888361656320*lm + 
             3145675927738598286610090186366569676800*lm^2 + 
             66829999265877940653355559594159972803969974341175*Zeta[3]) + 
           77*(3298534883328*(9436438288891485600273746239 + 
               3039422824814659973381011320*lm + 253208036805297175774972800*
                lm^2)*NL + 37145*NM*
              (-35872275482304087882559226417199578884810 + 
               269905565024484711765253082786562048*lm + 
               22485275061011518361751724669009920*lm^2 + 
               29843330953639960039343464183280168242575*Zeta[3]) + 
             37145*NH*(269905565024484711765253082786562048*lm + 
               22485275061011518361751724669009920*lm^2 - 141151*
                (-102300882497035623412913172296042 + 
                 85238106111257098601516175035775*Zeta[3]))))))/
       4385863646939717447460755927930873944473600000, 
      -(CF*NC*(-4*CA*(25416450384507790693831024569379316866412076995858 + 
            211468914655447906724576641742653725081600*lm + 
            20280008097016601838822711716273455104000*lm^2 - 
            21144131806400306507901700226762365247410029514875*Zeta[3]) + 
          5*(184*CF*(-10937868955738812624388271477590120134146377061338 + 
              2425346881704889435502528136735746949120*lm + 
              288569285174939789010916056041835724800*lm^2 + 
              9099293824236583722532401587341716696100474907175*Zeta[3]) + 
            7*(18141941858304*(752685326229577935878900299 + 
                212646942816298110713076120*lm + 23228095919589055275580800*
                 lm^2)*NL + 74290*NM*(
                -15293225846082030187871217291272955144842 + 
                51929310444465954636802106811482112*lm + 
                5672402283649118659608158750638080*lm^2 + 
                12722757197183264574000835461306799952175*Zeta[3]) + 
              37145*NH*(103858620888931909273604213622964224*lm + 
                11344804567298237319216317501276160*lm^2 - 
                7429*(-767700026498502397243572252455774 + 
                  639270541663982508409753934234925*Zeta[3]))))))/
       199357438497259883975488905815039724748800000}, 0, 20, 1]
 
CbarLSeries["a", 2, 3, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(CF*(-1157360400*lm^2 + 16218036*Pi^2 + 793800*Pi^4 + 
            7144200*lm*(-221 + 12*Pi^2) + 35*(-35804493 + 124743552*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] - 9797760*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 20790592*PolyGamma[2, 1] - 
              207349952*Zeta[3])) + 35*CA*(21043251 + 6735960*lm^2 - 
            2241432*Pi^2 + 61236*Pi^4 - 15120*lm*(-1645 + 33*Pi^2) - 
            62371776*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            4898880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 10395296*PolyGamma[2, 1] + 
            109713040*Zeta[3]) + 70*(9*NL*(-131005 - 68040*lm^2 - 
              4932*Pi^2 + 1680*lm*(-98 + 3*Pi^2) - 60480*Zeta[3]) + 
            9*NM*(-131005 - 68040*lm^2 - 4932*Pi^2 + 1680*lm*(-98 + 
                3*Pi^2) + 5040*PolyGamma[2, 1] - 50400*Zeta[3]) + 
            NH*(3319767 - 612360*lm^2 + 15120*lm*(-98 + 3*Pi^2) - 
              257432016*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              42905336*PolyGamma[2, 1] + 459939952*Zeta[3]))))/10287648000, 
      (CF*NC*(-49*CA*(-15970032 + 5773680*lm^2 - 2768823*Pi^2 + 96228*Pi^4 - 
           3240*lm*(-4501 + 132*Pi^2) - 12578388*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 7698240*Im[PolyLog[2, (-1)^(1/3)]]^
             2 + 2143378*PolyGamma[2, 1] + 21321380*Zeta[3]) + 
         2*(-98*(NH*(83733093 - 262440*lm^2 + 1620*lm*(-203 + 12*Pi^2) + 
               32125776*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 5354296*
                PolyGamma[2, 1] - 127193072*Zeta[3]) + 
             27*NL*(25795 - 9720*lm^2 - 516*Pi^2 + 60*lm*(-203 + 12*Pi^2) - 
               8640*Zeta[3]) + 27*NM*(25795 - 9720*lm^2 - 516*Pi^2 + 60*lm*
                (-203 + 12*Pi^2) + 720*PolyGamma[2, 1] - 7200*Zeta[3])) + 
           CF*(694416240*lm^2 + 2492829*Pi^2 + 1666980*Pi^4 - 
             17146080*lm*(-8 + 3*Pi^2) + 7*(87103341 - 88048716*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 53887680*Im[PolyLog[2, 
                   (-1)^(1/3)]]^2 + 15003646*PolyGamma[2, 1] + 93534620*
                Zeta[3])))))/2057529600, 
      -(CF*NC*(CF*(52081218000*lm^2 + 5138715006*Pi^2 - 547722000*Pi^4 + 
            21432600*lm*(-1519 + 60*Pi^2) + 35*(1319307453 + 3276553608*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 2057529600*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 505821332*PolyGamma[2, 1] - 
              8176386856*Zeta[3])) + 35*CA*(1545748893 - 303118200*lm^2 - 
            97541739*Pi^2 + 8913240*Pi^4 - 22680*lm*(22763 + 330*Pi^2) - 
            1638276804*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            1028764800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 252910666*
             PolyGamma[2, 1] + 3705159332*Zeta[3]) + 
          70*(135*NL*(-808045 + 204120*lm^2 + 93708*Pi^2 + 168*lm*(523 + 
                30*Pi^2) - 60480*Zeta[3]) + 135*NM*(-1291381 + 204120*lm^2 + 
              154188*Pi^2 + 168*lm*(523 + 30*Pi^2) + 11088*PolyGamma[2, 1] - 
              38304*Zeta[3]) + NH*(-5975737335 + 27556200*lm^2 + 
              22680*lm*(523 + 30*Pi^2) - 14293401840*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 2468044312*PolyGamma[2, 1] + 30796731824*Zeta[
                3]))))/30862944000, 
      (CF*NC*(30269340725085*CF + 29281218120000*CF*lm + 
         25248974486400*CF*lm^2 - 2680761031200*NM + 2071589385600*lm*NM + 
         935147203200*lm^2*NM + 1122068052000*NL + 2071589385600*lm*NL + 
         935147203200*lm^2*NL - 141176810043360*NH + 2071589385600*lm*NH + 
         935147203200*lm^2*NH - 1277351945424*CF*Pi^2 - 
         444426393600*CF*lm*Pi^2 + 368777888640*NM*Pi^2 - 
         16460236800*lm*NM*Pi^2 + 430503776640*NL*Pi^2 - 
         16460236800*lm*NL*Pi^2 - 16460236800*lm*NH*Pi^2 + 
         111125140000*Sqrt[3]*CF*Pi^3 + 5185034960000*Sqrt[3]*NH*Pi^3 + 
         45248505120*CF*Pi^4 - 15707566459200*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] - 52848078097920*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 20036223244800*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 4114805184000*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 191994437376000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 85725108000*Sqrt[3]*CF*Pi*
          Log[3]^2 + 3999884112000*Sqrt[3]*NH*Pi*Log[3]^2 + 
         61725888000*(-2*CA*(76 + 33*lm) + 9*CF*(61 + 36*lm) + 
           4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
         246903552000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
         2935385967920*CF*PolyGamma[2, 1] + 131681894400*NM*
          PolyGamma[2, 1] + 11663501987200*NH*PolyGamma[2, 1] + 
         14312688513760*CF*Zeta[3] + 90531302400*NM*Zeta[3] + 
         2049299481600*NL*Zeta[3] + 56527301600000*NH*Zeta[3] - 
         529200*Log[x]*(-4*(243*NM*(4859 + 4800*lm + 1080*lm^2 + 600*Pi^2) + 
             243*NL*(9179 + 4800*lm + 1080*lm^2 + 600*Pi^2) + 
             NH*(53023659 + 1166400*lm + 262440*lm^2 - 30233440*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) + CF*(-97433481 - 96053040*lm - 
             28343520*lm^2 + 1102248*Pi^2 + 2591840*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 8398080*Zeta[3]) + 
           4*CA*(14923374 + 8252280*lm + 1443420*lm^2 + 2187*Pi^2 - 
             323980*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1049760*Zeta[3])) - 
         140*CA*(36737925840*lm^2 - 6725758374*Pi^2 + 396875500*Sqrt[3]*
            Pi^3 + 255660300*Pi^4 - 1224720*lm*(-104629 + 528*Pi^2) + 
           306161100*Sqrt[3]*Pi*Log[3]^2 + 7*(10194408567 - 
             8014064520*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             10222562880*Im[PolyLog[2, (-1)^(1/3)]]^2 + 2099390400*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1497645902*
              PolyGamma[2, 1] + 12698293468*Zeta[3]))))/555532992000, 
      -(CF*NC*(162*CF*(7 + 5*lm) - 5*CA*(76 + 33*lm) + 
           10*(3*(2 + lm)*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2)/15 - 
       (2*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/3 + 
       (CF*NC*Log[x]*(-4*(243*NL*(23119 + 12492*lm + 3240*lm^2 + 
              1800*Pi^2) + 243*NM*(7193 + 12492*lm + 3240*lm^2 + 
              2640*Pi^2) + NH*(78472599 + 3035556*lm + 787320*lm^2 - 
              44756800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          3*CF*(-79365759 - 79361856*lm - 28343520*lm^2 + 2618568*Pi^2 + 
            10544608*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 8398080*Zeta[3]) - 
          12*CA*(-14060505 - 7402266*lm - 1443420*lm^2 + 220401*Pi^2 + 
            1318076*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1049760*Zeta[3])))/
        2099520 + (CF*NC*(3*CF*(-22749076022400*lm^2 + 1050455139408*Pi^2 - 
            452100068000*Sqrt[3]*Pi^3 + 18729234720*Pi^4 + 
            514382400*lm*(-24409 + 24*Pi^2) - 348762909600*Sqrt[3]*Pi*
             Log[3]^2 - 35*(344574821277 + 34267717824*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 770691801600*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 478303418880*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 14648594672*PolyGamma[2, 1] - 
              917705303456*Zeta[3])) - 420*CA*(34254407457 - 
            33100507440*lm^2 + 2249226954*Pi^2 - 1614643100*Sqrt[3]*Pi^3 + 
            64277388*Pi^4 + 544320*lm*(-175147 + 33*Pi^2) - 
            4283464728*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            96336475200*Im[PolyLog[2, (-1)^(1/3)]]^2 - 59787927360*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1245581820*Sqrt[3]*Pi*
             Log[3]^2 - 1831074334*PolyGamma[2, 1] + 74294638564*Zeta[3]) + 
          1120*(486*NL*(1299655 - 4643730*lm^2 - 2591586*Pi^2 + 
              420*lm*(-17773 + 6*Pi^2) - 10236240*Zeta[3]) + 
            243*NM*(47953955 - 9287460*lm^2 - 7522992*Pi^2 + 
              840*lm*(-17773 + 6*Pi^2) - 2610234*PolyGamma[2, 1] + 
              8327052*Zeta[3]) - NH*(-271127954259 + 2256852780*lm^2 + 
              6853385000*Sqrt[3]*Pi^3 - 204120*lm*(-17773 + 6*Pi^2) - 
              306267222048*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              253771056000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              5286897000*Sqrt[3]*Pi*Log[3]^2 + 58239022474*PolyGamma[2, 1] + 
              576522067988*Zeta[3]))))/1111065984000, 
      (CF*NC*(-111106598400*(3*CA*(6763 + 3300*lm) - 
           2*(38391*CF + 24300*CF*lm + 2070*NM + 900*lm*NM + 1350*NL + 
             900*lm*NL + 16*NH + 900*lm*NH))*Log[x]^2 + 
         66663959040000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 + 
         105840*Log[x]*(2*(16*(14580*NM*(15280 + 9567*lm + 2025*lm^2 + 
                 525*Pi^2) + 10935*NL*(26035 + 12756*lm + 2700*lm^2 + 
                 1800*Pi^2) + 2*NH*(2961461823 + 69743430*lm + 14762250*
                  lm^2 - 1685686600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
             5*CF*(-9618891519 - 9359030304*lm - 2550916800*lm^2 + 181171080*
                Pi^2 + 655622048*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
               755827200*Zeta[3])) + 5*CA*(-12128834145 - 6232635072*lm - 
             1039262400*lm^2 + 56179656*Pi^2 + 655622048*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 755827200*Zeta[3])) - 
         35*CA*(17546906361600*lm^2 - 4047183293040*Pi^2 + 
           803137008800*Sqrt[3]*Pi^3 + 194092645824*Pi^4 - 
           117573120*lm*(-531539 + 1650*Pi^2) + 619562835360*Sqrt[3]*Pi*
            Log[3]^2 + 7*(3086755153605 - 4350027102720*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 6068687754240*
              Im[PolyLog[2, (-1)^(1/3)]]^2 + 4248430871040*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 957239937248*
              PolyGamma[2, 1] + 6675519388096*Zeta[3])) + 
         2*(CF*(1507438773792000*lm^2 - 151721367246864*Pi^2 + 
             28109795308000*Sqrt[3]*Pi^3 + 5805628395840*Pi^4 - 
             27776649600*lm*(-66931 + 600*Pi^2) + 21684699237600*Sqrt[3]*Pi*
              Log[3]^2 - 35*(-33666731677629 + 30450189719040*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 42480814279680*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 29739016097280*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 6700679560736*
                PolyGamma[2, 1] - 26277871485760*Zeta[3])) - 
           3136*(54675*NL*(-339583 - 325620*lm^2 - 207240*Pi^2 + 48*lm*
                (-15527 + 75*Pi^2) - 1209600*Zeta[3]) + 21870*NM*
              (4142690 - 814050*lm^2 - 298950*Pi^2 + 120*lm*(-15527 + 
                 75*Pi^2) - 152379*PolyGamma[2, 1] + 3637242*Zeta[3]) - 
             2*NH*(-1622112923079 + 8901636750*lm^2 + 73748788750*Sqrt[3]*
                Pi^3 - 1312200*lm*(-15527 + 75*Pi^2) - 535249410600*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 2730812292000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 56891922750*Sqrt[3]*
                Pi*Log[3]^2 + 130009507585*PolyGamma[2, 1] + 98618415170*
                Zeta[3])))))/6666395904000, 
      -(CF*NC*(-825*CA*(267 + 98*lm) + 14*CF*(46283 + 28350*lm) + 
           3*(17939*NM + 4900*lm*NM + 7075*NL + 4900*lm*NL + 108*NH + 
             4900*lm*NH))*Log[x]^2)/405 - 
       (20*CF*NC*(449*CA + 2783*CF - 151*NM - 98*NL)*Log[x]^3)/81 + 
       (CF*NC*Log[x]*(-8*(10404481185*NL + 5174748180*lm*NL + 
            1240029000*lm^2*NL + 133639937139*NH + 5174748180*lm*NH + 
            1240029000*lm^2*NH + 841995000*NL*Pi^2 + 
            3645*NM*(2042947 + 1419684*lm + 340200*lm^2 + 292800*Pi^2) - 
            75934812800*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
            5*CF*(-21641434869 - 20875474872*lm - 6696156600*lm^2 + 
              360347616*Pi^2 + 3460496624*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 1984046400*Zeta[3])) + 
          5*CA*(120973230921 + 59426108784*lm + 10912255200*lm^2 - 
            385121952*Pi^2 - 13841986496*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            7936185600*Zeta[3])))/566870400 - 
       (CF*NC*(-5*CA*(-194505443588205 + 168528869308800*lm^2 - 
            17185551675840*Pi^2 + 16956433457600*Sqrt[3]*Pi^3 + 
            1078196948640*Pi^4 - 3879912960*lm*(-130912 + 75*Pi^2) - 
            81001411759680*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            557263080460800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            627872507458560*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
            13080677238720*Sqrt[3]*Pi*Log[3]^2 + 46236666329392*
             PolyGamma[2, 1] - 379458746490016*Zeta[3]) + 
          8*(5*CF*(33179412400335 + 103415442530400*lm^2 - 7115862247848*Pi^
                2 + 4239108364400*Sqrt[3]*Pi^3 + 258967656360*Pi^4 - 
              297606960*lm*(-238241 + 600*Pi^2) - 20250352939920*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 139315770115200*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 156968126864640*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 3270169309680*Sqrt[3]*Pi*Log[3]^
                2 + 11559166582348*PolyGamma[2, 1] - 155429885433544*Zeta[
                3]) - 8*(984150*NL*(1163547 - 2432430*lm^2 - 1723570*Pi^2 + 
                28*lm*(-151259 + 150*Pi^2) - 9752400*Zeta[3]) + 
              32805*NM*(407825005 - 72972900*lm^2 - 81787080*Pi^2 + 
                840*lm*(-151259 + 150*Pi^2) - 43238502*PolyGamma[2, 1] + 
                383754996*Zeta[3]) - NH*(-328546178117487 + 2393875984500*
                 lm^2 + 11627518210000*Sqrt[3]*Pi^3 - 27556200*lm*
                 (-151259 + 150*Pi^2) - 256604944771200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 430550388576000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 8969799762000*
                 Sqrt[3]*Pi*Log[3]^2 + 53062243630490*PolyGamma[2, 1] + 
                393533448764980*Zeta[3])))))/8571080448000, 
      (CF*NC*(25975109602292445*CF + 106594295560804800*CF*lm + 
         84810305340432000*CF*lm^2 - 31847606424597600*NM + 
         7263566093750400*lm*NM + 3141122420016000*lm^2*NM + 
         703484030138400*NL + 7263566093750400*lm*NL + 
         3141122420016000*lm^2*NL - 744765145013591712*NH + 
         7263566093750400*lm*NH + 3141122420016000*lm^2*NH - 
         13443326080782192*CF*Pi^2 - 699971569920000*CF*lm*Pi^2 - 
         3070001851862400*NM*Pi^2 - 25924872960000*lm*NM*Pi^2 + 
         2517629225328000*NL*Pi^2 - 25924872960000*lm*NL*Pi^2 - 
         25924872960000*lm*NH*Pi^2 + 3138295670580000*Sqrt[3]*CF*Pi^3 + 
         35796501124720000*Sqrt[3]*NH*Pi^3 + 513056476487520*CF*Pi^4 - 
         69897014614862400*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
         222002630298892800*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
         99398296167206400*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         116206605402048000*Sqrt[3]*CF*Im[PolyLog[3, 
            -((-1)^(5/6)/Sqrt[3])]] + 1325493298789632000*Sqrt[3]*NH*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2420970945876000*Sqrt[3]*CF*
          Pi*Log[3]^2 + 27614443724784000*Sqrt[3]*NH*Pi*Log[3]^2 - 
         9258883200*(105*CA*(111217 + 57200*lm) - 
           4*(189*CF*(60701 + 39000*lm) + 168*(-3177 + 1625*lm)*NM + 
             386050*NL + 273000*lm*NL + 11502*NH + 273000*lm*NH))*
          Log[x]^2 + 12962436480000*(3609*CA + 
           20*(791*CF - 26*(6*NM + NL)))*Log[x]^3 + 17617484182248720*CF*
          PolyGamma[2, 1] - 2884829125933440*NM*PolyGamma[2, 1] + 
         56565922536220160*NH*PolyGamma[2, 1] + 15120*Log[x]*
          (4*(535815*NM*(630379 + 560440*lm + 113400*lm^2 - 196680*Pi^2) + 
             535815*NL*(1234937 + 560440*lm + 113400*lm^2 + 89800*Pi^2) + 
             NH*(12856238837727 + 300292158600*lm + 60761421000*lm^2 - 
               7305408392800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
           735*CF*(-35476895253 - 34700341680*lm - 8928208800*lm^2 + 
             787582440*Pi^2 + 3485542880*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             2645395200*Zeta[3]) + 1470*CA*(-11342519751 - 5651528760*lm - 
             909354600*lm^2 + 77295870*Pi^2 + 871385720*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 661348800*Zeta[3])) + 
         54080297386123680*CF*Zeta[3] - 34258501147610880*NM*Zeta[3] + 
         17771500414080000*NL*Zeta[3] - 55084285615815680*NH*Zeta[3] - 
         5880*CA*(2938124712600*lm^2 - 976453855875*Pi^2 + 
           266861876750*Sqrt[3]*Pi^3 + 47154445002*Pi^4 - 
           5511240*lm*(-1911291 + 4400*Pi^2) + 205864876350*Sqrt[3]*Pi*
            Log[3]^2 + 7*(9512429115 - 849089098820*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 1207462295520*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             1411644866400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
             214012198521*PolyGamma[2, 1] + 1255702420242*Zeta[3]))))/
       34998578496000, (-711769888668973*CF^2*NC)/2857026816000 - 
       (527741*CF^2*lm*NC)/320 - (35937*CF^2*lm^2*NC)/16 + 
       (1052823911*CF*NM*NC)/1944000 - (1286411*CF*lm*NM*NC)/8640 - 
       (1331*CF*lm^2*NM*NC)/16 + (109673893*CF*NC*NL)/933120 - 
       (1286411*CF*lm*NC*NL)/8640 - (1331*CF*lm^2*NC*NL)/16 + 
       (30826623701056663*CF*NC*NH)/2187411156000 - (1286411*CF*lm*NC*NH)/
        8640 - (1331*CF*lm^2*NC*NH)/16 - (683976521*CF^2*NC*Pi^2)/19051200 + 
       (95*CF^2*lm*NC*Pi^2)/24 - (39902659*CF*NM*NC*Pi^2)/272160 + 
       (95*CF*lm*NM*NC*Pi^2)/648 - (3905591*CF*NC*NL*Pi^2)/54432 + 
       (95*CF*lm*NC*NL*Pi^2)/648 + (95*CF*lm*NC*NH*Pi^2)/648 - 
       (67553205937*CF^2*NC*Pi^3)/(153055008*Sqrt[3]) - 
       (130366685155*CF*NC*NH*Pi^3)/(76527504*Sqrt[3]) - 
       (154373*CF^2*NC*Pi^4)/12960 + (3914222509349*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1785641760*Sqrt[3]) + 
       (11830806419239*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (446410440*Sqrt[3]) - (20671*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        6 - (9650457991*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (590490*Sqrt[3]) - (3724762433*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (9650457991*CF^2*NC*Pi*Log[3]^2)/(28343520*Sqrt[3]) - 
       (3724762433*CF*NC*NH*Pi*Log[3]^2)/(2834352*Sqrt[3]) - 
       (CF*NC*(-7*CA*(39552817 + 10659660*lm) + 
          2*(28*CF*(13394396 + 6541155*lm) + 420*(83582 + 16151*lm)*NM + 
            9111165*NL + 6783420*lm*NL + 346032*NH + 6783420*lm*NH))*
         Log[x]^2)/45360 - (CF*NC*(84095*CA + 1322865*CF - 94172*NM - 
          32302*NL)*Log[x]^3)/162 - (31617104639597*CF^2*NC*PolyGamma[2, 1])/
        53569252800 - (11742721*CF*NM*NC*PolyGamma[2, 1])/226800 - 
       (929007322207*CF*NC*NH*PolyGamma[2, 1])/478296900 + 
       (CA*CF*NC*(23529222907344000*lm^2 + 3230121749911200*Pi^2 + 
          3782979532472000*Sqrt[3]*Pi^3 + 312314695963200*Pi^4 - 
          10912255200*lm*(-6603513 + 3800*Pi^2) + 2918298496478400*Sqrt[3]*Pi*
           Log[3]^2 + 3*(-13078995168722631 - 6262756014958400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 29528800656768000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 46692775943654400*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 5058736742335520*
             PolyGamma[2, 1] - 25707654962432960*Zeta[3])))/51426482688000 + 
       (122304108494143*CF^2*NC*Zeta[3])/26784626400 + 
       (106302479*CF*NM*NC*Zeta[3])/113400 - (13793*CF*NC*NL*Zeta[3])/27 - 
       (2607726105457*CF*NC*NH*Zeta[3])/239148450 - 
       (CF*NC*Log[x]*(-49*CA*(26690252463327 + 11127398788080*lm + 
            1964205936000*lm^2 + 427046042160*Pi^2 - 3088146557120*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 1428513408000*Zeta[3]) + 
          2*(4*(428652*NM*(85798397 + 22414215*lm + 5103000*lm^2 + 
                1722750*Pi^2) + 535815*NL*(39420973 + 17931372*lm + 
                4082400*lm^2 + 3298920*Pi^2) + 2*NH*(128875205125389 + 
                4803949044090*lm + 1093705578000*lm^2 - 73005343686800*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            49*CF*(19851760567047 + 16087512688560*lm + 4821232752000*lm^2 + 
              183056623920*Pi^2 - 3088146557120*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 1428513408000*Zeta[3]))))/166659897600, 
      (CF*NC*(-4124832465600*(21*CA*(11056547 + 6871480*lm) - 
           2*(7*CF*(72460807 + 50599080*lm) + 2*(42*(-2798347 + 156170*lm)*
                NM + 245*(36581 + 26772*lm)*NL + 10*(44921 + 655914*lm)*
                NH)))*Log[x]^2 + 5389781088384000*(103738*CA + 499351*CF - 
           6*(34278*NM + 2231*NL))*Log[x]^3 + 83160*Log[x]*
          (2*(-20*(-8680203*NL*(12897273 + 5406428*lm + 1058400*lm^2 + 
                 977480*Pi^2) + 34720812*NM*(5495792 - 1351607*lm - 
                 264600*lm^2 + 2122050*Pi^2) - 2*NH*(1046190705420783 + 
                 23464446272442*lm + 4593563427600*lm^2 - 593665595682320*
                  Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
             49*CF*(-375126405180387 - 410304891158640*lm - 101245887792000*
                lm^2 + 13096340716320*Pi^2 + 51304807934080*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 29998781568000*Zeta[3])) + 
           49*CA*(-497394580388937 - 263199017945520*lm - 41248324656000*
              lm^2 + 7012697031360*Pi^2 + 51304807934080*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 29998781568000*Zeta[3])) - 
         3773*CA*(-46068811932404457 + 31051149539256000*lm^2 - 
           18452762461877400*Pi^2 + 4489170694232000*Sqrt[3]*Pi^3 + 
           660877622047440*Pi^4 - 1913187600*lm*(-58359963 + 107800*Pi^2) - 
           73398121248811200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           103272734040940800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           166227577706419200*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           3463074535550400*Sqrt[3]*Pi*Log[3]^2 + 19095642410257960*
            PolyGamma[2, 1] + 107377046196771920*Zeta[3]) + 
         2*(49*CF*(5868667262919384000*lm^2 - 1632937822949218248*Pi^2 + 
             345666143455864000*Sqrt[3]*Pi^3 + 48577670716916880*Pi^4 - 
             3977517020400*lm*(-1870163 + 9800*Pi^2) + 266656739237380800*
              Sqrt[3]*Pi*Log[3]^2 - 77*(18160146330167547 + 73398121248811200*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 103272734040940800*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 166227577706419200*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 19095642410257960*
                PolyGamma[2, 1] - 53090066425557200*Zeta[3])) - 
           220*(-2*NH*(-7435543927014172989 + 24205782481738200*lm^2 + 
               363620177355421000*Sqrt[3]*Pi^3 - 16405583670*lm*(-3427593 + 
                 9800*Pi^2) - 2058665153945519280*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 13464335710075017600*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 280506993959896200*
                Sqrt[3]*Pi*Log[3]^2 + 537345450515352416*PolyGamma[2, 1] - 
               1025670040605119168*Zeta[3]) + 911421315*NL*
              (59731261 - 53116560*lm^2 - 51223320*Pi^2 + 36*lm*(-3427593 + 
                 9800*Pi^2) - 426504960*Zeta[3]) + 364568526*NM*
              (1701946541 - 132791400*lm^2 + 1150368420*Pi^2 + 90*lm*
                (-3427593 + 9800*Pi^2) + 1000374552*PolyGamma[2, 1] + 
               2363629104*Zeta[3])))))/62367466879872000, 
      (101558019215173631569*CF^2*NC)/31498720646400000 - 
       (47135309*CF^2*lm*NC)/8000 - (621621*CF^2*lm^2*NC)/80 + 
       (438287113799*CF*NM*NC)/416745000 - (112750859*CF*lm*NM*NC)/216000 - 
       (23023*CF*lm^2*NM*NC)/80 + (97306588313*CF*NC*NL)/116640000 - 
       (112750859*CF*lm*NC*NL)/216000 - (23023*CF*lm^2*NC*NL)/80 + 
       (48648767176219619*CF*NC*NH)/803538792000 - (112750859*CF*lm*NC*NH)/
        216000 - (23023*CF*lm^2*NC*NH)/80 - (382802450353*CF^2*NC*Pi^2)/
        74844000 + (1519*CF^2*lm*NC*Pi^2)/120 - (300477281*CF*NM*NC*Pi^2)/
        194400 + (1519*CF*lm*NM*NC*Pi^2)/3240 - (56924321*CF*NC*NL*Pi^2)/
        194400 + (1519*CF*lm*NC*NL*Pi^2)/3240 + (1519*CF*lm*NC*NH*Pi^2)/
        3240 - (14961964181899*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) - 
       (5380203227287*CF*NC*NH*Pi^3)/(688747536*Sqrt[3]) - 
       (100009*CF^2*NC*Pi^4)/1620 + (580150195938661*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(57395628000*Sqrt[3]) + 
       (56537720338201*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (573956280*Sqrt[3]) - (201292*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        15 - (2137423454557*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) - (768600461041*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (2137423454557*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) - 
       (768600461041*CF*NC*NH*Pi*Log[3]^2)/(127545840*Sqrt[3]) - 
       (CF*NC*(-30*CA*(1159793538 + 166904815*lm) + 
          CF*(83063496247 + 24580527300*lm) + 15*(723413924*NM + 
            60692660*lm*NM + 78172507*NL + 60692660*lm*NL + 4887540*NH + 
            60692660*lm*NH))*Log[x]^2)/567000 + 
       (CF*NC*(17330035*CA - 273142357*CF + 14205500*NM + 4335190*NL)*
         Log[x]^3)/4050 - (4248095494150993*CF^2*NC*PolyGamma[2, 1])/
        723184912800 + (10075409*CF*NM*NC*PolyGamma[2, 1])/226800 - 
       (681420133489859*CF*NC*NH*PolyGamma[2, 1])/90398114100 + 
       (CA*CF*NC*(-112851474420611225259 + 35897154749382326400*lm^2 + 
          62547445910945858688*Pi^2 + 8211125943026171200*Sqrt[3]*Pi^3 + 
          708540621878960640*Pi^4 - 192492181728*lm*(-575598777 + 
            303800*Pi^2) - 38206371303736458816*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 152170571432523571200*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 304046263490340510720*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6334297156048760640*
           Sqrt[3]*Pi*Log[3]^2 + 66610137348287570240*PolyGamma[2, 1] - 
          186113632021631753600*Zeta[3]))/22679078865408000 + 
       (8311995815450297*CF^2*NC*Zeta[3])/361592456400 + 
       (691643009*CF*NM*NC*Zeta[3])/113400 - (336589*CF*NC*NL*Zeta[3])/
        135 - (1476687051639269*CF*NC*NH*Zeta[3])/45199057050 - 
       (CF*NC*Log[x]*(-5*CA*(417102278286540783 + 105975081590459760*lm + 
            18190511173296000*lm^2 + 19561279803644880*Pi^2 - 
            33514799767453760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            13229462671488000*Zeta[3]) + 
          2*(20*(78732*NM*(313700545741 + 23908357095*lm + 5250987000*lm^2 + 
                161971950*Pi^2) + 49*(19683*NL*(4688058049 + 1951702620*lm + 
                  428652000*lm^2 + 402995400*Pi^2) + 10*NH*
                 (108790344587397 + 3841536266946*lm + 843715731600*lm^2 - 
                  61488036883280*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
            CF*(1741550191029421971 + 780820692398031600*lm + 
              223247182581360000*lm^2 + 84671293625427600*Pi^2 - 
              167573998837268800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              66147313357440000*Zeta[3]))))/37498476960000, 
      (-316291410506445914773*CF^2*NC)/15749360323200000 + 
       (17890431*CF^2*lm*NC)/500 + (281043*CF^2*lm^2*NC)/10 + 
       (2251586045501*CF*NM*NC)/104186250 + (2726938*CF*lm*NM*NC)/1125 + 
       (10409*CF*lm^2*NM*NC)/10 - (7545588649*CF*NC*NL)/2430000 + 
       (2726938*CF*lm*NC*NL)/1125 + (10409*CF*lm^2*NC*NL)/10 - 
       (1776220146247472357363*CF*NC*NH)/4367166372954000 + 
       (2726938*CF*lm*NC*NH)/1125 + (10409*CF*lm^2*NC*NH)/10 - 
       (4877440724393*CF^2*NC*Pi^2)/224532000 - (784*CF^2*lm*NC*Pi^2)/5 - 
       (201707237*CF*NM*NC*Pi^2)/4050 - (784*CF*lm*NM*NC*Pi^2)/135 + 
       (1583071*CF*NC*NL*Pi^2)/1350 - (784*CF*lm*NC*NL*Pi^2)/135 - 
       (784*CF*lm*NC*NH*Pi^2)/135 + (16271406301577*CF^2*NC*Pi^3)/
        (2295825120*Sqrt[3]) + (2581057946033*CF*NC*NH*Pi^3)/
        (43046721*Sqrt[3]) + (1595713*CF^2*NC*Pi^4)/5400 - 
       (2716197925163227*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (28697814000*Sqrt[3]) - (7664393188918*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
       (647794*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (2324486614511*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (8857350*Sqrt[3]) + (5899561019504*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) + 
       (2324486614511*CF^2*NC*Pi*Log[3]^2)/(425152800*Sqrt[3]) + 
       (368722563719*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) + 
       (CF*NC*(-275*CA*(19175665 + 638476608*lm) + 
          8*(33*CF*(2602032563 + 3264937200*lm) + 
            20*(33*(-452894803 + 6046180*lm)*NM + 77*(3465319 + 2591220*lm)*
               NL + 30*(626909 + 6650798*lm)*NH)))*Log[x]^2)/4158000 + 
       (4*CF*NC*(28334865*CA + 102583166*CF - 107307900*NM - 2591220*NL)*
         Log[x]^3)/2025 + (647060741089379*CF^2*NC*PolyGamma[2, 1])/
        154968195600 - (5529143*CF*NM*NC*PolyGamma[2, 1])/135 + 
       (545606024901269*CF*NC*NH*PolyGamma[2, 1])/19371024450 - 
       (CA*CF*NC*(1338939860677212024000*lm^2 - 2382639341045843129670*Pi^2 + 
          276264071891325094500*Sqrt[3]*Pi^3 + 35642336005363071600*Pi^4 - 
          34648592711040*lm*(-139171479 + 215600*Pi^2) + 
          213117998316165072900*Sqrt[3]*Pi*Log[3]^2 - 
          11*(354934988915469451371 + 335396119799155269960*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 459105350454315936000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 929969447197811227200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 44388366838731399400*
             PolyGamma[2, 1] - 545984361022294670000*Zeta[3])))/
        233878000799520000 + (2087264611768967*CF^2*NC*Zeta[3])/77484097800 - 
       (3169606*CF*NM*NC*Zeta[3])/135 + (507392*CF*NC*NL*Zeta[3])/45 - 
       (677388051910651*CF*NC*NH*Zeta[3])/9685512225 + 
       CF*Log[x]*((-390648468649*NM*NC)/1323000 + (6235852*lm*NM*NC)/675 + 
         1764*lm^2*NM*NC + (643429361*NC*NL)/27000 + (6235852*lm*NC*NL)/
          675 + 1764*lm^2*NC*NL + (822733737722295253*NC*NH)/
          1890548213400 + (6235852*lm*NC*NH)/675 + 1764*lm^2*NC*NH - 
         (2303012*NM*NC*Pi^2)/45 + (252128*NC*NL*Pi^2)/135 - 
         (5899561019504*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7971615*Sqrt[3]) + CA*NC*(-13103608486538261/208324872000 - 
           (42632086*lm)/675 - 9702*lm^2 + (63508327*Pi^2)/10800 + 
           (2324486614511*Im[PolyLog[2, (-1)^(1/3)]])/(53144100*Sqrt[3]) - 
           7056*Zeta[3]) + CF*NC*(66602674175114963/1041624360000 + 
           (4979002*lm)/25 + 47628*lm^2 - (242298931*Pi^2)/16200 - 
           (2324486614511*Im[PolyLog[2, (-1)^(1/3)]])/(26572050*Sqrt[3]) + 
           14112*Zeta[3])), (642974482348166892683*CF^2*NC)/
        8099671023360000 - (61415759*CF^2*lm*NC)/3600 - 
       (88389*CF^2*lm^2*NC)/4 - (159335905432663*CF*NM*NC)/15431472000 - 
       (145385309*CF*lm*NM*NC)/97200 - (9821*CF*lm^2*NM*NC)/12 + 
       (3896301497*CF*NC*NL)/972000 - (145385309*CF*lm*NC*NL)/97200 - 
       (9821*CF*lm^2*NC*NL)/12 + (39940960717842674931317*CF*NC*NH)/
        188661587311612800 - (145385309*CF*lm*NC*NH)/97200 - 
       (9821*CF*lm^2*NC*NH)/12 - (44553031774693*CF^2*NC*Pi^2)/449064000 + 
       (98*CF^2*lm*NC*Pi^2)/3 - (69872551*CF*NM*NC*Pi^2)/2430 + 
       (98*CF*lm*NM*NC*Pi^2)/81 - (2332601*CF*NC*NL*Pi^2)/2430 + 
       (98*CF*lm*NC*NL*Pi^2)/81 + (98*CF*lm*NC*NH*Pi^2)/81 - 
       (22615719792631*CF^2*NC*Pi^3)/(2754990144*Sqrt[3]) - 
       (3663383042480*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) - 
       (1506211*CF^2*NC*Pi^4)/6480 + (3716714930178959*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(103312130400*Sqrt[3]) + 
       (40191968915480*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (129140163*Sqrt[3]) - 42483*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (3230817113233*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10628820*Sqrt[3]) - (1674689390848*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (3230817113233*CF^2*NC*Pi*Log[3]^2)/(510183360*Sqrt[3]) - 
       (104668086928*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) - 
       (CF*NC*(-1155*CA*(46487804413 + 2328242400*lm) + 
          8*(924*CF*(15524280349 + 1785867750*lm) + 
            25*(77*(1706686159 + 31748760*lm)*NM + 1386*(2211779 + 
                1763820*lm)*NL + 5*(53064863 + 488930904*lm)*NH)))*
         Log[x]^2)/74844000 + (4*CF*NC*(67446990*CA - 275736064*CF + 
          25*(-642550*NM + 88191*NL))*Log[x]^3)/2025 - 
       (16408201821259741*CF^2*NC*PolyGamma[2, 1])/241061637600 - 
       (22343431*CF*NM*NC*PolyGamma[2, 1])/12600 - 
       (493009856176531*CF*NC*NH*PolyGamma[2, 1])/20088469800 + 
       (CA*CF*NC*(-153612694839949387629 + 13672118130071940000*lm^2 + 
          152771129415881775225*Pi^2 + 4155638511895946250*Sqrt[3]*Pi^3 + 
          355943746096155000*Pi^4 - 15624365400*lm*(-2712939799 + 
            1293600*Pi^2) - 18211903157876899100*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 64518435766013040000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 153877357469061324000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3205778280605444250*
           Sqrt[3]*Pi*Log[3]^2 + 103371671473936368300*PolyGamma[2, 1] - 
          139099494188551541400*Zeta[3]))/3037376633760000 + 
       (13760090138683487*CF^2*NC*Zeta[3])/120530818800 + 
       (284886569*CF*NM*NC*Zeta[3])/6300 - (256154*CF*NC*NL*Zeta[3])/27 - 
       (839096493948931*CF*NC*NH*Zeta[3])/10044234900 + 
       CF*Log[x]*((-2485029859559*NM*NC)/6123600 - (5567863*lm*NM*NC)/810 - 
         1470*lm^2*NM*NC - (1747532687*NC*NL)/97200 - (5567863*lm*NC*NL)/
          810 - 1470*lm^2*NC*NL - (469239323224350667*NC*NH)/
          2268657856080 - (5567863*lm*NC*NH)/810 - 1470*lm^2*NC*NH - 
         (915068*NM*NC*Pi^2)/81 - (14209*NC*NL*Pi^2)/9 + 
         (1674689390848*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CF*NC*(-918355793876340131/892820880000 - 
           (4311013*lm)/30 - 39690*lm^2 - (2505711041*Pi^2)/32400 + 
           (3230817113233*Im[PolyLog[2, (-1)^(1/3)]])/(31886460*Sqrt[3]) - 
           11760*Zeta[3]) + CA*NC*(97683426207327953/178564176000 + 
           (77916293*lm)/1620 + 8085*lm^2 + (518380927*Pi^2)/12960 - 
           (3230817113233*Im[PolyLog[2, (-1)^(1/3)]])/(63772920*Sqrt[3]) + 
           5880*Zeta[3])), (3832357142913824500943*CF^2*NC)/
        141744242908800000 + (280292351*CF^2*lm*NC)/3000 + 
       (731997*CF^2*lm^2*NC)/10 + (22880245029847273*CF*NM*NC)/30005640000 + 
       (512091401*CF*lm*NM*NC)/81000 + (27111*CF*lm^2*NM*NC)/10 - 
       (734212828*CF*NC*NL)/50625 + (512091401*CF*lm*NC*NL)/81000 + 
       (27111*CF*lm^2*NC*NL)/10 - (39114856831012204316758751*CF*NC*NH)/
        29606393380258094400 + (512091401*CF*lm*NC*NH)/81000 + 
       (27111*CF*lm^2*NC*NH)/10 - (132093853667389*CF^2*NC*Pi^2)/486486000 - 
       (1764*CF^2*lm*NC*Pi^2)/5 - (2827722547*CF*NM*NC*Pi^2)/4050 - 
       (196*CF*lm*NM*NC*Pi^2)/15 + (1572037*CF*NC*NL*Pi^2)/450 - 
       (196*CF*lm*NC*NL*Pi^2)/15 - (196*CF*lm*NC*NH*Pi^2)/15 + 
       (169849519748167*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) + 
       (2795484489581*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) + 
       (1680539*CF^2*NC*Pi^4)/1800 - (73907802913555441*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(258280326000*Sqrt[3]) - 
       (129501079517710*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (129140163*Sqrt[3]) + (628614*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 + (24264217106881*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) + (6389678833328*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(885735*Sqrt[3]) + 
       (24264217106881*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) + 
       (399354927083*CF*NC*NH*Pi*Log[3]^2)/(2657205*Sqrt[3]) + 
       (CF*NC*(-143*CA*(-1327102821431 + 170859981600*lm) + 
          4*(143*CF*(-497682685417 + 209691795600*lm) + 
            30*(143*(-78373248661 + 258878760*lm)*NM + 7*(6971777098*NL + 
                5288523240*lm*NL + 626503715*NH + 5288523240*lm*NH))))*
         Log[x]^2)/162162000 + (CF*NC*(653013639*CA + 425065922*CF - 
          80*(41490690*NM + 308189*NL))*Log[x]^3)/1350 - 
       (35527098696395947*CF^2*NC*PolyGamma[2, 1])/464904586800 - 
       (1437827003*CF*NM*NC*PolyGamma[2, 1])/2700 + 
       (410203075455589*CF*NC*NH*PolyGamma[2, 1])/4649045868 + 
       (43077407276897057*CF^2*NC*Zeta[3])/232452293400 - 
       (20564603*CF*NM*NC*Zeta[3])/1350 + (1716092*CF*NC*NL*Zeta[3])/45 - 
       (2939090694326359*CF*NC*NH*Zeta[3])/11622614670 - 
       (CA*CF*NC*(-56978266441101813594 + 95109997195136800800*lm^2 - 
          852174033059630288637*Pi^2 + 26216273373129576450*Sqrt[3]*Pi^3 + 
          3044260594785697560*Pi^4 - 39373400808*lm*(-8707392811 + 
            11642400*Pi^2) - 304204516792194195156*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 400960869803425814400*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 970751151187883745120*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 20223982316414244690*
           Sqrt[3]*Pi*Log[3]^2 - 243715897057276196420*PolyGamma[2, 1] + 
          836391330088528001480*Zeta[3]))/6378490930896000 + 
       CF*Log[x]*((-14643605640259*NM*NC)/2976750 + (2119358*lm*NM*NC)/75 + 
         5292*lm^2*NM*NC + (1061066783*NC*NL)/13500 + (2119358*lm*NC*NL)/
          75 + 5292*lm^2*NC*NL + (107647262778546758*NC*NH)/76072059063 + 
         (2119358*lm*NC*NH)/75 + 5292*lm^2*NC*NH - (9143564*NM*NC*Pi^2)/
          15 + (854518*NC*NL*Pi^2)/135 - (6389678833328*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) + 
         CA*NC*(7466485828108043/9765228375 - (14434769*lm)/75 - 29106*lm^2 + 
           (987292891*Pi^2)/10800 + (24264217106881*Im[PolyLog[2, (-1)^
                (1/3)]])/(159432300*Sqrt[3]) - 21168*Zeta[3]) + 
         CF*NC*(-1079468824636197517/624974616000 + (15303672*lm)/25 + 
           142884*lm^2 - (116072297*Pi^2)/600 - 
           (24264217106881*Im[PolyLog[2, (-1)^(1/3)]])/(79716150*Sqrt[3]) + 
           42336*Zeta[3])), (1637153210582346378910227913*CF^2*NC)/
        1131969523869676800000 - (37595254931*CF^2*lm*NC)/882000 - 
       (1091961*CF^2*lm^2*NC)/20 + (12751463535004396969*CF*NM*NC)/
        718875123120000 - (88426039481*CF*lm*NM*NC)/23814000 - 
       (40443*CF*lm^2*NM*NC)/20 + (74825602896293*CF*NC*NL)/5000940000 - 
       (88426039481*CF*lm*NC*NL)/23814000 - (40443*CF*lm^2*NC*NL)/20 + 
       (358699712483411434017066493*CF*NC*NH)/565212964532199984000 - 
       (88426039481*CF*lm*NC*NH)/23814000 - (40443*CF*lm^2*NC*NH)/20 - 
       (4840304722169359*CF^2*NC*Pi^2)/3143448000 + (366*CF^2*lm*NC*Pi^2)/5 - 
       (3369602698*CF*NM*NC*Pi^2)/6075 + (122*CF*lm*NM*NC*Pi^2)/45 - 
       (12693824*CF*NC*NL*Pi^2)/4725 + (122*CF*lm*NC*NL*Pi^2)/45 + 
       (122*CF*lm*NC*NH*Pi^2)/45 - (638592391263959*CF^2*NC*Pi^3)/
        (24794911296*Sqrt[3]) - (33747171466918*CF*NC*NH*Pi^3)/
        (387420489*Sqrt[3]) - (7699813*CF^2*NC*Pi^4)/10800 + 
       (1642410589171914997*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (15186883168800*Sqrt[3]) + (2349462551497318*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2711943423*Sqrt[3]) - 
       115699*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (638592391263959*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (669615660*Sqrt[3]) - (77136391924384*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23914845*Sqrt[3]) - 
       (638592391263959*CF^2*NC*Pi*Log[3]^2)/(32141551680*Sqrt[3]) - 
       (4821024495274*CF*NC*NH*Pi*Log[3]^2)/(71744535*Sqrt[3]) - 
       (CF*NC*(-13*CA*(5050879597358813 + 62950227832800*lm) + 
          8*(13*CF*(1284579561486281 + 38628548897400*lm) + 
            35*(91*(1786477540949 + 5839538760*lm)*NM + 
              11*(234*(254175573 + 206448340*lm)*NL + 5*(1298781121 + 
                  9661782312*lm)*NH))))*Log[x]^2)/6810804000 + 
       (CF*NC*(63781728331*CA - 157606536922*CF - 37162431600*NM + 
          412896680*NL)*Log[x]^3)/28350 - (17484291148835908309*CF^2*NC*
         PolyGamma[2, 1])/19525992645600 - 
       (2147694487*CF*NM*NC*PolyGamma[2, 1])/16200 - 
       (340422732775742231*CF*NC*NH*PolyGamma[2, 1])/4881498161400 + 
       CA*CF*NC*((444873*lm^2)/40 + (647044530861649*Pi^2)/838252800 + 
         (638592391263959*Pi^3)/(49589822592*Sqrt[3]) + 
         (7746661*Pi^4)/21600 + lm*(1646863155691/47628000 - (671*Pi^2)/45) + 
         (638592391263959*Pi*Log[3]^2)/(64283103360*Sqrt[3]) + 
         (-67237805765963617620621012 - 1606745643228046862840145*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 5156854838974035858276000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 14168771107820177115544200*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           39910779455257518640163485*PolyGamma[2, 1] - 
           34294582029372374748306730*Zeta[3])/89142600004737048000) + 
       (8163819881884054679*CF^2*NC*Zeta[3])/9762996322800 + 
       (4070997113*CF*NM*NC*Zeta[3])/8100 - (4076314*CF*NC*NL*Zeta[3])/
        135 - (460805033500816871*CF*NC*NH*Zeta[3])/2440749080700 + 
       CF*Log[x]*((-163548653216436683*NM*NC)/25933446000 - 
         (62519699*lm*NM*NC)/3150 - 4158*lm^2*NM*NC - (446745693211*NC*NL)/
          7938000 - (62519699*lm*NC*NL)/3150 - 4158*lm^2*NC*NL - 
         (332440428697063171553*NC*NH)/522822515014800 - 
         (62519699*lm*NC*NH)/3150 - 4158*lm^2*NC*NH - 
         (45663436*NM*NC*Pi^2)/135 - (2035961*NC*NL*Pi^2)/405 + 
         (77136391924384*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (71744535*Sqrt[3]) + CF*NC*(-131106608802560791833899/
            9528362995536000 - (146083047*lm)/350 - 112266*lm^2 - 
           (12562203427*Pi^2)/10800 + (638592391263959*
             Im[PolyLog[2, (-1)^(1/3)]])/(2008846980*Sqrt[3]) - 
           33264*Zeta[3]) + CA*NC*(1356939677125502282479/194456387664000 + 
           (871084489*lm)/6300 + 22869*lm^2 + (29524634029*Pi^2)/50400 - 
           (638592391263959*Im[PolyLog[2, (-1)^(1/3)]])/(4017693960*
             Sqrt[3]) + 16632*Zeta[3])), 
      (19875492709165258246355423473*CF^2*NC)/7131408000378963840000 + 
       (637102477*CF^2*lm*NC)/2940 + (339039*CF^2*lm^2*NC)/2 + 
       (4879524207163514407*CF*NM*NC)/399375068400 + 
       (290794498*CF*lm*NM*NC)/19845 + (12557*CF*lm^2*NM*NC)/2 - 
       (81978583987*CF*NC*NL)/1587600 + (290794498*CF*lm*NC*NL)/19845 + 
       (12557*CF*lm^2*NC*NL)/2 - (936031015624406415602918723*CF*NC*NH)/
        249803944145927671500 + (290794498*CF*lm*NC*NH)/19845 + 
       (12557*CF*lm^2*NC*NH)/2 - (80561491251011753*CF^2*NC*Pi^2)/
        20432412000 - 720*CF^2*lm*NC*Pi^2 - (52626362963*CF*NM*NC*Pi^2)/
        5670 - (80*CF*lm*NM*NC*Pi^2)/3 + (1147453*CF*NC*NL*Pi^2)/126 - 
       (80*CF*lm*NC*NL*Pi^2)/3 - (80*CF*lm*NC*NH*Pi^2)/3 + 
       (40705809795314467*CF^2*NC*Pi^3)/(557885504160*Sqrt[3]) + 
       (1923902656435025*CF*NC*NH*Pi^3)/(3486784401*Sqrt[3]) + 
       (13727161*CF^2*NC*Pi^4)/5400 - (261513978223420261613*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(341704871298000*Sqrt[3]) - 
       (48288784249382734*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (17433922005*Sqrt[3]) + (1608694*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 + (40705809795314467*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(15066352350*Sqrt[3]) + 
       (879498357227440*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) + (40705809795314467*CF^2*NC*Pi*Log[3]^2)/
        (723184912800*Sqrt[3]) + (54968647326715*CF*NC*NH*Pi*Log[3]^2)/
        (129140163*Sqrt[3]) + 
       (CF*NC*(CA*(75890202087369631 - 1559993467032000*lm) + 
          32*(52*CF*(-87550234337452 + 4602253453875*lm) + 
            1575*(78*(-96254553289 + 72149770*lm)*NM + 
              7*(143*(7337197 + 5622060*lm)*NL + 3*(37735431 + 267984860*lm)*
                 NH))))*Log[x]^2)/3405402000 - 
       (CF*NC*(-86041458599*CA + 48*(2289165702*CF + 
            175*(50702757*NM + 93701*NL)))*Log[x]^3)/14175 - 
       (21500265194899760869*CF^2*NC*PolyGamma[2, 1])/12552423843600 - 
       (8839797457*CF*NM*NC*PolyGamma[2, 1])/1350 + 
       (190313159549917867*CF*NC*NH*PolyGamma[2, 1])/784526490225 + 
       CA*CF*NC*((-138127*lm^2)/4 + (17848870077662929*Pi^2)/9081072000 - 
         (40705809795314467*Pi^3)/(1115771008320*Sqrt[3]) - 
         (13957561*Pi^4)/10800 + lm*(-4943095133/39690 + (440*Pi^2)/3) - 
         (40705809795314467*Pi*Log[3]^2)/(1446369825600*Sqrt[3]) + 
         (-21293819932551319224470069073 + 2046681617490389525056589640*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 2581256983896368292515616000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 - 7225282476124935670059796800*
            Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           13741812798312441540330047800*PolyGamma[2, 1] - 
           19184893764808585492130729200*Zeta[3])/16045668000852668640000) + 
       (95686519999872953993*CF^2*NC*Zeta[3])/43933483452600 + 
       (917968343*CF*NM*NC*Zeta[3])/675 + (1001968*CF*NC*NL*Zeta[3])/9 - 
       (596893687720514266*CF*NC*NH*Zeta[3])/784526490225 + 
       CF*Log[x]*((-4018121437567913*NM*NC)/57629880 + (7892362*lm*NM*NC)/
          105 + 13860*lm^2*NM*NC + (1698323549*NC*NL)/7560 + 
         (7892362*lm*NC*NL)/105 + 13860*lm^2*NC*NL + 
         (14824769774524449818011*NC*NH)/3697102070461800 + 
         (7892362*lm*NC*NH)/105 + 13860*lm^2*NC*NH - 7499508*NM*NC*Pi^2 + 
         (499544*NC*NL*Pi^2)/27 - (879498357227440*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(129140163*Sqrt[3]) + 
         CA*NC*(28133957657461635586517/1715105339196480 - 
           (53595091*lm)/105 - 76230*lm^2 + (323529785723*Pi^2)/226800 + 
           (40705809795314467*Im[PolyLog[2, (-1)^(1/3)]])/
            (90398114100*Sqrt[3]) - 55440*Zeta[3]) + 
         CF*NC*(-7151465916001458842177393/214388167399560000 + 
           (57205908*lm)/35 + 374220*lm^2 - (21799909267*Pi^2)/7560 - 
           (40705809795314467*Im[PolyLog[2, (-1)^(1/3)]])/
            (45199057050*Sqrt[3]) + 110880*Zeta[3])), 
      (3026559610092068187571112200624483*CF^2*NC)/
        125341627014660668451840000 - (53850295979*CF^2*lm*NC)/564480 - 
       (1940679*CF^2*lm^2*NC)/16 + (23578186507593947196411401*CF*NM*NC)/
        5053979665582848000 - (126121181939*CF*lm*NM*NC)/15240960 - 
       (71877*CF*lm^2*NM*NC)/16 + (299041719103447*CF*NC*NL)/6401203200 - 
       (126121181939*CF*lm*NC*NL)/15240960 - (71877*CF*lm^2*NC*NL)/16 + 
       (503646101826843078817091098327*CF*NC*NH)/298432445273001591552000 - 
       (126121181939*CF*lm*NC*NH)/15240960 - (71877*CF*lm^2*NC*NH)/16 - 
       (291284043689087507*CF^2*NC*Pi^2)/13076743680 + 
       (1185*CF^2*lm*NC*Pi^2)/8 - (2599541627989*CF*NM*NC*Pi^2)/272160 + 
       (395*CF*lm*NM*NC*Pi^2)/72 - (1260281*CF*NC*NL*Pi^2)/189 + 
       (395*CF*lm*NC*NL*Pi^2)/72 + (395*CF*lm*NC*NH*Pi^2)/72 - 
       (31386428814233129*CF^2*NC*Pi^3)/(446308403328*Sqrt[3]) - 
       (2189459521141585*CF*NC*NH*Pi^3)/(9298091736*Sqrt[3]) - 
       (8162047*CF^2*NC*Pi^4)/4320 + (22446053332090916639*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(78103970582400*Sqrt[3]) + 
       (709079457887570267*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (325433210760*Sqrt[3]) - (561869*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 - (4483775544890447*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1721868840*Sqrt[3]) - 
       (125111972636662*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) - (4483775544890447*CF^2*NC*Pi*Log[3]^2)/
        (82649704320*Sqrt[3]) - (62555986318331*CF*NC*NH*Pi*Log[3]^2)/
        (344373768*Sqrt[3]) - 
       (CF*NC*(-(CA*(734457350801565689 + 1890537626577600*lm)) + 
          2*CF*(737111738802421709 + 4640410537963200*lm) + 
          280*((2232169204077991 + 1227621835440*lm)*NM + 
            5148*(289736031 + 238465780*lm)*NL + 
            (194133654653 + 1227621835440*lm)*NH))*Log[x]^2)/5448643200 + 
       (CF*NC*(757640742065*CA - 1593165373652*CF - 596215124400*NM + 
          953863120*NL)*Log[x]^3)/22680 - (2160347097386360731627*CF^2*NC*
         PolyGamma[2, 1])/175733933810400 - 
       (47343680798*CF*NM*NC*PolyGamma[2, 1])/14175 - 
       (5208563457509373271*CF*NC*NH*PolyGamma[2, 1])/29288988968400 + 
       CA*CF*NC*(-12435746922799867790065972097261/
          1023196955221719742464000 + (790647*lm^2)/32 + 
         (485693587998243341*Pi^2)/43589145600 + (31386428814233129*Pi^3)/
          (892616806656*Sqrt[3]) + (8199967*Pi^4)/8640 + 
         lm*(2345873173009/30481920 - (4345*Pi^2)/144) - 
         (22446053332090916639*Im[PolyLog[2, (-1)^(1/3)]])/
          (156207941164800*Sqrt[3]) + (561869*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 + (4483775544890447*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3443737680*Sqrt[3]) + (4483775544890447*Pi*Log[3]^2)/
          (165299408640*Sqrt[3]) + (2160347097386360731627*PolyGamma[2, 1])/
          351467867620800 - (213177233994069390797*Zeta[3])/43933483452600) + 
       (434082528520513773709*CF^2*NC*Zeta[3])/43933483452600 + 
       (192546002533*CF*NM*NC*Zeta[3])/28350 - (4532869*CF*NC*NL*Zeta[3])/
        54 - (5652276995886149071*CF*NC*NH*Zeta[3])/14644494484200 + 
       CF*Log[x]*((-665003662599333986987*NM*NC)/7012403798400 - 
         (254206103*lm*NM*NC)/5040 - 10395*lm^2*NM*NC - 
         (196044518653*NC*NL)/1270080 - (254206103*lm*NC*NL)/5040 - 
         10395*lm^2*NC*NL - (237437990985289474471093*NC*NH)/
          138025143963907200 - (254206103*lm*NC*NH)/5040 - 
         10395*lm^2*NC*NH - (178219361*NM*NC*Pi^2)/27 - 
         (2264657*NC*NL*Pi^2)/162 + (125111972636662*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(-136936702903013627495725817/724632005810512800 - 
           (596714109*lm)/560 - 280665*lm^2 - (33905805427*Pi^2)/2016 + 
           (4483775544890447*Im[PolyLog[2, (-1)^(1/3)]])/(5165606520*
             Sqrt[3]) - 83160*Zeta[3]) + CA*NC*(10984991143616295980997753487/
            115941120929682048000 + (3529738333*lm)/10080 + (114345*lm^2)/2 + 
           (509295361621*Pi^2)/60480 - (4483775544890447*
             Im[PolyLog[2, (-1)^(1/3)]])/(10331213040*Sqrt[3]) + 
           41580*Zeta[3])), (5412213921293020647374675743247951*CF^2*NC)/
        94006220260995501338880000 + (43130433917*CF^2*lm*NC)/94080 + 
       (2866347*CF^2*lm^2*NC)/8 + (48150751713092260747582783*CF*NM*NC)/
        280776648087936000 + (78711354677*CF*lm*NM*NC)/2540160 + 
       (106161*CF*lm^2*NM*NC)/8 - (10957303144717*CF*NC*NL)/71124480 + 
       (78711354677*CF*lm*NC*NL)/2540160 + (106161*CF*lm^2*NC*NL)/8 - 
       (62973742098750302956219758836615383*CF*NC*NH)/
        6597893716318155686827392000 + (78711354677*CF*lm*NC*NH)/2540160 + 
       (106161*CF*lm^2*NC*NH)/8 - (11562034264539919*CF^2*NC*Pi^2)/
        202176000 - (5445*CF^2*lm*NC*Pi^2)/4 - (5504381006671*CF*NM*NC*Pi^2)/
        45360 - (605*CF*lm*NM*NC*Pi^2)/12 + (10783597*CF*NC*NL*Pi^2)/504 - 
       (605*CF*lm*NC*NL*Pi^2)/12 - (605*CF*lm*NC*NH*Pi^2)/12 + 
       (1277072074503528319*CF^2*NC*Pi^3)/(6694626049920*Sqrt[3]) + 
       (58691583656372555*CF*NC*NH*Pi^3)/(41841412812*Sqrt[3]) + 
       (44466653*CF^2*NC*Pi^4)/7200 - (15235665120613376341927*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8200916911152000*Sqrt[3]) - 
       (10142535375419879221*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1464449448420*Sqrt[3]) + (7445493*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/10 + (1277072074503528319*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(180796228200*Sqrt[3]) + 
       (6707609560728292*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) + (1277072074503528319*CF^2*NC*Pi*Log[3]^2)/
        (8678218953600*Sqrt[3]) + (1676902390182073*CF*NC*NH*Pi*Log[3]^2)/
        (1549681956*Sqrt[3]) + 
       (CF*NC*(CA*(52409979931698764437 - 189962833460400000*lm) + 
          34*CF*(-3060986910949866869 + 27427788788400000*lm) + 
          8400*(17*(-1573495902307837 + 241867626000*lm)*NM + 
            26206180*(203263 + 156900*lm)*NL + (663253074881 + 
              4111749642000*lm)*NH))*Log[x]^2)/154378224000 - 
       (CF*NC*(-814204930956*CA + 1504531251749*CF + 
          1400*(2580257481*NM + 1006775*NL))*Log[x]^3)/9450 - 
       (153192097208181704051*CF^2*NC*PolyGamma[2, 1])/5578855041600 - 
       (54072870074*CF*NM*NC*PolyGamma[2, 1])/675 + 
       (3774880764616288741*CF*NC*NH*PolyGamma[2, 1])/6276211921800 + 
       CA*CF*NC*(-336192319069534327362180290771327/
          11750777532624437667360000 - (1167771*lm^2)/16 + 
         (566255314980822911*Pi^2)/19813248000 - (1277072074503528319*Pi^3)/
          (13389252099840*Sqrt[3]) - (45047453*Pi^4)/14400 + 
         lm*(-1337740271527/5080320 + (6655*Pi^2)/24) + 
         (15235665120613376341927*Im[PolyLog[2, (-1)^(1/3)]])/
          (16401833822304000*Sqrt[3]) - (7445493*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/20 - (1277072074503528319*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(361592456400*Sqrt[3]) - 
         (1277072074503528319*Pi*Log[3]^2)/(17356437907200*Sqrt[3]) + 
         (153192097208181704051*PolyGamma[2, 1])/11157710083200 - 
         (595132552942052687977*Zeta[3])/39051985291200) + 
       (584705781784049519569*CF^2*NC*Zeta[3])/19525992645600 + 
       (19810616627*CF*NM*NC*Zeta[3])/675 + (2607055*CF*NC*NL*Zeta[3])/9 - 
       (6295809637077477059*CF*NC*NH*Zeta[3])/3138105960900 + 
       CF*Log[x]*((-51510687650177755243*NM*NC)/55653998400 + 
         (30144301*lm*NM*NC)/168 + 32670*lm^2*NM*NC + (24307328153*NC*NL)/
          42336 + (30144301*lm*NC*NL)/168 + 32670*lm^2*NC*NL + 
         (1830470592625779143077893053*NC*NH)/179501699725061313600 + 
         (30144301*lm*NC*NH)/168 + 32670*lm^2*NC*NH - 
         95540920*NM*NC*Pi^2 + (1300805*NC*NL*Pi^2)/27 - 
         (6707609560728292*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CA*NC*(84487312130977131019654329887/
            347823362789046144000 - (408427151*lm)/336 - 179685*lm^2 + 
           (6438968611309*Pi^2)/302400 + (1277072074503528319*
             Im[PolyLog[2, (-1)^(1/3)]])/(1084777369200*Sqrt[3]) - 
           130680*Zeta[3]) + CF*NC*(-423628131277146198492861982333/
            869558406972615360000 + (219157389*lm)/56 + 882090*lm^2 - 
           (61436904997*Pi^2)/1440 - (1277072074503528319*
             Im[PolyLog[2, (-1)^(1/3)]])/(542388684600*Sqrt[3]) + 
           261360*Zeta[3])), (549646980029301651939402284354010691*CF^2*NC)/
        1450381684026787734942720000 - (995583268031*CF^2*lm*NC)/5080320 - 
       (3966039*CF^2*lm^2*NC)/16 + (624176272193786505129732181*CF*NM*NC)/
        5053979665582848000 - (2324840899271*CF*lm*NM*NC)/137168640 - 
       (440671*CF*lm^2*NM*NC)/48 + (12250219403946721*CF*NC*NL)/
        96018048000 - (2324840899271*CF*lm*NC*NL)/137168640 - 
       (440671*CF*lm^2*NC*NL)/48 + (1452689174051506128297684427048297817*CF*
         NC*NH)/356286260681180407088679168000 - 
       (2324840899271*CF*lm*NC*NH)/137168640 - (440671*CF*lm^2*NC*NH)/48 - 
       (15205096866713804009*CF^2*NC*Pi^2)/49037788800 + 
       (6655*CF^2*lm*NC*Pi^2)/24 - (122116282582327*CF*NM*NC*Pi^2)/816480 + 
       (6655*CF*lm*NM*NC*Pi^2)/648 - (614748013*CF*NC*NL*Pi^2)/40824 + 
       (6655*CF*lm*NC*NL*Pi^2)/648 + (6655*CF*lm*NC*NH*Pi^2)/648 - 
       (3115459182420241987*CF^2*NC*Pi^3)/(18075490334784*Sqrt[3]) - 
       (1300667453407112875*CF*NC*NH*Pi^3)/(2259436291848*Sqrt[3]) - 
       (29045753*CF^2*NC*Pi^4)/6480 + (15363704407513853433103*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22142475660110400*Sqrt[3]) + 
       (398800930618221276473*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (79080270214680*Sqrt[3]) - (1869131*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (3115459182420241987*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(488149816140*Sqrt[3]) - 
       (74323854480406450*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (3115459182420241987*CF^2*NC*Pi*Log[3]^2)/
        (23431191174720*Sqrt[3]) - (37161927240203225*CF*NC*NH*Pi*Log[3]^2)/
        (83682825624*Sqrt[3]) - 
       (CF*NC*(-51*CA*(5076334231447289849 + 2434895172309600*lm) + 
          34*CF*(15239348221785572141 + 17929682632461600*lm) + 
          420*(51*(11643372866267249 + 1054067174160*lm)*NM + 
            962676*(67176909 + 55841660*lm)*NL + 
            (9665382324617 + 53757425882160*lm)*NH))*Log[x]^2)/
        138940401600 + (CF*NC*(32093245633789*CA - 
          840*(77207042749*CF + 35180105898*NM - 8775118*NL))*Log[x]^3)/
        68040 - (4796907730099338333041039*CF^2*NC*PolyGamma[2, 1])/
        28468897277284800 - (195654175391*CF*NM*NC*PolyGamma[2, 1])/3150 - 
       (2955531508923242383387*CF*NC*NH*PolyGamma[2, 1])/7117224319321200 + 
       CA*CF*NC*(-110040727396603106045322383187402017/
          580152673610715093977088000 + (4847381*lm^2)/96 + 
         (1382384778395787253*Pi^2)/8915961600 + (3115459182420241987*Pi^3)/
          (36150980669568*Sqrt[3]) + (3239137*Pi^4)/1440 + 
         lm*(43203403737901/274337280 - (73205*Pi^2)/1296) - 
         (15363704407513853433103*Im[PolyLog[2, (-1)^(1/3)]])/
          (44284951320220800*Sqrt[3]) + (1869131*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/6 + (3115459182420241987*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(976299632280*Sqrt[3]) + 
         (3115459182420241987*Pi*Log[3]^2)/(46862382349440*Sqrt[3]) + 
         (4796907730099338333041039*PolyGamma[2, 1])/56937794554569600 - 
         (1949375938662840236730001*Zeta[3])/28468897277284800) + 
       (1955385744502763234571901*CF^2*NC*Zeta[3])/14234448638642400 + 
       (295417075843*CF*NM*NC*Zeta[3])/3150 - (11330033*CF*NC*NL*Zeta[3])/
        54 - (2580614364177034396387*CF*NC*NH*Zeta[3])/3558612159660600 + 
       CF*Log[x]*((-353788344073895113597*NM*NC)/259718659200 - 
         (15788388209*lm*NM*NC)/136080 - 23595*lm^2*NM*NC - 
         (7268789407267*NC*NL)/19051200 - (15788388209*lm*NC*NL)/136080 - 
         23595*lm^2*NC*NL - (40785543070786855004054694811*NC*NH)/
          9693091785153310934400 - (15788388209*lm*NC*NH)/136080 - 
         23595*lm^2*NC*NH - (325951751*NM*NC*Pi^2)/3 - 
         (5661689*NC*NL*Pi^2)/162 + (74323854480406450*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(-11926512809415673661023774651879/4695615397652122944000 - 
           (12399202409*lm)/5040 - 637065*lm^2 - (3213504887977*Pi^2)/13608 + 
           (3115459182420241987*Im[PolyLog[2, (-1)^(1/3)]])/
            (1464449448420*Sqrt[3]) - 188760*Zeta[3]) + 
         CA*NC*(5966157388805867150294903272709/4695615397652122944000 + 
           (218623576699*lm)/272160 + (259545*lm^2)/2 + (3214299867055*Pi^2)/
            27216 - (3115459182420241987*Im[PolyLog[2, (-1)^(1/3)]])/
            (2928898896840*Sqrt[3]) + 94380*Zeta[3])), 
      (99424903163946279602038529494548091*CF^2*NC)/
        103598691716199123924480000 + (11921053999*CF^2*lm*NC)/13230 + 
       (2815263*CF^2*lm^2*NC)/4 + (14869397729859504000807191*CF*NM*NC)/
        6381287456544000 + (86999363791*CF*lm*NM*NC)/1428840 + 
       (104269*CF*lm^2*NM*NC)/4 - (9702545926308733*CF*NC*NL)/24004512000 + 
       (86999363791*CF*lm*NC*NL)/1428840 + (104269*CF*lm^2*NC*NL)/4 - 
       (618722769269977064834814744812306454341*CF*NC*NH)/
        27770084795593368320696027424000 + (86999363791*CF*lm*NC*NH)/
        1428840 + (104269*CF*lm^2*NC*NH)/4 - 
       (131075320660378910869*CF^2*NC*Pi^2)/163459296000 - 
       2420*CF^2*lm*NC*Pi^2 - (26667347669453*CF*NM*NC*Pi^2)/17010 - 
       (2420*CF*lm*NM*NC*Pi^2)/27 + (314676527*CF*NC*NL*Pi^2)/6804 - 
       (2420*CF*lm*NC*NL*Pi^2)/27 - (2420*CF*lm*NC*NH*Pi^2)/27 + 
       (40875353310611443229*CF^2*NC*Pi^3)/(90377451673920*Sqrt[3]) + 
       (3691690035116949635*CF*NC*NH*Pi^3)/(1129718145924*Sqrt[3]) + 
       (148058647*CF^2*NC*Pi^4)/10800 - (461414878511921874768227*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(110712378300552000*Sqrt[3]) - 
       (157799626084926622444*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) + (23837407*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + (40875353310611443229*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2440749080700*Sqrt[3]) + 
       (421907432584794244*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) + (40875353310611443229*CF^2*NC*Pi*Log[3]^2)/
        (117155955873600*Sqrt[3]) + (105476858146198561*CF*NC*NH*Pi*
         Log[3]^2)/(41841412812*Sqrt[3]) + 
       CF*((-21779282624829941137*CF*NC)/2270268000 + 
         CA*(21806114675377449343/4540536000 - (26948878*lm)/9)*NC + 
         14699388*CF*lm*NC - (693289276415059*NM*NC)/36855 + 
         (4899796*lm*NM*NC)/9 + (94686086*NC*NL)/135 + 
         (4899796*lm*NC*NL)/9 + (1167003118009*NC*NH)/11904165 + 
         (4899796*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-51791581640242*CA + 102089422008353*CF + 
          138600*(1508830008*NM + 111359*NL))*Log[x]^3)/42525 - 
       (816670795625271114730373*CF^2*NC*PolyGamma[2, 1])/2033492662663200 - 
       (664952508499*CF*NM*NC*PolyGamma[2, 1])/675 + 
       (348529024444735841527*CF*NC*NH*PolyGamma[2, 1])/254186582832900 + 
       CA*CF*NC*(-608435880331161663728147269493801831/
          1269083973523439268074880000 - (1146959*lm^2)/8 + 
         (567380673574488719*Pi^2)/1415232000 - (40875353310611443229*Pi^3)/
          (180754903347840*Sqrt[3]) - (49869149*Pi^4)/7200 + 
         lm*(-1478436014561/2857680 + (13310*Pi^2)/27) + 
         (461414878511921874768227*Im[PolyLog[2, (-1)^(1/3)]])/
          (221424756601104000*Sqrt[3]) - (23837407*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/30 - (40875353310611443229*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4881498161400*Sqrt[3]) - 
         (40875353310611443229*Pi*Log[3]^2)/(234311911747200*Sqrt[3]) + 
         (816670795625271114730373*PolyGamma[2, 1])/4066985325326400 - 
         (2937232870764475258727347*Zeta[3])/14234448638642400) + 
       (2928480274965021833280991*CF^2*NC*Zeta[3])/7117224319321200 + 
       (327184948852*CF*NM*NC*Zeta[3])/675 + (2061202*CF*NC*NL*Zeta[3])/3 - 
       (607734362647206219473*CF*NC*NH*Zeta[3])/127093291416450 + 
       CF*Log[x]*((-630894869414901290777*NM*NC)/53124271200 + 
         (1113792746*lm*NM*NC)/2835 + 70785*lm^2*NM*NC + 
         (12776132112917*NC*NL)/9525600 + (1113792746*lm*NC*NL)/2835 + 
         70785*lm^2*NC*NL + (75589025879690017655929724705*NC*NH)/
          3181096485854859315744 + (1113792746*lm*NC*NH)/2835 + 
         70785*lm^2*NC*NH - 1229375301*NM*NC*Pi^2 + (3086963*NC*NL*Pi^2)/
          27 - (421907432584794244*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (10460353203*Sqrt[3]) + CA*NC*(15512276920219253938752238003459/
            4695615397652122944000 - (7530588428*lm)/2835 - (778635*lm^2)/2 + 
           (413508629970733*Pi^2)/1360800 + (40875353310611443229*
             Im[PolyLog[2, (-1)^(1/3)]])/(14644494484200*Sqrt[3]) - 
           283140*Zeta[3]) + CF*NC*(-77598075162779948282546558337203/
            11739038494130307360000 + (1803937267*lm)/210 + 1911195*lm^2 - 
           (16545385495693*Pi^2)/27216 - (40875353310611443229*
             Im[PolyLog[2, (-1)^(1/3)]])/(7322247242100*Sqrt[3]) + 
           566280*Zeta[3])), (468915814020723581068538275999079928078727*CF^2*
         NC)/83133460825608761654025139200000 - (477285036349*CF^2*lm*NC)/
        1270080 - (18942363*CF^2*lm^2*NC)/40 + 
       (16155334034232359285166747297677*CF*NM*NC)/6897278360280147840000 - 
       (1112157274657*CF*lm*NM*NC)/34292160 - (701569*CF*lm^2*NM*NC)/40 + 
       (2789982852177869*CF*NC*NL)/8890560000 - (1112157274657*CF*lm*NC*NL)/
        34292160 - (701569*CF*lm^2*NC*NL)/40 + 
       (162190776025227217784572485040032631603*CF*NC*NH)/
        17811716195424317873332728960000 - (1112157274657*CF*lm*NC*NH)/
        34292160 - (701569*CF*lm^2*NC*NH)/40 - 
       (586375371489022509643*CF^2*NC*Pi^2)/140107968000 + 
       (14641*CF^2*lm*NC*Pi^2)/30 - (79761307419067*CF*NM*NC*Pi^2)/36450 + 
       (14641*CF*lm*NM*NC*Pi^2)/810 - (4019129719*CF*NC*NL*Pi^2)/127575 + 
       (14641*CF*lm*NC*NL*Pi^2)/810 + (14641*CF*lm*NC*NH*Pi^2)/810 - 
       (7780199243967983897*CF^2*NC*Pi^3)/(20083878149760*Sqrt[3]) - 
       (1465333381961357461*CF*NC*NH*Pi^3)/(1129718145924*Sqrt[3]) - 
       (126309733*CF^2*NC*Pi^4)/12960 + (114409656075227154681229*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(73808252200368000*Sqrt[3]) + 
       (107650686674569702928*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) - (38514619*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - (7780199243967983897*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(542388684600*Sqrt[3]) - 
       (837333361120775692*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (17433922005*Sqrt[3]) - (7780199243967983897*CF^2*NC*Pi*Log[3]^2)/
        (26034656860800*Sqrt[3]) - (209333340280193923*CF*NC*NH*Pi*Log[3]^2)/
        (209207064060*Sqrt[3]) - 
       (CF*NC*(-19*CA*(34898811042616966758617 + 2918553896837779200*lm) + 
          2*(19*CF*(34902974341202340031963 + 7163723201329094400*lm) + 
            840*(19*(21717273417829774699 + 315860811346080*lm)*NM + 
              9*(2032316*(391681191 + 328107080*lm)*NL + 7*(19012311436407 + 
                  95259609771040*lm)*NH))))*Log[x]^2)/26398676304000 + 
       (CF*NC*(547778920415153*CA - 1097711344677935*CF - 
          555775903990440*NM + 21655067280*NL)*Log[x]^3)/85050 - 
       (193910556497265856296341779*CF^2*NC*PolyGamma[2, 1])/
        85406691831854400 - (32386689440941*CF*NM*NC*PolyGamma[2, 1])/
        32400 - (19247678348212317293219*CF*NC*NH*PolyGamma[2, 1])/
        21351672957963600 + CA*CF*NC*
        (-5862332900618699026648200126578495278871/
          2078336520640219041350628480000 + (7717259*lm^2)/80 + 
         (74630466445599306679*Pi^2)/35663846400 + (7780199243967983897*Pi^3)/
          (40167756299520*Sqrt[3]) + (633422713*Pi^4)/129600 - 
         (11*lm*(-1877649160081 + 619841376*Pi^2))/68584320 - 
         (114409656075227154681229*Im[PolyLog[2, (-1)^(1/3)]])/
          (147616504400736000*Sqrt[3]) + (38514619*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/60 + (7780199243967983897*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1084777369200*Sqrt[3]) + 
         (7780199243967983897*Pi*Log[3]^2)/(52069313721600*Sqrt[3]) + 
         (193910556497265856296341779*PolyGamma[2, 1])/170813383663708800 - 
         (81352459526566159605957539*Zeta[3])/85406691831854400) + 
       (81392538195458863822007591*CF^2*NC*Zeta[3])/42703345915927200 + 
       (20576599488179*CF*NM*NC*Zeta[3])/16200 - 
       (21655777*CF*NC*NL*Zeta[3])/45 - (13512886704778061096579*CF*NC*NH*
         Zeta[3])/10675836478981800 + CF*Log[x]*
        ((-13565692380736306936609177*NM*NC)/723780249192000 - 
         (20953131067*lm*NM*NC)/85050 - (99099*lm^2*NM*NC)/2 - 
         (3058797080809*NC*NL)/3528000 - (20953131067*lm*NC*NL)/85050 - 
         (99099*lm^2*NC*NL)/2 - (11852213572367366641508332503653*NC*NH)/
          1249716476585837588328000 - (20953131067*lm*NC*NH)/85050 - 
         (99099*lm^2*NC*NH)/2 - (220567137869*NM*NC*Pi^2)/135 - 
         (64938049*NC*NL*Pi^2)/810 + (837333361120775692*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(52301766015*Sqrt[3]) + 
         CF*NC*(-25035138935705243516573686478415289/
            753907138845257517120000 - (33009649409*lm)/6300 - 
           (2675673*lm^2)/2 - (4383237567344519*Pi^2)/1360800 + 
           (7780199243967983897*Im[PolyLog[2, (-1)^(1/3)]])/
            (1627166053800*Sqrt[3]) - 396396*Zeta[3]) + 
         CA*NC*(5007437165108700779186042462215337/301562855538103006848000 + 
           (289483031387*lm)/170100 + (1090089*lm^2)/4 + 
           (4383419576286791*Pi^2)/2721600 - (7780199243967983897*
             Im[PolyLog[2, (-1)^(1/3)]])/(3254332107600*Sqrt[3]) + 
           198198*Zeta[3])), (98197260119783885141465305696798690133294599*
         CF^2*NC)/6733810326874309693976036275200000 + 
       (1764826305569*CF^2*lm*NC)/1058400 + (26039871*CF^2*lm^2*NC)/20 + 
       (35770767628780747456076473551067*CF*NM*NC)/1149546393380024640000 + 
       (3219413499629*CF*lm*NM*NC)/28576800 + (2893319*CF*lm^2*NM*NC)/60 - 
       (19210582438050821*CF*NC*NL)/20003760000 + 
       (3219413499629*CF*lm*NC*NL)/28576800 + (2893319*CF*lm^2*NC*NL)/60 - 
       (3990433296376215739360150700588604308359361*CF*NC*NH)/
        82477151842912303912467201449280000 + (3219413499629*CF*lm*NC*NH)/
        28576800 + (2893319*CF*lm^2*NC*NH)/60 - 
       (8232045397207063533749*CF^2*NC*Pi^2)/757856736000 - 
       (20449*CF^2*lm*NC*Pi^2)/5 - (1698480247339243*CF*NM*NC*Pi^2)/85050 - 
       (20449*CF*lm*NM*NC*Pi^2)/135 + (15880713563*CF*NC*NL*Pi^2)/170100 - 
       (20449*CF*lm*NC*NL*Pi^2)/135 - (20449*CF*lm*NC*NH*Pi^2)/135 + 
       (483394281479733144215*CF^2*NC*Pi^3)/(488038239039168*Sqrt[3]) + 
       (216041497787140438693*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) + 
       (916220591*CF^2*NC*Pi^4)/32400 - (26172017772697498280460127*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2989234214114904000*Sqrt[3]) - 
       (9175029884408976943268*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (266895911974545*Sqrt[3]) + (9521369*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + (96678856295946628843*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2636009007156*Sqrt[3]) + 
       (123452284449794536396*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) + 
       (96678856295946628843*CF^2*NC*Pi*Log[3]^2)/(126528432343488*Sqrt[3]) + 
       (30863071112448634099*CF*NC*NH*Pi*Log[3]^2)/(5648590729620*Sqrt[3]) + 
       (CF*NC*(-95*CA*(-9052541021281707162727 + 933887758063740480*lm) + 
          2*(19*CF*(-45253453629029221516937 + 11461349758054996800*lm) + 
            2520*(19*(-33031537066873899479 + 168450172810920*lm)*NM + 
              1109644536*(3699811 + 2884305*lm)*NL + (631317701539519 + 
                3200553283407480*lm)*NH)))*Log[x]^2)/13199338152000 - 
       (CF*NC*(-1420188033388747*CA + 2833052246441420*CF + 
          5346461718995040*NM + 69292543320*NL)*Log[x]^3)/85050 - 
       (307095243966860075135413889*CF^2*NC*PolyGamma[2, 1])/
        54904301891906400 - (13108189182367*CF*NM*NC*PolyGamma[2, 1])/1080 + 
       (40020171952592706231833*CF*NC*NH*PolyGamma[2, 1])/
        13726075472976600 + CA*CF*NC*
        (-19636873052951968019085553777496292854151809/
          2693524130749723877590414510080000 - (31826509*lm^2)/120 + 
         (5321232360067129147*Pi^2)/979776000 - (483394281479733144215*Pi^3)/
          (976076478078336*Sqrt[3]) - (924073007*Pi^4)/64800 + 
         lm*(-54705968122399/57153600 + (224939*Pi^2)/270) + 
         (26172017772697498280460127*Im[PolyLog[2, (-1)^(1/3)]])/
          (5978468428229808000*Sqrt[3]) - (9521369*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/6 - (96678856295946628843*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(5272018014312*Sqrt[3]) - 
         (96678856295946628843*Pi*Log[3]^2)/(253056864686976*Sqrt[3]) + 
         (307095243966860075135413889*PolyGamma[2, 1])/109808603783812800 - 
         (1058251250013911403068338579*Zeta[3])/384330113243344800) + 
       (151106230427216389281159241*CF^2*NC*Zeta[3])/27452150945953200 + 
       (3859922187737*CF*NM*NC*Zeta[3])/540 + (7550972*CF*NC*NL*Zeta[3])/
        5 - (72159884467241397085927*CF*NC*NH*Zeta[3])/6863037736488300 + 
       CF*Log[x]*((-62855475395758143979579807*NM*NC)/422205145362000 + 
         (22723907921*lm*NM*NC)/28350 + 143143*lm^2*NM*NC + 
         (69294221732833*NC*NL)/23814000 + (22723907921*lm*NC*NL)/28350 + 
         143143*lm^2*NC*NL + (380202922423701266318245499807209*NC*NH)/
          7381137939835103256062250 + (22723907921*lm*NC*NH)/28350 + 
         143143*lm^2*NC*NH - (707201224523*NM*NC*Pi^2)/45 + 
         (33938476*NC*NL*Pi^2)/135 - (123452284449794536396*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CA*NC*(197874509520233537638160646795342817/
            4579985868484939416504000 - (306776443831*lm)/56700 - 
           (1574573*lm^2)/2 + (5678891373437761*Pi^2)/1360800 + 
           (96678856295946628843*Im[PolyLog[2, (-1)^(1/3)]])/
            (15816054042936*Sqrt[3]) - 572572*Zeta[3]) + 
         CF*NC*(-1978897015406113365303922016257170403/
            22899929342424697082520000 + (9220176823*lm)/525 + 3864861*lm^2 - 
           (5679166453398433*Pi^2)/680400 - (96678856295946628843*
             Im[PolyLog[2, (-1)^(1/3)]])/(7908027021468*Sqrt[3]) + 
           1145144*Zeta[3])), 
      (36318861828721106798575464692570391534297622591*CF^2*NC)/
        452815735608145982264525811878400000 - (104655175155277*CF^2*lm*NC)/
        153679680 - (6846255*CF^2*lm^2*NC)/8 + 
       (361746652433564825974811232893544463*CF*NM*NC)/
        9461686454632306806912000 - (243477920116177*CF*lm*NM*NC)/
        4149351360 - (253565*CF*lm^2*NM*NC)/8 + 
       (1373868203837882971*CF*NC*NL)/1936363968000 - 
       (243477920116177*CF*lm*NC*NL)/4149351360 - (253565*CF*lm^2*NC*NL)/
        8 + (57116064034271901449646431064015573513413*CF*NC*NH)/
        2999169157924083778635170961792000 - (243477920116177*CF*lm*NC*NH)/
        4149351360 - (253565*CF*lm^2*NC*NH)/8 - 
       (10080136869083119504569331*CF^2*NC*Pi^2)/183401330112000 + 
       (4901*CF^2*lm*NC*Pi^2)/6 - (8547100926467987*CF*NM*NC*Pi^2)/280665 + 
       (4901*CF*lm*NM*NC*Pi^2)/162 - (69466456111*CF*NC*NL*Pi^2)/1122660 + 
       (4901*CF*lm*NC*NL*Pi^2)/162 + (4901*CF*lm*NC*NH*Pi^2)/162 - 
       (2902301236410501452107*CF^2*NC*Pi^3)/(3578947086287232*Sqrt[3]) - 
       (41658883844654155555*CF*NC*NH*Pi^3)/(15251194969974*Sqrt[3]) - 
       (255892429*CF^2*NC*Pi^4)/12960 + (22365915966890753268831461*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(6889473141102921600*Sqrt[3]) + 
       (1183759363122858695000*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (53379182394909*Sqrt[3]) - (14934647*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - (414614462344357350301*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13807666227960*Sqrt[3]) - 
       (9522030593063806984*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) - (414614462344357350301*CF^2*NC*Pi*Log[3]^2)/
        (662767978942080*Sqrt[3]) - (1190253824132975873*CF*NC*NH*Pi*
         Log[3]^2)/(564859072962*Sqrt[3]) - 
       (CF*NC*(-85*CA*(1126653993403874120515201 + 15643642743455126400*lm) + 
          2*(17*CF*(5633382222339322482558103 + 191990160942403824000*lm) + 
            46200*((1148461086176464004621 + 2616508526551920*lm)*NM + 
              9*(26420108*(13055757 + 11003860*lm)*NL + (63289330134189 + 
                  290723169616880*lm)*NH))))*Log[x]^2)/290385439344000 + 
       (CF*NC*(79960327047180940*CA - 159976916579075563*CF - 
          86706134629468200*NM + 519272153400*NL)*Log[x]^3)/935550 - 
       (511548341592390978513732131*CF^2*NC*PolyGamma[2, 1])/
        17081338366370880 - (3350365279472341*CF*NM*NC*PolyGamma[2, 1])/
        226800 - (50519865579055985661251*CF*NC*NH*PolyGamma[2, 1])/
        27452150945953200 + CA*CF*NC*
        (-159806538045793839356852254050916762558987027637/
          3984778473351684643927827144529920000 + (2789215*lm^2)/16 + 
         (9122311918888810936351*Pi^2)/331948108800 + 
         (2902301236410501452107*Pi^3)/(7157894172574464*Sqrt[3]) + 
         (256519757*Pi^4)/25920 + lm*(410862282461377/754427520 - 
           (53911*Pi^2)/324) - (22365915966890753268831461*
           Im[PolyLog[2, (-1)^(1/3)]])/(13778946282205843200*Sqrt[3]) + 
         (14934647*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (414614462344357350301*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27615332455920*Sqrt[3]) + (414614462344357350301*Pi*Log[3]^2)/
          (1325535957884160*Sqrt[3]) + (511548341592390978513732131*
           PolyGamma[2, 1])/34162676732741760 - (2403606927717030456385434401*
           Zeta[3])/187894722030079680) + (2403790720317375871596551357*CF^2*
         NC*Zeta[3])/93947361015039840 + (1905043087096859*CF*NM*NC*Zeta[3])/
        113400 - (9253127*CF*NC*NL*Zeta[3])/9 - 
       (28365084351069293898851*CF*NC*NH*Zeta[3])/13726075472976600 + 
       CF*Log[x]*((-90940987208230307251662468809*NM*NC)/
          365798537941636800 - (45824988521*lm*NM*NC)/93555 - 
         (195195*lm^2*NM*NC)/2 - (6113210147081*NC*NL)/3326400 - 
         (45824988521*lm*NC*NL)/93555 - (195195*lm^2*NC*NL)/2 - 
         (943647771605514804167518010201267*NC*NH)/
          47239282814944660838798400 - (45824988521*lm*NC*NH)/93555 - 
         (195195*lm^2*NC*NH)/2 - (625594195594*NM*NC*Pi^2)/27 - 
         (27749579*NC*NL*Pi^2)/162 + (9522030593063806984*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(-1207367315326908988089409839605060864989/
            2852882177843716772225472000 - (144747965609*lm)/13860 - 
           (5270265*lm^2)/2 - (127941438504360149*Pi^2)/2993760 + 
           (414614462344357350301*Im[PolyLog[2, (-1)^(1/3)]])/
            (41422998683880*Sqrt[3]) - 780780*Zeta[3]) + 
         CA*NC*(1207383234746409005396637632362180308361/
            5705764355687433544450944000 + (28722961423*lm)/8505 + 
           (2147145*lm^2)/4 + (127942292652576389*Pi^2)/5987520 - 
           (414614462344357350301*Im[PolyLog[2, (-1)^(1/3)]])/
            (82845997367760*Sqrt[3]) + 390390*Zeta[3])), 
      (249837279899409196735492742287025650468009263929*CF^2*NC)/
        1196371872886200452356667097945600000 + (239661244261*CF^2*lm*NC)/
        81675 + (45815679*CF^2*lm^2*NC)/20 + 
       (689302843682844335806372572586384711*CF*NM*NC)/
        1689586866898626215520000 + (3497243644403*CF*lm*NM*NC)/17641800 + 
       (1696877*CF*lm^2*NM*NC)/20 - (4372085024861892893*CF*NC*NL)/
        2074675680000 + (3497243644403*CF*lm*NC*NL)/17641800 + 
       (1696877*CF*lm^2*NC*NL)/20 - 
       (148805627280388198794965385704462516190265006843*CF*NC*NH)/
        1505249259709071002554482660050084640000 + 
       (3497243644403*CF*lm*NC*NH)/17641800 + (1696877*CF*lm^2*NC*NH)/20 - 
       (5327443976579907049921*CF^2*NC*Pi^2)/37322208000 - 
       (33124*CF^2*lm*NC*Pi^2)/5 - (33464889839111909*CF*NM*NC*Pi^2)/
        133650 - (33124*CF*lm*NM*NC*Pi^2)/135 + (47578344229*CF*NC*NL*Pi^2)/
        267300 - (33124*CF*lm*NC*NL*Pi^2)/135 - (33124*CF*lm*NC*NH*Pi^2)/
        135 + (14868764026648253110361*CF^2*NC*Pi^3)/(7320573585587520*
         Sqrt[3]) + (1322075191876031322359*CF*NC*NH*Pi^3)/
        (91507169819844*Sqrt[3]) + (118556711*CF^2*NC*Pi^4)/2160 - 
       (49035529756452347831719583*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2818420830451195200*Sqrt[3]) - (55954089720114846699892*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(800687735923635*Sqrt[3]) + 
       (89932843*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (2124109146664036158623*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (28242953648100*Sqrt[3]) + (755471538214875041348*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1412147682405*Sqrt[3]) + 
       (2124109146664036158623*CF^2*NC*Pi*Log[3]^2)/(1355661775108800*
         Sqrt[3]) + (188867884553718760337*CF*NC*NH*Pi*Log[3]^2)/
        (16945772188860*Sqrt[3]) + 
       (CF*NC*(-108537*CA*(-1254751650384064378121 + 20669707272614400*lm) + 
          10*(299*CF*(-91091986526760549744553 + 3683341835979886080*lm) + 
            2112*(644*(-35129680229263547959 + 29989530641070*lm)*NM + 
              44663192574*(552779 + 432420*lm)*NL + (4114102720425109 + 
                19313257732849080*lm)*NH)))*Log[x]^2)/159020597736000 - 
       (CF*NC*(-14830900942695107*CA + 29648703264121273*CF + 
          27720*(1911135066603*NM + 4122404*NL))*Log[x]^3)/66825 - 
       (12375333126326309945711244113*CF^2*NC*PolyGamma[2, 1])/
        164712905675719200 - (402389886560131*CF*NM*NC*PolyGamma[2, 1])/
        2700 + (1203726090284301372394*CF*NC*NH*PolyGamma[2, 1])/
        205891132094649 + CA*CF*NC*
        (-27325425633046865702318459772274110560411203667/
          261706347193856348953020927675600000 - (18665647*lm^2)/40 + 
         (5327434559425465287821*Pi^2)/74644416000 - 
         (14868764026648253110361*Pi^3)/(14641147171175040*Sqrt[3]) - 
         (199007809*Pi^4)/7200 + lm*(-5402259577223/3207600 + 
           (182182*Pi^2)/135) + (49035529756452347831719583*
           Im[PolyLog[2, (-1)^(1/3)]])/(5636841660902390400*Sqrt[3]) - 
         (89932843*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
         (2124109146664036158623*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (56485907296200*Sqrt[3]) - (2124109146664036158623*Pi*Log[3]^2)/
          (2711323550217600*Sqrt[3]) + (12375333126326309945711244113*
           PolyGamma[2, 1])/329425811351438400 - 
         (64918878740507398098344738459*Zeta[3])/1811841962432911200) + 
       (64914032418404079169435790759*CF^2*NC*Zeta[3])/905920981216455600 + 
       (132702533626529*CF*NM*NC*Zeta[3])/1350 + 
       (46718126*CF*NC*NL*Zeta[3])/15 - (22275750610511742607664*CF*NC*NH*
         Zeta[3])/1029455660473245 + CF*Log[x]*
        ((-79728707571364618417852911137*NM*NC)/43547444993052000 + 
         (34345090559*lm*NM*NC)/22275 + 273273*lm^2*NM*NC + 
         (444088398188423*NC*NL)/74844000 + (34345090559*lm*NC*NL)/22275 + 
         273273*lm^2*NC*NL + (19694390106198665993640858679797759983*NC*NH)/
          187421854568292941877932652000 + (34345090559*lm*NC*NH)/22275 + 
         273273*lm^2*NC*NH - (8918627426933*NM*NC*Pi^2)/45 + 
         (70010941*NC*NL*Pi^2)/135 - (755471538214875041348*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) + 
         CA*NC*(13178802251879354748836809202830432291783/
            23983020506048827810466880000 - (42092380109*lm)/4050 - 
           (3006003*lm^2)/2 + (118641041649975197*Pi^2)/2138400 + 
           (2124109146664036158623*Im[PolyLog[2, (-1)^(1/3)]])/
            (169457721888600*Sqrt[3]) - 1093092*Zeta[3]) + 
         CF*NC*(-13178961259656003747393690266134541268571/
            11991510253024413905233440000 + (55839518293*lm)/1650 + 
           7378371*lm^2 - (118641928178838989*Pi^2)/1069200 - 
           (2124109146664036158623*Im[PolyLog[2, (-1)^(1/3)]])/
            (84728860944300*Sqrt[3]) + 2186184*Zeta[3])), 
      (171981851465953284916977067044234624136133211547093*CF^2*NC)/
        156772570223007707276817656514791424000 - (73828593091343*CF^2*lm*NC)/
        62726400 - (118076049*CF^2*lm^2*NC)/80 + 
       (486568575460389316733177619853511284579*CF*NM*NC)/
        851551780916907612622080000 - (171553054285703*CF*lm*NM*NC)/
        1693612800 - (4373187*CF*lm^2*NM*NC)/80 + 
       (195600286929577304081*CF*NC*NL)/130704567840000 - 
       (171553054285703*CF*lm*NC*NL)/1693612800 - (4373187*CF*lm^2*NC*NL)/
        80 + (53024148400345190516928788504718570400112934757*CF*NC*NH)/
        1407505801286404054336659110696183040000 - 
       (171553054285703*CF*lm*NC*NH)/1693612800 - (4373187*CF*lm^2*NC*NH)/
        80 - (2050176097930237898618147*CF^2*NC*Pi^2)/2911132224000 + 
       (157339*CF^2*lm*NC*Pi^2)/120 - (2033985937777823321*CF*NM*NC*Pi^2)/
        4989600 + (157339*CF*lm*NM*NC*Pi^2)/3240 - 
       (369668184587*CF*NC*NL*Pi^2)/3207600 + (157339*CF*lm*NC*NL*Pi^2)/
        3240 + (157339*CF*lm*NC*NH*Pi^2)/3240 - 
       (463727213838800357589703*CF^2*NC*Pi^3)/(289894713989265792*Sqrt[3]) - 
       (17899271409286457050511*CF*NC*NH*Pi^3)/(3294258113514384*Sqrt[3]) - 
       (271617437*CF^2*NC*Pi^4)/7200 + (3591877124637436092972718943*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(558047324429336649600*Sqrt[3]) + 
       (353643198601790169100871*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (8235645283785960*Sqrt[3]) - (27507571*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - (66246744834114336798529*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1118420964464760*Sqrt[3]) - 
       (2557038772755208150073*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(12709329141645*Sqrt[3]) - 
       (66246744834114336798529*CF^2*NC*Pi*Log[3]^2)/(53684206294308480*
         Sqrt[3]) - (2557038772755208150073*CF*NC*NH*Pi*Log[3]^2)/
        (610047798798960*Sqrt[3]) - 
       (CF*NC*(-23*CA*(35058260730420923948739769 + 77769692945468203680*
             lm) + 6*(23*CF*(11686124307426658433815283 + 
              63629748773564893920*lm) + 44*(23*(153732812038330860876427 + 
                53560394590542840*lm)*NM + 7*(2734481178*(75979169 + 
                  64357420*lm)*NL + (41235862289240393 + 175984153654640760*
                   lm)*NH))))*Log[x]^2)/190824717283200 + 
       (CF*NC*(591028258566255829*CA - 1182127738131285916*CF - 
          14520*(46348771431394*NM - 41832323*NL))*Log[x]^3)/534600 - 
       (8021860498976617928158434651523*CF^2*NC*PolyGamma[2, 1])/
        20753826115140619200 - (46748170765965443*CF*NM*NC*PolyGamma[2, 1])/
        226800 - (9248335189733686591951549*CF*NC*NH*PolyGamma[2, 1])/
        2594228264392577400 + CA*CF*NC*
        (-4299560116402215057884696193934955322099127720393411/
          7838628511150385363840882825739571200000 + (48105057*lm^2)/160 + 
         (157705894442844262660451*Pi^2)/447866496000 + 
         (463727213838800357589703*Pi^3)/(579789427978531584*Sqrt[3]) + 
         (2449591781*Pi^4)/129600 + lm*(289383505103783/307929600 - 
           (1730729*Pi^2)/6480) - (3591877124637436092972718943*
           Im[PolyLog[2, (-1)^(1/3)]])/(1116094648858673299200*Sqrt[3]) + 
         (27507571*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (66246744834114336798529*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2236841928929520*Sqrt[3]) + (66246744834114336798529*Pi*Log[3]^2)/
          (107368412588616960*Sqrt[3]) + (8021860498976617928158434651523*
           PolyGamma[2, 1])/41507652230281238400 - 
         (3450600432441041241228747446147*Zeta[3])/20753826115140619200) + 
       (3450640493336080107815349826271*CF^2*NC*Zeta[3])/
        10376913057570309600 + (24629939164550197*CF*NM*NC*Zeta[3])/113400 - 
       (279345586*CF*NC*NL*Zeta[3])/135 - (4107393460106576327160889*CF*NC*
         NH*Zeta[3])/1297114132196288700 + CF*Log[x]*
        ((-487422850602289913287237892087*NM*NC)/152416057475682000 - 
         (985451344423*lm*NM*NC)/1069200 - 182182*lm^2*NM*NC - 
         (69295269464391259*NC*NL)/18860688000 - (985451344423*lm*NC*NL)/
          1069200 - 182182*lm^2*NC*NL - 
         (19151830112198842655894853120935155813*NC*NH)/
          481941911747038993400398248000 - (985451344423*lm*NC*NH)/1069200 - 
         182182*lm^2*NC*NH - (509837522979103*NM*NC*Pi^2)/1620 - 
         (558533833*NC*NL*Pi^2)/1620 + (2557038772755208150073*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(38127987424935*Sqrt[3]) + 
         CF*NC*(-14796669314454720700538117063546960495610703/
            2806013399207712853824624960000 - (779840739223*lm)/39600 - 
           4918914*lm^2 - (107460346297230091*Pi^2)/194400 + 
           (66246744834114336798529*Im[PolyLog[2, (-1)^(1/3)]])/
            (3355262893394280*Sqrt[3]) - 1457456*Zeta[3]) + 
         CA*NC*(3699174935490872507844362720936737609637737/
            1403006699603856426912312480000 + (1233364610023*lm)/194400 + 
           1002001*lm^2 + (21492091556105183*Pi^2)/77760 - 
           (66246744834114336798529*Im[PolyLog[2, (-1)^(1/3)]])/
            (6710525786788560*Sqrt[3]) + 728728*Zeta[3])), 
      (467128076510590901749697282212844514227542585584269*CF^2*NC)/
        163304760648966361746685058869574400000 + (2069248062533*CF^2*lm*NC)/
        418176 + (30901689*CF^2*lm^2*NC)/8 + 
       (16537292522501430737801213641613917103*CF*NM*NC)/
        3153895484877435602304000 + (3774279654797*CF*lm*NM*NC)/11290752 + 
       (1144507*CF*lm^2*NM*NC)/8 - (415156065215789045471*CF*NC*NL)/
        95850016416000 + (3774279654797*CF*lm*NC*NL)/11290752 + 
       (1144507*CF*lm^2*NC*NL)/8 - 
       (418326349391565239300197289169500497932686366537*CF*NC*NH)/
        2181520666245030438484757478333456000000 + 
       (3774279654797*CF*lm*NC*NH)/11290752 + (1144507*CF*lm^2*NC*NH)/8 - 
       (60637703141395586151599779*CF^2*NC*Pi^2)/33186907353600 - 
       (41405*CF^2*lm*NC*Pi^2)/4 - (4623848259710414039*CF*NM*NC*Pi^2)/
        1496880 - (41405*CF*lm*NM*NC*Pi^2)/108 + (3456637639*CF*NC*NL*Pi^2)/
        10692 - (41405*CF*lm*NC*NL*Pi^2)/108 - (41405*CF*lm*NC*NH*Pi^2)/
        108 + (1903812541951485558316651*CF^2*NC*Pi^3)/(483157856648776320*
         Sqrt[3]) + (5121591396584796022855*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) + (2186033941*CF^2*NC*Pi^4)/21600 - 
       (6130981969556560182110538139*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (186015774809778883200*Sqrt[3]) - (317527448742843173064283*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2348684025375996*Sqrt[3]) + 
       (324090221*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
       (271973220278783651188093*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1864034940774600*Sqrt[3]) + 
       (292662365519131201306*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) + 
       (271973220278783651188093*CF^2*NC*Pi*Log[3]^2)/(89473677157180800*
         Sqrt[3]) + (146331182759565600653*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((-4331210827362198917071073*CF*NC)/
          197541115200 + CA*(16843683369014300843619467/1536430896000 - 
           (55951181*lm)/2)*NC + 137334717*CF*lm*NC - 
         (38831062503987455577143*NM*NC)/1047566520 + 5086471*lm*NM*NC + 
         (1167148151*NC*NL)/180 + 5086471*lm*NC*NL + 
         (6061606223344799*NC*NH)/5237832600 + 5086471*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-383516586383614828*CA + 25*(30679086797196479*CF + 
            1188*(44288689608370*NM + 15259413*NL)))*Log[x]^3)/133650 - 
       (968124682598193564760639235947*CF^2*NC*PolyGamma[2, 1])/
        988277434054315200 - (3269861609673379*CF*NM*NC*PolyGamma[2, 1])/
        1800 + (229561184758659329615917*CF*NC*NH*PolyGamma[2, 1])/
        20589113209464900 + CA*CF*NC*
        (-467126768640309867425618798006823684163220748241787/
          326609521297932723493370117739148800000 - (12589577*lm^2)/16 + 
         (49099342321611816869057*Pi^2)/53743979520 - 
         (1903812541951485558316651*Pi^3)/(966315713297552640*Sqrt[3]) - 
         (2199283541*Pi^4)/43200 + lm*(-5830107220589/2052864 + 
           (455455*Pi^2)/216) + (6130981969556560182110538139*
           Im[PolyLog[2, (-1)^(1/3)]])/(372031549619557766400*Sqrt[3]) - 
         (324090221*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 - 
         (271973220278783651188093*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3728069881549200*Sqrt[3]) - (271973220278783651188093*Pi*Log[3]^2)/
          (178947354314361600*Sqrt[3]) + (968124682598193564760639235947*
           PolyGamma[2, 1])/1976554868108630400 - 
         (989615563406922209899483128881*Zeta[3])/2174210354919493440) + 
       (197920873464568986517904492725*CF^2*NC*Zeta[3])/217421035491949344 + 
       (1158973454459221*CF*NM*NC*Zeta[3])/900 + 
       (54763124*CF*NC*NL*Zeta[3])/9 - (433694773347615124441583*CF*NC*NH*
         Zeta[3])/10294556604732450 + CF*Log[x]*
        ((-337386544216835025464338147117*NM*NC)/15241605747568200 + 
         (100569427049*lm*NM*NC)/35640 + 496860*lm^2*NM*NC + 
         (79378945110243743*NC*NL)/6915585600 + (100569427049*lm*NC*NL)/
          35640 + 496860*lm^2*NC*NL + (8293046615129836114752528659229967781*
           NC*NH)/40743881427889769973463620000 + (100569427049*lm*NC*NH)/
          35640 + 496860*lm^2*NC*NH - (44288689292821*NM*NC*Pi^2)/18 + 
         (6080191*NC*NL*Pi^2)/6 - (292662365519131201306*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CA*NC*(12774946910066904812346795748673581139186773/
            1870675599471808569216416640000 - (123106996649*lm)/6480 - 
           2732730*lm^2 + (3068108147087497519*Pi^2)/4276800 + 
           (271973220278783651188093*Im[PolyLog[2, (-1)^(1/3)]])/
            (11184209644647600*Sqrt[3]) - 1987440*Zeta[3]) + 
         CF*NC*(-2554994093533578290806678339728197631353411/
            187067559947180856921641664000 + (81877553849*lm)/1320 + 
           13415220*lm^2 - (3068111595164565823*Pi^2)/2138400 - 
           (271973220278783651188093*Im[PolyLog[2, (-1)^(1/3)]])/
            (5592104822323800*Sqrt[3]) + 3974880*Zeta[3])), 
      (771317350257644565249343844227667596662809514853143206329*CF^2*NC)/
        53136159010164325859317554747002302126080000 - 
       (828541192380179*CF^2*lm*NC)/424030464 - (39139821*CF^2*lm^2*NC)/16 + 
       (2380912826104671811625324444203352729111147*CF*NM*NC)/
        296023729097600426364938496000 - (1923447625472651*CF*lm*NM*NC)/
        11448822528 - (1449623*CF*lm^2*NM*NC)/16 + 
       (72350698468597002228503*CF*NC*NL)/24297979161456000 - 
       (1923447625472651*CF*lm*NC*NL)/11448822528 - (1449623*CF*lm^2*NC*NL)/
        16 + (577476235928629534785466104240378452862300802985543*CF*NC*NH)/
        8128346002428983413794206364270457056000000 - 
       (1923447625472651*CF*lm*NC*NH)/11448822528 - (1449623*CF*lm^2*NC*NH)/
        16 - (204020800186215027344114147*CF^2*NC*Pi^2)/23112310478400 + 
       (48755*CF^2*lm*NC*Pi^2)/24 - (17638292190266213515*CF*NM*NC*Pi^2)/
        3335904 + (48755*CF*lm*NM*NC*Pi^2)/648 - 
       (342182598377*CF*NC*NL*Pi^2)/1667952 + (48755*CF*lm*NC*NL*Pi^2)/
        648 + (48755*CF*lm*NC*NH*Pi^2)/648 - 
       (4239929715266363633782463*CF^2*NC*Pi^3)/(1413236730697670736*
         Sqrt[3]) - (101729603445433916108345*CF*NC*NH*Pi^3)/
        (9882774340543152*Sqrt[3]) - (27783637*CF^2*NC*Pi^4)/405 + 
       (861051546841973123114538690569*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (70732498371418420336800*Sqrt[3]) + (13765197772236711121942571*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(172948550959505160*Sqrt[3]) - 
       (24245984*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (605704245038051947683209*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5452302201765705*Sqrt[3]) - 
       (2906560098440969031667*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (605704245038051947683209*CF^2*NC*Pi*Log[3]^2)/(261710505684753840*
         Sqrt[3]) - (2906560098440969031667*CF*NC*NH*Pi*Log[3]^2)/
        (366028679279376*Sqrt[3]) - 
       (CF*NC*(200*CF*(164237005938253747728786314 + 138448481137997521491*
             lm) - 3*CA*(5474564140019250436658590661 + 
            1880164558664163872100*lm) + 
          429*(105*(436782945740582786304337 + 22767106332021480*lm)*NM + 
            8700621930*(323039471 + 274755780*lm)*NL + 
            (596700654264118123 + 2390546164862255400*lm)*NH))*Log[x]^2)/
        310090165585200 + (CF*NC*(19426526481356898099*CA - 
          104*(373590765416662862*CF + 220853975978079510*NM - 
            29467557405*NL))*Log[x]^3)/1389960 - 
       (8450634184524758265347322650857*CF^2*NC*PolyGamma[2, 1])/
        1729485509595051600 - (208405094924622719*CF*NM*NC*PolyGamma[2, 1])/
        75600 - (1902540266303382286792951*CF*NC*NH*PolyGamma[2, 1])/
        288247584932508600 + CA*CF*NC*
        (-5399223937501206018822632276623485525553222120279557265453/
          743906226142300562030445766458032229765120000 + 
         (15945853*lm^2)/32 + (150331121473797353859524239*Pi^2)/
          34060247020800 + (4239929715266363633782463*Pi^3)/
          (2826473461395341472*Sqrt[3]) + (1546244*Pi^4)/45 + 
         lm*(3243621889297067/2081604096 - (536305*Pi^2)/1296) - 
         (861051546841973123114538690569*Im[PolyLog[2, (-1)^(1/3)]])/
          (141464996742836840673600*Sqrt[3]) + 
         (12122992*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (605704245038051947683209*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (10904604403531410*Sqrt[3]) + (605704245038051947683209*Pi*
           Log[3]^2)/(523421011369507680*Sqrt[3]) + 
         (8450634184524758265347322650857*PolyGamma[2, 1])/
          3458971019190103200 - (259925843744854079830749762541877*Zeta[3])/
          123658213936046189400) + (519852586136297879609519739101509*CF^2*NC*
         Zeta[3])/123658213936046189400 + (103914304376174281*CF*NM*NC*
         Zeta[3])/37800 - (106862986*CF*NC*NL*Zeta[3])/27 - 
       (656095897741307875601251*CF*NC*NH*Zeta[3])/144123792466254300 + 
       CF*Log[x]*((-494694811555590027285752078639*NM*NC)/
          12341034857852415 - (4600643315891*lm*NM*NC)/2779920 - 
         324870*lm^2*NM*NC - (3768930024663567677*NC*NL)/539415676800 - 
         (4600643315891*lm*NC*NL)/2779920 - 324870*lm^2*NC*NL - 
         (3809703513516573905388800409000593412953*NC*NH)/
          50603900733439094307041816040000 - (4600643315891*lm*NC*NH)/
          2779920 - 324870*lm^2*NC*NH - (1338509332402375*NM*NC*Pi^2)/324 - 
         (7913971*NC*NL*Pi^2)/12 + (2906560098440969031667*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-372859309441036260915607029249184254250994462941/
            5789086243905432388725583754976000 - (3647357782691*lm)/102960 - 
           8771490*lm^2 - (19426545094376282141*Pi^2)/2779920 + 
           (605704245038051947683209*Im[PolyLog[2, (-1)^(1/3)]])/
            (16356906605297115*Sqrt[3]) - 2598960*Zeta[3]) + 
         CA*NC*(745718851495931252124477436587952854439199182277/
            23156344975621729554902335019904000 + (5750059365491*lm)/505440 + 
           1786785*lm^2 + (19426548140319357173*Pi^2)/5559840 - 
           (605704245038051947683209*Im[PolyLog[2, (-1)^(1/3)]])/
            (32713813210594230*Sqrt[3]) + 1299480*Zeta[3])), 
      (316448249832467134029395059264171572918965901771572756791511*CF^2*NC)/
        8368945044100881322842514872652862584857600000 + 
       (22207970880257*CF^2*lm*NC)/2760615 + 6279651*CF^2*lm^2*NC + 
       (475350230870296942324763299574305861989943*CF*NM*NC)/
        7195021193344454807481144000 + (81013528000729*CF*lm*NM*NC)/
        149073210 + (697739*CF*lm^2*NM*NC)/3 - 
       (974913533823590262157*CF*NC*NL)/115704662673600 + 
       (81013528000729*CF*lm*NC*NL)/149073210 + (697739*CF*lm^2*NC*NL)/3 - 
       (58071059594922830577649036184921270713075396431623*CF*NC*NH)/
        163292665227367970366401467139361860500000 + 
       (81013528000729*CF*lm*NC*NH)/149073210 + (697739*CF*lm^2*NC*NH)/3 - 
       (284486581565380132826258771*CF^2*NC*Pi^2)/12445090257600 - 
       15680*CF^2*lm*NC*Pi^2 - (45624071450446569929*CF*NM*NC*Pi^2)/
        1216215 - (15680*CF*lm*NM*NC*Pi^2)/27 + (19571454481*CF*NC*NL*Pi^2)/
        34749 - (15680*CF*lm*NC*NL*Pi^2)/27 - (15680*CF*lm*NC*NH*Pi^2)/27 + 
       (927293495386715661023280797*CF^2*NC*Pi^3)/(127191305762790366240*
         Sqrt[3]) + (288157482762597372997100*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) + (1446648091*CF^2*NC*Pi^4)/8100 - 
       (38130920305848268289472452330447*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (636592485342765783031200*Sqrt[3]) - (76596919731124750465874348*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(305748331160553765*Sqrt[3]) + 
       (280340228*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (132470499340959380146182971*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(490707198158913450*
         Sqrt[3]) + (131729134977187370512960*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (132470499340959380146182971*CF^2*NC*Pi*Log[3]^2)/
        (23553945511627845600*Sqrt[3]) + (8233070936074210657060*CF*NC*NH*Pi*
         Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((-483303005888120264694620534*CF*NC)/1761875940825 + 
         CA*(425306972765366711367273527249/3100901655852000 - 
           (158518360*lm)/3)*NC + 259393680*CF*lm*NC - 
         (1355764827134890520246006*NM*NC)/3011753745 + 
         (28821520*lm*NM*NC)/3 + (36657140*NC*NL)/3 + (28821520*lm*NC*NL)/
          3 + (452598906256856*NC*NH)/195568425 + (28821520*lm*NC*NH)/3)*
        Log[x]^2 - (CF*NC*(-62931227223327203059*CA + 
          40*(3146524492250983271*CF + 154440*(33824954119169*NM + 
              1801345*NL)))*Log[x]^3)/1737450 - 
       (124593178549919084138038812922531*CF^2*NC*PolyGamma[2, 1])/
        10006309019799941400 - (548218674189198*CF*NM*NC*PolyGamma[2, 1])/
        25 + (25466801214780969318857879*CF*NC*NH*PolyGamma[2, 1])/
        1250788627474992675 + CA*CF*NC*
        (-1412714833727966460375273473005145353378876677739983796897/
          74722723608043583239665311362971987364800000 - (7675129*lm^2)/6 + 
         (568973142867277126737270949*Pi^2)/49780361030400 - 
         (927293495386715661023280797*Pi^3)/(254382611525580732480*Sqrt[3]) - 
         (1454174491*Pi^4)/16200 + lm*(-125140761170749/27104220 + 
           (86240*Pi^2)/27) + (38130920305848268289472452330447*
           Im[PolyLog[2, (-1)^(1/3)]])/(1273184970685531566062400*Sqrt[3]) - 
         (140170114*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
         (132470499340959380146182971*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (981414396317826900*Sqrt[3]) - (132470499340959380146182971*Pi*
           Log[3]^2)/(47107891023255691200*Sqrt[3]) + 
         (124593178549919084138038812922531*PolyGamma[2, 1])/
          20012618039599882800 - (1012138718155905585325893300509858*Zeta[3])/
          178862773728923952525) + (8097096168602587262630591066623609*CF^2*
         NC*Zeta[3])/715451094915695810100 + 
       (3662029383060836*CF*NM*NC*Zeta[3])/225 + 
       (102121040*CF*NC*NL*Zeta[3])/9 - (97854665493625843109066642*CF*NC*
         NH*Zeta[3])/1250788627474992675 + CF*Log[x]*
        ((-2124829647939995995032034751611759*NM*NC)/8062809440463577800 + 
         (57316007048*lm*NM*NC)/11583 + 866320*lm^2*NM*NC + 
         (851644513667821*NC*NL)/40135095 + (57316007048*lm*NC*NL)/11583 + 
         866320*lm^2*NC*NL + (235857708126665752198826869120151108203*NC*
           NH)/625597673902406385663978495000 + (57316007048*lm*NC*NH)/
          11583 + 866320*lm^2*NC*NH - 30066626035696*NM*NC*Pi^2 + 
         (17009720*NC*NL*Pi^2)/9 - (131729134977187370512960*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(5417325246482381844307924756679000118288330174431/
            65127220243936114373162817243480000 - (35043648244*lm)/1053 - 
           4764760*lm^2 + (125862303338370963053*Pi^2)/13899600 + 
           (132470499340959380146182971*Im[PolyLog[2, (-1)^(1/3)]])/
            (2944243188953480700*Sqrt[3]) - 3465280*Zeta[3]) + 
         CF*NC*(-13607100125499649246633776776892146900273419283/
            81792427307926046308524731232000 + (46723945568*lm)/429 + 
           23390640*lm^2 - (125862324155582021411*Pi^2)/6949800 - 
           (132470499340959380146182971*Im[PolyLog[2, (-1)^(1/3)]])/
            (1472121594476740350*Sqrt[3]) + 6930560*Zeta[3])), 
      (109381989225777706757469905352016810529327571162134010805976207*CF^2*
         NC)/585826153087061692598976041085700380940032000000 - 
       (4068873776885399*CF^2*lm*NC)/1298593296 - (7835157*CF^2*lm^2*NC)/2 + 
       (637504144060191689210759741022959670397472297*CF*NM*NC)/
        5886835521827281206120936000000 - (9438845018908787*CF*lm*NM*NC)/
        35062018992 - (290191*CF*lm^2*NM*NC)/2 + 
       (101653208011806263083*CF*NC*NL)/18031895481600 - 
       (9438845018908787*CF*lm*NC*NL)/35062018992 - (290191*CF*lm^2*NC*NL)/
        2 + (2350722433291415273810913939389467364289363140268059*CF*NC*NH)/
        18288778505465212681036964319608528376000000 - 
       (9438845018908787*CF*lm*NC*NH)/35062018992 - (290191*CF*lm^2*NC*NH)/
        2 - (14454452965346641359538303607*CF^2*NC*Pi^2)/133235672169600 + 
       (9160*CF^2*lm*NC*Pi^2)/3 - (243721170870764505916*CF*NM*NC*Pi^2)/
        3648645 + (9160*CF*lm*NM*NC*Pi^2)/81 - (36610672646*CF*NC*NL*Pi^2)/
        104247 + (9160*CF*lm*NC*NL*Pi^2)/81 + (9160*CF*lm*NC*NH*Pi^2)/81 - 
       (274116952594066418070432421*CF^2*NC*Pi^3)/(50876522305116146496*
         Sqrt[3]) - (103925690891781070492460*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (387457331*CF^2*NC*Pi^4)/3240 + 
       (196926491251366154718496902995021*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8912294794798720962436800*Sqrt[3]) + 
       (789301407215266729107440*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5559060566555523*Sqrt[3]) - (41152274*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (274116952594066418070432421*CF^2*
         NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1373980154844957660*
         Sqrt[3]) - (47508887264814203653696*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (274116952594066418070432421*CF^2*NC*Pi*Log[3]^2)/
        (65951047432557967680*Sqrt[3]) - (2969305454050887728356*CF*NC*NH*Pi*
         Log[3]^2)/(205891132094649*Sqrt[3]) - 
       (CF*NC*(-9*CA*(89709397458498895021598413847 + 4646360078051362070400*
             lm) + 8*(CF*(201846159491129072497459948217 + 
              25660579521965476888800*lm) + 
            858*(21*(6897541335604686565993343 + 52746799541950800*lm)*NM + 
              2485891980*(522085351 + 445587660*lm)*NL + 
              (292119013695418051 + 1107682790380966800*lm)*NH)))*Log[x]^2)/
        1240360662340800 - (CF*NC*(-842098238360687857215*CA + 
          16*(105262447625076338627*CF + 30030*(2135270784103570*NM - 
              41375997*NL)))*Log[x]^3)/4864860 - 
       (8487743425498166837749019143539347*CF^2*NC*PolyGamma[2, 1])/
        140088326277199179600 - (32097570785722189*CF*NM*NC*PolyGamma[2, 1])/
        900 - (411417656850673743936696671*CF*NC*NH*PolyGamma[2, 1])/
        35022081569299794900 + CA*CF*NC*
        (-262937491219767742821291839629845978973529494077169017638677/
          2816471889841642752879692505219713369904000000 + (3192101*lm^2)/4 + 
         (491451403358769164096361350141*Pi^2)/9060025707532800 + 
         (274116952594066418070432421*Pi^3)/(101753044610232292992*Sqrt[3]) + 
         (129347857*Pi^4)/2160 + lm*(15913642880104451/6374912544 - 
           (50380*Pi^2)/81) - (196926491251366154718496902995021*
           Im[PolyLog[2, (-1)^(1/3)]])/(17824589589597441924873600*Sqrt[3]) + 
         (20576137*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (274116952594066418070432421*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2747960309689915320*Sqrt[3]) + (274116952594066418070432421*Pi*
           Log[3]^2)/(131902094865115935360*Sqrt[3]) + 
         (8487743425498166837749019143539347*PolyGamma[2, 1])/
          280176652554398359200 - (130014778702314633541630967636868821*
           Zeta[3])/5008157664409870670700) + 
       (520059246313510107460731191518635329*CF^2*NC*Zeta[3])/
        10016315328819741341400 + (5117635085923937*CF*NM*NC*Zeta[3])/150 - 
       (195614308*CF*NC*NL*Zeta[3])/27 - (106918462658933308337418671*CF*NC*
         NH*Zeta[3])/17511040784649897450 + 
       CF*Log[x]*((-1188731617805588548091281689502912667*NM*NC)/
          2418842832139073340000 - (3471413382473*lm*NM*NC)/1216215 - 
         556920*lm^2*NM*NC - (14182997168635229*NC*NL)/1114495200 - 
         (3471413382473*lm*NC*NL)/1216215 - 556920*lm^2*NC*NL - 
         (31133822090875726056432973962972309562453*NC*NH)/
          227717553300475924381688172180000 - (3471413382473*lm*NC*NH)/
          1216215 - 556920*lm^2*NC*NH - (4270541741117488*NM*NC*Pi^2)/81 - 
         (10865426*NC*NL*Pi^2)/9 + (47508887264814203653696*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-2818790754399203033864615144971168820874065781999467/
            3647124333660422404897117765634880000 - (2756449232573*lm)/
            45045 - 15036840*lm^2 - (240599531505719851757*Pi^2)/2779920 + 
           (274116952594066418070432421*Im[PolyLog[2, (-1)^(1/3)]])/
            (4121940464534872980*Sqrt[3]) - 4455360*Zeta[3]) + 
         CA*NC*(352348860585892268551335480478280026475234876411179/
            911781083415105601224279441408720000 + (4333475419673*lm)/
            221130 + 3063060*lm^2 + (1684196759532808601837*Pi^2)/38918880 - 
           (274116952594066418070432421*Im[PolyLog[2, (-1)^(1/3)]])/
            (8243880929069745960*Sqrt[3]) + 2227680*Zeta[3])), 
      (142159018059606269071163320811011522515456770294749658076868657*CF^2*
         NC)/292913076543530846299488020542850190470016000000 + 
       (2742043501773227*CF^2*lm*NC)/216432216 + 9890073*CF^2*lm^2*NC + 
       (11524444022732147709705794184797258406225781*CF*NM*NC)/
        14107884692832264328394400000 + (5001492273997871*CF*lm*NM*NC)/
        5843669832 + 366299*CF*lm^2*NM*NC - (329340514226151338341709*CF*NC*
         NL)/21058248606595200 + (5001492273997871*CF*lm*NC*NL)/
        5843669832 + 366299*CF*lm^2*NC*NL - 
       (349220193366922756718229385669060529244586417042307837*CF*NC*NH)/
        550672862925667990219519163939422714274400000 + 
       (5001492273997871*CF*lm*NC*NH)/5843669832 + 366299*CF*lm^2*NC*NH - 
       (105812702722785200482428098161*CF^2*NC*Pi^2)/377501071147200 - 
       23120*CF^2*lm*NC*Pi^2 - (109180146860616003187*CF*NM*NC*Pi^2)/
        243243 - (23120*CF*lm*NM*NC*Pi^2)/27 + (230188257121*CF*NC*NL*Pi^2)/
        243243 - (23120*CF*lm*NC*NL*Pi^2)/27 - (23120*CF*lm*NC*NH*Pi^2)/
        27 + (1646797926424093166435150897*CF^2*NC*Pi^3)/
        (127191305762790366240*Sqrt[3]) + (171112937206446949114660*CF*NC*NH*
         Pi^3)/(1853020188851841*Sqrt[3]) + (819277277*CF^2*NC*Pi^4)/2700 - 
       (93541527465448341293190518107477*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (891229479479872096243680*Sqrt[3]) - (153551365835692400625151612*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(343495038711239415*Sqrt[3]) + 
       (468129748*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (1646797926424093166435150897*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3434950387112394150*
         Sqrt[3]) + (78223057008661462452416*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) + 
       (1646797926424093166435150897*CF^2*NC*Pi*Log[3]^2)/
        (164877618581394919200*Sqrt[3]) + (4888941063041341403276*CF*NC*NH*
         Pi*Log[3]^2)/(68630377364883*Sqrt[3]) + 
       CF*((-202807624382587853250998900441*CF*NC)/60295309974900 + 
         CA*(4056152950101186178169189712067/2411812398996000 - 95678924*lm)*
          NC + 469696536*CF*lm*NC - (1908468950551982405033729*NM*NC)/
          354323970 + 17396168*lm*NM*NC + (993749246*NC*NL)/45 + 
         17396168*lm*NC*NL + (9994527900747167*NC*NH)/2268593730 + 
         17396168*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-5444266656311626045243*CA + 20*(544425667762367317387*CF + 
            18378360*(47896437669442*NM + 383739*NL)))*Log[x]^3)/12162150 - 
       (4647064298537625047612486329993697*CF^2*NC*PolyGamma[2, 1])/
        30018927059399824200 - (39277301939836303*CF*NM*NC*PolyGamma[2, 1])/
        150 + (268656477363486437898806651*CF*NC*NH*PolyGamma[2, 1])/
        7504731764849956050 + CA*CF*NC*
        (-8884938123267014604704975682913093631196477003466978362300847/
          36614134567941355787436002567856273808752000000 - 
         (4029289*lm^2)/2 + (1778364742902925524154179419*Pi^2)/
          12689111635200 - (1646797926424093166435150897*Pi^3)/
          (254382611525580732480*Sqrt[3]) - (822976477*Pi^4)/5400 + 
         lm*(-7725803712278303/1062485424 + (127160*Pi^2)/27) + 
         (93541527465448341293190518107477*Im[PolyLog[2, (-1)^(1/3)]])/
          (1782458958959744192487360*Sqrt[3]) - 
         (234064874*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
         (1646797926424093166435150897*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6869900774224788300*Sqrt[3]) - (1646797926424093166435150897*Pi*
           Log[3]^2)/(329755237162789838400*Sqrt[3]) + 
         (4647064298537625047612486329993697*PolyGamma[2, 1])/
          60037854118799648400 - (103692243437413398805288777432255771*
           Zeta[3])/1502447299322961201210) + 
       (414768872643424885699001566532893153*CF^2*NC*Zeta[3])/
        3004894598645922402420 + (45015952865797091*CF*NM*NC*Zeta[3])/225 + 
       (182876072*CF*NC*NL*Zeta[3])/9 - (523352876744577590741547349*CF*NC*
         NH*Zeta[3])/3752365882424978025 + CF*Log[x]*
        ((-14672275012767389758633055327789579*NM*NC)/4742829082625634000 + 
         (3389839723492*lm*NM*NC)/405405 + 1456560*lm^2*NM*NC + 
         (11017803093060363239*NC*NL)/292183491600 + 
         (3389839723492*lm*NC*NL)/405405 + 1456560*lm^2*NC*NL + 
         (4287292997961919065318383466359517538561607*NC*NH)/
          6383682077523341746833325093446000 + (3389839723492*lm*NC*NH)/
          405405 + 1456560*lm^2*NC*NH - (3256957766713040*NM*NC*Pi^2)/9 + 
         (10154644*NC*NL*Pi^2)/3 - (78223057008661462452416*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CA*NC*(453795212744382933993722181859903226476685654453381/
            455890541707552800612139720704360000 - (2070690493346*lm)/36855 - 
           8011080*lm^2 + (10888531392715441792471*Pi^2)/97297200 + 
           (1646797926424093166435150897*Im[PolyLog[2, (-1)^(1/3)]])/
            (20609702322674364900*Sqrt[3]) - 5826240*Zeta[3]) + 
         CF*NC*(-3630361848065867280519269951547197539564822734153517/
            1823562166830211202448558882817440000 + (2766537644092*lm)/
            15015 + 39327120*lm^2 - (10888531652827973766337*Pi^2)/48648600 - 
           (1646797926424093166435150897*Im[PolyLog[2, (-1)^(1/3)]])/
            (10304851161337182450*Sqrt[3]) + 11652480*Zeta[3])), 
      (8826436109930810655590669383791910203731891339881399135359161989*CF^2*
         NC)/3766025269845396595279131692693788163185920000000 - 
       (791333457438817739*CF^2*lm*NC)/162324162000 - (60889257*CF^2*lm^2*NC)/
        10 + (2461905872555874588503931346634433239047670607377*CF*NM*NC)/
        1748390149982702518217917992000000 - (1834623205934512439*CF*lm*NM*
         NC)/4382752374000 - (6765473*CF*lm^2*NM*NC)/30 + 
       (10765846271533558514640719*CF*NC*NL)/1052912430329760000 - 
       (1834623205934512439*CF*lm*NC*NL)/4382752374000 - 
       (6765473*CF*lm^2*NC*NL)/30 + 
       (180033626789145272444996666789821890337463467688808245491*CF*NC*NH)/
        802881034145623929740058941023678317412075200000 - 
       (1834623205934512439*CF*lm*NC*NH)/4382752374000 - 
       (6765473*CF*lm^2*NC*NH)/30 - (14835776001810589459964028647171*CF^2*
         NC*Pi^2)/11325032134416000 + (67048*CF^2*lm*NC*Pi^2)/15 - 
       (1157895765210312660856*CF*NM*NC*Pi^2)/1403325 + 
       (67048*CF*lm*NM*NC*Pi^2)/405 - (10600158103099*CF*NC*NL*Pi^2)/
        18243225 + (67048*CF*lm*NC*NL*Pi^2)/405 + (67048*CF*lm*NC*NH*Pi^2)/
        405 - (4266445020657433720098255277*CF^2*NC*Pi^3)/
        (457888700746045318464*Sqrt[3]) - (1637126126888018432232280*CF*NC*
         NH*Pi^3)/(50031545098999707*Sqrt[3]) - (651129971*CF^2*NC*Pi^4)/
        3240 + (2216219670582805673390988938858287*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(57293323680848920472808000*Sqrt[3]) + 
       (306588223334216986683646166768*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1252039416102467667675*Sqrt[3]) - 
       (112619934*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (609492145808204817156893611*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1766545913372088420*
         Sqrt[3]) - (748400515148808426163328*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (609492145808204817156893611*CF^2*NC*Pi*Log[3]^2)/
        (84794203841860244160*Sqrt[3]) - (46775032196800526635208*CF*NC*NH*
         Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) - 
       (CF*NC*(-29*CA*(341222856295531040210145567821693 + 
            2606516083873877910134400*lm) + 
          8*(29*CF*(85305715025228932549987092535879 + 
              1599453051468061444855200*lm) + 
            10010*(203*(766807539511880336929010263 + 845426029773433680*lm)*
               NM + 56563603668*(3544596931 + 3034132780*lm)*NL + 
              (47501546271073626517 + 171621484044007037040*lm)*NH)))*
         Log[x]^2)/1258966072275912000 - 
       (CF*NC*(-51197403148336710843567*CA + 8*(12799353973137237095881*CF + 
            60060*(133038218976560098*NM - 368430409*NL)))*Log[x]^3)/
        24324300 - (930605271930541741673870464960694939*CF^2*NC*
         PolyGamma[2, 1])/1260794936494792616400 - 
       (25461488684716742477*CF*NM*NC*PolyGamma[2, 1])/56700 - 
       (6365336852768754124597277929*CF*NC*NH*PolyGamma[2, 1])/
        315198734123698154100 + CA*CF*NC*
        (-1930782916625864504041152817844124269427746942253735861784685789/
          1647636055557361010434620115553532321393840000000 + 
         (74420203*lm^2)/60 + (1745385413216719252503587357153*Pi^2)/
          2664713443392000 + (4266445020657433720098255277*Pi^3)/
          (915777401492090636928*Sqrt[3]) + (3259940927*Pi^4)/32400 + 
         lm*(3092561084503484039/796864068000 - (368764*Pi^2)/405) - 
         (2216219670582805673390988938858287*Im[PolyLog[2, (-1)^(1/3)]])/
          (114586647361697840945616000*Sqrt[3]) + 
         (56309967*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (609492145808204817156893611*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3533091826744176840*Sqrt[3]) + (609492145808204817156893611*Pi*
           Log[3]^2)/(169588407683720488320*Sqrt[3]) + 
         (930605271930541741673870464960694939*PolyGamma[2, 1])/
          2521589872989585232800 - (14165775659966664606323984735407806257*
           Zeta[3])/45073418979688836036300) + 
       (56663104702233942131535890691289329497*CF^2*NC*Zeta[3])/
        90146837959377672072600 + (11789214211313670403*CF*NM*NC*Zeta[3])/
        28350 - (1723061588*CF*NC*NL*Zeta[3])/135 - 
       (1186418856142200661930796089*CF*NC*NH*Zeta[3])/
        157599367061849077050 + CF*Log[x]*
        ((-128670985233371393364591917026239229459*NM*NC)/
          21769585489251660060000 - (28904072501147*lm*NM*NC)/6081075 - 
         922488*lm^2*NM*NC - (65218173458742673739*NC*NL)/2921834916000 - 
         (28904072501147*lm*NC*NL)/6081075 - 922488*lm^2*NC*NL - 
         (82484986430599844246910105188270500352942113*NC*NH)/
          344718832186260454328999555046084000 - (28904072501147*lm*NC*NH)/
          6081075 - 922488*lm^2*NC*NH - (53215287888181472*NM*NC*Pi^2)/81 - 
         (861396698*NC*NL*Pi^2)/405 + (748400515148808426163328*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CF*NC*(-1498289493530736441839773753156342859338879757229026623/
            164120595014719008220370299453569600000 - (22982702746847*lm)/
            225225 - 24907176*lm^2 - (34131602828383453751789*Pi^2)/
            32432400 + (609492145808204817156893611*Im[PolyLog[2, (-1)^
                (1/3)]])/(5299637740116265260*Sqrt[3]) - 7379904*Zeta[3]) + 
         CA*NC*(187286187948575747788016311856038180434695301689635241/
            41030148753679752055092574863392400000 + (36043714501547*lm)/
            1105650 + 5073684*lm^2 + (11377200980926607820089*Pi^2)/
            21621600 - (609492145808204817156893611*Im[PolyLog[2, (-1)^
                (1/3)]])/(10599275480232530520*Sqrt[3]) + 3689952*Zeta[3])), 
      (80087611103614602844423825103546252557058252391480342060227894273*CF^2*
         NC)/13181088444458888083476960924428258571150720000000 + 
       (7291304934157873*CF^2*lm*NC)/375750375 + (75744639*CF^2*lm^2*NC)/5 + 
       (1324290644464583504802231494471517326221241179*CF*NM*NC)/
        133424156744711730633235500000 + (26599508838566921*CF*lm*NM*NC)/
        20290520250 + (2805357*CF*lm^2*NM*NC)/5 - 
       (7337240478476369836866719*CF*NC*NL)/263228107582440000 + 
       (26599508838566921*CF*lm*NC*NL)/20290520250 + 
       (2805357*CF*lm^2*NC*NL)/5 - 
       (653290376713923637675848171377853791855493006596913963050039*CF*NC*
         NH)/597965722205807062272152397800910018850578307080000 + 
       (26599508838566921*CF*lm*NC*NH)/20290520250 + 
       (2805357*CF*lm^2*NC*NH)/5 - (78676361503622808390021151363*CF^2*NC*
         Pi^2)/23302535256000 - (166464*CF^2*lm*NC*Pi^2)/5 - 
       (10736845822024801918727*CF*NM*NC*Pi^2)/2027025 - 
       (18496*CF*lm*NM*NC*Pi^2)/15 + (1040765710273*CF*NC*NL*Pi^2)/675675 - 
       (18496*CF*lm*NC*NL*Pi^2)/15 - (18496*CF*lm*NC*NH*Pi^2)/15 + 
       (25395202917009591845018140853*CF^2*NC*Pi^3)/(1144721751865113296160*
         Sqrt[3]) + (7952678788683866983813340*CF*NC*NH*Pi^3)/
        (50031545098999707*Sqrt[3]) + (448841939*CF^2*NC*Pi^4)/900 - 
       (35708100068138860198358684403668173*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(200526632882971221654828000*Sqrt[3]) - 
       (74298791318431049864226680644*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (96310724315574435975*Sqrt[3]) + 
       (252599532*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (25395202917009591845018140853*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(30914553484011547350*
         Sqrt[3]) + (3635510303398339192600384*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) + 
       (25395202917009591845018140853*CF^2*NC*Pi*Log[3]^2)/
        (1483898567232554272800*Sqrt[3]) + (227219393962396199537524*CF*NC*
         NH*Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) + 
       CF*((-3664351391083301373077825604383*CF*NC)/90442964962350 + 
         CA*(2254985508762788853247743262741/111314418415200 - 
           (7513718344*lm)/45)*NC + (4098391824*CF*lm*NC)/5 - 
         (17403060548141271033332816*NM*NC)/273795795 + 
         (1366130608*lm*NM*NC)/45 + (25971181724*NC*NL)/675 + 
         (1366130608*lm*NC*NL)/45 + (108792716895596580358*NC*NH)/
          13537833083775 + (1366130608*lm*NC*NH)/45)*Log[x]^2 - 
       (CF*NC*(-7337939097301706667041*CA + 8*(1834484259928805373509*CF + 
            40040*(72465514655066049*NM + 85383163*NL)))*Log[x]^3)/
        1351350 - (56663599731034569562858039028239577*CF^2*NC*
         PolyGamma[2, 1])/30018927059399824200 - 
       (417383333200172981*CF*NM*NC*PolyGamma[2, 1])/135 + 
       (228421510224624465637822786*CF*NC*NH*PolyGamma[2, 1])/
        3752365882424978025 + CA*CF*NC*
        (-227521620641376892724994696093125685316589503960711784902308899/
          74892547979880045928846368888796923699720000000 - 
         (30858927*lm^2)/10 + (35701878305523276099338885893*Pi^2)/
          21148519392000 - (25395202917009591845018140853*Pi^3)/
          (2289443503730226592320*Sqrt[3]) - (90123511*Pi^4)/360 + 
         lm*(-41088784151979821/3689185500 + (101728*Pi^2)/15) + 
         (35708100068138860198358684403668173*Im[PolyLog[2, (-1)^(1/3)]])/
          (401053265765942443309656000*Sqrt[3]) - 
         (126299766*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (25395202917009591845018140853*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(61829106968023094700*Sqrt[3]) - 
         (25395202917009591845018140853*Pi*Log[3]^2)/(2967797134465108545600*
           Sqrt[3]) + (56663599731034569562858039028239577*PolyGamma[2, 1])/
          60037854118799648400 - (621595760960570473709010276879634346*
           Zeta[3])/751223649661480600605) + 
       (4972765914388127709328831544577705577*CF^2*NC*Zeta[3])/
        3004894598645922402420 + (324681537144420086*CF*NM*NC*Zeta[3])/135 + 
       (1580286544*CF*NC*NL*Zeta[3])/45 - (900339600885051206408650108*CF*NC*
         NH*Zeta[3])/3752365882424978025 + CF*Log[x]*
        ((-1667604216207959197696939541590507079*NM*NC)/
          46516208310366795000 + (3080715784724*lm*NM*NC)/225225 + 
         2372112*lm^2*NM*NC + (23639715593678951087*NC*NL)/365229364500 + 
         (3080715784724*lm*NC*NL)/225225 + 2372112*lm^2*NC*NL + 
         (19147467058327907033177810393159428568549417203*NC*NH)/
          16563739886549814830508428619964336200 + (3080715784724*lm*NC*NH)/
          225225 + 2372112*lm^2*NC*NH - 4294252721782704*NM*NC*Pi^2 + 
         (789810344*NC*NL*Pi^2)/135 - (3635510303398339192600384*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CA*NC*(240560130150168465432831707641664036478335400208886161/
            20515074376839876027546287431696200000 - (1880340844762*lm)/
            20475 - 13046616*lm^2 + (14675877821603442942451*Pi^2)/10810800 + 
           (25395202917009591845018140853*Im[PolyLog[2, (-1)^(1/3)]])/
            (185487320904069284100*Sqrt[3]) - 9488448*Zeta[3]) + 
         CF*NC*(-174952822938953000308177987645752341360062772161287523/
            7460027046123591282744104520616800000 + (7550327424372*lm)/
            25025 + 64047024*lm^2 - (2935175574283189226809*Pi^2)/1081080 - 
           (25395202917009591845018140853*Im[PolyLog[2, (-1)^(1/3)]])/
            (92743660452034642050*Sqrt[3]) + 18976896*Zeta[3])), 
      (3418492964241452042433838679214834766759899653808581797377949036689749\
3*CF^2*NC)/1186979320880890417727703138409406024462011975680000000 - 
       (1705235566208065039*CF^2*lm*NC)/230861030400 - 
       (147486339*CF^2*lm^2*NC)/16 + 
       (63071158852686686678332737071120785260200418280034953*CF*NM*NC)/
        3544227521490130428410747171481600000 - 
       (3951513745506017839*CF*lm*NM*NC)/6233247820800 - 
       (5462457*CF*lm^2*NM*NC)/16 + (45142342172686211490544193*CF*NC*NL)/
        2526989832791424000 - (3951513745506017839*CF*lm*NC*NL)/
        6233247820800 - (5462457*CF*lm^2*NC*NL)/16 + 
       (869824917617546123626194431145353351651814769256691575379545353*CF*NC*
         NH)/2296188373270299119125065207555494472386220699187200000 - 
       (3951513745506017839*CF*lm*NC*NH)/6233247820800 - 
       (5462457*CF*lm^2*NC*NH)/16 - (940405692586307251363815442463339*CF^2*
         NC*Pi^2)/60400171383552000 + (51153*CF^2*lm*NC*Pi^2)/8 - 
       (10805522432464115052797*CF*NM*NC*Pi^2)/1081080 + 
       (17051*CF*lm*NM*NC*Pi^2)/72 - (24205794619189*CF*NC*NL*Pi^2)/
        25945920 + (17051*CF*lm*NC*NL*Pi^2)/72 + (17051*CF*lm*NC*NH*Pi^2)/
        72 - (85654903486012082890266589973*CF^2*NC*Pi^3)/
        (5494664408952543821568*Sqrt[3]) - (33283797489144095512309775*CF*NC*
         NH*Pi^3)/(600378541187996484*Sqrt[3]) - (1412997347*CF^2*NC*Pi^4)/
        4320 + (126244009803073619437943663184116519*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1925055675676523727886348800*Sqrt[3]) + 
       (2462817994238026232711038037887*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (6009789197291844804840*Sqrt[3]) - 
       (71841337*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (85654903486012082890266589973*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(148389856723255427280*
         Sqrt[3]) - (3803862570187896629978260*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (85654903486012082890266589973*CF^2*NC*Pi*Log[3]^2)/
        (7122713122716260509440*Sqrt[3]) - (950965642546974157494565*CF*NC*
         NH*Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) + 
       CF*((-940875900237205588003151563923820577*CF*NC)/
          5035864289103648000 - 506832526*CF*lm*NC + 
         CA*(940875898714341668663682835541209871/10071728578207296000 + 
           (2787578893*lm)/27)*NC - (3017026516389376547965392857617*NM*NC)/
          25154167278240 - (506832526*lm*NM*NC)/27 - (13780849213*NC*NL)/
          630 - (506832526*lm*NC*NL)/27 - (4228833551715617783033*NC*NH)/
          779779185625440 - (506832526*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-816455012952501150628095*CA + 
          8*(204113760995128522140069*CF + 100100*(1299200509567916847*NM - 
              506832526*NL)))*Log[x]^3)/32432400 - 
       (33465845963873234359401596702561965003*CF^2*NC*PolyGamma[2, 1])/
        3782384809484377849200 - (626752328461382102597*CF*NM*NC*
         PolyGamma[2, 1])/113400 - (18190134404536802530320201269*CF*NC*NH*
         PolyGamma[2, 1])/540340687069196835600 + 
       CA*CF*NC*(-44440408591120421381004953480030423722792067353409161563155\
6214743484209/30861462342903150860920281598644556636012311367680000000 + 
         (60087027*lm^2)/32 + (3687865461477503795769279839093*Pi^2)/
          473726834380800 + (85654903486012082890266589973*Pi^3)/
          (10989328817905087643136*Sqrt[3]) + (1414634243*Pi^4)/8640 + 
         lm*(6659944851645176239/1133317785600 - (187561*Pi^2)/144) - 
         (126244009803073619437943663184116519*Im[PolyLog[2, (-1)^(1/3)]])/
          (3850111351353047455772697600*Sqrt[3]) + 
         (71841337*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (85654903486012082890266589973*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(296779713446510854560*Sqrt[3]) + 
         (85654903486012082890266589973*Pi*Log[3]^2)/(14245426245432521018880*
           Sqrt[3]) + (33465845963873234359401596702561965003*
           PolyGamma[2, 1])/7564769618968755698400 - 
         (8089873581814278427426288994052437635489*Zeta[3])/
          2163524111025064129742400) + 
       (8089873623582218078478596406313924574197*CF^2*NC*Zeta[3])/
        1081762055512532064871200 + (282688033651952666953*CF*NM*NC*Zeta[3])/
        56700 - (1173936071*CF*NC*NL*Zeta[3])/54 - 
       (2223711277797803699167709069*CF*NC*NH*Zeta[3])/
        270170343534598417800 + CF*Log[x]*
        ((-315015897003625863278938558123213546735513*NM*NC)/
          4506639112974928273344000 - (33189943403371*lm*NM*NC)/4324320 - 
         1482570*lm^2*NM*NC - (132785865659859119789*NC*NL)/3506201899200 - 
         (33189943403371*lm*NC*NL)/4324320 - 1482570*lm^2*NC*NL - 
         (585949474916728887039981705361703786405083599667*NC*NH)/
          1445562753735256567026190134105978432000 - 
         (33189943403371*lm*NC*NH)/4324320 - 1482570*lm^2*NC*NH - 
         (433066836852948235*NM*NC*Pi^2)/54 - (293445653*NC*NL*Pi^2)/81 + 
         (3803862570187896629978260*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CF*NC*(-4002104972137611866940462506791311099062858215256954668597/
            37643296474739641612726751411032372800000 - (26422663684171*lm)/
            160160 - 40029390*lm^2 - (1632910030956447182962261*Pi^2)/
            129729600 + (85654903486012082890266589973*
             Im[PolyLog[2, (-1)^(1/3)]])/(445169570169766281840*Sqrt[3]) - 
           11860560*Zeta[3]) + CA*NC*
          (352185237885555796004635289062073204476417035822942290548291/
            6625220179554176923839908248341697612800000 + (41349534260971*lm)/
            786240 + 8154135*lm^2 + (326582006347059290888737*Pi^2)/
            51891840 - (85654903486012082890266589973*
             Im[PolyLog[2, (-1)^(1/3)]])/(890339140339532563680*Sqrt[3]) + 
           5930280*Zeta[3])), (6462331989139949693635891438168995647337121325\
898919239267093432278372501*CF^2*NC)/
        86797862839415111796338291996187815538784625721600000000 + 
       (5578763782274059061*CF^2*lm*NC)/192384192000 + 
       (905614803*CF^2*lm^2*NC)/40 + 
       (71976302917262464938989341156590035312551037799669671*CF*NM*NC)/
        606456709232755651083616738231296000 + 
       (10176393602592794261*CF*lm*NM*NC)/5194373184000 + 
       (33541289*CF*lm^2*NM*NC)/40 - (201939024864713830294634399*CF*NC*NL)/
        4211649721319040000 + (10176393602592794261*CF*lm*NC*NL)/
        5194373184000 + (33541289*CF*lm^2*NC*NL)/40 - 
       (5547506901056780646250900620208763169014428371363985528159598497*CF*
         NC*NH)/3039072846975395892959645127646977978158233278336000000 + 
       (10176393602592794261*CF*lm*NC*NH)/5194373184000 + 
       (33541289*CF*lm^2*NC*NH)/40 - (55607050926483619199471223794683489*
         CF^2*NC*Pi^2)/1389203941821696000 - (938961*CF^2*lm*NC*Pi^2)/20 - 
       (1000744274010160609929061*CF*NM*NC*Pi^2)/16216200 - 
       (104329*CF*lm*NM*NC*Pi^2)/60 + (52708681813691*CF*NC*NL*Pi^2)/
        21621600 - (104329*CF*lm*NC*NL*Pi^2)/60 - (104329*CF*lm*NC*NH*Pi^2)/
        60 + (700520255752161483683033959001*CF^2*NC*Pi^3)/
        (19019992184835728613120*Sqrt[3]) + (717047896167453135981601745*CF*
         NC*NH*Pi^3)/(2701703435345984178*Sqrt[3]) + 
       (17194533227*CF^2*NC*Pi^4)/21600 - 
       (1956074859051138365599393369906987139*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(6663654261957197519606592000*Sqrt[3]) - 
       (174739668888997582983433981486061*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(135220256939066508108900*Sqrt[3]) + 
       (795622321*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
       (700520255752161483683033959001*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(513657196349730325200*
         Sqrt[3]) + (163896661981132145367223256*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) + 
       (700520255752161483683033959001*CF^2*NC*Pi*Log[3]^2)/
        (24655545424787055609600*Sqrt[3]) + (20487082747641518170902907*CF*NC*
         NH*Pi*Log[3]^2)/(100063090197999414*Sqrt[3]) + 
       CF*((-12094533507963196223706488160195630283*CF*NC)/
          25179321445518240000 + CA*(12094533536542883240670214479036701503/
            50358642891036480000 - (12692090554*lm)/45)*NC + 
         (6922958484*CF*lm*NC)/5 - (5174432330378849754649331722871*NM*NC)/
          6987268688400 + (2307652828*lm*NM*NC)/45 + (43809637619*NC*NL)/
          675 + (2307652828*lm*NC*NL)/45 + (179920056431058714457*NC*NH)/
          12741489961200 + (2307652828*lm*NC*NH)/45)*Log[x]^2 - 
       (CF*NC*(-1050570593418860474113713*CA + 
          16*(131321318652792175787219*CF + 30030*(6789141169373103387*NM + 
              1153826414*NL)))*Log[x]^3)/16216200 - 
       (440075601765912104195492278793890835279*CF^2*NC*PolyGamma[2, 1])/
        19452264734491086081600 - (97469690036234348659*CF*NM*NC*
         PolyGamma[2, 1])/2700 + (48869207560874963889771046343*CF*NC*NH*
         PolyGamma[2, 1])/486306618362277152040 + 
       CA*CF*NC*(-64623319820141319842886808539897381433089413711468440014528\
13876063633751/173595725678830223592676583992375631077569251443200000000 - 
         (368954179*lm^2)/80 + (2495044237515131486507859022511*Pi^2)/
          124664956416000 - (700520255752161483683033959001*Pi^3)/
          (38039984369671457226240*Sqrt[3]) - (17254626731*Pi^4)/43200 + 
         lm*(-15719947261541699861/944431488000 + (1147619*Pi^2)/120) + 
         (1956074859051138365599393369906987139*Im[PolyLog[2, (-1)^(1/3)]])/
          (13327308523914395039213184000*Sqrt[3]) - 
         (795622321*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 - 
         (700520255752161483683033959001*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1027314392699460650400*Sqrt[3]) - 
         (700520255752161483683033959001*Pi*Log[3]^2)/
          (49311090849574111219200*Sqrt[3]) + 
         (440075601765912104195492278793890835279*PolyGamma[2, 1])/
          38904529468982172163200 - (2717490867573240578174175367119526384601*
           Zeta[3])/278167385703222530966880) + 
       (95112179898161926393913004981328392305047*CF^2*NC*Zeta[3])/
        4867929249806394291920400 + (38313132826343587871*CF*NM*NC*Zeta[3])/
        1350 + (2646617749*CF*NC*NL*Zeta[3])/45 - 
       (97263466622627019053490604801*CF*NC*NH*Zeta[3])/
        243153309181138576020 + CF*Log[x]*
        ((-38181421392123999574246171035711810222629*NM*NC)/
          92994140426466773894400 + (78356429457209*lm*NM*NC)/3603600 + 
         3755844*lm^2*NM*NC + (39349161190527376577*NC*NL)/365229364500 + 
         (78356429457209*lm*NC*NL)/3603600 + 3755844*lm^2*NC*NL + 
         (3124508988312459103438388952366697879828625027501*NC*NH)/
          1618899464024778282076841892268007520000 + 
         (78356429457209*lm*NC*NH)/3603600 + 3755844*lm^2*NC*NH - 
         (150869803773550997*NM*NC*Pi^2)/3 + (1322839394*NC*NL*Pi^2)/135 - 
         (163896661981132145367223256*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CA*NC*(3691624074346165834115499860206414870175582804572844023508647/
            27103173461812541961163261015943308416000000 - 
           (95582232378809*lm)/655200 - 20657142*lm^2 + 
           (22234298193278628485233*Pi^2)/1372800 + 
           (700520255752161483683033959001*Im[PolyLog[2, (-1)^(1/3)]])/
            (3081943178098381951200*Sqrt[3]) - 15023376*Zeta[3]) + 
         CF*NC*(-580112355014527013843278256717182775299829820733630889982298\
1/21295350577138425826628276512526885184000000 + (192209850150027*lm)/
            400400 + 101407788*lm^2 - (4202282360527162451122861*Pi^2)/
            129729600 - (700520255752161483683033959001*
             Im[PolyLog[2, (-1)^(1/3)]])/(1540971589049190975600*Sqrt[3]) + 
           30046752*Zeta[3])), (722799058741272779292431561523441380639972202\
714191177372059360591105219574521*CF^2*NC)/
        2080876555807491840185568708477790798398620465932646400000000 - 
       (3646759531793601786071*CF^2*lm*NC)/333594188928000 - 
       (1090629279*CF^2*lm^2*NC)/80 + 
       (255055998713946481043833910945442045229861109333884432970657*CF*NM*
         NC)/1161446903019837231520630258841691801600000 - 
       (8447262452094680977271*CF*lm*NM*NC)/9007043101056000 - 
       (40393677*CF*lm^2*NM*NC)/80 + (27568335836643399226255448143*CF*NC*
         NL)/912875077095901920000 - (8447262452094680977271*CF*lm*NC*NL)/
        9007043101056000 - (40393677*CF*lm^2*NC*NL)/80 + 
       (34492222717098920919314293245906755930524144079340956205890903*CF*NC*
         NH)/55463487277060365196257613709069914791937698048000000 - 
       (8447262452094680977271*CF*lm*NC*NH)/9007043101056000 - 
       (40393677*CF*lm^2*NC*NH)/80 - (1077034906554600299034601775002793447*
         CF^2*NC*Pi^2)/5904116752742208000 + (358473*CF^2*lm*NC*Pi^2)/40 - 
       (1367140741671394451218298*CF*NM*NC*Pi^2)/11486475 + 
       (119491*CF*lm*NM*NC*Pi^2)/360 - (3216797218043413*CF*NC*NL*Pi^2)/
        2205403200 + (119491*CF*lm*NC*NL*Pi^2)/360 + 
       (119491*CF*lm*NC*NH*Pi^2)/360 - (10646104397490572650768357858201*
         CF^2*NC*Pi^3)/(420341827284869602349952*Sqrt[3]) - 
       (54780479509300987667394295*CF*NC*NH*Pi^3)/(600378541187996484*
         Sqrt[3]) - (5589112523*CF^2*NC*Pi^4)/10800 + 
       (270478200064982455388570211208738721339*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2503534906217319108116196614400*
         Sqrt[3]) + (2228948359532253167104416789883*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3338771776273247113800*Sqrt[3]) - 
       55819853*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (10646104397490572650768357858201*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11351824039329040186920*
         Sqrt[3]) - (6260626229634398590559348*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (10646104397490572650768357858201*CF^2*NC*Pi*Log[3]^2)/
        (544887553887793928972160*Sqrt[3]) - (1565156557408599647639837*CF*NC*
         NH*Pi*Log[3]^2)/(22236242266222092*Sqrt[3]) - 
       (CF*NC*(-(CA*(7261907861037440048560113272036028205111 + 
             1141938315379736987984503632000*lm)) + 
          11*(CF*(1320346884129913520027727987108514649887 + 
              509625363888477664059199968000*lm) + 
            154700*((5568642568996453030247414481767063 + 
                122010429717847605654720*lm)*NM + 23*(5794080445296*
                 (1064549793 + 915555340*lm)*NL + 5*(318475799185300692547 + 
                  1060960258416066136128*lm)*NH))))*Log[x]^2)/
        6634751200894056240000 + (CF*NC*(163556111514087527324271843*CA - 
          136*(2405236947716064261080007*CF + 20020*(77881948321920363927*
               NM - 4224633926*NL)))*Log[x]^3)/551350800 - 
       (14230727831684088260244211565262582529333*CF^2*NC*PolyGamma[2, 1])/
        136165853141437602571200 - (7564778544430191201839*CF*NM*NC*
         PolyGamma[2, 1])/113400 - (206508071273750165049536801741*CF*NC*NH*
         PolyGamma[2, 1])/3782384809484377849200 + 
       CA*CF*NC*(-12215304094835648332448299820210561553468651498612806999167\
0312208964676110588049/
          703336275862932241982722223465493289858733717485234483200000000 + 
         (444330447*lm^2)/160 + (821536923393180581623458827616737*Pi^2)/
          9007043101056000 + (10646104397490572650768357858201*Pi^3)/
          (840683654569739204699904*Sqrt[3]) + (5594848091*Pi^4)/21600 + 
         lm*(14235428652649092250871/1637644200192000 - (1314401*Pi^2)/720) - 
         (270478200064982455388570211208738721339*Im[PolyLog[2, (-1)^(1/3)]])/
          (5007069812434638216232393228800*Sqrt[3]) + 
         (55819853*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (10646104397490572650768357858201*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(22703648078658080373840*Sqrt[3]) + 
         (10646104397490572650768357858201*Pi*Log[3]^2)/
          (1089775107775587857944320*Sqrt[3]) + 
         (14230727831684088260244211565262582529333*PolyGamma[2, 1])/
          272331706282875205142400 - 
         (14502890526916846721440211168939156569258541*Zeta[3])/
          331019188986834811850587200) + 
       (14502890537398888244774526391581983505637313*CF^2*NC*Zeta[3])/
        165509594493417405925293600 + (3338694229622495975671*CF*NM*NC*
         Zeta[3])/56700 - (9703027711*CF*NC*NL*Zeta[3])/270 - 
       (13591744238530909912074746261*CF*NC*NH*Zeta[3])/
        1891192404742188924600 + CF*Log[x]*
        ((-45854857415371745121441651147120587893417220521*NM*NC)/
          56301442438395778918886592000 - (4432979402428867*lm*NM*NC)/
          367567200 - 2319786*lm^2*NM*NC - (18593922788610001705883*NC*NL)/
          298027161432000 - (4432979402428867*lm*NC*NL)/367567200 - 
         2319786*lm^2*NC*NL - 
         (2305802931288571535367100932347554886027457252583*NC*NH)/
          3456780498062570051584367711992557120000 - 
         (4432979402428867*lm*NC*NH)/367567200 - 2319786*lm^2*NC*NH - 
         (5192129888662243135*NM*NC*Pi^2)/54 - (2425488073*NC*NL*Pi^2)/
          405 + (6260626229634398590559348*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (5559060566555523*Sqrt[3]) + 
         CF*NC*
          (-42528329217650953702800375089672822945714690448211515531528478475\
3/347902142378710462729626153385151723251008000000 - (3532931199775267*lm)/
            13613600 - 62634222*lm^2 - (1460322424875683107564993*Pi^2)/
            9845550 + (10646104397490572650768357858201*
             Im[PolyLog[2, (-1)^(1/3)]])/(34055472117987120560760*Sqrt[3]) - 
           18558288*Zeta[3]) + CA*NC*(148849152281827634370783026237073640240\
8641340068094991256529859873/
            2435314996650973239107383073696062062757056000000 + 
           (5518204986489667*lm)/66830400 + 12758823*lm^2 + 
           (4088902789925340645067391*Pi^2)/55135080 - 
           (10646104397490572650768357858201*Im[PolyLog[2, (-1)^(1/3)]])/
            (68110944235974241121520*Sqrt[3]) + 9279144*Zeta[3])), 
      (8434673227646798629970050735330460257684430538577631324175839641994208\
285806063*CF^2*NC)/
        9419682266021413955125744064269999417750898002034390400000000 + 
       (1178557342780101421*CF^2*lm*NC)/27799515744 + 
       (132414021*CF^2*lm^2*NC)/4 + 
       (9289797263153252662231177374450709102483697880985020915779*CF*NM*NC)/
        6642261700276846912291186120826668800000 + 
       (2149944392346783169*CF*lm*NM*NC)/750586925088 + 
       (4904223*CF*lm^2*NM*NC)/4 - (1556725910048070945531965087*CF*NC*NL)/
        19474668311379240960 + (2149944392346783169*CF*lm*NC*NL)/
        750586925088 + (4904223*CF*lm^2*NC*NL)/4 - 
       (6764064709438732924697939121193671908014030176636663856898972473*CF*
         NC*NH)/2279304635231546919719733845735233483618674958752000000 + 
       (2149944392346783169*CF*lm*NC*NH)/750586925088 + 
       (4904223*CF*lm^2*NC*NH)/4 - (629554315318271096366304666097873*CF^2*
         NC*Pi^2)/1345667635952640 - 64980*CF^2*lm*NC*Pi^2 - 
       (39176728629825940724187829*CF*NM*NC*Pi^2)/55135080 - 
       (7220*CF*lm*NM*NC*Pi^2)/3 + (6915454396133*CF*NC*NL*Pi^2)/1837836 - 
       (7220*CF*lm*NC*NL*Pi^2)/3 - (7220*CF*lm*NC*NH*Pi^2)/3 + 
       (374873629574844518021560171895789*CF^2*NC*Pi^3)/
        (6305127409273044035249280*Sqrt[3]) + 
       (6990772857269965400959318465*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) + (4457035523*CF^2*NC*Pi^4)/3600 - 
       (17708308379878815555228846210718150217707*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(37553023593259786621742949216000*
         Sqrt[3]) - (85498584205488004265362573407173*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40566077081719952432670*Sqrt[3]) + 
       (611328363*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (374873629574844518021560171895789*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(170277360589935602803800*
         Sqrt[3]) + (798945469402281760109636396*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) + 
       (374873629574844518021560171895789*CF^2*NC*Pi*Log[3]^2)/
        (8173313308316908934582400*Sqrt[3]) + 
       (199736367350570440027409099*CF*NC*NH*Pi*Log[3]^2)/
        (600378541187996484*Sqrt[3]) + 
       CF*((-12415952155404263154285550264757507370317*CF*NC)/
          2211583733631352080000 + 
         CA*(12415952159530691552660859926942247392177/
            4423167467262704160000 - (4165459034*lm)/9)*NC + 
         2272068564*CF*lm*NC - (46173261417972713968436368394203*NM*NC)/
          5415133233510 + (757356188*lm*NM*NC)/9 + (14360892664*NC*NL)/
          135 + (757356188*lm*NC*NL)/9 + (649999413356193732959*NC*NH)/
          27075666167550 + (757356188*lm*NC*NH)/9)*Log[x]^2 - 
       (4*CF*NC*(-2186841464524065158601377*CA + 4373682901915003606639064*
           CF + 850850*(7854470303941190382*NM + 189339047*NL))*Log[x]^3)/
        11486475 - (2596990401538269867829855219070336933359*CF^2*NC*
         PolyGamma[2, 1])/9726132367245543040800 - 
       (281464230135454355842*CF*NM*NC*PolyGamma[2, 1])/675 + 
       (65469177996029930090614912843*CF*NC*NH*PolyGamma[2, 1])/
        405255515301897626700 + CA*CF*NC*
        (-1686934645274475818204099819895287599957236876371237562681801424622\
3762676670501/
          37678729064085655820502976257079997671003592008137561600000000 - 
         (53946453*lm^2)/8 + (573480651598895882065130829392791*Pi^2)/
          2451621199104000 - (374873629574844518021560171895789*Pi^3)/
          (12610254818546088070498560*Sqrt[3]) - (4470897923*Pi^4)/7200 + 
         lm*(-3321186193738188913/136470350016 + (39710*Pi^2)/3) + 
         (17708308379878815555228846210718150217707*
           Im[PolyLog[2, (-1)^(1/3)]])/(75106047186519573243485898432000*
           Sqrt[3]) - (611328363*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
         (374873629574844518021560171895789*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(340554721179871205607600*Sqrt[3]) - 
         (374873629574844518021560171895789*Pi*Log[3]^2)/
          (16346626616633817869164800*Sqrt[3]) + 
         (2596990401538269867829855219070336933359*PolyGamma[2, 1])/
          19452264734491086081600 - 
         (168105208424943369841247612274767748192047*Zeta[3])/
          1477764236548369695761550) + 
       (4706945832686079716035691341870048084017917*CF^2*NC*Zeta[3])/
        20688699311677175740661700 + (222518569690934550166*CF*NM*NC*
         Zeta[3])/675 + (862006478*CF*NC*NL*Zeta[3])/9 - 
       (131405970860949858083418142157*CF*NC*NH*Zeta[3])/
        202627757650948813350 + CF*Log[x]*
        ((-7274869074351459152052566987556501489063754609*NM*NC)/
          1563928956622104969969072000 + (25802907961037*lm*NM*NC)/765765 + 
         5799465*lm^2*NM*NC + (6933560478300723116011*NC*NL)/
          39736954857600 + (25802907961037*lm*NC*NL)/765765 + 
         5799465*lm^2*NC*NL + 
         (1682886108443258907669915159049830539004012122694203*NC*NH)/
          536665172324214000508473087286844492880000 + 
         (25802907961037*lm*NC*NH)/765765 + 5799465*lm^2*NC*NH - 
         (1745437845339470863*NM*NC*Pi^2)/3 + (430873279*NC*NL*Pi^2)/27 - 
         (798945469402281760109636396*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + CA*NC*(11413746319620592765431841924\
737885306823339252286470547218394700287/
            7305944989952919717322149221088186188271168000000 - 
           (31455124544687*lm)/139230 - (63794115*lm^2)/2 + 
           (19993979094146924192518547*Pi^2)/105019200 + 
           (374873629574844518021560171895789*Im[PolyLog[2, (-1)^(1/3)]])/
            (1021664163539613616822800*Sqrt[3]) - 23197860*Zeta[3]) + 
         CF*NC*
          (-87798048622482892346757531091506361326719002245496163588658559499\
9/280997884228958450666236508503391776471968000000 + (126690941433297*lm)/
            170170 + 156585555*lm^2 - (139957853668226538541179637*Pi^2)/
            367567200 - (374873629574844518021560171895789*
             Im[PolyLog[2, (-1)^(1/3)]])/(510832081769806808411400*Sqrt[3]) + 
           46395720*Zeta[3])), (451458882738483240783713174756972717188340770\
706877080900991176513102639472967483*CF^2*NC)/
        109558150663264445385770192501355685535687367531353832960000000 - 
       (95133308526379681169*CF^2*lm*NC)/6004695400704 - 
       (157973049*CF^2*lm^2*NC)/8 + 
       (53970767359677703106966312299465223353946610361202267235878137*CF*NM*
         NC)/20325320802847151551611029529729606528000000 - 
       (220293175016270409665*CF*lm*NM*NC)/162126775819008 - 
       (17552561*CF*lm^2*NM*NC)/24 + (1158711217708696454152604047*CF*NC*
         NL)/23369601973655089152 - (220293175016270409665*CF*lm*NC*NL)/
        162126775819008 - (17552561*CF*lm^2*NC*NL)/24 + 
       (4164265222787183684774103904667680892563028844938579732367794120041*
         CF*NC*NH)/
        4184803310285120144605431340769888675923887224268672000000 - 
       (220293175016270409665*CF*lm*NC*NH)/162126775819008 - 
       (17552561*CF*lm^2*NC*NH)/24 - (2299713039735754861478087668018939399*
         CF^2*NC*Pi^2)/1089990785121638400 + (74005*CF^2*lm*NC*Pi^2)/6 - 
       (115449052485337921530848351*CF*NM*NC*Pi^2)/82702620 + 
       (74005*CF*lm*NM*NC*Pi^2)/162 - (21048129585715*CF*NC*NL*Pi^2)/
        9451728 + (74005*CF*lm*NC*NL*Pi^2)/162 + (74005*CF*lm*NC*NH*Pi^2)/
        162 - (209988211239876262515375419104963*CF^2*NC*Pi^3)/
        (5238105847703759660053248*Sqrt[3]) - 
       (64045767739186151695253937005*CF*NC*NH*Pi^3)/(437675956526049436836*
         Sqrt[3]) - (10348376467*CF^2*NC*Pi^4)/12960 + 
       (22088318528908039158781426544177431537*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(127338353157678397335894458880*
         Sqrt[3]) + (1162642054693997754951105311746621*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1095284081206438715682090*Sqrt[3]) - 
       (508535209*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (29998315891410894645053631300709*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(20208741696387961651440*
         Sqrt[3]) - (7319516313049845908029021372*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (29998315891410894645053631300709*CF^2*NC*Pi*Log[3]^2)/
        (970019601426622159269120*Sqrt[3]) - (1829879078262461477007255343*CF*
         NC*NH*Pi*Log[3]^2)/(16210220612075905068*Sqrt[3]) - 
       (CF*NC*(-(CA*(201575597229383795937807555596134167925663 + 
             4444362030176021998028432448000*lm)) + 
          182*(7*CF*(316445207591722924852888688047520434399 + 
              17125413845404965598225728000*lm) + 
            44880*(7*(4665153713837755215670702034482499 + 
                14132677960491323032800*lm)*NM + 666319251209040*(
                172300383 + 148470490*lm)*NL + (30736689910743526170541 + 
                98928745723439261229600*lm)*NH)))*Log[x]^2)/
        15923402882145734976000 + (CF*NC*(95077918167370326853518677*CA - 
          104*(1828421504749669005052059*CF + 13090*(91900712955958807137*
               NM - 685085261*NL)))*Log[x]^3)/27567540 - 
       (13434096780078076150889395984373270322632987*CF^2*NC*PolyGamma[2, 1])/
        11029434104456445808267200 - (179529742303869055508561*CF*NM*NC*
         PolyGamma[2, 1])/226800 - (34029702279570980650449005839957*CF*NC*
         NH*PolyGamma[2, 1])/393908360873444493152400 + 
       CA*CF*NC*(-29344827378688887516175896246904087570554134268651917447739\
91581766478370179142827/
          1424255958622437790015012502517623911963935777907599828480000000 + 
         (193078171*lm^2)/48 + (121037528407351040901168711656375773*Pi^2)/
          114735872118067200 + (209988211239876262515375419104963*Pi^3)/
          (10476211695407519320106496*Sqrt[3]) + (383624041*Pi^4)/960 + 
         lm*(371203636047143441153/29477595603456 - (814055*Pi^2)/324) - 
         (22088318528908039158781426544177431537*Im[PolyLog[2, (-1)^(1/3)]])/
          (254676706315356794671788917760*Sqrt[3]) + 
         (508535209*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (29998315891410894645053631300709*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(40417483392775923302880*Sqrt[3]) + 
         (29998315891410894645053631300709*Pi*Log[3]^2)/
          (1940039202853244318538240*Sqrt[3]) + 
         (13434096780078076150889395984373270322632987*PolyGamma[2, 1])/
          22058868208912891616534400 - 
         (130564726938310158104484392340611057917473107*Zeta[3])/
          257813022191669420768245800) + 
       (261129453902725515968018046219403728326797219*CF^2*NC*Zeta[3])/
        257813022191669420768245800 + (77792254001810468283439*CF*NM*NC*
         Zeta[3])/113400 - (520566959*CF*NC*NL*Zeta[3])/9 - 
       (537959528753944472528955881557*CF*NC*NH*Zeta[3])/
        196954180436722246576200 + CF*Log[x]*
        ((-101391882385871671670861565825792708383164557071*NM*NC)/
          10827200468922265176708960000 - (1019764087412897*lm*NM*NC)/
          55135080 - (7088235*lm^2*NM*NC)/2 - (2652018409917079648267*NC*
           NL)/26491303238400 - (1019764087412897*lm*NC*NL)/55135080 - 
         (7088235*lm^2*NC*NL)/2 - 
         (30996458485540784160557538813275319880756089890804339*NC*NH)/
          28979919305507556027457546713489602615520000 - 
         (1019764087412897*lm*NC*NH)/55135080 - (7088235*lm^2*NC*NH)/2 - 
         (3403730109526728445*NM*NC*Pi^2)/3 - (1561552867*NC*NL*Pi^2)/162 + 
         (7319516313049845908029021372*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4052555153018976267*Sqrt[3]) + 
         CF*NC*
          (-42164028134783650828393210409317102115346355976921786149647059720\
903/3034777149672751267195354291836631185897254400000 - (813503040971447*lm)/
            2042040 - (191382345*lm^2)/2 - (19503162702202247007399223*Pi^2)/
            11309760 + (29998315891410894645053631300709*
             Im[PolyLog[2, (-1)^(1/3)]])/(60626225089163884954320*Sqrt[3]) - 
           28352940*Zeta[3]) + CA*NC*(548132365762428139830868461887718860919\
743711697753172921723070298539/
            78904205891491532947079211587752410833328614400000 + 
           (1268461617093497*lm)/10024560 + (77970585*lm^2)/4 + 
           (19503162702382698384078247*Pi^2)/22619520 - 
           (29998315891410894645053631300709*Im[PolyLog[2, (-1)^(1/3)]])/
            (121252450178327769908640*Sqrt[3]) + 14176470*Zeta[3])), 
      (4898642878231664698048463110734052121159105916495428177394279400249653\
68541561397*CF^2*NC)/
        46242076578650577597890016315507269868958953828168825600000000 + 
       (6206450146671332957*CF^2*lm*NC)/102120670080 + 
       (189845397*CF^2*lm^2*NC)/4 + 
       (291497684368585628689193760594762314308376079353912555730743*CF*NM*
         NC)/17923563318207364683960343500643392000000 + 
       (11322500756555066477*CF*lm*NM*NC)/2757258092160 + 
       (7031311*CF*lm^2*NM*NC)/4 - (15324667511183288497519273699*CF*NC*NL)/
        118239057604802534400 + (11322500756555066477*CF*lm*NC*NL)/
        2757258092160 + (7031311*CF*lm^2*NC*NL)/4 - 
       (498918227006655498358721003837712902435738840125700244479986104930641\
531*CF*NC*NH)/
        105986421037936095342349456852008585550786329785440521408000000 + 
       (11322500756555066477*CF*lm*NC*NH)/2757258092160 + 
       (7031311*CF*lm^2*NC*NH)/4 - (1092718360241487204357435190966007581*
         CF^2*NC*Pi^2)/202426860094018560 - 88445*CF^2*lm*NC*Pi^2 - 
       (21247217359430870356167097*CF*NM*NC*Pi^2)/2625480 - 
       (88445*CF*lm*NM*NC*Pi^2)/27 + (8946629765713*CF*NC*NL*Pi^2)/
        1575288 - (88445*CF*lm*NC*NL*Pi^2)/27 - (88445*CF*lm*NC*NH*Pi^2)/
        27 + (15934516221991751370851992227053653*CF^2*NC*Pi^3)/
        (170238440050372188951730560*Sqrt[3]) + 
       (299291847282892334736265401575*CF*NC*NH*Pi^3)/(437675956526049436836*
         Sqrt[3]) + (20318346559*CF^2*NC*Pi^4)/10800 - 
       (107195475310278877430126077326475443126257*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(144847376716859176969579946976000*
         Sqrt[3]) - (12496511635269161770121473530340879*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3723965876101891633319106*Sqrt[3]) + 
       (2757031879*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (2276359460284535910121713175293379*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(656784105132608753671800*
         Sqrt[3]) + (34204782546616266827001760180*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) + (2276359460284535910121713175293379*CF^2*NC*Pi*Log[3]^2)/
        (31525637046365220176246400*Sqrt[3]) + 
       (8551195636654066706750440045*CF*NC*NH*Pi*Log[3]^2)/
        (16210220612075905068*Sqrt[3]) + 
       CF*((-61397112859312745628152037719974556162203*CF*NC)/
          947821600127722320000 + 
         CA*(61397112862144992382770036142728263927743/
            1895643200255444640000 - (6660475745*lm)/9)*NC + 
         3632986770*CF*lm*NC - (500834733207017651813347567827391*NM*NC)/
          5157269746200 + (1210995590*lm*NM*NC)/9 + (4587785657*NC*NL)/27 + 
         (1210995590*lm*NC*NL)/9 + (52939441008701492138867*NC*NH)/
          1335732864265800 + (1210995590*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-86962080799748611032670629*CA + 
          44*(3952821850972958651973097*CF + 232050*(25672418753970453012*
               NM + 86499685*NL)))*Log[x]^3)/9845550 - 
       (2448677700361842586202262161649484855916381*CF^2*NC*PolyGamma[2, 1])/
        787816721746888986304800 - (953430506572284439787*CF*NM*NC*
         PolyGamma[2, 1])/200 + (49946431146615536647401783005033*CF*NC*NH*
         PolyGamma[2, 1])/196954180436722246576200 + 
       CA*CF*NC*(-26942535829721672667613647592061362391720787772586457314724\
78878105429107641731371/
          508662842365156353576790179470579968558548492109857081600000000 - 
         (77344421*lm^2)/8 + (1437787316104976368015402670700793303*Pi^2)/
          532702263405312000 - (15934516221991751370851992227053653*Pi^3)/
          (340476880100744377903461120*Sqrt[3]) - (6791650453*Pi^4)/7200 + 
         lm*(-17491135941678037037/501319653120 + (972895*Pi^2)/54) + 
         (107195475310278877430126077326475443126257*
           Im[PolyLog[2, (-1)^(1/3)]])/(289694753433718353939159893952000*
           Sqrt[3]) - (2757031879*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
         (2276359460284535910121713175293379*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1313568210265217507343600*
           Sqrt[3]) - (2276359460284535910121713175293379*Pi*Log[3]^2)/
          (63051274092730440352492800*Sqrt[3]) + 
         (2448677700361842586202262161649484855916381*PolyGamma[2, 1])/
          1575633443493777972609600 - 
         (15658197485868698257455382690395161758952194*Zeta[3])/
          11969890316041794535668555) + 
       (626327899376016312925633647301005780655523773*CF^2*NC*Zeta[3])/
        239397806320835890713371100 + (1133195841703696402039*CF*NM*NC*
         Zeta[3])/300 + (1368958360*CF*NC*NL*Zeta[3])/9 - 
       (100983909892718784058643094525367*CF*NC*NH*Zeta[3])/
        98477090218361123288100 + CF*Log[x]*
        ((-9714981885333742542636596721737478256084333783*NM*NC)/
          186182018645488686901080000 + (13400055271385*lm*NM*NC)/262548 + 
         8756055*lm^2*NM*NC + (532166486483495031221*NC*NL)/1930080664512 + 
         (13400055271385*lm*NC*NL)/262548 + 8756055*lm^2*NC*NL + 
         (3793282296233231846134512589793516399831910631381115927*NC*NH)/
          762952106331535465415180412514755115012440000 + 
         (13400055271385*lm*NC*NH)/262548 + 8756055*lm^2*NC*NH - 
         (59902310426037612239*NM*NC*Pi^2)/9 + (684302290*NC*NL*Pi^2)/27 - 
         (34204782546616266827001760180*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4052555153018976267*Sqrt[3]) + CA*NC*(4992065587012133801551809673\
42282602920722056706801196362731336989797/
            28180073532675547481099718424197289583331648000000 - 
           (16325908561745*lm)/47736 - (96316605*lm^2)/2 + 
           (695696646349616130395058251*Pi^2)/315057600 + 
           (2276359460284535910121713175293379*Im[PolyLog[2, (-1)^(1/3)]])/
            (3940704630795652522030800*Sqrt[3]) - 35024220*Zeta[3]) + 
         CF*NC*(-499206558709062012902992038990096086087443990407236744876374\
055505997/14090036766337773740549859212098644791665824000000 + 
           (10973454725015*lm)/9724 + 236413485*lm^2 - 
           (695696646355865526487012123*Pi^2)/157528800 - 
           (2276359460284535910121713175293379*Im[PolyLog[2, (-1)^(1/3)]])/
            (1970352315397826261015400*Sqrt[3]) + 70048440*Zeta[3])), 
      (1862178640587525884192326601139477731670881262691690440060618493865182\
34168044888981*CF^2*NC)/
        3865837601975188287183605363976407761044968540034913820160000000 - 
       (996839341824293108833*CF^2*lm*NC)/44238674278656 - 
       (224573769*CF^2*lm^2*NC)/8 + 
       (213723249530817606754319831395052989081047881836262058860143687*CF*
         NM*NC)/6775106934282383850537009843243202176000000 - 
       (2307687053963887201297*CF*lm*NM*NC)/1194444205523712 - 
       (8317547*CF*lm^2*NM*NC)/8 + (21873101682484159464214007357609*CF*NC*
         NL)/275806244831387081011200 - (2307687053963887201297*CF*lm*NC*
         NL)/1194444205523712 - (8317547*CF*lm^2*NC*NL)/8 + 
       (157048220611067288198264241766543771404318998613720059592241262447897\
33*CF*NC*NH)/
        10093944860755818604033281604953198623884412360518144896000000 - 
       (2307687053963887201297*CF*lm*NC*NH)/1194444205523712 - 
       (8317547*CF*lm^2*NC*NH)/8 - (309183899290355690521780027547816695637*
         CF^2*NC*Pi^2)/12820367805954508800 + (100205*CF^2*lm*NC*Pi^2)/6 - 
       (50760496628264955639649422689*CF*NM*NC*Pi^2)/3142699560 + 
       (100205*CF*lm*NM*NC*Pi^2)/162 - (597669847929677*CF*NC*NL*Pi^2)/
        179582832 + (100205*CF*lm*NC*NL*Pi^2)/162 + 
       (100205*CF*lm*NC*NH*Pi^2)/162 - (7290466601355992485606806669281663*
         CF^2*NC*Pi^3)/(117619285852984421457559296*Sqrt[3]) - 
       (16724062831787671930453602985*CF*NC*NH*Pi^3)/(72945992754341572806*
         Sqrt[3]) - (15611719627*CF^2*NC*Pi^4)/12960 + 
       (517375954926026498962985174473297102213909*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1901451017992224104946122213030400*
         Sqrt[3]) + (66545838996725908458330972911467*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(40302660996773718975315*Sqrt[3]) - 
       (756222929*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (1041495228765141783658115238468809*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(453778109000711502536880*
         Sqrt[3]) - (3822642932980039298389394968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) - (1041495228765141783658115238468809*CF^2*NC*Pi*Log[3]^2)/
        (21781349232034152121770240*Sqrt[3]) - 
       (477830366622504912298674371*CF*NC*NH*Pi*Log[3]^2)/
        (2701703435345984178*Sqrt[3]) + 
       CF*((-6254017322983562862746818503422696200066927*CF*NC)/
          21610332482912068896000 - 2167546600*CF*lm*NC + 
         CA*(6254017322955400080399866901189312404211067/
            43220664965824137792000 + (11921506300*lm)/27)*NC - 
         (125948974653994127524983727971811463*NM*NC)/649815988021200 - 
         (2167546600*lm*NM*NC)/27 - (4185292336*NC*NL)/45 - 
         (2167546600*lm*NC*NL)/27 - (9820291564549149269293*NC*NH)/
          381637961218800 - (2167546600*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(2963966593844052599134955269*CA - 
          304*(19499780225024668192517176*CF + 
            12155*(1069163337110501893287*NM - 1083773300*NL)))*Log[x]^3)/
        74826180 - (463988392890369160320113461908287057369981581*CF^2*NC*
         PolyGamma[2, 1])/33088302313369337424801600 - 
       (699531891113156801581013*CF*NM*NC*PolyGamma[2, 1])/75600 - 
       (1105852808370653613956744190864983*CF*NC*NH*PolyGamma[2, 1])/
        8272075578342334356200400 + CA*CF*NC*
        (-2327723300741746946437739749963624690377009102176012440467826090775\
8303508695374857/
          966459400493797071795901340994101940261242135008728455040000000 + 
         (91493017*lm^2)/16 + (309183899290424635758470156257336662709*Pi^2)/
          25640735611909017600 + (7290466601355992485606806669281663*Pi^3)/
          (235238571705968842915118592*Sqrt[3]) + (15624545867*Pi^4)/25920 + 
         lm*(3888230706878613092689/217171673731584 - (1102255*Pi^2)/324) - 
         (517375954926026498962985174473297102213909*
           Im[PolyLog[2, (-1)^(1/3)]])/(3802902035984448209892244426060800*
           Sqrt[3]) + (756222929*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (1041495228765141783658115238468809*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(907556218001423005073760*
           Sqrt[3]) + (1041495228765141783658115238468809*Pi*Log[3]^2)/
          (43562698464068304243540480*Sqrt[3]) + 
         (463988392890369160320113461908287057369981581*PolyGamma[2, 1])/
          66176604626738674849603200 - 
         (2209542029153320416580205190474673473289634284619*Zeta[3])/
          382078898888054081578540275600) + 
       (552385507295885535924460163661972967808835653561*CF^2*NC*Zeta[3])/
        47759862361006760197317534450 + (298353890205194748650587*CF*NM*NC*
         Zeta[3])/37800 - (2453931755*CF*NC*NL*Zeta[3])/27 + 
       (31843940440573803299018042735017*CF*NC*NH*Zeta[3])/
        4136037789171167178100200 + CF*Log[x]*
        ((-383994152987711359073805109101882491324214354671*NM*NC)/
          3609066822974088392236320000 - (4153307179066801*lm*NM*NC)/
          149652360 - (10599435*lm^2*NM*NC)/2 - 
         (929280322404268061286967*NC*NL)/5923862962617600 - 
         (4153307179066801*lm*NC*NL)/149652360 - (10599435*lm^2*NC*NL)/2 - 
         (41108437091468095648117710511614203438637308383522993*NC*NH)/
          24535256356981969203209264966460894236640000 - 
         (4153307179066801*lm*NC*NH)/149652360 - (10599435*lm^2*NC*NH)/2 - 
         (356387779037482146370*NM*NC*Pi^2)/27 - (2453731345*NC*NL*Pi^2)/
          162 + (3822642932980039298389394968*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1350851717672992089*Sqrt[3]) + 
         CF*NC*(-167325158744642666949268771806072281876531631105919578267134\
70747667271/107084279424167080428178930011949700416660262400000 - 
           (3316129990569151*lm)/5542680 - (286184745*lm^2)/2 - 
           (23711732750954763594555936917*Pi^2)/1197218880 + 
           (1041495228765141783658115238468809*Im[PolyLog[2, (-1)^(1/3)]])/
            (1361334327002134507610640*Sqrt[3]) - 42397740*Zeta[3]) + 
         CA*NC*(1287116605731316353842434506016767018545390898803942827104308\
942552867/16474504526794935450489066155684569294870809600000 + 
           (5162726564241001*lm)/27209520 + (116593785*lm^2)/4 + 
           (878212324110546859563218143*Pi^2)/88682880 - 
           (1041495228765141783658115238468809*Im[PolyLog[2, (-1)^(1/3)]])/
            (2722668654004269015221280*Sqrt[3]) + 21198870*Zeta[3]))}, 0, 39, 
     1]
 
CbarLSeries["a", 2, 3, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-3*CA*(1159077970103966 + 3376313794560*lm + 
           1907490816000*lm^2 - 963789424282125*Zeta[3]) + 
         2*(35*CF*(-660472099990178 - 224036388864*lm + 401316249600*lm^2 + 
             549808396646355*Zeta[3]) + 3*(131072*(3728303 + 657930*lm + 
               1323000*lm^2)*NL + 35*NH*(-16417085090 + 2463891456*lm + 
               4954521600*lm^2 + 12911454675*Zeta[3]) + 
             35*NM*(2463891456*lm + 4954521600*lm^2 + 35*(-469059574 + 
                 368898705*Zeta[3]))))))/2621932830720000, 
      -(CF*NC*(-9*CA*(386734469345162 + 1549324779520*lm + 
            635830272000*lm^2 - 321263141427375*Zeta[3]) + 
          2*(1552264593408*NL + 605525114880*lm*NL + 520224768000*lm^2*
             NL - 2284328679850*NH + 605525114880*lm*NH + 
            520224768000*lm^2*NH + 1599290193375*NH*Zeta[3] + 
            35*NM*(-28308193918 + 17300717568*lm + 14863564800*lm^2 + 
              31774722525*Zeta[3]) + 35*CF*(-660546778786466 + 
              43507777536*lm + 401316249600*lm^2 + 549808396646355*Zeta[
                3]))))/873977610240000, 
      (CF*NC*(-(CA*(246104214360749838946 + 201492102740705280*lm + 
            67673959170048000*lm^2 - 204648797687510869875*Zeta[3])) + 
         2*(63*CF*(-41450228058636929762 + 1711479961681920*lm + 
             2636647759872000*lm^2 + 34484694168336282675*Zeta[3]) + 
           2*(131072*(79153795817 + 40006328670*lm + 23468697000*lm^2)*NL + 
             315*NH*(-59664173513518 + 16646696861696*lm + 9765362073600*
                lm^2 + 41577800573925*Zeta[3]) + 315*NM*(16646696861696*lm + 
               9765362073600*lm^2 + 2639*(-3198148754 + 8444742075*
                  Zeta[3]))))))/6229712405790720000, 
      -(CF*NC*(-2*CA*(217140914288462632138 + 68384189015654400*lm + 
            20085878292480000*lm^2 - 180604179130520415375*Zeta[3]) + 
          252*CF*(-38398446621127173962 + 842282473881600*lm + 
            782566686720000*lm^2 + 31944579375830122575*Zeta[3]) + 
          5*(524288*(10905874079 + 5939878140*lm + 2786238000*lm^2)*NL + 
            63*NM*(-28287528088542 + 49431854448640*lm + 23187161088000*lm^
                2 + 89678658502125*Zeta[3]) + 63*NH*(-188312961752258 + 
              49431854448640*lm + 23187161088000*lm^2 + 134904721903875*Zeta[
                3]))))/3114856202895360000, 
      (CF*NC*(-176*CA*(516502641346901973994294 + 49080934551630643200*lm + 
           13205692443525120000*lm^2 - 429651862838315699360625*Zeta[3]) + 
         2464*CF*(-1007236557346644657208934 + 6428927080444723200*lm + 
           4630567480197120000*lm^2 + 837931443538637976845625*Zeta[3]) + 
         5*(2097152*(184237947015449 + 98491484446740*lm + 40300575084000*
              lm^2)*NL + 3465*NH*(-253117978399092422 + 59610855293059072*
              lm + 24391466562355200*lm^2 + 187694104486113225*Zeta[3]) + 
           3465*NM*(59610855293059072*lm + 24391466562355200*lm^2 + 
             55*(-2409339505225178 + 3994775256166695*Zeta[3])))))/
       195986752286176051200000, 
      -(CF*NC*(-1367832491546072739726*NM + 156094673995715051520*lm*NM + 
          59879402338516992000*lm^2*NM + 320748094734945222656*NL + 
          156094673995715051520*lm*NL + 59879402338516992000*lm^2*NL - 
          705267542668360865886*NH + 156094673995715051520*lm*NH + 
          59879402338516992000*lm^2*NH - 88*CA*(579670810667081825639834 + 
            14519051401659678720*lm + 3742462646157312000*lm^2 - 
            482222902802614012722375*Zeta[3]) + 1545236310749073067125*NM*
           Zeta[3] + 538756812388956286125*NH*Zeta[3] + 
          1232*CF*(-1284973813136710227789034 + 2035708791588126720*lm + 
            1312292096704512000*lm^2 + 1068980165440741721526975*Zeta[3])))/
       39197350457235210240000, 
      (CF*NC*(-88*CA*(157812444730956158467325405386 + 
           684696444331890416025600*lm + 186583347504768614400000*lm^2 - 
           131284992669434608323143199375*Zeta[3]) + 
         208*CF*(-2364264157836820648279492998682 + 519807406762405291622400*
            lm + 387519260202211737600000*lm^2 + 
           1966848779554919157772493994375*Zeta[3]) + 
         5*(134217728*(28991049281841307 + 10662716134210140*lm + 
             4448493659610000*lm^2)*NL + 9009*NH*(-425367429555323537854 + 
             158855093111624826880*lm + 66274471308165120000*lm^2 + 
             334726867281321640125*Zeta[3]) + 3003*NM*
            (-22941824426477271969082 + 476565279334874480640*lm + 
             198823413924495360000*lm^2 + 21434914998166327032375*Zeta[3]))))/
       4239585425454560339558400000, 
      (CF*NC*(832*CF*(3075684211601738094766706449486 + 
           190935372355417512345600*lm + 21762165351257210880000*lm^2 - 
           2558684040950428382553179743125*Zeta[3]) - 
         352*CA*(-181904348625378516379495425118 + 116327778786556143206400*
            lm + 10478079613568286720000*lm^2 + 
           151327819460532354918191038125*Zeta[3]) + 
         5*(1073741824*(-225547204092701 + 1227760804850580*lm + 
             124908442659000*lm^2)*NL + 429*NM*(664269088376646275799446 + 
             3072956004745850388480*lm + 312632678446792704000*lm^2 - 
             569104682973459242234625*Zeta[3]) + 1287*NH*
            (1024318668248616796160*lm + 104210892815597568000*lm^2 + 
             5577*(-4089507041465450354 + 3245850763358308875*Zeta[3])))))/
       8479170850909120679116800000, 
      -(CF*NC*(-11*CA*(-23788160254086360922332473056094666 + 
            28847346325693638887079936000*lm + 5415600963051512974540800000*
             lm^2 + 19789583745799395591657316306959375*Zeta[3]) + 
          2*(CF*(5857340296996580147450067117647721554 + 
              438433981161899047960707072000*lm + 
              146221226002390850312601600000*lm^2 - 
              4872764130170206183863752876789590875*Zeta[3]) + 
            175*(8589934592*(21392748284329943 + 14604976189063260*lm + 
                3602622451428000*lm^2)*NL + 429*NM*(
                35735360344028167764204146 + 292437739351447154196480*lm + 
                72135876963723116544000*lm^2 - 29653058038992339153076875*
                 Zeta[3]) + 429*NH*(-4743425409127150371395198 + 
                292437739351447154196480*lm + 72135876963723116544000*lm^2 + 
                3820243655081792761948125*Zeta[3])))))/
       16144341300130965773038387200000, 
      (CF*NC*(-11*CA*(-6872810717577261695986519124392906 + 
           5865356243418685613958758400*lm + 1172344900864957344645120000*
            lm^2 + 5717549297692397048241533079279375*Zeta[3]) + 
         2*(7*CF*(269002396536070911770896244612810398 + 
             12095250718795215889917542400*lm + 4521901760479121186488320000*
              lm^2 - 223785066506916132604315470810394125*Zeta[3]) + 
           10*(4294967296*(186230633884421837 + 101823381032913540*lm + 
               27295781785272000*lm^2)*NL + 858*NM*
              (87463992781026697464277466 + 509706400354907172372480*lm + 
               136636934832745611264000*lm^2 - 72091747065582538277358375*
                Zeta[3]) + 3003*NH*(-2762594921789798595082154 + 
               145630400101402049249280*lm + 39039124237927317504000*lm^2 + 
               2248023590015500043121375*Zeta[3])))))/
       2306334471447280824719769600000, 
      -(CF*NC*(306*CF*(2012507889451810636638499218094351041694 + 
            43622023723048622551459273113600*lm + 
            17750106515609776242347212800000*lm^2 - 
            1674220117967836637425899096591939898125*Zeta[3]) - 
          99*CA*(-112891664692180565966507866735618448326 + 
            53486591211114006718946318745600*lm + 
            11175992991309859115551948800000*lm^2 + 
            93915475423769810426844510232693367625*Zeta[3]) + 
          35*(4294967296*(9848915591026978228463 + 4701361608044721399780*
               lm + 1338229872842302440000*lm^2)*NL + 
            7293*NM*(885441550369907874826209423482 + 
              2768708947377217731727196160*lm + 788105517398591463751680000*
               lm^2 - 731163755839055986723121220375*Zeta[3]) + 
            7293*NH*(-67181710320988088633559933038 + 
              2768708947377217731727196160*lm + 788105517398591463751680000*
               lm^2 + 55077802405505136364147165125*Zeta[3]))))/
       177297156158038266119507568230400000, 
      (CF*NC*(3264*CF*(764604823547322492911838040308391790098 + 
           6943942260093648185072182886400*lm + 
           3174183537527934857080995840000*lm^2 - 
           636080385556336394419176142184232634875*Zeta[3]) - 
         1056*CA*(-38980689390503097857192320828049843498 + 
           9025324734583173450410911334400*lm + 
           1998560005110181206310256640000*lm^2 + 
           32428334176200329498577417675466137375*Zeta[3]) + 
         385*(68719476736*(111363859641563071363 + 47038100586532735680*lm + 
             14503667918047308000*lm^2)*NL + 221*NM*
            (10404426700180241827115392665086 + 14626396646886263730607226880*
              lm + 4509884480004169849110528000*lm^2 - 
             8618103818957761569902532196125*Zeta[3]) + 
           21879*NH*(-4870261952227245305193497386 + 
             147741380271578421521285120*lm + 45554388686910806556672000*
              lm^2 + 4014448407796771691485113375*Zeta[3]))))/
       354594312316076532239015136460800000, 
      -(CF*NC*(2432*CF*(3453510762253443101012312820779474549726866 + 
            11417442036294580853805068404654080*lm + 
            6318477282709908336747158175744000*lm^2 - 
            2873001059854973018660067575007693145138875*Zeta[3]) - 
          64*CA*(-1976578813513711150868561726991641165331242 + 
            202255060616864815418895114814095360*lm + 
            48909694521717438606672446619648000*lm^2 + 
            1644330732192689255198392163224103379820575*Zeta[3]) + 
          21*(1924145348608*(109130153346524780685581 + 
              40318825683113398380960*lm + 14084942061107745828000*lm^2)*
             NL + 12597*NH*(6158552107604938768478833213440*lm + 
              2151423017567170408419950592000*lm^2 + 
              4199*(-70427228515236758253739903858 + 
                58276782384502374251873188875*Zeta[3])) + 
            4199*NM*(18475656322814816305436499640320*lm + 
              6454269052701511225259851776000*lm^2 - 
              5491*(-6181574979185528260562748652754 + 
                5131566551839787867499575758875*Zeta[3])))))/
       614441024381297415063765428459274240000, 
      (CF*NC*(-128*CA*(-2826163089301050773629207533062087243484638 + 
           114480981940013908729833178791936000*lm + 
           31934338240640246945344703692800000*lm^2 + 
           2351106034889448408809274463114140485158125*Zeta[3]) + 
         7*(4864*CF*(769217554126225714331004968290071715480634 + 
             740586388043335619838102994944000*lm + 
             589355524605117339387769651200000*lm^2 - 
             639917754455285988011473689883285149576375*Zeta[3]) + 
           25*(1099511627776*(28849765126264929425921 + 
               8930691496681179420195*lm + 3862489624534364323500*lm^2)*NL + 
             146965*NM*(375978084495894295499063357233574 + 
               66814541861539858374457294848*lm + 
               28897031635693464317224550400*lm^2 - 
               312492416704317146215970355929625*Zeta[3]) + 
             37791*NH*(259834329461543893678445035520*lm + 
               112377345249919027900317696000*lm^2 + 4199*
                (-4850088929391017946246199162 + 4024310162224403019630036375*
                  Zeta[3]))))))/1024068373968829025106275714098790400000, 
      CA*CF*NC*((1790305611869219*lm)/224956320124536000 + 
         (1867213*lm^2)/648997440 + 
         (-53822190025706123900464175028297699789051542 + 
           44775077231719097604397914098437268614454913*Zeta[3])/
          91443281863804850594783913764821401600) - 
       (CF*NC*(32*CF*(4497252453354504600104591229624860513244743304418 + 
            600883174682832279930681689862517555200*lm + 
            1372248284046515036060500126083317760000*lm^2 - 
            3741297473973303594304294902030230537592123181875*Zeta[3]) + 
          19635*(274877906944*(2000997282110326353636793 + 
              450023623889125491485280*lm + 301334022981890062164000*lm^2)*
             NL + 741*NM*(3879630656205840981468709787222821274 + 
              166938666410251946318527746539520*lm + 
              111781464950441476254729240576000*lm^2 - 
              3226374213486065808548981508160626375*Zeta[3]) + 
            4199*NH*(-4869419692686510824540026756534114 + 
              29459764660632696409151955271680*lm + 
              19726140873607319339069865984000*lm^2 + 
              4047965584251614093521021411717875*Zeta[3]))))/
        3109071583369364920222653068003927654400000, 
      (CF*NC*(128*CF*(3950681712043349478833233429995983961614237817482 - 
           387309023915113105810547405491902873600*lm + 
           451119317990005042727804402726338560000*lm^2 - 
           3286601244245832614609991285641984525907163011375*Zeta[3]) - 
         64*CA*(-92822240273840722155517793397437358201654748534 + 
           270121026457201501537097620101739315200*lm + 
           183789351773705758148364756666286080000*lm^2 + 
           77219505806766775080002600388093677813991548625*Zeta[3]) + 
         1155*(23089744183296*(386650439519570307835099 + 
             15798374028090760597920*lm + 80193011881710195468000*lm^2)*NL + 
           20995*NM*(8873784693699621722073633869910373442 + 
             17374632761164240858498870542336*lm + 
             88194147636899499948370191974400*lm^2 - 
             7381351440942488714771322435321617475*Zeta[3]) + 
           20995*NH*(17374632761164240858498870542336*lm + 
             88194147636899499948370191974400*lm^2 + 
             4199*(-7427160694409107985555654367742 + 
               6181960090854872634185295344925*Zeta[3])))))/
       6218143166738729840445306136007855308800000, 
      -(CF*NC*(CA*(79716795598107996157690170303496553334722856544375822 + 
            50082719073266791217438355832493601875558400*lm - 
            57850713096957124279609560707902759501824000*lm^2 - 
            66316989545033501401843954132968810585534483676003125*Zeta[3]) + 
          2*(23*CF*(159160340590286311756710926632266226920035212626356446 - 
              19719128879376963144422997812348314032537600*lm + 
              6173791516276056741302206083452073148416000*lm^2 - 
              132406660793289531359590858704580369099814871258742125*Zeta[
                3]) + 2310*(28587302322176*(66412205733995890377473087 - 
                170306068986007783651662840*lm + 79639931364799221222206400*
                 lm^2)*NL + 334305*NM*(-14563321163022887384983150461452288*
                 lm + 6810220591504350918561126395412480*lm^2 + 
                69*(32291268476703484615217095452716790466 - 
                  26862685877103603879254953703918940675*Zeta[3])) + 
              37145*NH*(-131069890467205986464848354153070592*lm + 
                61291985323539158267050137558712320*lm^2 + 37145*
                 (-913377037962802557243979536253934 + 
                  760841880197423734430032116409605*Zeta[3]))))))/
       52630363763276609369529071135170487333683200000, 
      (CF*NC*(CA*(11247588324924653564392273104472554758983372284248078 + 
           15773778784045126055368572474779226655948800*lm - 
           2442775095159594022077481009872019390464000*lm^2 - 
           9356951594243948643112141046882012021455244673187125*Zeta[3]) + 
         10*(23*CF*(4831490301631064098705900002054135957633151121636806 - 
             458066207485753625922460951730932930314240*lm + 
             52138282663485406004815800210707133235200*lm^2 - 
             4019352403064680598316198472682726185515669398001225*Zeta[3]) + 
           21*(140737488355328*(-149663541815472688474366964 - 
               116164603400904582924995595*lm + 15027671852479108240768350*
                lm^2)*NL + 37145*NM*
              (75136411946855620707223299502799741670698 - 
               440132306324837908891861518183825408*lm + 
               56937859532803038101589267515965440*lm^2 - 
               62506618045117105333164067964191666636575*Zeta[3]) + 
             334305*NH*(-48903589591648656543540168687091712*lm + 
               6326428836978115344621029723996160*lm^2 + 7429*
                (-896452130693051068308997012051658 + 
                 747073917774763480848513461669775*Zeta[3]))))))/
       4784578523934237215411733739560953393971200000}, 0, 18, 1]
 
CbarLSeries["a", 2, 4, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(3*CF*(-21946982400*lm^2 + 758015568*Pi^2 + 8467200*Pi^4 + 
            5080320*lm*(-6499 + 240*Pi^2) - 35*(763887201 + 170003328*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 104509440*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 28333888*PolyGamma[2, 1] - 
              576208256*Zeta[3])) + 60*CA*(167650560*lm^2 - 49399236*Pi^2 + 
            1143072*Pi^4 - 3528*lm*(-189389 + 2640*Pi^2) + 
            7*(107513337 + 21250416*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              13063680*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3541736*PolyGamma[2, 
                1] - 55543504*Zeta[3])) + 
          280*(9*NL*(-1868447 - 725760*lm^2 - 81936*Pi^2 + 168*lm*(-11719 + 
                240*Pi^2) - 483840*Zeta[3]) + 9*NM*(-1868447 - 725760*lm^2 - 
              81936*Pi^2 + 168*lm*(-11719 + 240*Pi^2) + 40320*PolyGamma[2, 
                1] - 403200*Zeta[3]) + NH*(259270353 - 6531840*lm^2 + 
              1512*lm*(-11719 + 240*Pi^2) - 4036636608*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 672772768*PolyGamma[2, 1] + 
              7038406976*Zeta[3]))))/576108288000, 
      (CF*NC*(-80*CA*(2640496320*lm^2 - 1125368073*Pi^2 + 37292724*Pi^4 - 
           79380*lm*(-100229 + 1848*Pi^2) - 14*(251836254 + 97053738*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 213101280*Im[PolyLog[2, 
                 (-1)^(1/3)]]^2 - 18063733*PolyGamma[2, 1] - 
             158447834*Zeta[3])) - 47040*(NH*(304716771 - 816480*lm^2 + 
             270*lm*(-5263 + 168*Pi^2) + 226315104*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 37719184*PolyGamma[2, 1] - 
             659312288*Zeta[3]) + 9*NL*(130649 - 90720*lm^2 - 9072*Pi^2 + 
             30*lm*(-5263 + 168*Pi^2) - 60480*Zeta[3]) + 
           9*NM*(130649 - 90720*lm^2 - 9072*Pi^2 + 30*lm*(-5263 + 168*
                Pi^2) + 5040*PolyGamma[2, 1] - 50400*Zeta[3])) + 
         CF*(1382659891200*lm^2 - 39095186544*Pi^2 + 2552860800*Pi^4 - 
           457228800*lm*(-1609 + 168*Pi^2) - 35*(-26593798239 + 
             6211439232*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             13638481920*Im[PolyLog[2, (-1)^(1/3)]]^2 - 1156078912*
              PolyGamma[2, 1] + 3556233856*Zeta[3]))))/1728324864000, 
      -(CF*NC*(CF*(4740548198400*lm^2 + 262328799312*Pi^2 - 
            31777401600*Pi^4 + 1097349120*lm*(-259 + 60*Pi^2) + 
            35*(66888225261 + 96152989440*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 121335459840*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              10571236352*PolyGamma[2, 1] - 287599554304*Zeta[3])) + 
          560*CA*(4243735755 - 1293304320*lm^2 - 296012394*Pi^2 + 
            30985416*Pi^4 - 27216*lm*(115051 + 660*Pi^2) - 3004780920*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 3791733120*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 330351136*PolyGamma[2, 1] + 
            7597423040*Zeta[3]) + 3360*(27*NL*(-3443083 + 1451520*lm^2 + 
              596592*Pi^2 + 336*lm*(4961 + 60*Pi^2) - 241920*Zeta[3]) + 
            27*NM*(-5596675 + 1451520*lm^2 + 898992*Pi^2 + 336*lm*(4961 + 
                60*Pi^2) + 40320*PolyGamma[2, 1] - 161280*Zeta[3]) + 
            NH*(-9166528257 + 39191040*lm^2 + 9072*lm*(4961 + 60*Pi^2) - 
              25653766592*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              4387756560*PolyGamma[2, 1] + 53893109280*Zeta[3]))))/
       1728324864000, (CF*NC*(740710656000*(-14*CA*(76 + 33*lm) + 
           27*CF*(179 + 112*lm) + 28*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 
             3*lm*NH))*Log[x]^2 + 20739898368000*(11*CA + 36*CF - 
           2*(NM + NL))*Log[x]^3 + 846720*Log[x]*
          (12*(729*NM*(45743 + 37000*lm + 8400*lm^2 + 4200*Pi^2) + 
             729*NL*(70943 + 37000*lm + 8400*lm^2 + 4200*Pi^2) + 
             NH*(1465911399 + 26973000*lm + 6123600*lm^2 - 836208800*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]])) + 2*CA*(-2044181037 - 
             1147300200*lm - 202078800*lm^2 + 7064010*Pi^2 - 
             1412560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             110224800*Zeta[3]) + 5*CF*(1532268069 + 1691163360*lm + 
             529079040*lm^2 - 21170160*Pi^2 + 1130048*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 88179840*Zeta[3])) - 
         80*CA*(7984860871680*lm^2 - 1337804930169*Pi^2 - 2422540400*Sqrt[3]*
            Pi^3 + 39643451568*Pi^4 - 15002820*lm*(-2020091 + 6600*Pi^2) - 
           1868816880*Sqrt[3]*Pi*Log[3]^2 + 7*(3251789551557 - 
             1315380392724*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             1855480193280*Im[PolyLog[2, (-1)^(1/3)]]^2 - 12814744320*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 236650358822*
              PolyGamma[2, 1] + 2499132814444*Zeta[3])) + 
         7*(-6720*(243*NL*(-20274007 - 10160640*lm^2 - 4338720*Pi^2 + 1050*
                lm*(-24413 + 120*Pi^2) - 17841600*Zeta[3]) + 
             1215*NM*(2173105 - 2032128*lm^2 - 777024*Pi^2 + 210*lm*
                (-24413 + 120*Pi^2) - 240912*PolyGamma[2, 1] - 784224*
                Zeta[3]) - NH*(-350877255237 + 2469035520*lm^2 + 14633654000*
                Sqrt[3]*Pi^3 - 255150*lm*(-24413 + 120*Pi^2) - 208131997920*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 541863302400*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 11288818800*Sqrt[3]*
                Pi*Log[3]^2 + 42893490832*PolyGamma[2, 1] + 225796972064*
                Zeta[3])) + CF*(597309072998400*lm^2 - 27985688903664*Pi^2 - 
             55372352000*Sqrt[3]*Pi^3 + 576931299840*Pi^4 - 
             12345177600*lm*(-63601 + 600*Pi^2) - 42715814400*Sqrt[3]*Pi*
              Log[3]^2 + 5*(122949814718025 - 42092172567168*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 59375366184960*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 410071818240*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 7572811482304*
                PolyGamma[2, 1] + 49733906543744*Zeta[3])))))/46664771328000, 
      (-2*CF*NC*(-70*CA*(76 + 33*lm) + 108*CF*(191 + 140*lm) + 
          35*(23*NM + 12*lm*NM + 20*NL + 12*lm*NL + 12*lm*NH))*Log[x]^2)/
        315 - (8*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       (CF*NC*Log[x]*(2*(-2*(8748*NL*(91927 + 49605*lm + 12600*lm^2 + 
                6300*Pi^2) + 10935*NM*(37579 + 39684*lm + 10080*lm^2 + 
                6720*Pi^2) + NH*(13780943877 + 433944540*lm + 110224800*
                 lm^2 - 7871393600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            9*CF*(-2124251733 - 2406049920*lm - 881798400*lm^2 + 
              58305420*Pi^2 + 150128240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              146966400*Zeta[3])) - 9*CA*(-2596078353 - 1403674920*lm - 
            269438400*lm^2 + 37805940*Pi^2 + 150128240*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 146966400*Zeta[3])))/165337200 + 
       (CF*NC*(-288*CA*(-2407001002560*lm^2 + 200730671964*Pi^2 - 
            64367482900*Sqrt[3]*Pi^3 + 4526565120*Pi^4 + 
            1786050*lm*(-4521953 + 2640*Pi^2) - 49654915380*Sqrt[3]*Pi*
             Log[3]^2 + 7*(-253770197553 + 112198051488*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 804200140800*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 340490848320*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 38127433670*PolyGamma[2, 1] + 
              171499340180*Zeta[3])) + 9*CF*(-504157300899840*lm^2 + 
            19516120644240*Pi^2 - 4119518905600*Sqrt[3]*Pi^3 + 
            333594132480*Pi^4 + 4115059200*lm*(-107119 + 240*Pi^2) - 
            3177914584320*Sqrt[3]*Pi*Log[3]^2 + 7*(-41938450022727 + 
              7180675295232*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              51468809011200*Im[PolyLog[2, (-1)^(1/3)]]^2 - 21791414292480*
               Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              2440155754880*PolyGamma[2, 1] + 32126329095680*Zeta[3])) + 
          112*(2187*NL*(-449799119 - 514563840*lm^2 - 252778320*Pi^2 + 
              840*lm*(-1275791 + 1200*Pi^2) - 926553600*Zeta[3]) + 
            2187*NM*(1432859113 - 514563840*lm^2 - 329164560*Pi^2 + 
              840*lm*(-1275791 + 1200*Pi^2) - 103029264*PolyGamma[2, 1] + 
              86664672*Zeta[3]) - NH*(-131318581201515 + 1125351118080*lm^
                2 + 3856982864000*Sqrt[3]*Pi^3 - 1837080*lm*(-1275791 + 
                1200*Pi^2) - 159337547171520*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 142818565478400*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 2975386780800*Sqrt[3]*Pi*Log[3]^
                2 + 29952399742192*PolyGamma[2, 1] + 281828766409184*Zeta[
                3]))))/27998862796800, (321984371001611*CF^2*NC)/
        317447424000 + (242857*CF^2*lm*NC)/140 + (6408*CF^2*lm^2*NC)/5 - 
       (13689341*CF*NM*NC)/151200 + (459661*CF*lm*NM*NC)/5040 + 
       (178*CF*lm^2*NM*NC)/5 + (3487627*CF*NC*NL)/50400 + 
       (459661*CF*lm*NC*NL)/5040 + (178*CF*lm^2*NC*NL)/5 - 
       (28199608755439*CF*NC*NH)/4960116000 + (459661*CF*lm*NC*NH)/5040 + 
       (178*CF*lm^2*NC*NH)/5 - (526132611*CF^2*NC*Pi^2)/5488000 - 
       10*CF^2*lm*NC*Pi^2 + (6533*CF*NM*NC*Pi^2)/540 - 
       (5*CF*lm*NM*NC*Pi^2)/18 + (10709*CF*NC*NL*Pi^2)/540 - 
       (5*CF*lm*NC*NL*Pi^2)/18 - (5*CF*lm*NC*NH*Pi^2)/18 + 
       (110182481*CF^2*NC*Pi^3)/(4251528*Sqrt[3]) + 
       (1847482315*CF*NC*NH*Pi^3)/(2125764*Sqrt[3]) + 
       (100381*CF^2*NC*Pi^4)/37800 - (5634137988151*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3472081200*Sqrt[3]) - 
       (50767392044*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6200145*Sqrt[3]) + 
       (27214*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
       (220364962*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (229635*Sqrt[3]) + (211140836*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) + 
       (110182481*CF^2*NC*Pi*Log[3]^2)/(5511240*Sqrt[3]) + 
       (52785209*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) + 
       (CF*NC*(-6*CA*(16133 + 8085*lm) + CF*(473091 + 317520*lm) + 
          14*(7*(179 + 90*lm)*NM + 945*NL + 630*lm*NL + 8*NH + 
            630*lm*NH))*Log[x]^2)/210 + 14*CF*NC*(13*CA + 46*CF - 
         2*(2*NM + NL))*Log[x]^3 + (2310057164783*CF^2*NC*PolyGamma[2, 1])/
        20832487200 + (1186*CF*NM*NC*PolyGamma[2, 1])/225 + 
       (172734596567*CF*NC*NH*PolyGamma[2, 1])/279006525 + 
       (6831061666697*CF^2*NC*Zeta[3])/10416243600 - 
       (19828*CF*NM*NC*Zeta[3])/225 + (304*CF*NC*NL*Zeta[3])/3 + 
       (262635255934*CF*NC*NH*Zeta[3])/279006525 - 
       (CF*NC*Log[x]*(2*(-4*(15309*NL*(1408403 + 701460*lm + 151200*lm^2 + 
                88200*Pi^2) + 2187*NM*(8406683 + 4910220*lm + 1058400*lm^2 + 
                289800*Pi^2) + NH*(518718690717 + 10738651140*lm + 
                2314720800*lm^2 - 295597170400*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) + 5*CF*(-208157226105 - 228720868992*lm - 
              66663959040*lm^2 + 3959904672*Pi^2 + 7051678784*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 11110659840*Zeta[3])) + 
          5*CA*(227940529215 + 120425002992*lm + 20369543040*lm^2 - 
            1657676016*Pi^2 - 7051678784*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            11110659840*Zeta[3])))/661348800 - 
       (CA*CF*NC*(2741088667806720*lm^2 - 564105839771448*Pi^2 + 
          60468145572800*Sqrt[3]*Pi^3 + 21699303845184*Pi^4 - 
          1388832480*lm*(-7568207 + 15400*Pi^2) + 46646855156160*Sqrt[3]*Pi*
           Log[3]^2 + 21*(304757192946279 - 180292415620832*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 259170425902080*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 106621383214080*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 36960914636528*
             PolyGamma[2, 1] + 340525832483296*Zeta[3])))/13999431398400, 
      -(CF*NC*(-21*CA*(129951 + 49390*lm) + CF*(10268581 + 6788880*lm) + 
           42*(14721*NM + 4490*lm*NM + 6515*NL + 4490*lm*NL + 72*NH + 
             4490*lm*NH))*Log[x]^2)/2835 - 
       (4*CF*NC*(4435*CA + 24718*CF - 1472*NM - 898*NL)*Log[x]^3)/81 + 
       (CF*NC*Log[x]*(4*(-2*(10935*NL*(12081847 + 6142092*lm + 
                1451520*lm^2 + 861000*Pi^2) + 2187*NM*(53025161 + 
                30710460*lm + 7257600*lm^2 + 4615800*Pi^2) + 
              NH*(2053408835967 + 67163776020*lm + 15872371200*lm^2 - 
                1170101178400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            3*CF*(-1070886503679 - 1151631859680*lm - 380936908800*lm^2 + 
              19514163600*Pi^2 + 99617668480*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 63489484800*Zeta[3])) + 
          CA*(7722085811409 + 3844058932080*lm + 698384332800*lm^2 - 
            51568935120*Pi^2 - 597706010880*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 380936908800*Zeta[3])))/2976069600 - 
       (CF*NC*(-60*CA*(5752033041807360*lm^2 - 650680553061432*Pi^2 + 
            341688602886400*Sqrt[3]*Pi^3 + 24113927994912*Pi^4 - 
            925888320*lm*(-21430559 + 14300*Pi^2) + 263588350798080*Sqrt[3]*
             Pi*Log[3]^2 - 7*(-508856139893025 + 631502990982048*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 2140113077061120*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 1807462976901120*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 204754126790528*PolyGamma[2, 1] + 
              151982697488384*Zeta[3])) + 3*CF*(752993416382054400*lm^2 - 
            40605313836618288*Pi^2 + 13667544115456000*Sqrt[3]*Pi^3 + 
            887523211572480*Pi^4 - 1333279180800*lm*(-547009 + 1300*Pi^2) + 
            10543534031923200*Sqrt[3]*Pi*Log[3]^2 - 
            35*(-9774979202407797 + 5052023927856384*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 17120904616488960*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 14459703815208960*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                   Sqrt[3])]] - 1638033014324224*PolyGamma[2, 1] + 
              8470890129262336*Zeta[3])) - 
          224*(492075*NL*(-476848939 - 569286144*lm^2 - 344083440*Pi^2 + 
              1008*lm*(-1229437 + 1300*Pi^2) - 1751500800*Zeta[3]) + 
            295245*NM*(3088796627 - 948810240*lm^2 - 751586000*Pi^2 + 
              1680*lm*(-1229437 + 1300*Pi^2) - 344670576*PolyGamma[2, 1] + 
              2832207648*Zeta[3]) - NH*(-35966019264400647 + 
              280131479308800*lm^2 + 1433373943540000*Sqrt[3]*Pi^3 - 
              496011600*lm*(-1229437 + 1300*Pi^2) - 29031010406846400*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 53075789452224000*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1105745613588000*Sqrt[
                3]*Pi*Log[3]^2 + 5940397800389120*PolyGamma[2, 1] + 
              39647842416202240*Zeta[3]))))/1259948825856000, 
      (CF*NC*(197519507515929123063*CF + 527057991986457254400*CF*lm + 
         386744819953211596800*CF*lm^2 - 68449302734725281600*NM + 
         27621518039720035200*lm*NM + 10742911665366988800*lm^2*NM + 
         15678159304918904640*NL + 27621518039720035200*lm*NL + 
         10742911665366988800*lm^2*NL - 2138330218340526116544*NH + 
         27621518039720035200*lm*NH + 10742911665366988800*lm^2*NH - 
         41155839713345240016*CF*Pi^2 - 2263708057121280000*CF*lm*Pi^2 - 
         7736844982142707200*NM*Pi^2 - 62880779364480000*lm*NM*Pi^2 + 
         7298781663433075200*NL*Pi^2 - 62880779364480000*lm*NL*Pi^2 - 
         62880779364480000*lm*NH*Pi^2 + 6040091489377792000*Sqrt[3]*CF*
          Pi^3 + 113513498443477440000*Sqrt[3]*NH*Pi^3 + 
         1265960765008114560*CF*Pi^4 - 190294059757766321280*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] - 878867023881582489600*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 274807690397217331200*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 223655959149531955200*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 4203242685221336064000*
          Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         4659499148948582400*Sqrt[3]*CF*Pi*Log[3]^2 + 87567555942111168000*
          Sqrt[3]*NH*Pi*Log[3]^2 + 7333035494400*
          (-3*CA*(10512217 + 5621770*lm) + 7*CF*(23197813 + 15770160*lm) + 
           6*((-1601687 + 511070*lm)*NM + 245*(2951 + 2086*lm)*NL + 
             2*(8019 + 255535*lm)*NH))*Log[x]^2 + 7186374784512000*
          (14509*CA + 63502*CF - 12392*NM - 2086*NL)*Log[x]^3 + 
         43941696968372477120*CF*PolyGamma[2, 1] - 5916779950438748160*NM*
          PolyGamma[2, 1] + 210749098337322209280*NH*PolyGamma[2, 1] + 
         332640*Log[x]*(2*(-108*(-1701*NM*(371696261 + 430385340*lm + 
                 88905600*lm^2 - 107826600*Pi^2) - 1701*NL*(914128031 + 
                 430385340*lm + 88905600*lm^2 + 60299400*Pi^2) - 5*NH*
                (6852263918865 + 146417092668*lm + 30245685120*lm^2 - 
                 3900003382240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
             7*CF*(-276573525009519 - 305125305428160*lm - 83996588390400*
                lm^2 + 5921233740720*Pi^2 + 16008723799040*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 13999431398400*Zeta[3])) + 
           35*CA*(-61025395394445 - 31382140284432*lm - 5133124846080*lm^2 + 
             559200328560*Pi^2 + 3201744759808*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 2799886279680*Zeta[3])) + 
         223501689357331960960*CF*Zeta[3] - 70462058642864824320*NM*
          Zeta[3] + 44972333401476096000*NL*Zeta[3] - 44854408591477309440*
          NH*Zeta[3] - 154*CA*(540894642961622859 + 383675416620249600*
            lm^2 - 107693354060562600*Pi^2 + 19610686653824000*Sqrt[3]*Pi^3 + 
           4436915623348320*Pi^4 - 229157359200*lm*(-6435739 + 9800*Pi^2) - 
           617837856356384160*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           892232761029926400*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           726155711524454400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           15128243990092800*Sqrt[3]*Pi*Log[3]^2 + 142667847299910640*
            PolyGamma[2, 1] + 1157340705772467680*Zeta[3])))/
       41578311253248000, (-15693492281544071*CF^2*NC)/4285540224000 - 
       (623935*CF^2*lm*NC)/56 - (55596*CF^2*lm^2*NC)/5 + 
       (6819092767*CF*NM*NC)/6048000 - (6881671*CF*lm*NM*NC)/10080 - 
       (4633*CF*lm^2*NM*NC)/15 - (1016006293*CF*NC*NL)/10886400 - 
       (6881671*CF*lm*NC*NL)/10080 - (4633*CF*lm^2*NC*NL)/15 + 
       (2508428477678609341*CF*NC*NH)/52497867744000 - 
       (6881671*CF*lm*NC*NH)/10080 - (4633*CF*lm^2*NC*NH)/15 + 
       (10052682707*CF^2*NC*Pi^2)/39293100 + (70*CF^2*lm*NC*Pi^2)/3 - 
       (1875407*CF*NM*NC*Pi^2)/6480 + (35*CF*lm*NM*NC*Pi^2)/54 - 
       (1440947*CF*NC*NL*Pi^2)/6480 + (35*CF*lm*NC*NL*Pi^2)/54 + 
       (35*CF*lm*NC*NH*Pi^2)/54 - (228822642833*CF^2*NC*Pi^3)/
        (229582512*Sqrt[3]) - (91322311535*CF*NC*NH*Pi^3)/
        (14348907*Sqrt[3]) - (4043*CF^2*NC*Pi^4)/135 + 
       (142597553140817*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (13392313200*Sqrt[3]) + (60629796941827*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(669615660*Sqrt[3]) - 
       9936*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (228822642833*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6200145*Sqrt[3]) - (41747342416*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (228822642833*CF^2*NC*Pi*Log[3]^2)/(297606960*Sqrt[3]) - 
       (2609208901*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) - 
       (CF*NC*(-5*CA*(10376447 + 3001152*lm) + CF*(175201333 + 98219520*lm) + 
          24*(70*(6037 + 1624*lm)*NM + 245*(629 + 464*lm)*NL + 
            (4359 + 113680*lm)*NH))*Log[x]^2)/3780 - 
       (56*CF*NC*(2430*CA + 27161*CF - 2364*NM - 696*NL)*Log[x]^3)/81 - 
       (532521599326513*CF^2*NC*PolyGamma[2, 1])/337486292640 - 
       (18712243*CF*NM*NC*PolyGamma[2, 1])/264600 - 
       (462506810182471*CF*NC*NH*PolyGamma[2, 1])/70309644300 + 
       (CA*CF*NC*(53799983769177639 + 229324185757497600*lm^2 + 
          2767079487870900*Pi^2 + 22424618997634000*Sqrt[3]*Pi^3 + 
          2091415054982400*Pi^4 - 11160261000*lm*(-71571387 + 43120*Pi^2) - 
          239563889276572560*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          670652760734208000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          830351606312390400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          17298991798174800*Sqrt[3]*Pi*Log[3]^2 + 106504319865302600*
           PolyGamma[2, 1] - 93858217978454000*Zeta[3]))/134994517056000 + 
       (976915977210587*CF^2*NC*Zeta[3])/168743146320 + 
       (285783557*CF*NM*NC*Zeta[3])/132300 - (12614*CF*NC*NL*Zeta[3])/9 - 
       (1093173903309871*CF*NC*NH*Zeta[3])/35154822150 + 
       (CF*NC*Log[x]*(-78884546379597*NM - 23340164779260*lm*NM - 
          5249786774400*lm^2*NM - 49029976050867*NL - 23340164779260*lm*
           NL - 5249786774400*lm^2*NL - 719529320564499*NH - 
          23340164779260*lm*NH - 5249786774400*lm^2*NH - 
          245360404800*NM*Pi^2 - 3629482214400*NL*Pi^2 + 
          409123955676800*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          14*CF*(-46929946810893 - 43705729097640*lm - 13499451705600*lm^2 + 
            173000480805*Pi^2 + 4576452856660*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2249908617600*Zeta[3]) + 
          35*CA*(11062777974024 + 4717697534478*lm + 824966493120*lm^2 + 
            58908404331*Pi^2 - 915290571332*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 449981723520*Zeta[3])))/15624365400, 
      (CF*NC*(220929336632821975389*CF + 1960066905075371030400*CF*lm + 
         1434751102078079385600*CF*lm^2 - 460228604647376254536*NM + 
         102603457965362508000*lm*NM + 39854197279946649600*lm^2*NM + 
         25895021761789598880*NL + 102603457965362508000*lm*NL + 
         39854197279946649600*lm^2*NL - 9970313417098631613720*NH + 
         102603457965362508000*lm*NH + 39854197279946649600*lm^2*NH - 
         244895808041311845096*CF*Pi^2 - 6791124171363840000*CF*lm*Pi^2 - 
         248451076065438892800*NM*Pi^2 - 188642338093440000*lm*NM*Pi^2 + 
         31908671829135763200*NL*Pi^2 - 188642338093440000*lm*NL*Pi^2 - 
         188642338093440000*lm*NH*Pi^2 + 37558154471703096000*Sqrt[3]*CF*
          Pi^3 + 531988281669115040000*Sqrt[3]*NH*Pi^3 + 
         6447471729168476160*CF*Pi^4 - 814661794651153716960*Sqrt[3]*CF*
          Im[PolyLog[2, (-1)^(1/3)]] - 3659256917684038809600*Sqrt[3]*NH*
          Im[PolyLog[2, (-1)^(1/3)]] + 1165124069263016755200*CF*
          Im[PolyLog[2, (-1)^(1/3)]]^2 + 1390724805580777497600*Sqrt[3]*CF*
          Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 19698766086947802624000*
          Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
         28973433449599531200*Sqrt[3]*CF*Pi*Log[3]^2 + 410390960144745888000*
          Sqrt[3]*NH*Pi*Log[3]^2 - 1374944155200*
          (CA*(782372755 + 522485040*lm) - 12*(45*CF*(8682425 + 6333152*lm) - 
             163255593*NM + 7916440*lm*NM + 10831450*NL + 7916440*lm*NL + 
             416695*NH + 7916440*lm*NH))*Log[x]^2 + 10779562176768000*
          (62933*CA + 301761*CF - 122212*NM - 8078*NL)*Log[x]^3 + 
         194811818811493194080*CF*PolyGamma[2, 1] - 177317955945106986240*NM*
          PolyGamma[2, 1] + 908024642124720736000*NH*PolyGamma[2, 1] + 
         83160*Log[x]*(-8*(-275562*NL*(3010524319 + 1334326560*lm + 
               266716800*lm^2 + 207652200*Pi^2) + 964467*NM*
              (1923896329 - 381236160*lm - 76204800*lm^2 + 448323600*Pi^2) - 
             NH*(17361233576088693 + 367689695526720*lm + 73497014841600*
                lm^2 - 9869912461393600*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]])) + 21*CA*(-1768849076125911 - 
             966389496871680*lm - 153993745382400*lm^2 + 27477148348080*
              Pi^2 + 132726051671360*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             83996588390400*Zeta[3]) - 42*CF*(-1579443129867009 - 
             1912325503495680*lm - 503979530342400*lm^2 + 48196900771920*
              Pi^2 + 132726051671360*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             83996588390400*Zeta[3])) + 949989714466617119680*CF*Zeta[3] - 
         418412421540334932480*NM*Zeta[3] + 230671851020658432000*NL*
          Zeta[3] - 1076279720772241216000*NH*Zeta[3] - 
         7*CA*(31314012148529510400*lm^2 - 14633574868581122340*Pi^2 + 
           2682725319407364000*Sqrt[3]*Pi^3 + 482092819294141440*Pi^4 - 
           343736038800*lm*(-350475907 + 431200*Pi^2) + 2069530960685680800*
            Sqrt[3]*Pi*Log[3]^2 + 11*(405243667722028779 - 
             5290011653578920240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             7565740709500108800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             9030680555719334400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] + 1265011810464241520*PolyGamma[2, 1] + 
             10030204778912873440*Zeta[3]))))/31183733439936000, 
      (-6828519277537993163*CF^2*NC)/492167510100000 - 
       (791696491*CF^2*lm*NC)/15750 - (246784*CF^2*lm^2*NC)/5 - 
       (132959453359*CF*NM*NC)/61740000 - (1731018091*CF*lm*NM*NC)/567000 - 
       (61696*CF*lm^2*NM*NC)/45 + (1454619319*CF*NC*NL)/1822500 - 
       (1731018091*CF*lm*NC*NL)/567000 - (61696*CF*lm^2*NC*NL)/45 + 
       (611571969310164259*CF*NC*NH)/2362404048480 - 
       (1731018091*CF*lm*NC*NH)/567000 - (61696*CF*lm^2*NC*NH)/45 - 
       (18439981390289*CF^2*NC*Pi^2)/1571724000 + (4144*CF^2*lm*NC*Pi^2)/45 - 
       (125977862*CF*NM*NC*Pi^2)/42525 + (1036*CF*lm*NM*NC*Pi^2)/405 - 
       (6966311*CF*NC*NL*Pi^2)/6075 + (1036*CF*lm*NC*NL*Pi^2)/405 + 
       (1036*CF*lm*NC*NH*Pi^2)/405 - (5504994911381*CF^2*NC*Pi^3)/
        (860934420*Sqrt[3]) - (1558853630789*CF*NC*NH*Pi^3)/
        (43046721*Sqrt[3]) - (821539*CF^2*NC*Pi^4)/4050 + 
       (5847159259772251*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (100442349000*Sqrt[3]) + (627593615283644*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1506635235*Sqrt[3]) - 
       (245656*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (3145711377932*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (13286025*Sqrt[3]) - (3563094013232*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (786427844483*CF^2*NC*Pi*Log[3]^2)/(159432300*Sqrt[3]) - 
       (222693375827*CF*NC*NH*Pi*Log[3]^2)/(7971615*Sqrt[3]) - 
       (CF*NC*(-5*CA*(9559989169 + 1538885040*lm) + 
          CF*(133086054767 + 50363510400*lm) + 
          60*((173844691 + 23316440*lm)*NM + 14*(2173067 + 1665460*lm)*NL + 
            5*(289411 + 4663288*lm)*NH))*Log[x]^2)/283500 + 
       (4*CF*NC*(2711165*CA - 96807338*CF + 8281400*NM + 1665460*NL)*
         Log[x]^3)/2025 - (2549229782325964*CF^2*NC*PolyGamma[2, 1])/
        158196699675 + (20381972*CF*NM*NC*PolyGamma[2, 1])/19845 - 
       (30050793981858463*CF*NC*NH*PolyGamma[2, 1])/949180198050 + 
       (6381400452266407*CF^2*NC*Zeta[3])/158196699675 + 
       (356408224*CF*NM*NC*Zeta[3])/19845 - (1154168*CF*NC*NL*Zeta[3])/
        135 - (50645744996306623*CF*NC*NH*Zeta[3])/474590099025 - 
       (CF*NC*Log[x]*(-40*(-19683*NM*(472826784361 + 49170612120*lm + 
              10668672000*lm^2 - 9021742800*Pi^2) - 551124*NL*
             (3945274873 + 1756093290*lm + 381024000*lm^2 + 301881300*Pi^2) - 
            5*NH*(6152189385766335 + 193565031671592*lm + 41998294195200*lm^
                2 - 3491832132967360*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
          5*CA*(195104642705322459 + 54343829342406240*lm + 
            9239624722944000*lm^2 + 5326375363409520*Pi^2 - 
            12331188601493440*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            5039795303424000*Zeta[3]) + CF*(1747677626581940583 + 
            1028283068537222400*lm + 302387718205440000*lm^2 + 
            41377426059236400*Pi^2 - 123311886014934400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 50397953034240000*Zeta[3])))/
        4687309620000 + (CA*CF*NC*(587861883372589056000*lm^2 + 
          521386844524501338180*Pi^2 + 83081383202562052000*Sqrt[3]*Pi^3 + 
          8066529244448136000*Pi^4 - 68747207760*lm*(-29924373401 + 
            15954400*Pi^2) + 64091352756262154400*Sqrt[3]*Pi*Log[3]^2 - 
          11*(1272942090185984163 + 68762592894921671760*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 174101618680020864000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 279671357481871219200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 57102747124101593600*
             PolyGamma[2, 1] + 60510062496078809600*Zeta[3])))/
        77959333599840000, (-1005361681373763914827*CF^2*NC)/
        15749360323200000 + (362481991*CF^2*lm*NC)/1500 + 
       (883512*CF^2*lm^2*NC)/5 - (15838073698193*CF*NM*NC)/370440000 + 
       (682755091*CF*lm*NM*NC)/54000 + (24542*CF*lm^2*NM*NC)/5 - 
       (1870451357*CF*NC*NL)/810000 + (682755091*CF*lm*NC*NL)/54000 + 
       (24542*CF*lm^2*NC*NL)/5 - (6856620592582695070973*CF*NC*NH)/
        4491942555038400 + (682755091*CF*lm*NC*NH)/54000 + 
       (24542*CF*lm^2*NC*NH)/5 - (5735640001777*CF^2*NC*Pi^2)/75816000 - 
       (3528*CF^2*lm*NC*Pi^2)/5 - (509464649*CF*NM*NC*Pi^2)/3150 - 
       (98*CF*lm*NM*NC*Pi^2)/5 + (6107969*CF*NC*NL*Pi^2)/1350 - 
       (98*CF*lm*NC*NL*Pi^2)/5 - (98*CF*lm*NC*NH*Pi^2)/5 + 
       (139733758064579*CF^2*NC*Pi^3)/(6887475360*Sqrt[3]) + 
       (20931392916259*CF*NC*NH*Pi^3)/(86093442*Sqrt[3]) + 
       (5457221*CF^2*NC*Pi^4)/5400 - (1237903107611141*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3587226750*Sqrt[3]) - 
       (2328585354044504*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1506635235*Sqrt[3]) + (806078*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 + (19961965437797*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26572050*Sqrt[3]) + (23921591904296*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) + 
       (19961965437797*CF^2*NC*Pi*Log[3]^2)/(1275458400*Sqrt[3]) + 
       (2990198988037*CF*NC*NH*Pi*Log[3]^2)/(15943230*Sqrt[3]) + 
       (CF*NC*(-2695*CA*(-119880067 + 591196320*lm) + 
          8*(11*CF*(102176540953 + 118507989600*lm) + 
            45*(11*(-5907127813 + 73153080*lm)*NM + 
              7*(66*(2335013 + 1741740*lm)*NL + 5*(1705919 + 22990968*lm)*
                 NH))))*Log[x]^2)/12474000 + 
       (4*CF*NC*(28753465*CA + 103715003*CF - 90*(1175910*NM + 29029*NL))*
         Log[x]^3)/675 + (120679442686072741*CF^2*NC*PolyGamma[2, 1])/
        7593441584400 - (1029550157*CF*NM*NC*PolyGamma[2, 1])/9450 + 
       (5899958495894579*CF*NC*NH*PolyGamma[2, 1])/45199057050 + 
       (573327007930113061*CF^2*NC*Zeta[3])/3796720792200 - 
       (222765857*CF*NM*NC*Zeta[3])/4725 + (187852*CF*NC*NL*Zeta[3])/5 - 
       (5296679598040141*CF*NC*NH*Zeta[3])/22599528525 + 
       CF*Log[x]*((-1606733319701*NM*NC)/1323000 + (8149096*lm*NM*NC)/225 + 
         7056*lm^2*NM*NC + (2052587701*NC*NL)/23625 + (8149096*lm*NC*NL)/
          225 + 7056*lm^2*NC*NL + (95132292603863321*NC*NH)/54015663240 + 
         (8149096*lm*NC*NH)/225 + 7056*lm^2*NC*NH - (754722*NM*NC*Pi^2)/
          5 + (93338*NC*NL*Pi^2)/15 - (23921591904296*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
         CA*NC*(-19015856354441311/78121827000 - (55933228*lm)/225 - 
           38808*lm^2 + (4532627023*Pi^2)/226800 + 
           (19961965437797*Im[PolyLog[2, (-1)^(1/3)]])/(159432300*Sqrt[3]) - 
           21168*Zeta[3]) + CF*NC*(1194129635579063291/3124873080000 + 
           (24922984*lm)/25 + 254016*lm^2 - (5838456061*Pi^2)/113400 - 
           (19961965437797*Im[PolyLog[2, (-1)^(1/3)]])/(79716150*Sqrt[3]) + 
           42336*Zeta[3])) - (CA*CF*NC*(12627634570368003648000*lm^2 - 
          16263241538394719806560*Pi^2 + 1581646407532969701000*Sqrt[3]*
           Pi^3 + 243690698808990972000*Pi^4 - 4331074088880*lm*
           (-11221056401 + 11642400*Pi^2) + 1220127228668290912200*Sqrt[3]*Pi*
           Log[3]^2 + 11*(-1962051263851121651583 - 2445700411645179050880*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 3427707475063190592000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 5324191543279814889600*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 337902439521003674800*
             PolyGamma[2, 1] + 5081490464122777191200*Zeta[3])))/
        467756001599040000, (-4436657512798001079917*CF^2*NC)/
        70872121454400000 - (4250399374*CF^2*lm*NC)/23625 - 
       (875184*CF^2*lm^2*NC)/5 - (11756794264812829*CF*NM*NC)/67512690000 - 
       (2311788256*CF*lm*NM*NC)/212625 - (72932*CF*lm^2*NM*NC)/15 + 
       (110707679063*CF*NC*NL)/12757500 - (2311788256*CF*lm*NC*NL)/212625 - 
       (72932*CF*lm^2*NC*NL)/15 + (98533316370460084206659*CF*NC*NH)/
        88435119052318500 - (2311788256*CF*lm*NC*NH)/212625 - 
       (72932*CF*lm^2*NC*NH)/15 - (6463522318505957*CF^2*NC*Pi^2)/
        20432412000 + (1456*CF^2*lm*NC*Pi^2)/5 - (951435127*CF*NM*NC*Pi^2)/
        12150 + (364*CF*lm*NM*NC*Pi^2)/45 - (9386497*CF*NC*NL*Pi^2)/2025 + 
       (364*CF*lm*NC*NL*Pi^2)/45 + (364*CF*lm*NC*NH*Pi^2)/45 - 
       (34930156266833*CF^2*NC*Pi^3)/(1147912560*Sqrt[3]) - 
       (61923416295041*CF*NC*NH*Pi^3)/(387420489*Sqrt[3]) - 
       (2591431*CF^2*NC*Pi^4)/2700 + (55416154023933541*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(225995285250*Sqrt[3]) + 
       (21645236495742166*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (13559717115*Sqrt[3]) - (961556*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (34930156266833*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31000725*Sqrt[3]) - (141539237245808*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23914845*Sqrt[3]) - 
       (34930156266833*CF^2*NC*Pi*Log[3]^2)/(1488034800*Sqrt[3]) - 
       (8846202327863*CF*NC*NH*Pi*Log[3]^2)/(71744535*Sqrt[3]) - 
       (CF*NC*(-495*CA*(89735540101 + 5178071360*lm) + 
          2*(33*CF*(1538741093497 + 254196230400*lm) + 
            40*(44*(5125844053 + 132393870*lm)*NM + 1386*(5355881 + 
                4202980*lm)*NL + 5*(99377669 + 1165066056*lm)*NH)))*
         Log[x]^2)/18711000 + (16*CF*NC*(47645855*CA - 229338457*CF - 
          1984200*NM + 2101490*NL)*Log[x]^3)/2025 - 
       (2278283033928936667*CF^2*NC*PolyGamma[2, 1])/11390162376600 + 
       (2295510293*CF*NM*NC*PolyGamma[2, 1])/396900 - 
       (427996869334769639*CF*NC*NH*PolyGamma[2, 1])/3417048712980 + 
       (CA*CF*NC*(3752581877948330380800*lm^2 + 22680378774524933978544*
           Pi^2 + 711673989811708908600*Sqrt[3]*Pi^3 + 68250148261093260000*
           Pi^4 - 1319946388992*lm*(-9975756554 + 4729725*Pi^2) + 
          549005649283318300920*Sqrt[3]*Pi*Log[3]^2 + 
          11*(18135182316972827133 - 521355177057166753728*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 1226655245109726835200*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 2395661015054479858560*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1275838499000204533520*
             PolyGamma[2, 1] - 1304275511466224746400*Zeta[3])))/
        140326800479712000 + (1722801741072330713*CF^2*NC*Zeta[3])/
        5695081188300 + (29661206693*CF*NM*NC*Zeta[3])/198450 - 
       (5371328*CF*NC*NL*Zeta[3])/135 - (102770635938122011*CF*NC*NH*
         Zeta[3])/341704871298 - 
       (CF*NC*Log[x]*(-81675*CA*(71387327724523431 + 7634910194421048*lm + 
            1270448399404800*lm^2 + 3682745399659914*Pi^2 - 
            1956088750942648*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            692971854220800*Zeta[3]) + 
          2*(10*(450130527*NL*(23831777099 + 9926780820*lm + 2095632000*
                 lm^2 + 1875378400*Pi^2) + 2381643*NM*(78559841337289 + 
                1876161574980*lm + 396074448000*lm^2 + 838098802800*Pi^2) + 
              5*NH*(29613341153500379601 + 893669416384018428*lm + 
                188661587311612800*lm^2 - 16783722752607912640*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 3267*CF*
             (1709735097357653379 + 366778695160231200*lm + 
              103945778133120000*lm^2 + 87495353836452450*Pi^2 - 
              48902218773566200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              17324296355520000*Zeta[3]))))/2552240088090000, 
      (-169806487321063148254007*CF^2*NC)/255139637235840000 + 
       (418234991*CF^2*lm*NC)/540 + (2830296*CF^2*lm^2*NC)/5 + 
       (49178947546654039*CF*NM*NC)/54010152000 + (787588619*CF*lm*NM*NC)/
        19440 + (235858*CF*lm^2*NM*NC)/15 - (304894508189*CF*NC*NL)/
        10206000 + (787588619*CF*lm*NC*NL)/19440 + (235858*CF*lm^2*NC*NL)/
        15 - (886489157655117277096302451*CF*NC*NH)/148031966901290472000 + 
       (787588619*CF*lm*NC*NH)/19440 + (235858*CF*lm^2*NC*NH)/15 - 
       (706586319261811*CF^2*NC*Pi^2)/648648000 - 1960*CF^2*lm*NC*Pi^2 - 
       (23003328127*CF*NM*NC*Pi^2)/8505 - (490*CF*lm*NM*NC*Pi^2)/9 + 
       (6642083*CF*NC*NL*Pi^2)/405 - (490*CF*lm*NC*NL*Pi^2)/9 - 
       (490*CF*lm*NC*NH*Pi^2)/9 + (16360971752397377*CF^2*NC*Pi^3)/
        (185961834720*Sqrt[3]) + (244465031236825*CF*NC*NH*Pi^3)/
        (258280326*Sqrt[3]) + (7077091*CF^2*NC*Pi^4)/1800 - 
       (10256641678883679917*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8135830269000*Sqrt[3]) - (25731926092291022*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4519905705*Sqrt[3]) + 
       (2864022*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (2337281678913911*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (717445350*Sqrt[3]) + (55877721425560*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
       (2337281678913911*CF^2*NC*Pi*Log[3]^2)/(34437376800*Sqrt[3]) + 
       (6984715178195*CF*NC*NH*Pi*Log[3]^2)/(9565938*Sqrt[3]) + 
       (CF*NC*(-429*CA*(-5369962117651 + 632952012000*lm) + 
          8*(1287*CF*(-286416124627 + 172623276000*lm) + 
            25*(143*(-546664109657 + 1726232760*lm)*NM + 
              7*(2574*(18125463 + 13700260*lm)*NL + (3351261631 + 
                  35264469240*lm)*NH))))*Log[x]^2)/486486000 + 
       (2*CF*NC*(1816721413*CA + 1202759098*CF - 
          100*(89495328*NM + 685013*NL))*Log[x]^3)/2025 - 
       (53629870173423692657*CF^2*NC*PolyGamma[2, 1])/205022922778800 - 
       (9515963983*CF*NM*NC*PolyGamma[2, 1])/5670 + 
       (197917135673136479*CF*NC*NH*PolyGamma[2, 1])/406791513450 - 
       (CA*CF*NC*(14198698159736338632384000*lm^2 - 
          87518507552278459280988840*Pi^2 + 2407467910450016833419000*Sqrt[3]*
           Pi^3 + 329910353190919903802400*Pi^4 - 4222797236658000*lm*
           (-12942882361 + 11642400*Pi^2) + 1857189530918584414351800*Sqrt[3]*
           Pi*Log[3]^2 - 143*(456206022502041048642423 + 
            241236212287344151647840*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            328826490351959226816000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
            623392290098545817404800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                 Sqrt[3])]] + 150163636485586339439600*PolyGamma[2, 1] - 
            747636803242807479797600*Zeta[3])))/164182356561263040000 + 
       (3961266226538857639*CF^2*NC*Zeta[3])/4100458455576 + 
       (1119677957*CF*NM*NC*Zeta[3])/2835 + (4154780*CF*NC*NL*Zeta[3])/27 - 
       (218470318384806721*CF*NC*NH*Zeta[3])/203395756725 + 
       CF*Log[x]*((-124422820290187*NM*NC)/5358150 + (3659773*lm*NM*NC)/
          27 + 25872*lm^2*NM*NC + (7834781117*NC*NL)/22680 + 
         (3659773*lm*NC*NL)/27 + 25872*lm^2*NC*NL + 
         (234897903701552096503*NC*NH)/34232426578350 + 
         (3659773*lm*NC*NH)/27 + 25872*lm^2*NC*NH - (59126302*NM*NC*Pi^2)/
          27 + (2068570*NC*NL*Pi^2)/81 - (55877721425560*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CA*NC*(29093679824808719921/8437157316000 - (50037119*lm)/54 - 
           142296*lm^2 + (78629802479*Pi^2)/226800 + 
           (2337281678913911*Im[PolyLog[2, (-1)^(1/3)]])/(4304672100*
             Sqrt[3]) - 77616*Zeta[3]) + CF*NC*(-617214987774513855199/
            84371573160000 + (11262796*lm)/3 + 931392*lm^2 - 
           (3355221133*Pi^2)/4536 - (2337281678913911*
             Im[PolyLog[2, (-1)^(1/3)]])/(2152336050*Sqrt[3]) + 
           155232*Zeta[3])), (194349967014968522902440773*CF^2*NC)/
        519998500027632780000 - (16829454667*CF^2*lm*NC)/30870 - 
       (18457344*CF^2*lm^2*NC)/35 - (221094304647346892863*CF*NM*NC)/
        83868764364000 - (7300073807*CF*lm*NM*NC)/222264 - 
       (512704*CF*lm^2*NM*NC)/35 + (3522524264078*CF*NC*NL)/72930375 - 
       (7300073807*CF*lm*NC*NL)/222264 - (512704*CF*lm^2*NC*NL)/35 + 
       (22782785657775741418075919*CF*NC*NH)/5652129645321999840 - 
       (7300073807*CF*lm*NC*NH)/222264 - (512704*CF*lm^2*NC*NH)/35 - 
       (19315557785372269*CF^2*NC*Pi^2)/3178375200 + (5520*CF^2*lm*NC*Pi^2)/
        7 - (40782141251*CF*NM*NC*Pi^2)/19845 + (460*CF*lm*NM*NC*Pi^2)/21 - 
       (34581476*CF*NC*NL*Pi^2)/2205 + (460*CF*lm*NC*NL*Pi^2)/21 + 
       (460*CF*lm*NC*NH*Pi^2)/21 - (3814380080581421*CF^2*NC*Pi^3)/
        (32543321076*Sqrt[3]) - (227182713312725*CF*NC*NH*Pi^3)/
        (387420489*Sqrt[3]) - (151369*CF^2*NC*Pi^4)/42 + 
       (68693388467665316869*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (79731136636200*Sqrt[3]) + (100602510341986784*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(18983603961*Sqrt[3]) - 
       (4439160*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/7 - 
       (15257520322325684*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3515482215*Sqrt[3]) - (726984682600720*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(33480783*Sqrt[3]) - 
       (3814380080581421*CF^2*NC*Pi*Log[3]^2)/(42185786580*Sqrt[3]) - 
       (45436542662545*CF*NC*NH*Pi*Log[3]^2)/(100442349*Sqrt[3]) - 
       (CF*NC*(-91*CA*(167395634677741 + 2429221410000*lm) + 
          13*CF*(2429152009250639 + 111302508240000*lm) + 
          140*(13*(5414456771011 + 22083831000*lm)*NM + 
            11*(234*(139916583 + 111534500*lm)*NL + 7*(400198243 + 
                3728439000*lm)*NH)))*Log[x]^2)/397296900 + 
       (8*CF*NC*(6787240936*CA - 17630842055*CF - 3469317600*NM + 
          55767250*NL)*Log[x]^3)/6615 - (7840361921113451624*CF^2*NC*
         PolyGamma[2, 1])/2562786534735 - (8942830487*CF*NM*NC*
         PolyGamma[2, 1])/22050 - (111189186173186252*CF*NC*NH*
         PolyGamma[2, 1])/261508830075 + CA*CF*NC*
        (-175682918991068958482996033/594284000031580320000 + 
         (2819872*lm^2)/35 + (298336211721853*Pi^2)/97796160 + 
         (3814380080581421*Pi^3)/(65086642152*Sqrt[3]) + (50947*Pi^4)/28 + 
         lm*(629415343097/2222640 - (2530*Pi^2)/21) - 
         (68693388467665316869*Im[PolyLog[2, (-1)^(1/3)]])/
          (159462273272400*Sqrt[3]) + (2219580*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          7 + (7628760161162842*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3515482215*Sqrt[3]) + (3814380080581421*Pi*Log[3]^2)/
          (84371573160*Sqrt[3]) + (3920180960556725812*PolyGamma[2, 1])/
          2562786534735 - (3887486362228833526*Zeta[3])/2562786534735) + 
       (8668740787126836029*CF^2*NC*Zeta[3])/2562786534735 + 
       (20254064513*CF*NM*NC*Zeta[3])/11025 - (9583304*CF*NC*NL*Zeta[3])/
        63 - (1311901446322094728*CF*NC*NH*Zeta[3])/1830561810525 + 
       CF*Log[x]*((-42777824357059373*NM*NC)/1512784350 - 
         (30053672*lm*NM*NC)/245 - 25344*lm^2*NM*NC - (58178243551*NC*NL)/
          185220 - (30053672*lm*NC*NL)/245 - 25344*lm^2*NC*NL - 
         (55701223023121079941*NC*NH)/13070562875370 - (30053672*lm*NC*NH)/
          245 - 25344*lm^2*NC*NH - (68818700*NM*NC*Pi^2)/63 - 
         (4783372*NC*NL*Pi^2)/189 + (726984682600720*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) + 
         CF*NC*(-3302719832196308102926541/50023905726564000 - 
           (811828512*lm)/245 - 912384*lm^2 - (56393627567*Pi^2)/13230 + 
           (15257520322325684*Im[PolyLog[2, (-1)^(1/3)]])/
            (10546446645*Sqrt[3]) - 152064*Zeta[3]) + 
         CA*NC*(238412422930949197072291/7146272246652000 + 
           (208760156*lm)/245 + 139392*lm^2 + (28490855641*Pi^2)/13230 - 
           (7628760161162842*Im[PolyLog[2, (-1)^(1/3)]])/(10546446645*
             Sqrt[3]) + 76032*Zeta[3])), 
      (-18062781047209311686808436661*CF^2*NC)/10697112000568445760000 + 
       (11450439607*CF^2*lm*NC)/5292 + (7905216*CF^2*lm^2*NC)/5 + 
       (253699749563833659557*CF*NM*NC)/10269644616000 + 
       (107802101747*CF*lm*NM*NC)/952560 + (658768*CF*lm^2*NM*NC)/15 - 
       (11420378861501*CF*NC*NL)/71442000 + (107802101747*CF*lm*NC*NL)/
        952560 + (658768*CF*lm^2*NC*NL)/15 - 
       (62744403023891526989174121577*CF*NC*NH)/3108671304927099912000 + 
       (107802101747*CF*lm*NC*NH)/952560 + (658768*CF*lm^2*NC*NH)/15 - 
       (1772871245506803619*CF^2*NC*Pi^2)/95351256000 - 
       4840*CF^2*lm*NC*Pi^2 - (361747775944*CF*NM*NC*Pi^2)/8505 - 
       (1210*CF*lm*NM*NC*Pi^2)/9 + (144974962*CF*NC*NL*Pi^2)/2835 - 
       (1210*CF*lm*NC*NL*Pi^2)/9 - (1210*CF*lm*NC*NH*Pi^2)/9 + 
       (926901874705034393*CF^2*NC*Pi^3)/(2928898896840*Sqrt[3]) + 
       (817383428962835*CF*NC*NH*Pi^3)/(258280326*Sqrt[3]) + 
       (40700341*CF^2*NC*Pi^4)/3150 - (28675503823832817103633*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7175802297258000*Sqrt[3]) - 
       (247971108297205526*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (13559717115*Sqrt[3]) + (61479528*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/35 + (1853803749410068786*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(158196699675*Sqrt[3]) + 
       (186830498048648*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) + (926901874705034393*CF^2*NC*Pi*Log[3]^2)/
        (3796720792200*Sqrt[3]) + (23353812256081*CF*NC*NH*Pi*Log[3]^2)/
        (9565938*Sqrt[3]) + 
       (CF*NC*(-91*CA*(-1967586430457533 + 38168345754000*lm) + 
          4*(52*CF*(-1618806570908183 + 109300262841000*lm) + 
            175*(13*(-95273356933021 + 69396992280*lm)*NM + 
              5*(18018*(13129441 + 10013996*lm)*NL + (20698037519 + 
                  180432179928*lm)*NH))))*Log[x]^2)/1702701000 - 
       (4*CF*NC*(-95250196571*CA + 120779758249*CF + 456998677800*NM + 
          876224650*NL)*Log[x]^3)/14175 - (1933323062311744291187*CF^2*NC*
         PolyGamma[2, 1])/263600900715600 - 
       (692377122953*CF*NM*NC*PolyGamma[2, 1])/28350 + 
       (5753357143760975953*CF*NC*NH*PolyGamma[2, 1])/3661123621050 + 
       CA*CF*NC*((-3623224*lm^2)/15 + (160523302115685079*Pi^2)/17336592000 - 
         (926901874705034393*Pi^3)/(5857797793680*Sqrt[3]) - 
         (4597549*Pi^4)/700 + (605*lm*(-585621409 + 465696*Pi^2))/381024 - 
         (926901874705034393*Pi*Log[3]^2)/(7593441584400*Sqrt[3]) + 
         (14988977841199235563789130727 + 9160102941485155095584525520*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
           12079348103719906108501248000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
           26861242602116015639272742400*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           50435758720363860370769981200*PolyGamma[2, 1] - 
           82587792149048933400102988000*Zeta[3])/13753429715016573120000) + 
       (10055240344525265886607*CF^2*NC*Zeta[3])/922603152504600 + 
       (185358203347*CF*NM*NC*Zeta[3])/14175 + (14448404*CF*NC*NL*Zeta[3])/
        27 - (7195119382238530847*CF*NC*NH*Zeta[3])/1830561810525 + 
       CF*Log[x]*((-49480882137750257*NM*NC)/129667230 + 
         (409333111*lm*NM*NC)/945 + 81312*lm^2*NM*NC + 
         (5311370731*NC*NL)/4536 + (409333111*lm*NC*NL)/945 + 
         81312*lm^2*NC*NL + (2750547043780471130257*NC*NH)/
          119813493024225 + (409333111*lm*NC*NH)/945 + 81312*lm^2*NC*NH - 
         (868978930*NM*NC*Pi^2)/27 + (7202422*NC*NL*Pi^2)/81 - 
         (186830498048648*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CA*NC*(16047089378982934054250243/
            180086060615630400 - (5578421981*lm)/1890 - 447216*lm^2 + 
           (2515984206149*Pi^2)/396900 + (926901874705034393*
             Im[PolyLog[2, (-1)^(1/3)]])/(474590099025*Sqrt[3]) - 
           243936*Zeta[3]) + CF*NC*(-404396614747908224687112479/
            2251075757695380000 + (1265939884*lm)/105 + 2927232*lm^2 - 
           (10397864057*Pi^2)/810 - (1853803749410068786*
             Im[PolyLog[2, (-1)^(1/3)]])/(474590099025*Sqrt[3]) + 
           487872*Zeta[3])), (549531505282444977121774152063181*CF^2*NC)/
        18278987272971347482560000 - (215711128457*CF^2*lm*NC)/148176 - 
       (49097004*CF^2*lm^2*NC)/35 - (25362052701131565437828611*CF*NM*NC)/
        1105558051846248000 - (2334358810597*CF*lm*NM*NC)/26671680 - 
       (4091417*CF*lm^2*NM*NC)/105 + (4467056862445651*CF*NC*NL)/
        22404211200 - (2334358810597*CF*lm*NC*NL)/26671680 - 
       (4091417*CF*lm^2*NC*NL)/105 + (12819609267866730246815704469573*CF*NC*
         NH)/1007209502796380371488000 - (2334358810597*CF*lm*NC*NH)/
        26671680 - (4091417*CF*lm^2*NC*NH)/105 - 
       (60308127291009106577*CF^2*NC*Pi^2)/572107536000 + 
       (13310*CF^2*lm*NC*Pi^2)/7 - (42303397598131*CF*NM*NC*Pi^2)/952560 + 
       (6655*CF*lm*NM*NC*Pi^2)/126 - (2939979845*CF*NC*NL*Pi^2)/63504 + 
       (6655*CF*lm*NC*NL*Pi^2)/126 + (6655*CF*lm*NC*NH*Pi^2)/126 - 
       (501409855388980621*CF^2*NC*Pi^3)/(1301732843040*Sqrt[3]) - 
       (234340281194346155*CF*NC*NH*Pi^3)/(125524238436*Sqrt[3]) - 
       (433295819*CF^2*NC*Pi^4)/37800 + (4213464720708278565133*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1594622732724000*Sqrt[3]) + 
       (481993443211537843039*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (30753438416820*Sqrt[3]) - (64153826*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - (501409855388980621*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(35154822150*Sqrt[3]) - 
       (187472224955476924*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2711943423*Sqrt[3]) - (501409855388980621*CF^2*NC*Pi*Log[3]^2)/
        (1687431463200*Sqrt[3]) - (46868056238869231*CF*NC*NH*Pi*Log[3]^2)/
        (32543321076*Sqrt[3]) - 
       (CF*NC*(-(CA*(7614080747463607553 + 22860027797607000*lm)) + 
          CF*(15344616178707166909 + 149629272857064000*lm) + 
          1750*((3633587121032254 + 2375067823128*lm)*NM + 
            1287*(2289746553 + 1845429544*lm)*NL + 
            56*(5426402428 + 42411925413*lm)*NH))*Log[x]^2)/11918907000 + 
       (CF*NC*(14686174996109*CA - 31257297975361*CF - 
          700*(15988288092*NM - 32954099*NL))*Log[x]^3)/99225 - 
       (61958715078849848613547*CF^2*NC*PolyGamma[2, 1])/1230137536672800 - 
       (5755357149289*CF*NM*NC*PolyGamma[2, 1])/396900 - 
       (3533845427823702736163*CF*NC*NH*PolyGamma[2, 1])/2767809457513800 + 
       CA*CF*NC*(-281170207800140954800997023577351/
          18278987272971347482560000 + (45005587*lm^2)/210 + 
         (1828769666271487489*Pi^2)/34673184000 + (501409855388980621*Pi^3)/
          (2603465686080*Sqrt[3]) + (436490219*Pi^4)/75600 + 
         lm*(8045588449195/10668672 - (73205*Pi^2)/252) - 
         (4213464720708278565133*Im[PolyLog[2, (-1)^(1/3)]])/
          (3189245465448000*Sqrt[3]) + (32076913*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/35 + (501409855388980621*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(70309644300*Sqrt[3]) + 
         (501409855388980621*Pi*Log[3]^2)/(3374862926400*Sqrt[3]) + 
         (61958715078849848613547*PolyGamma[2, 1])/2460275073345600 - 
         (31103744338575988238441*Zeta[3])/1230137536672800) + 
       (129683180998414500121*CF^2*NC*Zeta[3])/2510484768720 + 
       (5822973723911*CF*NM*NC*Zeta[3])/198450 - 
       (94568500*CF*NC*NL*Zeta[3])/189 - (2016215698532878140563*CF*NC*NH*
         Zeta[3])/1383904728756900 + CF*Log[x]*
        ((-3180750428818103583509*NM*NC)/6135853323600 - 
         (9839621077*lm*NM*NC)/26460 - 75504*lm^2*NM*NC - 
         (4503880581169*NC*NL)/4445280 - (9839621077*lm*NC*NL)/26460 - 
         75504*lm^2*NC*NL - (6325573381492265357098739*NC*NH)/
          465834860878186800 - (9839621077*lm*NC*NH)/26460 - 
         75504*lm^2*NC*NH - (5355454387*NM*NC*Pi^2)/189 - 
         (47224355*NC*NL*Pi^2)/567 + (187472224955476924*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(8135830269*Sqrt[3]) + 
         CF*NC*(-178668408972899688479565650543/169080801355786320000 - 
           (7425569437*lm)/735 - 2718144*lm^2 - (3946930538533*Pi^2)/52920 + 
           (501409855388980621*Im[PolyLog[2, (-1)^(1/3)]])/
            (105464466450*Sqrt[3]) - 453024*Zeta[3]) + 
         CA*NC*(4476067431663555506956472051/8454040067789316000 + 
           (136205533607*lm)/52920 + 415272*lm^2 + (59319344233153*Pi^2)/
            1587600 - (501409855388980621*Im[PolyLog[2, (-1)^(1/3)]])/
            (210928932900*Sqrt[3]) + 226512*Zeta[3])), 
      (3844142656797244988024328727205203*CF^2*NC)/
        46043862984977388410880000 + (12765517217*CF^2*lm*NC)/2352 + 
       (19828116*CF^2*lm^2*NC)/5 + (21989816299144540049287393*CF*NM*NC)/
        46796108014656000 + (120179091757*CF*lm*NM*NC)/423360 + 
       (550781*CF*lm^2*NM*NC)/5 - (812586548837*CF*NC*NL)/1296000 + 
       (120179091757*CF*lm*NC*NL)/423360 + (550781*CF*lm^2*NC*NL)/5 - 
       (17041420664973679068480967347856753*CF*NC*NH)/
        282766873556492386578316800 + (120179091757*CF*lm*NC*NH)/423360 + 
       (550781*CF*lm^2*NC*NH)/5 - (12928638497143813721*CF^2*NC*Pi^2)/
        40864824000 - 10890*CF^2*lm*NC*Pi^2 - (492703662229*CF*NM*NC*Pi^2)/
        756 - (605*CF*lm*NM*NC*Pi^2)/2 + (1070864993*CF*NC*NL*Pi^2)/7560 - 
       (605*CF*lm*NC*NL*Pi^2)/2 - (605*CF*lm*NC*NH*Pi^2)/2 + 
       (9910641365619476621*CF^2*NC*Pi^3)/(10041939074880*Sqrt[3]) + 
       (588659909640795895*CF*NC*NH*Pi^3)/(62762119218*Sqrt[3]) + 
       (402520327*CF^2*NC*Pi^4)/10800 - (139287771795741222571433*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12301375366728000*Sqrt[3]) - 
       (8256427671913736533*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (156905298045*Sqrt[3]) + (23987909*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 + (9910641365619476621*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(271194342300*Sqrt[3]) + 
       (134550836489324776*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) + (9910641365619476621*CF^2*NC*Pi*Log[3]^2)/
        (13017328430400*Sqrt[3]) + (16818854561165597*CF*NC*NH*Pi*Log[3]^2)/
        (2324522934*Sqrt[3]) + CF*((-12655924498642681283*CF*NC)/3405402000 + 
         CA*(179100308809743004633/95351256000 - 6484962*lm)*NC + 
         42447024*CF*lm*NC - (201203265695569*NM*NC)/25740 + 
         1179084*lm*NM*NC + (13824175*NC*NL)/9 + 1179084*lm*NC*NL + 
         (160249466191*NC*NH)/1021020 + 1179084*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-14876258521511*CA + 294*(93364643291*CF + 
            900*(241641135*NM + 98257*NL)))*Log[x]^3)/33075 - 
       (1543602288637738471743439*CF^2*NC*PolyGamma[2, 1])/
        11071237830055200 - (239051635927*CF*NM*NC*PolyGamma[2, 1])/675 + 
       (223708582291422554581*CF*NC*NH*PolyGamma[2, 1])/49425168884175 + 
       CA*CF*NC*(-80812610302587468935327240568452719/
          1974130625480905528116480000 - (6058591*lm^2)/10 + 
         (10962430670698474421*Pi^2)/69346368000 - (9910641365619476621*Pi^3)/
          (20083878149760*Sqrt[3]) - (407747527*Pi^4)/21600 + 
         lm*(-394974042595/169344 + (6655*Pi^2)/4) + 
         (139287771795741222571433*Im[PolyLog[2, (-1)^(1/3)]])/
          (24602750733456000*Sqrt[3]) - (23987909*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/10 - (9910641365619476621*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(542388684600*Sqrt[3]) - 
         (9910641365619476621*Pi*Log[3]^2)/(26034656860800*Sqrt[3]) + 
         (1543602288637738471743439*PolyGamma[2, 1])/22142475660110400 - 
         (187758975496678873463191*Zeta[3])/2214247566011040) + 
       (920714289752845368713927*CF^2*NC*Zeta[3])/5535618915027600 + 
       (168648592396*CF*NM*NC*Zeta[3])/675 + 1635738*CF*NC*NL*Zeta[3] - 
       (608179298255518159738*CF*NC*NH*Zeta[3])/49425168884175 + 
       CF*Log[x]*((-76153081462810676087*NM*NC)/12985932960 + 
         (1541474209*lm*NM*NC)/1260 + 226512*lm^2*NM*NC + 
         (1372364941*NC*NL)/392 + (1541474209*lm*NC*NL)/1260 + 
         226512*lm^2*NC*NL + (18327687749734157343109512517*NC*NH)/
          269252549587591970400 + (1541474209*lm*NC*NH)/1260 + 
         226512*lm^2*NC*NH - 483153584*NM*NC*Pi^2 + 272018*NC*NL*Pi^2 - 
         (134550836489324776*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CA*NC*(115744220797609151470419892147/
            74533577740509888000 - (20951887979*lm)/2520 - 1245816*lm^2 + 
           (353127766661777*Pi^2)/3175200 + (9910641365619476621*
             Im[PolyLog[2, (-1)^(1/3)]])/(1627166053800*Sqrt[3]) - 
           679536*Zeta[3]) + CF*NC*(-8113338055715659513232772458959/
            2608675220917846080000 + (1196609689*lm)/35 + 8154432*lm^2 - 
           (1444444918291*Pi^2)/6480 - (9910641365619476621*
             Im[PolyLog[2, (-1)^(1/3)]])/(813583026900*Sqrt[3]) + 
           1359072*Zeta[3])), (13547076788616530060250545866754087021*CF^2*
         NC)/15793045003847244224931840000 - (11730378159061*CF^2*lm*NC)/
        3333960 - (118341344*CF^2*lm^2*NC)/35 - 
       (375534681520311074439857*CF*NM*NC)/54595459350432000 - 
       (5070317038961*CF*lm*NM*NC)/24004512 - (29585336*CF*lm^2*NM*NC)/
        315 + (19051963239496811*CF*NC*NL)/28005264000 - 
       (5070317038961*CF*lm*NC*NL)/24004512 - (29585336*CF*lm^2*NC*NL)/
        315 + (106940691105586698424130359518575353*CF*NC*NH)/
        2969052172343170059072326400 - (5070317038961*CF*lm*NC*NH)/
        24004512 - (29585336*CF*lm^2*NC*NH)/315 - 
       (91310491104870140311*CF^2*NC*Pi^2)/52809926400 + 
       (263780*CF^2*lm*NC*Pi^2)/63 - (598325481025421*CF*NM*NC*Pi^2)/
        714420 + (65945*CF*lm*NM*NC*Pi^2)/567 - (21904091374*CF*NC*NL*Pi^2)/
        178605 + (65945*CF*lm*NC*NL*Pi^2)/567 + (65945*CF*lm*NC*NH*Pi^2)/
        567 - (7859113986629429395*CF^2*NC*Pi^3)/(7029357352416*Sqrt[3]) - 
       (55540208311590340*CF*NC*NH*Pi^3)/(10460353203*Sqrt[3]) - 
       (728537359*CF^2*NC*Pi^4)/22680 + (62702444812158042808223*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8610962756709600*Sqrt[3]) + 
       (972114162332610185393*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (23065078812615*Sqrt[3]) - (100183226*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/21 - (1571822797325885879*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37967207922*Sqrt[3]) - 
       (177728666597089088*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (903981141*Sqrt[3]) - (1571822797325885879*CF^2*NC*Pi*Log[3]^2)/
        (1822425980256*Sqrt[3]) - (11108041662318068*CF*NC*NH*Pi*Log[3]^2)/
        (2711943423*Sqrt[3]) - 
       (CF*NC*(-51*CA*(99099953945423957231 + 55422754292505600*lm) + 
          7*(119*CF*(12152143212324191393 + 22210231775846400*lm) + 
            240*(85*(34230748489733569 + 3598880148864*lm)*NM + 
              9*(4862*(8604740377 + 6990831680*lm)*NL + 35*(142850999651 + 
                  971126389376*lm)*NH))))*Log[x]^2)/486291405600 + 
       (CF*NC*(147494482948124*CA - 3*(99597898054537*CF + 
            560*(80790850203*NM - 24967256*NL)))*Log[x]^3)/59535 - 
       (114137280569374618960997*CF^2*NC*PolyGamma[2, 1])/138390472875690 - 
       (32639339385356*CF*NM*NC*PolyGamma[2, 1])/99225 - 
       (14398355371011579042973*CF*NC*NH*PolyGamma[2, 1])/4151714186270700 + 
       CA*CF*NC*(-424350467403939683028262063620904159/
          987065312740452764058240000 + (162719348*lm^2)/315 + 
         (53962240850675871811*Pi^2)/62411731200 + (7859113986629429395*Pi^3)/
          (14058714704832*Sqrt[3]) + (244252613*Pi^4)/15120 + 
         lm*(436685560039751/240045120 - (725395*Pi^2)/1134) - 
         (62702444812158042808223*Im[PolyLog[2, (-1)^(1/3)]])/
          (17221925513419200*Sqrt[3]) + (50091613*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/21 + (1571822797325885879*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(75934415844*Sqrt[3]) + 
         (1571822797325885879*Pi*Log[3]^2)/(3644851960512*Sqrt[3]) + 
         (114137280569374618960997*PolyGamma[2, 1])/276780945751380 - 
         (46389247632376902191123*Zeta[3])/110712378300552) + 
       (116394644074950640538831*CF^2*NC*Zeta[3])/138390472875690 + 
       (48424468461788*CF*NM*NC*Zeta[3])/99225 - 
       (92036620*CF*NC*NL*Zeta[3])/63 - (5153660872905925594573*CF*NC*NH*
         Zeta[3])/2075857093135350 + CF*Log[x]*
        ((-54429342862214496800929*NM*NC)/6135853323600 - 
         (119783376691*lm*NM*NC)/119070 - 201344*lm^2*NM*NC - 
         (16164059362421*NC*NL)/5556600 - (119783376691*lm*NC*NL)/119070 - 
         201344*lm^2*NC*NL - (1734197921830455814666602379*NC*NH)/
          44875424931265328400 - (119783376691*lm*NC*NH)/119070 - 
         201344*lm^2*NC*NH - (107794124084*NM*NC*Pi^2)/189 - 
         (137923040*NC*NL*Pi^2)/567 + (177728666597089088*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2711943423*Sqrt[3]) + 
         CF*NC*(-12094517742852200126763383463739/730429061856996902400 - 
           (181629514022*lm)/6615 - 7248384*lm^2 - (295424030145271*Pi^2)/
            238140 + (1571822797325885879*Im[PolyLog[2, (-1)^(1/3)]])/
            (113901623766*Sqrt[3]) - 1208064*Zeta[3]) + 
         CA*NC*(15123842061238733466627448623581/1826072654642492256000 + 
           (1653253564721*lm)/238140 + 1107392*lm^2 + (84435602095379*Pi^2)/
            136080 - (1571822797325885879*Im[PolyLog[2, (-1)^(1/3)]])/
            (227803247532*Sqrt[3]) + 604032*Zeta[3])), 
      (103513608992111900416482612792223338433*CF^2*NC)/
        38764746827625054006650880000 + (11889399237349*CF^2*lm*NC)/952560 + 
       (45598696*CF^2*lm^2*NC)/5 + (1155353947348431627894233497*CF*NM*NC)/
        140388324043968000 + (22386310253941*CF*lm*NM*NC)/34292160 + 
       (11399674*CF*lm^2*NM*NC)/45 - (218734553333867*CF*NC*NL)/107163000 + 
       (22386310253941*CF*lm*NC*NL)/34292160 + (11399674*CF*lm^2*NC*NL)/
        45 - (14226239149097418631776144318900775827649*CF*NC*NH)/
        87277409357579157579330371904000 + (22386310253941*CF*lm*NC*NH)/
        34292160 + (11399674*CF*lm^2*NC*NH)/45 - 
       (300945741885831656362129*CF^2*NC*Pi^2)/58354968672000 - 
       (204490*CF^2*lm*NC*Pi^2)/9 - (997329166396223*CF*NM*NC*Pi^2)/102060 - 
       (102245*CF*lm*NM*NC*Pi^2)/162 + (72779958823*CF*NC*NL*Pi^2)/204120 - 
       (102245*CF*lm*NC*NL*Pi^2)/162 - (102245*CF*lm*NC*NH*Pi^2)/162 + 
       (2608525070592151643801*CF^2*NC*Pi^3)/(948963242576160*Sqrt[3]) + 
       (7116684471900375610*CF*NC*NH*Pi^3)/(282429536481*Sqrt[3]) + 
       (10987026193*CF^2*NC*Pi^4)/113400 - (1063834838364772074686389*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(36327499129868625*Sqrt[3]) - 
       (1367039917405340617007*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9885033776835*Sqrt[3]) + (1252839302*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/105 + (2608525070592151643801*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(25627865347350*Sqrt[3]) + 
       (3253341472868743136*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) + (2608525070592151643801*CF^2*NC*Pi*Log[3]^2)/
        (1230137536672800*Sqrt[3]) + (203333842054296446*CF*NC*NH*Pi*
         Log[3]^2)/(10460353203*Sqrt[3]) + 
       CF*((-801722648091527198003*CF*NC)/13002444000 + 
         CA*(3187373421999156451/103194000 - (497693768*lm)/27)*NC + 
         (361959104*CF*lm*NC)/3 - (81488264386136749*NM*NC)/694980 + 
         (90489776*lm*NM*NC)/27 + (65182663*NC*NL)/15 + 
         (90489776*lm*NC*NL)/27 + (263720495087957*NC*NH)/523783260 + 
         (90489776*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-2207127151711132*CA + 4349303191376193*CF + 
          999600*(8629015593*NM + 665366*NL))*Log[x]^3)/297675 - 
       (711350863661105554664237641*CF^2*NC*PolyGamma[2, 1])/
        298923421411490400 - (72962752096544*CF*NM*NC*PolyGamma[2, 1])/
        14175 + (1055852884627288011907*CF*NC*NH*PolyGamma[2, 1])/
        88965303991515 + CA*CF*NC*((-62698207*lm^2)/45 + 
         (15472759155845354513*Pi^2)/6001128000 - 
         (2608525070592151643801*Pi^3)/(1897926485152320*Sqrt[3]) - 
         (3700513531*Pi^4)/75600 + lm*(-367868795606279/68584320 + 
           (1124695*Pi^2)/324) - (2608525070592151643801*Pi*Log[3]^2)/
          (2460275073345600*Sqrt[3]) + 
         (-8303302958693520147420548926314681777 + 
           30407372290323938275258969315599360*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] - 37167855886016699218932238665984000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 - 
           105687290876509520095487187012595200*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           7412852478088630839542856117404266400*PolyGamma[2, 1] - 
           8254527111361788693382601363186878400*Zeta[3])/
          6230048597296883679640320000) + (15790220426090328571926539*CF^2*NC*
         Zeta[3])/5978468428229808 + (59097271649762*CF*NM*NC*Zeta[3])/
        14175 + (40537718*CF*NC*NL*Zeta[3])/9 - 
       (3045919198593483362866*CF*NC*NH*Zeta[3])/88965303991515 + 
       CF*Log[x]*((-151820436732982427579489*NM*NC)/1753100949600 + 
         (106431132379*lm*NM*NC)/34020 + 572572*lm^2*NM*NC + 
         (6434483305711*NC*NL)/680400 + (106431132379*lm*NC*NL)/34020 + 
         572572*lm^2*NC*NL + (32006729586659529933401425570969*NC*NH)/
          174960306722017262365920 + (106431132379*lm*NC*NH)/34020 + 
         572572*lm^2*NC*NH - (195584297990*NM*NC*Pi^2)/27 + 
         (60704332*NC*NL*Pi^2)/81 - (3253341472868743136*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CA*NC*(5495061440982847878290113463719/224108916706124049600 - 
           (1443447048329*lm)/68040 - 3149146*lm^2 + (8811669261836719*Pi^2)/
            4762800 + (2608525070592151643801*Im[PolyLog[2, (-1)^(1/3)]])/
            (153767192084100*Sqrt[3]) - 1717716*Zeta[3]) + 
         CF*NC*(-2198550667689347569233430089187003/44821783341224809920000 + 
           (82894128889*lm)/945 + 20612592*lm^2 - (220369607388928*Pi^2)/
            59535 - (2608525070592151643801*Im[PolyLog[2, (-1)^(1/3)]])/
            (76883596042050*Sqrt[3]) + 3435432*Zeta[3])), 
      (5569595132792941009766556041466275193815453*CF^2*NC)/
        299280458972191541954490501120000 - (43581900958189*CF^2*lm*NC)/
        5556600 - (52657176*CF^2*lm^2*NC)/7 + 
       (834057598545368362646028604981*CF*NM*NC)/167642182367920260000 - 
       (94089347747989*CF*lm*NM*NC)/200037600 - (4388098*CF*lm^2*NM*NC)/
        21 + (566249953908896597*CF*NC*NL)/280052640000 - 
       (94089347747989*CF*lm*NC*NL)/200037600 - (4388098*CF*lm^2*NC*NL)/
        21 + (106684663972024323119904205929440416784839*CF*NC*NH)/
        1145515997818226443228711131240000 - (94089347747989*CF*lm*NC*NH)/
        200037600 - (4388098*CF*lm^2*NC*NH)/21 - 
       (527978800303683295061827*CF^2*NC*Pi^2)/19451656224000 + 
       (899756*CF^2*lm*NC*Pi^2)/105 - (34331982031715653*CF*NM*NC*Pi^2)/
        2381400 + (224939*CF*lm*NM*NC*Pi^2)/945 - 
       (708365427341*CF*NC*NL*Pi^2)/2381400 + (224939*CF*lm*NC*NL*Pi^2)/
        945 + (224939*CF*lm*NC*NH*Pi^2)/945 - 
       (199036197031902811513*CF^2*NC*Pi^3)/(67783088755440*Sqrt[3]) - 
       (23337768818970359003*CF*NC*NH*Pi^3)/(1694577218886*Sqrt[3]) - 
       (1538799119*CF^2*NC*Pi^4)/18900 + (15275159751616372928311*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(830342837254140*Sqrt[3]) + 
       (43452962973623114117167*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (415171418627070*Sqrt[3]) - (56992364*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (199036197031902811513*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1830561810525*Sqrt[3]) - 
       (186702150551762872024*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(366112362105*Sqrt[3]) - 
       (199036197031902811513*CF^2*NC*Pi*Log[3]^2)/(87866966905200*Sqrt[3]) - 
       (23337768818970359003*CF*NC*NH*Pi*Log[3]^2)/(2196674172630*Sqrt[3]) - 
       (CF*NC*(-38*CA*(22006002432584020448657 + 2144522630660810400*lm) + 
          35*(19*CF*(2515607272427503369277 + 802107165753653760*lm) + 
            16*(38*(41731847372732326739 + 696273581383380*lm)*NM + 
              3*(1801371*(5989930921 + 4895973880*lm)*NL + 
                14*(103855034601121 + 629961811727820*lm)*NH))))*Log[x]^2)/
        5133075948000 + (CF*NC*(3920001990930665*CA - 7859044100046541*CF - 
          840*(4799876819934*NM - 227313073*NL))*Log[x]^3)/99225 - 
       (1959129127495073258605915561*CF^2*NC*PolyGamma[2, 1])/
        149461710705745200 - (329199129690409*CF*NM*NC*PolyGamma[2, 1])/
        52920 - (647561207528243035331089*CF*NC*NH*PolyGamma[2, 1])/
        74730855352872600 + CA*CF*NC*
        (-69640169237942692964497693447691372190559/
          7482011474304788548862262528000 + (24134539*lm^2)/21 + 
         (27148705485690583297*Pi^2)/2000376000 + 
         (199036197031902811513*Pi^3)/(135566177510880*Sqrt[3]) + 
         (171777463*Pi^4)/4200 + lm*(1620172553551079/400075200 - 
           (2474329*Pi^2)/1890) - (15275159751616372928311*
           Im[PolyLog[2, (-1)^(1/3)]])/(1660685674508280*Sqrt[3]) + 
         (28496182*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (199036197031902811513*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3661123621050*Sqrt[3]) + (199036197031902811513*Pi*Log[3]^2)/
          (175733933810400*Sqrt[3]) + (1959129127495073258605915561*
           PolyGamma[2, 1])/298923421411490400 - 
         (995268454451526233841057611*Zeta[3])/149461710705745200) + 
       (995852485421282340047417597*CF^2*NC*Zeta[3])/74730855352872600 + 
       (208826241938903*CF*NM*NC*Zeta[3])/26460 - 
       (406446976*CF*NC*NL*Zeta[3])/105 - (121819722189615050024209*CF*NC*
         NH*Zeta[3])/37365427676436300 + CF*Log[x]*
        ((-210971834272231638589714169*NM*NC)/1477718008767000 - 
         (492518690521*lm*NM*NC)/198450 - 490776*lm^2*NM*NC - 
         (422145227939861*NC*NL)/55566000 - (492518690521*lm*NC*NL)/
          198450 - 490776*lm^2*NC*NL - (328985459684605686257607397984117*NC*
           NH)/3280505751037823669361000 - (492518690521*lm*NC*NH)/198450 - 
         490776*lm^2*NC*NH - (3200226940682*NM*NC*Pi^2)/315 - 
         (609220586*NC*NL*Pi^2)/945 + (186702150551762872024*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1098337086315*Sqrt[3]) + 
         CF*NC*(-35656591149188317308781061500279934737/
            142488449241753670735680000 - (749667346142*lm)/11025 - 
           17667936*lm^2 - (15684091661413789*Pi^2)/793800 + 
           (199036197031902811513*Im[PolyLog[2, (-1)^(1/3)]])/
            (5491685431575*Sqrt[3]) - 2944656*Zeta[3]) + 
         CA*NC*(445735917152744437641552503902672211/
            3562211231043841768392000 + (6781228556531*lm)/396900 + 
           2699268*lm^2 + (7842488209620079*Pi^2)/793800 - 
           (199036197031902811513*Im[PolyLog[2, (-1)^(1/3)]])/
            (10983370863150*Sqrt[3]) + 1472328*Zeta[3])), 
      (13364197536406113189413511012949621380195887*CF^2*NC)/
        230873496921404903793464100864000 + (2597070641921*CF^2*lm*NC)/
        97200 + 19523504*CF^2*lm^2*NC + (52651225648562877866413138705391*CF*
         NM*NC)/383182131126674880000 + (4890106186721*CF*lm*NM*NC)/
        3499200 + (4880876*CF*lm^2*NM*NC)/9 - (528275030692943*CF*NC*NL)/
        90720000 + (4890106186721*CF*lm*NC*NL)/3499200 + 
       (4880876*CF*lm^2*NC*NL)/9 - 
       (33485697308101118175842963401923205630260139*CF*NC*NH)/
        82477151842912303912467201449280000 + (4890106186721*CF*lm*NC*NH)/
        3499200 + (4880876*CF*lm^2*NC*NH)/9 - 
       (804970333265138671187*CF^2*NC*Pi^2)/10007712000 - 
       (2004002*CF^2*lm*NC*Pi^2)/45 - (73038162997120117*CF*NM*NC*Pi^2)/
        510300 - (1002001*CF*lm*NM*NC*Pi^2)/810 + 
       (120912582791*CF*NC*NL*Pi^2)/145800 - (1002001*CF*lm*NC*NL*Pi^2)/
        810 - (1002001*CF*lm*NC*NH*Pi^2)/810 + 
       (6390175394274149141489*CF^2*NC*Pi^3)/(915071698198440*Sqrt[3]) + 
       (1903156551801193100657*CF*NC*NH*Pi^3)/(30502389939948*Sqrt[3]) + 
       (1873794923*CF^2*NC*Pi^4)/8100 - (1284756450888403290090259*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(18301433963968800*Sqrt[3]) - 
       (89904030966412572915133*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (266895911974545*Sqrt[3]) + (411967556*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + (1825764398364042611854*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7060738412025*Sqrt[3]) + 
       (1087518029600681771804*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(470715894135*Sqrt[3]) + 
       (912882199182021305927*CF^2*NC*Pi*Log[3]^2)/(169457721888600*
         Sqrt[3]) + (271879507400170442951*CF*NC*NH*Pi*Log[3]^2)/
        (5648590729620*Sqrt[3]) + 
       (CF*NC*(-57*CA*(-55861839248058133138117 + 5533698303218685600*lm) + 
          5*(19*CF*(-67013379869012822680243 + 21732342427186110720*lm) + 
            168*(19*(-710211224877951895663 + 3593310586505640*lm)*NM + 
              9*(235379144*(41638787 + 32228335*lm)*NL + (1260238185570827 + 
                  7585877904845240*lm)*NH))))*Log[x]^2)/6599669076000 - 
       (CF*NC*(-4991438061960340*CA + 9956578131765273*CF + 
          18170863542667080*NM + 246353392740*NL)*Log[x]^3)/42525 - 
       (61771720305131709127626223723*CF^2*NC*PolyGamma[2, 1])/
        1614186475622048160 - (2108791047514537*CF*NM*NC*PolyGamma[2, 1])/
        28350 + (691134232248426924094111*CF*NC*NH*PolyGamma[2, 1])/
        24020632077709050 + CA*CF*NC*
        (-116911276602363208130828173570596213664936477/
          4040286196124585816385621765120000 - (26844818*lm^2)/9 + 
         (2344509392651112436003*Pi^2)/58296672000 - 
         (6390175394274149141489*Pi^3)/(1830143396396880*Sqrt[3]) - 
         (209980771*Pi^4)/1800 + (847*lm*(-94874559973 + 56216160*Pi^2))/
          6998400 + (1284756450888403290090259*Im[PolyLog[2, (-1)^(1/3)]])/
          (36602867927937600*Sqrt[3]) - (205983778*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/15 - (912882199182021305927*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(7060738412025*Sqrt[3]) - 
         (912882199182021305927*Pi*Log[3]^2)/(338915443777200*Sqrt[3]) + 
         (61771720305131709127626223723*PolyGamma[2, 1])/
          3228372951244096320 - (164744546115583045375322127001*Zeta[3])/
          8070932378110240800) + (164657698502979581181862689409*CF^2*NC*
         Zeta[3])/4035466189055120400 + (918766322195483*CF*NM*NC*Zeta[3])/
        14175 + (511945252*CF*NC*NL*Zeta[3])/45 - 
       (1041892245432716057363009*CF*NC*NH*Zeta[3])/12010316038854525 + 
       CF*Log[x]*((-392778576297118550066842511*NM*NC)/316653859021500 + 
         (179143783247*lm*NM*NC)/24300 + (4008004*lm^2*NM*NC)/3 + 
         (53273188288319*NC*NL)/2268000 + (179143783247*lm*NC*NL)/24300 + 
         (4008004*lm^2*NC*NL)/3 + (13377418313930056730591759411638679*NC*
           NH)/29524551759340413024249000 + (179143783247*lm*NC*NH)/24300 + 
         (4008004*lm^2*NC*NH)/3 - (14421269023891*NM*NC*Pi^2)/135 + 
         (766915877*NC*NL*Pi^2)/405 - (1087518029600681771804*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CA*NC*(10120695745403652818904412868184844979/
            27479915210909636499024000 - (2425089269317*lm)/48600 - 
           (22044022*lm^2)/3 + (1247466063480214*Pi^2)/42525 + 
           (912882199182021305927*Im[PolyLog[2, (-1)^(1/3)]])/
            (21182215236075*Sqrt[3]) - 4008004*Zeta[3]) + 
         CF*NC*(-404843986097241539164310879602874698859/
            549598304218192729980480000 + (139915444097*lm)/675 + 
           48096048*lm^2 - (19960572489922177*Pi^2)/340200 - 
           (1825764398364042611854*Im[PolyLog[2, (-1)^(1/3)]])/
            (21182215236075*Sqrt[3]) + 8016008*Zeta[3])), 
      (6455942555831203934556641510816636418206559006793*CF^2*NC)/
        18474882012812356076392653124638720000 - (96155687067743*CF^2*lm*NC)/
        5880600 - 15659488*CF^2*lm^2*NC + 
       (1670359332159370388619137713896912749*CF*NM*NC)/
        11827108068290383508640000 - (207427702436543*CF*lm*NM*NC)/
        211701600 - (3914872*CF*lm^2*NM*NC)/9 + 
       (1400661344437285943*CF*NC*NL)/259334460000 - 
       (207427702436543*CF*lm*NC*NL)/211701600 - (3914872*CF*lm^2*NC*NL)/
        9 + (82862945099651881447008385438693982754986441*CF*NC*NH)/
        371147183293105367606102406521760000 - (207427702436543*CF*lm*NC*NH)/
        211701600 - (3914872*CF*lm^2*NC*NH)/9 - 
       (37608423661513443241509353*CF^2*NC*Pi^2)/91700665056000 + 
       (742924*CF^2*lm*NC*Pi^2)/45 - (186364345182293903*CF*NM*NC*Pi^2)/
        801900 + (185731*CF*lm*NM*NC*Pi^2)/405 - 
       (268830134963*CF*NC*NL*Pi^2)/400950 + (185731*CF*lm*NC*NL*Pi^2)/
        405 + (185731*CF*lm*NC*NH*Pi^2)/405 - 
       (95313183476873158425059*CF^2*NC*Pi^3)/(13421051573577120*Sqrt[3]) - 
       (4540789498699543877893*CF*NC*NH*Pi^3)/(137260754729766*Sqrt[3]) - 
       (3080264447*CF^2*NC*Pi^4)/16200 + (6381896421042956247908269*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(147631567309348320*Sqrt[3]) + 
       (583463847273130152025831*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2402063207770905*Sqrt[3]) - (380434522*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (95313183476873158425059*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(362451238483950*Sqrt[3]) - 
       (5189473712799478717592*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4236443047215*Sqrt[3]) - 
       (95313183476873158425059*CF^2*NC*Pi*Log[3]^2)/(17397659447229600*
         Sqrt[3]) - (648684214099934839699*CF*NC*NH*Pi*Log[3]^2)/
        (25418658283290*Sqrt[3]) - 
       (CF*NC*(-3*CA*(59549730851212544148073019 + 963042791522832820800*
             lm) + 5*(CF*(71462694974795728957003901 + 3782131690344216168960*
               lm) + 3696*(7*(1565095671512719412399 + 4060730272907880*lm)*
               NM + 3*(3602742*(3202540557 + 2629951660*lm)*NL + 
                (1718075446386991 + 9475037303451720*lm)*NH))))*Log[x]^2)/
        72596359836000 + (CF*NC*(283090324317162380*CA - 
          33*(17164424588271833*CF + 9503620410238080*NM - 68378743160*NL))*
         Log[x]^3)/467775 - (33843694100185883660670001217*CF^2*NC*
         PolyGamma[2, 1])/168144424543963350 - 
       (42155071078060379*CF*NM*NC*PolyGamma[2, 1])/396900 - 
       (3052992593634073655419486*CF*NC*NH*PolyGamma[2, 1])/
        151329982089567015 + CA*CF*NC*
        (-8877259286677344759870848676173096271250061034379/
          50805925535233979210079796092756480000 + (21531796*lm^2)/9 + 
         (206640233098800193597477*Pi^2)/1007699616000 + 
         (95313183476873158425059*Pi^3)/(26842103147154240*Sqrt[3]) + 
         (343572359*Pi^4)/3600 + lm*(324629574423743/38491200 - 
           (2043041*Pi^2)/810) - (6381896421042956247908269*
           Im[PolyLog[2, (-1)^(1/3)]])/(295263134618696640*Sqrt[3]) + 
         (190217261*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (95313183476873158425059*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (724902476967900*Sqrt[3]) + (95313183476873158425059*Pi*Log[3]^2)/
          (34795318894459200*Sqrt[3]) + (33843694100185883660670001217*
           PolyGamma[2, 1])/336288849087926700 - 
         (749820618021143357384593985201*Zeta[3])/7398354679934387400) + 
       (374944749989738429491085998729*CF^2*NC*Zeta[3])/1849588669983596850 + 
       (24378593975554261*CF*NM*NC*Zeta[3])/198450 - 
       (425800544*CF*NC*NL*Zeta[3])/45 - (304498881439441301549108*CF*NC*NH*
         Zeta[3])/151329982089567015 + CF*Log[x]*
        ((-62423088444558593618107203902*NM*NC)/28578010776690375 - 
         (5307684027529*lm*NM*NC)/935550 - (3331328*lm^2*NM*NC)/3 - 
         (686276508976187*NC*NL)/37422000 - (5307684027529*lm*NC*NL)/
          935550 - (3331328*lm^2*NC*NL)/3 - 
         (16008169272328302754062542224487663*NC*NH)/
          66430241458515929304560250 - (5307684027529*lm*NC*NH)/935550 - 
         (3331328*lm^2*NC*NH)/3 - (22627977793498*NM*NC*Pi^2)/135 - 
         (638329354*NC*NL*Pi^2)/405 + (5189473712799478717592*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) + 
         CF*NC*(-2656666189461418916389665816858311959608079/
            727484955350147776917495360000 - (8104754349458*lm)/51975 - 
           39975936*lm^2 - (566205349392076453*Pi^2)/1871100 + 
           (95313183476873158425059*Im[PolyLog[2, (-1)^(1/3)]])/
            (1087353715451850*Sqrt[3]) - 6662656*Zeta[3]) + 
         CA*NC*(132834694692533951078286406744106108973263/
            72748495535014777691749536000 + (6629888110729*lm)/170100 + 
           (18322304*lm^2)/3 + (1132420860457732007*Pi^2)/7484400 - 
           (95313183476873158425059*Im[PolyLog[2, (-1)^(1/3)]])/
            (2174707430903700*Sqrt[3]) + 3331328*Zeta[3])), 
      (1400219447723237872347754302041376686741745094046281*CF^2*NC)/
        1306438085191730893973480470956595200000 + (2815238751977*CF^2*lm*NC)/
        52272 + (196786044*CF^2*lm^2*NC)/5 + 
       (138478220584646676227127037571350037*CF*NM*NC)/
        63077909697548712046080 + (26505593871013*CF*lm*NM*NC)/9408960 + 
       (5466279*CF*lm^2*NM*NC)/5 - (296655683297628881*CF*NC*NL)/
        19758816000 + (26505593871013*CF*lm*NC*NL)/9408960 + 
       (5466279*CF*lm^2*NC*NL)/5 - 
       (1703699705177159953288734691849309600338795764923*CF*NC*NH)/
        1806299111650885203065379192060101568000 + 
       (26505593871013*CF*lm*NC*NH)/9408960 + (5466279*CF*lm^2*NC*NH)/5 - 
       (2676147649398707534879*CF^2*NC*Pi^2)/2218376160 - 
       82810*CF^2*lm*NC*Pi^2 - (51041416411916555*CF*NM*NC*Pi^2)/24948 - 
       (41405*CF*lm*NM*NC*Pi^2)/18 + (64326472301*CF*NC*NL*Pi^2)/35640 - 
       (41405*CF*lm*NC*NL*Pi^2)/18 - (41405*CF*lm*NC*NH*Pi^2)/18 + 
       (3970353397219598073426539*CF^2*NC*Pi^3)/(241578928324388160*
         Sqrt[3]) + (39587012056590013863995*CF*NC*NH*Pi^3)/
        (274521509459532*Sqrt[3]) + (1852326203*CF^2*NC*Pi^4)/3600 - 
       (14676298049276401101401457479*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (93007887404889441600*Sqrt[3]) - (369457685912236946770733*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(480412641554181*Sqrt[3]) + 
       (296164323*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (567193342459942581918077*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(932017470387300*Sqrt[3]) + 
       (4524229949324573013028*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) + 
       (567193342459942581918077*CF^2*NC*Pi*Log[3]^2)/(44736838578590400*
         Sqrt[3]) + (1131057487331143253257*CF*NC*NH*Pi*Log[3]^2)/
        (10167463313316*Sqrt[3]) + CF*((-11675794226779759886465597*CF*NC)/
          806626220400 + CA*(116763775677416796761611943/16132524408000 - 
           (344244901*lm)/3)*NC + 751079784*CF*lm*NC - 
         (4286446311326666492303*NM*NC)/174594420 + (62589982*lm*NM*NC)/3 + 
         (1209660088*NC*NL)/45 + (62589982*lm*NC*NL)/3 + 
         (15155623235682899*NC*NH)/4015671660 + (62589982*lm*NC*NH)/3)*
        Log[x]^2 - (CF*NC*(-278337247913783113*CA + 
          60*(9273720246599152*CF + 1155*(13862439363060*NM + 
              31294991*NL)))*Log[x]^3)/155925 - 
       (4747942859258089398595969235723*CF^2*NC*PolyGamma[2, 1])/
        8070932378110240800 - (2004749054778301*CF*NM*NC*PolyGamma[2, 1])/
        1890 + (2015678843190691859897533*CF*NC*NH*PolyGamma[2, 1])/
        30883669814197350 + CA*CF*NC*
        (-2450313348545625962265112746422982436822219218905779/
          4572533298171058128907181648348083200000 - (60129069*lm^2)/10 + 
         (3033682616838563990761*Pi^2)/5029516800 - 
         (3970353397219598073426539*Pi^3)/(483157856648776320*Sqrt[3]) - 
         (621858601*Pi^4)/2400 + lm*(-7919475161249/342144 + 
           (455455*Pi^2)/36) + (14676298049276401101401457479*
           Im[PolyLog[2, (-1)^(1/3)]])/(186015774809778883200*Sqrt[3]) - 
         (296164323*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
         (567193342459942581918077*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1864034940774600*Sqrt[3]) - (567193342459942581918077*Pi*Log[3]^2)/
          (89473677157180800*Sqrt[3]) + (4747942859258089398595969235723*
           PolyGamma[2, 1])/16141864756220481600 - 
         (27010201759680797802894065528321*Zeta[3])/88780256159212648800) + 
       (27008000438627878611847928155781*CF^2*NC*Zeta[3])/
        44390128079606324400 + (906213624898079*CF*NM*NC*Zeta[3])/945 + 
       (80162264*CF*NC*NL*Zeta[3])/3 - (3143670972921883931273567*CF*NC*NH*
         Zeta[3])/15441834907098675 + CF*Log[x]*
        ((-3995304289308996373079189093*NM*NC)/230933420417700 + 
         (19271794789*lm*NM*NC)/1188 + 2914912*lm^2*NM*NC + 
         (90417861794189*NC*NL)/1663200 + (19271794789*lm*NC*NL)/1188 + 
         2914912*lm^2*NC*NL + (5889107638655074400715054544062520757*NC*NH)/
          5622655637048788256337979560 + (19271794789*lm*NC*NH)/1188 + 
         2914912*lm^2*NC*NH - 1540270694371*NM*NC*Pi^2 + 
         (40039727*NC*NL*Pi^2)/9 - (4524229949324573013028*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CA*NC*(3173070543745537010735703985054988706581479/
            595214963468302726568859840000 - (23679141733*lm)/216 - 
           16032016*lm^2 + (247398481863916171*Pi^2)/554400 + 
           (567193342459942581918077*Im[PolyLog[2, (-1)^(1/3)]])/
            (5592104822323800*Sqrt[3]) - 8744736*Zeta[3]) + 
         CF*NC*(-13961600222866068351668757461276455041460961/
            1309472919630265998451491648000 + (15087438613*lm)/33 + 
           104936832*lm^2 - (2226605430136197853*Pi^2)/2494800 - 
           (567193342459942581918077*Im[PolyLog[2, (-1)^(1/3)]])/
            (2796052411161900*Sqrt[3]) + 17489472*Zeta[3])), 
      (32784218706963438537022684351085906420871324164571457*CF^2*NC)/
        5487039957805269754688617978017699840000 - 
       (530480319078329*CF^2*lm*NC)/16465680 - (154097788*CF^2*lm^2*NC)/5 + 
       (15422731067891738569547928192630412423*CF*NM*NC)/
        5322198630730672578888000 - (1143667161674657*CF*lm*NM*NC)/
        592764480 - (38524447*CF*lm^2*NM*NC)/45 + 
       (692141855802633863411*CF*NC*NL)/52281827136000 - 
       (1143667161674657*CF*lm*NC*NL)/592764480 - (38524447*CF*lm^2*NC*NL)/
        45 + (239948187933442566815106573689129079791429687483*CF*NC*NH)/
        478138000142881377282012139074732768000 - 
       (1143667161674657*CF*lm*NC*NH)/592764480 - (38524447*CF*lm^2*NC*NH)/
        45 - (2087390301639849621180145469*CF^2*NC*Pi^2)/348462527212800 + 
       (272090*CF^2*lm*NC*Pi^2)/9 - (15993568647819592721*CF*NM*NC*Pi^2)/
        4490640 + (136045*CF*lm*NM*NC*Pi^2)/162 - 
       (911303458091*CF*NC*NL*Pi^2)/641520 + (136045*CF*lm*NC*NL*Pi^2)/
        162 + (136045*CF*lm*NC*NH*Pi^2)/162 - 
       (36299925156267338769967*CF^2*NC*Pi^3)/(2264802453041139*Sqrt[3]) - 
       (183961575364461493236085*CF*NC*NH*Pi^3)/(2470693585135788*Sqrt[3]) - 
       (167980891*CF^2*NC*Pi^4)/405 + (9328726439090870362529563999*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(97658281775133913680*Sqrt[3]) + 
       (9197930886593845615570219*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (17294855095950516*Sqrt[3]) - 53132144*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (580798802500277420319472*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(978618343906665*Sqrt[3]) - 
       (21024180041652742084124*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (36299925156267338769967*CF^2*NC*Pi*Log[3]^2)/(2935855031719995*
         Sqrt[3]) - (5256045010413185521031*CF*NC*NH*Pi*Log[3]^2)/
        (91507169819844*Sqrt[3]) + CF*((-1043710723869957437133670981*CF*NC)/
          14519271967200 - 607582872*CF*lm*NC + 
         CA*(104370364169804956232095907/2903854393440 + 92825161*lm)*NC - 
         (11192841141858616421407*NM*NC)/261891630 - 16877302*lm*NM*NC - 
         (11056798649*NC*NL)/540 - 16877302*lm*NC*NL - 
         (352717240125997*NC*NH)/106297191 - 16877302*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(837234012370448823*CA - 1674591988327782754*CF - 
          978621960496303200*NM + 1052637325740*NL)*Log[x]^3)/93555 - 
       (43430373653965005737837416670381*CF^2*NC*PolyGamma[2, 1])/
        14527678280598433440 - (49792595615178149*CF*NM*NC*PolyGamma[2, 1])/
        29400 - (301080563554096871181544402*CF*NC*NH*PolyGamma[2, 1])/
        6809849194030515675 + CA*CF*NC*
        (-409804839669222118135905432089704476335403671979719/
          137175998945131743867215449450442496000 + (423768917*lm^2)/90 + 
         (528186007481038465386557*Pi^2)/176347432800 + 
         (36299925156267338769967*Pi^3)/(4529604906082278*Sqrt[3]) + 
         (168525071*Pi^4)/810 + lm*(1789531672998689/107775360 - 
           (1496495*Pi^2)/324) - (9328726439090870362529563999*
           Im[PolyLog[2, (-1)^(1/3)]])/(195316563550267827360*Sqrt[3]) + 
         26566072*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (290399401250138710159736*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (978618343906665*Sqrt[3]) + (36299925156267338769967*Pi*Log[3]^2)/
          (5871710063439990*Sqrt[3]) + (43430373653965005737837416670381*
           PolyGamma[2, 1])/29055356561196866880 - 
         (237332748757487400395186620657721*Zeta[3])/159804461086582767840) + 
       (47467215346513623515591342410549*CF^2*NC*Zeta[3])/
        15980446108658276784 + (9030910022867017*CF*NM*NC*Zeta[3])/4900 - 
       (583382540*CF*NC*NL*Zeta[3])/27 + (38870017987282394940494296*CF*NC*
         NH*Zeta[3])/6809849194030515675 + CF*Log[x]*
        ((-266456178302104275211040580991*NM*NC)/8313603135037200 - 
         (650223581449*lm*NM*NC)/53460 - (7079072*lm^2*NM*NC)/3 - 
         (39058713813227519*NC*NL)/943034400 - (650223581449*lm*NC*NL)/
          53460 - (7079072*lm^2*NC*NL)/3 - 
         (16148904425108525687827089433155460241*NC*NH)/
          29767000431434761357083421200 - (650223581449*lm*NC*NH)/53460 - 
         (7079072*lm^2*NC*NH)/3 - (211823342076455*NM*NC*Pi^2)/81 - 
         (32395025*NC*NL*Pi^2)/9 + (21024180041652742084124*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(-18446095733069974519662432860028738864749903/
            357128978080981635941315904000 - (497793463609*lm)/1485 - 
           84948864*lm^2 - (372106613629967819*Pi^2)/83160 + 
           (580798802500277420319472*Im[PolyLog[2, (-1)^(1/3)]])/
            (2935855031719995*Sqrt[3]) - 14158144*Zeta[3]) + 
         CA*NC*(50726846595340723103941525495326113482872193/
            1964209379445398997677237472000 + (810776934409*lm)/9720 + 
           (38934896*lm^2)/3 + (111632138348785181*Pi^2)/49896 - 
           (290399401250138710159736*Im[PolyLog[2, (-1)^(1/3)]])/
            (2935855031719995*Sqrt[3]) + 7079072*Zeta[3])), 
      (22749382094484126019235778159475950236149703280552383*CF^2*NC)/
        1259779582149169076331570454136716800000 + 
       (60651900353071*CF^2*lm*NC)/588060 + (376891424*CF^2*lm^2*NC)/5 + 
       (407098768553498656065730877836369379*CF*NM*NC)/
        12095905978933346770200 + (114213636629119*CF*lm*NM*NC)/21170160 + 
       (94222856*CF*lm^2*NM*NC)/45 - (733043793406555485521*CF*NC*NL)/
        20539289232000 + (114213636629119*CF*lm*NC*NL)/21170160 + 
       (94222856*CF*lm^2*NC*NL)/45 - 
       (1820553779806419409891512555548108007570177475357*CF*NC*NH)/
        881981988110783790559267183623096468750 + 
       (114213636629119*CF*lm*NC*NH)/21170160 + (94222856*CF*lm^2*NC*NH)/
        45 - (217605572077798945758432383*CF^2*NC*Pi^2)/12445090257600 - 
       (1324960*CF^2*lm*NC*Pi^2)/9 - (16028563040013590113*CF*NM*NC*Pi^2)/
        561330 - (331240*CF*lm*NM*NC*Pi^2)/81 + 
       (148826717221*CF*NC*NL*Pi^2)/40095 - (331240*CF*lm*NC*NL*Pi^2)/81 - 
       (331240*CF*lm*NC*NH*Pi^2)/81 + (59126983403043955914398779*CF^2*NC*
         Pi^3)/(1630657766189620080*Sqrt[3]) + 
       (21561509394641080816420*CF*NC*NH*Pi^3)/(68630377364883*Sqrt[3]) + 
       (4364788883*CF^2*NC*Pi^4)/4050 - (13169078506591775808474859528*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(39237702498937733175*Sqrt[3]) - 
       (6267333293833959852653098*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3774670755068565*Sqrt[3]) + (604223256*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + (8446711914720565130628397*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6291117925114275*Sqrt[3]) + 
       (9856690008978779801792*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) + 
       (8446711914720565130628397*CF^2*NC*Pi*Log[3]^2)/(301973660405485200*
         Sqrt[3]) + (616043125561173737612*CF*NC*NH*Pi*Log[3]^2)/
        (2541865828329*Sqrt[3]) + CF*((-761608089999427983251165671*CF*NC)/
          3629817991800 + CA*(1904035046970786433680723293/18149089959000 - 
           (774265492*lm)/3)*NC + 1689306528*CF*lm*NC - 
         (6409895890052545580221*NM*NC)/18706545 + (140775544*lm*NM*NC)/3 + 
         (1628912714*NC*NL)/27 + (140775544*lm*NC*NL)/3 + 
         (412589636424429307*NC*NH)/45176306175 + (140775544*lm*NC*NH)/3)*
        Log[x]^2 - (CF*NC*(-12254131654215387933*CA + 
          10*(2450643412574406263*CF + 64680*(62742376547311*NM + 
              22624641*NL)))*Log[x]^3)/467775 - 
       (1423355148530466148886784755459851*CF^2*NC*PolyGamma[2, 1])/
        163436380656732376200 - (23407084700927359*CF*NM*NC*PolyGamma[2, 1])/
        1575 + (45343118030705197354212397*CF*NC*NH*PolyGamma[2, 1])/
        324278533049072175 + CA*CF*NC*
        (-34834854639761155367657435456523679752991555387058233/
          3858074970331830296265434515793695200000 - (518225708*lm^2)/45 + 
         (7323262020144917215623917*Pi^2)/837650305800 - 
         (59126983403043955914398779*Pi^3)/(3261315532379240160*Sqrt[3]) - 
         (4391288083*Pi^4)/8100 + lm*(-170629760104831/3849120 + 
           (1821820*Pi^2)/81) + (6584539253295887904237429764*
           Im[PolyLog[2, (-1)^(1/3)]])/(39237702498937733175*Sqrt[3]) - 
         (302111628*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (8446711914720565130628397*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (12582235850228550*Sqrt[3]) - (8446711914720565130628397*Pi*
           Log[3]^2)/(603947320810970400*Sqrt[3]) + 
         (1423355148530466148886784755459851*PolyGamma[2, 1])/
          326872761313464752400 - (717377668889952601367093233763711*Zeta[3])/
          163436380656732376200) + (717368860997391583439246823515621*CF^2*NC*
         Zeta[3])/81718190328366188100 + (21504739301930882*CF*NM*NC*
         Zeta[3])/1575 + (1592655064*CF*NC*NL*Zeta[3])/27 - 
       (145281951777768975842696806*CF*NC*NH*Zeta[3])/324278533049072175 + 
       CF*Log[x]*((-21543363056170780374824554609151*NM*NC)/
          91449634485409200 + (450072919088*lm*NM*NC)/13365 + 
         (18019456*lm^2*NM*NC)/3 + (12538952221162621*NC*NL)/105850800 + 
         (450072919088*lm*NC*NL)/13365 + (18019456*lm^2*NC*NL)/3 + 
         (3208003834588182420991919933325813270007*NC*NH)/
          1405663909262197064084494890000 + (450072919088*lm*NC*NH)/13365 + 
         (18019456*lm^2*NC*NH)/3 - (1756786572223760*NM*NC*Pi^2)/81 + 
         (29469076*NC*NL*Pi^2)/3 - (9856690008978779801792*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CA*NC*(3305657968080755604447684504608562611298251029/
            44194711037521477447737843120000 - (276121617304*lm)/1215 - 
           (99107008*lm^2)/3 + (742668905449556507*Pi^2)/113400 + 
           (8446711914720565130628397*Im[PolyLog[2, (-1)^(1/3)]])/
            (37746707550685650*Sqrt[3]) - 18019456*Zeta[3]) + 
         CF*NC*(-1322264519226100500228494446526148643052254513/
            8838942207504295489547568624000 + (1412287740032*lm)/1485 + 
           216233472*lm^2 - (247556619473289923*Pi^2)/18900 - 
           (8446711914720565130628397*Im[PolyLog[2, (-1)^(1/3)]])/
            (18873353775342825*Sqrt[3]) + 36038912*Zeta[3])), 
      (233066250164431022688595297009448256860711034483985609292579*CF^2*NC)/
        2440942304529423719162400171190418253916800000 - 
       (1001885644798403*CF^2*lm*NC)/16563690 - (289060608*CF^2*lm^2*NC)/5 + 
       (554876871728388930464734371068592251499107*CF*NM*NC)/
        10792531790016682211221716000 - (2158963967811587*CF*lm*NM*NC)/
        596292840 - (24088384*CF*lm^2*NM*NC)/15 + 
       (24477407899046266244789*CF*NC*NL)/809932638715200 - 
       (2158963967811587*CF*lm*NC*NL)/596292840 - (24088384*CF*lm^2*NC*NL)/
        15 + (50824755337032944958921489044033023891544254477181*CF*NC*NH)/
        47627027357982324690200427915647209312500 - 
       (2158963967811587*CF*lm*NC*NH)/596292840 - (24088384*CF*lm^2*NC*NH)/
        15 - (356106041627182289278252817*CF^2*NC*Pi^2)/4194456346080 + 
       (159040*CF^2*lm*NC*Pi^2)/3 - (63714203993605620781*CF*NM*NC*Pi^2)/
        1216215 + (39760*CF*lm*NM*NC*Pi^2)/27 - (99178634108*CF*NC*NL*Pi^2)/
        34749 + (39760*CF*lm*NC*NL*Pi^2)/27 + (39760*CF*lm*NC*NH*Pi^2)/27 - 
       (45182502551421271851009469*CF^2*NC*Pi^3)/(1324909435029066315*
         Sqrt[3]) - (293650754435007794431600*CF*NC*NH*Pi^3)/
        (1853020188851841*Sqrt[3]) - (576428536*CF^2*NC*Pi^4)/675 + 
       (14868291119199850276526804914411*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (74269123289989341353640*Sqrt[3]) + (789687881753593036229269396*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(713412772707958785*Sqrt[3]) - 
       (528500352*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (722920040822740349616151504*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(572491731185399025*
         Sqrt[3]) - (134240344884574991740160*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (45182502551421271851009469*CF^2*NC*Pi*Log[3]^2)/
        (1717475193556197075*Sqrt[3]) - (8390021555285936983760*CF*NC*NH*Pi*
         Log[3]^2)/(68630377364883*Sqrt[3]) + 
       CF*((-184285301437501263739170073303*CF*NC)/180885929924700 - 
         1332706752*CF*lm*NC + CA*(921425534357830026800683261577/
            1808859299247000 + 203607976*lm)*NC - 
         (90158643098844687328814*NM*NC)/143416845 - 37019632*lm*NM*NC - 
         (2820984296*NC*NL)/63 - 37019632*lm*NC*NL - 
         (10683731487132698*NC*NH)/1368978975 - 37019632*lm*NC*NH)*
        Log[x]^2 + (2*CF*NC*(43327582701554118689*CA - 
          65*(1333172655919624911*CF + 6160*(131752797553639*NM - 
              20823543*NL)))*Log[x]^3)/675675 - 
       (879703122017915469610410854994964*CF^2*NC*PolyGamma[2, 1])/
        20429547582091547025 - (848986301750741888*CF*NM*NC*PolyGamma[2, 1])/
        33075 - (69570702517279896361153673*CF*NC*NH*PolyGamma[2, 1])/
        756649910447835075 + CA*CF*NC*
        (-58266603335409907786613525954828073107520363945979242186323/
          1220471152264711859581200085595209126958400000 + 
         (132486112*lm^2)/15 + (16024772748023206332402289463*Pi^2)/
          377501071147200 + (45182502551421271851009469*Pi^3)/
          (2649818870058132630*Sqrt[3]) + (289009468*Pi^4)/675 + 
         lm*(3377704771988483/108416880 - (218680*Pi^2)/27) - 
         (14868291119199850276526804914411*Im[PolyLog[2, (-1)^(1/3)]])/
          (148538246579978682707280*Sqrt[3]) + 
         (264250176*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (361460020411370174808075752*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (572491731185399025*Sqrt[3]) + (45182502551421271851009469*Pi*
           Log[3]^2)/(3434950387112394150*Sqrt[3]) + 
         (439851561008957734805205427497482*PolyGamma[2, 1])/
          20429547582091547025 - (61539041018169459009020879093005774*
           Zeta[3])/2921425304239091224575) + 
       (123078339743664928116544088325728918*CF^2*NC*Zeta[3])/
        2921425304239091224575 + (884389387447116224*CF*NM*NC*Zeta[3])/
        33075 - (418878640*CF*NC*NL*Zeta[3])/9 + 
       (22345988936101237839884654*CF*NC*NH*Zeta[3])/756649910447835075 + 
       CF*Log[x]*((-3661101006237409973972634424098431*NM*NC)/
          8062809440463577800 - (10007355186284*lm*NM*NC)/405405 - 
         4752384*lm^2*NM*NC - (198586499529575011*NC*NL)/2247565320 - 
         (10007355186284*lm*NC*NL)/405405 - 4752384*lm^2*NC*NL - 
         (129674219037248542425203729751083573081*NC*NH)/
          112286761982483197426867935000 - (10007355186284*lm*NC*NH)/
          405405 - 4752384*lm^2*NC*NH - (1054022660207104*NM*NC*Pi^2)/27 - 
         (23262200*NC*NL*Pi^2)/3 + (134240344884574991740160*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(-3085264901909450768355271711445801321006558686069/
            4341814682929074291544187816232000 - (30717326273456*lm)/45045 - 
           171085824*lm^2 - (129982889624819846884*Pi^2)/2027025 + 
           (722920040822740349616151504*Im[PolyLog[2, (-1)^(1/3)]])/
            (1717475193556197075*Sqrt[3]) - 28514304*Zeta[3]) + 
         CA*NC*(26996074684606723980034068182444878882159112190041/
            75981756951258800102023286784060000 + (6229721379382*lm)/36855 + 
           26138112*lm^2 + (2407091047391557148*Pi^2)/75075 - 
           (361460020411370174808075752*Im[PolyLog[2, (-1)^(1/3)]])/
            (1717475193556197075*Sqrt[3]) + 14257152*Zeta[3])), 
      (2383188054162599091310176889405194037770541479894106903031461*CF^2*NC)/
        8368945044100881322842514872652862584857600000 + 
       (18780924905015959*CF^2*lm*NC)/99382140 + (690639824*CF^2*lm^2*NC)/5 + 
       (4023313700393850494836214852893258883633563*CF*NM*NC)/
        8094398842512511658416287000 + (35368263627282271*CF*lm*NM*NC)/
        3577757040 + (172659956*CF*lm^2*NM*NC)/45 - 
       (275345211021763777542971*CF*NC*NL)/3471139880208000 + 
       (35368263627282271*CF*lm*NC*NL)/3577757040 + 
       (172659956*CF*lm^2*NC*NL)/45 - 
       (4903030494204752581759676571835733562444734467156649*CF*NC*NH)/
        1143048656591575792564810269975533023500000 + 
       (35368263627282271*CF*lm*NC*NH)/3577757040 + 
       (172659956*CF*lm^2*NC*NH)/45 - (795866084734866247970746975*CF^2*NC*
         Pi^2)/3235723466976 - (2265760*CF^2*lm*NC*Pi^2)/9 - 
       (568632614632229018363*CF*NM*NC*Pi^2)/1459458 - 
       (566440*CF*lm*NM*NC*Pi^2)/81 + (3789059533147*CF*NC*NL*Pi^2)/
        521235 - (566440*CF*lm*NC*NL*Pi^2)/81 - (566440*CF*lm*NC*NH*Pi^2)/
        81 + (875171636678776473110753777*CF^2*NC*Pi^3)/
        (11562845978435487840*Sqrt[3]) + (3615086051779491737430500*CF*NC*NH*
         Pi^3)/(5559060566555523*Sqrt[3]) + (17365772221*CF^2*NC*Pi^4)/8100 - 
       (39373004837010957259608639166529*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (57872044122069616639200*Sqrt[3]) - (208783839685393027451988550*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(61149666232110753*Sqrt[3]) + 
       (1174963636*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (125024519525539496158679111*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(44609745287173950*Sqrt[3]) + 
       (1652610766527767651396800*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) + 
       (125024519525539496158679111*CF^2*NC*Pi*Log[3]^2)/
        (2141267773784349600*Sqrt[3]) + (103288172907985478212300*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((-3203353747954745546738770096199*CF*NC)/1085315579548200 + 
         CA*(32033575313925869001260047341463/21706311590964000 - 
           (1646360716*lm)/3)*NC + 3592059744*CF*lm*NC - 
         (182873221354280214864683*NM*NC)/39113685 + (299338312*lm*NM*NC)/
          3 + (3457650638*NC*NL)/27 + (299338312*lm*NC*NL)/3 + 
         (934926227611070029*NC*NH)/45176306175 + (299338312*lm*NC*NH)/3)*
        Log[x]^2 - (CF*NC*(-4531601563893113739243*CA + 
          20*(453154729998208544489*CF + 840840*(863418022751161*NM + 
              48107943*NL)))*Log[x]^3)/12162150 - 
       (2266323563418776715478621533553279*CF^2*NC*PolyGamma[2, 1])/
        18159597850748041800 - (965058132750258451*CF*NM*NC*PolyGamma[2, 1])/
        4725 + (2495861031901344098308274093*CF*NC*NH*PolyGamma[2, 1])/
        8755520392324948725 + CA*CF*NC*
        (-1042644212893701030613632825323970041304663551127029335771201/
          7322826913588271157487200513571254761750400000 - 
         (949629758*lm^2)/45 + (32770954910310322878409970867*Pi^2)/
          266471344339200 - (875171636678776473110753777*Pi^3)/
          (23125691956870975680*Sqrt[3]) - (17456402621*Pi^4)/16200 + 
         lm*(-52839567109042399/650501280 + (3115420*Pi^2)/81) + 
         (39373004837010957259608639166529*Im[PolyLog[2, (-1)^(1/3)]])/
          (115744088244139233278400*Sqrt[3]) - 
         (587481818*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (125024519525539496158679111*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (89219490574347900*Sqrt[3]) - (125024519525539496158679111*Pi*
           Log[3]^2)/(4282535547568699200*Sqrt[3]) + 
         (2266323563418776715478621533553279*PolyGamma[2, 1])/
          36319195701496083600 - (19962722738171304113546817692963279*
           Zeta[3])/324602811582121247175) + 
       (159701492798151271596979827795212617*CF^2*NC*Zeta[3])/
        1298411246328484988700 + (890378947148252698*CF*NM*NC*Zeta[3])/
        4725 + (3332535976*CF*NC*NL*Zeta[3])/27 - 
       (8171883904717105749575189414*CF*NC*NH*Zeta[3])/8755520392324948725 + 
       CF*Log[x]*((-151820428238806843582138634626008353*NM*NC)/
          48376856642781466800 + (11551666256192*lm*NM*NC)/173745 + 
         11781952*lm^2*NM*NC + (337156543986597307*NC*NL)/1376060400 + 
         (11551666256192*lm*NC*NL)/173745 + 11781952*lm^2*NC*NL + 
         (537915546806714961862444770601315624472189*NC*NH)/
          113858776650237962190844086090000 + (11551666256192*lm*NC*NH)/
          173745 + 11781952*lm^2*NC*NH - (24175704874051472*NM*NC*Pi^2)/
          81 + (185015012*NC*NL*Pi^2)/9 - (1652610766527767651396800*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CA*NC*(8954264432133039761093932782032517495943458419971/
            8767125802068323088694994628930000 - (7078504650976*lm)/15795 - 
           64800736*lm^2 + (3021064202006766178927*Pi^2)/32432400 + 
           (125024519525539496158679111*Im[PolyLog[2, (-1)^(1/3)]])/
            (267658471723043700*Sqrt[3]) - 35345856*Zeta[3]) + 
         CF*NC*(-744994915330452425134046031393943066938056225029651/
            364712433366042240489711776563488000 + (36312564648608*lm)/
            19305 + 424150272*lm^2 - (1007021589937930712843*Pi^2)/5405400 - 
           (125024519525539496158679111*Im[PolyLog[2, (-1)^(1/3)]])/
            (133829235861521850*Sqrt[3]) + 70691712*Zeta[3])), 
      (296995391633652460073206925102267857339835315548102548924791089*CF^2*
         NC)/205039153580471592409641614379995133329011200000 - 
       (1856370173692386013*CF^2*lm*NC)/17044037010 - 
       (3640986016*CF^2*lm^2*NC)/35 + 
       (94649196801547901412045335413358655785897785811*CF*NM*NC)/
        113321583795175163217828018000000 - (3998817687833215909*CF*lm*NM*
         NC)/613585332360 - (910246504*CF*lm^2*NM*NC)/315 + 
       (345309893907833075782307*CF*NC*NL)/5315182941568500 - 
       (3998817687833215909*CF*lm*NC*NL)/613585332360 - 
       (910246504*CF*lm^2*NC*NL)/315 + 
       (207608225352960099471719579822466410309643172492462073*CF*NC*NH)/
        96016087153692366575444062677944773974000000 - 
       (3998817687833215909*CF*lm*NC*NH)/613585332360 - 
       (910246504*CF*lm^2*NC*NH)/315 - (2321601669885617048353648264973*CF^2*
         NC*Pi^2)/1981880623522800 + (5641280*CF^2*lm*NC*Pi^2)/63 - 
       (19016913247313697367349*CF*NM*NC*Pi^2)/25540515 + 
       (1410320*CF*lm*NM*NC*Pi^2)/567 - (139881437611823*CF*NC*NL*Pi^2)/
        25540515 + (1410320*CF*lm*NC*NL*Pi^2)/567 + 
       (1410320*CF*lm*NC*NH*Pi^2)/567 - (6139910629087581662835049411*CF^2*
         NC*Pi^3)/(89033914033953256368*Sqrt[3]) - 
       (5358198653296317683682620*CF*NC*NH*Pi^3)/(16677181699666569*
         Sqrt[3]) - (1897299025*CF^2*NC*Pi^4)/1134 + 
       (6248282344974361752119097727237169*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15596515890897761684264400*Sqrt[3]) + 
       (1800763866503627299482521828*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (817181903283661881*Sqrt[3]) - (1407383080*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/7 - (6139910629087581662835049411*CF^2*
         NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2404465270978675905*
         Sqrt[3]) - (17146235690548216587784384*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1441237924662543*Sqrt[3]) - 
       (6139910629087581662835049411*CF^2*NC*Pi*Log[3]^2)/
        (115414333006976443440*Sqrt[3]) - (1071639730659263536736524*CF*NC*
         NH*Pi*Log[3]^2)/(4323713773987629*Sqrt[3]) - 
       (CF*NC*(-(CA*(106793696811281018686735465604317 + 
             6435435796271311983753600*lm)) + 
          52*(CF*(4107450534233100992999981847097 + 810054855474710599353600*
               lm) + 924*(21*(134549191329584886714323599 + 
                1159633259286044400*lm)*NM + 21130081830*(1390577303 + 
                1152494280*lm)*NL + (5455788004051105619 + 
                24352298445006932400*lm)*NH)))*Log[x]^2)/15194418113674800 - 
       (CF*NC*(-2173794078104804760081*CA + 4347596637964737165202*CF + 
          68640*(39821636915479226*NM - 909647271*NL))*Log[x]^3)/1216215 - 
       (29576750204279355270403923702481151*CF^2*NC*PolyGamma[2, 1])/
        49030914197019712860 - (915439945280984623*CF*NM*NC*PolyGamma[2, 1])/
        2450 - (67165413460815169415239235087*CF*NC*NH*PolyGamma[2, 1])/
        367731856477647846450 + CA*CF*NC*
        (-421868494343243719587593947790664289578472484185781147318111/
          582497595399067023891027313579531628775600000 + 
         (5006355772*lm^2)/315 + (546259220607457028335900556161*Pi^2)/
          932649705187200 + (6139910629087581662835049411*Pi^3)/
          (178067828067906512736*Sqrt[3]) + (1901812049*Pi^4)/2268 + 
         lm*(6255439520909450533/111560969520 - (7756760*Pi^2)/567) - 
         (6248282344974361752119097727237169*Im[PolyLog[2, (-1)^(1/3)]])/
          (31193031781795523368528800*Sqrt[3]) + 
         (703691540*Im[PolyLog[2, (-1)^(1/3)]]^2)/7 + 
         (6139910629087581662835049411*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4808930541957351810*Sqrt[3]) + (6139910629087581662835049411*Pi*
           Log[3]^2)/(230828666013952886880*Sqrt[3]) + 
         (29576750204279355270403923702481151*PolyGamma[2, 1])/
          98061828394039425720 - (1018218128286389335862658687123959089*
           Zeta[3])/3505710365086909469490) + 
       (407287376211698374994521278531428209*CF^2*NC*Zeta[3])/
        701142073017381893898 + (4149999174269477593*CF*NM*NC*Zeta[3])/
        11025 - (18013792688*CF*NC*NL*Zeta[3])/189 + 
       (16269243380960056902682992913*CF*NC*NH*Zeta[3])/
        183865928238823923225 + CF*Log[x]*
        ((-13213715329085148335280296009335863443*NM*NC)/
          2116487478121689172500 - (406785862100146*lm*NM*NC)/8513505 - 
         9137024*lm^2*NM*NC - (4233554478873808657*NC*NL)/23599435860 - 
         (406785862100146*lm*NC*NL)/8513505 - 9137024*lm^2*NC*NL - 
         (1399726822071278704126529408046485433049583*NC*NH)/
          597758577413749301501931451972500 - (406785862100146*lm*NC*NH)/
          8513505 - 9137024*lm^2*NC*NH - (318573106848796400*NM*NC*Pi^2)/
          567 - (1000452856*NC*NL*Pi^2)/63 + (17146235690548216587784384*NC*
           NH*Im[PolyLog[2, (-1)^(1/3)]])/(4323713773987629*Sqrt[3]) + 
         CF*NC*(-2435222170926779744241914388488778153474442360031747/
            255298703356229568342798243594441600 - (1251167634106504*lm)/
            945945 - 328932864*lm^2 - (3381458011021860226129*Pi^2)/3783780 + 
           (6139910629087581662835049411*Im[PolyLog[2, (-1)^(1/3)]])/
            (7213395812936027715*Sqrt[3]) - 54822144*Zeta[3]) + 
         CA*NC*(3044027828238208812050073167251863282377684125595353/
            638246758390573920856995608986104000 + (252894448919513*lm)/
            773955 + 50253632*lm^2 + (10144374341327967809657*Pi^2)/
            22702680 - (6139910629087581662835049411*Im[PolyLog[2, (-1)^
                (1/3)]])/(14426791625872055430*Sqrt[3]) + 27411072*Zeta[3])), 
      (1750849940964554769347357247999643249347536736688788224979431797*CF^2*
         NC)/410078307160943184819283228759990266658022400000 + 
       (1335355734339177*CF^2*lm*NC)/4008004 + (1217764944*CF^2*lm^2*NC)/5 + 
       (41745591303730570061418136530588213815454527*CF*NM*NC)/
        5878285288680110136831000000 + (4191473393783927*CF*lm*NM*NC)/
        240480240 + (33826804*CF*lm^2*NM*NC)/5 - 
       (1948662873806510475036539*CF*NC*NL)/11699027003664000 + 
       (4191473393783927*CF*lm*NC*NL)/240480240 + (33826804*CF*lm^2*NC*NL)/
        5 - (284980134738270856824111458300059644856034658079878834919*CF*NC*
         NH)/33453376422734330405835789209319929892169800000 + 
       (4191473393783927*CF*lm*NC*NH)/240480240 + (33826804*CF*lm^2*NC*NH)/
        5 - (58581069412695344824574383159*CF^2*NC*Pi^2)/17384917750200 - 
       416160*CF^2*lm*NC*Pi^2 - (468960352499116042307*CF*NM*NC*Pi^2)/
        90090 - 11560*CF*lm*NM*NC*Pi^2 + (1843559687636*CF*NC*NL*Pi^2)/
        135135 - 11560*CF*lm*NC*NL*Pi^2 - 11560*CF*lm*NC*NH*Pi^2 + 
       (134072387054784426416361104917*CF^2*NC*Pi^3)/(890339140339532563680*
         Sqrt[3]) + (21465069034092619131031640*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) + (77078209457*CF^2*NC*Pi^4)/18900 - 
       (41240644601573131268341765465477159*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(31193031781795523368528800*Sqrt[3]) - 
       (112290050593335278481083602174*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (16693858881366235569*Sqrt[3]) + (15337861516*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + (134072387054784426416361104917*
         CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (24044652709786759050*Sqrt[3]) + (9812602987013768745614464*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) + 
       (134072387054784426416361104917*CF^2*NC*Pi*Log[3]^2)/
        (1154143330069764434400*Sqrt[3]) + (613287686688360546600904*CF*NC*
         NH*Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((-102399675157221242004684228691417*CF*NC)/2532403018945800 + 
         CA*(1023996930940161168025585943218591/50648060378916000 - 
           1111311828*lm)*NC + 7274041056*CF*lm*NC - 
         (6148070160766385793954193*NM*NC)/98423325 + 202056696*lm*NM*NC + 
         (1294818838*NC*NL)/5 + 202056696*lm*NC*NL + 
         (1290219372019463267*NC*NH)/29113619535 + 202056696*lm*NC*NH)*
        Log[x]^2 - (CF*NC*(-146297258110602151904371*CA + 
          20*(14629698420118196876261*CF + 385945560*(59112097249751*NM + 
              495237*NL)))*Log[x]^3)/28378350 - 
       (2556665251628373779402450643017290943*CF^2*NC*PolyGamma[2, 1])/
        1470927425910591385800 - (13007302527276826907*CF*NM*NC*
         PolyGamma[2, 1])/4725 + (2922896359588732735207797571*CF*NC*NH*
         PolyGamma[2, 1])/5253312235394969235 + 
       CA*CF*NC*
        (-109428113245438508994422746526721150394244559772105172560542121/
          51259788395117898102410403594998783332252800000 - 
         (186047422*lm^2)/5 + (55135123801047259410326624929*Pi^2)/
          32724551059200 - (134072387054784426416361104917*Pi^3)/
          (1780678280679065127360*Sqrt[3]) - (77427783857*Pi^4)/37800 + 
         lm*(-1252423737742027/8744736 + 63580*Pi^2) + 
         (41240644601573131268341765465477159*Im[PolyLog[2, (-1)^(1/3)]])/
          (62386063563591046737057600*Sqrt[3]) - 
         (7668930758*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
         (134072387054784426416361104917*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(48089305419573518100*Sqrt[3]) - 
         (134072387054784426416361104917*Pi*Log[3]^2)/(2308286660139528868800*
           Sqrt[3]) + (2556665251628373779402450643017290943*PolyGamma[2, 1])/
          2941854851821182771600 - (22072544913230062121837036721063364816*
           Zeta[3])/26292827738151821021175) + 
       (176580313038237707550249721880627541713*CF^2*NC*Zeta[3])/
        105171310952607284084700 + (11970821157386193386*CF*NM*NC*Zeta[3])/
        4725 + 246474840*CF*NC*NL*Zeta[3] - (9741653118791665862983581178*CF*
         NC*NH*Zeta[3])/5253312235394969235 + 
       CF*Log[x]*((-1333088367765426523883429755957579*NM*NC)/
          32529691924730000 + (5660185764566*lm*NM*NC)/45045 + 
         22139712*lm^2*NM*NC + (748608465528648623*NC*NL)/1545944400 + 
         (5660185764566*lm*NC*NL)/45045 + 22139712*lm^2*NC*NL + 
         (537252356813818817933173430192847132855332683*NC*NH)/
          57453138697710075721499925841014000 + (5660185764566*lm*NC*NH)/
          45045 + 22139712*lm^2*NC*NH - 4019622622873600*NM*NC*Pi^2 + 
         41056020*NC*NL*Pi^2 - (9812602987013768745614464*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CA*NC*(5431327453455240213404920181717133213602329650281969/
            398904223994108700535622255616315000 - (3464727726763*lm)/4095 - 
           121768416*lm^2 + (13933069824488087978557*Pi^2)/10810800 + 
           (134072387054784426416361104917*Im[PolyLog[2, (-1)^(1/3)]])/
            (144267916258720554300*Sqrt[3]) - 66419136*Zeta[3]) + 
         CF*NC*(-69520993001433615278723948125440189945669004758517069/
            2552987033562295683427982435944416000 + (17820540310904*lm)/
            5005 + 797029632*lm^2 - (292594474221988680262559*Pi^2)/
            113513400 - (134072387054784426416361104917*
             Im[PolyLog[2, (-1)^(1/3)]])/(72133958129360277150*Sqrt[3]) + 
           132838272*Zeta[3])), 
      (2670824977677325688937634641363650241925386674583396012800293873*CF^2*
         NC)/126741235042873923879586162734887101645680000000 - 
       (8952328377510807407*CF^2*lm*NC)/47344547250 - 
       (6317628672*CF^2*lm^2*NC)/35 + 
       (9758371562347460425104027895665043864826217939299*CF*NM*NC)/
        764920690617432351720339121500000 - (19278581717884978607*CF*lm*NM*
         NC)/1704403701000 - (526469056*CF*lm^2*NM*NC)/105 + 
       (733204133840701759974440837*CF*NC*NL)/5527790259231240000 - 
       (19278581717884978607*CF*lm*NC*NL)/1704403701000 - 
       (526469056*CF*lm^2*NC*NL)/105 + 
       (11062000989432154665197738121835014471397942027739677491349*CF*NC*
         NH)/2634453393290328519459568400233944479008371750000 - 
       (19278581717884978607*CF*lm*NC*NH)/1704403701000 - 
       (526469056*CF*lm^2*NC*NH)/105 - (104246080824322558176470277208013*
         CF^2*NC*Pi^2)/6606268745076000 + (5123392*CF^2*lm*NC*Pi^2)/35 - 
       (145812421638470286081233*CF*NM*NC*Pi^2)/14189175 + 
       (1280848*CF*lm*NM*NC*Pi^2)/315 - (143240424294854*CF*NC*NL*Pi^2)/
        14189175 + (1280848*CF*lm*NC*NL*Pi^2)/315 + 
       (1280848*CF*lm*NC*NH*Pi^2)/315 - (66811189499834925550443392839*CF^2*
         NC*Pi^3)/(500815766440987067070*Sqrt[3]) - 
       (93690503651232483812431240*CF*NC*NH*Pi^3)/(150094635296999121*
         Sqrt[3]) - (14834581004*CF^2*NC*Pi^4)/4725 + 
       (270119470069042164279672269080961657*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(350921607545199637895949000*Sqrt[3]) + 
       (110891770695813772605619012668476*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(26292827738151821021175*Sqrt[3]) - 
       (12869291584*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
       (534489515998679404403547142712*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(108200937194040415725*
         Sqrt[3]) - (299809611683943948199779968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(12971141321962887*Sqrt[3]) - 
       (66811189499834925550443392839*CF^2*NC*Pi*Log[3]^2)/
        (649205623164242494350*Sqrt[3]) - (18738100730246496762486248*CF*NC*
         NH*Pi*Log[3]^2)/(38913423965888661*Sqrt[3]) - 
       (CF*NC*(-1827*CA*(57087141066436523619118607738269 + 
            507214067173303296206400*lm) + 
          2*(87*CF*(1198829990781348297871529225049191 + 
              34859439525728844721094400*lm) + 
            40040*(1015*(1671285316561839699447023779 + 2072893744691549208*
                 lm)*NM + 11*(10284291576*(22394407169 + 18598418545*lm)*
                 NL + (45211470804543282307 + 191271559169265676920*lm)*
                 NH))))*Log[x]^2)/1101595313241423000 + 
       (2*CF*NC*(34473429761944745485131*CA - 7*(9849554355223409989271*CF + 
            2288*(2778146272111237803*NM - 9033517579*NL)))*Log[x]^3)/
        2837835 - (4545811640574849626097601990784280844*CF^2*NC*
         PolyGamma[2, 1])/551597784716471769675 - 
       (20878644694520405939*CF*NM*NC*PolyGamma[2, 1])/3969 - 
       (576616866326319521194182821408*CF*NC*NH*PolyGamma[2, 1])/
        1654793354149415309025 + CA*CF*NC*
        (-60761269032915395853674753875851683427699371845612239660967947517/
          5766726194450763536521170404437363124878440000000 + 
         (2895579808*lm^2)/105 + (2044040802615838167445636338521*Pi^2)/
          259069362552000 + (66811189499834925550443392839*Pi^3)/
          (1001631532881974134140*Sqrt[3]) + (7432660678*Pi^4)/4725 + 
         lm*(30155136960410751407/309891582000 - (7044664*Pi^2)/315) - 
         (270119470069042164279672269080961657*Im[PolyLog[2, (-1)^(1/3)]])/
          (701843215090399275791898000*Sqrt[3]) + 
         (6434645792*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
         (267244757999339702201773571356*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(108200937194040415725*Sqrt[3]) + 
         (66811189499834925550443392839*Pi*Log[3]^2)/(1298411246328484988700*
           Sqrt[3]) + (2272905820287424813048800995392140422*PolyGamma[2, 1])/
          551597784716471769675 - (308148413513028293520898273517265075172*
           Zeta[3])/78878483214455463063525) + 
       (616296854233849427651860866570319243118*CF^2*NC*Zeta[3])/
        78878483214455463063525 + (102365953338510210562*CF*NM*NC*Zeta[3])/
        19845 - (176463577072*CF*NC*NL*Zeta[3])/945 + 
       (360215080386856931681091871424*CF*NC*NH*Zeta[3])/
        1654793354149415309025 + CF*Log[x]*
        ((-3186505629676577964149074629736194387007*NM*NC)/
          38096774606190405105000 - (46635497898488*lm*NM*NC)/525525 - 
         16868352*lm^2*NM*NC - (5350209797669130255577*NC*NL)/
          15339633309000 - (46635497898488*lm*NC*NL)/525525 - 
         16868352*lm^2*NC*NL - 
         (41169149480565602778384450390493481394975962291*NC*NH)/
          9048869344889336926136238319959705000 - (46635497898488*lm*NC*NH)/
          525525 - 16868352*lm^2*NC*NH - (1481678019005391520*NM*NC*Pi^2)/
          189 - (88208733272*NC*NL*Pi^2)/2835 + 
         (299809611683943948199779968*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (38913423965888661*Sqrt[3]) + 
         CF*NC*(-17989023421040280143863814301850936214221710811472674301/
            143605520637879132192824012021873400000 - (431087234852256*lm)/
            175175 - 607260672*lm^2 - (34473430598786444624006*Pi^2)/
            2837835 + (534489515998679404403547142712*
             Im[PolyLog[2, (-1)^(1/3)]])/(324602811582121247175*Sqrt[3]) - 
           101210112*Zeta[3]) + CA*NC*
          (642465125724694218170115349379414769240076811333736767/
            10257537188419938013773143715848100000 + (28958947566844*lm)/
            47775 + 92775936*lm^2 + (86183576873787467253083*Pi^2)/14189175 - 
           (267244757999339702201773571356*Im[PolyLog[2, (-1)^(1/3)]])/
            (324602811582121247175*Sqrt[3]) + 50605056*Zeta[3])), 
      (728580772215238643492191542466331195814571998638813072660404003*CF^2*
         NC)/11851128471541457817311952879106326387648000000 + 
       (7681053197967135671*CF^2*lm*NC)/13527013500 + 
       (2075706528*CF^2*lm^2*NC)/5 + 
       (21537195941646586096296465718195010479081719354169*CF*NM*NC)/
        218548768747837814777239749000000 + (14466596502654883271*CF*lm*NM*
         NC)/486972486000 + (172975544*CF*lm^2*NM*NC)/15 - 
       (526070624812466168540669591*CF*NC*NL)/1579368645494640000 + 
       (14466596502654883271*CF*lm*NC*NL)/486972486000 + 
       (172975544*CF*lm^2*NC*NL)/15 - 
       (14293634466161908627968640037080313438262870923650815417043621*CF*NC*
         NH)/879361356185010385694341761471926498309673981000000 + 
       (14466596502654883271*CF*lm*NC*NH)/486972486000 + 
       (172975544*CF*lm^2*NC*NH)/15 - (1957519032337093340634496023602203*
         CF^2*NC*Pi^2)/43412623181928000 - (3338528*CF^2*lm*NC*Pi^2)/5 - 
       (4389211435683877149667*CF*NM*NC*Pi^2)/64350 - 
       (834632*CF*lm*NM*NC*Pi^2)/45 + (16661952220262*CF*NC*NL*Pi^2)/
        675675 - (834632*CF*lm*NC*NL*Pi^2)/45 - (834632*CF*lm*NC*NH*Pi^2)/
        45 + (1479764781214567152110048583937*CF^2*NC*Pi^3)/
        (5151247883393009832720*Sqrt[3]) + (122507238079709032943238440*CF*NC*
         NH*Pi^3)/(50031545098999707*Sqrt[3]) + (3356620199*CF^2*NC*Pi^4)/
        450 - (1116633662265314462610971715799098937*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(451184923986685248723363000*Sqrt[3]) - 
       (1452029788777486323354932942378*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (113821765100224333425*Sqrt[3]) + 
       (3938194296*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (1479764781214567152110048583937*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(139115490678051963075*
         Sqrt[3]) + (56003308836438415059766144*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) + 
       (1479764781214567152110048583937*CF^2*NC*Pi*Log[3]^2)/
        (6677543552546494227600*Sqrt[3]) + (3500206802277400941235384*CF*NC*
         NH*Pi*Log[3]^2)/(1853020188851841*Sqrt[3]) + 
       CF*((-978759468862348790844316412494469*CF*NC)/1808859299247000 + 
         CA*(85641455706966056403261569254541/316550377368225 - 
           (291067856948*lm)/135)*NC + (211685714144*CF*lm*NC)/15 - 
         (10084595519558793530896854797*NM*NC)/12320810775 + 
         (52921428536*lm*NM*NC)/135 + (112913000842*NC*NL)/225 + 
         (52921428536*lm*NC*NL)/135 + (9961663767221500769*NC*NH)/
          110262893895 + (52921428536*lm*NC*NH)/135)*Log[x]^2 - 
       (CF*NC*(-197515251387363452071435*CA + 
          154*(2565132400594158927767*CF + 728*(5372661367318261941*NM + 
              6615178567*NL)))*Log[x]^3)/2837835 - 
       (937448073447087570847287073096140399329*CF^2*NC*PolyGamma[2, 1])/
        39715040499585967416600 - (516142706847978688139*CF*NM*NC*
         PolyGamma[2, 1])/14175 + (82343861041880234429003944099*CF*NC*NH*
         PolyGamma[2, 1])/78799683530924538525 + 
       CA*CF*NC*
        (-45581834103270050279645336084944963195064822498858963030685988583/
          1482872450001624909391158103998179089254456000000 - 
         (951365492*lm^2)/15 + (922239414086007804768092564129*Pi^2)/
          40905688824000 - (1479764781214567152110048583937*Pi^3)/
          (10302495766786019665440*Sqrt[3]) - (3369974311*Pi^4)/900 + 
         lm*(-21613751832984297671/88540452000 + (4590476*Pi^2)/45) + 
         (1116633662265314462610971715799098937*Im[PolyLog[2, (-1)^(1/3)]])/
          (902369847973370497446726000*Sqrt[3]) - 
         (1969097148*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (1479764781214567152110048583937*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(278230981356103926150*Sqrt[3]) - 
         (1479764781214567152110048583937*Pi*Log[3]^2)/
          (13355087105092988455200*Sqrt[3]) + 
         (937448073447087570847287073096140399329*PolyGamma[2, 1])/
          79430080999171934833200 - 
         (63584786627860424646607257909920612602139*Zeta[3])/
          5679250791440793340573800) + 
       (63584784255135282279005459013726418269497*CF^2*NC*Zeta[3])/
        2839625395720396670286900 + (472059725286789263882*CF*NM*NC*Zeta[3])/
        14175 + (63768306008*CF*NC*NL*Zeta[3])/135 - 
       (278534763440082277834065248122*CF*NC*NH*Zeta[3])/
        78799683530924538525 + CF*Log[x]*
        ((-5719612438781948531413270734839123444567*NM*NC)/
          10884792744625830030000 + (154422824922458*lm*NM*NC)/675675 + 
         40062336*lm^2*NM*NC + (4029635411736241830091*NC*NL)/
          4382752374000 + (154422824922458*lm*NC*NL)/675675 + 
         40062336*lm^2*NC*NL + 
         (866692245197147993306003239911178981716074246647*NC*NH)/
          48716882019264161266201260646953930000 + 
         (154422824922458*lm*NC*NH)/675675 + 40062336*lm^2*NC*NH - 
         (1432709698658201344*NM*NC*Pi^2)/27 + (31869129628*NC*NL*Pi^2)/
          405 - (56003308836438415059766144*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1853020188851841*Sqrt[3]) + 
         CA*NC*(66802808413885556086638820294835830290161830691991583/
            375985363124629000650302867839086720 - (94437215382829*lm)/
            61425 - 220342848*lm^2 + (1975152465308051525686063*Pi^2)/
            113513400 + (1479764781214567152110048583937*
             Im[PolyLog[2, (-1)^(1/3)]])/(834692944068311778450*Sqrt[3]) - 
           120187008*Zeta[3]) + CF*NC*
          (-5248792107336860471207236240535945931630814766908881931/
            14770853551324710739833326950821264000 + (486857225118632*lm)/
            75075 + 1442244096*lm^2 - (56432927796043869517807*Pi^2)/
            1621620 - (1479764781214567152110048583937*
             Im[PolyLog[2, (-1)^(1/3)]])/(417346472034155889225*Sqrt[3]) + 
           240374016*Zeta[3])), (59973575328358857177041461573387221660879560\
51187897743186055827024178761*CF^2*NC)/
        20252834662530192752478934799110490292383079335040000000 - 
       (12348425739948015941*CF^2*lm*NC)/38846808000 - 
       (10615770972*CF^2*lm^2*NC)/35 + 
       (148011364350579697161037687918549056384284976952522083277*CF*NM*NC)/
        795974430867991792047246968928576000000 - 
       (26585658698181901541*CF*lm*NM*NC)/1398485088000 - 
       (294882527*CF*lm^2*NM*NC)/35 + (15267916076269002649825727033*CF*NC*
         NL)/58963096098466560000 - (26585658698181901541*CF*lm*NC*NL)/
        1398485088000 - (294882527*CF*lm^2*NC*NL)/35 + 
       (52595452738100535889800344602984610380099284472746627309818052419*CF*
         NC*NH)/6697216088705039097448106855370192211126477039296000000 - 
       (26585658698181901541*CF*lm*NC*NH)/1398485088000 - 
       (294882527*CF*lm^2*NC*NH)/35 - (24084304890883427749738229110660219*
         CF^2*NC*Pi^2)/115766995151808000 + (8137662*CF^2*lm*NC*Pi^2)/35 - 
       (1162468896666060515963239*CF*NM*NC*Pi^2)/8408400 + 
       (1356277*CF*lm*NM*NC*Pi^2)/210 - (6533584867421*CF*NC*NL*Pi^2)/
        363825 + (1356277*CF*lm*NC*NL*Pi^2)/210 + 
       (1356277*CF*lm*NC*NH*Pi^2)/210 - (35798131415586620911369644599947*
         CF^2*NC*Pi^3)/(144234940735004275316160*Sqrt[3]) - 
       (38952809306427051801272615*CF*NC*NH*Pi^3)/(33354363399333138*
         Sqrt[3]) - (23825287823*CF^2*NC*Pi^4)/4200 + 
       (72083885511637098475788902970462669553*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(50532711486508747857016656000*
         Sqrt[3]) + (273223243366537024045500573945763*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(35057103650869094694900*Sqrt[3]) - 
       (22732455114*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
       (35798131415586620911369644599947*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3895233738985454966100*
         Sqrt[3]) - (62324494890283282882036184*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1441237924662543*Sqrt[3]) - 
       (35798131415586620911369644599947*CF^2*NC*Pi*Log[3]^2)/
        (186971219471301838372800*Sqrt[3]) - (7790561861285410360254523*CF*NC*
         NH*Pi*Log[3]^2)/(8647427547975258*Sqrt[3]) - 
       (CF*NC*(-31*CA*(7333670868257738250581345544153106579 + 
            9424670822474787458068089600*lm) + 
          4*(31*CF*(3666835446734415051336469748888651861 + 
              15422188618595106749565964800*lm) + 
            20020*(217*(17387931766055005712027081282417 + 
                3056901158086973889120*lm)*NM + 33315962560452*(
                23933120439 + 19910802520*lm)*NL + 
              (164447835839620975842793 + 663347551304873333939040*lm)*NH)))*
         Log[x]^2)/182130425122581936000 - 
       (CF*NC*(-1221962981172753568183457*CA + 2443926075603406868949922*CF + 
          32032*(50315185471975593849*NM - 22968532907*NL))*Log[x]^3)/
        3783780 - (17485847696844042331609267128029311957093*CF^2*NC*
         PolyGamma[2, 1])/158860161998343869666400 - 
       (793618474183750694201*CF*NM*NC*PolyGamma[2, 1])/11025 - 
       (5094011903690480765007239263087*CF*NC*NH*PolyGamma[2, 1])/
        7943008099917193483320 + CA*CF*NC*
        (-2398943017366104608101766076545933314352884657962779120012252568649\
5226169/162022677300241542019831478392883922339064634680320000000 + 
         (3243707797*lm^2)/70 + (22693516524438505704551297291539*Pi^2)/
          218163673728000 + (35798131415586620911369644599947*Pi^3)/
          (288469881470008550632320*Sqrt[3]) + (23868688687*Pi^4)/8400 + 
         lm*(41581615669863987941/254270016000 - (14919047*Pi^2)/420) - 
         (72083885511637098475788902970462669553*Im[PolyLog[2, (-1)^(1/3)]])/
          (101065422973017495714033312000*Sqrt[3]) + 
         (11366227557*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
         (35798131415586620911369644599947*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(7790467477970909932200*Sqrt[3]) + 
         (35798131415586620911369644599947*Pi*Log[3]^2)/
          (373942438942603676745600*Sqrt[3]) + 
         (17485847696844042331609267128029311957093*PolyGamma[2, 1])/
          317720323996687739332800 - 
         (1167725571418920245910588880658180412853603*Zeta[3])/
          22717003165763173362295200) + 
       (1167725578728106216707057993460634361127219*CF^2*NC*Zeta[3])/
        11358501582881586681147600 + (253601686400093765896*CF*NM*NC*
         Zeta[3])/3675 - (110827998374*CF*NC*NL*Zeta[3])/315 + 
       (1900953861601373732382009888449*CF*NC*NH*Zeta[3])/
        3971504049958596741660 + CF*Log[x]*
        ((-187174725361780138747065907389890659769273873*NM*NC)/
          170876733033632697030960000 - (154179228515369*lm*NM*NC)/970200 - 
         30046752*lm^2*NM*NC - (26697564359084562608437*NC*NL)/
          40905688824000 - (154179228515369*lm*NC*NL)/970200 - 
         30046752*lm^2*NC*NL - 
         (10122649365397509214433425052077359944507053167509*NC*NH)/
          1189191581598448244241630772715388240000 - 
         (154179228515369*lm*NC*NH)/970200 - 30046752*lm^2*NC*NH - 
         (6708691400606841188*NM*NC*Pi^2)/63 - (55401792694*NC*NL*Pi^2)/
          945 + (62324494890283282882036184*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4323713773987629*Sqrt[3]) + 
         CF*NC*
          (-28052486798826200859091956774373995631540938127775015605393411/
            17391202971329714425079759151896956233600000 - 
           (118954669976969*lm)/26950 - 1081683072*lm^2 - 
           (2443925970928201519967341*Pi^2)/15135120 + 
           (35798131415586620911369644599947*Im[PolyLog[2, (-1)^(1/3)]])/
            (11685701216956364898300*Sqrt[3]) - 180280512*Zeta[3]) + 
         CA*NC*(2805248682111516707459505071489618862089340175176635109654621\
1/34782405942659428850159518303793912467200000 + (191280957884969*lm)/
            176400 + 165257136*lm^2 + (12219629862203041355941247*Pi^2)/
            151351200 - (35798131415586620911369644599947*
             Im[PolyLog[2, (-1)^(1/3)]])/(23371402433912729796600*Sqrt[3]) + 
           90140256*Zeta[3])), (135688699295454208996148515976470059189116633\
109898154509468484475643986889*CF^2*NC)/
        158500445185018899802009054949560358809954533926400000000 + 
       (1626073528610603209*CF^2*lm*NC)/1731457728 + 
       (3433426692*CF^2*lm^2*NC)/5 + 
       (1855557085861018497509678573092377323003799682225575649*CF*NM*NC)/
        1392375097728265525447079245939200000 + 
       (15313707734809740941*CF*lm*NM*NC)/311662391040 + 
       (286118891*CF*lm^2*NM*NC)/15 - (322630706174302017398817829*CF*NC*
         NL)/505397966558284800 + (15313707734809740941*CF*lm*NC*NL)/
        311662391040 + (286118891*CF*lm^2*NC*NL)/15 - 
       (36818401894927694665081761571468780000410729905287415315999220977*CF*
         NC*NH)/1230100914251945956674142075476157753064046803136000000 + 
       (15313707734809740941*CF*lm*NC*NH)/311662391040 + 
       (286118891*CF*lm^2*NC*NH)/15 - (574539678518545452599164669443543047*
         CF^2*NC*Pi^2)/972442759275187200 - 1043290*CF^2*lm*NC*Pi^2 - 
       (2847276454404879804695669*CF*NM*NC*Pi^2)/3243240 - 
       (521645*CF*lm*NM*NC*Pi^2)/18 + (279670101376181*CF*NC*NL*Pi^2)/
        6486480 - (521645*CF*lm*NC*NL*Pi^2)/18 - (521645*CF*lm*NC*NH*Pi^2)/
        18 + (1370855302432930315788318541809617*CF^2*NC*Pi^3)/
        (2596228933230076955690880*Sqrt[3]) + 
       (2025000437204647914639598250*CF*NC*NH*Pi^3)/(450283905890997363*
         Sqrt[3]) + (332082960583*CF^2*NC*Pi^4)/25200 - 
       (4075530772929836042360177416974169253123*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(909588806757157461426299808000*
         Sqrt[3]) - (52704939219003805168648908140657*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2253670948984441801815*Sqrt[3]) + 
       (47953026063*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
       (1370855302432930315788318541809617*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(70114207301738189389800*
         Sqrt[3]) + (925714485579267618120959200*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) + 
       (1370855302432930315788318541809617*CF^2*NC*Pi*Log[3]^2)/
        (3365481950483433090710400*Sqrt[3]) + 
       (57857155348704226132559950*CF*NC*NH*Pi*Log[3]^2)/
        (16677181699666569*Sqrt[3]) + 
       CF*((-3880819230359866108578874360380264023*CF*NC)/
          547376553163440000 + CA*(2469612246494278156567031841516750181/
            696661067662560000 - (108738868612*lm)/27)*NC + 
         (79082813536*CF*lm*NC)/3 - (66249369340913578573406761612577*NM*NC)/
          6288541819560 + (19770703384*lm*NM*NC)/27 + (126426523678*NC*NL)/
          135 + (19770703384*lm*NC*NL)/27 + (171932572121386215377377*NC*
           NH)/974723982031800 + (19770703384*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-52177697910382295120643653*CA + 
          26*(4013668897763058547717751*CF + 215600*(27852045098637078801*
               NM + 4942675846*NL)))*Log[x]^3)/56756700 - 
       (448116461609408426794379000884835137772063*CF^2*NC*PolyGamma[2, 1])/
        1429741457985094826997600 - (76645986071088631339*CF*NM*NC*
         PolyGamma[2, 1])/162 + (2689938469269335231339936523253*CF*NC*NH*
         PolyGamma[2, 1])/1418394303556641693450 + 
       CA*CF*NC*(-67844349555146794422391162263241340120567289916582297176752\
365856492769257/158500445185018899802009054949560358809954533926400000000 - 
         (3147307801*lm^2)/30 + (8893803072010789289333686583706773*Pi^2)/
          30106586974464000 - (1370855302432930315788318541809617*Pi^3)/
          (5192457866460153911381760*Sqrt[3]) - (333251445383*Pi^4)/50400 + 
         lm*(-4575971810805371113/11333177856 + (5738095*Pi^2)/36) + 
         (4075530772929836042360177416974169253123*
           Im[PolyLog[2, (-1)^(1/3)]])/(1819177613514314922852599616000*
           Sqrt[3]) - (47953026063*Im[PolyLog[2, (-1)^(1/3)]]^2)/70 - 
         (1370855302432930315788318541809617*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(140228414603476378779600*
           Sqrt[3]) - (1370855302432930315788318541809617*Pi*Log[3]^2)/
          (6730963900966866181420800*Sqrt[3]) + 
         (448116461609408426794379000884835137772063*PolyGamma[2, 1])/
          2859482915970189653995200 - 
         (1868653515136015347477085859622543028059779*Zeta[3])/
          12778314280741785016291050) + 
       (1494922804276886251547452225699825017980737*CF^2*NC*Zeta[3])/
        5111325712296714006516420 + (34762193852241098255*CF*NM*NC*Zeta[3])/
        81 + (23565983746*CF*NC*NL*Zeta[3])/27 - 
       (4606636768162147856155326867047*CF*NC*NH*Zeta[3])/
        709197151778320846725 + CF*Log[x]*
        ((-97053729275719224344033362671095749265707649*NM*NC)/
          14646577117168516888368000 + (28958337592819*lm*NM*NC)/72072 + 
         70109088*lm^2*NM*NC + (421918450960640829511*NC*NL)/250442992800 + 
         (28958337592819*lm*NC*NL)/72072 + 70109088*lm^2*NC*NL + 
         (149874271232694393282621039629188108144351879020787*NC*NH)/
          4586881814736871799217718694759354640000 + 
         (28958337592819*lm*NC*NH)/72072 + 70109088*lm^2*NC*NH - 
         (18568030067399320186*NM*NC*Pi^2)/27 + (11778297068*NC*NL*Pi^2)/
          81 - (925714485579267618120959200*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CA*NC*
          (309577668196683805960711768982814636737320675370399231721164647/
            136105066732145591152798115101802266176000000 - 
           (35389304016883*lm)/13104 - 385599984*lm^2 + 
           (29815827273411509507759213*Pi^2)/129729600 + 
           (1370855302432930315788318541809617*Im[PolyLog[2, (-1)^(1/3)]])/
            (420685243810429136338800*Sqrt[3]) - 210327264*Zeta[3]) + 
         CF*NC*
          (-44225381192419372424347565893430526746925732613341012719991121/
            9721790480867542225199865364414447584000000 + (22852747446163*lm)/
            2002 + 2523927168*lm^2 - (208710791025234614246419423*Pi^2)/
            454053600 - (1370855302432930315788318541809617*
             Im[PolyLog[2, (-1)^(1/3)]])/(210342621905214568169400*Sqrt[3]) + 
           420654528*Zeta[3])), (16577777385268269027046725474832302025535875\
2096178683091564028710794849558903659*CF^2*NC)/
        41027949425337714115658796368820441908426133519972011520000000 - 
       (4547445983360722264649*CF^2*lm*NC)/8756847459360 - 
       (17336366688*CF^2*lm^2*NC)/35 + 
       (7143778999735845764960475975387914804046763830656734041222409*CF*NM*
         NC)/2736100877306347324255330898232831648000000 - 
       (9788571744079815117257*CF*lm*NM*NC)/315246508536960 - 
       (1444697224*CF*lm^2*NM*NC)/105 + (62112831936659047975420396273*CF*NC*
         NL)/127802510793426268800 - (9788571744079815117257*CF*lm*NC*NL)/
        315246508536960 - (1444697224*CF*lm^2*NC*NL)/105 + 
       (679854315752115835834909469210829991051041795302027043197469872209*CF*
         NC*NH)/47865397339862485314114410760439903155992174133792000000 - 
       (9788571744079815117257*CF*lm*NC*NH)/315246508536960 - 
       (1444697224*CF*lm^2*NC*NH)/105 - 
       (4447137222866776653752971119586509431*CF^2*NC*Pi^2)/
        1653152690767818240 + (2519780*CF^2*lm*NC*Pi^2)/7 - 
       (9748155253097022184040291*CF*NM*NC*Pi^2)/5360355 + 
       (629945*CF*lm*NM*NC*Pi^2)/63 - (3981925041919453*CF*NC*NL*Pi^2)/
        128648520 + (629945*CF*lm*NC*NL*Pi^2)/63 + 
       (629945*CF*lm*NC*NH*Pi^2)/63 - (31248494096266009751701169554967*CF^2*
         NC*Pi^3)/(70056971214144933724992*Sqrt[3]) - 
       (25685815619878949239360794910*CF*NC*NH*Pi^3)/(12157665459056928801*
         Sqrt[3]) - (74934546557*CF^2*NC*Pi^4)/7560 + 
       (1067941957180590701383853364978090115453*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(417255817702886518019366102400*
         Sqrt[3]) + (457249205561854690253832646705933*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(32764908412158423118695*Sqrt[3]) - 
       1112358914*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (31248494096266009751701169554967*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1891970673221506697820*
         Sqrt[3]) - (82194609983612637565954543712*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1050662447078993847*
         Sqrt[3]) - (31248494096266009751701169554967*CF^2*NC*Pi*Log[3]^2)/
        (90814592314632321495360*Sqrt[3]) - (5137163123975789847872158982*CF*
         NC*NH*Pi*Log[3]^2)/(3151987341236981541*Sqrt[3]) - 
       (CF*NC*(-(CA*(149924113709818586491377292981052713439497 + 
             27406663453375301222023792896000*lm)) + 
          32*(CF*(9370257111461256130027591609875115825012 + 
              5605908433644947977232139456000*lm) + 
            85085*(7*(10635594888254072929515806930134439 + 
                261452293441616645596800*lm)*NM + 333159625604520*(
                6593358903 + 5493360880*lm)*NL + (473478943089575548720297 + 
                1830166054091316519177600*lm)*NH)))*Log[x]^2)/
        9288651681251678736000 + (CF*NC*(405932635524884427211887621*CA - 
          17*(47756780980842204269447003*CF + 160160*(200261533387755739059*
               NM - 12673968316*NL)))*Log[x]^3)/96486390 - 
       (8580691113441611197302292746406413565921*CF^2*NC*PolyGamma[2, 1])/
        5957256074937895112490 - (95357736110636939044358*CF*NM*NC*
         PolyGamma[2, 1])/99225 - (612834839087548538292341518894517*CF*NC*
         NH*PolyGamma[2, 1])/536153046744410560124100 + 
       CA*CF*NC*(-41444443473023699864550736525984189906507870417700548609356\
560658972084848205821/
          20513974712668857057829398184410220954213066759986005760000000 + 
         (7945834732*lm^2)/105 + (2229141465138296805721600906897543*Pi^2)/
          1657295930594304 + (31248494096266009751701169554967*Pi^3)/
          (140113942428289867449984*Sqrt[3]) + (75055495997*Pi^4)/15120 + 
         lm*(15309005147219674673609/57317547006720 - (6929395*Pi^2)/126) - 
         (1067941957180590701383853364978090115453*
           Im[PolyLog[2, (-1)^(1/3)]])/(834511635405773036038732204800*
           Sqrt[3]) + 556179457*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (31248494096266009751701169554967*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3783941346443013395640*Sqrt[3]) + 
         (31248494096266009751701169554967*Pi*Log[3]^2)/
          (181629184629264642990720*Sqrt[3]) + 
         (8580691113441611197302292746406413565921*PolyGamma[2, 1])/
          11914512149875790224980 - 
         (76835963062468775253901918838542161378938221*Zeta[3])/
          115856716145392184147705520) + 
       (10976566161390776265540033066322481555022721*CF^2*NC*Zeta[3])/
        8275479724670870296264680 + (89650674834061256726984*CF*NM*NC*
         Zeta[3])/99225 - (121011976676*CF*NC*NL*Zeta[3])/189 + 
       (261297806745315427831102292685883*CF*NC*NH*Zeta[3])/
        268076523372205280062050 + CF*Log[x]*
        ((-314816515817538575930637843895836696712227757513*NM*NC)/
          22392619151634684797284440000 - (17722720750981417*lm*NM*NC)/
          64324260 - 51845376*lm^2*NM*NC - (15390789846184643185357*NC*NL)/
          13038688312650 - (17722720750981417*lm*NC*NL)/64324260 - 
         51845376*lm^2*NC*NL - 
         (86773674741076475122487886283151231263905096882575137*NC*NH)/
          5634984309404247005338967416511867175240000 - 
         (17722720750981417*lm*NC*NH)/64324260 - 51845376*lm^2*NC*NH - 
         (267015377873091115732*NM*NC*Pi^2)/189 - (60494649328*NC*NL*Pi^2)/
          567 + (82194609983612637565954543712*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(3151987341236981541*Sqrt[3]) + 
         CF*NC*
          (-36235038143326617628740490242865739498139479167893403085174135982\
1/17757505183913346535158001579033785874270200000 - (13693031254188457*lm)/
            1786785 - 1866433536*lm^2 - (33137358018579385189215823*Pi^2)/
            15752880 + (31248494096266009751701169554967*
             Im[PolyLog[2, (-1)^(1/3)]])/(5675912019664520093460*Sqrt[3]) - 
           311072256*Zeta[3]) + CA*NC*(57976061035854169173244549758551449423\
10020252613245311537783825211/
            568240165885227089125056050529081147976646400000 + 
           (21967158590863657*lm)/11695320 + 285149568*lm^2 + 
           (1623730543050577878255301597*Pi^2)/1543782240 - 
           (31248494096266009751701169554967*Im[PolyLog[2, (-1)^(1/3)]])/
            (11351824039329040186920*Sqrt[3]) + 155536128*Zeta[3])), 
      (5694668039327335988584057353084596233850660533522366332978139804889200\
2597571807*CF^2*NC)/
        4914616834445955107022127337879999696217859827148377600000000 + 
       (2859670828370642991*CF^2*lm*NC)/1891123520 + 
       (5529010032*CF^2*lm^2*NC)/5 + 
       (288247663212000364721784401596411515214494862564286988202141*CF*NM*
         NC)/16364992594884985146224661457109184000000 + 
       (598505264727389431*CF*lm*NM*NC)/7564494080 + 
       (153583612*CF*lm^2*NM*NC)/5 - (9107757781715713858378547*CF*NC*NL)/
        7728042980706048 + (598505264727389431*CF*lm*NC*NL)/7564494080 + 
       (153583612*CF*lm^2*NC*NL)/5 - 
       (369021145879388421760949108466943571510664612020897992858721897*CF*NC*
         NH)/6912117520250268643122130288835850017217328550400000 + 
       (598505264727389431*CF*lm*NC*NH)/7564494080 + 
       (153583612*CF*lm^2*NC*NH)/5 - (7280635138870501193256792059960363*
         CF^2*NC*Pi^2)/958460511808800 - 1592010*CF^2*lm*NC*Pi^2 - 
       (204282148144708512541742633*CF*NM*NC*Pi^2)/18378360 - 
       (88445*CF*lm*NM*NC*Pi^2)/2 + (384255765439889*CF*NC*NL*Pi^2)/
        5250960 - (88445*CF*lm*NC*NL*Pi^2)/2 - (88445*CF*lm*NC*NH*Pi^2)/2 + 
       (1110092164334608965478361172072167*CF^2*NC*Pi^3)/
        (1182211389238695756609240*Sqrt[3]) + 
       (194602922347877513292824520155*CF*NC*NH*Pi^3)/(24315330918113857602*
         Sqrt[3]) + (15236745734*CF^2*NC*Pi^4)/675 - 
       (31673621485855347261852106970759711057767*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4023538242134977138043887416000*
         Sqrt[3]) - (2530240767259964435947087334570206*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(60849115622579928649005*Sqrt[3]) + 
       (11572885408*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
       (317169189809888275850960334877762*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9122001460175121578775*
         Sqrt[3]) + (44480667965229145895502747464*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) + (158584594904944137925480167438881*CF^2*NC*Pi*Log[3]^2)/
        (218928035044202917890600*Sqrt[3]) + (5560083495653643236937843433*CF*
         NC*NH*Pi*Log[3]^2)/(900567811781994726*Sqrt[3]) + 
       CF*((-13147497540812339006546701877718497651311*CF*NC)/
          144233721758566440000 + 
         CA*(1643437193444171308056362619156704902877/36058430439641610000 - 
           7272927046*lm)*NC + 47604613392*CF*lm*NC - 
         (209360602341720091575975472903769*NM*NC)/1569603835800 + 
         1322350372*lm*NM*NC + (15208431098*NC*NL)/9 + 
         1322350372*lm*NC*NL + (1513765455913070681*NC*NH)/4566842280 + 
         1322350372*lm*NC*NH)*Log[x]^2 - 
       (CF*NC*(-1641129257708393123492037871*CA + 
          3282258494657459754197007682*CF + 367567200*
           (13144367869221346236*NM + 330587593*NL))*Log[x]^3)/137837700 - 
       (17493990389994023200999682119329746662848497*CF^2*NC*PolyGamma[2, 1])/
        4289224373955284480992800 - (57134520960469928208907*CF*NM*NC*
         PolyGamma[2, 1])/9450 + (127819966068485881764307970283253*CF*NC*NH*
         PolyGamma[2, 1])/38296646196029325723150 + 
       CA*CF*NC*(-19931338133979575758729103073356399463989886641894458401487\
2330089400388018339637/
          34402317841121685749154891365159997873525018790038643200000000 - 
         (844709866*lm^2)/5 + (107293570465917224220865792761048073*Pi^2)/
          28249362453312000 - (1110092164334608965478361172072167*Pi^3)/
          (2364422778477391513218480*Sqrt[3]) - (7642253017*Pi^4)/675 + 
         lm*(-894231674411502839/1375362560 + (972895*Pi^2)/4) + 
         (31673621485855347261852106970759711057767*
           Im[PolyLog[2, (-1)^(1/3)]])/(8047076484269954276087774832000*
           Sqrt[3]) - (5786442704*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
         (158584594904944137925480167438881*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(9122001460175121578775*Sqrt[3]) - 
         (158584594904944137925480167438881*Pi*Log[3]^2)/
          (437856070088405835781200*Sqrt[3]) + 
         (17493990389994023200999682119329746662848497*PolyGamma[2, 1])/
          8578448747910568961985600 - 
         (19545933089673654325780977479999164927851602329*Zeta[3])/
          10427104453085296573293496800) + 
       (19545933075478570047528523355776886511670465561*CF^2*NC*Zeta[3])/
        5213552226542648286646748400 + (25674996565711535300543*CF*NM*NC*
         Zeta[3])/4725 + 1561045738*CF*NC*NL*Zeta[3] - 
       (221241094956520293291705575283347*CF*NC*NH*Zeta[3])/
        19148323098014662861575 + CF*Log[x]*
        ((-9326449581370551761161914682848962779358780489*NM*NC)/
          113328185262471374635440000 + (599745248354881*lm*NM*NC)/875160 + 
         119082348*lm^2*NM*NC + (37721216931611253277*NC*NL)/12614906304 + 
         (599745248354881*lm*NC*NL)/875160 + 119082348*lm^2*NC*NL + 
         (19483506930565634733969580598482442041877639223061*NC*NH)/
          335066704885045161607787567504793648000 + 
         (599745248354881*lm*NC*NH)/875160 + 119082348*lm^2*NC*NH - 
         8762911912943685348*NM*NC*Pi^2 + (780257534*NC*NL*Pi^2)/3 - 
         (44480667965229145895502747464*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + CA*NC*(13636802498336708161664253447\
284373560954861125913536031476240887371/
            476474673257799111999270601375316490539424000000 - 
           (732383930851201*lm)/159120 - 654952914*lm^2 + 
           (273521542818136644983350723*Pi^2)/91891800 + 
           (158584594904944137925480167438881*Im[PolyLog[2, (-1)^(1/3)]])/
            (27366004380525364736325*Sqrt[3]) - 357247044*Zeta[3]) + 
         CF*NC*
          (-13636802499276576761055875153293717880602315283052790569878113918\
721/238237336628899555999635300687658245269712000000 + (473817451580101*lm)/
            24310 + 4286964528*lm^2 - (1641129257029453006749337489*Pi^2)/
            275675400 - (317169189809888275850960334877762*
             Im[PolyLog[2, (-1)^(1/3)]])/(27366004380525364736325*Sqrt[3]) + 
           714494088*Zeta[3])), (12759649852257189722987687539680481010768313\
3987778602818898726602581472673309740233*CF^2*NC)/
        2373759931037396316691687504196039853273226296512666380800000000 - 
       (1330023659546876565221*CF^2*lm*NC)/1608400553760 - 
       (3942545144*CF^2*lm^2*NC)/5 + 
       (60203995100311466079746936629055810071922065887656220095819723*CF*NM*
         NC)/1693776733570595962634252460810800544000000 - 
       (2862478342814947976069*CF*lm*NM*NC)/57902419935360 - 
       (985636286*CF*lm^2*NM*NC)/45 + (11697405426913198444865812111*CF*NC*
         NL)/13278182939576755200 - (2862478342814947976069*CF*lm*NC*NL)/
        57902419935360 - (985636286*CF*lm^2*NC*NL)/45 + 
       (208621396681171480539533723697706659499778572378189896124941580567*CF*
         NC*NH)/8369606620570240289210862681539777351847774448537344000 - 
       (2862478342814947976069*CF*lm*NC*NH)/57902419935360 - 
       (985636286*CF*lm^2*NC*NH)/45 - 
       (60538348615596076834919243938447763213*CF^2*NC*Pi^2)/
        1771235025822662400 + (4902380*CF^2*lm*NC*Pi^2)/9 - 
       (775682596401992228906338367*CF*NM*NC*Pi^2)/33081048 + 
       (1225595*CF*lm*NM*NC*Pi^2)/81 - (61270833289493*CF*NC*NL*Pi^2)/
        1181466 + (1225595*CF*lm*NC*NL*Pi^2)/81 + 
       (1225595*CF*lm*NC*NH*Pi^2)/81 - (501179751589975462283167900219439*
         CF^2*NC*Pi^3)/(644842575948379503605040*Sqrt[3]) - 
       (405784987872316425582431446420*CF*NC*NH*Pi^3)/(109418989131512359209*
         Sqrt[3]) - (68080262813*CF^2*NC*Pi^4)/4050 + 
       (778693104352268161075466697721724252161*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(174575006373625041113474454000*
         Sqrt[3]) + (292341758415765069377090043149003*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(12036088804466359512990*Sqrt[3]) - 
       (27795393208*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (71597107369996494611881128602777*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2487818580047760430575*
         Sqrt[3]) - (185501708741630365980540089792*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (71597107369996494611881128602777*CF^2*NC*Pi*Log[3]^2)/
        (119415291842292500667600*Sqrt[3]) - (11593856796351897873783755612*
         CF*NC*NH*Pi*Log[3]^2)/(4052555153018976267*Sqrt[3]) - 
       (CF*NC*(-4*CA*(510224769465701314829055070898660650894159 + 
            13074108039735890308284483360000*lm) + 
          7*(CF*(583114022286743962178687323966691674035191 + 
              48900559940830342971245859840000*lm) + 
            8751600*((45710548780830551296338743587870357 + 
                155211491298195450518400*lm)*NM + 45*(6169622696380*
                 (670144943 + 559052704*lm)*NL + (927287871945789225163 + 
                  3449144251071010011520*lm)*NH))))*Log[x]^2)/
        9952126801341084360000 - (CF*NC*(-3709097920036934341807232719*CA + 
          7418195847626503874531287343*CF + 462862400*
           (10932825522786091935*NM - 94839298*NL))*Log[x]^3)/68918850 - 
       (119043217637555702015715117409508627771529391*CF^2*NC*
         PolyGamma[2, 1])/6433836560932926721489200 - 
       (3322030908731887481115607*CF*NM*NC*PolyGamma[2, 1])/264600 - 
       (19100393649210155347678224766550161*CF*NC*NH*PolyGamma[2, 1])/
        9650754841399390082233800 + CA*CF*NC*
        (-6379824926331750000518219253291136760385974429694335156556085301548\
1846128844782679/
          2373759931037396316691687504196039853273226296512666380800000000 + 
         (5420999573*lm^2)/45 + (7965572186282552863133304231878775731*Pi^2)/
          466114480479648000 + (501179751589975462283167900219439*Pi^3)/
          (1289685151896759007210080*Sqrt[3]) + (22726103471*Pi^4)/2700 + 
         lm*(4476599890081631342981/10527712715520 - (13481545*Pi^2)/162) - 
         (778693104352268161075466697721724252161*Im[PolyLog[2, (-1)^(1/3)]])/
          (349150012747250082226948908000*Sqrt[3]) + 
         (13897696604*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (71597107369996494611881128602777*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(4975637160095520861150*Sqrt[3]) + 
         (71597107369996494611881128602777*Pi*Log[3]^2)/
          (238830583684585001335200*Sqrt[3]) + 
         (119043217637555702015715117409508627771529391*PolyGamma[2, 1])/
          12867673121865853442978400 - 
         (131483006884242333549249308115190092591760905551*Zeta[3])/
          15640656679627944859940245200) + 
       (26296601380029239941906128654377152118760734677*CF^2*NC*Zeta[3])/
        1564065667962794485994024520 + (1535059044266306005586393*CF*NM*NC*
         Zeta[3])/132300 - (30496438300*CF*NC*NL*Zeta[3])/27 + 
       (9039537546491276065188677542622639*CF*NC*NH*Zeta[3])/
        4825377420699695041116900 + CF*Log[x]*
        ((-2078767820081964777833330951098096855469556791617*NM*NC)/
          11729467174665787274768040000 - (12793332615417301*lm*NM*NC)/
          27567540 - 86949016*lm^2*NM*NC - (112203145110474355829*NC*NL)/
          54186756624 - (12793332615417301*lm*NC*NL)/27567540 - 
         86949016*lm^2*NC*NL - 
         (7833179319564355758569616354113101807865171201360161*NC*NH)/
          289799193055075560274575467134896026155200 - 
         (12793332615417301*lm*NC*NH)/27567540 - 86949016*lm^2*NC*NH - 
         (495621423705140258264*NM*NC*Pi^2)/27 - (15245767960*NC*NL*Pi^2)/
          81 + (185501708741630365980540089792*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CF*NC*(-245632867728701365092409265813843242133176203485890621646613\
134874121/966963307493768786116166808673436407271184000000 - 
           (9896993289597361*lm)/765765 - 3130164576*lm^2 - 
           (2472731946864254923936390579*Pi^2)/91891800 + 
           (71597107369996494611881128602777*Im[PolyLog[2, (-1)^(1/3)]])/
            (7463455740143281291725*Sqrt[3]) - 521694096*Zeta[3]) + 
         CA*NC*(1043939687863429416090003268689777966480140513136719867757371\
340768683/8219188113697034681987417873724209461805064000000 + 
           (15844022312832661*lm)/5012280 + 478219588*lm^2 + 
           (17171749631205992877681332*Pi^2)/1276275 - 
           (71597107369996494611881128602777*Im[PolyLog[2, (-1)^(1/3)]])/
            (14926911480286562583450*Sqrt[3]) + 260847048*Zeta[3])), 
      (1286699937969185505023889768988345239956160652719342736413142129963922\
647860210379*CF^2*NC)/
        8407650287027377745070912057364958157992537059667059200000000 + 
       (9027082778759452013*CF^2*lm*NC)/3797876160 + 
       (8691776632*CF^2*lm^2*NC)/5 + 
       (772663474689062733415589876966047605356944893897435705366357997*CF*
         NM*NC)/3387553467141191925268504921621601088000000 + 
       (17004569832949609517*CF*lm*NM*NC)/136723541760 + 
       (2172944158*CF*lm^2*NM*NC)/45 - (1493166166076246184248446018447*CF*
         NC*NL)/709434345628815206400 + (17004569832949609517*CF*lm*NC*NL)/
        136723541760 + (2172944158*CF*lm^2*NC*NL)/45 - 
       (140104324634499756566447771435876912786852827386632849564845424285345\
7739*CF*NC*NH)/
        15140917291133727906049922407429797935826618540777217344000000 + 
       (17004569832949609517*CF*lm*NC*NH)/136723541760 + 
       (2172944158*CF*lm^2*NC*NH)/45 - 
       (4416780301815097845364262331438852017*CF^2*NC*Pi^2)/
        46006104566822400 - (21403690*CF^2*lm*NC*Pi^2)/9 - 
       (11464310143660080965640229403*CF*NM*NC*Pi^2)/82702620 - 
       (10701845*CF*lm*NM*NC*Pi^2)/162 + (519541021771079*CF*NC*NL*Pi^2)/
        4296240 - (10701845*CF*lm*NC*NL*Pi^2)/162 - 
       (10701845*CF*lm*NC*NH*Pi^2)/162 + (107218484204999749678134080539357*
         CF^2*NC*Pi^3)/(66137700097269692677440*Sqrt[3]) + 
       (6059258680389511073445763678765*CF*NC*NH*Pi^3)/
        (437675956526049436836*Sqrt[3]) + (609288202831*CF^2*NC*Pi^4)/16200 - 
       (524402898893663322987617636782232034239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(38958412242296712471646032000*
         Sqrt[3]) - (1339185140248750192069531527656177503*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(18619829380509458166595530*Sqrt[3]) + 
       (57130907834*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
       (15316926314999964239733440077051*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(255160880004898505700*
         Sqrt[3]) + (692486706330229836965230134716*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) + (15316926314999964239733440077051*CF^2*NC*Pi*Log[3]^2)/
        (12247722240235128273600*Sqrt[3]) + (173121676582557459241307533679*
         CF*NC*NH*Pi*Log[3]^2)/(16210220612075905068*Sqrt[3]) + 
       CF*((-521152470667550624276962710608674388877827*CF*NC)/
          452369400060958380000 + 
         CA*(94754994673577432404767064159769374270109/
            164497963658530320000 - (344034291601*lm)/27)*NC + 
         (250206757528*CF*lm*NC)/3 - (540468393114171626964546195338019383*
           NM*NC)/324907994010600 + (62551689382*lm*NM*NC)/27 + 
         (8875538875*NC*NL)/3 + (62551689382*lm*NC*NL)/27 + 
         (804120745388320656456001*NC*NH)/1335732864265800 + 
         (62551689382*lm*NC*NH)/27)*Log[x]^2 - 
       (CF*NC*(-1898168599627621705859938521*CA + 
          3796337195771013916084043442*CF + 618800*
           (8904446954491216796034*NM + 31275844691*NL))*Log[x]^3)/
        12530700 - (2011871548987327099968743669240379253237186813*CF^2*NC*
         PolyGamma[2, 1])/38603019365597560328935200 - 
       (51349124799764984515649*CF*NM*NC*PolyGamma[2, 1])/675 + 
       (984625423025475706970065885927682*CF*NC*NH*PolyGamma[2, 1])/
        172334907882131965754175 + CA*CF*NC*
        (-4953794761059374484372261062817752971554832003112451572950800437919\
8419013834507779/
          647389072101108086370460228417101778165425353594363558400000000 - 
         (11951192869*lm^2)/45 + (8136174240169322865352879401619395163*Pi^2)/
          169496174719872000 - (107218484204999749678134080539357*Pi^3)/
          (132275400194539385354880*Sqrt[3]) - (203666832677*Pi^4)/10800 + 
         lm*(-279479083686855805423/273447083520 + (117720295*Pi^2)/324) + 
         (524402898893663322987617636782232034239*Im[PolyLog[2, (-1)^(1/3)]])/
          (77916824484593424943292064000*Sqrt[3]) - 
         (28565453917*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
         (15316926314999964239733440077051*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(510321760009797011400*Sqrt[3]) - 
         (15316926314999964239733440077051*Pi*Log[3]^2)/
          (24495444480470256547200*Sqrt[3]) + 
         (2011871548987327099968743669240379253237186813*PolyGamma[2, 1])/
          77206038731195120657870400 - 
         (201540754581229128442482011769914195960217084541*Zeta[3])/
          8531267279797060832694679200) + 
       (201540754561169467900904515014431710709699561749*CF^2*NC*Zeta[3])/
        4265633639898530416347339600 + (45709199629438144376102*CF*NM*NC*
         Zeta[3])/675 + (73206446264*CF*NC*NL*Zeta[3])/27 - 
       (3439941395660606614360391579390636*CF*NC*NH*Zeta[3])/
        172334907882131965754175 + CF*Log[x]*
        ((-1477702980563364139846777377554223639665126687693*NM*NC)/
          1466183396833223409346005000 + (814472282357327*lm*NM*NC)/716040 + 
         196913948*lm^2*NM*NC + (298641956222842208226121*NC*NL)/
          57902419935360 + (814472282357327*lm*NC*NL)/716040 + 
         196913948*lm^2*NC*NL + 
         (997617715728136739765687479123438944671570011249026084583*NC*NH)/
          9918377382309961050397345362691816495161720000 + 
         (814472282357327*lm*NC*NH)/716040 + 196913948*lm^2*NC*NH - 
         (2968148984837385009905*NM*NC*Pi^2)/27 + (36592521287*NC*NL*Pi^2)/
          81 - (692486706330229836965230134716*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CA*NC*(1766061801994955589425300113784577008707454534844907551767578\
22804099/498132612951335435271964719619649058291216000000 - 
           (10933170792493477*lm)/1432080 - 1083026714*lm^2 + 
           (421815244333341364473646069*Pi^2)/11138400 + 
           (15316926314999964239733440077051*Im[PolyLog[2, (-1)^(1/3)]])/
            (1530965280029391034200*Sqrt[3]) - 590741844*Zeta[3]) + 
         CF*NC*(-176606180201201215773717236661740165313451034202993073937878\
962036749/249066306475667717635982359809824529145608000000 + 
           (644099380838507*lm)/19890 + 7088902128*lm^2 - 
           (140605081445855168759671609*Pi^2)/1856400 - 
           (15316926314999964239733440077051*Im[PolyLog[2, (-1)^(1/3)]])/
            (765482640014695517100*Sqrt[3]) + 1181483688*Zeta[3])), 
      (5045700056805239585629059509740992285701141422123304489370172680062634\
116785868113*CF^2*NC)/
        7214306375320266065125363249222835064600047928617541120000000 - 
       (158326857761498952031*CF^2*lm*NC)/123041449440 - 
       (6133500384*CF^2*lm^2*NC)/5 + 
       (20471626286868773933743944800480617904784837117300780813838189*CF*NM*
         NC)/43430172655656306734211601559251296000000 - 
       (340706595630303460063*CF*lm*NM*NC)/4429492179840 - 
       (511125032*CF*lm^2*NM*NC)/15 + (462506498004000956313030430689263*CF*
         NC*NL)/298790098567336004428800 - (340706595630303460063*CF*lm*NC*
         NL)/4429492179840 - (511125032*CF*lm^2*NC*NL)/15 + 
       (173532546979583632936052499613708863850702075141944795293821588867833\
649*CF*NC*NH)/
        4076400809151388282398056032769560982722551145593866208000000 - 
       (340706595630303460063*CF*lm*NC*NH)/4429492179840 - 
       (511125032*CF*lm^2*NC*NH)/15 - 
       (871661570269046634602797635888932005343*CF^2*NC*Pi^2)/
        2039603969129126400 + (2422420*CF^2*lm*NC*Pi^2)/3 - 
       (31108573958651425553478513623*CF*NM*NC*Pi^2)/104756652 + 
       (605605*CF*lm*NM*NC*Pi^2)/27 - (88646183764567*CF*NC*NL*Pi^2)/
        1046520 + (605605*CF*lm*NC*NL*Pi^2)/27 + (605605*CF*lm*NC*NH*Pi^2)/
        27 - (12910181237267456039037835354030229*CF^2*NC*Pi^3)/
        (9801607154415368454796608*Sqrt[3]) - 
       (462111878147969456181497493085*CF*NC*NH*Pi^3)/(72945992754341572806*
         Sqrt[3]) - (29975203577*CF^2*NC*Pi^4)/1080 + 
       (25194325321641747169144507414054442957090767*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3327539281486392183655713872803200*
         Sqrt[3]) + (383548691996011852633295322158580406*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9309914690254729083297765*Sqrt[3]) - 
       3010752118*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (12910181237267456039037835354030229*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(264703896917081709813180*
         Sqrt[3]) - (105625572148107304270056569848*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) - (12910181237267456039037835354030229*CF^2*NC*Pi*Log[3]^2)/
        (12705787052019922071032640*Sqrt[3]) - 
       (13203196518513413033757071231*CF*NC*NH*Pi*Log[3]^2)/
        (2701703435345984178*Sqrt[3]) + 
       CF*((-23698298942171951711914266750916661252021*CF*NC)/
          4620977742558177000 - 59506037680*CF*lm*NC + 
         CA*(189586391535560872609347524624438469282163/
            73935643880930832000 + (81820801810*lm)/9)*NC - 
         (10156294480161835457850333438401057*NM*NC)/2850070122900 - 
         (14876509420*lm*NM*NC)/9 - (89065046456*NC*NL)/45 - 
         (14876509420*lm*NC*NL)/9 - (102438023924677547990003*NC*NH)/
          222622144044300 - (14876509420*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-3224365888226413275573126027*CA + 
          19*(339406935652797387712624369*CF + 
            74256*(3160304101792588780284*NM - 3719127355*NL)))*Log[x]^3)/
        4761666 - (7518275129917585294291519122642535196202437*CF^2*NC*
         PolyGamma[2, 1])/32169182804664633607446 - 
       (21285002779447557432955171*CF*NM*NC*PolyGamma[2, 1])/132300 - 
       (12082157467393300759872099696963124*CF*NC*NH*PolyGamma[2, 1])/
        3619033065524771280837675 + CA*CF*NC*
        (-1387567515627321806524064041472147229467541015662554073026671276248\
1240740283937217/
          39678685064261463358189497870725592855300263607396476160000000 + 
         (2811187676*lm^2)/15 + (871661570269331747127222695185057052581*
           Pi^2)/4079207938258252800 + (12910181237267456039037835354030229*
           Pi^3)/(19603214308830736909593216*Sqrt[3]) + (10004654099*Pi^4)/
          720 + lm*(5860861928620176498581/8858984359680 - 
           (6661655*Pi^2)/54) - (25194325321641747169144507414054442957090767*
           Im[PolyLog[2, (-1)^(1/3)]])/(6655078562972784367311427745606400*
           Sqrt[3]) + 1505376059*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (12910181237267456039037835354030229*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(529407793834163419626360*
           Sqrt[3]) + (12910181237267456039037835354030229*Pi*Log[3]^2)/
          (25411574104039844142065280*Sqrt[3]) + 
         (7518275129917585294291519122642535196202437*PolyGamma[2, 1])/
          64338365609329267214892 - 
         (566599392599128383482587278326238880405890659357*Zeta[3])/
          5403135943871471860706630160) + 
       (566599392608493671577477123550140087679945303991*CF^2*NC*Zeta[3])/
        2701567971935735930353315080 + (9685977418761066179583629*CF*NM*NC*
         Zeta[3])/66150 - (17437332608*CF*NC*NL*Zeta[3])/9 + 
       (12441517960790900178896685276804352*CF*NC*NH*Zeta[3])/
        3619033065524771280837675 + CF*Log[x]*
        ((-613910572182198970846272735161608509897097722427*NM*NC)/
          279273027968233030351620000 - (132835494146377*lm*NM*NC)/174420 - 
         142133376*lm^2*NM*NC - (22678706133743041787565733*NC*NL)/
          6417518209502400 - (132835494146377*lm*NC*NL)/174420 - 
         142133376*lm^2*NC*NL - 
         (2008475353939860338687446208624371209736701682821153593*NC*NH)/
          43501655185570004607005900713560598662990000 - 
         (132835494146377*lm*NC*NH)/174420 - 142133376*lm^2*NC*NH - 
         (2106869401198082495470*NM*NC*Pi^2)/9 - (8717455094*NC*NL*Pi^2)/
          27 + (105625572148107304270056569848*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1350851717672992089*Sqrt[3]) + 
         CF*NC*
          (
           -50971759050964715669972343687281403798002085041928266605948951838\
77/1635573671556804136549653745294930663744200000 - (102879819154057*lm)/
            4845 - 5116801536*lm^2 - (64487317765151781330766442203*Pi^2)/
            190466640 + (12910181237267456039037835354030229*
             Im[PolyLog[2, (-1)^(1/3)]])/(794111690751245129439540*Sqrt[3]) - 
           852800256*Zeta[3]) + CA*NC*(57088370137204750764091940077742266624\
4959250321979227366278759941349/
            366368502428724126587122438946064468678700800000 + 
           (1808263083797027*lm)/348840 + 781733568*lm^2 + 
           (3070824655488392287458351613*Pi^2)/18139680 - 
           (12910181237267456039037835354030229*Im[PolyLog[2, (-1)^(1/3)]])/
            (1588223381502490258879080*Sqrt[3]) + 426400128*Zeta[3]))}, 0, 
     39, 1]
 
CbarLSeries["a", 2, 4, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-(CA*(17036075145618258994 + 14901261442744320*lm + 
            6592288260096000*lm^2 - 14168688762407704875*Zeta[3])) + 
         2*(1865515073011712*NL + 591916034949120*lm*NL + 
           599298932736000*lm^2*NL - 3044031235202790*NH + 
           591916034949120*lm*NH + 599298932736000*lm^2*NH + 
           2291871384581625*NH*Zeta[3] + 315*NM*(-9663591222866 + 
             1879098523648*lm + 1902536294400*lm^2 + 7275782173275*Zeta[3]) + 
           9*CF*(-18184140651872328926 - 528947368427520*lm + 
             2397195730944000*lm^2 + 15128850587933494125*Zeta[3]))))/
       12459424811581440000, 
      -(CF*NC*(-(CA*(17039800460978945074 + 18197405572792320*lm + 
             6592288260096000*lm^2 - 14168688762407704875*Zeta[3])) + 
          2*(9*CF*(-18184272888714435806 + 669650497044480*lm + 
              2397195730944000*lm^2 + 15128850587933494125*Zeta[3]) + 
            2*(4194304*(240027199 + 106282890*lm + 71442000*lm^2)*NL + 
              2520*NM*(-362465535426 + 176897916928*lm + 118908518400*lm^2 + 
                336227782275*Zeta[3]) + 315*NH*(-6294092308546 + 
                1415183335424*lm + 951268147200*lm^2 + 4585959915075*
                 Zeta[3])))))/3114856202895360000, 
      (CF*NC*(-33*CA*(4692910231738684795673038 + 1220017836988248883200*lm + 
           383242678000680960000*lm^2 - 3903476147535887688583125*Zeta[3]) + 
         154*CF*(-28442529366265778348050234 + 377536478081502412800*lm + 
           537535184728227840000*lm^2 + 23661845096456022971736375*Zeta[3]) + 
         15*(8388608*(68124034634701 + 34916612082660*lm + 18274434948000*
              lm^2)*NL + 3465*NM*(-62462790707677558 + 84531535771860992*
              lm + 44241578989977600*lm^2 + 102846921630678225*Zeta[3]) + 
           3465*NH*(-388647980451338806 + 84531535771860992*lm + 
             44241578989977600*lm^2 + 285058165905738225*Zeta[3]))))/
       2743814532006464716800000, 
      -(CF*NC*(-33*CA*(4010549520867345607781758 + 421795268309444198400*lm + 
            119287456066437120000*lm^2 - 3336161849489083185388125*Zeta[3]) + 
          154*CF*(-25634151329309710257372874 + 176497050762451353600*lm + 
            167312276041236480000*lm^2 + 21325345411655574139071375*
             Zeta[3]) + 15*(8388608*(23795639522161 + 12873404964420*lm + 
              5688069156000*lm^2)*NL + 385*NM*(-76133339719762394 + 
              280493371095515136*lm + 123935019289804800*lm^2 + 
              330384992709947175*Zeta[3]) + 231*NH*(-2370589113499198526 + 
              467488951825858560*lm + 206558365483008000*lm^2 + 
              1772066839914496125*Zeta[3]))))/548762906401292943360000, 
      (CF*NC*(-33*CA*(206154460590833587507092871034 + 
           7576673045523512426496000*lm + 1983359537613908213760000*lm^2 - 
           171496415987596281168616404375*Zeta[3]) + 
         14*(13*CF*(-1313925177477756451522332561074 + 
             3151983357607330971648000*lm + 2353877253431891066880000*lm^2 + 
             1093065749545341773506198768875*Zeta[3]) + 
           75*(143*NM*(201893996818323210240*lm + 79255126378178150400*
                lm^2 + 143*(-875670918347998534 + 2562579556495583625*
                  Zeta[3])) + 3*(201326592*(88272943930013 + 47801007073820*
                  lm + 18764673127200*lm^2)*NL + 143*NH*
                (-392247193496418168766 + 67297998939441070080*lm + 
                 26418375459392716800*lm^2 + 299680672947226696125*
                  Zeta[3]))))))/7419274494545480594227200000, 
      -(CF*NC*(-66*CA*(330388106661032784353891991262 + 
            4053395244328343411097600*lm + 1005405440347534786560000*lm^2 - 
            274849351075332694411904278125*Zeta[3]) + 
          364*CF*(-2364215234954190729067828415942 + 
            1850150863973739449548800*lm + 1193228434698173153280000*lm^2 + 
            1966809027368185443798481751625*Zeta[3]) + 
          15*(134217728*(31631715045762653 + 16533066751060860*lm + 
              5992683412716000*lm^2)*NL + 3003*NM*
             (-1845164325981143942518 + 738937947452457615360*lm + 
              267840277148860416000*lm^2 + 2782132641442221692625*Zeta[3]) + 
            9009*NH*(246312649150819205120*lm + 89280092382953472000*lm^2 + 
              429*(-3940734569450494294 + 3072607350169982625*Zeta[3])))))/
       7419274494545480594227200000, 
      (CF*NC*(-33*CA*(4093433855965772477533182611381398 + 
           15264490854931733918043340800*lm + 3676576679755328299991040000*
            lm^2 - 3405345951766482948340728437450625*Zeta[3]) + 
         14*CF*(-427575129252461036257888251345980294 + 
           94772797040000905589764915200*lm + 56724325916225065199861760000*
            lm^2 + 355702946431892780809105761866747625*Zeta[3]) + 
         15*(8589934592*(1012028905963916033 + 492912318759320460*lm + 
             171203942958048000*lm^2)*NL + 3003*NM*
            (-12436698277061753441350942 + 1409951574336868911677440*lm + 
             489720503463913193472000*lm^2 + 13449311858229541995826125*
              Zeta[3]) + 1001*NH*(-35102868800520438838140506 + 
             4229854723010606735032320*lm + 1469161510391739580416000*lm^2 + 
             27880934676160986987942375*Zeta[3]))))/
       16144341300130965773038387200000, 
      -(CF*NC*(-33*CA*(1513162106892026193523567869559702 + 
            1432674384079451398235750400*lm + 348532709412931727523840000*
             lm^2 - 1258809593712339246526283440730625*Zeta[3]) + 
          2*(CF*(-1232497300356133750183402621203614122 + 
              61337909753797454020686643200*lm + 
              37641532616596626572574720000*lm^2 + 
              1025323611857960124374776849027665375*Zeta[3]) + 
            15*(3003*NM*(65873280011460788879360*lm + 
                23212301659202912256000*lm^2 + 93*(-24163834581175718989786 + 
                  22314777065996838798375*Zeta[3])) + 2*(2147483648*
                 (108135625929638149 + 46057966508533980*lm + 
                  16229819013408000*lm^2)*NL + 143*NH*
                 (-7221997133985529059441134 + 691669440120338283233280*lm + 
                  243729167421630578688000*lm^2 + 5841608097747135513925125*
                   Zeta[3]))))))/2306334471447280824719769600000, 
      (CF*NC*(-297*CA*(432990614033740090464283262774845542602 + 
           57983725682183720510485954560000*lm + 
           16898942558862805958614056960000*lm^2 - 
           360208053832697149172634630468683679375*Zeta[3]) + 
         34*CF*(-206754966618136602836762801982121482580294 + 
           918049712639974623695087861760000*lm + 
           966221892189096905398403727360000*lm^2 + 
           172000980437437210651037084157351855647625*Zeta[3]) + 
         40425*(85899345920*(2106703152957030451 + 567232166116996380*lm + 
             262792764804810240*lm^2)*NL + 7293*NH*
            (-108348822658625752204342094 + 6681046490365388075827200*lm + 
             3095259373267735648665600*lm^2 + 90406290976028209168111125*
              Zeta[3]) + 3315*NM*(-3738672353101317026571761626 + 
             14698302278803853766819840*lm + 6809570621189018427064320*lm^2 + 
             3217481695411501672777998375*Zeta[3]))))/
       2482160186212535725673105955225600000, 
      (CF*NC*(272*CF*(259744318688300228423001833472000*lm + 
           45313289882255701369033850880000*lm^2 + 
           97*(657706208623216070827740852826608610906 - 
             547150640757687985512982716020520102375*Zeta[3])) - 
         264*CA*(-1091760147694131733637209771089030299014 + 
           58582210476711863773380476928000*lm + 
           7132647481466175215496069120000*lm^2 + 
           908243408070944177442100666871546075625*Zeta[3]) + 
         175*(2431*NM*(2601841007895864606232207325498 + 
             5585487886265305673477652480*lm + 804764833073694330008371200*
              lm^2 - 2179012647802787264037002808375*Zeta[3]) + 
           3*(206158430208*(11386397125110423217 + 21954508542792946120*lm + 
               3163236007744612800*lm^2)*NL + 2431*NH*
              (1861829295421768557825884160*lm + 268254944357898110002790400*
                lm^2 + 46189*(-345809936491137482771158 + 
                 263847402434086877030625*Zeta[3]))))))/
       2482160186212535725673105955225600000, 
      -(CF*NC*(152*CF*(1532121836388627022228355325418520961118091498 + 
            5719361659371286960118465066906419200*lm + 
            1808494200354292645351640121999360000*lm^2 - 
            1274583446498410981794229143334880764377309375*Zeta[3]) - 
          924*CA*(-3819253737435762534028388692875322596767246 + 
            256508680088662154097299292998860800*lm + 
            45451573818427989764128521584640000*lm^2 + 
            3177265670847360339064894341146843135299125*Zeta[3]) + 
          35*(46189*NM*(8600286943168242394634397677519542 + 
              20645042499459731309871035842560*lm + 
              4723366046644316847470542848000*lm^2 - 
              7145109568387468647616093198376625*Zeta[3]) + 
            3*(274877906944*(1786381589377699211234167 + 
                1156360507602640342122120*lm + 264562979680648945296000*lm^2)*
               NL + 46189*NH*(-99502213789319149924426173831566 + 
                6881680833153243769957011947520*lm + 
                1574455348881438949156847616000*lm^2 + 
                80122556162220950394146272267125*Zeta[3])))))/
       14336957235563606351487859997383065600000, 
      (CF*NC*(152*CF*(3377927541370205919977612521801384417440406874 + 
           7440354864869963941948404156648652800*lm + 
           2656058721442164043951737730498560000*lm^2 - 
           2810122820183884364122121033794803492583350375*Zeta[3]) - 
         396*CA*(-18003481443016434379106405014582103958777862 + 
           822758496896458457956796802583756800*lm + 
           155756529961114558132972274319360000*lm^2 + 
           14977229977876347479871843461424729802931625*Zeta[3]) + 
         8085*(274877906944*(37781249888201468435389 + 
             20233034120936074478040*lm + 5046135406883979408000*lm^2)*NL + 
           4199*NM*(883026338834101416687628273053398 + 
             1324509185589293432376121098240*lm + 
             330333683924810209268072448000*lm^2 - 
             732833320877178618001991275814625*Zeta[3]) + 
           264537*NH*(21023955326814181466287636480*lm + 
             5243391808330320782032896000*lm^2 + 
             79781*(-5060319496069044254035694 + 4124270579657206402549125*
                Zeta[3])))))/14336957235563606351487859997383065600000, 
      -(CF*NC*(4*CF*(820619632200561474285059994040620358775857026440254 + 
            898507035492256790790193932682152797798400*lm + 
            348345478700334010728917904404691025920000*lm^2 - 
            682679521521232673671228898030992872388039190656125*Zeta[3]) - 
          26*CA*(-1612657124365135585486730273271272567893504254026 + 
            41432705299027294319449111966983703756800*lm + 
            8187607405349731021406190060794019840000*lm^2 + 
            1341581403256340033585502429186950369136855975375*Zeta[3]) + 
          15015*(8796093022208*(2325063653328326668426103 + 
              1110009973419039621408480*lm + 293057282776952868174000*lm^2)*
             NL + 323*NM*(40127391137929121604212521040435344006 + 
              30228331212917962756296634615726080*lm + 
              7980678390531244027819855970304000*lm^2 - 
              33325480481162530583579642836229003625*Zeta[3]) + 
            4199*NH*(-58465847300178262313254129669394498 + 
              2325256247147535596638202662748160*lm + 
              613898337733172617524604305408000*lm^2 + 
              47972331124262938806521627027383875*Zeta[3]))))/
       43527002167171108883117142952054987161600000, 
      (CF*NC*(2*CF*(829622163543314222879647258122292886818077049948814 + 
           404416559107379647787267025034612310016000*lm + 
           172292102044773236758028965708761661440000*lm^2 - 
           690168794081264646870515387033669398536768311035125*Zeta[3]) - 
         CA*(-19567610929478044604842229512734245480705507915122 + 
           254186688013512380893920679569880252416000*lm + 
           52644808958125155676064406188788285440000*lm^2 + 
           16278440114560902299446156254760647041084174596875*Zeta[3]) + 
         5775*(274877906944*(49499650866863231555271167 + 
             21439501511402626377846120*lm + 6029774082425856831868800*lm^2)*
            NL + 134368*NM*(132760190952090727697206041347609722 + 
             43858993967143058528866884648960*lm + 
             12335166699827322428032706150400*lm^2 - 
             110341031160936097197946706024964375*Zeta[3]) + 
           4199*NH*(1403487806948577872923740308766720*lm + 
             394725334394474317697046596812800*lm^2 + 
             4199*(-11179347514189173549241903789418 + 
               9214321385682509840679149589375*Zeta[3])))))/
       10881750541792777220779285738013746790400000, 
      -(CF*NC*
         (-6*CA*(-66479708471348243857301642378075461196275111867485722 + 
            403131154547059908881326185863826817155072000*lm + 
            88873524812832389354542213942917168365568000*lm^2 + 
            55304960100416418321414749240893180266804982079274375*Zeta[3]) + 
          25*(92*CF*(15876184362208806598389631044231526925988911094413774 + 
              3118434742595525751038481253459977075425280*lm + 
              1517524218147968071192183257839534258257920*lm^2 - 
              13207514818053160827288762276283565874254033497151445*Zeta[
                3]) + 1617*(8796093022208*(2265225625907980529680915219 + 
                889765909244090342135872200*lm + 272659807539740029853283840*
                 lm^2)*NL + 22287*NM*(
                2702446527143238821002562845756673849954 + 
                351167214326759979464338350853324800*lm + 
                107611658389953044566554834433474560*lm^2 - 
                2247185366462172427009180845992916181875*Zeta[3]) + 
              7429*NH*(1053501642980279938393015052559974400*lm + 
                322834975169859133699664503300423680*lm^2 + 
                7429*(-6521527448434424741691574011752914 + 
                  5392511117152561493173800825982875*Zeta[3]))))))/
       122804182114312088528901165982064470445260800000, 
      (CF*NC*(46*CF*(204341221323734660445565244645699926807658990898846458 + 
           14270794792018205580461570260398972390604800*lm + 
           8581247664968609288191883031216069279744000*lm^2 - 
           169992968538713929350310434252449197619216704456860375*Zeta[3]) - 
         5*CA*(-19079081580697588647320980519833763683177650148482434 + 
           49983509733770056298882725112595519457198080*lm + 
           12061420329094767499514146704987030709862400*lm^2 + 
           15872028687387030799555491589200328926551140715415075*Zeta[3]) + 
         735*(4398046511104*(27743575065410562506238872939 + 
             9739695836153434256621235720*lm + 3392021609513908326949593600*
              lm^2)*NL + 1634380*NM*
            (572195295516222587583677526479109803942 + 
             26209103936299249599212460731006976*lm + 
             9127784728956557942892077651066880*lm^2 - 
             475922743604973349822917952265888019225*Zeta[3]) + 
           37145*NH*(1153200573197166982365348272164306944*lm + 
             401622528074088549487251416646942720*lm^2 + 
             7429*(-10392010603526443131038681383495354 + 
               8613047569392946769181385465747575*Zeta[3])))))/
       16746024833769830253941068088463336878899200000}, 0, 16, 1]

CbarLTable["a", 2, -1] = {{0., -0.000038580246913580246*CF*NC*
       (-3.*CA*(5160.430157209292 + 198.04533104651125*lm + 7140.*lm^2 + 
          1320.*lm^3) + 2.*(CF*(-135.93938964079425 + 116.1865557539944*lm + 
            5670.*lm^2 - 3240.*lm^3) - 
          15.*((-288.8434648794611 - 83.04316479128514*lm - 84.*lm^2 - 
              24.*lm^3)*NM + (-288.8434648794611 - 83.04316479128514*lm - 
              84.*lm^2 - 24.*lm^3)*NL - 1.*(-114.9438057198067 + 
              83.04316479128514*lm + 84.*lm^2 + 24.*lm^3)*NH)))}, 
     {0.005, CF*NC*(CA*(0.6281659519423299 + 0.04255425769679392*lm + 
          0.8369638869030109*lm^2 + 0.154309375*lm^3) + 
        CF*(0.03677470535618152 + 0.004806524065402655*lm - 
          0.4381379293859821*lm^2 + 0.25250625*lm^3) - 
        0.3412698042883041*NM - 0.10007604008820126*lm*NM - 
        0.09861332034600198*lm^2*NM - 0.02805625*lm^3*NM - 
        0.34129322848438026*NL - 0.10007604008820126*lm*NL - 
        0.09861332034600198*lm^2*NL - 0.02805625*lm^3*NL + 
        0.13636653792220954*NH - 0.10007604008820126*lm*NH - 
        0.09861332034600198*lm^2*NH - 0.02805625*lm^3*NH)}, 
     {0.01, CF*NC*(CA*(0.6586066295608243 + 0.062120685795076014*lm + 
          0.8475741530142338*lm^2 + 0.15584861111111112*lm^3) + 
        CF*(0.062268351212858515 + 0.01851513398317798*lm - 
          0.4388076359767084*lm^2 + 0.255025*lm^3) - 0.34811731769024096*
         NM - 0.10403131900315318*lm*NM - 0.10000817933592128*lm^2*NM - 
        0.02833611111111111*lm^3*NM - 0.3482164250986726*NL - 
        0.10403131900315318*lm*NL - 0.10000817933592128*lm^2*NL - 
        0.02833611111111111*lm^3*NL + 0.13970746863646918*NH - 
        0.10403131900315318*lm*NH - 0.10000817933592128*lm^2*NH - 
        0.02833611111111111*lm^3*NH)}, 
     {0.015, CF*NC*(CA*(0.6884066583685199 + 0.08155263983838029*lm + 
          0.858215306595869*lm^2 + 0.15739548611111112*lm^3) + 
        CF*(0.08673027984685326 + 0.03208284462252465*lm - 
          0.4395162880703962*lm^2 + 0.25755625*lm^3) - 0.35481851706403156*
         NM - 0.10796915945812019*lm*NM - 0.10140600271440042*lm^2*NM - 
        0.02861736111111111*lm^3*NM - 0.3550513556933227*NL - 
        0.10796915945812019*lm*NL - 0.10140600271440042*lm^2*NL - 
        0.02861736111111111*lm^3*NL + 0.1430566040348293*NH - 
        0.10796915945812019*lm*NH - 0.10140600271440042*lm^2*NH - 
        0.02861736111111111*lm^3*NH)}, 
     {0.02, CF*NC*(CA*(0.7174667617788887 + 0.10080260814349593*lm + 
          0.8688836933765636*lm^2 + 0.15895*lm^3) + 
        CF*(0.11007273757006425 + 0.04546044914999557*lm - 
          0.4402698653838051*lm^2 + 0.2601*lm^3) - 0.3613551357887721*NM - 
        0.1118817685817572*lm*NM - 0.1028061260684661*lm^2*NM - 
        0.0289*lm^3*NM - 0.3617839431656498*NL - 0.1118817685817572*lm*
         NL - 0.1028061260684661*lm^2*NL - 0.0289*lm^3*NL + 
        0.14641142116738123*NH - 0.1118817685817572*lm*NH - 
        0.1028061260684661*lm^2*NH - 0.0289*lm^3*NH)}, 
     {0.025, CF*NC*(CA*(0.7457268047447873 + 0.11983410883221617*lm + 
          0.8795761008966015*lm^2 + 0.16051215277777778*lm^3) + 
        CF*(0.13226665246688937 + 0.05861333899159588*lm - 
          0.4410736246691975*lm^2 + 0.26265625*lm^3) - 0.36771577970576436*
         NM - 0.1157632566844072*lm*NM - 0.10420796531453361*lm^2*NM - 
        0.029184027777777777*lm^3*NM - 0.36840603714319986*NL - 
        0.1157632566844072*lm*NL - 0.10420796531453361*lm^2*NL - 
        0.029184027777777777*lm^3*NL + 0.1497696891296892*NH - 
        0.1157632566844072*lm*NH - 0.10420796531453361*lm^2*NH - 
        0.029184027777777777*lm^3*NH)}, 
     {0.03, CF*NC*(CA*(0.7731493172106829 + 0.13861784111726852*lm + 
          0.8902896352838215*lm^2 + 0.16208194444444443*lm^3) + 
        CF*(0.15331295440280632 + 0.07151616830693336*lm - 
          0.44193230135374656*lm^2 + 0.265225*lm^3) - 0.3738930677921966*
         NM - 0.11960896600657038*lm*NM - 0.10561099429402816*lm^2*NM - 
        0.029469444444444444*lm^3*NM - 0.37491284215062026*NL - 
        0.11960896600657038*lm*NL - 0.10561099429402816*lm^2*NL - 
        0.029469444444444444*lm^3*NL + 0.1531293890429781*NH - 
        0.11960896600657038*lm*NH - 0.10561099429402816*lm^2*NH - 
        0.029469444444444444*lm^3*NH)}, 
     {0.035, CF*NC*(CA*(0.7997115067114711 + 0.15712964726732986*lm + 
          0.9010216506548824*lm^2 + 0.163659375*lm^3) + 
        CF*(0.17322963296540478 + 0.08415007039316094*lm - 
          0.4428502250647379*lm^2 + 0.26780625*lm^3) - 0.37988223820013306*
         NM - 0.12341511650398596*lm*NM - 0.10701473193725135*lm^2*NM - 
        0.02975625*lm^3*NM - 0.3813016894330108*NL - 0.12341511650398596*lm*
         NL - 0.10701473193725135*lm^2*NL - 0.02975625*lm^3*NL + 
        0.15648866829082236*NH - 0.12341511650398596*lm*NH - 
        0.10701473193725135*lm^2*NH - 0.02975625*lm^3*NH)}, 
     {0.04, CF*NC*(CA*(0.8254007206514495 + 0.17534926699985884*lm + 
          0.9117697031329591*lm^2 + 0.16524444444444444*lm^3) + 
        CF*(0.19204486621358377 + 0.09650097853669394*lm - 
          0.44383139487333956*lm^2 + 0.2704*lm^3) - 0.38568035191827826*NM - 
        0.12717859001413478*lm*NM - 0.10841873390296228*lm^2*NM - 
        0.030044444444444443*lm^3*NM - 0.3875713486649027*NL - 
        0.12717859001413478*lm*NL - 0.10841873390296228*lm^2*NL - 
        0.030044444444444443*lm^3*NL + 0.15984581074205056*NH - 
        0.12717859001413478*lm*NH - 0.10841873390296228*lm^2*NH - 
        0.030044444444444443*lm^3*NH)}, 
     {0.045, CF*NC*(CA*(0.8502116112891035 + 0.193259507288219*lm + 
          0.9225315184716917*lm^2 + 0.16683715277777778*lm^3) + 
        CF*(0.2097930084503381 + 0.10855852037006504*lm - 
          0.44487953227359545*lm^2 + 0.27300625*lm^3) - 
        0.3912857925477928*NM - 0.13089678680405892*lm*NM - 
        0.10982258669182272*lm^2*NM - 0.03033402777777778*lm^3*NM - 
        0.393721603495856*NL - 0.13089678680405892*lm*NL - 
        0.10982258669182272*lm^2*NL - 0.03033402777777778*lm^3*NL + 
        0.16319921578942512*NH - 0.13089678680405892*lm*NH - 
        0.10982258669182272*lm^2*NH - 0.03033402777777778*lm^3*NH)}, 
     {0.05, CF*NC*(CA*(0.8741442470016932 + 0.21084565547415293*lm + 
          0.9333049680162004*lm^2 + 0.1684375*lm^3) + 
        CF*(0.22651209715741707 + 0.12031524525299357*lm - 
          0.44599812051894466*lm^2 + 0.275625*lm^3) - 0.396697931301326*NM - 
        0.13456752442627867*lm*NM - 0.11122590327567282*lm^2*NM - 
        0.030625*lm^3*NM - 0.399752972363189*NL - 0.13456752442627867*lm*
         NL - 0.11122590327567282*lm^2*NL - 0.030625*lm^3*NL + 
        0.166547382778335*NH - 0.13456752442627867*lm*NH - 
        0.11122590327567282*lm^2*NH - 0.030625*lm^3*NH)}, 
     {0.055, CF*NC*(CA*(0.897202794094907 + 0.22809504620031035*lm + 
          0.9440880501496999*lm^2 + 0.17004548611111112*lm^3) + 
        CF*(0.2422422362434798 + 0.1317660605169433*lm - 0.4471904349823092*
           lm^2 + 0.27825625*lm^3) - 0.4019168920260736*NM - 
        0.13818896327259814*lm*NM - 0.11262831972418787*lm^2*NM - 
        0.03091736111111111*lm^3*NM - 0.40566651610902194*NL - 
        0.13818896327259814*lm*NL - 0.11262831972418787*lm^2*NL - 
        0.03091736111111111*lm^3*NL + 0.1698888989748979*NH - 
        0.13818896327259814*lm*NH - 0.11262831972418787*lm^2*NH - 
        0.03091736111111111*lm^3*NH)}, 
     {0.06, CF*NC*(CA*(0.9193945638496851 + 0.24499673122385035*lm + 
          0.9548788755443631*lm^2 + 0.1716611111111111*lm^3) + 
        CF*(0.2570245158647242 + 0.14290780634963204*lm - 
          0.4484595672910421*lm^2 + 0.2809*lm^3) - 0.4069433805192855*NM - 
        0.14175954995323756*lm*NM - 0.11402949252321755*lm^2*NM - 
        0.03121111111111111*lm^3*NM - 0.41146370067928467*NL - 
        0.14175954995323756*lm*NL - 0.11402949252321755*lm^2*NL - 
        0.03121111111111111*lm^3*NL + 0.1732224299842636*NH - 
        0.14175954995323756*lm*NH - 0.11402949252321755*lm^2*NH - 
        0.03121111111111111*lm^3*NH)}, 
     {0.065, CF*NC*(CA*(0.9407293043964735 + 0.26154122109365546*lm + 
          0.9656756551596631*lm^2 + 0.173284375*lm^3) + 
        CF*(0.2709002759743214 + 0.15373892681698442*lm - 
          0.4498084449660058*lm^2 + 0.28355625*lm^3) - 0.41177855711562944*
         NM - 0.14527797310629753*lm*NM - 0.11542909639266602*lm^2*NM - 
        0.03150625*lm^3*NM - 0.4171462964252604*NL - 0.14527797310629753*lm*
         NL - 0.11542909639266602*lm^2*NL - 0.03150625*lm^3*NL + 
        0.17654671193577678*NH - 0.14527797310629753*lm*NH - 
        0.11542909639266602*lm^2*NH - 0.03150625*lm^3*NH)}, 
     {0.07, CF*NC*(CA*(0.9612186628148996 + 0.27772027878976296*lm + 
          0.9764766902901677*lm^2 + 0.17491527777777777*lm^3) + 
        CF*(0.28391059794007634 + 0.16425920990809637*lm - 
          0.45123984770699826*lm^2 + 0.286225*lm^3) - 0.4164239394814298*
         NM - 0.14874312818064517*lm*NM - 0.1168268224770002*lm^2*NM - 
        0.03180277777777778*lm^3*NM - 0.42271630263373505*NL - 
        0.14874312818064517*lm*NL - 0.1168268224770002*lm^2*NL - 
        0.03180277777777778*lm^3*NL + 0.17986054498446713*NH - 
        0.14874312818064517*lm*NH - 0.1168268224770002*lm^2*NH - 
        0.03180277777777778*lm^3*NH)}, 
     {0.075, CF*NC*(CA*(0.9808757691622804 + 0.2935267520091193*lm + 
          0.9872803641830106*lm^2 + 0.17655381944444445*lm^3) + 
        CF*(0.2960959517557914 + 0.17446957856060577*lm - 
          0.452756421109619*lm^2 + 0.28890625*lm^3) - 0.42088132713031845*
         NM - 0.15215408888217372*lm*NM - 0.11822237682115344*lm^2*NM - 
        0.032100694444444446*lm^3*NM - 0.42817588997018474*NL - 
        0.15215408888217372*lm*NL - 0.11822237682115344*lm^2*NL - 
        0.032100694444444446*lm^3*NL + 0.18316278781975673*NH - 
        0.15215408888217372*lm*NH - 0.11822237682115344*lm^2*NH - 
        0.032100694444444446*lm^3*NH)}, 
     {0.08, CF*NC*(CA*(0.9997149100176365 + 0.3089544348760812*lm + 
          0.998085134884304*lm^2 + 0.1782*lm^3) + 
        CF*(0.30749595178652617 + 0.18437192023770785*lm - 
          0.4543606883711391*lm^2 + 0.2916*lm^3) - 0.42515274194683383*NM - 
        0.15551008368563277*lm*NM - 0.11961547906987344*lm^2*NM - 
        0.0324*lm^3*NM - 0.4335273559569673*NL - 0.15551008368563277*lm*
         NL - 0.11961547906987344*lm^2*NL - 0.0324*lm^3*NL + 
        0.18645235296224494*NH - 0.15551008368563277*lm*NH - 
        0.11961547906987344*lm^2*NH - 0.0324*lm^3*NH)}, 
     {0.085, CF*NC*(CA*(1.0177512691230735 + 0.323997952504928*lm + 
          1.0088895290657973*lm^2 + 0.17985381944444445*lm^3) + 
        CF*(0.31814918957729976 + 0.19396894624373168*lm - 
          0.45605506039233157*lm^2 + 0.29430625*lm^3) - 
        0.42924038075337506*NM - 0.15881047627453604*lm*NM - 
        0.12100586134529649*lm^2*NM - 0.03270069444444444*lm^3*NM - 
        0.43877309013445004*NL - 0.15881047627453604*lm*NL - 
        0.12100586134529649*lm^2*NL - 0.03270069444444444*lm^3*NL + 
        0.18972820268889273*NH - 0.15881047627453604*lm*NH - 
        0.12100586134529649*lm^2*NH - 0.03270069444444444*lm^3*NH)}, 
     {0.09, CF*NC*(CA*(1.0350007192164443 + 0.33865266361359864*lm + 
          1.01969213664599*lm^2 + 0.1815152777777778*lm^3) + 
        CF*(0.3280931221544586 + 0.20326407437347452*lm - 
          0.45784184457928934*lm^2 + 0.297025*lm^3) - 0.43314657709833576*
         NM - 0.16205474907926934*lm*NM - 0.12239326726896785*lm^2*NM - 
        0.03300277777777778*lm^3*NM - 0.4439155465421023*NL - 
        0.16205474907926934*lm*NL - 0.12239326726896785*lm^2*NL - 
        0.03300277777777778*lm^3*NL + 0.19298934546750607*NH - 
        0.16205474907926934*lm*NH - 0.12239326726896785*lm^2*NH - 
        0.03300277777777778*lm^3*NH)}, 
     {0.095, CF*NC*(CA*(1.0514796535193414 + 0.352914577607496*lm + 
          1.0304916060640845*lm^2 + 0.183184375*lm^3) + 
        CF*(0.3373640007229738 + 0.21226133014117476*lm - 
          0.45972325257695273*lm^2 + 0.29975625*lm^3) - 
        0.43687377021195845*NM - 0.16524248929504906*lm*NM - 
        0.1237774511025608*lm^2*NM - 0.03330625*lm^3*NM - 
        0.44895722181696657*NL - 0.16524248929504906*lm*NL - 
        0.1237774511025608*lm^2*NL - 0.03330625*lm^3*NL + 
        0.196234832809877*NH - 0.16524248929504906*lm*NH - 
        0.1237774511025608*lm^2*NH - 0.03330625*lm^3*NH)}, 
     {0.1, CF*NC*(CA*(1.0672048483530403 + 0.3667802834126067*lm + 
          1.041286640096956*lm^2 + 0.18486111111111111*lm^3) + 
        CF*(0.34599682900481793 + 0.22096526299475502*lm - 
          0.461701407114072*lm^2 + 0.3025*lm^3) - 0.4404244796071003*NM - 
        0.16837337691046364*lm*NM - 0.12515817698732534*lm^2*NM - 
        0.03361111111111111*lm^3*NM - 0.45390063765924193*NL - 
        0.16837337691046364*lm*NL - 0.12515817698732534*lm^2*NL - 
        0.03361111111111111*lm^3*NL + 0.19946375647337672*NH - 
        0.16837337691046364*lm*NH - 0.12515817698732534*lm^2*NH - 
        0.03361111111111111*lm^3*NH)}, 
     {0.105, CF*NC*(CA*(1.082193350472874 + 0.38024688795735045*lm + 
          1.0520759921326304*lm^2 + 0.1865454861111111*lm^3) + 
        CF*(0.3540253434397525 + 0.2293808747535757*lm - 0.46377834810115015*
           lm^2 + 0.30525625*lm^3) - 0.4438012841766782*NM - 
        0.1714471743846909*lm*NM - 0.12653521826653888*lm^2*NM - 
        0.03391736111111111*lm^3*NM - 0.4587483267315014*NL - 
        0.1714471743846909*lm*NL - 0.12653521826653888*lm^2*NL - 
        0.03391736111111111*lm^3*NL + 0.20267524595577618*NH - 
        0.1714471743846909*lm*NH - 0.12653521826653888*lm^2*NH - 
        0.03391736111111111*lm^3*NH)}, 
     {0.11, CF*NC*(CA*(1.0964623842318766 + 0.3933119626581289*lm + 
          1.0628584628312192*lm^2 + 0.1882375*lm^3) + 
        CF*(0.3614820095491331 + 0.2375135581171595*lm - 0.4659560380943686*
           lm^2 + 0.308025*lm^3) - 0.4470068049092006*NM - 
        0.1744637176902739*lm*NM - 0.1279083568784035*lm^2*NM - 
        0.034225*lm^3*NM - 0.46350282128431436*NL - 0.1744637176902739*lm*
         NL - 0.1279083568784035*lm^2*NL - 0.034225*lm^3*NL + 
        0.20586846623925295*NH - 0.1744637176902739*lm*NH - 
        0.1279083568784035*lm^2*NH - 0.034225*lm^3*NH)}, 
     {0.115, CF*NC*(CA*(1.1100292747950877 + 0.40597349660384985*lm + 
          1.0736328971175058*lm^2 + 0.18993715277777778*lm^3) + 
        CF*(0.3683980302404805 + 0.24536904354569952*lm - 
          0.4682363672168089*lm^2 + 0.31080625*lm^3) - 
        0.450043690541301*NM - 0.17742290849714687*lm*NM - 
        0.12927738280924345*lm^2*NM - 0.034534027777777775*lm^3*NM - 
        0.4681666439654602*NL - 0.17742290849714687*lm*NL - 
        0.12927738280924345*lm^2*NL - 0.034534027777777775*lm^3*NL + 
        0.20904261574802868*NH - 0.17742290849714687*lm*NH - 
        0.12927738280924345*lm^2*NH - 0.034534027777777775*lm^3*NH)}, 
     {0.12, CF*NC*(CA*(1.122911384449818 + 0.41822985539276286*lm + 
          1.0843981814595975*lm^2 + 0.19164444444444445*lm^3) + 
        CF*(0.374803362895536 + 0.25295335315565565*lm - 0.47062115761156753*
           lm^2 + 0.3136*lm^3) - 0.4529146056131196*NM - 
        0.18032470731815667*lm*NM - 0.13064209359871473*lm^2*NM - 
        0.03484444444444444*lm^3*NM - 0.4727423003912641*NL - 
        0.18032470731815667*lm*NL - 0.13064209359871473*lm^2*NL - 
        0.03484444444444444*lm^3*NL + 0.2121969244906117*NH - 
        0.18032470731815667*lm*NH - 0.13064209359871473*lm^2*NH - 
        0.03484444444444444*lm^3*NH)}, 
     {0.125, CF*NC*(CA*(1.1351260596769903 + 0.43007974477330196*lm + 
          1.0951532413960374*lm^2 + 0.193359375*lm^3) + 
        CF*(0.38072674286240615 + 0.2602727605360149*lm - 
          0.47311216748830254*lm^2 + 0.31640625*lm^3) - 
        0.45562222050322027*NM - 0.18316912747054598*lm*NM - 
        0.1320022938901886*lm^2*NM - 0.03515625*lm^3*NM - 
        0.47723227314939165*NL - 0.18316912747054598*lm*NL - 
        0.1320022938901886*lm^2*NL - 0.03515625*lm^3*NL + 
        0.21533065236271362*NH - 0.18316912747054598*lm*NH - 
        0.1320022938901886*lm^2*NH - 0.03515625*lm^3*NH)}, 
     {0.13, CF*NC*(CA*(1.1466905871208741 + 0.4415221783949693*lm + 
          1.105897039280067*lm^2 + 0.19508194444444443*lm^3) + 
        CF*(0.3861957115472113 + 0.2673337555941121*lm - 0.4757110948144357*
           lm^2 + 0.319225*lm^3) - 0.45816920310440407*NM - 
        0.18595622973446574*lm*NM - 0.13335779502061826*lm^2*NM - 
        0.03546944444444444*lm^3*NM - 0.48163901697125316*NL - 
        0.18595622973446574*lm*NL - 0.13335779502061826*lm^2*NL - 
        0.03546944444444444*lm^3*NL + 0.2184430875909268*NH - 
        0.18595622973446574*lm*NH - 0.13335779502061826*lm^2*NH - 
        0.03546944444444444*lm^3*NH)}, 
     {0.135, CF*NC*(CA*(1.157622156958389 + 0.4525564490967263*lm + 
          1.1166285722147808*lm^2 + 0.19681215277777778*lm^3) + 
        CF*(0.39123664772978684 + 0.2741430136992909*lm - 
          0.4784195806939951*lm^2 + 0.32205625*lm^3) - 0.46055821186720036*
         NM - 0.18868611761049878*lm*NM - 0.13470841464511166*lm^2*NM - 
        0.035784027777777776*lm^3*NM - 0.4859649548649058*NL - 
        0.18868611761049878*lm*NL - 0.13470841464511166*lm^2*NL - 
        0.035784027777777776*lm^3*NL + 0.22153354530045624*NH - 
        0.18868611761049878*lm*NH - 0.13470841464511166*lm^2*NH - 
        0.035784027777777776*lm^3*NH)}, 
     {0.14, CF*NC*(CA*(1.167937832452474 + 0.463182103256871*lm + 
          1.1273468701569545*lm^2 + 0.19855*lm^3) + 
        CF*(0.39587480105130135 + 0.2807073685189032*lm - 
          0.48123921247043805*lm^2 + 0.3249*lm^3) - 0.4627918899888956*NM - 
        0.1913589330947841*lm*NM - 0.13605397639217356*lm^2*NM - 
        0.0361*lm^3*NM - 0.4902124750401823*NL - 0.1913589330947841*lm*
         NL - 0.13605397639217356*lm^2*NL - 0.0361*lm^3*NL + 
        0.2246013661927813*NH - 0.1913589330947841*lm*NH - 
        0.13605397639217356*lm^2*NH - 0.0361*lm^3*NH)}, 
     {0.145, CF*NC*(CA*(1.1776545246967285 + 0.4733989178058058*lm + 
          1.138050994170652*lm^2 + 0.20029548611111112*lm^3) + 
        CF*(0.4001343268672139 + 0.2870337880420358*lm - 0.4841715265843875*
           lm^2 + 0.32775625*lm^3) - 0.46487286056621213*NM - 
        0.1939748529036447*lm*NM - 0.13739430954617918*lm^2*NM - 
        0.03641736111111111*lm^3*NM - 0.49438392848969986*NL - 
        0.1939748529036447*lm*NL - 0.13739430954617918*lm^2*NL - 
        0.03641736111111111*lm^3*NL + 0.2276459153212208*NH - 
        0.1939748529036447*lm*NH - 0.13739430954617918*lm^2*NH - 
        0.03641736111111111*lm^3*NH)}, 
     {0.15, CF*NC*(CA*(1.1867889717351354 + 0.48320687956574293*lm + 
          1.1487400348144123*lm^2 + 0.2020486111111111*lm^3) + 
        CF*(0.4040383218468389 + 0.2931293533676863*lm - 0.4872180112127798*
           lm^2 + 0.330625*lm^3) - 0.4668037225617549*NM - 
        0.19653408509038278*lm*NM - 0.1387292487541356*lm^2*NM - 
        0.03673611111111111*lm^3*NM - 0.4984816271145752*NL - 
        0.19653408509038278*lm*NL - 0.1387292487541356*lm^2*NL - 
        0.03673611111111111*lm^3*NL + 0.2306665809540972*NH - 
        0.19653408509038278*lm*NH - 0.1387292487541356*lm^2*NH - 
        0.03673611111111111*lm^3*NH)}, 
     {0.155, CF*NC*(CA*(1.1953577213818525 + 0.49260616663247814*lm + 
          1.1594131106480672*lm^2 + 0.203809375*lm^3) + 
        CF*(0.40760885984536743 + 0.2990012399002059*lm - 
          0.4903801087122538*lm^2 + 0.33350625*lm^3) - 
        0.4685870474599893*NM - 0.19903686600567788*lm*NM - 
        0.14005863375419403*lm^2*NM - 0.03705625*lm^3*NM - 
        0.5025078423036765*NL - 0.19903686600567788*lm*NL - 
        0.14005863375419403*lm^2*NL - 0.03705625*lm^3*NL + 
        0.23366277351661408*NH - 0.19903686600567788*lm*NH - 
        0.14005863375419403*lm^2*NH - 0.03705625*lm^3*NH)}, 
     {0.16, CF*NC*(CA*(1.2033771171797363 + 0.5015971315563321*lm + 
          1.1700693668471034*lm^2 + 0.20557777777777778*lm^3) + 
        CF*(0.41086702768609 + 0.3046567006489202*lm - 0.49365921788655825*
           lm^2 + 0.3364*lm^3) - 0.47022537650921753*NM - 
        0.20148345756021938*lm*NM - 0.14138230912371574*lm^2*NM - 
        0.03737777777777778*lm^3*NM - 0.5064648038912597*NL - 
        0.20148345756021938*lm*NL - 0.14138230912371574*lm^2*NL - 
        0.03737777777777778*lm^3*NL + 0.23663392460374474*NH - 
        0.20148345756021938*lm*NH - 0.14138230912371574*lm^2*NH - 
        0.03737777777777778*lm^3*NH)}, 
     {0.165, CF*NC*(CA*(1.2108632870284677 + 0.5101802861140617*lm + 
          1.1807079739140465*lm^2 + 0.20735381944444445*lm^3) + 
        CF*(0.41383296057755425 + 0.3101030513734249*lm - 
          0.49705669609519654*lm^2 + 0.33930625*lm^3) - 
        0.47172121846285053*NM - 0.20387414475415552*lm*NM - 
        0.14270012404497817*lm^2*NM - 0.037700694444444446*lm^3*NM - 
        0.5103546994307449*NL - 0.20387414475415552*lm*NL - 
        0.14270012404497817*lm^2*NL - 0.037700694444444446*lm^3*NL + 
        0.23957948605741908*NH - 0.20387414475415552*lm*NH - 
        0.14270012404497817*lm^2*NH - 0.037700694444444446*lm^3*NH)}, 
     {0.17, CF*NC*(CA*(1.2178321340883576 + 0.518356287492432*lm + 
          1.191328126477663*lm^2 + 0.2091375*lm^3) + 
        CF*(0.41652587695827953 + 0.315347657353022*lm - 0.5005738612183697*
           lm^2 + 0.342225*lm^3) - 0.4730770477470361*NM - 
        0.20620923344288614*lm*NM - 0.14401193208684782*lm^2*NM - 
        0.038025*lm^3*NM - 0.514179673732859*NL - 0.20620923344288614*lm*
         NL - 0.14401193208684782*lm^2*NL - 0.038025*lm^3*NL + 
        0.2424989291021294*NH - 0.20620923344288614*lm*NH - 
        0.14401193208684782*lm^2*NH - 0.038025*lm^3*NH)}, 
     {0.175, CF*NC*(CA*(1.2242993296276834 + 0.5261259257283197*lm + 
          1.2019290421718918*lm^2 + 0.21092881944444444*lm^3) + 
        CF*(0.4189641126147892 + 0.32039792158960395*lm - 
          0.5042119934914497*lm^2 + 0.34515625*lm^3) - 
        0.4742953029930277*NM - 0.2084890483128657*lm*NM - 
        0.14531759100095004*lm^2*NM - 0.038350694444444444*lm^3*NM - 
        0.5179418286249083*NL - 0.2084890483128657*lm*NL - 
        0.14531759100095004*lm^2*NL - 0.038350694444444444*lm^3*NL + 
        0.2453917435337834*NH - 0.2084890483128657*lm*NH - 
        0.14531759100095004*lm^2*NH - 0.038350694444444444*lm^3*NH)}, 
     {0.18, CF*NC*(CA*(1.2302803075323618 + 0.5334901122705782*lm + 
          1.2125099605873768*lm^2 + 0.21272777777777777*lm^3) + 
        CF*(0.4211651539604082 + 0.3252612742791607*lm - 0.5079723372206563*
           lm^2 + 0.3481*lm^3) - 0.4753783858820472*NM - 
        0.21071393104456315*lm*NM - 0.1466169625310382*lm^2*NM - 
        0.038677777777777776*lm^3*NM - 0.5216432228949508*NL - 
        0.21071393104456315*lm*NL - 0.1466169625310382*lm^2*NL - 
        0.038677777777777776*lm^3*NL + 0.24825743695723512*NH - 
        0.21071393104456315*lm*NH - 0.1466169625310382*lm^2*NH - 
        0.038677777777777776*lm^3*NH)}, 
     {0.185, CF*NC*(CA*(1.2357902602390693 + 0.5404498695461134*lm + 
          1.2230701422892776*lm^2 + 0.214534375*lm^3) + 
        CF*(0.42314567039501955 + 0.32994516340889246*lm - 
          0.5118561023902731*lm^2 + 0.35105625*lm^3) - 0.47632866025818144*
         NM - 0.21288423864266828*lm*NM - 0.1479099122344141*lm^2*NM - 
        0.03900625*lm^3*NM - 0.5252858723904077*NL - 0.21288423864266828*lm*
         NL - 0.1479099122344141*lm^2*NL - 0.03900625*lm^3*NL + 
        0.25109553406843915*NH - 0.21288423864266828*lm*NH - 
        0.1479099122344141*lm^2*NH - 0.03900625*lm^3*NH)}, 
     {0.19, CF*NC*(CA*(1.2408441358881643 + 0.5470063214272702*lm + 
          1.2336088678957502*lm^2 + 0.21634861111111112*lm^3) + 
        CF*(0.42492154569170926 + 0.33445704635538576*lm - 
          0.5158644661705905*lm^2 + 0.354025*lm^3) - 0.47714845147135676*
         NM - 0.21500034191613335*lm*NM - 0.14919630931437883*lm^2*NM - 
        0.03933611111111111*lm^3*NM - 0.5288717502454342*NL - 
        0.21500034191613335*lm*NL - 0.14919630931437883*lm^2*NL - 
        0.03933611111111111*lm^3*NL + 0.25390557597762003*NH - 
        0.21500034191613335*lm*NH - 0.14919630931437883*lm^2*NH - 
        0.03933611111111111*lm^3*NH)}, 
     {0.195, CF*NC*(CA*(1.2454566365222905 + 0.5531606845101316*lm + 
          1.244125437212087*lm^2 + 0.21817048611111112*lm^3) + 
        CF*(0.42650790837644015 + 0.3388043823750318*lm - 
          0.5199985743347668*lm^2 + 0.35700625*lm^3) - 0.47784004591789686*
         NM - 0.21706262409277352*lm*NM - 0.15047602646280367*lm^2*NM - 
        0.03966736111111111*lm^3*NM - 0.5324027872153434*NL - 
        0.21706262409277352*lm*NL - 0.15047602646280367*lm^2*NL - 
        0.03966736111111111*lm^3*NL + 0.25668711957023016*NH - 
        0.21706262409277352*lm*NH - 0.15047602646280367*lm^2*NH - 
        0.03966736111111111*lm^3*NH)}, 
     {0.2, NC*(CA*CF*(1.2496422171813673 + 0.5589142601240608*lm + 
          1.254619168416038*lm^2 + 0.22*lm^3) + 
        CF^2*(0.4279191610827451 + 0.3429946258912999*lm - 
          0.5242595425919377*lm^2 + 0.36*lm^3) + 
        CF*((-0.47840569075075845 - 0.21907147955497713*lm - 
            0.15174893971200692*lm^2 - 0.04*lm^3)*NM + 
          (-0.5358808720996934 - 0.21907147955497713*lm - 0.15174893971200692*
             lm^2 - 0.04*lm^3)*NL + (0.25943973690280514 - 
            0.21907147955497713*lm - 0.15174893971200692*lm^2 - 0.04*lm^3)*
           NH))}, {0.205, NC*(CA*CF*(1.2534150857656305 + 
          0.5642684270020626*lm + 1.2650893972902977*lm^2 + 
          0.22183715277777777*lm^3) + CF^2*(0.4291690088758012 + 
          0.34703522049500807*lm - 0.5286484578431492*lm^2 + 
          0.36300625*lm^3) + CF*((-0.47884759373545055 - 0.22102731268465048*
             lm - 0.15301492829520563*lm^2 - 0.04033402777777778*lm^3)*NM + 
          (-0.5393078522384311 - 0.22102731268465048*lm - 0.15301492829520563*
             lm^2 - 0.04033402777777778*lm^3)*NL + 
          (0.26216301463111463 - 0.22102731268465048*lm - 0.15301492829520563*
             lm^2 - 0.04033402777777778*lm^3)*NH))}, 
     {0.21, NC*(CA*CF*(1.256789203556133 + 0.5692246345495167*lm + 
          1.2755354764985352*lm^2 + 0.22368194444444445*lm^3) + 
        CF^2*(0.4302704865499146 + 0.3509335935836581*lm - 
          0.5331663793660333*lm^2 + 0.366025*lm^3) + 
        CF*((-0.4791679232308978 - 0.22293053680688132*lm - 
            0.1542738745148852*lm^2 - 0.040669444444444446*lm^3)*NM + 
          (-0.5426855340678197 - 0.22293053680688132*lm - 0.1542738745148852*
             lm^2 - 0.040669444444444446*lm^3)*NL + 
          (0.26485655346826226 - 0.22293053680688132*lm - 0.1542738745148852*
             lm^2 - 0.040669444444444446*lm^3)*NH))}, 
     {0.215, NC*(CA*CF*(1.2597782862972307 + 0.5737843966557746*lm + 
          1.2859567749017093*lm^2 + 0.225534375*lm^3) + 
        CF^2*(0.43123598491083387 + 0.35469715157448595*lm - 
          0.5378143399335665*lm^2 + 0.36905625*lm^3) + 
        CF*((-0.47936880827736444 - 0.22478157322298278*lm - 
            0.1555256636184926*lm^2 - 0.04100625*lm^3)*NM + 
          (-0.546015683724853 - 0.22478157322298278*lm - 0.1555256636184926*
             lm^2 - 0.04100625*lm^3)*NL + (0.2675199676706118 - 
            0.22478157322298278*lm - 0.1555256636184926*lm^2 - 
            0.04100625*lm^3)*NH))}, 
     {0.22, NC*(CA*CF*(1.262395805758443 + 0.5779492859991405*lm + 
          1.2963526769117135*lm^2 + 0.22739444444444445*lm^3) + 
        CF^2*(0.4320772760600418 + 0.35833327563331846*lm - 
          0.5425933468717417*lm^2 + 0.3721*lm^3) + 
        CF*((-0.4794523387759479 - 0.2265808503246051*lm - 0.1567701836809176*
             lm^2 - 0.04134444444444445*lm^3)*NM + 
          (-0.5493000276905259 - 0.2265808503246051*lm - 0.1567701836809176*
             lm^2 - 0.04134444444444445*lm^3)*NL + 
          (0.27015288454961295 - 0.2265808503246051*lm - 0.1567701836809176*
             lm^2 - 0.04134444444444445*lm^3)*NH))}, 
     {0.225, NC*(CA*CF*(1.2646549917041012 + 0.5817209288010253*lm + 
          1.3067225818796735*lm^2 + 0.22926215277777778*lm^3) + 
        CF^2*(0.4328055377024462 + 0.3618493178678023*lm - 
          0.5475043830605343*lm^2 + 0.37515625*lm^3) + 
        CF*((-0.47942056574617237 - 0.22832880278149625*lm - 
            0.15800732549327395*lm^2 - 0.04168402777777778*lm^3)*NM + 
          (-0.5525402534637462 - 0.22832880278149625*lm - 0.15800732549327395*
             lm^2 - 0.04168402777777778*lm^3)*NL + 
          (0.27275494400777517 - 0.22832880278149625*lm - 0.15800732549327395*
             lm^2 - 0.04168402777777778*lm^3)*NH))}, 
     {0.23, NC*(CA*CF*(1.2665688342086558 + 0.5851009999896811*lm + 
          1.3170659035164665*lm^2 + 0.2311375*lm^3) + 
        CF^2*(0.43343137650205465 + 0.3652525979392205*lm - 
          0.5525484078821459*lm^2 + 0.378225*lm^3) + 
        CF*((-0.4792755016500098 - 0.23002587079627607*lm - 
            0.15923698245753934*lm^2 - 0.042025*lm^3)*NM + 
          (-0.5557380102588784 - 0.23002587079627607*lm - 0.15923698245753934*
             lm^2 - 0.042025*lm^3)*NL + (0.2753257980971929 - 
            0.23002587079627607*lm - 0.15923698245753934*lm^2 - 
            0.042025*lm^3)*NH))}, 
     {0.235, NC*(CA*CF*(1.2681500862636337 + 0.5880912187379771*lm + 
          1.3273820693432408*lm^2 + 0.23302048611111112*lm^3) + 
        CF^2*(0.4339648505125338 + 0.36855040005205747*lm - 
          0.5577263581201514*lm^2 + 0.38130625*lm^3) + 
        CF*((-0.479019120772212 - 0.23167249942027476*lm - 
            0.16045905048664985*lm^2 - 0.04236736111111111*lm^3)*NM + 
          (-0.5588949097209349 - 0.23167249942027476*lm - 0.16045905048664985*
             lm^2 - 0.04236736111111111*lm^3)*NL + 
          (0.27786511059916263 - 0.23167249942027476*lm - 0.16045905048664985*
             lm^2 - 0.04236736111111111*lm^3)*NH))}, 
     {0.24, NC*(CA*CF*(1.2694112666292754 + 0.5906933443432536*lm + 
          1.3376705201699177*lm^2 + 0.2349111111111111*lm^3) + 
        CF^2*(0.43441549071104907 + 0.3717499702848106*lm - 
          0.563039148812862*lm^2 + 0.3844*lm^3) + 
        CF*((-0.47865335964803446 - 0.2332691379250932*lm - 
            0.161673427909682*lm^2 - 0.04271111111111111*lm^3)*NM + 
          (-0.5620125266533107 - 0.2332691379250932*lm - 0.161673427909682*
             lm^2 - 0.04271111111111111*lm^3)*NL + 
          (0.28037255662355504 - 0.2332691379250932*lm - 0.161673427909682*
             lm^2 - 0.04271111111111111*lm^3)*NH))}, 
     {0.245, NC*(CA*CF*(1.2703646628899194 + 0.5929091724204456*lm + 
          1.3479307095998185*lm^2 + 0.236809375*lm^3) + 
        CF^2*(0.43479232166486365 + 0.3748585142293662*lm - 
          0.5684876740639334*lm^2 + 0.38750625*lm^3) + 
        CF*((-0.4781801175307273 - 0.2348162392250749*lm - 
            0.16288001538178518*lm^2 - 0.04305625*lm^3)*NM + 
          (-0.5650923997537024 - 0.2348162392250749*lm - 0.16288001538178518*
             lm^2 - 0.04305625*lm^3)*NL + (0.28284782222671645 - 
            0.2348162392250749*lm - 0.16288001538178518*lm^2 - 
            0.04305625*lm^3)*NH))}, 
     {0.25, NC*(CA*CF*(1.271022334677469 + 0.594740531382464*lm + 
          1.358162103558726*lm^2 + 0.2387152777777778*lm^3) + 
        CF^2*(0.4351038813606563 + 0.3778831949096222*lm - 
          0.5740728078129939*lm^2 + 0.390625*lm^3) + 
        CF*((-0.47760125689202576 - 0.2363142593463531*lm - 
            0.16407871579855624*lm^2 - 0.043402777777777776*lm^3)*NM + 
          (-0.568136032354506 - 0.2363142593463531*lm - 0.16407871579855624*
             lm^2 - 0.043402777777777776*lm^3)*NL + 
          (0.285290604046771 - 0.2363142593463531*lm - 0.16407871579855624*
             lm^2 - 0.043402777777777776*lm^3)*NH))}, 
     {0.255, NC*(CA*CF*(1.2713961170318315 + 0.5961892791843063*lm + 
          1.3683641798468194*lm^2 + 0.24062881944444445*lm^3) + 
        CF^2*(0.43535824022674396 + 0.3808311309530178*lm - 
          0.5797954045688409*lm^2 + 0.39375625*lm^3) + 
        CF*((-0.47691860394979574 - 0.2377636569385553*lm - 
            0.16526943421457324*lm^2 - 0.043750694444444446*lm^3)*NM + 
          (-0.5711448931645319 - 0.2377636569385553*lm - 0.16526943421457324*
             lm^2 - 0.043750694444444446*lm^3)*NL + 
          (0.28770060895528515 - 0.2377636569385553*lm - 0.16526943421457324*
             lm^2 - 0.043750694444444446*lm^3)*NH))}, 
     {0.26, NC*(CA*CF*(1.2714976238711817 + 0.5972573003095738*lm + 
          1.3785364277120518*lm^2 + 0.24255*lm^3) + 
        CF^2*(0.43556301937830216 + 0.38370939499126816*lm - 
          0.5856563001075518*lm^2 + 0.3969*lm^3) + 
        CF*((-0.47613394921771784 - 0.23916489282561992*lm - 
            0.1664520777658276*lm^2 - 0.0441*lm^3)*NM + 
          (-0.5741204170093579 - 0.23916489282561992*lm - 0.1664520777658276*
             lm^2 - 0.0441*lm^3)*NL + (0.2900775537243357 - 
            0.23916489282561992*lm - 0.1664520777658276*lm^2 - 0.0441*lm^3)*
           NH))}, {0.265, NC*(CA*CF*(1.2713382515483442 + 
          0.5979465029800446*lm + 1.3886783474436497*lm^2 + 
          0.24447881944444444*lm^3) + CF^2*(0.4357254081153823 + 
          0.3865250122689414*lm - 0.5916563121376641*lm^2 + 
          0.40005625*lm^3) + CF*((-0.4752490480725435 - 0.24051842959251196*
             lm - 0.1676265555958151*lm^2 - 0.044450694444444445*lm^3)*NM + 
          (-0.5770640055680505 - 0.24051842959251196*lm - 0.1676265555958151*
             lm^2 - 0.044450694444444445*lm^3)*NL + 
          (0.2924211647080941 - 0.24051842959251196*lm - 0.1676265555958151*
             lm^2 - 0.044450694444444445*lm^3)*NH))}, 
     {0.27, NC*(CA*CF*(1.2709291824726034 + 0.5982588165707104*lm + 
          1.3987894499845193*lm^2 + 0.24641527777777777*lm^3) + 
        CF^2*(0.43585218070306386 + 0.3892849594406014*lm - 
          0.597796240934423*lm^2 + 0.403225*lm^3) + 
        CF*((-0.4742656213350268 - 0.2418247312049211*lm - 0.1687927787850641*
             lm^2 - 0.044802777777777775*lm^3)*NM + 
          (-0.5799770281043348 - 0.2418247312049211*lm - 0.1687927787850641*
             lm^2 - 0.044802777777777775*lm^3)*NL + 
          (0.2947311775381066 - 0.2418247312049211*lm - 0.1687927787850641*
             lm^2 - 0.044802777777777775*lm^3)*NH))}, 
     {0.275, NC*(CA*CF*(1.270281388778855 + 0.598196189214262*lm + 
          1.4088692565614314*lm^2 + 0.248359375*lm^3) + 
        CF^2*(0.4359497124625057 + 0.3919961635390946*lm - 
          0.6040768699449307*lm^2 + 0.40640625*lm^3) + 
        CF*((-0.47318535586113447 - 0.24308426265929045*lm - 
            0.1699506602838966*lm^2 - 0.04515625*lm^3)*NM + 
          (-0.5828608221906044 - 0.24308426265929045*lm - 0.1699506602838966*
             lm^2 - 0.04515625*lm^3)*NL + (0.297007336831509 - 
            0.24308426265929045*lm - 0.1699506602838966*lm^2 - 
            0.04515625*lm^3)*NH))}, 
     {0.28, NC*(CA*CF*(1.2694056360283148 + 0.5977605855804203*lm + 
          1.4189172983319456*lm^2 + 0.2503111111111111*lm^3) + 
        CF^2*(0.43602399520098845 + 0.39466550109921944*lm - 
          0.6104989663659074*lm^2 + 0.4096*lm^3) + 
        CF*((-0.4720099051405668 - 0.244297489660762*lm - 0.1711001148482325*
             lm^2 - 0.04551111111111111*lm^3)*NM + 
          (-0.5857166944234232 - 0.244297489660762*lm - 0.1711001148482325*
             lm^2 - 0.04551111111111111*lm^3)*NL + 
          (0.29924939591146776 - 0.244297489660762*lm - 0.1711001148482325*
             lm^2 - 0.04551111111111111*lm^3)*NH))}, 
     {0.285, NC*(CA*CF*(1.2683124869269904 + 0.5969539848167836*lm + 
          1.4289331160471097*lm^2 + 0.25227048611111114*lm^3) + 
        CF^2*(0.43608065200830026 + 0.39729979742249955*lm - 
          0.6170632816956386*lm^2 + 0.41280625*lm^3) + 
        CF*((-0.4707408899000098 - 0.24546487832683847*lm - 
            0.1722410589782624*lm^2 - 0.04586736111111111*lm^3)*NM + 
          (-0.5885459211293983 - 0.24546487832683847*lm - 0.1722410589782624*
             lm^2 - 0.04586736111111111*lm^3)*NL + 
          (0.30145711653919083 - 0.24546487832683847*lm - 0.1722410589782624*
             lm^2 - 0.04586736111111111*lm^3)*NH))}, 
     {0.29, NC*(CA*CF*(1.267012305049899 + 0.5957783786390021*lm + 
          1.4389162597290366*lm^2 + 0.2542375*lm^3) + 
        CF^2*(0.4361249514459979 + 0.3999058259701123*lm - 
          0.6237705522615766*lm^2 + 0.416025*lm^3) + 
        CF*((-0.46937989870886926 - 0.24658689491475252*lm - 
            0.17337341085982483*lm^2 - 0.046225*lm^3)*NM + 
          (-0.5913497490605045 - 0.24658689491475252*lm - 0.17337341085982483*
             lm^2 - 0.046225*lm^3)*NL + (0.30363026865689413 - 
            0.24658689491475252*lm - 0.17337341085982483*lm^2 - 
            0.046225*lm^3)*NH))}, 
     {0.295, NC*(CA*CF*(1.2655152585605987 + 0.594235769559127*lm + 
          1.4488662883625265*lm^2 + 0.25621215277777776*lm^3) + 
        CF^2*(0.43616182115515395 + 0.40249030787221757*lm - 
          0.6306214997249565*lm^2 + 0.41925625*lm^3) + 
        CF*((-0.46792848858553543 - 0.24766400557070836*lm - 
            0.17449709030833818*lm^2 - 0.04658402777777778*lm^3)*NM + 
          (-0.594129396078108 - 0.24766400557070836*lm - 0.17449709030833818*
             lm^2 - 0.04658402777777778*lm^3)*NL + 
          (0.3057686301411526 - 0.24766400557070836*lm - 0.17449709030833818*
             lm^2 - 0.04658402777777778*lm^3)*NH))}, 
     {0.3, NC*(CA*CF*(1.263831302205613 + 0.5923281692419106*lm + 
          1.4587827695999651*lm^2 + 0.25819444444444445*lm^3) + 
        CF^2*(0.43619590433004235 + 0.40505991154300486*lm - 
          0.6376168315636933*lm^2 + 0.4225*lm^3) + 
        CF*((-0.4663881856024831 - 0.24869667609931556*lm - 
            0.17561201871514517*lm^2 - 0.04694444444444444*lm^3)*NM + 
          (-0.5968860518250854 - 0.24869667609931556*lm - 0.17561201871514517*
             lm^2 - 0.04694444444444444*lm^3)*NL + 
          (0.3078719865661016 - 0.24869667609931556*lm - 0.17561201871514517*
             lm^2 - 0.04694444444444444*lm^3)*NH))}, 
     {0.305, NC*(CA*CF*(1.2619702721119885 + 0.590057596979677*lm + 
          1.468665279478769*lm^2 + 0.260184375*lm^3) + 
        CF^2*(0.43623139000940325 + 0.40762125239174285*lm - 
          0.6447572415347418*lm^2 + 0.42575625*lm^3) + 
        CF*((-0.4647604854887425 - 0.24968537175167718*lm - 
            0.1767181189961398*lm^2 - 0.04730625*lm^3)*NM + 
          (-0.5996208783855639 - 0.24968537175167718*lm - 0.1767181189961398*
             lm^2 - 0.04730625*lm^3)*NL + (0.3099401309759901 - 
            0.24968537175167718*lm - 0.1767181189961398*lm^2 - 
            0.04730625*lm^3)*NH))}, 
     {0.31, NC*(CA*CF*(1.259941745894669 + 0.5874260782771524*lm + 
          1.478513402150712*lm^2 + 0.2621819444444444*lm^3) + 
        CF^2*(0.4362723121813003 + 0.4101808926209862*lm - 
          0.6520434101170167*lm^2 + 0.429025*lm^3) + 
        CF*((-0.46304685422847625 - 0.25063055703072123*lm - 
            0.1778153155425537*lm^2 - 0.047669444444444445*lm^3)*NM + 
          (-0.6023350109319155 - 0.25063055703072123*lm - 0.1778153155425537*
             lm^2 - 0.047669444444444445*lm^3)*NL + 
          (0.31197286366661725 - 0.25063055703072123*lm - 0.1778153155425537*
             lm^2 - 0.047669444444444445*lm^3)*NH))}, 
     {0.315, NC*(CA*CF*(1.2577551470789248 + 0.5844356435383299*lm + 
          1.4883267296225033*lm^2 + 0.26418715277777777*lm^3) + 
        CF^2*(0.4363223597014351 + 0.41274534110388117*lm - 
          0.6594760049359035*lm^2 + 0.43230625*lm^3) + 
        CF*((-0.4612487286545733 - 0.25153269551248086*lm - 
            0.1789035341737885*lm^2 - 0.04803402777777778*lm^3)*NM + 
          (-0.6050295583587377 - 0.25153269551248086*lm - 0.1789035341737885*
             lm^2 - 0.04803402777777778*lm^3)*NL + 
          (0.3139699919752154 - 0.25153269551248086*lm - 0.1789035341737885*
             lm^2 - 0.04803402777777778*lm^3)*NH))}, 
     {0.32, NC*(CA*CF*(1.2554197220424634 + 0.5810883268480814*lm + 
          1.4981048615070283*lm^2 + 0.2662*lm^3) + 
        CF^2*(0.43638494062682354 + 0.4153210533332218*lm - 
          0.6670556811703173*lm^2 + 0.4356*lm^3) + 
        CF*((-0.45936751703632994 - 0.2523922496821328*lm - 
            0.17998270209218695*lm^2 - 0.0484*lm^3)*NM + 
          (-0.6077056039036294 - 0.2523922496821328*lm - 0.17998270209218695*
             lm^2 - 0.0484*lm^3)*NL + (0.315931330078368 - 
            0.2523922496821328*lm - 0.17998270209218695*lm^2 - 0.0484*lm^3)*
           NH))}, {0.325, NC*(CA*CF*(1.2529445435650872 + 
          0.5773861648417983*lm + 1.5078474047847052*lm^2 + 
          0.2682204861111111*lm^3) + CF^2*(0.4364631928008355 + 
          0.41791443143555285*lm - 0.6747830819432095*lm^2 + 
          0.43890625*lm^3) + CF*((-0.45740459966042263 - 0.253209680783701*
             lm - 0.1810527478396434*lm^2 - 0.04876736111111111*lm^3)*NM + 
          (-0.6103642057546502 - 0.253209680783701*lm - 0.1810527478396434*
             lm^2 - 0.04876736111111111*lm^3)*NL + 
          (0.31785669879757666 - 0.253209680783701*lm - 0.1810527478396434*
             lm^2 - 0.04876736111111111*lm^3)*NH))}, 
     {0.33, NC*(CA*CF*(1.250338514332125 + 0.573331195656867*lm + 
          1.517553973574445*lm^2 + 0.2702486111111111*lm^3) + 
        CF^2*(0.4365599940093514 + 0.42053182424419744*lm - 
          0.6826588386963627*lm^2 + 0.442225*lm^3) + 
        CF*((-0.455361329404501 - 0.25398544868241685*lm - 
            0.18211360125595968*lm^2 - 0.04913611111111111*lm^3)*NM + 
          (-0.6130063976444038 - 0.25398544868241685*lm - 0.18211360125595968*
             lm^2 - 0.04913611111111111*lm^3)*NL + 
          (0.3197459254121149 - 0.25398544868241685*lm - 0.18211360125595968*
             lm^2 - 0.04913611111111111*lm^3)*NH))}, 
     {0.335, NC*(CA*CF*(1.247610370388727 + 0.5689254579602621*lm + 
          1.527224188913728*lm^2 + 0.272284375*lm^3) + 
        CF^2*(0.43667797172639167 + 0.42317952742561626*lm - 
          0.6906835715502633*lm^2 + 0.44555625*lm^3) + 
        CF*((-0.453239032302835 - 0.2547200117388092*lm - 0.18316519343885962*
             lm^2 - 0.04950625*lm^3)*NM + (-0.6156331894307435 - 
            0.2547200117388092*lm - 0.18316519343885962*lm^2 - 
            0.04950625*lm^3)*NL + (0.3215988434788265 - 0.2547200117388092*
             lm - 0.18316519343885962*lm^2 - 0.04950625*lm^3)*NH))}, 
     {0.34, NC*(CA*CF*(1.2447686845425967 + 0.564170990046975*lm + 
          1.536857678547351*lm^2 + 0.2743277777777778*lm^3) + 
        CF^2*(0.43681951246680084 + 0.42586378365398686*lm - 
          0.6988578896497895*lm^2 + 0.4489*lm^3) + 
        CF*((-0.4510390081035465 - 0.2554138266936673*lm - 
            0.18420745670557895*lm^2 - 0.04987777777777778*lm^3)*NM + 
          (-0.6182455676641427 - 0.2554138266936673*lm - 0.18420745670557895*
             lm^2 - 0.04987777777777778*lm^3)*NL + 
          (0.32341529265854824 - 0.2554138266936673*lm - 0.18420745670557895*
             lm^2 - 0.04987777777777778*lm^3)*NH))}, 
     {0.345, NC*(CA*CF*(1.2418218697131902 + 0.559069829004395*lm + 
          1.5464540767244153*lm^2 + 0.2763788194444444*lm^3) + 
        CF^2*(0.4369867707628216 + 0.42859078282932644*lm - 
          0.7071823914964114*lm^2 + 0.45225625*lm^3) + 
        CF*((-0.4487625308170369 - 0.25606734856308805*lm - 
            0.1852403245559543*lm^2 - 0.050250694444444445*lm^3)*NM + 
          (-0.6208444961418089 - 0.25606734856308805*lm - 0.1852403245559543*
             lm^2 - 0.050250694444444445*lm^3)*NL + 
          (0.3251951185488521 - 0.25606734856308805*lm - 0.1852403245559543*
             lm^2 - 0.050250694444444445*lm^3)*NH))}, 
     {0.35, NC*(CA*CF*(1.2387781822257768 + 0.5536240099381223*lm + 
          1.5560130240031607*lm^2 + 0.2784375*lm^3) + 
        CF^2*(0.4371816777806667 + 0.43136666233487975*lm - 
          0.7156576652675554*lm^2 + 0.455625*lm^3) + 
        CF*((-0.4464108492552976 - 0.2566810305428772*lm - 0.1862637316369383*
             lm^2 - 0.050625*lm^3)*NM + (-0.6234309164486542 - 
            0.2566810305428772*lm - 0.1862637316369383*lm^2 - 0.050625*lm^3)*
           NL + (0.32693817252282315 - 0.2566810305428772*lm - 
            0.1862637316369383*lm^2 - 0.050625*lm^3)*NH))}, 
     {0.355, NC*(CA*CF*(1.2356457250491173 + 0.5478355652550309*lm + 
          1.5655341670632659*lm^2 + 0.28050381944444447*lm^3) + 
        CF^2*(0.43740594959250234 + 0.4341975073298561*lm - 
          0.7242842891237468*lm^2 + 0.45900625*lm^3) + 
        CF*((-0.4439851875618553 - 0.25725532392163164*lm - 
            0.18727761370847257*lm^2 - 0.051000694444444446*lm^3)*NM + 
          (-0.6260057484852644 - 0.25725532392163164*lm - 0.18727761370847257*
             lm^2 - 0.051000694444444446*lm^3)*NL + 
          (0.32864431157360136 - 0.25725532392163164*lm - 0.18727761370847257*
             lm^2 - 0.051000694444444446*lm^3)*NH))}, 
     {0.36, NC*(CA*CF*(1.2324324509757976 + 0.5417065239996989*lm + 
          1.5750171585252668*lm^2 + 0.28257777777777776*lm^3) + 
        CF^2*(0.4376610951185818 + 0.4370893510739278*lm - 
          0.733062831504109*lm^2 + 0.4624*lm^3) + 
        CF*((-0.44148674573215774 - 0.2577906780018779*lm - 
            0.18828190761065455*lm^2 - 0.05137777777777778*lm^3)*NM + 
          (-0.6285698909830268 - 0.2577906780018779*lm - 0.18828190761065455*
             lm^2 - 0.05137777777777778*lm^3)*NL + 
          (0.3303133981644334 - 0.2577906780018779*lm - 0.18828190761065455*
             lm^2 - 0.05137777777777778*lm^3)*NH))}, 
     {0.365, NC*(CA*CF*(1.2291461657445353 + 0.5352389112406141*lm + 
          1.5844616567767549*lm^2 + 0.284659375*lm^3) + 
        CF^2*(0.4379484237536217 + 0.44004817528020534*lm - 
          0.7419938514107648*lm^2 + 0.46580625*lm^3) + 
        CF*((-0.4389167001242613 - 0.25828754002869175*lm - 
            0.18927655123213724*lm^2 - 0.05175625*lm^3)*NM + 
          (-0.6311242220066033 - 0.25828754002869175*lm - 0.18927655123213724*
             lm^2 - 0.05175625*lm^3)*NL + (0.33194530008399226 - 
            0.25828754002869175*lm - 0.18927655123213724*lm^2 - 
            0.05175625*lm^3)*NH))}, 
     {0.37, NC*(CA*CF*(1.2257945311039982 + 0.5284347475028125*lm + 
          1.593867325805046*lm^2 + 0.2867486111111111*lm^3) + 
        CF^2*(0.4382690526908943 + 0.44307991049367834*lm - 
          0.751077898682652*lm^2 + 0.469225*lm^3) + 
        CF*((-0.4362762039597209 - 0.2587463551252629*lm - 
            0.19026148347970534*lm^2 - 0.05213611111111111*lm^3)*NM + 
          (-0.6336695994439445 - 0.2587463551252629*lm - 0.19026148347970534*
             lm^2 - 0.05213611111111111*lm^3)*NL + 
          (0.33353989030673764 - 0.2587463551252629*lm - 0.19026148347970534*
             lm^2 - 0.05213611111111111*lm^3)*NH))}, 
     {0.375, NC*(CA*CF*(1.2223850678178845 + 0.5212960482438526*lm + 
          1.6032338350360202*lm^2 + 0.2888454861111111*lm^3) + 
        CF^2*(0.43862391395691114 + 0.4461904364923633*lm - 
          0.7603155142592396*lm^2 + 0.47265625*lm^3) + 
        CF*((-0.433566387814624 - 0.25916756623491066*lm - 
            0.19123664424897338*lm^2 - 0.05251736111111111*lm^3)*NM + 
          (-0.6362068614840586 - 0.25916756623491066*lm - 0.19123664424897338*
             lm^2 - 0.05251736111111111*lm^3)*NL + 
          (0.33509704685809943 - 0.25916756623491066*lm - 0.19123664424897338*
             lm^2 - 0.05251736111111111*lm^3)*NH))}, 
     {0.38, NC*(CA*CF*(1.218925158611191 + 0.5138248233702426*lm + 
          1.6125608591788545*lm^2 + 0.29095*lm^3) + 
        CF^2*(0.43901376116900515 + 0.4493855827086278*lm - 
          0.7697072304346019*lm^2 + 0.4761*lm^3) + 
        CF*((-0.4307883601007448 - 0.2595516140690916*lm - 
            0.19220197439615536*lm^2 - 0.0529*lm^3)*NM + 
          (-0.6387368270827576 - 0.2595516140690916*lm - 0.19220197439615536*
             lm^2 - 0.0529*lm^3)*NL + (0.3366166526842805 - 
            0.2595516140690916*lm - 0.19220197439615536*lm^2 - 0.0529*lm^3)*
           NH))}, {0.385, NC*(CA*CF*(1.2154220510577582 + 
          0.5060230767916446*lm + 1.6218480780763833*lm^2 + 
          0.29306215277777775*lm^3) + CF^2*(0.43943917602756816 + 
          0.4526711286683737*lm - 0.7792535711022818*lm^2 + 
          0.47955625*lm^3) + CF*((-0.42794320753682197 - 0.25989893706097245*
             lm - 0.1931574157108576*lm^2 - 0.05328402777777778*lm^3)*NM + 
          (-0.6412602964166112 - 0.25989893706097245*lm - 0.1931574157108576*
             lm^2 - 0.05328402777777778*lm^3)*NL + 
          (0.3380985955264838 - 0.25989893706097245*lm - 0.1931574157108576*
             lm^2 - 0.05328402777777778*lm^3)*NH))}, 
     {0.39, NC*(CA*CF*(1.211882860409307 + 0.4978928060103597*lm + 
          1.631095176560839*lm^2 + 0.29518194444444446*lm^3) + 
        CF^2*(0.43990057455418174 + 0.4560528044459513*lm - 
          0.7889550519913542*lm^2 + 0.483025*lm^3) + 
        CF*((-0.4250319956099923 - 0.2602099713241741*lm - 
            0.19410291088984954*lm^2 - 0.05366944444444444*lm^3)*NM + 
          (-0.6437780513253459 - 0.2602099713241741*lm - 0.19410291088984954*
             lm^2 - 0.05366944444444444*lm^3)*NL + 
          (0.3395427677993801 - 0.2602099713241741*lm - 0.19410291088984954*
             lm^2 - 0.05366944444444444*lm^3)*NH))}, 
     {0.395, NC*(CA*CF*(1.208314572366316 + 0.4894360017437775*lm + 
          1.640301844314732*lm^2 + 0.297309375*lm^3) + 
        CF^2*(0.4403982130863747 + 0.4595362911328559*lm - 
          0.7988121808940749*lm^2 + 0.48650625*lm^3) + 
        CF*((-0.4220557690274325 - 0.26048515061631883*lm - 
            0.19503840351176946*lm^2 - 0.05405625*lm^3)*NM + 
          (-0.6462908557429322 - 0.26048515061631883*lm - 0.19503840351176946*
             lm^2 - 0.05405625*lm^3)*NL + (0.3409490664736404 - 
            0.26048515061631883*lm - 0.19503840351176946*lm^2 - 
            0.05405625*lm^3)*NH))}, 
     {0.4, NC*(CA*CF*(1.204724045791182 + 0.4806546475776274*lm + 
          1.6494677757366496*lm^2 + 0.29944444444444446*lm^3) + 
        CF^2*(0.4409321940392652 + 0.46312722131841844*lm - 
          0.8088254578854825*lm^2 + 0.49*lm^3) + 
        CF*((-0.4190155521582833 - 0.26072490630703954*lm - 
            0.19596383801272416*lm^2 - 0.05444444444444444*lm^3)*NM + 
          (-0.6487994561176036 - 0.26072490630703954*lm - 0.19596383801272416*
             lm^2 - 0.05444444444444444*lm^3)*NL + 
          (0.3423173929623679 - 0.26072490630703954*lm - 0.19596383801272416*
             lm^2 - 0.05444444444444444*lm^3)*NH))}, 
     {0.405, NC*(CA*CF*(1.2011180153642007 + 0.47155071964801687*lm + 
          1.6585926698117617*lm^2 + 0.30158715277777776*lm^3) + 
        CF^2*(0.44150247144388655 + 0.4668311795808521*lm - 
          0.8189953755352989*lm^2 + 0.49350625*lm^3) + 
        CF*((-0.4159123494659441 - 0.2609296673501347*lm - 
            0.19687915966274458*lm^2 - 0.05483402777777778*lm^3)*NM + 
          (-0.6513045818210572 - 0.2609296673501347*lm - 0.19687915966274458*
             lm^2 - 0.05483402777777778*lm^3)*NL + 
          (0.34364765301126976 - 0.2609296673501347*lm - 0.19687915966274458*
             lm^2 - 0.05483402777777778*lm^3)*NH))}, 
     {0.41, NC*(CA*CF*(1.1975030941829796 + 0.46212618635038094*lm + 
          1.6676762299868304*lm^2 + 0.3037375*lm^3) + 
        CF^2*(0.4421088562715592 + 0.4706537029871502*lm - 
          0.8293224191124593*lm^2 + 0.497025*lm^3) + 
        CF*((-0.412747145930844 - 0.26109986025957316*lm - 
            0.19778431454306009*lm^2 - 0.055225*lm^3)*NM + 
          (-0.6538069455470827 - 0.26109986025957316*lm - 0.19778431454306009*
             lm^2 - 0.055225*lm^3)*NL + (0.3449397565924203 - 
            0.26109986025957316*lm - 0.19778431454306009*lm^2 - 
            0.055225*lm^3)*NH))}, 
     {0.415, NC*(CA*CF*(1.1938857763059667 + 0.45238300807358933*lm + 
          1.676718164049533*lm^2 + 0.3058954861111111*lm^3) + 
        CF^2*(0.4427510215532559 + 0.47460028160046125*lm - 
          0.8398070667825823*lm^2 + 0.50055625*lm^3) + 
        CF*((-0.40952090746380576 - 0.2612359090890754*lm - 
            0.19867924952415753*lm^2 - 0.05561736111111111*lm^3)*NM + 
          (-0.6563072436998681 - 0.2612359090890754*lm - 0.19867924952415753*
             lm^2 - 0.05561736111111111*lm^3)*NL + 
          (0.34619361780147073 - 0.2612359090890754*lm - 0.19867924952415753*
             lm^2 - 0.05561736111111111*lm^3)*NH))}, 
     {0.42, NC*(CA*CF*(1.1902724392408301 + 0.442323136957577*lm + 
          1.6857181840119198*lm^2 + 0.3080611111111111*lm^3) + 
        CF^2*(0.443428507302506 + 0.47867635899367594*lm - 
          0.8504497897986769*lm^2 + 0.5041*lm^3) + 
        CF*((-0.40623458131012924 - 0.26133823541501455*lm - 
            0.19956391224459144*lm^2 - 0.05601111111111111*lm^3)*NM + 
          (-0.6588061567722309 - 0.26133823541501455*lm - 0.19956391224459144*
             lm^2 - 0.05601111111111111*lm^3)*NL + 
          (0.3474091547581704 - 0.26133823541501455*lm - 0.19956391224459144*
             lm^2 - 0.05601111111111111*lm^3)*NH))}, 
     {0.425, NC*(CA*CF*(1.1866693463784728 + 0.431948516672972*lm + 
          1.6946760059978312*lm^2 + 0.310234375*lm^3) + 
        CF^2*(0.4441407252500088 + 0.48288733276807255*lm - 
          0.861251052685367*lm^2 + 0.50765625*lm^3) + 
        CF*((-0.402889096444531 - 0.26140725832240125*lm - 
            0.20043825109051477*lm^2 - 0.05640625*lm^3)*NM + 
          (-0.661304349714019 - 0.26140725832240125*lm - 0.20043825109051477*
             lm^2 - 0.05640625*lm^3)*NL + (0.34858628951006926 - 
            0.26140725832240125*lm - 0.20043825109051477*lm^2 - 
            0.05640625*lm^3)*NH))}, 
     {0.43, NC*(CA*CF*(1.1830826493735092 + 0.42126108222129327*lm + 
          1.7035913501341158*lm^2 + 0.3124152777777778*lm^3) + 
        CF^2*(0.44488696339775824 + 0.4872385550759611*lm - 
          0.8722113134169015*lm^2 + 0.511225*lm^3) + 
        CF*((-0.3994853639570849 - 0.2614433943937286*lm - 
            0.20130221517589983*lm^2 - 0.05680277777777778*lm^3)*NM + 
          (-0.6638024722909268 - 0.2614433943937286*lm - 0.20130221517589983*
             lm^2 - 0.05680277777777778*lm^3)*NL + 
          (0.3497249479392776 - 0.2614433943937286*lm - 0.20130221517589983*
             lm^2 - 0.05680277777777778*lm^3)*NH))}, 
     {0.435, NC*(CA*CF*(1.1795183904720627 + 0.41026275975438686*lm + 
          1.7124639404454869*lm^2 + 0.31460381944444443*lm^3) + 
        CF^2*(0.4456663904001414 + 0.4917353331463575*lm - 
          0.8833310235892032*lm^2 + 0.51480625*lm^3) + 
        CF*((-0.39602427743031154 - 0.26144705770047294*lm - 
            0.20215575432342187*lm^2 - 0.05720069444444444*lm^3)*NM + 
          (-0.6663011594339665 - 0.26144705770047294*lm - 0.20215575432342187*
             lm^2 - 0.05720069444444444*lm^3)*NL + 
          (0.35082505967216576 - 0.26144705770047294*lm - 0.20215575432342187*
             lm^2 - 0.05720069444444444*lm^3)*NH))}, 
     {0.44, NC*(CA*CF*(1.175982504787766 + 0.3989554664118546*lm + 
          1.721293504752879*lm^2 + 0.3168*lm^3) + 
        CF^2*(0.4464780597791365 + 0.4963829298128018*lm - 
          0.894610628586198*lm^2 + 0.5184*lm^3) + 
        CF*((-0.39250671330757286 - 0.2614186597970563*lm - 
            0.202998819045978*lm^2 - 0.0576*lm^3)*NM + 
          (-0.6688010315798331 - 0.2614186597970563*lm - 0.202998819045978*
             lm^2 - 0.0576*lm^3)*NL + (0.3518865579918912 - 
            0.2614186597970563*lm - 0.202998819045978*lm^2 - 0.0576*lm^3)*
           NH))}, {0.445, NC*(CA*CF*(1.1724808225268748 + 
          0.3873411101753085*lm + 1.7300797745751555*lm^2 + 
          0.31900381944444445*lm^3) + CF^2*(0.447320913980428 + 
          0.5011865640425102*lm - 0.9060505677406546*lm^2 + 
          0.52200625*lm^3) + CF*((-0.38893353125292995 - 0.2613586097170927*
             lm - 0.20383136052881615*lm^2 - 0.058000694444444445*lm^3)*NM + 
          (-0.6713026950023976 - 0.2613586097170927*lm - 0.20383136052881615*
             lm^2 - 0.058000694444444445*lm^3)*NL + 
          (0.35290937975364467 - 0.2613586097170927*lm - 0.20383136052881615*
             lm^2 - 0.058000694444444445*lm^3)*NH))}, 
     {0.45, NC*(CA*CF*(1.169019071163417 + 0.3754215897383628*lm + 
          1.7388224850340397*lm^2 + 0.32121527777777775*lm^3) + 
        CF^2*(0.4481937882769486 + 0.5061514114661205*lm - 
          0.9176512744897534*lm^2 + 0.525625*lm^3) + 
        CF*((-0.3853055745026259 - 0.2612673139717496*lm - 
            0.20465333061224963*lm^2 - 0.058402777777777776*lm^3)*NM + 
          (-0.6738067421355599 - 0.2612673139717496*lm - 0.20465333061224963*
             lm^2 - 0.058402777777777776*lm^3)*NL + 
          (0.3538934653025138 - 0.2612673139717496*lm - 0.20465333061224963*
             lm^2 - 0.058402777777777776*lm^3)*NH))}, 
     {0.455, NC*(CA*CF*(1.1656028775653107 + 0.3631987943913416*lm + 
          1.7475213747621383*lm^2 + 0.323434375*lm^3) + 
        CF^2*(0.4490954145260816 + 0.5112826049073568*lm - 
          0.9294131765255919*lm^2 + 0.52925625*lm^3) + 
        CF*((-0.3816236702083576 - 0.26114517655006947*lm - 
            0.20546468177493424*lm^2 - 0.05880625*lm^3)*NM + 
          (-0.6763137518876869 - 0.26114517655006947*lm - 0.20546468177493424*
             lm^2 - 0.05880625*lm^3)*NL + (0.35483875839386647 - 
            0.26114517655006947*lm - 0.20546468177493424*lm^2 - 
            0.05880625*lm^3)*NH))}, 
     {0.46, NC*(CA*CF*(1.1622377700724018 + 0.3506746039197469*lm + 
          1.7561761858139389*lm^2 + 0.3256611111111111*lm^3) + 
        CF^2*(0.4500244247864697 + 0.5165852349119949*lm - 
          0.9413366959408273*lm^2 + 0.5329*lm^3) + 
        CF*((-0.37788862977250204 - 0.2609925989211051*lm - 
            0.20626536711768587*lm^2 - 0.05921111111111111*lm^3)*NM + 
          (-0.6788242899478594 - 0.2609925989211051*lm - 0.20626536711768587*
             lm^2 - 0.05921111111111111*lm^3)*NL + 
          (0.3557452061161594 - 0.2609925989211051*lm - 0.20626536711768587*
             lm^2 - 0.05921111111111111*lm^3)*NH))}, 
     {0.465, NC*(CA*CF*(1.1589291805273614 + 0.3378508885155934*lm + 
          1.7647866635796625*lm^2 + 0.32789548611111113*lm^3) + 
        CF^2*(0.4509793548001321 + 0.5220643502755707*lm - 
          0.9534222493696429*lm^2 + 0.53655625*lm^3) + 
        CF*((-0.3741012491754633 - 0.2608099800377337*lm - 
            0.20705534034781745*lm^2 - 0.059617361111111114*lm^3)*NM + 
          (-0.6813389090841462 - 0.2608099800377337*lm - 0.20705534034781745*
             lm^2 - 0.059617361111111114*lm^3)*NL + 
          (0.35661275881608256 - 0.2608099800377337*lm - 0.20705534034781745*
             lm^2 - 0.059617361111111114*lm^3)*NH))}, 
     {0.47, NC*(CA*CF*(1.155682446260403 + 0.32472950870077016*lm + 
          1.7733525567018646*lm^2 + 0.3301375*lm^3) + 
        CF^2*(0.45195864734532903 + 0.5277249585693182*lm - 
          0.9656702481242213*lm^2 + 0.540225*lm^3) + 
        CF*((-0.37026230929530646 - 0.2605977163420214*lm - 
            0.20783455576397541*lm^2 - 0.060025*lm^3)*NM + 
          (-0.6838581494341192 - 0.2605977163420214*lm - 0.20783455576397541*
             lm^2 - 0.060025*lm^3)*NL + (0.35744137002595555 - 
            0.2605977163420214*lm - 0.20783455576397541*lm^2 - 0.060025*lm^3)*
           NH))}, {0.475, NC*(CA*CF*(1.1525028120287653 + 
          0.3113123152616451*lm + 1.781873616994676*lm^2 + 
          0.33238715277777775*lm^3) + CF^2*(0.4529606554653845 + 
          0.5335720266638752*lm - 0.9780810983268936*lm^2 + 
          0.54390625*lm^3) + CF*((-0.36637257621984587 - 0.2603562017720214*
             lm - 0.20860296824145627*lm^2 - 0.06043402777777778*lm^3)*NM + 
          (-0.6863825387878176 - 0.2603562017720214*lm - 0.20860296824145627*
             lm^2 - 0.06043402777777778*lm^3)*NL + 
          (0.35823099639329087 - 0.2603562017720214*lm - 0.20860296824145627*
             lm^2 - 0.06043402777777778*lm^3)*NH))}, 
     {0.48, NC*(CA*CF*(1.1493954319119097 + 0.29760114919417485*lm + 
          1.7903495993655858*lm^2 + 0.33464444444444447*lm^3) + 
        CF^2*(0.4539836455784481 + 0.5396104812503352*lm - 
          0.9906552010381323*lm^2 + 0.5476*lm^3) + 
        CF*((-0.36243280155135205 - 0.2600858277698936*lm - 
            0.20936053321798528*lm^2 - 0.060844444444444444*lm^3)*NM + 
          (-0.688912592863367 - 0.2600858277698936*lm - 0.20936053321798528*
             lm^2 - 0.060844444444444444*lm^3)*NL + 
          (0.3589815976124495 - 0.2600858277698936*lm - 0.20936053321798528*
             lm^2 - 0.060844444444444444*lm^3)*NH))}, 
     {0.485, NC*(CA*CF*(1.1463653711633779 + 0.2835978416588299*lm + 
          1.7987802617396684*lm^2 + 0.336909375*lm^3) + 
        CF^2*(0.45502580047296215 + 0.5458452093582655*lm - 
          1.0033929523805427*lm^2 + 0.55130625*lm^3) + 
        CF*((-0.35844372270404373 - 0.2597869832912435*lm - 
            0.2101072066799397*lm^2 - 0.06125625*lm^3)*NM + 
          (-0.6914488155754536 - 0.2597869832912435*lm - 0.2101072066799397*
             lm^2 - 0.06125625*lm^3)*NL + (0.35969313635831046 - 
            0.2597869832912435*lm - 0.2101072066799397*lm^2 - 
            0.06125625*lm^3)*NH))}, 
     {0.49, NC*(CA*CF*(1.1434176080202414 + 0.2693042139446878*lm + 
          1.8071653649861652*lm^2 + 0.33918194444444444*lm^3) + 
        CF^2*(0.456085222193394 + 0.5522810588703458*lm - 
          1.0162947436590024*lm^2 + 0.555025*lm^3) + 
        CF*((-0.3544060631945273 - 0.25946005481558304*lm - 
            0.21084294514899973*lm^2 - 0.06166944444444444*lm^3)*NM + 
          (-0.6939916992968462 - 0.25946005481558304*lm - 0.21084294514899973*
             lm^2 - 0.06166944444444444*lm^3)*NL + 
          (0.3603655782218848 - 0.25946005481558304*lm - 0.21084294514899973*
             lm^2 - 0.06166944444444444*lm^3)*NH))}, 
     {0.495, NC*(CA*CF*(1.1405570354710775 + 0.2547220774420865*lm + 
          1.8155046728473314*lm^2 + 0.3414621527777778*lm^3) + 
        CF^2*(0.4571599348205981 + 0.5589228390333179*lm - 
          1.029360961477094*lm^2 + 0.55875625*lm^3) + 
        CF*((-0.3503205329253461 - 0.25910542635782374*lm - 
            0.21156770566921176*lm^2 - 0.06208402777777778*lm^3)*NM + 
          (-0.6965417251131605 - 0.25910542635782374*lm - 0.21156770566921176*
             lm^2 - 0.06208402777777778*lm^3)*NL + 
          (0.36099889164780385 - 0.25910542635782374*lm - 0.21156770566921176*
             lm^2 - 0.06208402777777778*lm^3)*NH))}, 
     {0.5, CF*NC*(CA*(1.1377884629531894 + 0.2398532336080883*lm + 
          1.823797951868706*lm^2 + 0.34375*lm^3) + 
        CF*(0.45824788713216197 + 0.5657753209460582*lm - 
          1.0425919878512084*lm^2 + 0.5625*lm^3) - 0.34618782845558144*NM - 
        0.2587234794781332*lm*NM - 0.2122814457943102*lm^2*NM - 
        0.0625*lm^3*NM - 0.6990993630668513*NL - 0.2587234794781332*lm*
         NL - 0.2122814457943102*lm^2*NL - 0.0625*lm^3*NL + 
        0.3615930478731479*NH - 0.2587234794781332*lm*NH - 
        0.2122814457943102*lm^2*NH - 0.0625*lm^3*NH)}, 
     {0.505, CF*NC*(CA*(1.1351166181682744 + 0.22469947401887774*lm + 
          1.8320449713354594*lm^2 + 0.34604548611111113*lm^3) + 
        CF*(0.4593469552641603 + 0.5728432381424395*lm - 1.055988200314703*
           lm^2 + 0.56625625*lm^3) - 0.34200863329744224*NM - 
        0.25831459330619144*lm*NM - 0.21298412357614413*lm^2*NM - 
        0.06291736111111111*lm^3*NM - 0.7016650724167853*NL - 
        0.25831459330619144*lm*NL - 0.21298412357614413*lm^2*NL - 
        0.06291736111111111*lm^3*NL + 0.3621480208704738*NH - 
        0.25831459330619144*lm*NH - 0.21298412357614413*lm^2*NH - 
        0.06291736111111111*lm^3*NH)}, 
     {0.51, CF*NC*(CA*(1.1325461485272674 + 0.20926258026217295*lm + 
          1.8402455032024165*lm^2 + 0.3483486111111111*lm^3) + 
        CF*(0.46045494507229184 + 0.5801312869617874*lm - 
          1.0695499720324093*lm^2 + 0.570025*lm^3) - 0.337783618138043*NM - 
        0.25787914453782246*lm*NM - 0.21367569755195454*lm^2*NM - 
        0.0633361111111111*lm^3*NM - 0.7042393018454397*NL - 
        0.25787914453782246*lm*NL - 0.21367569755195454*lm^2*NL - 
        0.0633361111111111*lm^3*NL + 0.3626637872873741*NH - 
        0.25787914453782246*lm*NH - 0.21367569755195454*lm^2*NH - 
        0.0633361111111111*lm^3*NH)}, 
     {0.515, CF*NC*(CA*(1.1300816229072614 + 0.1935443240120462*lm + 
          1.8483993220348325*lm^2 + 0.350659375*lm^3) + 
        CF*(0.4615695946218797 + 0.5876441271338569*lm - 1.0832776718975468*
           lm^2 + 0.57380625*lm^3) - 0.333513441127002*NM - 
        0.25741750746230263*lm*NM - 0.21435612673360593*lm^2*NM - 
        0.06375625*lm^3*NM - 0.7068224897087041*NL - 0.25741750746230263*lm*
         NL - 0.21435612673360593*lm^2*NL - 0.06375625*lm^3*NL + 
        0.3631403263930933*NH - 0.25741750746230263*lm*NH - 
        0.21435612673360593*lm^2*NH - 0.06375625*lm^3*NH)}, 
     {0.52, CF*NC*(CA*(1.127727533186255 + 0.17754646701669227*lm + 
          1.8565062049463936*lm^2 + 0.3529777777777778*lm^3) + 
        CF*(0.46268857647592004 + 0.5953863822430208*lm - 
          1.097171664633174*lm^2 + 0.5776*lm^3) - 0.32919874811978317*NM - 
        0.25693005397448393*lm*NM - 0.215025370596314*lm^2*NM - 
        0.06417777777777778*lm^3*NM - 0.7094150642540603*NL - 
        0.25693005397448393*lm*NL - 0.215025370596314*lm^2*NL - 
        0.06417777777777778*lm^3*NL + 0.3635776200238421*NH - 
        0.25693005397448393*lm*NH - 0.215025370596314*lm^2*NH - 
        0.06417777777777778*lm^3*NH)}, 
     {0.525, CF*NC*(CA*(1.1254882957811698 + 0.1612707611116332*lm + 
          1.8645659315400247*lm^2 + 0.35530381944444445*lm^3) + 
        CF*(0.463809499924958 + 0.6033626402121667*lm - 1.1112323108890507*
           lm^2 + 0.58140625*lm^3) - 0.3248401729231938*NM - 
        0.25641715359089173*lm*NM - 0.21568338906788326*lm^2*NM - 
        0.06460069444444444*lm^3*NM - 0.7120174438385276*NL - 
        0.25641715359089173*lm*NL - 0.21568338906788326*lm^2*NL - 
        0.06460069444444444*lm^3*NL + 0.3639756525302395*NH - 
        0.25641715359089173*lm*NH - 0.21568338906788326*lm^2*NH - 
        0.06460069444444444*lm^3*NH)}, 
     {0.53, CF*NC*(CA*(1.1233682531505624 + 0.14471894823815393*lm + 
          1.872578283850447*lm^2 + 0.3576375*lm^3) + 
        CF*(0.4649299131373446 + 0.6115774537814815*lm - 1.1254599673356322*
           lm^2 + 0.585225*lm^3) - 0.3204383375350649*NM - 
        0.2558791734663697*lm*NM - 0.21633014251826307*lm^2*NM - 
        0.065025*lm^3*NM - 0.714630037141052*NL - 0.2558791734663697*lm*
         NL - 0.21633014251826307*lm^2*NL - 0.065025*lm^3*NL + 
        0.3643344107262217*NH - 0.2558791734663697*lm*NH - 
        0.21633014251826307*lm^2*NH - 0.065025*lm^3*NH)}, 
     {0.535, CF*NC*(CA*(1.1213716752628622 + 0.12789276046660283*lm + 
          1.8805430462884258*lm^2 + 0.35997881944444443*lm^3) + 
        CF*(0.4660473052329585 + 0.6200353409820052*lm - 1.1398549867553032*
           lm^2 + 0.58905625*lm^3) - 0.315993852378257*NM - 
        0.2553164784112172*lm*NM - 0.21696559174941074*lm^2*NM - 
        0.06545069444444444*lm^3*NM - 0.7172532433694936*NL - 
        0.2553164784112172*lm*NL - 0.21696559174941074*lm^2*NL - 
        0.06545069444444444*lm^3*NL + 0.3646538838393663*NH - 
        0.2553164784112172*lm*NH - 0.21696559174941074*lm^2*NH - 
        0.06545069444444444*lm^3*NH)}, 
     {0.54, CF*NC*(CA*(1.1195027610309436 + 0.11079392002421198*lm + 
          1.8884600055866472*lm^2 + 0.3623277777777778*lm^3) + 
        CF*(0.4671591082833481 + 0.6287407856038514*lm - 1.154417718130941*
           lm^2 + 0.5929*lm^3) - 0.3115073165291313*NM - 
        0.25472943090877226*lm*NM - 0.217589697985451*lm^2*NM - 
        0.06587777777777777*lm^3*NM - 0.7198874524623625*NL - 
        0.25472943090877226*lm*NL - 0.217589697985451*lm^2*NL - 
        0.06587777777777777*lm^3*NL + 0.36493406346258633*NH - 
        0.25472943090877226*lm*NH - 0.217589697985451*lm^2*NH - 
        0.06587777777777777*lm^3*NH)}, 
     {0.545, CF*NC*(CA*(1.1177656397138358 + 0.09342413932711427*lm + 
          1.896328950747168*lm^2 + 0.364684375*lm^3) + 
        CF*(0.4682626992411246 + 0.6376982376590078*lm - 1.169148506731907*
           lm^2 + 0.59675625*lm^3) - 0.3069793179406246*NM - 
        0.2541183911333931*lm*NM - 0.21820242286312144*lm^2*NM - 
        0.06630625*lm^3*NM - 0.7225330452854485*NL - 0.2541183911333931*lm*
         NL - 0.21820242286312144*lm^2*NL - 0.06630625*lm^3*NL + 
        0.36517494350714674*NH - 0.2541183911333931*lm*NH - 
        0.21820242286312144*lm^2*NH - 0.06630625*lm^3*NH)}, 
     {0.55, CF*NC*(CA*(1.1161643722863464 + 0.07578512101625252*lm + 
          1.9041496729903853*lm^2 + 0.3670486111111111*lm^3) + 
        CF*(0.4693554018013201 + 0.6469121138386442*lm - 1.1840476941975515*
           lm^2 + 0.600625*lm^3) - 0.3024104336600623*NM - 
        0.2534837169687955*lm*NM - 0.2188037284224943*lm^2*NM - 
        0.06673611111111111*lm^3*NM - 0.7251903938234864*NL - 
        0.2534837169687955*lm*NL - 0.2188037284224943*lm^2*NL - 
        0.06673611111111111*lm^3*NL + 0.36537652015696076*NH - 
        0.2534837169687955*lm*NH - 0.2188037284224943*lm^2*NH - 
        0.06673611111111111*lm^3*NH)}, 
     {0.555, CF*NC*(CA*(1.1147029527773695 + 0.05787855799689524*lm + 
          1.9119219657054718*lm^2 + 0.3694204861111111*lm^3) + 
        CF*(0.47043448819731143 + 0.6563867979648663*lm - 
          1.199115618618319*lm^2 + 0.60450625*lm^3) - 0.2978012300418406*
         NM - 0.25282576402670737*lm*NM - 0.21939357709796456*lm^2*NM - 
        0.06716736111111112*lm^3*NM - 0.7278598613669965*NL - 
        0.25282576402670737*lm*NL - 0.21939357709796456*lm^2*NL - 
        0.06716736111111112*lm^3*NL + 0.36553879182412363*NH - 
        0.25282576402670737*lm*NH - 0.21939357709796456*lm^2*NH - 
        0.06716736111111112*lm^3*NH)}, 
     {0.56, CF*NC*(CA*(1.1133853095776267 + 0.03970613348148981*lm + 
          1.919645624402229*lm^2 + 0.3718*lm^3) + 
        CF*(0.4714971809338036 + 0.6661266414368665*lm - 1.2143526146145345*
           lm^2 + 0.6084*lm^3) - 0.2931522629551082*NM - 
        0.25214488566580145*lm*NM - 0.21997193170949617*lm^2*NM - 
        0.0676*lm^3*NM - 0.7305418026944324*NL - 0.25214488566580145*lm*
         NL - 0.21997193170949617*lm^2*NL - 0.0676*lm^3*NL + 
        0.3656617591056424*NH - 0.25214488566580145*lm*NH - 
        0.21997193170949617*lm^2*NH - 0.0676*lm^3*NH)}, 
     {0.565, CF*NC*(CA*(1.1122153067175748 + 0.02126952103560112*lm + 
          1.9273204466643077*lm^2 + 0.37418715277777775*lm^3) + 
        CF*(0.4725406544592627 + 0.6761359636714362*lm - 1.229759013412951*
           lm^2 + 0.61230625*lm^3) - 0.28846407798657225*NM - 
        0.2514414330108728*lm*NM - 0.22053875545411655*lm^2*NM - 
        0.06803402777777778*lm^3*NM - 0.7332365642497659*NL - 
        0.2514414330108728*lm*NL - 0.22053875545411655*lm^2*NL - 
        0.06803402777777778*lm^3*NL + 0.3657454247413242*NH - 
        0.2514414330108728*lm*NH - 0.22053875545411655*lm^2*NH - 
        0.06803402777777778*lm^3*NH)}, 
     {0.57, CF*NC*(CA*(1.1111967451162028 + 0.0025703846266976337*lm + 
          1.934946232103752*lm^2 + 0.3765819444444444*lm^3) + 
        CF*(0.47356203678009123 + 0.6864190525378078*lm - 
          1.2453351429211328*lm^2 + 0.616225*lm^3) - 0.2837372106385527*NM - 
        0.2507157549722278*lm*NM - 0.2210940118976519*lm^2*NM - 
        0.06846944444444444*lm^3*NM - 0.7359444843156385*NL - 
        0.2507157549722278*lm*NL - 0.2210940118976519*lm^2*NL - 
        0.06846944444444444*lm^3*NL + 0.36578979357278407*NH - 
        0.2507157549722278*lm*NH - 0.2210940118976519*lm^2*NH - 
        0.06846944444444444*lm^3*NH)}, 
     {0.575, CF*NC*(CA*(1.1103333638014163 - 0.01638962132443778*lm + 
          1.942522782316821*lm^2 + 0.378984375*lm^3) + 
        CF*(0.4745584110187443 + 0.6969801647868105*lm - 1.2610813277997475*
           lm^2 + 0.62015625*lm^3) - 0.27897218652240435*NM - 
        0.24996819826525463*lm*NM - 0.22163766496669474*lm^2*NM - 
        0.06890625*lm^3*NM - 0.7386658931821994*NL - 0.24996819826525463*lm*
         NL - 0.22163766496669474*lm^2*NL - 0.06890625*lm^3*NL + 
        0.3657948725035374*NH - 0.24996819826525463*lm*NH - 
        0.22163766496669474*lm^2*NH - 0.06890625*lm^3*NH)}, 
     {0.58, CF*NC*(CA*(1.1096288411027038 - 0.03560885188988229*lm + 
          1.9500499008410455*lm^2 + 0.3813944444444444*lm^3) + 
        CF*(0.4755268169178949 + 0.7078235264743283*lm - 1.2769978895328347*
           lm^2 + 0.6241*lm^3) - 0.27416952154742547*NM - 
        0.24919910743014703*lm*NM - 0.22216967894079614*lm^2*NM - 
        0.06934444444444444*lm^3*NM - 0.74140111331175*NL - 
        0.24919910743014703*lm*NL - 0.22216967894079614*lm^2*NL - 
        0.06934444444444444*lm^3*NL + 0.36576067046014127*NH - 
        0.24919910743014703*lm*NH - 0.22216967894079614*lm^2*NH - 
        0.06934444444444444*lm^3*NH)}, 
     {0.585, CF*NC*(CA*(1.109086795816751 - 0.055085671578529886*lm + 
          1.95752739311348*lm^2 + 0.3838121527777778*lm^3) + 
        CF*(0.476464252292672 + 0.7189533333790573*lm - 1.2930851464961235*
           lm^2 + 0.62805625*lm^3) - 0.2693297221053662*NM - 
        0.24840882485175453*lm*NM - 0.22269001844487518*lm^2*NM - 
        0.06978402777777777*lm^3*NM - 0.7441504594993122*NL - 
        0.24840882485175453*lm*NL - 0.22269001844487518*lm^2*NL - 
        0.06978402777777777*lm^3*NL + 0.36568719835435176*NH - 
        0.24840882485175453*lm*NH - 0.22269001844487518*lm^2*NH - 
        0.06978402777777777*lm^3*NH)}, 
     {0.59, CF*NC*(CA*(1.108710788346664 - 0.0748184542780158*lm + 
          1.9649550664301108*lm^2 + 0.3862375*lm^3) + 
        CF*(0.47736767443291167 + 0.7303737514145652*lm - 
          1.309343414023455*lm^2 + 0.632025*lm^3) - 0.26445328525064987*NM - 
        0.24759769077953522*lm*NM - 0.22319864844183832*lm^2*NM - 
        0.070225*lm^3*NM - 0.746914239029232*NL - 0.24759769077953522*lm*
         NL - 0.22319864844183832*lm^2*NL - 0.070225*lm^3*NL + 
        0.365574469046265*NH - 0.24759769077953522*lm*NH - 
        0.22319864844183832*lm^2*NH - 0.070225*lm^3*NH)}, 
     {0.595, CF*NC*(CA*(1.1085043218154433 - 0.09480558319478274*lm + 
          1.9723327299063784*lm^2 + 0.3886704861111111*lm^3) + 
        CF*(0.4782340014572842 + 0.7420889170356669*lm - 1.3257730044713807*
           lm^2 + 0.63600625*lm^3) - 0.2595406988764158*NM - 
        0.2467660433475875*lm*NM - 0.22369553422540214*lm^2*NM - 
        0.0706673611111111*lm^3*NM - 0.7496927518279273*NL - 
        0.2467660433475875*lm*NL - 0.22369553422540214*lm^2*NL - 
        0.0706673611111111*lm^3*NL + 0.36542249730841064*NH - 
        0.2467660433475875*lm*NH - 0.22369553422540214*lm^2*NH - 
        0.0706673611111111*lm^3*NH)}, 
     {0.6, CF*NC*(CA*(1.1084708431543342 - 0.11504545079245272*lm + 
          1.9796601944387848*lm^2 + 0.39111111111111113*lm^3) + 
        CF*(0.47906011362108364 + 0.7541029376391293*lm - 
          1.3423742272819885*lm^2 + 0.64*lm^3) - 0.2545924418864904*NM - 
        0.24591421859474008*lm*NM - 0.2241806414131124*lm^2*NM - 
        0.07111111111111111*lm^3*NM - 0.7524862906128871*NL - 
        0.24591421859474008*lm*NL - 0.2241806414131124*lm^2*NL - 
        0.07111111111111111*lm^3*NL + 0.365231299790768*NH - 
        0.24591421859474008*lm*NH - 0.2241806414131124*lm^2*NH - 
        0.07111111111111111*lm^3*NH)}, 
     {0.605, CF*NC*(CA*(1.108613744166667 - 0.13553645872865813*lm + 
          1.9869372726675434*lm^2 + 0.393559375*lm^3) + 
        CF*(0.47984285457939724 + 0.766419891958728*lm - 1.3591473890440198*
           lm^2 + 0.64400625*lm^3) - 0.24960898436339027*NM - 
        0.24504255048467977*lm*NM - 0.22465393593955335*lm^2*NM - 
        0.07155625*lm^3*NM - 0.7552951410380249*NL - 0.24504255048467977*lm*
         NL - 0.22465393593955335*lm^2*NL - 0.07155625*lm^3*NL + 
        0.3650008949866761*NH - 0.24504255048467977*lm*NH - 
        0.22465393593955335*lm^2*NH - 0.07155625*lm^3*NH)}, 
     {0.61, CF*NC*(CA*(1.1089363625677862 - 0.15627701779047673*lm + 
          1.9941637789402438*lm^2 + 0.3960152777777778*lm^3) + 
        CF*(0.4805790326072992 + 0.7790438304546841*lm - 1.3760927935523284*
           lm^2 + 0.648025*lm^3) - 0.2445907877324591*NM - 
        0.24415137092609904*lm*NM - 0.2251153840497413*lm^2*NM - 
        0.07200277777777778*lm^3*NM - 0.7581195818354866*NL - 
        0.24415137092609904*lm*NL - 0.2251153840497413*lm^2*NL - 
        0.07200277777777778*lm^3*NL + 0.36473130319960945*NH - 
        0.24415137092609904*lm*NH - 0.2251153840497413*lm^2*NH - 
        0.07200277777777778*lm^3*NH)}, 
     {0.615, CF*NC*(CA*(1.109441983001649 - 0.17726554782860618*lm + 
          2.001339529276494*lm^2 + 0.39847881944444447*lm^3) + 
        CF*(0.4812654217786519 + 0.7919787756975106*lm - 1.3932107418657373*
           lm^2 + 0.65205625*lm^3) - 0.23953830492223593*NM - 
        0.24324100979284602*lm*NM - 0.22556495229269585*lm^2*NM - 
        0.07245069444444445*lm^3*NM - 0.7609598849540085*NL - 
        0.24324100979284602*lm*NL - 0.22556495229269585*lm^2*NL - 
        0.07245069444444445*lm^3*NL + 0.36442254651079375*NH - 
        0.24324100979284602*lm*NH - 0.22556495229269585*lm^2*NH - 
        0.07245069444444445*lm^3*NH)}, 
     {0.62, CF*NC*(CA*(1.1101338380346693 - 0.19850047769040594*lm + 
          2.008464341333513*lm^2 + 0.40095*lm^3) + 
        CF*(0.4818987631050322 + 0.8052287227463037*lm - 1.4105015323633423*
           lm^2 + 0.6561*lm^3) - 0.23445198052115257*NM - 
        0.24231179494406077*lm*NM - 0.2260026075151842*lm^2*NM - 
        0.0729*lm^3*NM - 0.7638163156939227*NL - 0.24231179494406077*lm*
         NL - 0.2260026075151842*lm^2*NL - 0.0729*lm^3*NL + 
        0.3640746487476341*NH - 0.24231179494406077*lm*NH - 
        0.2260026075151842*lm^2*NH - 0.0729*lm^3*NH)}, 
     {0.625, CF*NC*(CA*(1.1110151091273521 - 0.21998024515192607*lm + 
          2.015538034372642*lm^2 + 0.4034288194444444*lm^3) + 
        CF*(0.4824757656362406 + 0.8187976395215187*lm - 1.427965460799313*
           lm^2 + 0.66015625*lm^3) - 0.22933225093065257*NM - 
        0.24136405224428345*lm*NM - 0.2264283168556319*lm^2*NM - 
        0.07335069444444445*lm^3*NM - 0.7666891328388992*NL - 
        0.24136405224428345*lm*NL - 0.2264283168556319*lm^2*NL - 
        0.07335069444444445*lm^3*NL + 0.36368763545293253*NH - 
        0.24136405224428345*lm*NH - 0.2264283168556319*lm^2*NH - 
        0.07335069444444445*lm^3*NH)}, 
     {0.63, CF*NC*(CA*(1.1120889275842758 - 0.24170329684903544*lm + 
          2.0225604292267434*lm^2 + 0.4059152777777778*lm^3) + 
        CF*(0.4829931075237942 + 0.8326894671722719*lm - 1.4456028203562383*
           lm^2 + 0.664225*lm^3) - 0.22417954451482391*NM - 
        0.2403981055835202*lm*NM - 0.22684204773819575*lm^2*NM - 
        0.07380277777777777*lm^3*NM - 0.7695785887845134*NL - 
        0.2403981055835202*lm*NL - 0.22684204773819575*lm^2*NL - 
        0.07380277777777777*lm^3*NL + 0.3632615338548694*NH - 
        0.2403981055835202*lm*NH - 0.22684204773819575*lm^2*NH - 
        0.07380277777777777*lm^3*NH)}, 
     {0.635, CF*NC*(CA*(1.1133583754829357 - 0.2636680882077553*lm + 
          2.029531348268462*lm^2 + 0.408409375*lm^3) + 
        CF*(0.48344743704874804 + 0.846908120438214*lm - 1.463413901697062*
           lm^2 + 0.66830625*lm^3) - 0.218994281746634*NM - 
        0.23941427689725414*lm*NM - 0.2272437678669931*lm^2*NM - 
        0.07425625*lm^3*NM - 0.7724849296637282*NL - 0.23941427689725414*lm*
         NL - 0.2272437678669931*lm^2*NL - 0.07425625*lm^3*NL + 
        0.36279637283772675*NH - 0.23941427689725414*lm*NH - 
        0.2272437678669931*lm^2*NH - 0.07425625*lm^3*NH)}, 
     {0.64, CF*NC*(CA*(1.1148264865819781 - 0.2858730833738967*lm + 
          2.036450615379324*lm^2 + 0.4109111111111111*lm^3) + 
        CF*(0.4838353736151385 + 0.8614574880060227*lm - 1.4813989930156517*
           lm^2 + 0.6724*lm^3) - 0.21377687535085377*NM - 
        0.23841288618638978*lm*NM - 0.22763344522048315*lm^2*NM - 
        0.07471111111111112*lm^3*NM - 0.7754083954693711*NL - 
        0.23841288618638978*lm*NL - 0.22763344522048315*lm^2*NL - 
        0.07471111111111112*lm^3*NL + 0.3622921829133298*NH - 
        0.23841288618638978*lm*NH - 0.22763344522048315*lm^2*NH - 
        0.07471111111111112*lm^3*NH)}, 
     {0.645, CF*NC*(CA*(1.1164962472093185 - 0.30831675514209583*lm + 
          2.043318055919639*lm^2 + 0.4134204861111111*lm^3) + 
        CF*(0.4841535087102893 + 0.876341432860565*lm - 1.4995583800860453*
           lm^2 + 0.67650625*lm^3) - 0.20852773044375533*NM - 
        0.23739425153711982*lm*NM - 0.22801104804599498*lm^2*NM - 
        0.07516736111111111*lm^3*NM - 0.7783492201736901*NL - 
        0.23739425153711982*lm*NL - 0.22801104804599498*lm^2*NL - 
        0.07516736111111111*lm^3*NL + 0.36174899619318635*NH - 
        0.23739425153711982*lm*NH - 0.22801104804599498*lm^2*NH - 
        0.07516736111111111*lm^3*NH)}, 
     {0.65, CF*NC*(CA*(1.1183705971306412 - 0.3309975848843332*lm + 
          2.0501334966991918*lm^2 + 0.4159375*lm^3) + 
        CF*(0.48439840683317353 + 0.8915637926307796*lm - 
          1.5178923463104135*lm^2 + 0.680625*lm^3) - 0.20324724466966526*
         NM - 0.23635868914070435*lm*NM - 0.2283765448543985*lm^2*NM - 
        0.075625*lm^3*NM - 0.7813076318450657*NL - 0.23635868914070435*lm*
         NL - 0.2283765448543985*lm^2*NL - 0.075625*lm^3*NL + 
        0.36116684636130253*NH - 0.23635868914070435*lm*NH - 
        0.2283765448543985*lm^2*NH - 0.075625*lm^3*NH)}, 
     {0.655, CF*NC*(CA*(1.1204524303987564 - 0.3539140624780195*lm + 
          2.0568967659486894*lm^2 + 0.41846215277777776*lm^3) + 
        CF*(0.4845666063919801 + 0.9071283799303377*lm - 1.536401172765781*
           lm^2 + 0.68475625*lm^3) - 0.19793580833445362*NM - 
        0.2353065133131529*lm*NM - 0.22872990441491323*lm^2*NM - 
        0.07608402777777777*lm^3*NM - 0.7842838527619577*NL - 
        0.2353065133131529*lm*NL - 0.22872990441491323*lm^2*NL - 
        0.07608402777777777*lm^3*NL + 0.36054576864765486*NH - 
        0.2353065133131529*lm*NH - 0.22872990441491323*lm^2*NH - 
        0.07608402777777777*lm^3*NH)}, 
     {0.66, CF*NC*(CA*(1.1227445961842792 - 0.377064686233725*lm + 
          2.063607693291948*lm^2 + 0.42099444444444445*lm^3) + 
        CF*(0.4846546205719853 + 0.9230389826931333*lm - 1.5550851382495399*
           lm^2 + 0.6889*lm^3) - 0.19259380453603642*NM - 
        0.23423803651480113*lm*NM - 0.22907109575005113*lm^2*NM - 
        0.07654444444444444*lm^3*NM - 0.787278099524159*NL - 
        0.23423803651480113*lm*NL - 0.22907109575005113*lm^2*NL - 
        0.07654444444444444*lm^3*NL + 0.3598857998022993*NH - 
        0.23423803651480113*lm*NH - 0.22907109575005113*lm^2*NH - 
        0.07654444444444444*lm^3*NH)}, 
     {0.665, CF*NC*(CA*(1.1252498995880917 - 0.40044796282262346*lm + 
          2.0702661097187907*lm^2 + 0.423534375*lm^3) + 
        CF*(0.4846589381747898 + 0.9392993645036645*lm - 1.573944519323797*
           lm^2 + 0.69305625*lm^3) - 0.18722160929196785*NM - 
        0.23315356936977394*lm*NM - 0.2294000881306892*lm^2*NM - 
        0.07700625*lm^3*NM - 0.7902905831614306*NL - 0.23315356936977394*lm*
         NL - 0.2294000881306892*lm^2*NL - 0.07700625*lm^3*NL + 
        0.3591869780700983*NH - 0.23315356936977394*lm*NH - 
        0.2294000881306892*lm^2*NH - 0.07700625*lm^3*NH)}, 
     {0.67, CF*NC*(CA*(1.1279711024360237 - 0.4240624072037185*lm + 
          2.0768718475586416*lm^2 + 0.42608194444444447*lm^3) + 
        CF*(0.4845760244299411 + 0.955913264922361*lm - 1.5929795903585866*
           lm^2 + 0.697225*lm^3) - 0.18181959166419553*NM - 
        0.23205342068532805*lm*NM - 0.22971685107126816*lm^2*NM - 
        0.07746944444444444*lm^3*NM - 0.793321509239588*NL - 
        0.23205342068532805*lm*NL - 0.22971685107126816*lm^2*NL - 
        0.07746944444444444*lm^3*NL + 0.35844934316604826*NH - 
        0.23205342068532805*lm*NH - 0.22971685107126816*lm^2*NH - 
        0.07746944444444444*lm^3*NH)}, 
     {0.675, CF*NC*(CA*(1.1309109240561908 - 0.44790654255091583*lm + 
          2.083424740454787*lm^2 + 0.42863715277777775*lm^3) + 
        CF*(0.4844023217799195 + 0.9728843998059207*lm - 1.6121906235739842*
           lm^2 + 0.70140625*lm^3) - 0.17638811388105105*NM - 
        0.23093789747106708*lm*NM - 0.23002135432511286*lm^2*NM - 
        0.07793402777777778*lm^3*NM - 0.796371077964104*NL - 
        0.23093789747106708*lm*NL - 0.23002135432511286*lm^2*NL - 
        0.07793402777777778*lm^3*NL + 0.3576729362511889*NH - 
        0.23093789747106708*lm*NH - 0.23002135432511286*lm^2*NH - 
        0.07793402777777778*lm^3*NH)}, 
     {0.68, CF*NC*(CA*(1.134072042039408 - 0.4719789001799998*lm + 
          2.089924623339294*lm^2 + 0.4312*lm^3) + 
        CF*(0.48413425063943144 + 0.9902164616227135*lm - 
          1.6315778890811559*lm^2 + 0.7056*lm^3) - 0.17092753145654555*NM - 
        0.22980730495802332*lm*NM - 0.2303135678798716*lm^2*NM - 
        0.0784*lm^3*NM - 0.7994394842812994*NL - 0.22980730495802332*lm*
         NL - 0.2303135678798716*lm^2*NL - 0.0784*lm^3*NL + 
        0.35685779990907884*NH - 0.22980730495802332*lm*NH - 
        0.2303135678798716*lm^2*NH - 0.0784*lm^3*NH)}, 
     {0.685, CF*NC*(CA*(1.13745709298309 - 0.49627801947556965*lm + 
          2.096371332408552*lm^2 + 0.43377048611111113*lm^3) + 
        CF*(0.4837682101299155 + 1.0079131197633155*lm - 1.6511416549223699*
           lm^2 + 0.70980625*lm^3) - 0.16543819330703857*NM - 
        0.22866194661760061*lm*NM - 0.23059346195307*lm^2*NM - 
        0.07886736111111112*lm^3*NM - 0.8025269179771813*NL - 
        0.22866194661760061*lm*NL - 0.23059346195307*lm^2*NL - 
        0.07886736111111112*lm^3*NL + 0.35600397812282*NH - 
        0.22866194661760061*lm*NH - 0.23059346195307*lm^2*NH - 
        0.07886736111111112*lm^3*NH)}, 
     {0.69, CF*NC*(CA*(1.1410686732190392 - 0.5208024478179875*lm + 
          2.1027647050994385*lm^2 + 0.4363486111111111*lm^3) + 
        CF*(0.4833005787901331 + 1.0259780208462346*lm - 1.6708821871100097*
           lm^2 + 0.714025*lm^3) - 0.15992044186534635*NM - 
        0.22750212418037316*lm*NM - 0.2308610069877767*lm^2*NM - 
        0.07933611111111111*lm^3*NM - 0.8056335637739939*NL - 
        0.22750212418037316*lm*NL - 0.2308610069877767*lm^2*NL - 
        0.07933611111111111*lm^3*NL + 0.3551115162526155*NH - 
        0.22750212418037316*lm*NH - 0.2308610069877767*lm^2*NH - 
        0.07933611111111111*lm^3*NH)}, 
     {0.695, CF*NC*(CA*(1.144909339525509 - 0.5455507405103852*lm + 
          2.109104580066073*lm^2 + 0.438934375*lm^3) + 
        CF*(0.482727715263683 + 1.0444147890188913*lm - 1.6907997496646083*
           lm^2 + 0.71825625*lm^3) - 0.15437461319235382*NM - 
        0.22632813765473578*lm*NM - 0.23111617364837686*lm^2*NM - 
        0.07980625*lm^3*NM - 0.8087596014245408*NL - 0.22632813765473578*lm*
         NL - 0.23111617364837686*lm^2*NL - 0.07980625*lm^3*NL + 
        0.35418046101384576*NH - 0.22632813765473578*lm*NH - 
        0.23111617364837686*lm^2*NH - 0.07980625*lm^3*NH)}, 
     {0.7, CF*NC*(CA*(1.1489816098239274 - 0.5705214607057774*lm + 
          2.115390797157147*lm^2 + 0.4415277777777778*lm^3) + 
        CF*(0.48204595896424585 + 1.063227026253917*lm - 1.7108946046519413*
           lm^2 + 0.7225*lm^3) - 0.1488010370861938*NM - 
        0.2251402853454016*lm*NM - 0.23135893281645095*lm^2*NM - 
        0.08027777777777778*lm^3*NM - 0.81190520580434*NL - 
        0.2251402853454016*lm*NL - 0.23135893281645095*lm^2*NL - 
        0.08027777777777778*lm^3*NL + 0.3532108604556478*NH - 
        0.2251402853454016*lm*NH - 0.23135893281645095*lm^2*NH - 
        0.08027777777777778*lm^3*NH)}, 
     {0.705, CF*NC*(CA*(1.1532879638606448 - 0.5957131793343193*lm + 
          2.1216231973938227*lm^2 + 0.44412881944444443*lm^3) + 
        CF*(0.48125163071933585 + 1.0824183126408318*lm - 
          1.7311670122191996*lm^2 + 0.72675625*lm^3) - 0.14320003718905333*
         NM - 0.22393886387174303*lm*NM - 0.2315892555867556*lm^2*NM - 
        0.08075069444444445*lm^3*NM - 0.8150705470016651*NL - 
        0.22393886387174303*lm*NL - 0.2315892555867556*lm^2*NL - 
        0.08075069444444445*lm^3*NL + 0.3522027639399836*NH - 
        0.22393886387174303*lm*NH - 0.2315892555867556*lm^2*NH - 
        0.08075069444444445*lm^3*NH)}, 
     {0.71, CF*NC*(CA*(1.1578308438740736 - 0.6211244750307524*lm + 
          2.1278016229481667*lm^2 + 0.4467375*lm^3) + 
        CF*(0.48034103339330675 + 1.1019922066731702*lm - 
          1.7516172306302729*lm^2 + 0.731025*lm^3) - 0.13757193109166774*
         NM - 0.2227241681859734*lm*NM - 0.231807113263303*lm^2*NM - 
        0.081225*lm^3*NM - 0.8182557904055326*NL - 0.2227241681859734*lm*
         NL - 0.231807113263303*lm^2*NL - 0.081225*lm^3*NL + 
        0.3511562221211838*NH - 0.2227241681859734*lm*NH - 
        0.231807113263303*lm^2*NH - 0.081225*lm^3*NH)}, 
     {0.715, CF*NC*(CA*(1.1626126552475662 - 0.6467539340620708*lm + 
          2.133925917122119*lm^2 + 0.44935381944444447*lm^3) + 
        CF*(0.47931045249033116 + 1.1219522455311117*lm - 
          1.7722455163001685*lm^2 + 0.73530625*lm^3) - 0.13191703043555936*
         NM - 0.22149649159116547*lm*NM - 0.23201247735553684*lm^2*NM - 
        0.08170069444444444*lm^3*NM - 0.8214610967916851*NL - 
        0.22149649159116547*lm*NL - 0.23201247735553684*lm^2*NL - 
        0.08170069444444444*lm^3*NL + 0.35007128692595296*NH - 
        0.22149649159116547*lm*NH - 0.23201247735553684*lm^2*NH - 
        0.08170069444444444*lm^3*NH)}, 
     {0.72, CF*NC*(CA*(1.1676357671483752 - 0.6726001502554457*lm + 
          2.1399959243269735*lm^2 + 0.45197777777777776*lm^3) + 
        CF*(0.4781561567380458 + 1.1423019453596848*lm - 1.7930521238285888*
           lm^2 + 0.7396*lm^3) - 0.12623564101307766*NM - 
        0.22025612575910464*lm*NM - 0.23220531957460125*lm^2*NM - 
        0.08217777777777778*lm^3*NM - 0.8246866224066259*NL - 
        0.22025612575910464*lm*NL - 0.23220531957460125*lm^2*NL - 
        0.08217777777777778*lm^3*NL + 0.3489480115338238*NH - 
        0.22025612575910464*lm*NH - 0.23220531957460125*lm^2*NH - 
        0.08217777777777778*lm^3*NH)}, 
     {0.725, CF*NC*(CA*(1.1729025131530346 - 0.6986617249264361*lm + 
          2.146011490063353*lm^2 + 0.454609375*lm^3) + 
        CF*(0.47687439865252906 + 1.1630448015426063*lm - 
          1.8140373060326949*lm^2 + 0.74390625*lm^3) - 0.12052806286529558*
         NM - 0.2190033607479747*lm*NM - 0.23238561182970055*lm^2*NM - 
        0.08265625*lm^3*NM - 0.8279325190497536*NL - 0.2190033607479747*lm*
         NL - 0.23238561182970055*lm^2*NL - 0.08265625*lm^3*NL + 
        0.3477864503580481*NH - 0.2190033607479747*lm*NH - 
        0.23238561182970055*lm^2*NH - 0.08265625*lm^3*NH)}, 
     {0.73, CF*NC*(CA*(1.1784151918594787 - 0.7249372668075184*lm + 
          2.1519724609016753*lm^2 + 0.4572486111111111*lm^3) + 
        CF*(0.4754614150852531 + 1.1841842889718202*lm - 1.8352013139790766*
           lm^2 + 0.748225*lm^3) - 0.1147945903778149*NM - 
        0.2177384850198734*lm*NM - 0.23255332622454702*lm^2*NM - 
        0.0831361111111111*lm^3*NM - 0.8311989341536477*NL - 
        0.2177384850198734*lm*NL - 0.23255332622454702*lm^2*NL - 
        0.0831361111111111*lm^3*NL + 0.34658665902691116*NH - 
        0.2177384850198734*lm*NH - 0.23255332622454702*lm^2*NH - 
        0.0831361111111111*lm^3*NH)}, 
     {0.735, CF*NC*(CA*(1.1841760674862238 - 0.751425391976959*lm + 
          2.1578786844630846*lm^2 + 0.4598954861111111*lm^3) + 
        CF*(0.47391342775262785 + 1.205723862312798*lm - 1.8565443970149527*
           lm^2 + 0.75255625*lm^3) - 0.10903551237453314*NM - 
        0.21646178545815692*lm*NM - 0.23270843505389416*lm^2*NM - 
        0.08361736111111111*lm^3*NM - 0.834486010862552*NL - 
        0.21646178545815692*lm*NL - 0.23270843505389416*lm^2*NL - 
        0.08361736111111111*lm^3*NL + 0.3453486943654595*NH - 
        0.21646178545815692*lm*NH - 0.23270843505389416*lm^2*NH - 
        0.08361736111111111*lm^3*NH)}, 
     {0.74, CF*NC*(CA*(1.1901873704589174 - 0.7781247237880585*lm + 
          2.163730009400841*lm^2 + 0.46255*lm^3) + 
        CF*(0.4722266437487327 + 1.2276669562656648*lm - 1.8780668027986236*
           lm^2 + 0.7569*lm^3) - 0.10325111220942183*NM - 
        0.2151735473846112*lm*NM - 0.23285091080015294*lm^2*NM - 
        0.0841*lm^3*NM - 0.8377938881091037*NL - 0.2151735473846112*lm*
         NL - 0.23285091080015294*lm^2*NL - 0.0841*lm^3*NL + 
        0.344072614377629*NH - 0.2151735473846112*lm*NH - 
        0.23285091080015294*lm^2*NH - 0.0841*lm^3*NH)}, 
     {0.745, CF*NC*(CA*(1.1964512979845578 - 0.805033892798787*lm + 
          2.169526285382157*lm^2 + 0.4652121527777778*lm^3) + 
        CF*(0.47039725604180826 + 1.2500169858222143*lm - 
          1.8997687773291978*lm^2 + 0.76125625*lm^3) - 0.09744166785636575*
         NM - 0.2138740545764489*lm*NM - 0.23298072613008913*lm^2*NM - 
        0.08458402777777778*lm^3*NM - 0.8411227006893516*NL - 
        0.2138740545764489*lm*NL - 0.23298072613008913*lm^2*NL - 
        0.08458402777777778*lm^3*NL + 0.34275847822876365*NH - 
        0.2138740545764489*lm*NH - 0.23298072613008913*lm^2*NH - 
        0.08458402777777778*lm^3*NH)}, 
     {0.75, CF*NC*(CA*(1.2029700146136748 - 0.8321515367018351*lm + 
          2.17526736307046*lm^2 + 0.4678819444444444*lm^3) + 
        CF*(0.4684214439550618 + 1.2727773465188719*lm - 1.9216505649756108*
           lm^2 + 0.765625*lm^3) - 0.09160745199711058*NM - 
        0.21256358928313127*lm*NM - 0.23309785389159882*lm^2*NM - 
        0.08506944444444445*lm^3*NM - 0.8444725793361092*NL - 
        0.21256358928313127*lm*NL - 0.23309785389159882*lm^2*NL - 
        0.08506944444444445*lm^3*NL + 0.3414063462285137*NH - 
        0.21256358928313127*lm*NH - 0.23309785389159882*lm^2*NH - 
        0.08506944444444445*lm^3*NH)}, 
     {0.755, CF*NC*(CA*(1.2097456527907624 - 0.859476300255099*lm + 
          2.180953094108081*lm^2 + 0.470559375*lm^3) + 
        CF*(0.46629537363231643 + 1.2959514146856732*lm - 
          1.9437124085049582*lm^2 + 0.77000625*lm^3) - 
        0.0857487321073657*NM - 0.21124243224301392*lm*NM - 
        0.2332022671105602*lm^2*NM - 0.08555625*lm^3*NM - 
        0.8478436507906854*NL - 0.21124243224301392*lm*NL - 
        0.2332022671105602*lm^2*NL - 0.08555625*lm^3*NL + 
        0.34001627981410265*NH - 0.21124243224301392*lm*NH - 
        0.2332022671105602*lm^2*NH - 0.08555625*lm^3*NH)}, 
     {0.76, CF*NC*(CA*(1.2167803133932356 - 0.8870068352126189*lm + 
          2.1865833310993454*lm^2 + 0.47324444444444447*lm^3) + 
        CF*(0.4640151984890185 + 1.3195425476913147*lm - 1.9659545491101618*
           lm^2 + 0.7744*lm^3) - 0.07986577054110713*NM - 
        0.2099108626998159*lm*NM - 0.2332939389877598*lm^2*NM - 
        0.08604444444444445*lm^3*NM - 0.8512360378730316*NL - 
        0.2099108626998159*lm*NL - 0.2332939389877598*lm^2*NL - 
        0.08604444444444445*lm^3*NL + 0.33858834153395406*NH - 
        0.2099108626998159*lm*NH - 0.2332939389877598*lm^2*NH - 
        0.08604444444444445*lm^3*NH)}, 
     {0.765, CF*NC*(CA*(1.2240760662591894 - 0.9147418002559857*lm + 
          2.1921579275940646*lm^2 + 0.47593715277777776*lm^3) + 
        CF*(0.46157705964909507 + 1.34355408418434*lm - 1.9883772264369854*
           lm^2 + 0.77880625*lm^3) - 0.07395882461312502*NM - 
        0.20856915841891152*lm*NM - 0.2333728428958905*lm^2*NM - 
        0.08653402777777777*lm^3*NM - 0.8546498595503503*NL - 
        0.20856915841891152*lm*NL - 0.2333728428958905*lm^2*NL - 
        0.08653402777777777*lm^3*NL + 0.337122595031667*NH - 
        0.20856915841891152*lm*NH - 0.2333728428958905*lm^2*NH - 
        0.08653402777777777*lm^3*NH)}, 
     {0.77, CF*NC*(CA*(1.2316349507042184 - 0.9426798609262336*lm + 
          2.197676738071409*lm^2 + 0.4786375*lm^3) + 
        CF*(0.45897708636813944 + 1.3679893443305213*lm - 
          2.010980678610422*lm^2 + 0.783225*lm^3) - 0.06802814667985799*NM - 
        0.20721759570344503*lm*NM - 0.2334389523766198*lm^2*NM - 
        0.087025*lm^3*NM - 0.8580852310041996*NL - 0.20721759570344503*lm*
         NL - 0.2334389523766198*lm^2*NL - 0.087025*lm^3*NL + 
        0.3356191050303325*NH - 0.20721759570344503*lm*NH - 
        0.2334389523766198*lm^2*NH - 0.087025*lm^3*NH)}, 
     {0.775, CF*NC*(CA*(1.2394589760275594 - 0.9708196895562311*lm + 
          2.2031396179241605*lm^2 + 0.4813454861111111*lm^3) + 
        CF*(0.4562113964433814 + 1.3928516300464964*lm - 2.0337651422604646*
           lm^2 + 0.78765625*lm^3) - 0.06207398421855674*NM - 
        0.20585644941026765*lm*NM - 0.23349224113772618*lm^2*NM - 
        0.08751736111111111*lm^3*NM - 0.8615422636961348*NL - 
        0.20585644941026765*lm*NL - 0.23349224113772618*lm^2*NL - 
        0.08751736111111111*lm^3*NL + 0.33407793731718005*NH - 
        0.20585644941026765*lm*NH - 0.23349224113772618*lm^2*NH - 
        0.08751736111111111*lm^3*NH)}, 
     {0.78, CF*NC*(CA*(1.2475501220078056 - 0.9991599652035842*lm + 
          2.208546423443327*lm^2 + 0.4840611111111111*lm^3) + 
        CF*(0.453276096610886 + 1.4181442252297216*lm - 2.056730852547283*
           lm^2 + 0.7921*lm^3) - 0.05609657990481681*NM - 
        0.20448599296569736*lm*NM - 0.23353268305030186*lm^2*NM - 
        0.08801111111111111*lm^3*NM - 0.8650210654319234*NL - 
        0.20448599296569736*lm*NL - 0.23353268305030186*lm^2*NL - 
        0.08801111111111111*lm^3*NL + 0.3324991587285476*NH - 
        0.20448599296569736*lm*NH - 0.23353268305030186*lm^2*NH - 
        0.08801111111111111*lm^3*NH)}, 
     {0.785, CF*NC*(CA*(1.2559103393884372 - 1.0276993735840618*lm + 
          2.2138970118031103*lm^2 + 0.486784375*lm^3) + 
        CF*(0.45016728293040603 + 1.4438703959847965*lm - 
          2.0798780431858197*lm^2 + 0.79655625*lm^3) - 0.05009617168852052*
         NM - 0.2031064983811012*lm*NM - 0.23356025214602005*lm^2*NM - 
        0.08850625*lm^3*NM - 0.8685217404243684*NL - 0.2031064983811012*lm*
         NL - 0.23356025214602005*lm^2*NL - 0.08850625*lm^3*NL + 
        0.3308828371351639*NH - 0.2031064983811012*lm*NH - 
        0.23356025214602005*lm^2*NH - 0.08850625*lm^3*NH)}, 
     {0.79, CF*NC*(CA*(1.2645415503534099 - 1.0564366070055566*lm + 
          2.2191912410462225*lm^2 + 0.48951527777777776*lm^3) + 
        CF*(0.44688104115829896 + 1.4700333908462224*lm - 
          2.103206946469818*lm^2 + 0.801025*lm^3) - 0.044072992868226225*
         NM - 0.20171823626830093*lm*NM - 0.23357492261446466*lm^2*NM - 
        0.08900277777777778*lm^3*NM - 0.8720443893547772*NL - 
        0.20171823626830093*lm*NL - 0.23357492261446466*lm^2*NL - 
        0.08900277777777778*lm^3*NL + 0.3292290414277374*NH - 
        0.20171823626830093*lm*NH - 0.23357492261446466*lm^2*NH - 
        0.08900277777777778*lm^3*NH)}, 
     {0.795, CF*NC*(CA*(1.273445648993028 - 1.0853703643025874*lm + 
          2.2244289700695346*lm^2 + 0.49225381944444446*lm^3) + 
        CF*(0.4434134471089056 + 1.4966364409976491*lm - 2.126717793295307*
           lm^2 + 0.80550625*lm^3) - 0.038027272164042496*NM - 
        0.2003214758548022*lm*NM - 0.23357666880052141*lm^2*NM - 
        0.08950069444444445*lm^3*NM - 0.8755891094331072*NL - 
        0.2003214758548022*lm*NL - 0.23357666880052141*lm^2*NL - 
        0.08950069444444445*lm^3*NL + 0.32753784150284143*NH - 
        0.2003214758548022*lm*NH - 0.23357666880052141*lm^2*NH - 
        0.08950069444444445*lm^3*NH)}, 
     {0.8, CF*NC*(CA*(1.2826245017603353 - 1.1144993507713548*lm + 
          2.229610058610055*lm^2 + 0.495*lm^3) + 
        CF*(0.43976056700477134 + 1.5236827604876688*lm - 
          2.150410813183546*lm^2 + 0.81*lm^3) - 0.03195923378902353*NM - 
        0.19891648499884762*lm*NM - 0.2335654652018282*lm^2*NM - 
        0.09*lm^3*NM - 0.8791559944568237*NL - 0.19891648499884762*lm*NL - 
        0.2335654652018282*lm^2*NL - 0.09*lm^3*NL + 0.32580930824909016*
         NH - 0.19891648499884762*lm*NH - 0.2335654652018282*lm^2*NH - 
        0.09*lm^3*NH)}, {0.805, 
      CF*NC*(CA*(1.2920799479182397 - 1.1438222781053553*lm + 
          2.234734367231223*lm^2 + 0.49775381944444447*lm^3) + 
        CF*(0.4359184578160789 + 1.5511755464422117*lm - 2.174286234303453*
           lm^2 + 0.81450625*lm^3) - 0.02586909751912133*NM - 
        0.19750353020429492*lm*NM - 0.23354128646628303*lm^2*NM - 
        0.09050069444444445*lm^3*NM - 0.8827451348685009*NL - 
        0.19750353020429492*lm*NL - 0.23354128646628303*lm^2*NL - 
        0.09050069444444445*lm^3*NL + 0.32404351353359573*NH - 
        0.19750353020429492*lm*NH - 0.23354128646628303*lm^2*NH - 
        0.09050069444444445*lm^3*NH)}, 
     {0.81, CF*NC*(CA*(1.3018137999775878 - 1.1733378643315613*lm + 
          2.2398017573095137*lm^2 + 0.5005152777777778*lm^3) + 
        CF*(0.4318831675896479 + 1.5791179792735999*lm - 2.198344283493523*
           lm^2 + 0.819025*lm^3) - 0.019757078761729115*NM - 
        0.19608287663532023*lm*NM - 0.23350410738960853*lm^2*NM - 
        0.09100277777777778*lm^3*NM - 0.8863566178121977*NL - 
        0.19608287663532023*lm*NL - 0.23350410738960853*lm^2*NL - 
        0.09100277777777778*lm^3*NL + 0.32224053018870064*NH - 
        0.19608287663532023*lm*NH - 0.23350410738960853*lm^2*NH - 
        0.09100277777777778*lm^3*NH)}, 
     {0.815, CF*NC*(CA*(1.311827844126402 - 1.2030448337471737*lm + 
          2.244812091021341*lm^2 + 0.503284375*lm^3) + 
        CF*(0.42765073576784396 + 1.6075132228863156*lm - 
          2.2225851862832604*lm^2 + 0.82355625*lm^3) - 0.013623388622849578*
         NM - 0.1946547881309481*lm*NM - 0.23345390291297108*lm^2*NM - 
        0.09150625*lm^3*NM - 0.8899905271886379*NL - 0.1946547881309481*lm*
         NL - 0.23345390291297108*lm^2*NL - 0.09150625*lm^3*NL + 
        0.3204004319989776*NH - 0.1946547881309481*lm*NH - 
        0.23345390291297108*lm^2*NH - 0.09150625*lm^3*NH)}, 
     {0.82, CF*NC*(CA*(1.3221238406504796 - 1.2329419168569506*lm + 
          2.2497652313302585*lm^2 + 0.5060611111111111*lm^3) + 
        CF*(0.4232171934977278 + 1.6363644248795335*lm - 2.247009166914123*
           lm^2 + 0.8281*lm^3) - 0.007468233972920718*NM - 
        0.19321952721940858*lm*NM - 0.23339064812065302*lm^2*NM - 
        0.09201111111111111*lm^3*NM - 0.8936469437092266*NL - 
        0.19321952721940858*lm*NL - 0.23339064812065302*lm^2*NL - 
        0.09201111111111111*lm^3*NL + 0.3185232936884901*NH - 
        0.19321952721940858*lm*NH - 0.23339064812065302*lm^2*NH - 
        0.09201111111111111*lm^3*NH)}, 
     {0.825, CF*NC*(CA*(1.3327035243455576 - 1.2630278503111179*lm + 
          2.254661041974441*lm^2 + 0.5088454861111111*lm^3) + 
        CF*(0.4185785639307639 + 1.665674716746477*lm - 2.2716164483600063*
           lm^2 + 0.83265625*lm^3) - 0.0012918175113310745*NM - 
        0.19177735513232258*lm*NM - 0.2333143182377771*lm^2*NM - 
        0.09251736111111111*lm^3*NM - 0.8973259449489281*NL - 
        0.19177735513232258*lm*NL - 0.2333143182377771*lm^2*NL - 
        0.09251736111111111*lm^3*NL + 0.31660919090830736*NH - 
        0.19177735513232258*lm*NH - 0.2333143182377771*lm^2*NH - 
        0.09251736111111111*lm^3*NH)}, 
     {0.83, CF*NC*(CA*(1.3435686049212352 - 1.2933013768438644*lm + 
          2.259499387454446*lm^2 + 0.5116375*lm^3) + 
        CF*(0.41373086251339536 + 1.6954472140706451*lm - 
          2.2964072523472705*lm^2 + 0.837225*lm^3) + 0.004905662170344655*
         NM - 0.19032853181871676*lm*NM - 0.23322488862808108*lm^2*NM - 
        0.093025*lm^3*NM - 0.9010276053980366*NL - 0.19032853181871676*lm*
         NL - 0.23322488862808108*lm^2*NL - 0.093025*lm^3*NL + 
        0.3146582002242666*NH - 0.19032853181871676*lm*NH - 
        0.23322488862808108*lm^2*NH - 0.093025*lm^3*NH)}, 
     {0.835, CF*NC*(CA*(1.3547207673968433 - 1.3237612452124252*lm + 
          2.2642801330212468*lm^2 + 0.5144371527777778*lm^3) + 
        CF*(0.40867009726878323 + 1.7256850167189652*lm - 
          2.3213817993743238*lm^2 + 0.84180625*lm^3) + 0.011124010526359378*
         NM - 0.18887331595886872*lm*NM - 0.23312233479174183*lm^2*NM - 
        0.09353402777777778*lm^3*NM - 0.9047519965128642*NL - 
        0.18887331595886872*lm*NL - 0.23312233479174183*lm^2*NL - 
        0.09353402777777778*lm^3*NL + 0.3126703991049769*NH - 
        0.18887331595886872*lm*NH - 0.23312233479174183*lm^2*NH - 
        0.09353402777777778*lm^3*NH)}, 
     {0.84, CF*NC*(CA*(1.3661616724894465 - 1.354406210136756*lm + 
          2.2690031446645254*lm^2 + 0.5172444444444444*lm^3) + 
        CF*(0.40339226906999626 + 1.7563912090319236*lm - 
          2.3465403087307766*lm^2 + 0.8464*lm^3) + 0.01736303699602741*NM - 
        0.18741196497798399*lm*NM - 0.23300663236324706*lm^2*NM - 
        0.09404444444444444*lm^3*NM - 0.9084991867653748*NL - 
        0.18741196497798399*lm*NL - 0.23300663236324706*lm^2*NL - 
        0.09404444444444444*lm^3*NL + 0.3106458659100581*NH - 
        0.18741196497798399*lm*NH - 0.23300663236324706*lm^2*NH - 
        0.09404444444444444*lm^3*NH)}, 
     {0.845, CF*NC*(CA*(1.3778929569941565 - 1.3852350322397984*lm + 
          2.2736682891012268*lm^2 + 0.520059375*lm^3) + 
        CF*(0.3978933719049276 + 1.7875688600107205*lm - 2.3718829985161745*
           lm^2 + 0.85100625*lm^3) + 0.02362255494414967*NM - 
        0.18594473505970588*lm*NM - 0.23287775710931394*lm^2*NM - 
        0.09455625*lm^3*NM - 0.912269241691788*NL - 0.18594473505970588*lm*
         NL - 0.23287775710931394*lm^2*NL - 0.09455625*lm^3*NL + 
        0.3085846798786091*NH - 0.18594473505970588*lm*NH - 
        0.23287775710931394*lm^2*NH - 0.09455625*lm^3*NH)}, 
     {0.85, CF*NC*(CA*(1.389916234156933 - 1.4162464779883404*lm + 
          2.2782754337643576*lm^2 + 0.5228819444444445*lm^3) + 
        CF*(0.39216939313320587 + 1.8192210235015045*lm - 
          2.397410085658324*lm^2 + 0.855625*lm^3) + 0.0299023816026024*NM - 
        0.18447188115945973*lm*NM - 0.2327356849268529*lm^2*NM - 
        0.09506944444444444*lm^3*NM - 0.9160622239401792*NL - 
        0.18447188115945973*lm*NL - 0.2327356849268529*lm^2*NL - 
        0.09506944444444444*lm^3*NL + 0.3064869211178999*NH - 
        0.18447188115945973*lm*NH - 0.2327356849268529*lm^2*NH - 
        0.09506944444444444*lm^3*NH)}, 
     {0.855, CF*NC*(CA*(1.4022330940400436 - 1.44743931963447*lm + 
          2.2828244467920342*lm^2 + 0.5257121527777778*lm^3) + 
        CF*(0.386216313735358 + 1.851350738376731*lm - 2.4231217859312166*
           lm^2 + 0.86025625*lm^3) + 0.0362023380130623*NM - 
        0.1829936570176324*lm*NM - 0.23258039184097593*lm^2*NM - 
        0.09558402777777777*lm^3*NM - 0.9198781933170991*NL - 
        0.1829936570176324*lm*NL - 0.23258039184097593*lm^2*NL - 
        0.09558402777777777*lm^3*NL + 0.3043526705922811*NH - 
        0.1829936570176324*lm*NH - 0.23258039184097593*lm^2*NH - 
        0.09558402777777777*lm^3*NH)}, 
     {0.86, CF*NC*(CA*(1.4148451038803467 - 1.4788123351576248*lm + 
          2.287315197016763*lm^2 + 0.52855*lm^3) + 
        CF*(0.3800301085544728 + 1.8839610287136952*lm - 
          2.44901831397257*lm^2 + 0.8649*lm^3) + 0.04252224897084162*NM - 
        0.1815103151725891*lm*NM - 0.23241185400304779*lm^2*NM - 
        0.0961*lm^3*NM - 0.9237172068332369*NL - 0.1815103151725891*lm*
         NL - 0.23241185400304779*lm^2*NL - 0.0961*lm^3*NL + 
        0.3021820101123068*NH - 0.1815103151725891*lm*NH - 
        0.23241185400304779*lm^2*NH - 0.0961*lm^3*NH)}, 
     {0.865, CF*NC*(CA*(1.4277538084405634 - 1.5103643082072364*lm + 
          2.291747553954954*lm^2 + 0.5313954861111111*lm^3) + 
        CF*(0.3736067465306058 + 1.9170549039702887*lm - 2.475099883300985*
           lm^2 + 0.86955625*lm^3) + 0.04886194296980747*NM - 
        0.18002210697352836*lm*NM - 0.23223004768877947*lm^2*NM - 
        0.0966173611111111*lm^3*NM - 0.927579318748151*NL - 
        0.18002210697352836*lm*NL - 0.23223004768877947*lm^2*NL - 
        0.0966173611111111*lm^3*NL + 0.29997502232406376*NH - 
        0.18002210697352836*lm*NH - 0.23223004768877947*lm^2*NH - 
        0.0966173611111111*lm^3*NH)}, 
     {0.87, CF*NC*(CA*(1.4409607303536962 - 1.5420940280459685*lm + 
          2.2961213877966595*lm^2 + 0.5342486111111111*lm^3) + 
        CF*(0.36694219092815683 + 1.9506353591580214*lm - 
          2.5013667063327385*lm^2 + 0.874225*lm^3) + 0.055221252148360295*
         NM - 0.17852928259317685*lm*NM - 0.23203494929636237*lm^2*NM - 
        0.09713611111111112*lm^3*NM - 0.9314645806140877*NL - 
        0.17852928259317685*lm*NL - 0.23203494929636237*lm^2*NL - 
        0.09713611111111112*lm^3*NL + 0.2977317906987038*NH - 
        0.17852928259317685*lm*NH - 0.23203494929636237*lm^2*NH - 
        0.09713611111111112*lm^3*NH)}, 
     {0.875, CF*NC*(CA*(1.4544673704607454 - 1.574000289493548*lm + 
          2.3004365693955338*lm^2 + 0.537109375*lm^3) + 
        CF*(0.36003239955644467 + 1.9847053750123629*lm - 
          2.527818994398217*lm^2 + 0.87890625*lm^3) + 0.0616000122364471*
         NM - 0.17703209104032555*lm*NM - 0.23182653534464254*lm^2*NM - 
        0.09765625*lm^3*NM - 0.9353730413189115*NL - 0.17703209104032555*lm*
         NL - 0.23182653534464254*lm^2*NL - 0.09765625*lm^3*NL + 
        0.2954523995221728*NH - 0.17703209104032555*lm*NH - 
        0.23182653534464254*lm^2*NH - 0.09765625*lm^3*NH)}, 
     {0.88, CF*NC*(CA*(1.4682752081418793 - 1.6060818928711909*lm + 
          2.3046929702590018*lm^2 + 0.5399777777777778*lm^3) + 
        CF*(0.3528733249836953 + 2.0192679181604394*lm - 2.554456957757997*
           lm^2 + 0.8836*lm^3) + 0.06799806250358563*NM - 
        0.17553078017220874*lm*NM - 0.23160478247133368*lm^2*NM - 
        0.09817777777777778*lm^3*NM - 0.9393047471281677*NL - 
        0.17553078017220874*lm*NL - 0.23160478247133368*lm^2*NL - 
        0.09817777777777778*lm^3*NL + 0.2931369338851319*NH - 
        0.17553078017220874*lm*NH - 0.23160478247133368*lm^2*NH - 
        0.09817777777777778*lm^3*NH)}, 
     {0.885, CF*NC*(CA*(1.4823857016412008 - 1.638337643946615*lm + 
          2.3088904625386415*lm^2 + 0.5428538194444444*lm^3) + 
        CF*(0.3454609147446521 + 2.0543259412861397*lm - 2.5812808056185865*
           lm^2 + 0.88830625*lm^3) + 0.07441524570787633*NM - 
        0.17402559670672735*lm*NM - 0.23136966743126816*lm^2*NM - 
        0.09870069444444445*lm^3*NM - 0.9432597417262967*NL - 
        0.17402559670672735*lm*NL - 0.23136966743126816*lm^2*NL - 
        0.09870069444444445*lm^3*NL + 0.29078547967306745*NH - 
        0.17402559670672735*lm*NH - 0.23136966743126816*lm^2*NH - 
        0.09870069444444445*lm^3*NH)}, 
     {0.89, CF*NC*(CA*(1.4968002883852574 - 1.6707663538796467*lm + 
          2.3130289190207667*lm^2 + 0.5457375*lm^3) + 
        CF*(0.3377911115420113 + 2.0898823832926685*lm - 2.608290746147836*
           lm^2 + 0.893025*lm^3) + 0.08085140804597948*NM - 
        0.17251678623451802*lm*NM - 0.2311211670946849*lm^2*NM - 
        0.099225*lm^3*NM - 0.9472380662570226*NL - 0.17251678623451802*lm*
         NL - 0.2311211670946849*lm^2*NL - 0.099225*lm^3*NL + 
        0.2883981235565828*NH - 0.17251678623451802*lm*NH - 
        0.2311211670946849*lm^2*NH - 0.099225*lm^3*NH)}, 
     {0.895, CF*NC*(CA*(1.5115203852954293 - 1.7033668391684094*lm + 
          2.31710821311721*lm^2 + 0.5486288194444444*lm^3) + 
        CF*(0.3298598534418754 + 2.125940169462592*lm - 2.6354869864900206*
           lm^2 + 0.89775625*lm^3) + 0.08730639910403569*NM - 
        0.17100459323087*lm*NM - 0.23085925844555327*lm^2*NM - 
        0.09975069444444444*lm^3*NM - 0.9512397593629334*NL - 
        0.17100459323087*lm*NL - 0.23085925844555327*lm^2*NL - 
        0.09975069444444444*lm^3*NL + 0.2859749529818698*NH - 
        0.17100459323087*lm*NH - 0.23085925844555327*lm^2*NH - 
        0.09975069444444444*lm^3*NH)}, 
     {0.9, CF*NC*(CA*(1.5265473890943388 - 1.7361379215960993*lm + 
          2.321128218856294*lm^2 + 0.5515277777777777*lm^3) + 
        CF*(0.32166307406341516 + 2.1625022116154207*lm - 
          2.6628697327806097*lm^2 + 0.9025*lm^3) + 0.09378007180950801*NM - 
        0.1694892610674907*lm*NM - 0.23058391857993224*lm^2*NM - 
        0.10027777777777777*lm^3*NM - 0.9552648572242728*NL - 
        0.1694892610674907*lm*NL - 0.23058391857993224*lm^2*NL - 
        0.10027777777777777*lm^3*NL + 0.2835160561613545*NH - 
        0.1694892610674907*lm*NH - 0.23058391857993224*lm^2*NH - 
        0.10027777777777777*lm^3*NH)}, 
     {0.905, CF*NC*(CA*(1.5418826766064067 - 1.769078428178343*lm + 
          2.325088810874*lm^2 + 0.554434375*lm^3) + 
        CF*(0.3131967027629213 + 2.199571408262766*lm - 2.6904391901607276*
           lm^2 + 0.90725625*lm^3) + 0.10027228238392517*NM - 
        0.16797103202412217*lm*NM - 0.2302951247043636*lm^2*NM - 
        0.10080625*lm^3*NM - 0.9593133935969623*NL - 0.16797103202412217*lm*
         NL - 0.2302951247043636*lm^2*NL - 0.10080625*lm^3*NL + 
        0.28102152206451286*NH - 0.16797103202412217*lm*NH - 
        0.2302951247043636*lm^2*NH - 0.10080625*lm^3*NH)}, 
     {0.91, CF*NC*(CA*(1.55752760505269 - 1.8021871911111318*lm + 
          2.3289898644053095*lm^2 + 0.5573486111111111*lm^3) + 
        CF*(0.3044566648124214 + 2.2371506447611194*lm - 2.718195562791312*
           lm^2 + 0.912025*lm^3) + 0.10678289029650524*NM - 
        0.1664501473000097*lm*NM - 0.22999285413429868*lm^2*NM - 
        0.10133611111111111*lm^3*NM - 0.9633853998498716*NL - 
        0.1664501473000097*lm*NL - 0.22999285413429868*lm^2*NL - 
        0.10133611111111111*lm^3*NL + 0.27849144040885304*NH - 
        0.1664501473000097*lm*NH - 0.22999285413429868*lm^2*NH - 
        0.10133611111111111*lm^3*NH)}, 
     {0.915, CF*NC*(CA*(1.5734835123401285 - 1.8354630477193343*lm + 
          2.3328312552757335*lm^2 + 0.5602704861111111*lm^3) + 
        CF*(0.2954388815730327 + 2.275242793462286*lm - 2.746139053866982*
           lm^2 + 0.91680625*lm^3) + 0.11331175821864019*NM - 
        0.16492684702522434*lm*NM - 0.2296770842925576*lm^2*NM - 
        0.10186736111111111*lm^3*NM - 0.9674809050013536*NL - 
        0.16492684702522434*lm*NL - 0.2296770842925576*lm^2*NL - 
        0.10186736111111111*lm^3*NL + 0.27592590165105957*NH - 
        0.16492684702522434*lm*NH - 0.2296770842925576*lm^2*NH - 
        0.10186736111111111*lm^3*NH)}, 
     {0.92, CF*NC*(CA*(1.5897517173453166 - 1.8689048404057795*lm + 
          2.3366128598930116*lm^2 + 0.5632*lm^3) + 
        CF*(0.2861392706632151 + 2.3138507138615214*lm - 2.7742698656296176*
           lm^2 + 0.9216*lm^3) + 0.1198587519792218*NM - 
        0.16340137027184087*lm*NM - 0.22934779270782027*lm^2*NM - 
        0.1024*lm^3*NM - 0.9715999357550636*NL - 0.16340137027184087*lm*
         NL - 0.22934779270782027*lm^2*NL - 0.1024*lm^3*NL + 
        0.27332499697829654*NH - 0.16340137027184087*lm*NH - 
        0.22934779270782027*lm^2*NH - 0.1024*lm^3*NH)}, 
     {0.925, CF*NC*(CA*(1.60633352019293 - 1.9025114166009094*lm + 
          2.3403345552389836*lm^2 + 0.5661371527777778*lm^3) + 
        CF*(0.27655374612208217 + 2.3529772527434027*lm - 
          2.8025881993816633*lm^2 + 0.92640625*lm^3) + 0.12642374052079033*
         NM - 0.16187395506497304*lm*NM - 0.22900495701314852*lm^2*NM - 
        0.10293402777777778*lm^3*NM - 0.9757425165350773*NL - 
        0.16187395506497304*lm*NL - 0.22900495701314852*lm^2*NL - 
        0.10293402777777778*lm^3*NL + 0.27068881829966485*NH - 
        0.16187395506497304*lm*NH - 0.22900495701314852*lm^2*NH - 
        0.10293402777777778*lm^3*NH)}, 
     {0.93, CF*NC*(CA*(1.6232302025289171 - 1.9362816287129974*lm + 
          2.343996218861627*lm^2 + 0.5690819444444445*lm^3) + 
        CF*(0.26667821856792506 + 2.392625244325479*lm - 2.8310942554991563*
           lm^2 + 0.931225*lm^3) + 0.13300659585648741*NM - 
        0.16034483839366734*lm*NM - 0.22864855494453817*lm^2*NM - 
        0.10346944444444445*lm^3*NM - 0.9799086695203238*NL - 
        0.16034483839366734*lm*NL - 0.22864855494453817*lm^2*NL - 
        0.10346944444444445*lm^3*NL + 0.2680174582378108*NH - 
        0.16034483839366734*lm*NH - 0.22864855494453817*lm^2*NH - 
        0.10346944444444445*lm^3*NH)}, 
     {0.935, CF*NC*(CA*(1.6404430277885746 - 1.970214334078927*lm + 
          2.347597728867255*lm^2 + 0.572034375*lm^3) + 
        CF*(0.25650859535209686 + 2.4327975103997366*lm - 
          2.859788233444492*lm^2 + 0.93605625*lm^3) + 0.13960719302779526*
         NM - 0.1588142562216574*lm*NM - 0.2282785643395009*lm^2*NM - 
        0.10400625*lm^3*NM - 0.9840984146783522*NL - 0.1588142562216574*lm*
         NL - 0.2282785643395009*lm^2*NL - 0.10400625*lm^3*NL + 
        0.2653110101206825*NH - 0.1588142562216574*lm*NH - 
        0.2282785643395009*lm^2*NH - 0.10400625*lm^3*NH)}, 
     {0.94, CF*NC*(CA*(1.6579732414596158 - 2.0043083949155287*lm + 
          2.351138963912877*lm^2 + 0.5749944444444445*lm^3) + 
        CF*(0.24604078070840077 + 2.4734968604719123*lm - 
          2.8886703317789286*lm^2 + 0.9409*lm^3) + 0.1462254100630451*NM - 
        0.15728244349798026*lm*NM - 0.22789496313567462*lm^2*NM - 
        0.10454444444444444*lm^3*NM - 0.9883117697984424*NL - 
        0.15728244349798026*lm*NL - 0.22789496313567462*lm^2*NL - 
        0.10454444444444444*lm^3*NL + 0.2625695679734298*NH - 
        0.15728244349798026*lm*NH - 0.22789496313567462*lm^2*NH - 
        0.10454444444444444*lm^3*NH)}, 
     {0.945, CF*NC*(CA*(1.6758220713403424 - 2.0385626782714703*lm + 
          2.3546198031987084*lm^2 + 0.5779621527777777*lm^3) + 
        CF*(0.23527067589812128 + 2.5147260918987016*lm - 
          2.9177407481748405*lm^2 + 0.94575625*lm^3) + 0.15286112793667736*
         NM - 0.15574963416745632*lm*NM - 0.22749772936946216*lm^2*NM - 
        0.10508402777777778*lm^3*NM - 0.9925487505240795*NL - 
        0.15574963416745632*lm*NL - 0.22749772936946216*lm^2*NL - 
        0.10508402777777778*lm^3*NL + 0.2597932265104456*NH - 
        0.15574963416745632*lm*NH - 0.22749772936946216*lm^2*NH - 
        0.10508402777777778*lm^3*NH)}, 
     {0.95, CF*NC*(CA*(1.6939907277930275 - 2.072976055979696*lm + 
          2.358040126460835*lm^2 + 0.5809375*lm^3) + 
        CF*(0.22419417935083233 + 2.5564879900228856*lm - 
          2.9469996794277247*lm^2 + 0.950625*lm^3) + 0.15951423052923744*
         NM - 0.15421606118103476*lm*NM - 0.22708684117469724*lm^2*NM - 
        0.105625*lm^3*NM - 0.9968093703848047*NL - 0.15421606118103476*lm*
         NL - 0.22708684117469724*lm^2*NL - 0.105625*lm^3*NL + 
        0.2569820811275444*NH - 0.15421606118103476*lm*NH - 
        0.22708684117469724*lm^2*NH - 0.105625*lm^3*NH)}, 
     {0.955, CF*NC*(CA*(1.7124804039926085 - 2.1075474046104095*lm + 
          2.3613998139640207*lm^2 + 0.5839204861111111*lm^3) + 
        CF*(0.21280718680111185 + 2.598785328306421*lm - 2.976447321467966*
           lm^2 + 0.95550625*lm^3) + 0.1661846045880906*NM - 
        0.1526819565060056*lm*NM - 0.2266622767813371*lm^2*NM - 
        0.10616736111111111*lm^3*NM - 1.0010936408274558*NL - 
        0.1526819565060056*lm*NL - 0.2266622767813371*lm^2*NL - 
        0.10616736111111111*lm^3*NL + 0.254136227894275*NH - 
        0.1526819565060056*lm*NH - 0.2266622767813371*lm^2*NH - 
        0.10616736111111111*lm^3*NH)}, 
     {0.96, CF*NC*(CA*(1.731292276170798 - 2.1422756054245995*lm + 
          2.364698746494664*lm^2 + 0.5869111111111112*lm^3) + 
        CF*(0.2011055914212886 + 2.641620868461525*lm - 3.0060838693723677*
           lm^2 + 0.9604*lm^3) + 0.17287213968884063*NM - 
        0.15114755113608053*lm*NM - 0.22622401451418134*lm^2*NM - 
        0.10671111111111112*lm^3*NM - 1.0054015712468138*NL - 
        0.15114755113608053*lm*NL - 0.22622401451418134*lm^2*NL - 
        0.10671111111111112*lm^3*NL + 0.25125576354636503*NH - 
        0.15114755113608053*lm*NH - 0.22622401451418134*lm^2*NH - 
        0.10671111111111112*lm^3*NH)}, 
     {0.965, CF*NC*(CA*(1.750427503855707 - 2.1771595443280987*lm + 
          2.367936805353889*lm^2 + 0.589909375*lm^3) + 
        CF*(0.18908528395034216 + 2.6849973605797888*lm - 
          3.035909517375454*lm^2 + 0.96530625*lm^3) + 0.17957672819743659*
         NM - 0.14961307510134378*lm*NM - 0.22577203279161626*lm^2*NM - 
        0.10725625*lm^3*NM - 1.009733169015666*NL - 0.14961307510134378*lm*
         NL - 0.22577203279161626*lm^2*NL - 0.10725625*lm^3*NL + 
        0.24834078547829364*NH - 0.14961307510134378*lm*NH - 
        0.22577203279161626*lm^2*NH - 0.10725625*lm^3*NH)}, 
     {0.97, CF*NC*(CA*(1.7698872301070772 - 2.2121981118261753*lm + 
          2.371113872350778*lm^2 + 0.5929152777777777*lm^3) + 
        CF*(0.17674215281907385 + 2.7289175432593518*lm - 
          3.065924458880545*lm^2 + 0.970225*lm^3) + 0.1862982652329526*NM - 
        0.14807875747807486*lm*NM - 0.2253063101243839*lm^2*NM - 
        0.10780277777777778*lm^3*NM - 1.0140884395143013*NL - 
        0.14807875747807486*lm*NL - 0.2253063101243839*lm^2*NL - 
        0.10780277777777778*lm^3*NL + 0.2453913917359891*NH - 
        0.14807875747807486*lm*NH - 0.2253063101243839*lm^2*NH - 
        0.10780277777777778*lm^3*NH)}, 
     {0.975, CF*NC*(CA*(1.78967258174722 - 2.2473902029786497*lm + 
          2.3742298297957327*lm^2 + 0.5959288194444444*lm^3) + 
        CF*(0.16407208427166178 + 2.773384143730175*lm - 3.0961288864706193*
           lm^2 + 0.97515625*lm^3) + 0.1930366486310266*NM - 
        0.1465448263984447*lm*NM - 0.22482682511437566*lm^2*NM - 
        0.10835069444444445*lm^3*NM - 1.0184673861594502*NL - 
        0.1465448263984447*lm*NL - 0.22482682511437566*lm^2*NL - 
        0.10835069444444445*lm^3*NL + 0.24240768100964957*NH - 
        0.1465448263984447*lm*NH - 0.22482682511437566*lm^2*NH - 
        0.10835069444444445*lm^3*NH)}, 
     {0.98, CF*NC*(CA*(1.8097846695877495 - 2.2827347173555355*lm + 
          2.3772845604939703*lm^2 + 0.59895*lm^3) + 
        CF*(0.15107096248370996 + 2.81839987797744*lm - 3.1265229919189577*
           lm^2 + 0.9801*lm^3) + 0.19979177890794325*NM - 
        0.14501150906008647*lm*NM - 0.22433355645344916*lm^2*NM - 
        0.1089*lm^3*NM - 1.022870010432679*NL - 0.14501150906008647*lm*
         NL - 0.22433355645344916*lm^2*NL - 0.1089*lm^3*NL + 
        0.23938975262668358*NH - 0.14501150906008647*lm*NH - 
        0.22433355645344916*lm^2*NH - 0.1089*lm^3*NH)}, 
     {0.985, CF*NC*(CA*(1.8302245886522022 - 2.3182305589931937*lm + 
          2.380277947739145*lm^2 + 0.6019788194444444*lm^3) + 
        CF*(0.1377346696768979 + 2.863967450863109*lm - 3.1571069661995805*
           lm^2 + 0.98505625*lm^3) + 0.20656355922534744*NM - 
        0.1434790317355435*lm*NM - 0.2238264829222688*lm^2*NM - 
        0.10945069444444444*lm^3*NM - 1.0272963119082559*NL - 
        0.1434790317355435*lm*NL - 0.2238264829222688*lm^2*NL - 
        0.10945069444444444*lm^3*NL + 0.23633770654476738*NH - 
        0.1434790317355435*lm*NH - 0.2238264829222688*lm^2*NH - 
        0.10945069444444444*lm^3*NH)}, 
     {0.99, CF*NC*(CA*(1.8509934183946308 - 2.353876636351004*lm + 
          2.3832098753070934*lm^2 + 0.6050152777777777*lm^3) + 
        CF*(0.12405908623033308 + 2.910089556245677*lm - 3.1878809994974837*
           lm^2 + 0.990025*lm^3) + 0.21335189535557478*NM - 
        0.14194761978159476*lm*NM - 0.22330558338916848*lm^2*NM - 
        0.11000277777777778*lm^3*NM - 1.0317462882804949*NL - 
        0.14194761978159476*lm*NL - 0.22330558338916848*lm^2*NL - 
        0.11000277777777778*lm^3*NL + 0.23325164334501705*NH - 
        0.14194761978159476*lm*NH - 0.22330558338916848*lm^2*NH - 
        0.11000277777777778*lm^3*NH)}, 
     {0.995, CF*NC*(CA*(1.8720922229142571 - 2.389671862268535*lm + 
          2.3860802274497006*lm^2 + 0.608059375*lm^3) + 
        CF*(0.11004009078870636 + 2.9567688770981415*lm - 
          3.2188452812186714*lm^2 + 0.99500625*lm^3) + 
        0.2201566956475858*NM - 0.14041749764846048*lm*NM - 
        0.22277083680903648*lm^2*NM - 0.11055625*lm^3*NM - 
        1.0362199353905932*NL - 0.14041749764846048*lm*NL - 
        0.22277083680903648*lm^2*NL - 0.11055625*lm^3*NL + 
        0.2301316642252725*NH - 0.14041749764846048*lm*NH - 
        0.22277083680903648*lm^2*NH - 0.11055625*lm^3*NH)}, 
     {1., 3.007364054733763*(CA - 2.*CF)*CF*NC - 0.001388888888888889*CF*NC*
        (CF*(-4399.489202281107 - 2162.8858216494473*lm + 2340.*lm^2 - 
           720.*lm^3) - 2.*CA*(-400.9831212842988 - 873.2214554123618*lm + 
           860.*lm^2 + 220.*lm^3) + 20.*((-8.17120335576568 + 5.*lm + 
             8.*lm^2 + 4.*lm^3)*NM + (37.465820901107016 + 5.*lm + 8.*lm^2 + 
             4.*lm^3)*NL + (-8.17120335576568 + 5.*lm + 8.*lm^2 + 4.*lm^3)*
            NH))}}
 
CbarLTable["a", 2, 0] = {{0., -6.430041152263374*^-6*CF*NC*
       (2.*CA*(-2388.1522153911205 - 28035.755618875908*lm) + 
        15.*(-3103.0124357078876*CF + 
          4.*((-67.3596725935698 + 169.91367041742973*lm)*NM + 
            (-67.3596725935698 + 169.91367041742973*lm)*NL + 
            (-206.3135567749981 + 169.91367041742973*lm)*NH)))}, 
     {0.005, CF*NC*(0.3193251196822399*CF + CA*(0.046281588105329535 + 
          0.370126043764463*lm) + 0.024205199630972767*NM - 
        0.06729564432081146*lm*NM + 0.02419887801910123*NL - 
        0.06729564432081146*lm*NL + 0.08077534592709505*NH - 
        0.06729564432081146*lm*NH)}, 
     {0.01, CF*NC*(0.33861840238164276*CF + CA*(0.06129438842048374 + 
          0.3796100892214369*lm) + 0.022521285208010153*NM - 
        0.06902001622207944*lm*NM + 0.022492476220845353*NL - 
        0.06902001622207944*lm*NL + 0.08195433069438693*NH - 
        0.06902001622207944*lm*NH)}, 
     {0.015, CF*NC*(0.357019145156126*CF + CA*(0.0756054525728381 + 
          0.3889521307938516*lm) + 0.02095904264332527*NM - 
        0.07071856923524575*lm*NM + 0.020888554070836778*NL - 
        0.07071856923524575*lm*NL + 0.08313182830280769*NH - 
        0.07071856923524575*lm*NH)}, 
     {0.02, CF*NC*(0.3744989863931915*CF + CA*(0.08915228498223503 + 
          0.3981273808510569*lm) + 0.019527795297485048*NM - 
        0.07238679651837399*lm*NM + 0.019394887803770012*NL - 
        0.07238679651837399*lm*NL + 0.08430675499434258*NH - 
        0.07238679651837399*lm*NH)}, 
     {0.025, CF*NC*(0.39107118575876226*CF + CA*(0.10190748615980494 + 
          0.4071197419913517*lm) + 0.018230973608974944*NM - 
        0.07402177127115486*lm*NM + 0.018014170070316235*NL - 
        0.07402177127115486*lm*NL + 0.08547822529442095*NH - 
        0.07402177127115486*lm*NH)}, 
     {0.03, CF*NC*(0.4067677115834081*CF + CA*(0.11386304156864628 + 
          0.41591853255392136*lm) + 0.017068793377654056*NM - 
        0.07562155137344025*lm*NM + 0.0167463947032051*NL - 
        0.07562155137344025*lm*NL + 0.08664549745207031*NH - 
        0.07562155137344025*lm*NH)}, 
     {0.035, CF*NC*(0.4216293785218507*CF + CA*(0.125022793827266 + 
          0.4245167739263425*lm) + 0.016039538576674624*NM - 
        0.07718486798660773*lm*NM + 0.015589972849573875*NL - 
        0.07718486798660773*lm*NL + 0.08780794160038115*NH - 
        0.07718486798660773*lm*NH)}, 
     {0.04, CF*NC*(0.4357008934760407*CF + CA*(0.13539822696753945 + 
          0.43291015698278984*lm) + 0.015140278441656385*NM - 
        0.07871093763323452*lm*NM + 0.014542344026662463*NL - 
        0.07871093763323452*lm*NL + 0.0889650186460143*NH - 
        0.07871093763323452*lm*NH)}, 
     {0.045, CF*NC*(0.4490281523952844*CF + CA*(0.1450058784690856 + 
          0.441096362732174*lm) + 0.014367306086698013*NM - 
        0.08019933867857709*lm*NM + 0.013600342711995974*NL - 
        0.08019933867857709*lm*NL + 0.09011626515116751*NH - 
        0.08019933867857709*lm*NH)}, 
     {0.05, CF*NC*(0.461656698116763*CF + CA*(0.1538656514110833 + 
          0.44907458946748247*lm) + 0.013716422952178838*NM - 
        0.08164992535772408*lm*NM + 0.012760431759254051*NL - 
        0.08164992535772408*lm*NL + 0.09126128192945351*NH - 
        0.08164992535772408*lm*NH)}, 
     {0.055, CF*NC*(0.4736308254617607*CF + CA*(0.1619996660732247 + 
          0.4568452098671669*lm) + 0.013183130807854413*NM - 
        0.08306276543039398*lm*NM + 0.012018857194391575*NL - 
        0.08306276543039398*lm*NL + 0.09239972511562292*NH - 
        0.08306276543039398*lm*NH)}, 
     {0.06, CF*NC*(0.48499306711539775*CF + CA*(0.16943145435633197 + 
          0.4644095145894605*lm) + 0.012762765022139848*NM - 
        0.08443809356172009*lm*NM + 0.011371753812517205*NL - 
        0.08443809356172009*lm*NL + 0.09353129897334654*NH - 
        0.08443809356172009*lm*NH)}, 
     {0.065, CF*NC*(0.4957839121259457*CF + CA*(0.17618538199285114 + 
          0.4717695159574657*lm) + 0.012450588851430931*NM - 
        0.08577627562863013*lm*NM + 0.010815218600762283*NL - 
        0.08577627562863013*lm*NL + 0.09465574997538848*NH - 
        0.08577627562863013*lm*NH)}, 
     {0.07, CF*NC*(0.506041670185925*CF + CA*(0.1822862274847376 + 
          0.4789277948302655*lm) + 0.012241860970102898*NM - 
        0.0870777808782301*lm*NM + 0.010345362389916676*NL - 
        0.0870777808782301*lm*NL + 0.09577286184624594*NH - 
        0.0870777808782301*lm*NH)}, 
     {0.075, CF*NC*(0.5158024286817243*CF + CA*(0.18775887191942756 + 
          0.4858873793719969*lm) + 0.012131884134292215*NM - 
        0.08834315988581762*lm*NM + 0.009958346371782379*NL - 
        0.08834315988581762*lm*NL + 0.09688245135246515*NH - 
        0.08834315988581762*lm*NH)}, 
     {0.08, CF*NC*(0.5251000690986726*CF + CA*(0.19262806901580262 + 
          0.49265164791770266*lm) + 0.012116040258938645*NM - 
        0.08957302689412776*lm*NM + 0.009650407867855032*NL - 
        0.08957302689412776*lm*NL + 0.09798436468672386*NH - 
        0.08957302689412776*lm*NH)}, 
     {0.085, CF*NC*(0.5339663211904282*CF + CA*(0.19691827430256134 + 
          0.49922425038782575*lm) + 0.01218981554278293*NM - 
        0.09076804552505922*lm*NM + 0.00941787833251954*NL - 
        0.09076804552505922*lm*NL + 0.09907847433226326*NH - 
        0.09076804552505922*lm*NH)}, 
     {0.09, CF*NC*(0.5424308406909665*CF + CA*(0.2006535185424904 + 
          0.5056090442087614*lm) + 0.012348818204730888*NM - 
        0.09192891712886571*lm*NM + 0.009257195669781577*NL - 
        0.09192891712886571*lm*NL + 0.10016467632207329*NH - 
        0.09192891712886571*lm*NH)}, 
     {0.095, CF*NC*(0.5505213010687429*CF + CA*(0.20385731467571708 + 
          0.5118100417321392*lm) + 0.012588790676605836*NM - 
        0.09305637122402531*lm*NM + 0.009164912342385307*NL - 
        0.09305637122402531*lm*NL + 0.10124288782688812*NH - 
        0.09305637122402531*lm*NH)}, 
     {0.1, CF*NC*(0.5582634929171274*CF + CA*(0.20655259041190172 + 
          0.5178313668751676*lm) + 0.012905617603381546*NM - 
        0.09415115761366685*lm*NM + 0.009137700343697378*NL - 
        0.09415115761366685*lm*NL + 0.10231304502027043*NH - 
        0.09415115761366685*lm*NH)}, 
     {0.105, CF*NC*(0.5656814266423452*CF + CA*(0.20876164060694583 + 
          0.5236772192298235*lm) + 0.013295330654965378*NM - 
        0.09521403985996792*lm*NM + 0.009172353818655669*NL - 
        0.09521403985996792*lm*NL + 0.10337510117957409*NH - 
        0.09521403985996792*lm*NH)}, 
     {0.11, CF*NC*(0.5727974355128235*CF + CA*(0.21050609499506584 + 
          0.5293518442742748*lm) + 0.01375411090515608*NM - 
        0.09624578986804998*lm*NM + 0.00926578991874583*NL - 
        0.09624578986804998*lm*NL + 0.10442902498948889*NH - 
        0.09624578986804998*lm*NH)}, 
     {0.115, CF*NC*(0.5796322770978304*CF + CA*(0.21180689789171223 + 
          0.534859508607682*lm) + 0.014278289352568797*NM - 
        0.09724718338321492*lm*NM + 0.009415048330895634*NL - 
        0.09724718338321492*lm*NL + 0.10547479902093017*NH - 
        0.09724718338321492*lm*NH)}, 
     {0.12, CF*NC*(0.5862052317924282*CF + CA*(0.21268429725459959 + 
          0.5402044793474753*lm) + 0.014864346024772036*NM - 
        0.0982189962449955*lm*NM + 0.009617289814108074*NL - 
        0.0982189962449955*lm*NL + 0.10651241836274473*NH - 
        0.0982189962449955*lm*NH)}, 
     {0.125, CF*NC*(0.5925341975936567*CF + CA*(0.21315784106797736 + 
          0.5453910069955147*lm) + 0.015508908006977172*NM - 
        0.09916200127191176*lm*NM + 0.009869793999095312*NL - 
        0.09916200127191176*lm*NL + 0.10754188938741252*NH - 
        0.09916200127191176*lm*NH)}, 
     {0.13, CF*NC*(0.5986357806215467*CF + CA*(0.2132463794531264 + 
          0.5504233112095136*lm) + 0.01620874666102839*NM - 
        0.10007696567445702*lm*NM + 0.010169956647322611*NL - 
        0.10007696567445702*lm*NL + 0.10856322863487988*NH - 
        0.10007696567445702*lm*NH)}, 
     {0.135, CF*NC*(0.604525381109847*CF + CA*(0.21296807124340328 + 
          0.5553055690181867*lm) + 0.016960774242661823*NM - 
        0.10096464891239759*lm*NM + 0.010515286521331319*NL - 
        0.10096464891239759*lm*NL + 0.10957646180104362*NH - 
        0.10096464891239759*lm*NH)}, 
     {0.14, CF*NC*(0.6102172747538085*CF + CA*(0.21234039402145077 + 
          0.5600419050995467*lm) + 0.017762040080440786*NM - 
        0.1018258009271903*lm*NM + 0.01090340198419713*NL - 
        0.1018258009271903*lm*NL + 0.11058162281934598*NH - 
        0.1018258009271903*lm*NH)}, 
     {0.145, CF*NC*(0.6157246894158367*CF + CA*(0.2113801568184365 + 
          0.5646363838065663*lm) + 0.018609726445130783*NM - 
        0.10266116069210297*lm*NM + 0.011332027419798059*NL - 
        0.10266116069210297*lm*NL + 0.1115787530255355*NH - 
        0.10266116069210297*lm*NH)}, 
     {0.15, CF*NC*(0.6210598772681578*CF + CA*(0.21010351483415182 + 
          0.569093002676702*lm) + 0.019501144211154807*NM - 
        0.10347145503212764*lm*NM + 0.011798989545270434*NL - 
        0.10347145503212764*lm*NL + 0.11256790039697179*NH - 
        0.10347145503212764*lm*NH)}, 
     {0.155, CF*NC*(0.6262341825046984*CF + CA*(0.20852598566264205 + 
          0.5734156872042714*lm) + 0.02043372839040162*NM - 
        0.1042573976735039*lm*NM + 0.012302213671200412*NL - 
        0.1042573976735039*lm*NL + 0.11354911885895698*NH - 
        0.1042573976735039*lm*NH)}, 
     {0.16, CF*NC*(0.6312581047891621*CF + CA*(0.2066624666082779 + 
          0.5776082866894656*lm) + 0.021405033601733917*NM - 
        0.10501968848899375*lm*NM + 0.012839719952684011*NL - 
        0.10501968848899375*lm*NL + 0.1145224676515068*NH - 
        0.10501968848899375*lm*NH)}, 
     {0.165, CF*NC*(0.6361413586278829*CF + CA*(0.20452725275747807 + 
          0.5816745710064289*lm) + 0.022412729526072348*NM - 
        0.10575901291025981*lm*NM + 0.013409619664608645*NL - 
        0.10575901291025981*lm*NL + 0.11548801075076257*NH - 
        0.10575901291025981*lm*NH)}, 
     {0.17, CF*NC*(0.6408929288680887*CF + CA*(0.20213405553594627 + 
          0.5856182281565788*lm) + 0.023454596386167148*NM - 
        0.10647604148301433*lm*NM + 0.01401011152677462*NL - 
        0.10647604148301433*lm*NL + 0.11644581633991728*NH - 
        0.10647604148301433*lm*NH)}, 
     {0.175, CF*NC*(0.6455211225274207*CF + CA*(0.19949602153357318 + 
          0.5894428624931127*lm) + 0.024528520481538193*NM - 
        0.10717142954420232*lm*NM + 0.01463947809833927*NL - 
        0.10717142954420232*lm*NL + 0.11739595632510572*NH - 
        0.10717142954420232*lm*NH)}, 
     {0.18, CF*NC*(0.6500336171608719*CF + CA*(0.19662575142161284 + 
          0.5931519935192038*lm) + 0.025632489802125003*NM - 
        0.10784581700349159*lm*NM + 0.015296082256187274*NL - 
        0.10784581700349159*lm*NL + 0.11833850589220501*NH - 
        0.10784581700349159*lm*NH)}, 
     {0.185, CF*NC*(0.6544375059681781*CF + CA*(0.19353531882133365 + 
          0.5967490551763034*lm) + 0.026764589738597383*NM - 
        0.10849982821387334*lm*NM + 0.01597836376794445*NL - 
        0.10849982821387334*lm*NL + 0.11927354310092385*NH - 
        0.10849982821387334*lm*NH)}, 
     {0.19, CF*NC*(0.6587393398391778*CF + CA*(0.19023628901161527 + 
          0.6002373955507282*lm) + 0.02792299890276564*NM - 
        0.10913407191831422*lm*NM + 0.01668483596725456*NL - 
        0.10913407191831422*lm*NL + 0.12020114851293232*NH - 
        0.10913407191831422*lm*NH)}, 
     {0.195, CF*NC*(0.6629451665275432*CF + CA*(0.18673973738612074 + 
          0.6036202769366726*lm) + 0.029105985067885174*NM - 
        0.10974914126121321*lm*NM + 0.017414082536469352*NL - 
        0.10974914126121321*lm*NL + 0.1211214048511138*NH - 
        0.10974914126121321*lm*NH)}, 
     {0.2, NC*(0.6670605671356831*CF^2 + CA*CF*(0.1830562675894132 + 
          0.6069008762022693*lm) + 
        CF*((0.030311901236406088 - 0.11034561385495806*lm)*NM + 
          (0.018164754399935843 - 0.11034561385495806*lm)*NL + 
          (0.12203439668730731 - 0.11034561385495806*lm)*NH))}, 
     {0.205, NC*(0.671090690081792*CF^2 + CA*CF*(0.17919602927855816 + 
          0.6100822854125596*lm) + 
        CF*((0.03153918183636863 - 0.11092405189319265*lm)*NM + 
          (0.01893556672950238 - 0.11092405189319265*lm)*NL + 
          (0.12294021015616308 - 0.11092405189319265*lm)*NH))}, 
     {0.21, NC*(0.6750402827189155*CF^2 + CA*CF*(0.17516873546565265 + 
          0.6131675126694378*lm) + 
        CF*((0.032786339055962434 - 0.11148500230353416*lm)*NM + 
          (0.01972529606262798 - 0.11148500230353416*lm)*NL + 
          (0.12383893269295887 - 0.11148500230353416*lm)*NH))}, 
     {0.215, NC*(0.6789137207552249*CF^2 + CA*CF*(0.17098367941310424 + 
          0.616159483133955*lm) + 
        CF*((0.03405195930923783 - 0.11202899693344637*lm)*NM + 
          (0.020532777532504484 - 0.11202899693344637*lm)*NL + 
          (0.12473065279342359 - 0.11202899693344637*lm)*NH))}, 
     {0.22, NC*(0.6827150356260612*CF^2 + CA*CF*(0.16664975105702243 + 
          0.6190610402009576*lm) + 
        CF*((0.0353346998381895 - 0.11255655276381048*lm)*NM + 
          (0.021356902208838735 - 0.11255655276381048*lm)*NL + 
          (0.12561545979379238 - 0.11255655276381048*lm)*NH))}, 
     {0.225, NC*(0.6864479399538997*CF^2 + CA*CF*(0.16217545294407024 + 
          0.6218749467999929*lm) + 
        CF*((0.036633285448088956 - 0.11306817214545326*lm)*NM + 
          (0.022196614547351053 - 0.11306817214545326*lm)*NL + 
          (0.1264934436694758 - 0.11306817214545326*lm)*NH))}, 
     {0.23, NC*(0.6901158512255942*CF^2 + CA*CF*(0.1575689156721736 + 
          0.624603886799838*lm) + 
        CF*((0.03794650537440669 - 0.113564343054516*lm)*NM + 
          (0.023050909945595034 - 0.113564343054516*lm)*NL + 
          (0.12736469485086815 - 0.113564343054516*lm)*NH))}, 
     {0.235, NC*(0.6937219138080282*CF^2 + CA*CF*(0.1528379128303554 + 
          0.6272504664969814*lm) + 
        CF*((0.03927321027900046 - 0.11404553936308752*lm)*NM + 
          (0.02391883240236493 - 0.11404553936308752*lm)*NL + 
          (0.12822930405494595 - 0.11404553936308752*lm)*NH))}, 
     {0.24, NC*(0.6972690194152479*CF^2 + CA*CF*(0.14798987543705805 + 
          0.6298172161709618*lm) + 
        CF*((0.040612309372249814 - 0.11451222112199304*lm)*NM + 
          (0.024799472277709976 - 0.11451222112199304*lm)*NL + 
          (0.12908736213142416 - 0.11451222112199304*lm)*NH))}, 
     {0.245, NC*(0.7007598261331535*CF^2 + CA*CF*(0.14303190587933762 + 
          0.6323065916917183*lm) + 
        CF*((0.04196276765815622 - 0.1149648348530397*lm)*NM + 
          (0.025691964150401907 - 0.1149648348530397*lm)*NL + 
          (0.12993895992233961 - 0.1149648348530397*lm)*NH))}, 
     {0.25, NC*(0.7041967761005604*CF^2 + CA*CF*(0.13797079135805942 + 
          0.6347209761660592*lm) + 
        CF*((0.04332360329862054 - 0.11540381384837438*lm)*NM + 
          (0.026595484769588992 - 0.11540381384837438*lm)*NL + 
          (0.13078418813402498 - 0.11540381384837438*lm)*NH))}, 
     {0.255, NC*(0.7075821119390316*CF^2 + CA*CF*(0.1328130168462297 + 
          0.6370626816120637*lm) + 
        CF*((0.04469388509321015 - 0.11582957847492067*lm)*NM + 
          (0.02750925109730503 - 0.11582957847492067*lm)*NL + 
          (0.1316231372205216 - 0.11582957847492067*lm)*NH))}, 
     {0.26, NC*(0.7109178920176693*CF^2 + CA*CF*(0.12756477756926884 + 
          0.6393339506517296*lm) + 
        CF*((0.04607273007053525 - 0.11624253648213265*lm)*NM + 
          (0.02843251843847591 - 0.11624253648213265*lm)*NL + 
          (0.13245589727755586 - 0.11624253648213265*lm)*NH))}, 
     {0.265, NC*(0.714206004633294*CF^2 + CA*CF*(0.12223199101731311 + 
          0.641536958213475*lm) + 
        CF*((0.047459301187301114 - 0.11664308331154091*lm)*NM + 
          (0.029364578655071298 - 0.11664308331154091*lm)*NL + 
          (0.1332825579462733 - 0.11664308331154091*lm)*NH))}, 
     {0.27, NC*(0.7174481811810193*CF^2 + CA*CF*(0.11682030850062364 + 
          0.6436738132372574*lm) + 
        CF*((0.0488528051310572 - 0.11703160240677406*lm)*NM + 
          (0.0303047584610789 - 0.11703160240677406*lm)*NL + 
          (0.13410320832598938 - 0.11703160240677406*lm)*NH))}, 
     {0.275, NC*(0.7206460083852363*CF^2 + CA*CF*(0.11133512625988726 + 
          0.6457465603760659*lm) + 
        CF*((0.0502524902227184 - 0.11740846552292107*lm)*NM + 
          (0.03125241779502774 - 0.11740846552292107*lm)*NL + 
          (0.1349179368952718 - 0.11740846552292107*lm)*NH))}, 
     {0.28, NC*(0.7238009396562982*CF^2 + CA*CF*(0.10578159614372194 + 
          0.6477571816884301*lm) + 
        CF*((0.05165764441491851 - 0.11777403303426003*lm)*NM + 
          (0.03220694826685131 - 0.11777403303426003*lm)*NL + 
          (0.1357268314407243 - 0.11777403303426003*lm)*NH))}, 
     {0.285, NC*(0.7269143056338654*CF^2 + CA*CF*(0.10016463586601593 + 
          0.649707598317353*lm) + 
        CF*((0.05306759338235509 - 0.11812865423951872*lm)*NM + 
          (0.033167771675957004 - 0.11812865423951872*lm)*NL + 
          (0.13652997899288866 - 0.11812865423951872*lm)*NH))}, 
     {0.29, NC*(0.7299873239737579*CF^2 + CA*CF*(0.09448893885594194 + 
          0.6515996721517602*lm) + 
        CF*((0.05448169870032978 - 0.11847266766395641*lm)*NM + 
          (0.03413433859745323 - 0.11847266766395641*lm)*NL + 
          (0.13732746576872634 - 0.11847266766395641*lm)*NH))}, 
     {0.295, NC*(0.7330211084312791*CF^2 + CA*CF*(0.08875898371360441 + 
          0.6534352074671481*lm) + 
        CF*((0.055899356107800696 - 0.1188064013576633*lm)*NM + 
          (0.03510612703357587 - 0.1188064013576633*lm)*NL + 
          (0.13811937712018243 - 0.1188064013576633*lm)*NH))}, 
     {0.3, NC*(0.736016729296121*CF^2 + CA*CF*(0.0829790172814149 + 
          0.6552159525426388*lm) + 
        CF*((0.05731999385132965 - 0.11913017318957068*lm)*NM + 
          (0.03608264112745139 - 0.11913017318957068*lm)*NL + 
          (0.13890579748837087 - 0.11913017318957068*lm)*NH))}, 
     {0.305, NC*(0.7389750036155119*CF^2 + CA*CF*(0.07715317214876441 + 
          0.656943601252108*lm) + 
        CF*((0.05874307110645022 - 0.11944429113674691*lm)*NM + 
          (0.037063409936431715 - 0.11944429113674691*lm)*NL + 
          (0.1396868103629547 - 0.11944429113674691*lm)*NH))}, 
     {0.31, NC*(0.7418968439965176*CF^2 + CA*CF*(0.07128530422873872 + 
          0.658619794627457*lm) + 
        CF*((0.06016807647304842 - 0.11974905356862854*lm)*NM + 
          (0.038047986262335416 - 0.11974905356862854*lm)*NL + 
          (0.1404624982463267 - 0.11974905356862854*lm)*NH))}, 
     {0.315, NC*(0.7447830265526053*CF^2 + CA*CF*(0.06537912015687612 + 
          0.6602461223924517*lm) + 
        CF*((0.06159452654150504 - 0.12004474952590032*lm)*NM + 
          (0.03903594553602984 - 0.12004474952590032*lm)*NL + 
          (0.14123294262222433 - 0.12004474952590032*lm)*NH))}, 
     {0.32, NC*(0.7476342599017004*CF^2 + CA*CF*(0.059438153589319885 + 
          0.6618241244658657*lm) + 
        CF*((0.06302196452642365 - 0.12033165899379376*lm)*NM + 
          (0.04002688475388831 - 0.12033165899379376*lm)*NL + 
          (0.14199822392843986 - 0.12033165899379376*lm)*NH))}, 
     {0.325, NC*(0.7504511909233533*CF^2 + CA*CF*(0.05346577257599342 + 
          0.663355292432933*lm) + 
        CF*((0.06444995896491096 - 0.12061005316962417*lm)*NM + 
          (0.04102042146375499 - 0.12061005316962417*lm)*NL + 
          (0.1427584215333114 - 0.12061005316962417*lm)*NH))}, 
     {0.33, NC*(0.75323441009019*CF^2 + CA*CF*(0.04746518662918337 + 
          0.66484107098436*lm) + 
        CF*((0.06587810247647923 - 0.12088019472442907*lm)*NM + 
          (0.04201619279814707 - 0.12088019472442907*lm)*NL + 
          (0.1435136137157029 - 0.12088019472442907*lm)*NH))}, 
     {0.335, NC*(0.755984456403307*CF^2 + CA*CF*(0.04143945349926322 + 
          0.6662828593223495*lm) + 
        CF*((0.06730601058176042 - 0.12114233805860901*lm)*NM + 
          (0.04301385455251881 - 0.12114233805860901*lm)*NL + 
          (0.1442638776482024 - 0.12114233805860901*lm)*NH))}, 
     {0.34, NC*(0.7587018219592321*CF^2 + CA*CF*(0.035391485668965675 + 
          0.6676820125332777*lm) + 
        CF*((0.06873332057733311 - 0.12139672955150503*lm)*NM + 
          (0.044013080306504485 - 0.12139672955150503*lm)*NL + 
          (0.1450092893832875 - 0.12139672955150503*lm)*NH))}, 
     {0.345, NC*(0.7613869561741644*CF^2 + CA*CF*(0.029324056577281217 + 
          0.6690398429268187*lm) + 
        CF*((0.07015969046406463 - 0.12164360780487614*lm)*NM + 
          (0.04501356058614757 - 0.12164360780487614*lm)*NL + 
          (0.14574992384222427 - 0.12164360780487614*lm)*NH))}, 
     {0.35, NC*(0.7640402696894493*CF^2 + CA*CF*(0.023239806583711605 + 
          0.670357621341456*lm) + 
        CF*((0.07158479792649325 - 0.12188320388026475*lm)*NM + 
          (0.04601500206521076 - 0.12188320388026475*lm)*NL + 
          (0.14648585480648363 - 0.12188320388026475*lm)*NH))}, 
     {0.355, NC*(0.7666621379806058*CF^2 + CA*CF*(0.01714124868325993 + 
          0.6716365784164345*lm) + 
        CF*((0.07300833936088234 - 0.12211574153026082*lm)*NM + 
          (0.047017126803745805 - 0.12211574153026082*lm)*NL + 
          (0.147217154911473 - 0.12211574153026082*lm)*NH))}, 
     {0.36, NC*(0.769252904690672*CF^2 + CA*CF*(0.011030773982200792 + 
          0.6728779058303151*lm) + 
        CF*((0.07443002894966676 - 0.12234143742369366*lm)*NM + 
          (0.04801967152218386 - 0.12234143742369366*lm)*NL + 
          (0.14794389564239732 - 0.12234143742369366*lm)*NH))}, 
     {0.365, NC*(0.7718128847072034*CF^2 + CA*CF*(0.00491065694433188 + 
          0.6740827575063822*lm) + 
        CF*((0.07584959778010099 - 0.12256050136479676*lm)*NM + 
          (0.04902238690928565 - 0.12256050136479676*lm)*NL + 
          (0.14866614733207484 - 0.12256050136479676*lm)*NH))}, 
     {0.37, NC*(0.7743423670009943*CF^2 + CA*CF*(-0.0012169395829647522 + 
          0.6752522507852309*lm) + 
        CF*((0.07726679300508461 - 0.12277313650640562*lm)*NM + 
          (0.05002503696236627 - 0.12277313650640562*lm)*NL + 
          (0.1493839791605468 - 0.12277313650640562*lm)*NH))}, 
     {0.375, NC*(0.7768416172432395*CF^2 + CA*CF*(-0.007349959553802635 + 
          0.6763874675649277*lm) + 
        CF*((0.07868137704410312 - 0.12297953955725958*lm)*NM + 
          (0.051027398358282273 - 0.12297953955725958*lm)*NL + 
          (0.15009745915633071 - 0.12297953955725958*lm)*NH))}, 
     {0.38, NC*(0.7793108802168344*CF^2 + CA*CF*(-0.013486449111361877 + 
          0.6774894554091939*lm) + 
        CF*((0.08009312682246111 - 0.1231799009834898*lm)*NM + 
          (0.05202925985373825 - 0.1231799009834898*lm)*NL + 
          (0.1508066541991781 - 0.1231799009834898*lm)*NH))}, 
     {0.385, NC*(0.781750382036343*CF^2 + CA*CF*(-0.019624552169575555 + 
          0.6785592286241079*lm) + 
        CF*((0.08150183304695749 - 0.12337440520438324*lm)*NM + 
          (0.05303042171353726 - 0.12337440520438324*lm)*NL + 
          (0.15151163002420676 - 0.12337440520438324*lm)*NH))}, 
     {0.39, NC*(0.7841603321902119*CF^2 + CA*CF*(-0.02576250618089888 + 
          0.6795977693038624*lm) + 
        CF*((0.08290729951629115 - 0.12356323078252045*lm)*NM + 
          (0.0540306951654632 - 0.12356323078252045*lm)*NL + 
          (0.15221245122728747 - 0.12356323078252045*lm)*NH))}, 
     {0.395, NC*(0.7865409254178629*CF^2 + CA*CF*(-0.031898638082429584 + 
          0.680606028346145*lm) + 
        CF*((0.08430934246454509 - 0.12374655060839*lm)*NM + 
          (0.055029901880544685 - 0.12374655060839*lm)*NL + 
          (0.1529091812715732 - 0.12374655060839*lm)*NH))}, 
     {0.4, NC*(0.7888923434334407*CF^2 + CA*CF*(-0.03803136041295421 + 
          0.681584926437735*lm) + 
        CF*((0.08570778993618346 - 0.12392453207958819*lm)*NM + 
          (0.056027873477508636 - 0.12392453207958819*lm)*NL + 
          (0.1536018824950669 - 0.12392453207958819*lm)*NH))}, 
     {0.405, NC*(0.791214756507177*CF^2 + CA*CF*(-0.04415916759378354 + 
          0.6825353550109349*lm) + 
        CF*((0.08710248119105979 - 0.12409733727471545*lm)*NM + 
          (0.05702445105028771 - 0.12409733727471545*lm)*NL + 
          (0.1542906161191304 - 0.12409733727471545*lm)*NH))}, 
     {0.41, NC*(0.7935083249145876*CF^2 + CA*CF*(-0.05028063236652769 + 
          0.683458177171466*lm) + 
        CF*((0.08849326613801128 - 0.12426512312208471*lm)*NM + 
          (0.05801948471749932 - 0.12426512312208471*lm)*NL + 
          (0.1549754422578468 - 0.12426512312208471*lm)*NH))}, 
     {0.415, NC*(0.7957732002630167*CF^2 + CA*CF*(-0.0563944023812349 + 
          0.6843542285984725*lm) + 
        CF*((0.08988000479567869 - 0.12442804156335864*lm)*NM + 
          (0.05901283319286504 - 0.12442804156335864*lm)*NL + 
          (0.15565641992815016 - 0.12442804156335864*lm)*NH))}, 
     {0.42, NC*(0.7980095267043885*CF^2 + CA*CF*(-0.06249919692858244 + 
          0.6852243184172887*lm) + 
        CF*((0.09126256677924939 - 0.12458623971223431*lm)*NM + 
          (0.06000436337558789 - 0.12458623971223431*lm)*NL + 
          (0.15633360706064744 - 0.12458623971223431*lm)*NH))}, 
     {0.425, NC*(0.8002174420424314*CF^2 + CA*CF*(-0.0685938038100722 + 
          0.6860692300456229*lm) + 
        CF*((0.09264083081190429 - 0.12473986000829507*lm)*NM + 
          (0.0609939499597518 - 0.12473986000829507*lm)*NL + 
          (0.15700706051105973 - 0.12473986000829507*lm)*NH))}, 
     {0.43, NC*(0.8023970787420421*CF^2 + CA*CF*(-0.07467707634041527 + 
          0.6868897220138223*lm) + 
        CF*((0.09401468425976504 - 0.12488904036614949*lm)*NM + 
          (0.06198147506185142 - 0.12488904036614949*lm)*NL + 
          (0.15767683607221591 - 0.12488904036614949*lm)*NH))}, 
     {0.435, NC*(0.804548564847979*CF^2 + CA*CF*(-0.08074793047655181 + 
          0.687686528759876*lm) + 
        CF*((0.09538402268924764 - 0.12503391431997746*lm)*NM + 
          (0.0629668278656034 - 0.12503391431997746*lm)*NL + 
          (0.15834298848653672 - 0.12503391431997746*lm)*NH))}, 
     {0.44, NC*(0.8066720248195313*CF^2 + CA*CF*(-0.08680534206796008 + 
          0.6884603613998164*lm) + 
        CF*((0.0967487494457358 - 0.12517461116360298*lm)*NM + 
          (0.0639499042832298 - 0.12517461116360298*lm)*NL + 
          (0.15900557145895441 - 0.12517461116360298*lm)*NH))}, 
     {0.445, NC*(0.8087675802873874*CF^2 + CA*CF*(-0.09284834422314567 + 
          0.6892119084741695*lm) + 
        CF*((0.0981087752525659 - 0.12531125608621263*lm)*NM + 
          (0.06493060663244364 - 0.12531125608621263*lm)*NL + 
          (0.1596646376702091 - 0.12531125608621263*lm)*NH))}, 
     {0.45, NC*(0.810835350738479*CF^2 + CA*CF*(-0.09887602478740531 + 
          0.6899418366711065*lm) + 
        CF*((0.09946401782934733 - 0.12544397030383755*lm)*NM + 
          (0.06590884332840209 - 0.12544397030383755*lm)*NL + 
          (0.1603202387904787 - 0.12544397030383755*lm)*NH))}, 
     {0.455, NC*(0.8128754541341998*CF^2 + CA*CF*(-0.10488752392717635 + 
          0.6906507915269352*lm) + 
        CF*((0.10081440152870909 - 0.12557287118671548*lm)*NM + 
          (0.06688452858992885 - 0.12557287118671548*lm)*NL + 
          (0.16097242549329263 - 0.12557287118671548*lm)*NH))}, 
     {0.46, NC*(0.8148880074669897*CF^2 + CA*CF*(-0.11088203181646018 + 
          0.6913393981045638*lm) + 
        CF*((0.10215985699057298 - 0.12569807238264796*lm)*NM + 
          (0.06785758215933946 - 0.12569807238264796*lm)*NL + 
          (0.16162124746968862 - 0.12569807238264796*lm)*NH))}, 
     {0.465, NC*(0.8168731272599775*CF^2 + CA*CF*(-0.11685878642102164 + 
          0.6920082616505641*lm) + 
        CF*((0.1035003208131379 - 0.1258196839364662*lm)*NM + 
          (0.06882792903523548 - 0.1258196839364662*lm)*NL + 
          (0.16226675344257274 - 0.1258196839364662*lm)*NH))}, 
     {0.47, NC*(0.8188309300140107*CF^2 + CA*CF*(-0.12281707137622791 + 
          0.6926579682314434*lm) + 
        CF*((0.10483573523976533 - 0.125937812405717*lm)*NM + 
          (0.0697954992176636 - 0.125937812405717*lm)*NL + 
          (0.16290899118124796 - 0.125937812405717*lm)*NH))}, 
     {0.475, NC*(0.8207615326061227*CF^2 + CA*CF*(-0.12875621395457484 + 
          0.6932890853497331*lm) + 
        CF*((0.106166047861012 - 0.12605256097267875*lm)*NM + 
          (0.07076022746506395 - 0.12605256097267875*lm)*NL + 
          (0.16354800751607365 - 0.12605256097267875*lm)*NH))}, 
     {0.48, NC*(0.8226650526432003*CF^2 + CA*CF*(-0.13467558311911346 + 
          0.6939021625404805*lm) + 
        CF*((0.10749121133108677 - 0.12616402955281464*lm)*NM + 
          (0.07172205306245963 - 0.12616402955281464*lm)*NL + 
          (0.16418384835323194 - 0.12616402955281464*lm)*NH))}, 
     {0.485, NC*(0.8245416087743519*CF^2 + CA*CF*(-0.14057458765914946 + 
          0.6944977319487282*lm) + 
        CF*((0.1088111830980446 - 0.12627231489976878*lm)*NM + 
          (0.07268091960036537 - 0.12627231489976878*lm)*NL + 
          (0.16481655868956535 - 0.12627231489976878*lm)*NH))}, 
     {0.49, NC*(0.8263913209652358*CF^2 + CA*CF*(-0.14645267440474252 + 
          0.6950763088885457*lm) + 
        CF*((0.1101259251470616 - 0.1263775107070083*lm)*NM + 
          (0.07363677476391767 - 0.1263775107070083*lm)*NL + 
          (0.16544618262746433 - 0.1263775107070083*lm)*NH))}, 
     {0.495, NC*(0.8282143107373773*CF^2 + CA*CF*(-0.15230932651667986 + 
          0.6956383923841699*lm) + 
        CF*((0.11143540375616837 - 0.1264797077062127*lm)*NM + 
          (0.07458957013175284 - 0.1264797077062127*lm)*NL + 
          (0.1660727633897778 - 0.1264797077062127*lm)*NH))}, 
     {0.5, CF*NC*(0.8300107015676443*CF + CA*(-0.1581440619675475 + 
          0.6961844656236992*lm) + 0.11273958928138199*NM - 
        0.12657899374976347*lm*NM + 0.07553926099327436*NL - 
        0.12657899374976347*lm*NL + 0.16669634333237335*NH - 
        0.12657899374976347*lm*NH)}, 
     {0.505, CF*NC*(0.8317806182544927*CF + CA*(-0.16395643147174216 + 
          0.6967149967618974*lm) + 0.11403845586157674*NM - 
        0.12667545395670862*lm*NM + 0.07648580612729315*NL - 
        0.12667545395670862*lm*NL + 0.167316963968957*NH - 
        0.12667545395670862*lm*NH)}, 
     {0.51, CF*NC*(0.8335241883570299*CF + CA*(-0.16974601778056098 + 
          0.6972304389406504*lm) + 0.11533198132586371*NM - 
        0.1267691707164819*lm*NM + 0.07742916768860375*NL - 
        0.1267691707164819*lm*NL + 0.16793466597015524*NH - 
        0.1267691707164819*lm*NH)}, 
     {0.515, CF*NC*(0.8352415414059594*CF + CA*(-0.17551243367709768 + 
          0.6977312310978383*lm) + 0.11662014690982882*NM - 
        0.1268602238359706*lm*NM + 0.07836931099812224*NL - 
        0.1268602238359706*lm*NL + 0.1685494891895187*NH - 
        0.1268602238359706*lm*NH)}, 
     {0.52, CF*NC*(0.8369328092516019*CF + CA*(-0.1812553207505561 + 
          0.6982177983372372*lm) + 0.11790293708767968*NM - 
        0.1269486906067704*lm*NM + 0.07930620439581233*NL - 
        0.1269486906067704*lm*NL + 0.16916147267524687*NH - 
        0.1269486906067704*lm*NH)}, 
     {0.525, CF*NC*(0.8385981261457752*CF + CA*(-0.18697434807669364 + 
          0.6986905523732777*lm) + 0.11918033939120391*NM - 
        0.12703464588605048*lm*NM + 0.0802398190892766*NL - 
        0.12703464588605048*lm*NL + 0.16977065468483482*NH - 
        0.12703464588605048*lm*NH)}, 
     {0.53, CF*NC*(0.8402376288046819*CF + CA*(-0.19266921095410838 + 
          0.6991498919614335*lm) + 0.12045234423758241*NM - 
        0.1271181621748061*lm*NM + 0.08117012900934925*NL - 
        0.1271181621748061*lm*NL + 0.17037707269962243*NH - 
        0.1271181621748061*lm*NH)}, 
     {0.535, CF*NC*(0.8418514564544836*CF + CA*(-0.19833962969401894 + 
          0.6995962033146935*lm) + 0.12171894476563674*NM - 
        0.12719930969358065*lm*NM + 0.08209711067236848*NL - 
        0.12719930969358065*lm*NL + 0.17098076343923307*NH - 
        0.12719930969358065*lm*NH)}, 
     {0.54, CF*NC*(0.8434397508611232*CF + CA*(-0.20398534846128763 + 
          0.7000298605065579*lm) + 0.12298013668010885*NM - 
        0.12727815645573778*lm*NM + 0.08302074304882125*NL - 
        0.12727815645573778*lm*NL + 0.17158176287589214*NH - 
        0.12727815645573778*lm*NH)}, 
     {0.545, CF*NC*(0.8450026563458435*CF + CA*(-0.2096061341645325 + 
          0.7004512258609857*lm) + 0.1242359181035912*NM - 
        0.12735476833836104*lm*NM + 0.08394100743806775*NL - 
        0.12735476833836104*lm*NL + 0.1721801062486147*NH - 
        0.12735476833836104*lm*NH)}, 
     {0.55, CF*NC*(0.8465403197877405*CF + CA*(-0.21520177539326638 + 
          0.7008606503297112*lm) + 0.12548628943574328*NM - 
        0.1274292091508566*lm*NM + 0.08485788734886646*NL - 
        0.1274292091508566*lm*NL + 0.1727758280772545*NH - 
        0.1274292091508566*lm*NH)}, 
     {0.555, CF*NC*(0.8480528906145994*CF + CA*(-0.2207720814000877 + 
          0.701258473857331*lm) + 0.12673125321944803*NM - 
        0.1275015407013329*lm*NM + 0.0857713683854342*NL - 
        0.1275015407013329*lm*NL + 0.17336896217640535*NH - 
        0.1275015407013329*lm*NH)}, 
     {0.56, CF*NC*(0.8495405207831627*CF + CA*(-0.2263168811260338 + 
          0.701645025734555*lm) + 0.12797081401357824*NM - 
        0.1275718228608282*lm*NM + 0.08668143813878706*NL - 
        0.1275718228608282*lm*NL + 0.17395954166914868*NH - 
        0.1275718228608282*lm*NH)}, 
     {0.565, CF*NC*(0.8510033647498984*CF + CA*(-0.23183602226728575 + 
          0.7020206249400006*lm) + 0.12920497827205837*NM - 
        0.12764011362545466*lm*NM + 0.0875880860831211*NL - 
        0.12764011362545466*lm*NL + 0.17454759900064068*NH - 
        0.12764011362545466*lm*NH)}, 
     {0.57, CF*NC*(0.8524415794332554*CF + CA*(-0.23732937038149238 + 
          0.7023855804709*lm) + 0.13043375422892284*NM - 
        0.12770646917652728*lm*NM + 0.08849130347700186*NL - 
        0.12770646917652728*lm*NL + 0.17513316595153344*NH - 
        0.12770646917652728*lm*NH)}, 
     {0.575, CF*NC*(0.8538553241683209*CF + CA*(-0.24279680803205347 + 
          0.7027401916630768*lm) + 0.13165715178908532*NM - 
        0.12777094393874122*lm*NM + 0.08939108326914327*NL - 
        0.12777094393874122*lm*NL + 0.17571627365122525*NH - 
        0.12777094393874122*lm*NH)}, 
     {0.58, CF*NC*(0.855244760654721*CF + CA*(-0.24823823396877398 + 
          0.70308474850054*lm) + 0.13287518242454788*NM - 
        0.12783359063646182*lm*NM + 0.0902874200085662*NL - 
        0.12783359063646182*lm*NL + 0.17629695259093564*NH - 
        0.12783359063646182*lm*NH)}, 
     {0.585, CF*NC*(0.8566100528985475*CF + CA*(-0.253653562343367 + 
          0.703419531915032*lm) + 0.13408785907579107*NM - 
        0.12789446034818763*lm*NM + 0.09118030975893693*NL - 
        0.12789446034818763*lm*NL + 0.1768752326366018*NH - 
        0.12789446034818763*lm*NH)}, 
     {0.59, CF*NC*(0.8579513671490295*CF + CA*(-0.25904272195834865 + 
          0.7037448140758539*lm) + 0.13529519605809873*NM - 
        0.12795360255924615*lm*NM + 0.09206975001689498*NL - 
        0.12795360255924615*lm*NL + 0.17745114304159285*NH - 
        0.12795360255924615*lm*NH)}, 
     {0.595, CF*NC*(0.8592688718306131*CF + CA*(-0.26440565554793005 + 
          0.7040608586702869*lm) + 0.13649720897258275*NM - 
        0.12801106521277944*lm*NM + 0.09295573963418838*NL - 
        0.12801106521277944*lm*NL + 0.17802471245923948*NH - 
        0.12801106521277944*lm*NH)}, 
     {0.6, CF*NC*(0.8605627374710625*CF + CA*(-0.2697423190895692 + 
          0.7043679211749142*lm) + 0.13769391462168457*NM - 
        0.12806689475907532*lm*NM + 0.0938382787434433*NL - 
        0.12806689475907532*lm*NL + 0.17859596895517685*NH - 
        0.12806689475907532*lm*NH)}, 
     {0.605, CF*NC*(0.8618331366261457*CF + CA*(-0.2750526811449038 + 
          0.7046662491181392*lm) + 0.13888533092894*NM - 
        0.12812113620329804*lm*NM + 0.09471736868740241*NL - 
        0.12812113620329804*lm*NL + 0.17916494001949854*NH - 
        0.12812113620329804*lm*NH)}, 
     {0.61, CF*NC*(0.8630802438014229*CF + CA*(-0.28033672222883865 + 
          0.7049560823341878*lm) + 0.14007147686280494*NM - 
        0.12817383315167052*lm*NM + 0.09559301195147427*NL - 
        0.12817383315167052*lm*NL + 0.17973165257872084*NH - 
        0.12817383315167052*lm*NH)}, 
     {0.615, CF*NC*(0.8643042353716144*CF + CA*(-0.2855944342056148 + 
          0.7052376532088732*lm) + 0.14125237236434826*NM - 
        0.12822502785615877*lm*NM + 0.09646521209944343*NL - 
        0.12822502785615877*lm*NL + 0.18029613300755562*NH - 
        0.12822502785615877*lm*NH)}, 
     {0.62, CF*NC*(0.8655052894979853*CF + CA*(-0.2908258197107342 + 
          0.7055111869173899*lm) + 0.1424280382786285*NM - 
        0.12827476125770726*lm*NM + 0.09733397371219753*NL - 
        0.12827476125770726*lm*NL + 0.1808584071404917*NH - 
        0.12827476125770726*lm*NH)}, 
     {0.625, CF*NC*(0.8666835860441485*CF + CA*(-0.2960308915976642 + 
          0.7057769016544003*lm) + 0.14359849628957777*NM - 
        0.12832307302807278*lm*NM + 0.09819930232933427*NL - 
        0.12832307302807278*lm*NL + 0.18141850028318396*NH - 
        0.12832307302807278*lm*NH)}, 
     {0.63, CF*NC*(0.8678393064906529*CF + CA*(-0.3012096724082905 + 
          0.7060350088566639*lm) + 0.14476376885822712*NM - 
        0.12837000161030251*lm*NM + 0.0990612043935179*NL - 
        0.12837000161030251*lm*NL + 0.18197643722365026*NH - 
        0.12837000161030251*lm*NH)}, 
     {0.635, CF*NC*(0.8689726338486925*CF + CA*(-0.30636219386612806 + 
          0.7062857134184537*lm) + 0.1459238791641129*NM - 
        0.12841558425790067*lm*NM + 0.09991968719746024*NL - 
        0.12841558425790067*lm*NL + 0.18253224224327638*NH - 
        0.12841558425790067*lm*NH)}, 
     {0.64, CF*NC*(0.8700837525732439*CF + CA*(-0.31148849639134624 + 
          0.7065292138999963*lm) + 0.14707885104971308*NM - 
        0.1284598570727266*lm*NM + 0.10077475883340718*NL - 
        0.1284598570727266*lm*NL + 0.18308593912762924*NH - 
        0.1284598570727266*lm*NH)}, 
     {0.645, CF*NC*(0.871172848475911*CF + CA*(-0.31658862863669823 + 
          0.7067657027291638*lm) + 0.14822870896776863*NM - 
        0.12850285504166614*lm*NM + 0.10162642814501738*NL - 
        0.12850285504166614*lm*NL + 0.18363755117707908*NH - 
        0.12850285504166614*lm*NH)}, 
     {0.65, CF*NC*(0.8722401086377322*CF + CA*(-0.3216626470434877 + 
          0.7069953663966381*lm) + 0.14937347793135256*NM - 
        0.128544612072116*lm*NM + 0.10247470468152427*NL - 
        0.128544612072116*lm*NL + 0.1841871012172317*NH - 
        0.128544612072116*lm*NH)}, 
     {0.655, CF*NC*(0.8732857213221786*CF + CA*(-0.3267106154167395 + 
          0.707218385644763*lm) + 0.15051318346655448*NM - 
        0.12858516102632056*lm*NM + 0.10331959865407846*NL - 
        0.12858516102632056*lm*NL + 0.18473461160917135*NH - 
        0.12858516102632056*lm*NH)}, 
     {0.66, CF*NC*(0.8743098758885566*CF + CA*(-0.3317326045187765 + 
          0.7074349356502895*lm) + 0.15164785156765687*NM - 
        0.1286245337545981*lm*NM + 0.10416112089417134*NL - 
        0.1286245337545981*lm*NL + 0.1852801042595158*NH - 
        0.1286245337545981*lm*NH)}, 
     {0.665, CF*NC*(0.8753127627059998*CF + CA*(-0.33672869168043823 + 
          0.7076451862012145*lm) + 0.1527775086546824*NM - 
        0.12866276112749356*lm*NM + 0.10499928281404584*NL - 
        0.12866276112749356*lm*NL + 0.18582360063028483*NH - 
        0.12866276112749356*lm*NH)}, 
     {0.67, CF*NC*(0.8762945730682234*CF + CA*(-0.3416989604292094 + 
          0.7078493018679087*lm) + 0.15390218153319982*NM - 
        0.12869987306689248*lm*NM + 0.10583409636900425*NL - 
        0.12869987306689248*lm*NL + 0.1863651217485837*NH - 
        0.12869987306689248*lm*NH)}, 
     {0.675, CF*NC*(0.8772554991091932*CF + CA*(-0.34664350013355577 + 
          0.7080474421687175*lm) + 0.15502189735627953*NM - 
        0.12873589857613046*lm*NM + 0.10666557402152728*NL - 
        0.12873589857613046*lm*NL + 0.18690468821610295*NH - 
        0.12873589857613046*lm*NH)}, 
     {0.68, CF*NC*(0.8781957337198452*CF + CA*(-0.3515624056627954 + 
          0.7082397617302193*lm) + 0.1561366835884956*NM - 
        0.12877086576913077*lm*NM + 0.10749372870712239*NL - 
        0.12877086576913077*lm*NL + 0.18744232021843682*NH - 
        0.12877086576913077*lm*NH)}, 
     {0.685, CF*NC*(0.8791154704659807*CF + CA*(-0.35645577706186043 + 
          0.7084264104423138*lm) + 0.15724656797187647*NM - 
        0.12880480189860252*lm*NM + 0.10831857380182279*NL - 
        0.12880480189860252*lm*NL + 0.18797803753422146*NH - 
        0.12880480189860252*lm*NH)}, 
     {0.69, CF*NC*(0.8800149035074426*CF + CA*(-0.3613237192403315 + 
          0.7086075336083123*lm) + 0.15835157849370965*NM - 
        0.12883773338332952*lm*NM + 0.10914012309126282*NL - 
        0.12883773338332952*lm*NL + 0.18851185954409555*NH - 
        0.12883773338332952*lm*NH)}, 
     {0.695, CF*NC*(0.8808942275186703*CF + CA*(-0.36616634167515355 + 
          0.7087832720901911*lm) + 0.15945174335611204*NM - 
        0.12886968583458022*lm*NM + 0.10995839074125786*NL - 
        0.12886968583458022*lm*NL + 0.1890438052394846*NH - 
        0.12886968583458022*lm*NH)}, 
     {0.7, CF*NC*(0.8817536376107169*CF + CA*(-0.3709837581264645 + 
          0.7089537624491687*lm) + 0.16054709094727998*NM - 
        0.12890068408166705*lm*NM + 0.11077339126982097*NL - 
        0.12890068408166705*lm*NL + 0.18957389323121188*NH - 
        0.12890068408166705*lm*NH)}, 
     {0.705, CF*NC*(0.8825933292548008*CF + CA*(-0.375776086365994 + 
          0.7091191370817589*lm) + 0.16163764981433842*NM - 
        0.12893075219668343*lm*NM + 0.1115851395205509*NL - 
        0.12893075219668343*lm*NL + 0.19010214175793733*NH - 
        0.12893075219668343*lm*NH)}, 
     {0.71, CF*NC*(0.8834134982074575*CF + CA*(-0.3805434479175105 + 
          0.7092795243514474*lm) + 0.1627234486377112*NM - 
        0.12895991351844496*lm*NM + 0.11239365063732945*NL - 
        0.12895991351844496*lm*NL + 0.19062856869442715*NH - 
        0.12895991351844496*lm*NH)}, 
     {0.715, CF*NC*(0.884214340437342*CF + CA*(-0.38528596780881613 + 
          0.7094350487161373*lm) + 0.1638045162069396*NM - 
        0.12898819067566134*lm*NM + 0.1131989400402689*NL - 
        0.12898819067566134*lm*NL + 0.19115319155965646*NH - 
        0.12898819067566134*lm*NH)}, 
     {0.72, CF*NC*(0.8849960520537309*CF + CA*(-0.39000377433481276 + 
          0.7095858308515*lm) + 0.16488088139787785*NM - 
        0.12901560560936362*lm*NM + 0.1140010234028525*NL - 
        0.12901560560936362*lm*NL + 0.19167602752474655*NH - 
        0.12901560560936362*lm*NH)}, 
     {0.725, CF*NC*(0.8857588292367589*CF + CA*(-0.3946969988311767 + 
          0.709731987770365*lm) + 0.1659525731511996*NM - 
        0.1290421795946118*lm*NM + 0.11479991663021426*NL - 
        0.1290421795946118*lm*NL + 0.1921970934207403*NH - 
        0.1290421795946118*lm*NH)}, 
     {0.73, CF*NC*(0.8865028681694223*CF + CA*(-0.3993657754582052 + 
          0.7098736329382811*lm) + 0.16701962045215069*NM - 
        0.12906793326150565*lm*NM + 0.11559563583850602*NL - 
        0.12906793326150565*lm*NL + 0.19271640574621685*NH - 
        0.12906793326150565*lm*NH)}, 
     {0.735, CF*NC*(0.8872283649713718*CF + CA*(-0.40401024099440996 + 
          0.7100108763853707*lm) + 0.16808205231148793*NM - 
        0.12909288661552196*lm*NM + 0.11638819733530256*NL - 
        0.12909288661552196*lm*NL + 0.193233980674749*NH - 
        0.12909288661552196*lm*NH)}, 
     {0.74, CF*NC*(0.8879355156345146*CF + CA*(-0.40863053463945526 + 
          0.7101438248146007*lm) + 0.16913989774754548*NM - 
        0.1291170590572001*lm*NM + 0.11717761760099756*NL - 
        0.1291170590572001*lm*NL + 0.19374983406220514*NH - 
        0.1291170590572001*lm*NH)}, 
     {0.745, CF*NC*(0.8886245159604348*CF + CA*(-0.4132267978260507 + 
          0.7102725817065851*lm) + 0.17019318576937387*NM - 
        0.1291404694011973*lm*NM + 0.11796391327114518*NL - 
        0.1291404694011973*lm*NL + 0.19426398145389814*NH - 
        0.1291404694011973*lm*NH)}, 
     {0.75, CF*NC*(0.8892955614996433*CF + CA*(-0.41779917404042877 + 
          0.7103972474210354*lm) + 0.17124194536089865*NM - 
        0.1291631358947337*lm*NM + 0.11874710111970446*NL - 
        0.1291631358947337*lm*NL + 0.19477643809158435*NH - 
        0.1291631358947337*lm*NH)}, 
     {0.755, CF*NC*(0.8899488474926567*CF + CA*(-0.4223478086510486 + 
          0.7105179192949638*lm) + 0.1722862054660487*NM - 
        0.12918507623544798*lm*NM + 0.11952719804314516*NL - 
        0.12918507623544798*lm*NL + 0.19528721892031395*NH - 
        0.12918507623544798*lm*NH)}, 
     {0.76, CF*NC*(0.8905845688129056*CF + CA*(-0.42687284874518533 + 
          0.71063469173775*lm) + 0.1733259949748061*NM - 
        0.12920630758868182*lm*NM + 0.1203042210453759*NL - 
        0.12920630758868182*lm*NL + 0.19579633859513648*NH - 
        0.12920630758868182*lm*NH)}, 
     {0.765, CF*NC*(0.8912029199114662*CF + CA*(-0.4313744429730768 + 
          0.7107476563231693*lm) + 0.174361342710132*NM - 
        0.1292268466042126*lm*NM + 0.12107818722345698*NL - 
        0.1292268466042126*lm*NL + 0.19630381148766293*NH - 
        0.1292268466042126*lm*NH)}, 
     {0.77, CF*NC*(0.8918040947636054*CF + CA*(-0.43585274139931246 + 
          0.7108569018784844*lm) + 0.1753922774157252*NM - 
        0.1292467094324517*lm*NM + 0.12184911375406215*NL - 
        0.1292467094324517*lm*NL + 0.1968096516924874*NH - 
        0.1292467094324517*lm*NH)}, 
     {0.775, CF*NC*(0.8923882868171309*CF + CA*(-0.440307895361164 + 
          0.7109625145706944*lm) + 0.17641882774457138*NM - 
        0.12926591174012625*lm*NM + 0.12261701788065478*NL - 
        0.12926591174012625*lm*NL + 0.1973138730334707*NH - 
        0.12926591174012625*lm*NH)}, 
     {0.78, CF*NC*(0.8929556889425261*CF + CA*(-0.4447400573335682 + 
          0.7110645779900338*lm) + 0.17744102224824426*NM - 
        0.12928446872546068*lm*NM + 0.12338191690134603*NL - 
        0.12928446872546068*lm*NL + 0.19781648906988816*NH - 
        0.12928446872546068*lm*NH)}, 
     {0.785, CF*NC*(0.8935064933848574*CF + CA*(-0.44914938080048383 + 
          0.7111631732308121*lm) + 0.17845888936692048*NM - 
        0.12930239513287492*lm*NM + 0.12414382815740357*NL - 
        0.12930239513287492*lm*NL + 0.1983175131024443*NH - 
        0.12930239513287492*lm*NH)}, 
     {0.79, CF*NC*(0.8940408917174327*CF + CA*(-0.4535360201323582 + 
          0.7112583789696788*lm) + 0.17947245742007223*NM - 
        0.1293197052672143*lm*NM + 0.12490276902238086*NL - 
        0.1293197052672143*lm*NL + 0.19881695817915665*NH - 
        0.1293197052672143*lm*NH)}, 
     {0.795, CF*NC*(0.8945590747971869*CF + CA*(-0.4579001304694469 + 
          0.7113502715413976*lm) + 0.18048175459780394*NM - 
        0.12933641300752685*lm*NM + 0.12565875689183867*NL - 
        0.12933641300752685*lm*NL + 0.199314837101111*NH - 
        0.12933641300752685*lm*NH)}, 
     {0.8, CF*NC*(0.8950612327217752*CF + CA*(-0.4622418676107427 + 
          0.7114389250122125*lm) + 0.18148680895279992*NM - 
        0.12935253182040227*lm*NM + 0.12641180917363143*NL - 
        0.12935253182040227*lm*NL + 0.19981116242809105*NH - 
        0.12935253182040227*lm*NH)}, 
     {0.805, CF*NC*(0.895547554788346*CF + CA*(-0.4665613879082793 + 
          0.7115244112508802*lm) + 0.18248764839285211*NM - 
        0.1293680747728873*lm*NM + 0.12716194327873231*NL - 
        0.1293680747728873*lm*NL + 0.20030594648408373*NH - 
        0.1293680747728873*lm*NH)}, 
     {0.81, CF*NC*(0.8960182294539681*CF + CA*(-0.4708588481665838 + 
          0.7116067999974486*lm) + 0.18348430067393826*NM - 
        0.12938305454499066*lm*NM + 0.1279091766125721*NL - 
        0.12938305454499066*lm*NL + 0.20079920136266377*NH - 
        0.12938305454499066*lm*NH)}, 
     {0.815, CF*NC*(0.896473444297684*CF + CA*(-0.47513440554706365 + 
          0.7116861589298512*lm) + 0.18447679339382228*NM - 
        0.12939748344179114*lm*NM + 0.12865352656686824*NL - 
        0.12939748344179114*lm*NL + 0.2012909389322589*NH - 
        0.12939748344179114*lm*NH)}, 
     {0.82, CF*NC*(0.8969133859841609*CF + CA*(-0.4793882174771191 + 
          0.7117625537283894*lm) + 0.18546515398615004*NM - 
        0.1294113734051617*lm*NM + 0.12939501051192118*NL - 
        0.1294113734051617*lm*NL + 0.20178117084129857*NH - 
        0.1294113734051617*lm*NH)}, 
     {0.825, CF*NC*(0.8973382402289096*CF + CA*(-0.4836204415637847 + 
          0.7118360481381705*lm) + 0.18644940971501484*NM - 
        0.12942473602512192*lm*NM + 0.13013364578935604*NL - 
        0.12942473602512192*lm*NL + 0.2022699085232479*NH - 
        0.12942473602512192*lm*NH)}, 
     {0.83, CF*NC*(0.8977481917650403*CF + CA*(-0.48783123551170693 + 
          0.7119067040295679*lm) + 0.18742958766996798*NM - 
        0.12943758255083054*lm*NM + 0.13086944970528955*NL - 
        0.12943758255083054*lm*NL + 0.20275716320152984*NH - 
        0.12943758255083054*lm*NH)}, 
     {0.835, CF*NC*(0.8981434243115242*CF + CA*(-0.49202075704527776 + 
          0.7119745814567673*lm) + 0.18840571476145165*NM - 
        0.12944992390123042*lm*NM + 0.13160243952390133*NL - 
        0.12944992390123042*lm*NL + 0.20324294589433692*NH - 
        0.12944992390123042*lm*NH)}, 
     {0.84, CF*NC*(0.8985241205429308*CF + CA*(-0.4961891638347468 + 
          0.7120397387144595*lm) + 0.1893778177166315*NM - 
        0.12946177067535627*lm*NM + 0.13233263246139165*NL - 
        0.12946177067535627*lm*NL + 0.20372726741933556*NH - 
        0.12946177067535627*lm*NH)}, 
     {0.845, CF*NC*(0.8988904620606063*CF + CA*(-0.5003366134261451 + 
          0.7121022323927413*lm) + 0.19034592307560794*NM - 
        0.1294731331623166*lm*NM + 0.13306004568030685*NL - 
        0.1294731331623166*lm*NL + 0.2042101383982645*NH - 
        0.1294731331623166*lm*NH)}, 
     {0.85, CF*NC*(0.8992426293652614*CF + CA*(-0.5044632631748585 + 
          0.712162117430281*lm) + 0.19131005718798605*NM - 
        0.12948402135096018*lm*NM + 0.13378469628421527*NL - 
        0.12948402135096018*lm*NL + 0.20469156926142973*NH - 
        0.12948402135096018*lm*NH)}, 
     {0.855, CF*NC*(0.899580801830938*CF + CA*(-0.5085692701826968 + 
          0.7122194471658047*lm) + 0.1922702462097851*NM - 
        0.1294944449392372*lm*NM + 0.13450660131271724*NL - 
        0.1294944449392372*lm*NL + 0.20517157025209828*NH - 
        0.1294944449392372*lm*NH)}, 
     {0.86, CF*NC*(0.8999051576803189*CF + CA*(-0.5126547912383094 + 
          0.7122742733879565*lm) + 0.19322651610066907*NM - 
        0.12950441334326482*lm*NM + 0.13522577773677316*NL - 
        0.12950441334326482*lm*NL + 0.20565015143079227*NH - 
        0.12950441334326482*lm*NH)}, 
     {0.865, CF*NC*(0.9002158739613491*CF + CA*(-0.5167199827608043 + 
          0.7123266463835874*lm) + 0.1941788926214812*NM - 
        0.1295139357061068*lm*NM + 0.13594224245433478*NL - 
        0.1295139357061068*lm*NL + 0.20612732267948597*NH - 
        0.1295139357061068*lm*NH)}, 
     {0.87, CF*NC*(0.9005131265251363*CF + CA*(-0.5207650007464375 + 
          0.7123766149845204*lm) + 0.19512740133206555*NM - 
        0.12952302090627643*lm*NM + 0.13665601228626492*NL - 
        0.12952302090627643*lm*NL + 0.20660309370570756*NH - 
        0.12952302090627643*lm*NH)}, 
     {0.875, CF*NC*(0.9007970900050971*CF + CA*(-0.5247900007182358 + 
          0.7124242266128412*lm) + 0.19607206758936027*NM - 
        0.12953167756597112*lm*NM + 0.13736710397253224*NL - 
        0.12953167756597112*lm*NL + 0.20707747404654736*NH - 
        0.12953167756597112*lm*NH)}, 
     {0.88, CF*NC*(0.9010679377973162*CF + CA*(-0.5287951376784332 + 
          0.7124695273247644*lm) + 0.1970129165457473*NM - 
        0.12953991405904808*lm*NM + 0.13807553416866744*NL - 
        0.12953991405904808*lm*NL + 0.207550473072575*NH - 
        0.12953991405904808*lm*NH)}, 
     {0.885, CF*NC*(0.901325842042086*CF + CA*(-0.5327805660635961 + 
          0.7125125618531172*lm) + 0.1979499731476441*NM - 
        0.1295477385187486*lm*NM + 0.13878131944246866*NL - 
        0.1295477385187486*lm*NL + 0.20802209999166688*NH - 
        0.1295477385187486*lm*NH)}, 
     {0.89, CF*NC*(0.9015709736065953*CF + CA*(-0.536746439702324 + 
          0.7125533736484874*lm) + 0.1988832621343242*NM - 
        0.1295551588451795*lm*NM + 0.13948447627094376*NL - 
        0.1295551588451795*lm*NL + 0.20849236385274633*NH - 
        0.1295551588451795*lm*NH)}, 
     {0.895, CF*NC*(0.9018035020687343*CF + CA*(-0.5406929117754135 + 
          0.7125920049190766*lm) + 0.19981280803695314*NM - 
        0.1295621827125594*lm*NM + 0.14018502103747832*NL - 
        0.1295621827125594*lm*NL + 0.20896127354943797*NH - 
        0.1295621827125594*lm*NH)}, 
     {0.9, CF*NC*(0.9020235957019838*CF + CA*(-0.5446201347783789 + 
          0.7126284966693025*lm) + 0.20073863517782783*NM - 
        0.1295688175762368*lm*NM + 0.14088297002921776*NL - 
        0.1295688175762368*lm*NL + 0.20942883782363808*NH - 
        0.1295688175762368*lm*NH)}, 
     {0.905, CF*NC*(0.9022314214613586*CF + CA*(-0.5485282604862293 + 
          0.7126628887371863*lm) + 0.20166076766980726*NM - 
        0.12957507067948842*lm*NM + 0.1415783394346541*NL - 
        0.12957507067948842*lm*NL + 0.20989506526900306*NH - 
        0.12957507067948842*lm*NH)}, 
     {0.91, CF*NC*(0.9024271449703734*CF + CA*(-0.5524174399204006 + 
          0.7126952198305686*lm) + 0.20257922941592388*NM - 
        0.1295809490601034*lm*NM + 0.14227114534140595*NL - 
        0.1295809490601034*lm*NL + 0.21035996433435755*NH - 
        0.1295809490601034*lm*NH)}, 
     {0.915, CF*NC*(0.9026109305089994*CF + CA*(-0.5562878233177521 + 
          0.7127255275621873*lm) + 0.20349404410916438*NM - 
        0.12958645955676132*lm*NM + 0.14296140373418367*NL - 
        0.12958645955676132*lm*NL + 0.21082354332702385*NH - 
        0.12958645955676132*lm*NH)}, 
     {0.92, CF*NC*(0.9027829410025852*CF + CA*(-0.5601395601015351 + 
          0.7127538484836556*lm) + 0.20440523523241036*NM - 
        0.12959160881521012*lm*NM + 0.1436491304929292*NL - 
        0.12959160881521012*lm*NL + 0.2112858104160746*NH - 
        0.12959160881521012*lm*NH)}, 
     {0.925, CF*NC*(0.9029433380117069*CF + CA*(-0.5639727988542473 + 
          0.7127802181183754*lm) + 0.20531282605852877*NM - 
        0.1295964032942501*lm*NM + 0.1443343413911228*NL - 
        0.1295964032942501*lm*NL + 0.21174677363551006*NH - 
        0.1295964032942501*lm*NH)}, 
     {0.93, CF*NC*(0.9030922817229242*CF + CA*(-0.5677876872922913 + 
          0.7128046709934183*lm) + 0.2062168396506033*NM - 
        0.1296008492715306*lm*NM + 0.14501705209424753*NL - 
        0.1296008492715306*lm*NL + 0.212206440887362*NH - 
        0.1296008492715306*lm*NH)}, 
     {0.935, CF*NC*(0.9032299309404085*CF + CA*(-0.5715843722423557 + 
          0.7128272406704087*lm) + 0.20711729886229796*NM - 
        0.1296049528491652*lm*NM + 0.14569727815840444*NL - 
        0.1296049528491652*lm*NL + 0.21266481994472547*NH - 
        0.1296049528491652*lm*NH)}, 
     {0.94, CF*NC*(0.9033564430784181*CF + CA*(-0.5753629996194436 + 
          0.71284795977544*lm) + 0.2080142263383444*NM - 
        0.12960871995917092*lm*NM + 0.1463750350290699*NL - 
        0.12960871995917092*lm*NL + 0.21312191845472017*NH - 
        0.12960871995917092*lm*NH)}, 
     {0.945, CF*NC*(0.9034719741545921*CF + CA*(-0.5791237144064753 + 
          0.7128668600280549*lm) + 0.20890764451514524*NM - 
        0.12961215636873724*lm*NM + 0.14705033803998827*NL - 
        0.12961215636873724*lm*NL + 0.21357774394138315*NH - 
        0.12961215636873724*lm*NH)}, 
     {0.95, CF*NC*(0.9035766787840351*CF + CA*(-0.5828666606353935 + 
          0.7128839722693175*lm) + 0.20979757562148593*NM - 
        0.12961526768533047*lm*NM + 0.1477232024121931*NL - 
        0.12961526768533047*lm*NL + 0.2140323038084939*NH - 
        0.12961526768533047*lm*NH)}, 
     {0.955, CF*NC*(0.9036707101741664*CF + CA*(-0.586591981369706 + 
          0.7128993264890104*lm) + 0.21068404167934804*NM - 
        0.12961805936163825*lm*NM + 0.14839364325314988*NL - 
        0.12961805936163825*lm*NL + 0.21448560534233366*NH - 
        0.12961805936163825*lm*NH)}, 
     {0.96, CF*NC*(0.903754220120308*CF + CA*(-0.5902998186883984 + 
          0.7129129518519796*lm) + 0.2115670645048171*NM - 
        0.12962053670035992*lm*NM + 0.149061675556014*NL - 
        0.12962053670035992*lm*NL + 0.21493765571438067*NH - 
        0.12962053670035992*lm*NH)}, 
     {0.965, CF*NC*(0.9038273590019861*CF + CA*(-0.5939903136711567 + 
          0.7129248767236566*lm) + 0.21244666570907866*NM - 
        0.12962270485884667*lm*NM + 0.1497273141989983*NL - 
        0.12962270485884667*lm*NL + 0.21538846198394193*NH - 
        0.12962270485884667*lm*NH)}, 
     {0.97, CF*NC*(0.9038902757799189*CF + CA*(-0.5976636063848401 + 
          0.7129351286947846*lm) + 0.21332286669949657*NM - 
        0.1296245688535972*lm*NM + 0.15039057394484392*NL - 
        0.1296245688535972*lm*NL + 0.21583803110072386*NH - 
        0.1296245688535972*lm*NH)}, 
     {0.975, CF*NC*(0.9039431179936703*CF + CA*(-0.6013198358711452 + 
          0.7129437346053716*lm) + 0.21419568868076744*NM - 
        0.12962613356461303*lm*NM + 0.15105146944038927*NL - 
        0.12962613356461303*lm*NL + 0.2162863699073424*NH - 
        0.12962613356461303*lm*NH)}, 
     {0.98, CF*NC*(0.9039860317599412*CF + CA*(-0.6049591401354101 + 
          0.7129507205678963*lm) + 0.21506515265614592*NM - 
        0.1296274037396175*lm*NM + 0.15171001521623154*NL - 
        0.1296274037396175*lm*NL + 0.21673348514177465*NH - 
        0.1296274037396175*lm*NH)}, 
     {0.985, CF*NC*(0.9040191617714778*CF + CA*(-0.6085816561365016 + 
          0.7129561119897904*lm) + 0.21593127942873577*NM - 
        0.1296283839981437*lm*NM + 0.1523662256864761*NL - 
        0.1296283839981437*lm*NL + 0.21717938343975277*NH - 
        0.1296283839981437*lm*NH)}, 
     {0.99, CF*NC*(0.9040426512965732*CF + CA*(-0.6121875197777401 + 
          0.712959933595219*lm) + 0.2167940896028414*NM - 
        0.12962907883549438*lm*NM + 0.15302011514856875*NL - 
        0.12962907883549438*lm*NL + 0.21762407133710154*NH - 
        0.12962907883549438*lm*NH)}, 
     {0.995, CF*NC*(0.9040566421791407*CF + CA*(-0.6157768658988084 + 
          0.712962209446183*lm) + 0.2176536035853754*NM - 
        0.12962949262657875*lm*NM + 0.1536716977832063*NL - 
        0.12962949262657875*lm*NL + 0.21806755527202143*NH - 
        0.12962949262657875*lm*NH)}, {1., 0.00019290123456790122*CF*NC*
       (4686.653648767114*CF + CA*(-3210.709509744441 + 3696.*lm) + 
        1132.7550187886534*NM - 672.*lm*NM + 800.*NL - 672.*lm*NL + 
        1132.7550187886534*NH - 672.*lm*NH)}}
 
CbarLTable["a", 2, 1] = {{0., -1.6075102880658437*^-7*CF*NC*
       (15.*CA*(-29093.002395114298 + 3898.992508165458*lm + 15840.*lm^2) + 
        2.*(CF*(-609746.3369659903 + 167166.91012706028*lm - 194400.*lm^2) + 
          60.*((-625.7551981765639 + 369.5683520871487*lm - 360.*lm^2)*NM + 
            (-625.7551981765639 + 369.5683520871487*lm - 360.*lm^2)*NL + 
            (-294.90179009708874 + 369.5683520871487*lm - 360.*lm^2)*NH)))}, 
     {0.005, CF*NC*(CA*(0.0797733677072757 - 0.007703283534154451*lm - 
          0.03895452419462652*lm^2) + CF*(0.20694183478533326 - 
          0.05789909635422005*lm + 0.0637437668639343*lm^2) + 
        0.011103446058569414*NM - 0.007613673055356567*lm*NM + 
        0.0070826407626593665*lm^2*NM + 0.011101154964571995*NL - 
        0.007613673055356567*lm*NL + 0.0070826407626593665*lm^2*NL + 
        0.00581265734014271*NH - 0.007613673055356567*lm*NH + 
        0.0070826407626593665*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(0.08885768684430924 - 0.006083698954388055*lm - 
          0.039704488361370756*lm^2) + CF*(0.21720455546571327 - 
          0.06190669882786249*lm + 0.06497098095497034*lm^2) + 
        0.010216931892715081*NM - 0.008081688405965654*lm*NM + 
        0.007218997883885592*lm^2*NM + 0.01020516995744759*NL - 
        0.008081688405965654*lm*NL + 0.007218997883885592*lm^2*NL + 
        0.005935244043248088*NH - 0.008081688405965654*lm*NH + 
        0.007218997883885592*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(0.09729795817531824 - 0.004565169366534574*lm - 
          0.04044168048759607*lm^2) + CF*(0.22675231095129847 - 
          0.06572582224966689*lm + 0.06617729534333902*lm^2) + 
        0.009426484964858138*NM - 0.008528374608172969*lm*NM + 
        0.007353032815926558*lm^2*NM + 0.00939633484235553*NL - 
        0.008528374608172969*lm*NL + 0.007353032815926558*lm^2*NL + 
        0.006055986816248885*NH - 0.008528374608172969*lm*NH + 
        0.007353032815926558*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(0.10506351558679418 - 0.003156916370158309*lm - 
          0.041164210457080276*lm^2) + CF*(0.23560189748920252 - 
          0.06933795577528293*lm + 0.0673596171115859*lm^2) + 
        0.008734972340757097*NM - 0.00895161762524599*lm*NM + 
        0.0074844019012873225*lm^2*NM + 0.008677105215588253*NL - 
        0.00895161762524599*lm*NL + 0.0074844019012873225*lm^2*NL + 
        0.00617457194164724*NH - 0.00895161762524599*lm*NH + 
        0.0074844019012873225*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(0.1121538926307974 - 0.0018621220937387727*lm - 
          0.04187065384320708*lm^2) + CF*(0.2437950161123299 - 
          0.07273531419092623*lm + 0.06851561537979341*lm^2) + 
        0.008140534685264156*NM - 0.009350509268987978*lm*NM + 
        0.007612846153310379*lm^2*NM + 0.008045859761065892*NL - 
        0.009350509268987978*lm*NL + 0.007612846153310379*lm^2*NL + 
        0.006290777739782159*NH - 0.009350509268987978*lm*NH + 
        0.007612846153310379*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(0.1185840810870643 - 0.0006805452235330892*lm - 
          0.042559917574704585*lm^2) + CF*(0.25138138122853537 - 
          0.0759163140049649*lm + 0.06964350148588024*lm^2) + 
        0.007639026065388301*NM - 0.009724840472512401*lm*NM + 
        0.00773816683176447*lm^2*NM + 0.0074990504913308095*NL - 
        0.009724840472512401*lm*NL + 0.00773816683176447*lm^2*NL + 
        0.006404447634867279*NH - 0.009724840472512401*lm*NH + 
        0.00773816683176447*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(0.1243776163745317 + 0.00039015503778488426*lm - 
          0.04323116098925165*lm^2) + CF*(0.2584120868717278 - 
          0.0788832640836985*lm + 0.0707418998005936*lm^2) + 
        0.007225143116872967*NM - 0.010074842301903418*lm*NM + 
        0.007860211088954846*lm^2*NM + 0.007032173733994124*NL - 
        0.010074842301903418*lm*NL + 0.007860211088954846*lm^2*NL + 
        0.006515474133159321*NH - 0.010074842301903418*lm*NH + 
        0.007860211088954846*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(0.12956280784735866 + 0.001353648426992949*lm - 
          0.04388374331990798*lm^2) + CF*(0.26493666163463897 - 
          0.08164100971573926*lm + 0.07180976179621305*lm^2) + 
        0.006893029217429108*NM - 0.010401033705382383*lm*NM + 
        0.007978862421801451*lm^2*NM + 0.0066402787910196945*NL - 
        0.010401033705382383*lm*NL + 0.007978862421801451*lm^2*NL + 
        0.006623788052148599*NH - 0.010401033705382383*lm*NH + 
        0.007978862421801451*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(0.13417050147421264 + 0.0022144475099177925*lm - 
          0.044517186090401804*lm^2) + CF*(0.2710017296235493 - 
          0.08419606909720428*lm + 0.0728463045115666*lm^2) + 
        0.006636623982946956*NM - 0.010704124427681339*lm*NM + 
        0.00809403383461851*lm^2*NM + 0.006318256690874716*NL - 
        0.010704124427681339*lm*NL + 0.00809403383461851*lm^2*NL + 
        0.006729350740398329*NH - 0.010704124427681339*lm*NH + 
        0.00809403383461851*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(0.1382326808868306 + 0.002977584826179298*lm - 
          0.04513114483236341*lm^2) + CF*(0.2766504486320452 - 
          0.08655605383364535*lm + 0.07385096427114013*lm^2) + 
        0.006449874336112291*NM - 0.010984949764315043*lm*NM + 
        0.008205662696793348*lm^2*NM + 0.006061011589580906*NL - 
        0.010984949764315043*lm*NL + 0.008205662696793348*lm^2*NL + 
        0.0068321481875716844*NH - 0.010984949764315043*lm*NH + 
        0.008205662696793348*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(0.1417815642295347 + 0.0036483910095109367*lm - 
          0.04572538705959294*lm^2) + CF*(0.28192234769070806 - 
          0.08872926599945472*lm + 0.07482336064297027*lm^2) + 
        0.00632686446111723*NM - 0.011244425122957381*lm*NM + 
        0.008313706738107808*lm^2*NM + 0.00586356458565066*NL - 
        0.011244425122957381*lm*NL + 0.008313706738107808*lm^2*NL + 
        0.006932186417721155*NH - 0.011244425122957381*lm*NH + 
        0.008313706738107808*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(0.14484901094869448 + 0.004232338814566713*lm - 
          0.046299774666137924*lm^2) + CF*(0.28685337549022605 - 
          0.09072441105097864*lm + 0.07576326763549843*lm^2) + 
        0.006261895679811524*NM - 0.011483513591506856*lm*NM + 
        0.008418140848388714*lm^2*NM + 0.005721116482225855*NL - 
        0.011483513591506856*lm*NL + 0.008418140848388714*lm^2*NL + 
        0.007029487800449976*NH - 0.011483513591506856*lm*NH + 
        0.008418140848388714*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(0.147466130421351 + 0.004734931925444474*lm - 
          0.04685424957866419*lm^2) + CF*(0.29147605960020134 - 
          0.09255038990880547*lm + 0.07667059021963231*lm^2) + 
        0.006249534245426568*NM - 0.011703202401341947*lm*NM + 
        0.008518954468848034*lm^2*NM + 0.005629084651404151*NL - 
        0.011703202401341947*lm*NL + 0.008518954468848034*lm^2*NL + 
        0.007124088045055236*NH - 0.011703202401341947*lm*NH + 
        0.008518954468848034*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(0.14966302610971705 + 0.005161625143166953*lm - 
          0.04738882187868064*lm^2) + CF*(0.2958197210354233 - 
          0.0942161468576704*lm + 0.0775453448923865*lm^2) + 
        0.0062846380445967616*NM - 0.011904485667377942*lm*NM + 
        0.00861614943248739*lm^2*NM + 0.0055831231213857024*NL - 
        0.011904485667377942*lm*NL + 0.00861614943248739*lm^2*NL + 
        0.007216033718729181*NH - 0.011904485667377942*lm*NH + 
        0.00861614943248739*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(0.15146863282028686 + 0.005517767092080168*lm - 
          0.04790355984691217*lm^2) + CF*(0.2999107126037715 - 
          0.09573055777442677*lm + 0.07838764338585628*lm^2) + 
        0.006362369195642651*NM - 0.01208835166726698*lm*NM + 
        0.008709738153984032*lm^2*NM + 0.00557913160334422*NL - 
        0.01208835166726698*lm*NL + 0.008709738153984032*lm^2*NL + 
        0.007305380176788716*NH - 0.01208835166726698*lm*NH + 
        0.008709738153984032*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(0.1529106190016708 + 0.005808559390460488*lm - 
          0.04839858153461773*lm^2) + CF*(0.30377266283455817 - 
          0.0971023480610947*lm + 0.07919767887482901*lm^2) + 
        0.006478197128983764*NM - 0.012255773467433282*lm*NM + 
        0.008799742097203224*lm^2*NM + 0.0056132571583040304*NL - 
        0.012255773467433282*lm*NL + 0.008799742097203224*lm^2*NL + 
        0.007392189823260081*NH - 0.012255773467433282*lm*NH + 
        0.008799742097203224*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(0.1540153349981851 + 0.006039028033480813*lm - 
          0.04887404756876261*lm^2) + CF*(0.3074267150242868 - 
          0.09834003279494391*lm + 0.07997571420342973*lm^2) + 
        0.0066278952353935605*NM - 0.012407702055057281*lm*NM + 
        0.008886190467047748*lm^2*NM + 0.005681890960749233*NL - 
        0.012407702055057281*lm*NL + 0.008886190467047748*lm^2*NL + 
        0.007476530640589092*NH - 0.012407702055057281*lm*NH + 
        0.008886190467047748*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(0.15480779399050246 + 0.006214003934509432*lm - 
          0.04933015496858391*lm^2) + CF*(0.310891755531808 - 
          0.09945187369547721*lm + 0.08072207176677366*lm^2) + 
        0.0068075331996247405*NM - 0.012545061369252536*lm*NM + 
        0.008969119085197074*lm^2*NM + 0.005781661823092832*NL - 
        0.012545061369252536*lm*NL + 0.008969119085197074*lm^2*NL + 
        0.007558474941481453*NH - 0.012545061369252536*lm*NH + 
        0.008969119085197074*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(0.15531167622667924 + 0.006338110389279944*lm - 
          0.04976713180131758*lm^2) + CF*(0.3141846282310513 - 
          0.10044584893856182*lm + 0.08143712476579242*lm^2) + 
        0.007013466494736544*NM - 0.012668744785132654*lm*NM + 
        0.009048569418421379*lm^2*NM + 0.00590942762583949*NL - 
        0.012668744785132654*lm*NL + 0.009048569418421379*lm^2*NL + 
        0.00763809830607591*NH - 0.012668744785132654*lm*NH + 
        0.009048569418421379*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(0.15554934978861804 + 0.006415755800490953*lm - 
          0.050185232541443525*lm^2) + CF*(0.31732033372274576 - 
          0.10132963285184579*lm + 0.08212128961327123*lm^2) + 
        0.007242324076602805*NM - 0.012779612717117517*lm*NM + 
        0.009124587734807912*lm^2*NM + 0.0060622654500752556*NL - 
        0.012779612717117517*lm*NL + 0.009124587734807912*lm^2*NL + 
        0.007715478675142611*NH - 0.012779612717117517*lm*NH + 
        0.009124587734807912*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(0.15554190297914686 + 0.006451130409940027*lm - 
          0.05058473402501934*lm^2) + CF*(0.3203122129399595 - 
          0.10211058324501951*lm + 0.08277501931366801*lm^2) + 
        0.007490995016514371*NM - 0.012878491088588613*lm*NM + 
        0.009197224368185335*lm^2*NM + 0.006237460970843742*NL - 
        0.012878491088588613*lm*NL + 0.009197224368185335*lm^2*NL + 
        0.0077906955756198056*NH - 0.012878491088588613*lm*NH + 
        0.009197224368185335*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(0.15530918471970534 + 0.006448206083325187*lm - 
          0.050965931911292325*lm^2) + CF*(0.32317211540643237 - 
          0.10279573465348268*lm + 0.0833987976730238*lm^2) + 
        0.007756614597736481*NM - 0.01296617047396148*lm*NM + 
        0.009266533074780422*lm^2*NM + 0.00643249750450046*NL - 
        0.01296617047396148*lm*NL + 0.009266533074780422*lm^2*NL + 
        0.007863829459101144*NH - 0.01296617047396148*lm*NH + 
        0.009266533074780422*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(0.1548698502881903 + 0.006410738413158768*lm - 
          0.05132913757965655*lm^2) + CF*(0.3259105527735689 - 
          0.10339179616322497*lm + 0.08399313422125618*lm^2) + 
        0.008036550250747522*NM - 0.013043405762974185*lm*NM + 
        0.009332570469028464*lm^2*NM + 0.006645044986547502*NL - 
        0.013043405762974185*lm*NL + 0.009332570469028464*lm^2*NL + 
        0.007934961137229907*NH - 0.013043405762974185*lm*NH + 
        0.009332570469028464*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(0.15424141041209924 + 0.006342270570354535*lm - 
          0.05167467540242822*lm^2) + CF*(0.32853683846580084 - 
          0.10390515277737172*lm + 0.084558559749428*lm^2) + 
        0.008328387592967806*NM - 0.013110916229882561*lm*NM + 
        0.009395395527714222*lm^2*NM + 0.0068729490733703035*NL - 
        0.013110916229882561*lm*NL + 0.009395395527714222*lm^2*NL + 
        0.008004171300596823*NH - 0.013110916229882561*lm*NH + 
        0.009395395527714222*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(0.15344028223811293 + 0.006246138460300144*lm - 
          0.0520028803437326*lm^2) + CF*(0.33105921436418817 - 
          0.10434186950757741*lm + 0.08509562238065334*lm^2) + 
        0.00862991675959068*NM - 0.013169385915298478*lm*NM + 
        0.009455069153405927*lm^2*NM + 0.007114220501558563*NL - 
        0.013169385915298478*lm*NL + 0.009455069153405927*lm^2*NL + 
        0.008071540109850691*NH - 0.013169385915298478*lm*NH + 
        0.009455069153405927*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(0.15248184107637686 + 0.006125476835250687*lm - 
          0.05231409584266093*lm^2) + CF*(0.33348496549256845 - 
          0.10470769754481306*lm + 0.08560488410617244*lm^2) + 
        0.008939119154147072*NM - 0.013219464247686125*lm*NM + 
        0.009511653789574715*lm^2*NM + 0.0073670247952397905*NL - 
        0.013219464247686125*lm*NL + 0.009511653789574715*lm^2*NL + 
        0.008137146849441588*NH - 0.013219464247686125*lm*NH + 
        0.009511653789574715*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(0.15138047210112854 + 0.005983226089183882*lm - 
          0.05260867194522187*lm^2) + CF*(0.3358205236638252 - 
          0.10500808199720658*lm + 0.08608691772854488*lm^2) + 
        0.009254154704779709*NM - 0.013261766846514526*lm*NM + 
        0.00956521308094943*lm^2*NM + 0.0076296723803869135*NL - 
        0.013261766846514526*lm*NL + 0.00956521308094943*lm^2*NL + 
        0.008201069635816259*NH - 0.013261766846514526*lm*NH + 
        0.00956521308094943*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(0.1501496214037353 + 0.005822139519226998*lm - 
          0.052886963654814025*lm^2) + CF*(0.33807156101191005 - 
          0.10524817078686956*lm + 0.08654230416242295*lm^2) + 
        0.009573349680736443*NM - 0.013296876460808155*lm*NM + 
        0.00961581157360255*lm^2*NM + 0.007900609142110123*NL - 
        0.013296876460808155*lm*NL + 0.00961581157360255*lm^2*NL + 
        0.008263385173041845*NH - 0.013296876460808155*lm*NH + 
        0.00961581157360255*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(0.14880184595733764 + 0.005644790883314299*lm - 
          0.05314932947523524*lm^2) + CF*(0.3402430742885909 - 
          0.10543282437994007*lm + 0.08697163005038494*lm^2) + 
        0.009895185100366017*NM - 0.013325344006111581*lm*NM + 
        0.009663514450042772*lm^2*NM + 0.008178407444200949*NL - 
        0.013325344006111581*lm*NL + 0.009663514450042772*lm^2*NL + 
        0.0083241685497978*NH - 0.013325344006111581*lm*NH + 
        0.009663514450042772*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(0.14734886217692542 + 0.005453582119745119*lm - 
          0.05339613012380717*lm^2) + CF*(0.34233946074935323 - 
          0.10556662608944879*lm + 0.08737548565713901*lm^2) + 
        0.010218285744789498*NM - 0.013347689670256145*lm*NM + 
        0.009708387295237668*lm^2*NM + 0.008461757618016038*NL - 
        0.013347689670256145*lm*NL + 0.009708387295237668*lm^2*NL + 
        0.008383493072485194*NH - 0.013347689670256145*lm*NH + 
        0.009708387295237668*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(0.14580159285417643 + 0.005250751122935209*lm - 
          0.05362772739517654*lm^2) + CF*(0.34436458639493484 - 
          0.10565389274284986*lm + 0.08775446301028889*lm^2) + 
        0.0105414097788786*NM - 0.01336440406421089*lm*NM + 
        0.009750495890032098*lm^2*NM + 0.008749459918980785*NL - 
        0.01336440406421089*lm*NL + 0.009750495890032098*lm^2*NL + 
        0.008441430129886908*NH - 0.01336440406421089*lm*NH + 
        0.009750495890032098*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(0.1441702123196755 + 0.005038379492506369*lm - 
          0.053844483158867265*lm^2) + CF*(0.3463218472764998 - 
          0.10569868554800159*lm + 0.08810915425996461*lm^2) + 
        0.010863438972058942*NM - 0.013375949399036559*lm*NM + 
        0.009789906028884958*lm^2*NM + 0.009040416942692257*NL - 
        0.013375949399036559*lm*NL + 0.009789906028884958*lm^2*NL + 
        0.008498049085394414*NH - 0.013375949399036559*lm*NH + 
        0.009789906028884958*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(0.1424641897413816 + 0.004818400191173085*lm - 
          0.05404675847578773*lm^2) + CF*(0.34821422451529266 - 
          0.10570482102520483*lm + 0.0884401502331072*lm^2) + 
        0.011183369504926533*NM - 0.013382760673784003*lm*NM + 
        0.009826683359234133*lm^2*NM + 0.009333626488170224*NL - 
        0.013382760673784003*lm*NL + 0.009826683359234133*lm^2*NL + 
        0.00855341719331515*NH - 0.013382760673784003*lm*NH + 
        0.009826683359234133*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(0.14069233051131397 + 0.004592605061604769*lm - 
          0.054234912820713244*lm^2) + CF*(0.35004433363286697 - 
          0.10567588190028053*lm + 0.08874803916116712*lm^2) + 
        0.011500303343086483*NM - 0.013385246862275007*lm*NM + 
        0.00986089324012968*lm^2*NM + 0.009628174852772514*NL - 
        0.013385246862275007*lm*NL + 0.00986089324012968*lm^2*NL + 
        0.008607599536202845*NH - 0.013385246862275007*lm*NH + 
        0.00986089324012968*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(0.13886281570534076 + 0.004362652164300307*lm - 
          0.054409303399319854*lm^2) + CF*(0.35181446873629496 - 
          0.1056152278758885*lm + 0.0890334055625234*lm^2) + 
        0.011813440156515715*NM - 0.013383792089219526*lm*NM + 
        0.009892600618058155*lm^2*NM + 0.009923230541304838*NL - 
        0.013383792089219526*lm*NL + 0.009892600618058155*lm^2*NL + 
        0.008660658980523345*NH - 0.013383792089219526*lm*NH + 
        0.009892600618058155*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(0.13698323962594305 + 0.004130072908078215*lm - 
          0.054570284549684926*lm^2) + CF*(0.35352664205446216 - 
          0.10552600621636764*lm + 0.08929682926312078*lm^2) + 
        0.012122069760751*NM - 0.013378756788172715*lm*NM + 
        0.009921869918124531*lm^2*NM + 0.010218038370651609*NL - 
        0.013378756788172715*lm*NL + 0.009921869918124531*lm^2*NL + 
        0.008712656148289526*NH - 0.013378756788172715*lm*NH + 
        0.009921869918124531*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(0.13506064545663268 + 0.003896278952509231*lm - 
          0.054718207219328345*lm^2) + CF*(0.35518261927672534 - 
          0.10541116209611351*lm + 0.08953888454071911*lm^2) + 
        0.01242556505502401*NM - 0.013370478835507411*lm*NM + 
        0.00994876494896879*lm^2*NM + 0.010511913950634076*NL - 
        0.013370478835507411*lm*NL + 0.00994876494896879*lm^2*NL + 
        0.008763649402578488*NH - 0.013370478835507411*lm*NH + 
        0.00994876494896879*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(0.13310155907068633 + 0.0036625688678529477*lm - 
          0.05485341850987389*lm^2) + CF*(0.3567839511038349 - 
          0.10527344867353111*lm + 0.08976013937979363*lm^2) + 
        0.012723375431874372*NM - 0.01335927465594408*lm*NM + 
        0.00997334881997707*lm^2*NM + 0.010804238521614917*NL - 
        0.01335927465594408*lm*NL + 0.00997334881997707*lm^2*NL + 
        0.008813694845088378*NH - 0.01335927465594408*lm*NH + 
        0.00997334881997707*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(0.1311120210470866 + 0.00343013454308785*lm - 
          0.05497626128228656*lm^2) + CF*(0.3583320013829332 - 
          0.10511543686241447*lm + 0.08996115482555982*lm^2) + 
        0.013015020632564921*NM - 0.01334544029629716*lm*NM + 
        0.009995683869506647*lm^2*NM + 0.01109445412949957*NL - 
        0.01334544029629716*lm*NL + 0.009995683869506647*lm^2*NL + 
        0.008862846324106199*NH - 0.01334544029629716*lm*NH + 
        0.009995683869506647*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(0.12909761693597627 + 0.0032000673366703717*lm - 
          0.05508707381640835*lm^2) + CF^2*(0.3598279721992419 - 
          0.10493952478061291*lm + 0.09014248442685002*lm^2) + 
        CF*((0.013300085065107981 - 0.013329252465009768*lm + 
            0.010015831602983336*lm^2)*NM + (0.011382059119147147 - 
            0.013329252465009768*lm + 0.010015831602983336*lm^2)*NL + 
          (0.008911155451445989 - 0.013329252465009768*lm + 
            0.010015831602983336*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(0.127063505922461 + 0.002973363967904308*lm - 
          0.05518618951918716*lm^2) + CF^2*(0.36127292606197786 - 
          0.10474794686237224*lm + 0.09030467375866989*lm^2) + 
        CF*((0.013578212360419974 - 0.013310969535794507*lm + 
            0.01003385263985221*lm^2)*NM + (0.011666603927731247 - 
            0.013310969535794507*lm + 0.01003385263985221*lm^2)*NL + 
          (0.008958671627082242 - 0.013310969535794507*lm + 
            0.01003385263985221*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(0.12501444777937967 + 0.0027509321493934874*lm - 
          0.055273936676585436*lm^2) + CF^2*(0.3626678058156293 - 
          0.10454278262605059*lm + 0.09044826001623071*lm^2) + 
        CF*((0.013849100564997378 - 0.013290832514306189*lm + 
            0.01004980666847008*lm^2)*NM + (0.011947687160232744 - 
            0.013290832514306189*lm + 0.01004980666847008*lm^2)*NL + 
          (0.009005442070349676 - 0.013290832514306189*lm + 
            0.01004980666847008*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(0.1229548283837829 + 0.0025335959631064995*lm - 
          0.055350638244677196*lm^2) + CF^2*(0.36401345211639474 - 
          0.10432596509321812*lm + 0.09057377167310814*lm^2) + 
        CF*((0.014112497457711143 - 0.01326906596726698*lm + 
            0.010063752408123126*lm^2)*NM + (0.012224951929964036 - 
            0.01326906596726698*lm + 0.010063752408123126*lm^2)*NL + 
          (0.009051511856709606 - 0.01326906596726698*lm + 
            0.010063752408123126*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(0.12088868373045966 + 0.0023221009841991125*lm - 
          0.05541661167590416*lm^2) + CF^2*(0.3653106189734994 - 
          0.10409928885863169*lm + 0.09068172819693407*lm^2) + 
        CF*((0.014368196294661217 - 0.013245878913865262*lm + 
            0.010075747577437118*lm^2)*NM + (0.012498082447788104 - 
            0.013245878913865262*lm + 0.010075747577437118*lm^2)*NL + 
          (0.009096923959197735 - 0.013245878913865262*lm + 
            0.010075747577437118*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(0.11881972256121456 + 0.0021171191579965206*lm - 
          0.05547216877687119*lm^2) + CF^2*(0.3665599874619875 - 
          0.10386441781337274*lm + 0.09077263981669831*lm^2) + 
        CF*((0.014616031843924045 - 0.013221465679572865*lm + 
            0.010085848868522033*lm^2)*NM + (0.012766800844483572 - 
            0.013221465679572865*lm + 0.010085848868522033*lm^2)*NL + 
          (0.009141719293769468 - 0.013221465679572865*lm + 
            0.010085848868522033*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(0.11675134767101347 + 0.0019192534364984807*lm - 
          0.055517615594425765*lm^2) + CF^2*(0.36776217780708004 - 
          0.10362289252566895*lm + 0.09084700733633307*lm^2) + 
        CF*((0.01485587670815019 - 0.013196006712784198*lm + 
            0.01009411192625923*lm^2)*NM + (0.013030864211502326 - 
            0.013196006712784198*lm + 0.01009411192625923*lm^2)*NL + 
          (0.009185936767850102 - 0.013196006712784198*lm + 
            0.01009411192625923*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(0.11468667595802909 + 0.0017290421814886536*lm - 
          0.055553252327090075*lm^2) + CF^2*(0.3689177600075433 - 
          0.10337613728568165*lm + 0.09090532198978375*lm^2) + 
        CF*((0.015087637916281605 - 0.01316966936488655*lm + 
            0.010100591332198195*lm^2)*NM + (0.01329006184615655 - 
            0.01316966936488655*lm + 0.010100591332198195*lm^2)*NL + 
          (0.009229613331475392 - 0.01316966936488655*lm + 
            0.010100591332198195*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(0.11262855728287453 + 0.0015469633418489371*lm - 
          0.055579373259204194*lm^2) + CF^2*(0.37002726314912693 - 
          0.10312546682191577*lm + 0.09094806533324323*lm^2) + 
        CF*((0.01531125376652631 - 0.013142608634532182*lm + 
            0.010105340592582581*lm^2)*NM + (0.013544212688048032 - 
            0.013142608634532182*lm + 0.010105340592582581*lm^2)*NL + 
          (0.009272784030482201 - 0.013142608634532182*lm + 
            0.010105340592582581*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(0.1105795922000676 + 0.0013734384130362268*lm - 
          0.0555962667153974*lm^2) + CF^2*(0.37109118354475645 - 
          0.10287209269796035*lm + 0.09097570917065029*lm^2) + 
        CF*((0.015526690903934628 - 0.013114967877007638*lm + 
            0.010108412130072254*lm^2)*NM + (0.013793162934307771 - 
            0.013114967877007638*lm + 0.010108412130072254*lm^2)*NL + 
          (0.009315482061270416 - 0.013114967877007638*lm + 
            0.010108412130072254*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(0.10854214862258316 + 0.0012088361869028387*lm - 
          0.055604215033236384*lm^2) + CF^2*(0.37210999182468624 - 
          0.10261712939905397*lm + 0.09098871550893227*lm^2) + 
        CF*((0.01573394161673464 - 0.013086879479689928*lm + 
            0.010109857278770252*lm^2)*NM + (0.01403678382194357 - 
            0.013086879479689928*lm + 0.010109857278770252*lm^2)*NL + 
          (0.009357738826715202 - 0.013086879479689928*lm + 
            0.010109857278770252*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(0.10651837747788315 + 0.001053476300157414*lm - 
          0.05560349455210724*lm^2) + CF^2*(0.3730841390879335 - 
          0.10236160011853433*lm + 0.09098753653981184*lm^2) + 
        CF*((0.015933021336607987 - 0.013058465504648478*lm + 
            0.010109726282201317*lm^2)*NM + (0.014274969566294168 - 
            0.013058465504648478*lm + 0.010109726282201317*lm^2)*NL + 
          (0.009399583992859097 - 0.013058465504648478*lm + 
            0.010109726282201317*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(0.1045102274113461 + 0.0009076325897910776*lm - 
          0.05559437561657455*lm^2) + CF^2*(0.37401406221543326 - 
          0.10210644225461538*lm + 0.09097261464530382*lm^2) + 
        CF*((0.016123966328969144 - 0.013029838299499927*lm + 
            0.010108068293922646*lm^2)*NM + (0.014507635445258831 - 
            0.013029838299499927*lm + 0.010108068293922646*lm^2)*NL + 
          (0.009441045546058693 - 0.013029838299499927*lm + 
            0.010108068293922646*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(0.10251945859049433 + 0.0007715362637509374*lm - 
          0.055577122592629175*lm^2) + CF^2*(0.3749001884355685 - 
          0.10185251262816922*lm + 0.09094438242430229*lm^2) + 
        CF*((0.016306831560179928 - 0.01300110107765403*lm + 
            0.010104931380478032*lm^2)*NM + (0.014734716019609746 - 
            0.01300110107765403*lm + 0.010104931380478032*lm^2)*NL + 
          (0.00948214985030111 - 0.01300110107765403*lm + 
            0.010104931380478032*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(0.10054765566089956 + 0.0006453788950438243*lm - 
          0.05555199389538741*lm^2) + CF^2*(0.37574293922387325 - 
          0.10160059243230182*lm + 0.09090326273790666*lm^2) + 
        CF*((0.01648168872944227 - 0.01297234846910588*lm + 
            0.010100362526434075*lm^2)*NM + (0.014956163480301009 - 
            0.01297234846910588*lm + 0.010100362526434075*lm^2)*NL + 
          (0.009522921704441509 - 0.01297234846910588*lm + 
            0.010100362526434075*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(0.09859623990212235 + 0.0005293152473092777*lm - 
          0.0555192420269408*lm^2) + CF^2*(0.3765427336107784 - 
          0.10135139192452292*lm + 0.09084966877135768*lm^2) + 
        CF*((0.01664862445391564 - 0.012943667042935095*lm + 
            0.010094407641261963*lm^2)*NM + (0.015171946114262312 - 
            0.012943667042935095*lm + 0.010094407641261963*lm^2)*NL + 
          (0.009563384399145287 - 0.012943667042935095*lm + 
            0.010094407641261963*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(0.09666648062957536 + 0.0004234659397218803*lm - 
          0.05547911362317897*lm^2) + CF^2*(0.3772999909640786 - 
          0.10110555487224072*lm + 0.0907840041106565*lm^2) + 
        CF*((0.016807738596318917 - 0.012915135802668534*lm + 
            0.010087111567850722*lm^2)*NM + (0.015382046880708293 - 
            0.012915135802668534*lm + 0.010087111567850722*lm^2)*NL + 
          (0.009603559773347245 - 0.012915135802668534*lm + 
            0.010087111567850722*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(0.09475950588575746 + 0.00032791995887728983*lm - 
          0.055431849508519156*lm^2) + CF^2*(0.3780151333063853 - 
          0.10086366276217684*lm + 0.09070666283212225*lm^2) + 
        CF*((0.016959142724997427 - 0.012886826655651542*lm + 
            0.010078518092458027*lm^2)*NM + (0.015586462090506518 - 
            0.012886826655651542*lm + 0.010078518092458027*lm^2)*NL + 
          (0.009643468270065814 - 0.012886826655651542*lm + 
            0.010078518092458027*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(0.09287631246196389 + 0.00024273702509039662*lm - 
          0.05537768475757685*lm^2) + CF^2*(0.37868858722198534 - 
          0.10062623878410933*lm + 0.09061802960330757*lm^2) + 
        CF*((0.017102958697076766 - 0.012858804857554881*lm + 
            0.010068669955923064*lm^2)*NM + (0.015785200181629478 - 
            0.012858804857554881*lm + 0.010068669955923064*lm^2)*NL + 
          (0.009683128991433696 - 0.012858804857554881*lm + 
            0.010068669955923064*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(0.09101777528934824 + 0.00016794982029352362*lm - 
          0.055316848762903194*lm^2) + CF^2*(0.37932078540218356 - 
          0.10039375159912328*lm + 0.09051847979384159*lm^2) + 
        CF*((0.017239317355964564 - 0.012831129433121875*lm + 
            0.0100576088659824*lm^2)*NM + (0.01597828058416958 - 
            0.012831129433121875*lm + 0.0100576088659824*lm^2)*NL + 
          (0.00972255975282608 - 0.012831129433121875*lm + 0.0100576088659824*
             lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(0.08918461805117403 + 0.00010356608447207928*lm - 
          0.05524956530799711*lm^2) + CF^2*(0.37991224424316744 - 
          0.10016661890228791*lm + 0.09040837959490436*lm^2) + 
        CF*((0.01736835733501704 - 0.012803853574233923*lm + 
            0.010045375510544928*lm^2)*NM + (0.01616573266882239 - 
            0.012803853574233923*lm + 0.010045375510544928*lm^2)*NL + 
          (0.009761777135986851 - 0.012803853574233923*lm + 
            0.010045375510544928*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(0.08737758081573763 + 0.0000495705873183507*lm - 
          0.05517605264487543*lm^2) + CF^2*(0.3804632460066663 - 
          0.09994521078939465*lm + 0.0902880861461598*lm^2) + 
        CF*((0.0174902239597724 - 0.012777025016343105*lm + 
            0.010032009571795533*lm^2)*NM + (0.016347594773143525 - 
            0.012777025016343105*lm + 0.010032009571795533*lm^2)*NL + 
          (0.009800796541068692 - 0.012777025016343105*lm + 
            0.010032009571795533*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(0.08559717820268127 + 5.926981524299913*^-6*lm - 
          0.055096523575551996*lm^2) + CF^2*(0.3809743386193269 - 
          0.09972985293708841*lm + 0.09015794766908508*lm^2) + 
        CF*((0.017605068241621516 - 0.012750686394289178*lm + 
            0.010017549741009454*lm^2)*NM + (0.016523913300259766 - 
            0.012750686394289178*lm + 0.010017549741009454*lm^2)*NL + 
          (0.009839632237518036 - 0.012750686394289178*lm + 
            0.010017549741009454*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(0.08384388057051398 - 0.00002742045612617094*lm - 
          0.05501118553683845*lm^2) + CF^2*(0.3814459882292146 - 
          0.09952082960541024*lm + 0.09001830360573565*lm^2) + 
        CF*((0.017713045956318094 - 0.012724875578485131*lm + 
            0.010002033733970628*lm^2)*NM + (0.01669474188506662 - 
            0.012724875578485131*lm + 0.010002033733970628*lm^2)*NL + 
          (0.00987829741374861 - 0.012724875578485131*lm + 
            0.010002033733970628*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(0.08211807519527105 - 0.0000505451899639239*lm - 
          0.05492024068793567*lm^2) + CF^2*(0.38187867066682485 - 
          0.09931838647144674*lm + 0.08986948476207655*lm^2) + 
        CF*((0.017814316801133222 - 0.012699625992421425*lm + 
            0.009985498306897395*lm^2)*NM + (0.016860140623273952 - 
            0.012699625992421425*lm + 0.009985498306897395*lm^2)*NL + 
          (0.009916804225558616 - 0.012699625992421425*lm + 
            0.009985498306897395*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(0.08042007260713203 - 0.0000635368912944526*lm - 
          0.05482388600033557*lm^2) + CF^2*(0.38227287155790696 - 
          0.09912273330245609*lm + 0.08971181345509456*lm^2) + 
        CF*((0.017909043624915365 - 0.01267496691240428*lm + 
            0.009967979272788285*lm^2)*NM + (0.017020175358969596 - 
            0.01267496691240428*lm + 0.009967979272788285*lm^2)*NL + 
          (0.009955163843257248 - 0.01267496691240428*lm + 
            0.009967979272788285*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(0.07875011251827156 - 0.00006649999951638778*lm - 
          0.05472231334959954*lm^2) + CF^2*(0.38262908629663667 - 
          0.09893404647651284*lm + 0.08954560366298106*lm^2) + 
        CF*((0.0179973917256951 - 0.012650923750408483*lm + 
            0.009949511518109007*lm^2)*NM + (0.017174917026659228 - 
            0.012650923750408483*lm + 0.009949511518109007*lm^2)*NL + 
          (0.009993386497474721 - 0.012650923750408483*lm + 
            0.009949511518109007*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(0.07710836936672455 - 0.00005955237334988192*lm - 
          0.05461570960862186*lm^2) + CF^2*(0.3829478198992284 - 
          0.09875247135838769*lm + 0.08937116117774487*lm^2) + 
        CF*((0.018079528210848263 - 0.012627518320890204*lm + 
            0.009930129019749429*lm^2)*NM + (0.01732444104401075 - 
            0.012627518320890204*lm + 0.009930129019749429*lm^2)*NL + 
          (0.010031481523638332 - 0.012627518320890204*lm + 
            0.009930129019749429*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(0.07549495749960265 - 0.00004282402726555712*lm - 
          0.054504256742024804*lm^2) + CF^2*(0.3832295867559251 - 
          0.09857812453805662*lm + 0.08918878375967695*lm^2) + 
        CF*((0.018155621415190438 - 0.012604769092370679*lm + 
            0.009909864862186328*lm^2)*NM + (0.017468826751783413 - 
            0.012604769092370679*lm + 0.009909864862186328*lm^2)*NL + 
          (0.010069457405104917 - 0.012604769092370679*lm + 
            0.009909864862186328*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(0.07390993601766006 - 0.00001645594843721083*lm - 
          0.05438813190136719*lm^2) + CF^2*(0.38347491029730674 - 
          0.09841109593891609*lm + 0.08899876129314631*lm^2) + 
        CF*((0.018225840372639843 - 0.01258269142456746*lm + 
            0.009888751254794034*lm^2)*NM + (0.01760815689765798 - 
            0.01258269142456746*lm + 0.009888751254794034*lm^2)*NL + 
          (0.010107321814943454 - 0.01258269142456746*lm + 
            0.009888751254794034*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(0.07235331330188317 + 0.000019401010233394172*lm - 
          0.05426750752087994*lm^2) + CF^2*(0.38368432258916596 - 
          0.0982514508024704*lm + 0.08880137594325808*lm^2) + 
        CF*((0.018290354337471556 - 0.012561297791816306*lm + 
            0.009866819549250899*lm^2)*NM + (0.01774251716090417 - 
            0.012561297791816306*lm + 0.009866819549250899*lm^2)*NL + 
          (0.01014508165637158 - 0.012561297791816306*lm + 
            0.009866819549250899*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(0.07082505124159433 + 0.00006458716525388627*lm - 
          0.05414255141347116*lm^2) + CF^2*(0.3838583638685466 - 
          0.09809923155595415*lm + 0.08859690231295281*lm^2) + 
        CF*((0.01834933235140603 - 0.012540597993494032*lm + 
            0.009844100256994757*lm^2)*NM + (0.017871995715027744 - 
            0.012540597993494032*lm + 0.009844100256994757*lm^2)*NL + 
          (0.010182743101849656 - 0.012540597993494032*lm + 
            0.009844100256994757*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(0.06932506918238591 + 0.00011893496986545983*lm - 
          0.05401342686676969*lm^2) + CF^2*(0.38399758203215406 - 
          0.09795445956905721*lm + 0.08838560760016857*lm^2) + 
        CF*((0.018402942853069416 - 0.01252059935212059*lm + 
            0.009820623066685397*lm^2)*NM + (0.0179966828257316 - 
            0.01252059935212059*lm + 0.009820623066685397*lm^2)*NL + 
          (0.010220311630844654 - 0.01252059935212059*lm + 
            0.009820623066685397*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(0.06785324761114477 + 0.00018226991737696924*lm - 
          0.053880292739000205*lm^2) + CF^2*(0.38410253208700135 - 
          0.09781713680563375*lm + 0.0881677517547276*lm^2) + 
        CF*((0.018451353326524016 - 0.012501306899787595*lm + 
            0.0097964168616364*lm^2)*NM + (0.018116670481704882 - 
            0.012501306899787595*lm + 0.0097964168616364*lm^2)*NL + 
          (0.010257792066275315 - 0.012501306899787595*lm + 
            0.0097964168616364*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(0.06640943159434813 + 0.00025441138413848514*lm - 
          0.05374330355450482*lm^2) + CF^2*(0.38417377557209775 - 
          0.0976872473759998*lm + 0.08794358763464426*lm^2) + 
        CF*((0.018494729986017366 - 0.012482723553530427*lm + 
            0.009771509737182694*lm^2)*NM + (0.01823205205592166 - 
            0.012482723553530427*lm + 0.009771509737182694*lm^2)*NL + 
          (0.010295188609657887 - 0.012482723553530427*lm + 
            0.009771509737182694*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(0.06499343398493089 + 0.0003351734155982736*lm - 
          0.053602609598746145*lm^2) + CF^2*(0.38421187995877715 - 
          0.0975647589951559*lm + 0.0877133611615846*lm^2) + 
        CF*((0.018533237493933614 - 0.012464850280231851*lm + 
            0.009745929017953844*lm^2)*NM + (0.01834292199528729 - 
            0.012464850280231851*lm + 0.009745929017953844*lm^2)*NL + 
          (0.010332504874970174 - 0.012464850280231851*lm + 
            0.009745929017953844*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(0.06360503841201871 + 0.0004243654587094645*lm - 
          0.053458357012644946*lm^2) + CF^2*(0.3842174180365076 - 
          0.0974496243520142*lm + 0.08747731147523718*lm^2) + 
        CF*((0.01856703870955716 - 0.01244768625161708*lm + 
            0.009719701275026353*lm^2)*NM + (0.018449375536616613 - 
            0.01244768625161708*lm + 0.009719701275026353*lm^2)*NL + 
          (0.010369743921256317 - 0.01244768625161708*lm + 
            0.009719701275026353*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(0.06224400206703504 + 0.0005217930437827399*lm - 
          0.05331068788612226*lm^2) + CF^2*(0.38419096729003976 - 
          0.0973417823944608*lm + 0.08723567108638187*lm^2) + 
        CF*((0.018596294466116468 - 0.012431228989873087*lm + 
            0.00969285234293132*lm^2)*NM + (0.01855150844706458 - 
            0.012431228989873087*lm + 0.00969285234293132*lm^2)*NL + 
          (0.010406908283996602 - 0.012431228989873087*lm + 
            0.00969285234293132*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(0.06091005829884554 + 0.000627258418719032*lm - 
          0.05315974035073076*lm^2) + CF^2*(0.38413310927306193 - 
          0.09724115953484631*lm + 0.08698866602846851*lm^2) + 
        CF*((0.018621163373910562 - 0.012415474504399008*lm + 
            0.009665407336496502*lm^2)*NM + (0.018649416787257143 - 
            0.012415474504399008*lm + 0.009665407336496502*lm^2)*NL + 
          (0.010444000005266544 - 0.012415474504399008*lm + 
            0.009665407336496502*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(0.05960291902985533 + 0.0007405611384012932*lm - 
          0.05300564867127408*lm^2) + CF^2*(0.38404442898282515 - 
          0.09714767078026842*lm + 0.0867365160075394*lm^2) + 
        CF*((0.018641801647419628 - 0.012400417420169443*lm + 
            0.009637390667504377*lm^2)*NM + (0.018743196695489035 - 
            0.012400417420169443*lm + 0.009637390667504377*lm^2)*NL + 
          (0.010481020662713213 - 0.012400417420169443*lm + 
            0.009637390667504377*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(0.05832227700424965 + 0.0008614986118766662*lm - 
          0.052848543336325285*lm^2) + CF^2*(0.3839255142396056 - 
          0.09706122079179187*lm + 0.08647943455035047*lm^2) + 
        CF*((0.018658362954485783 - 0.01238605109816855*lm + 
            0.009608826061150051*lm^2)*NM + (0.018832944191466045 - 
            0.01238605109816855*lm + 0.009608826061150051*lm^2)*NL + 
          (0.010517971397375892 - 0.01238605109816855*lm + 
            0.009608826061150051*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(0.05706780787890106 + 0.000989866609819643*lm - 
          0.0526885511475671*lm^2) + CF^2*(0.3837769550743118 - 
          0.09698170487654119*lm + 0.08621762915056434*lm^2) + 
        CF*((0.018670998285754938 - 0.012372367748329841*lm + 
            0.009579736572284926*lm^2)*NM + (0.01891875499817272 - 
            0.012372367748329841*lm + 0.009579736572284926*lm^2)*NL + 
          (0.010554852940378263 - 0.012372367748329841*lm + 
            0.009579736572284926*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(0.05583917216682535 + 0.001125459734632794*lm - 
          0.052525795307886876*lm^2) + CF^2*(0.38359934312706784 - 
          0.09690900991640099*lm + 0.0859513014129058*lm^2) + 
        CF*((0.018679855842725614 - 0.012359358535394662*lm + 
            0.009550144601433977*lm^2)*NM + (0.01900072438054313 - 
            0.012359358535394662*lm + 0.009550144601433977*lm^2)*NL + 
          (0.010591665638525776 - 0.012359358535394662*lm + 
            0.009550144601433977*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(0.054636017042472805 + 0.0012680718554141668*lm - 
          0.052360395508168775*lm^2) + CF^2*(0.3833932710591614 - 
          0.0968430152368675*lm + 0.08568064719518527*lm^2) + 
        CF*((0.01868508094286121 - 0.012347013678081302*lm + 
            0.009520071910576142*lm^2)*NM + (0.019078946999702313 - 
            0.012347013678081302*lm + 0.009520071910576142*lm^2)*NL + 
          (0.010628409478831294 - 0.012347013678081302*lm + 
            0.009520071910576142*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(0.05345797801758278 + 0.0014174965098992347*lm - 
          0.05219246801273416*lm^2) + CF^2*(0.383159331980352 - 
          0.09678359341941181*lm + 0.08540585674811044*lm^2) + 
        CF*((0.018686815940313146 - 0.012335322541936691*lm + 
            0.009489539638678938*lm^2)*NM + (0.01915351678163026 - 
            0.012335322541936691*lm + 0.009489539638678938*lm^2)*NL + 
          (0.010665084112005434 - 0.012335322541936691*lm + 
            0.009489539638678938*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(0.05230468049578576 + 0.0015735272753700734*lm - 
          0.05202212574338901*lm^2) + CF^2*(0.3828981188932163 - 
          0.09673061106054105*lm + 0.08512711485281839*lm^2) + 
        CF*((0.018685200160988222 - 0.012324273726223422*lm + 
            0.00945856831697982*lm^2)*NM + (0.019224526799178576 - 
            0.012324273726223422*lm + 0.00945856831697982*lm^2)*NL + 
          (0.0107016888749378 - 0.012324273726223422*lm + 0.00945856831697982*
             lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(0.051175741213670516 + 0.001735958110415041*lm - 
          0.05184947836204438*lm^2) + CF^2*(0.38261022415583695 - 
          0.09668392948057766*lm + 0.08484460095607262*lm^2) + 
        CF*((0.018680369850627168 - 0.01231385514517664*lm + 
            0.009427177884008068*lm^2)*NM + (0.019292069166443326 - 
            0.01231385514517664*lm + 0.009427177884008068*lm^2)*NL + 
          (0.010738222812200741 - 0.01231385514517664*lm + 
            0.009427177884008068*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(0.05007076957552273 + 0.0019045836693183534*lm - 
          0.051674632351882015*lm^2) + CF^2*(0.382296238963958 - 
          0.09664340538501814*lm + 0.08455848930307966*lm^2) + 
        CF*((0.018672458134865823 - 0.012304054103947935*lm + 
            0.009395387700342185*lm^2)*NM + (0.019356234944565773 - 
            0.012304054103947935*lm + 0.009395387700342185*lm^2)*NL + 
          (0.010774684696603158 - 0.012304054103947935*lm + 
            0.009395387700342185*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(0.048989368888543355 + 0.0020791995907603862*lm - 
          0.05149769109704355*lm^2) + CF^2*(0.3819567528533997 - 
          0.0966088914811826*lm + 0.08426894906788944*lm^2) + 
        CF*((0.018661594990142777 - 0.01229485736953676*lm + 
            0.009363216563098827*lm^2)*NM + (0.01941711405809658 - 
            0.01229485736953676*lm + 0.009363216563098827*lm^2)*NL + 
          (0.010811073048833648 - 0.01229485736953676*lm + 
            0.009363216563098827*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(0.04793113750491224 + 0.0022596027624160256*lm - 
          0.05131875496082644*lm^2) + CF^2*(0.381592353223375 - 
          0.096580237052722*lm + 0.08397614448135235*lm^2) + 
        CF*((0.018647907224517982 - 0.012286251236994157*lm + 
            0.009330682720150262*lm^2)*NM + (0.01947479522111835 - 
            0.012286251236994157*lm + 0.009330682720150262*lm^2)*NL + 
          (0.010847386156205478 - 0.012286251236994157*lm + 
            0.009330682720150262*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(0.04689566987669332 + 0.0024455915629497398*lm - 
          0.05113792136237501*lm^2) + CF^2*(0.381203624881117 - 
          0.09655728849441467*lm + 0.08368023495661364*lm^2) + 
        CF*((0.01863151846746112 - 0.012278221591168549*lm + 
            0.009297803884068184*lm^2)*NM + (0.01952936587237705 - 
            0.012278221591168549*lm + 0.009297803884068184*lm^2)*NL + 
          (0.010883622090551293 - 0.012278221591168549*lm + 
            0.009297803884068184*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(0.04588255752918615 + 0.0026369660828220024*lm - 
          0.050955284851858976*lm^2) + CF^2*(0.38079114960811844 - 
          0.09653988980955266*lm + 0.08338137521213287*lm^2) + 
        CF*((0.01861254916783914 - 0.012270753964249053*lm + 
            0.009264597245792542*lm^2)*NM + (0.019580912118724522 - 
            0.012270753964249053*lm + 0.009264597245792542*lm^2)*NL + 
          (0.010919778725284367 - 0.012270753964249053*lm + 
            0.009264597245792542*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(0.0448913899580277 + 0.0028335283252420656*lm - 
          0.05077093718413592*lm^2) + CF^2*(0.38035550574804866 - 
          0.09652788307209664*lm + 0.0830797153922224*lm^2) + 
        CF*((0.018591116599224033 - 0.01226383358934819*lm + 
            0.009231079488024712*lm^2)*NM + (0.019629518686222612 - 
            0.01226383358934819*lm + 0.009231079488024712*lm^2)*NL + 
          (0.010955853751659686 - 0.01226383358934819*lm + 
            0.009231079488024712*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(0.043921755454973684 + 0.0030350823885266537*lm - 
          0.05058496739089737*lm^2) + CF^2*(0.3798972678163941 - 
          0.09652110885565952*lm + 0.08277540118510479*lm^2) + 
        CF*((0.0185673348719084 - 0.012257445450352998*lm + 
            0.009197266798344976*lm^2)*NM + (0.019675268878304546 - 
            0.012257445450352998*lm + 0.009197266798344976*lm^2)*NL + 
          (0.01099184469426147 - 0.012257445450352998*lm + 
            0.009197266798344976*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(0.04297324186702526 + 0.003241434631052704*lm - 
          0.05039746185130181*lm^2) + CF^2*(0.3794170061316765 - 
          0.09651940663126886*lm + 0.08246857393849387*lm^2) + 
        CF*((0.018541314950904393 - 0.01225157432826124*lm + 
            0.009163174882054875*lm^2)*NM + (0.019718244540431213 - 
            0.01225157432826124*lm + 0.009163174882054875*lm^2)*NL + 
          (0.011027748925748872 - 0.01225157432826124*lm + 
            0.009163174882054875*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(0.042045437293262954 + 0.003452393819924647*lm - 
          0.050208504361100026*lm^2) + CF^2*(0.37891528646804523 - 
          0.09652261513575196*lm + 0.08215937077270914*lm^2) + 
        CF*((0.018513164679333227 - 0.012246204844207794*lm + 
            0.00912881897474546*lm^2)*NM + (0.019758526030719183 - 
            0.012246204844207794*lm + 0.00912881897474546*lm^2)*NL + 
          (0.011063563680873778 - 0.012246204844207794*lm + 
            0.00912881897474546*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(0.0411379307234849 + 0.0036677712644127094*lm - 
          0.050018176200261444*lm^2) + CF^2*(0.3783926697289524 - 
          0.09653057271248738*lm + 0.0818479246913369*lm^2) + 
        CF*((0.01848298880664128 - 0.012241321499375207*lm + 
            0.00909421385459299*lm^2)*NM + (0.01979619219605404 - 
            0.012241321499375207*lm + 0.00909421385459299*lm^2)*NL + 
          (0.011099286069819579 - 0.012241321499375207*lm + 
            0.00909421385459299*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(0.04025031262249488 + 0.0038873809351581243*lm - 
          0.04982655619911184*lm^2) + CF^2*(0.3778497116415493 - 
          0.09654311762617192*lm + 0.08153436468945574*lm^2) + 
        CF*((0.018450889021122362 - 0.012236908711971986*lm + 
            0.00905937385438397*lm^2)*NM + (0.01983132035323653 - 
            0.012236908711971986*lm + 0.00905937385438397*lm^2)*NL + 
          (0.011134913090862699 - 0.012236908711971986*lm + 
            0.00905937385438397*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(0.03938217546364945 + 0.004111039570083839*lm - 
          0.04963372080299507*lm^2) + CF^2*(0.37728696247138116 - 
          0.09656008835316132*lm + 0.08121881585944647*lm^2) + 
        CF*((0.018416963986261525 - 0.012232950851452118*lm + 
            0.009024312873271831*lm^2)*NM + (0.01986398627474103 - 
            0.012232950851452118*lm + 0.009024312873271831*lm^2)*NL + 
          (0.011170441642399982 - 0.012232950851452118*lm + 
            0.009024312873271831*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(0.03853311421504939 + 0.004338566767895073*lm - 
          0.04943974413547309*lm^2) + CF^2*(0.37670496675691284 - 
          0.0965813238488581*lm + 0.08090139949441051*lm^2) + 
        CF*((0.01838130938046158 - 0.012229432270139983*lm + 
            0.008989044388267834*lm^2)*NM + (0.019894264178695557 - 
            0.012229432270139983*lm + 0.008989044388267834*lm^2)*NL + 
          (0.011205868534355796 - 0.012229432270139983*lm + 
            0.008989044388267834*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(0.037702727354778094 + 0.004569784989052926*lm - 
          0.04924469801455459*lm^2) + CF*(0.3761042668600413 - 
          0.09660666357867714*lm + 0.08058223311472569*lm^2) + 
        0.01834401767612529*NM - 0.012226337307162752*lm*NM + 
        0.008953581457191743*lm^2*NM + 0.019922226540534962*NL - 
        0.012226337307162752*lm*NL + 0.008953581457191743*lm^2*NL + 
        0.011241190483799844*NH - 0.012226337307162752*lm*NH + 
        0.008953581457191743*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(0.03689061486427801 + 0.0048045199677771745*lm - 
          0.049048652204397865*lm^2) + CF*(0.37548538677933074 - 
          0.0966359486477935*lm + 0.08026143087992378*lm^2) + 
        0.01830517929266294*NM - 0.012223650421605272*lm*NM + 
        0.008917936764435976*lm^2*NM + 0.019947944855908853*NL - 
        0.012223650421605272*lm*NL + 0.008917936764435976*lm^2*NL + 
        0.011276404189073793*NH - 0.012223650421605272*lm*NH + 
        0.008917936764435976*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(0.036096382395757756 + 0.005042600232716877*lm - 
          0.04885167417142319*lm^2) + CF*(0.3748488571909789 - 
          0.09666902057536876*lm + 0.07993910318960158*lm^2) + 
        0.018264880892287533*NM - 0.012221356048922485*lm*NM + 
        0.008882122576622398*lm^2*NM + 0.019971488430536165*NL - 
        0.012221356048922485*lm*NL + 0.008882122576622398*lm^2*NL + 
        0.011311506238428137*NH - 0.012221356048922485*lm*NH + 
        0.008882122576622398*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(0.035319638914156674 + 0.005283857541358936*lm - 
          0.048653829355763005*lm^2) + CF*(0.3741951974196601 - 
          0.09670572249670385*lm + 0.07961535712761218*lm^2) + 
        0.018223206666342483*NM - 0.012219438742737692*lm*NM + 
        0.00884615079195691*lm^2*NM + 0.0199929252385587*NL - 
        0.012219438742737692*lm*NL + 0.00884615079195691*lm^2*NL + 
        0.011346493190586966*NH - 0.012219438742737692*lm*NH + 
        0.00884615079195691*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(0.03455999770505095 + 0.005528126820706794*lm - 
          0.0484551811703805*lm^2) + CF*(0.3735249200194452 - 
          0.09674589906457252*lm + 0.07929029646062265*lm^2) + 
        0.01818023805693588*NM - 0.012217883163852921*lm*NM + 
        0.008810032940069183*lm^2*NM + 0.020012321700909858*NL - 
        0.012217883163852921*lm*NL + 0.008810032940069183*lm^2*NL + 
        0.011381361564387717*NH - 0.012217883163852921*lm*NH + 
        0.008810032940069183*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(0.03381707663681975 + 0.005775246202232672*lm - 
          0.048255791055887044*lm^2) + CF*(0.3728385306147354 - 
          0.09678939660563084*lm + 0.07896402172781516*lm^2) + 
        0.01813605380952508*NM - 0.012216674099288892*lm*NM + 
        0.008773780191979462*lm^2*NM + 0.020029742693886098*NL - 
        0.012216674099288892*lm*NL + 0.008773780191979462*lm^2*NL + 
        0.011416107846972891*NH - 0.012216674099288892*lm*NH + 
        0.008773780191979462*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(0.03309049839397518 + 0.006025057049316918*lm - 
          0.04805571853403052*lm^2) + CF*(0.37213652775712935 - 
          0.09683606326212754*lm + 0.07863663032841357*lm^2) + 
        0.01809073002662841*NM - 0.01221579647965146*lm*NM + 
        0.00873740336982373*lm^2*NM + 0.020045251559876718*NL - 
        0.01221579647965146*lm*NL + 0.00873740336982373*lm^2*NL + 
        0.011450728501518181*NH - 0.01221579647965146*lm*NH + 
        0.00873740336982373*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(0.03237989068367961 + 0.006277403977719988*lm - 
          0.04785502125987745*lm^2) + CF*(0.3714194027975744 - 
          0.09688574911984892*lm + 0.07830821660707218*lm^2) + 
        0.018044340222442272*NM - 0.012215235394928994*lm*NM + 
        0.008700912956341355*lm^2*NM + 0.020058910120038093*NL - 
        0.012215235394928994*lm*NL + 0.008700912956341355*lm^2*NL + 
        0.011485219974516497*NH - 0.012215235394928994*lm*NH + 
        0.008700912956341355*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(0.03168488641734684 + 0.0065321348695998975*lm - 
          0.04765375507271183*lm^2) + CF*(0.3706876397731573 - 
          0.0969383063231791*lm + 0.07797887193716481*lm^2) + 
        0.01799695537816098*NM - 0.012214976108819248*lm*NM + 
        0.008664319104129424*lm^2*NM + 0.020070778688714177*NL - 
        0.012214976108819248*lm*NL + 0.008664319104129424*lm^2*NL + 
        0.011519578702636693*NH - 0.012214976108819248*lm*NH + 
        0.008664319104129424*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(0.031005123869105106 + 0.006789100881557064*lm - 
          0.04745197404567406*lm^2) + CF*(0.36994171530789727 - 
          0.09699358917810677*lm + 0.0776486848020121*lm^2) + 
        0.017948643997814186*NM - 0.012215004071678753*lm*NM + 
        0.008627631644668012*lm^2*NM + 0.020080916089419736*NL - 
        0.012215004071678753*lm*NL + 0.008627631644668012*lm^2*NL + 
        0.011553801119175179*NH - 0.012215004071678753*lm*NH + 
        0.008627631644668012*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(0.030340246812787595 + 0.007048156447159323*lm - 
          0.047249730534163654*lm^2) + CF*(0.3691820985269122 - 
          0.09705145424396187*lm + 0.07731774087408598*lm^2) + 
        0.017899472164453308*NM - 0.012215304932182541*lm*NM + 
        0.008590860097120664*lm^2*NM + 0.02008937967221633*NL - 
        0.012215304932182541*lm*NL + 0.008590860097120664*lm^2*NL + 
        0.011587883660117988*NH - 0.012215304932182541*lm*NH + 
        0.008590860097120664*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(0.029689904639011444 + 0.007309159274372389*lm - 
          0.04704707522302938*lm^2) + CF*(0.3684092509833384 - 
          0.09711176041462122*lm + 0.0769861230922299*lm^2) + 
        0.017849503596533346*NM - 0.012215864547776985*lm*NM + 
        0.008554013676914433*lm^2*NM + 0.02009622533232391*NL - 
        0.012215864547776985*lm*NL + 0.008554013676914433*lm^2*NL + 
        0.011621822769830238*NH - 0.012215864547776985*lm*NH + 
        0.008554013676914433*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(0.029053752453807348 + 0.007571970338295063*lm - 
          0.04684405717257079*lm^2) + CF*(0.3676236265973976 - 
          0.09717436898987956*lm + 0.07665391173693403*lm^2) + 
        0.017798799704350714*NM - 0.012216668994003914*lm*NM + 
        0.008517101304103781*lm^2*NM + 0.020101507529822666*NL - 
        0.012216668994003914*lm*NL + 0.008517101304103781*lm^2*NL + 
        0.01165561490638938*NH - 0.012216668994003914*lm*NH + 
        0.008517101304103781*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(0.028431451160169163 + 0.00783645386957401*lm - 
          0.046640723863375054*lm^2) + CF*(0.3668256716070159 - 
          0.0972391437376429*lm + 0.07632118450370463*lm^2) + 
        0.017747419646410554*NM - 0.012217704572769668*lm*NM + 
        0.008480131611522737*lm^2*NM + 0.020105279310310815*NL - 
        0.012217704572769668*lm*NL + 0.008480131611522737*lm^2*NL + 
        0.011689256546577988*NH - 0.012217704572769668*lm*NH + 
        0.008480131611522737*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(0.027822667523805793 + 0.008102477338849827*lm - 
          0.04643712124001288*lm^2) + CF*(0.36601582452941356 - 
          0.0973059509475627*lm + 0.07598801657456654*lm^2) + 
        0.017695420385609267*NM - 0.012218957819628569*lm*NM + 
        0.008443112952729615*lm^2*NM + 0.02010759232639441*NL - 
        0.012218957819628569*lm*NL + 0.008443112952729615*lm^2*NL + 
        0.011722744190551337*NH - 0.012218957819628569*lm*NH + 
        0.008443112952729615*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(0.027227074224295846 + 0.008369911437564295*lm - 
          0.04623329375361755*lm^2) + CF*(0.3651945161331004 - 
          0.097374659476694*lm + 0.07565448068773782*lm^2) + 
        0.017642856745128895*NM - 0.01222041551014633*lm*NM + 
        0.008406053409748647*lm^2*NM + 0.020108496859894753*NL - 
        0.01222041551014633*lm*NL + 0.008406053409748647*lm^2*NL + 
        0.011756074366194398*NH - 0.01222041551014633*lm*NH + 
        0.008406053409748647*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(0.026644349892768513 + 0.008638630055438216*lm - 
          0.046029284403370695*lm^2) + CF*(0.36436216941972477 - 
          0.09744514078772686*lm + 0.07532064720551568*lm^2) + 
        0.017589781463950585*NM - 0.012222064665405126*lm*NM + 
        0.008368960800612854*lm^2*NM + 0.02010804184466805*NL - 
        0.012222064665405126*lm*NL + 0.008368960800612854*lm^2*NL + 
        0.011789243633182423*NH - 0.012222064665405126*lm*NH + 
        0.008368960800612854*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(0.026074179137162156 + 0.00890851025490979*lm - 
          0.045825134776918464*lm^2) + CF*(0.3635191996152406 - 
          0.0975172689803081*lm + 0.07498658418041203*lm^2) + 
        0.017536245251903664*NM - 0.012223892556708532*lm*NM + 
        0.008331842686712448*lm^2*NM + 0.02010627488994017*NL - 
        0.012223892556708532*lm*NL + 0.008331842686712448*lm^2*NL + 
        0.011822248586758687*NH - 0.012223892556708532*lm*NH + 
        0.008331842686712448*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(0.025516252556044026 + 0.009179432242805222*lm - 
          0.045620885089741575*lm^2) + CF*(0.36266601416987465 - 
          0.09759092081594081*lm + 0.07465235741957713*lm^2) + 
        0.01748229684417581*NM - 0.012225886709541148*lm*NM + 
        0.008294706379953014*lm^2*NM + 0.020103242304067192*NL - 
        0.012225886709541148*lm*NL + 0.008294706379953014*lm^2*NL + 
        0.01185508586124251*NH - 0.012225886709541148*lm*NH + 
        0.008294706379953014*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(0.024970266741910982 + 0.009451279339496079*lm - 
          0.04541657422350249*lm^2) + CF*(0.3618030127663891 - 
          0.09766597573691957*lm + 0.07431803054754953*lm^2) + 
        0.017427983055217894*NM - 0.012228034906834573*lm*NM + 
        0.008257558949727725*lm^2*NM + 0.02009898911863972*NL - 
        0.012228034906834573*lm*NL + 0.008257558949727725*lm^2*NL + 
        0.011887752133280128*NH - 0.012228034906834573*lm*NH + 
        0.008257558949727725*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(0.02443592427483121 + 0.009723937945781564*lm - 
          0.04521223976339266*lm^2) + CF*(0.3609305873361551 - 
          0.09774231587973341*lm + 0.07398366506736981*lm^2) + 
        0.01737334883198456*NM - 0.01223032519158834*lm*NM + 
        0.008220407229707757*lm^2*NM + 0.020093559112855507*NL - 
        0.01223032519158834*lm*NL + 0.008220407229707757*lm^2*NL + 
        0.011920244124850573*NH - 0.01223032519158834*lm*NH + 
        0.008220407229707757*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(0.023912933707230816 + 0.009997297507718666*lm - 
          0.04500791803450281*lm^2) + CF*(0.36004912208256645 - 
          0.09781982608334223*lm + 0.0736493204200955*lm^2) + 
        0.01731843730645859*NM - 0.012232745868891648*lm*NM + 
        0.008183257824455056*lm^2*NM + 0.02008699483809132*NL - 
        0.012232745868891648*lm*NL + 0.008183257824455056*lm^2*NL + 
        0.011952558606038185*NH - 0.012232745868891648*lm*NH + 
        0.008183257824455056*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(0.023401009540576324 + 0.010271250479608654*lm - 
          0.044803644137238544*lm^2) + CF*(0.3591589935113413 - 
          0.09789839389270871*lm + 0.07331505404275397*lm^2) + 
        0.017263289847413366*NM - 0.012235285507389004*lm*NM + 
        0.008146117115861553*lm^2*NM + 0.020079337642610787*NL - 
        0.012235285507389004*lm*NL + 0.008146117115861553*lm^2*NL + 
        0.011984692397582963*NH - 0.012235285507389004*lm*NH + 
        0.008146117115861553*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(0.02289987219465471 + 0.01054569228533482*lm - 
          0.044599451981803706*lm^2) + CF*(0.3582605704672747 - 
          0.09797790955794468*lm + 0.0729809214247697*lm^2) + 
        0.017207946111373763*NM - 0.01223793294023033*lm*NM + 
        0.008108991269418855*lm^2*NM + 0.020070627696350325*NL - 
        0.01223793294023033*lm*NL + 0.008108991269418855*lm^2*NL + 
        0.012016642373219531*NH - 0.01223793294023033*lm*NH + 
        0.008108991269418855*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(0.02240924797010609 + 0.01082052127823355*lm - 
          0.04439537432177327*lm^2) + CF*(0.3573542141770235 - 
          0.09805826602940983*lm + 0.07264697616290171*lm^2) + 
        0.017152444092741085*NM - 0.012240677265543716*lm*NM + 
        0.008071886240322413*lm^2*NM + 0.020060904015730328*NL - 
        0.012240677265543716*lm*NL + 0.008071886240322413*lm^2*NL + 
        0.01204840546181504*NH - 0.012240677265543716*lm*NH + 
        0.008071886240322413*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(0.02192886900482041 + 0.011095638699668743*lm - 
          0.04419144278677743*lm^2) + CF*(0.35644027829751884 - 
          0.09813935894907991*lm + 0.0723132700147267*lm^2) + 
        0.017096820173052685*NM - 0.01224350784646678*lm*NM + 
        0.008034807779414078*lm^2*NM + 0.02005020448844344*NL - 
        0.01224350784646678*lm*NL + 0.008034807779414078*lm^2*NL + 
        0.012079978649315938*NH - 0.01224350784646678*lm*NH + 
        0.008034807779414078*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(0.021458473224768786 + 0.01137094863646825*lm - 
          0.04398768791431813*lm^2) + CF*(0.35551910896962013 - 
          0.09822108663848252*lm + 0.0719798529507024*lm^2) + 
        0.017041109169351434*NM - 0.012246414310770325*lm*NM + 
        0.007997761438966933*lm^2*NM + 0.020038565898176142*NL - 
        0.012246414310770325*lm*NL + 0.007997761438966933*lm^2*NL + 
        0.012111358980513142*NH - 0.012246414310770325*lm*NH + 
        0.007997761438966933*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(0.020997804289801407 + 0.01164635797737029*lm - 
          0.04378413918073901*lm^2) + CF*(0.35459104487663834 - 
          0.09830335008348065*lm + 0.07164677320484564*lm^2) + 
        0.016985344381644413*NM - 0.012249386550106104*lm*NM + 
        0.007960752578316183*lm^2*NM + 0.020026023949223842*NL - 
        0.012249386550106104*lm*NL + 0.007960752578316183*lm^2*NL + 
        0.012142543560634756*NH - 0.012249386550106104*lm*NH + 
        0.007960752578316183*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(0.02054661153490811 + 0.01192177636861772*lm - 
          0.0435808250313692*lm^2) + CF*(0.35365641730737335 - 
          0.09838605291616664*lm + 0.07131407732405869*lm^2) + 
        0.016929557639434045*NM - 0.012252414718908491*lm*NM + 
        0.007923786369339854*lm^2*NM + 0.020012613290963467*NL - 
        0.012252414718908491*lm*NL + 0.007923786369339854*lm^2*NL + 
        0.012173529556775073*NH - 0.012252414718908491*lm*NH + 
        0.007923786369339854*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(0.020104649907403682 + 0.012197116168828596*lm - 
          0.04337777290986149*lm^2) + CF*(0.3527155502233247 - 
          0.09846910139411345*lm + 0.07098181021613698*lm^2) + 
        0.016873779347308306*NM - 0.012255489232978105*lm*NM + 
        0.007886867801792997*lm^2*NM + 0.019998367542150973*NL - 
        0.012255489232978105*lm*NL + 0.007886867801792997*lm^2*NL + 
        0.012204314199168339*NH - 0.012255489232978105*lm*NH + 
        0.007886867801792997*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(0.019671679900468298 + 0.012472292403262494*lm - 
          0.043175009286744316*lm^2) + CF*(0.3517687603297497 - 
          0.0985524043772147*lm + 0.0706500151964907*lm^2) + 
        0.016818038529580005*NM - 0.012258600767773683*lm*NM + 
        0.007850001688498967*lm^2*NM + 0.019983319315014486*NL - 
        0.012258600767773683*lm*NL + 0.007850001688498967*lm^2*NL + 
        0.012234894782315266*NH - 0.012258600767773683*lm*NH + 
        0.007850001688498967*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(0.01924746748344373 + 0.012747222717593685*lm - 
          0.04297255968720745*lm^2) + CF*(0.3508163571502592 - 
          0.09863587330233042*lm + 0.07031873403361219*lm^2) + 
        0.016762362873967877*NM - 0.01226174025643694*lm*NM + 
        0.007813192670401354*lm^2*NM + 0.019967500239116708*NL - 
        0.01226174025643694*lm*NL + 0.007813192670401354*lm^2*NL + 
        0.01226526866597008*NH - 0.01226174025643694*lm*NH + 
        0.007813192670401354*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(0.018831784029257913 + 0.013021827331294384*lm - 
          0.04277044871814025*lm^2) + CF*(0.34985864310465303 - 
          0.09871942215594218*lm + 0.06998800699332042*lm^2) + 
        0.01670677877431506*NM - 0.012264898887573584*lm*NM + 
        0.007776445221480046*lm^2*NM + 0.01995094098496303*NL - 
        0.012264898887573584*lm*NL + 0.007776445221480046*lm^2*NL + 
        0.012295433275995483*NH - 0.012264898887573584*lm*NH + 
        0.007776445221480046*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(0.018424406239324412 + 0.01329602899072381*lm - 
          0.04256870009444135*lm^2) + CF*(0.34889591358971267 - 
          0.09880296744500802*lm + 0.06965787288181312*lm^2) + 
        0.016651311372342832*NM - 0.012268068102812245*lm*NM + 
        0.007739763653534792*lm^2*NM + 0.019933671287334326*NL - 
        0.012268068102812245*lm*NL + 0.007739763653534792*lm^2*NL + 
        0.012325386105092612*NH - 0.012268068102812245*lm*NH + 
        0.007739763653534792*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(0.01802511606623859 + 0.013569752922011881*lm - 
          0.04236733666461812*lm^2) + CF*(0.34792845706268205 - 
          0.09888642816619604*lm + 0.06932836908755692*lm^2) + 
        0.016595984598439733*NM - 0.012271239594161725*lm*NM + 
        0.007703152120839658*lm^2*NM + 0.019915719968325824*NL - 
        0.012271239594161725*lm*NL + 0.007703152120839658*lm^2*NL + 
        0.012355124713412824*NH - 0.012271239594161725*lm*NH + 
        0.007703152120839658*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(0.01763370063456942 + 0.013842926783819747*lm - 
          0.04216638043569392*lm^2) + CF*(0.34695655512717954 - 
          0.09896972577366346*lm + 0.0689995316220446*lm^2) + 
        0.01654082121148822*NM - 0.012274405301185655*lm*NM + 
        0.007666614624671622*lm^2*NM + 0.019897114960075606*NL - 
        0.012274405301185655*lm*NL + 0.007666614624671622*lm^2*NL + 
        0.012384646729057758*NH - 0.012274405301185655*lm*NH + 
        0.007666614624671622*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(0.017249952160024135 + 0.014115480620053236*lm - 
          0.041965852597440775*lm^2) + CF*(0.34598048262129766 - 
          0.09905278414553777*lm + 0.06867139515944853*lm^2) + 
        0.01648584283773274*NM - 0.012277557408012502*lm*NM + 
        0.007630155017716504*lm^2*NM + 0.019877883327168312*NL - 
        0.012277557408012502*lm*NL + 0.007630155017716504*lm^2*NL + 
        0.012413949848473934*NH - 0.012277557408012502*lm*NH + 
        0.007630155017716504*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(0.016873667867242828 + 0.014387346812599443*lm - 
          0.04176577354595468*lm^2) + CF*(0.34500050770765867 - 
          0.099135529549246*lm + 0.06834399307519856*lm^2) + 
        0.016431070008694815*NM - 0.012280688340197675*lm*NM + 
        0.007593777008355397*lm^2*NM + 0.019858051288701523*NL - 
        0.012280688340197675*lm*NL + 0.007593777008355397*lm^2*NL + 
        0.012443031836747819*NH - 0.012280688340197675*lm*NH + 
        0.007593777008355397*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(0.01650464990646098 + 0.01465846003415134*lm - 
          0.04156616290659054*lm^2) + CF*(0.34401689196520663 - 
          0.09921789060582888*lm + 0.0680173574835118*lm^2) + 
        0.016376522198142094*NM - 0.012283790761453426*lm*NM + 
        0.007557484164834644*lm^2*NM + 0.019837644240004015*NL - 
        0.012283790761453426*lm*NL + 0.007557484164834644*lm^2*NL + 
        0.012471890527807061*NH - 0.012283790761453426*lm*NH + 
        0.007557484164834644*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(0.016142705269260357 + 0.01492875720118004*lm - 
          0.041367039556273105*lm^2) + CF*(0.34302989048252736 - 
          0.09929979825336743*lm + 0.06769151927390145*lm^2) + 
        0.01632221785811978*NM - 0.012286857570261222*lm*NM + 
        0.0075212799193223835*lm^2*NM + 0.019816686773996665*NL - 
        0.012286857570261222*lm*NL + 0.0075212799193223835*lm^2*NL + 
        0.012500523824533333*NH - 0.012286857570261222*lm*NH + 
        0.0075212799193223835*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(0.015787645703611842 + 0.015198177427109697*lm - 
          0.0411684216452002*lm^2) + CF*(0.3420397519524987 - 
          0.09938118570964102*lm + 0.06736650814669123*lm^2) + 
        0.016268174454053843*NM - 0.012289881896380321*lm*NM + 
        0.007485167571854582*lm^2*NM + 0.01979520270218828*NL - 
        0.012289881896380321*lm*NL + 0.007485167571854582*lm^2*NL + 
        0.012528929698791982*NH - 0.012289881896380321*lm*NH + 
        0.007485167571854582*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(0.01543928762839839 + 0.015466661975745385*lm - 
          0.040970326617953925*lm^2) + CF*(0.34104671876808496 - 
          0.09946198843412805*lm + 0.06704235264756096*lm^2) + 
        0.016214408498936638*NM - 0.012292857097265358*lm*NM + 
        0.007449150294173441*lm^2*NM + 0.019773215075299923*NL - 
        0.012292857097265358*lm*NL + 0.007449150294173441*lm^2*NL + 
        0.012557106191383453*NH - 0.012292857097265358*lm*NH + 
        0.007449150294173441*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(0.0150974520475916 + 0.0157341542150002*lm - 
          0.040772771234035346*lm^2) + CF*(0.34005102711909835 - 
          0.09954214408945274*lm + 0.06671908020114875*lm^2) + 
        0.01616093558660637*NM - 0.01229577675440491*lm*NM + 
        0.0074132311334609725*lm^2*NM + 0.019750746203512616*NL - 
        0.01229577675440491*lm*NL + 0.0074132311334609725*lm^2*NL + 
        0.012585051411921254*NH - 0.01229577675440491*lm*NH + 
        0.0074132311334609725*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(0.014761964464241757 + 0.016000599570963756*lm - 
          0.04057577158783772*lm^2) + CF*(0.33905290708976094 - 
          0.09962159250237425*lm + 0.06639671714373445*lm^2) + 
        0.016107770424132653*NM - 0.012298634669592221*lm*NM + 
        0.007377413015970494*lm^2*NM + 0.019727817676334403*NL - 
        0.012298634669592221*lm*NL + 0.007377413015970494*lm^2*NL + 
        0.012612763538640971*NH - 0.012298634669592221*lm*NH + 
        0.007377413015970494*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(0.0144326547944285 + 0.01626594548235063*lm - 
          0.04037934312807294*lm^2) + CF*(0.3380525827569097 - 
          0.09970027562440824*lm + 0.06607528875502844*lm^2) + 
        0.01605492686332126*NM - 0.01230142486113848*lm*NM + 
        0.007341698750558716*lm^2*NM + 0.019704450382083804*NL - 
        0.01230142486113848*lm*NL + 0.007341698750558716*lm^2*NL + 
        0.012640240818144667*NH - 0.01230142486113848*lm*NH + 
        0.007341698750558716*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(0.014109357281307239 + 0.016530141355363744*lm - 
          0.04018350067666565*lm^2) + CF*(0.33705027228869666 - 
          0.09977813749216362*lm + 0.06575481928908924*lm^2) + 
        0.016002417931351574*NM - 0.012304141560038352*lm*NM + 
        0.007306091032121027*lm^2*NM + 0.019680664526987662*NL - 
        0.012304141560038352*lm*NL + 0.007306091032121027*lm^2*NL + 
        0.012667481565084817*NH - 0.012304141560038352*lm*NH + 
        0.007306091032121027*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(0.013791910409375314 + 0.01679313851900452*lm - 
          0.039988258447129055*lm^2) + CF*(0.3360461880436442 - 
          0.09985512418747239*lm + 0.065435332004393*lm^2) + 
        0.01595025586056096*NM - 0.012306779206096801*lm*NM + 
        0.007270592444932556*lm^2*NM + 0.01965647965389226*NL - 
        0.012306779206096801*lm*NL + 0.007270592444932556*lm^2*NL + 
        0.012694484161791683*NH - 0.012306779206096801*lm*NH + 
        0.007270592444932556*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(0.013480156819071448 + 0.017054890180858456*lm - 
          0.03979363006243611*lm^2) + CF*(0.3350405366699244 - 
          0.09993118379738414*lm + 0.06511684919307727*lm^2) + 
        0.015898452117390674*NM - 0.012309332444025595*lm*NM + 
        0.007235205465897474*lm^2*NM + 0.0196319146605874*NL - 
        0.012309332444025595*lm*NL + 0.007235205465897474*lm^2*NL + 
        0.01272124705784792*NH - 0.012309332444025595*lm*NH + 
        0.007235205465897474*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(0.01317394322181227 + 0.017315351383382048*lm - 
          0.039599628572399424*lm^2) + CF*(0.3340335192047387 - 
          0.10000626637409189*lm + 0.06479939220938087*lm^2) + 
        0.015847017430508266*NM - 0.012311796119517264*lm*NM + 
        0.007199932467708986*lm^2*NM + 0.019606987817743813*NL - 
        0.012311796119517264*lm*NL + 0.007199932467708986*lm^2*NL + 
        0.012747768769613982*NH - 0.012311796119517264*lm*NH + 
        0.007199932467708986*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(0.012873120315560583 + 0.01757447896071426*lm - 
          0.0394062664705731*lm^2) + CF*(0.3330253311736837 - 
          0.10008032389485066*lm + 0.06448298149730143*lm^2) + 
        0.015795961818121842*NM - 0.012314165275303804*lm*NM + 
        0.00716477572192238*lm^2*NM + 0.01958171678646502*NL - 
        0.012314165275303804*lm*NL + 0.00716477572192238*lm^2*NL + 
        0.012774047879707725*NH - 0.012314165275303804*lm*NH + 
        0.00716477572192238*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(0.01257754270101151 + 0.01783223149603318*lm - 
          0.03921355571068898*lm^2) + CF*(0.33201616268999234 - 
          0.10015331022194592*lm + 0.06416763661749106*lm^2) + 
        0.015745294614501693*NM - 0.012316435147206787*lm*NM + 
        0.0071297374019434505*lm^2*NM + 0.019556118635455293*NL - 
        0.012316435147206787*lm*NL + 0.0071297374019434505*lm^2*NL + 
        0.012800083036441512*NH - 0.012316435147206787*lm*NH + 
        0.0071297374019434505*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(0.012287068798474726 + 0.018088569279476344*lm - 
          0.039021507722639986*lm^2) + CF*(0.33100619855355135 - 
          0.10022518106276423*lm + 0.06385337627341088*lm^2) + 
        0.015695024495725133*NM - 0.012318601160185117*lm*NM + 
        0.007094819585934543*lm^2*NM + 0.01953020985780596*NL - 
        0.012318601160185117*lm*NL + 0.007094819585934543*lm^2*NL + 
        0.01282587295321985*NH - 0.012318601160185117*lm*NH + 
        0.007094819585934543*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(0.012001560765523571 + 0.018343454266640795*lm - 
          0.03883013342802245*lm^2) + CF*(0.3299956183495988 - 
          0.10029589393001481*lm + 0.063540218336764*lm^2) + 
        0.01564515950466044*NM - 0.012320658924386165*lm*NM + 
        0.007060024259640444*lm^2*NM + 0.019504006387402774*NL - 
        0.012320658924386165*lm*NL + 0.007060024259640444*lm^2*NL + 
        0.012851416407900568*NH - 0.012320658924386165*lm*NH + 
        0.007060024259640444*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(0.011720884415474883 + 0.018596850037677148*lm - 
          0.03863944325524935*lm^2) + CF*(0.3289845965470141 - 
          0.10036540810214614*lm + 0.06322817987222622*lm^2) + 
        0.015595707075205903*NM - 0.012322604231205613*lm*NM + 
        0.007025353319136246*lm^2*NM + 0.01947752361495748*NL - 
        0.012322604231205613*lm*NL + 0.007025353319136246*lm^2*NL + 
        0.012876712242122305*NH - 0.012322604231205613*lm*NH + 
        0.007025353319136246*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(0.011444909136756973 + 0.01884872175698987*lm - 
          0.038449447154246*lm^2) + CF*(0.3279733025961178 - 
          0.10043368458399891*lm + 0.06291727716149347*lm^2) + 
        0.015546674055800113*NM - 0.01232443304936087*lm*NM + 
        0.0069908085734992735*lm^2*NM + 0.01945077640366723*NL - 
        0.01232443304936087*lm*NL + 0.0069908085734992735*lm^2*NL + 
        0.012901759360600994*NH - 0.01232443304936087*lm*NH + 
        0.0069908085734992735*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(0.011173507813217163 + 0.01909903613355427*lm - 
          0.038260154610739255*lm^2) + CF*(0.32696190102590483 - 
          0.10050068606773259*lm + 0.06260752572666424*lm^2) + 
        0.015498066732219578*NM - 0.012326141520982587*lm*NM + 
        0.006956391747407137*lm^2*NM + 0.019423779104505684*NL - 
        0.012326141520982587*lm*NL + 0.006956391747407137*lm^2*NL + 
        0.01292655673039789*NH - 0.012326141520982587*lm*NH + 
        0.006956391747407137*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(0.010906556745414662 + 0.01934776138185912*lm - 
          0.03807157466015134*lm^2) + CF*(0.3259505515406401 - 
          0.10056637689405992*lm + 0.062298940352974924*lm^2) + 
        0.015449890849679784*NM - 0.012327725957728415*lm*NM + 
        0.006922104483663881*lm^2*NM + 0.0193965455711501*NL - 
        0.012327725957728415*lm*NL + 0.006922104483663881*lm^2*NL + 
        0.012951103380161536*NH - 0.012327725957728415*lm*NH + 
        0.006922104483663881*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(0.010643935572939389 + 0.019594867183482113*lm - 
          0.0378837159011089*lm^2) + CF*(0.32493940911575114 - 
          0.10063072301382073*lm + 0.06199153511090548*lm^2) + 
        0.015402151634255743*NM - 0.012329182836922775*lm*NM + 
        0.006887948345656164*lm^2*NM + 0.019369089174548947*NL - 
        0.012329182836922775*lm*NL + 0.006887948345656164*lm^2*NL + 
        0.01297539839934597*NH - 0.012329182836922775*lm*NH + 
        0.006887948345656164*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(0.010385527197792507 + 0.01984032464930422*lm - 
          0.037696586508577594*lm^2) + CF*(0.3239286240929558 - 
          0.10069369194992338*lm + 0.06168532337767242*lm^2) + 
        0.015354853813638035*NM - 0.01233050879772616*lm*NM + 
        0.006853924819741381*lm^2*NM + 0.01934142281713481*NL - 
        0.01233050879772616*lm*NL + 0.006853924819741381*lm^2*NL + 
        0.012999440937407358*NH - 0.01233050879772616*lm*NH + 
        0.006853924819741381*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(0.010131217708859866 + 0.02008410628236736*lm - 
          0.037510194246632426*lm^2) + CF*(0.322918342274571 - 
          0.10075525275967966*lm + 0.06138031785812578*lm^2) + 
        0.015308001637240214*NM - 0.012331700637337106*lm*NM + 
        0.006820035317569532*lm^2*NM + 0.019313558946687594*NL - 
        0.012331700637337106*lm*NL + 0.006820035317569532*lm^2*NL + 
        0.013023230202981103*NH - 0.012331700637337106*lm*NH + 
        0.006820035317569532*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(0.00988089630750548 + 0.020326185941378864*lm - 
          0.037324546480873674*lm^2) + CF*(0.3219087050169488 - 
          0.1008153759975566*lm + 0.06107653060506601*lm^2) + 
        0.015261598895673358*NM - 0.012332755307229734*lm*NM + 
        0.006786281178340668*lm^2*NM + 0.019285509569853226*NL - 
        0.012332755307229734*lm*NL + 0.006786281178340668*lm^2*NL + 
        0.013046765463041421*NH - 0.012332755307229734*lm*NH + 
        0.006786281178340668*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(0.009634455234308118 + 0.020566538804864882*lm - 
          0.03713965019049794*lm^2) + CF*(0.3208998493229942 - 
          0.10087403367836607*lm + 0.06077397303899663*lm^2) + 
        0.015215648939603395*NM - 0.0123336699094295*lm*NM + 
        0.0067526636709996255*lm^2*NM + 0.019257286265323248*NL - 
        0.0123336699094295*lm*NL + 0.0067526636709996255*lm^2*NL + 
        0.013070046042045211*NH - 0.0123336699094295*lm*NH + 
        0.0067526636709996255*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(0.009391789696960667 + 0.020805141335973918*lm - 
          0.03695551198003375*lm^2) + CF*(0.31989190793372085 - 
          0.10093119924091097*lm + 0.06047265596732796*lm^2) + 
        0.01517015469800666*NM - 0.012334441692829514*lm*NM + 
        0.006719183996369773*lm^2*NM + 0.019228900196680734*NL - 
        0.012334441692829514*lm*NL + 0.006719183996369773*lm^2*NL + 
        0.013093071321062006*NH - 0.012334441692829514*lm*NH + 
        0.006719183996369773*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(0.009152797799348432 + 0.02104197124793067*lm - 
          0.03677213809075079*lm^2) + CF*(0.31888500941880543 - 
          0.10098684751210492*lm + 0.06017258960304675*lm^2) + 
        0.015125118695838963*NM - 0.012335068049549562*lm*NM + 
        0.006685843289227417*lm^2*NM + 0.019200362124918262*NL - 
        0.012335068049549562*lm*NL + 0.006685843289227417*lm^2*NL + 
        0.013115840736891666*NH - 0.012335068049549562*lm*NH + 
        0.006685843289227417*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(0.008917380471819506 + 0.021277007470139483*lm - 
          0.03658953441175159*lm^2) + CF*(0.31787927826610496 - 
          0.1010409546715803*lm + 0.05987378358286624*lm^2) + 
        0.0150805430711333*NM - 0.012335546511339777*lm*NM + 
        0.0066526426203184705*lm^2*NM + 0.01917168242063353*NL - 
        0.012335546511339777*lm*NL + 0.0066526426203184705*lm^2*NL + 
        0.0131383537811714*NH - 0.012335546511339777*lm*NH + 
        0.0066526426203184705*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(0.008685441402657526 + 0.02151023011493585*lm - 
          0.036407706490754387*lm^2) + CF*(0.3168748349701051 - 
          0.1010934982167976*lm + 0.059576246984870816*lm^2) + 
        0.015036429591541072*NM - 0.012335874746030675*lm*NM + 
        0.006619582998318979*lm^2*NM + 0.01914287107590857*NL - 
        0.012335874746030675*lm*NL + 0.006619582998318979*lm^2*NL + 
        0.013160609999473615*NH - 0.012335874746030675*lm*NH + 
        0.006619582998318979*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(0.008456886970764368 + 0.02174162044498368*lm - 
          0.03622665954457551*lm^2) + CF*(0.3158717961192704 - 
          0.10114445692866782*lm + 0.05927998834566902*lm^2) + 
        0.014992779670331472*NM - 0.012336050554031036*lm*NM + 
        0.006586665371741002*lm^2*NM + 0.01911393771587827*NL - 
        0.012336050554031036*lm*NL + 0.006586665371741002*lm^2*NL + 
        0.013182608990395996*NH - 0.012336050554031036*lm*NH + 
        0.006586665371741002*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(0.008231626179558024 + 0.02197116084131529*lm - 
          0.03604639846931947*lm^2) + CF*(0.31487027448227045 - 
          0.10119381083769746*lm + 0.05898501567706823*lm^2) + 
        0.014949594381863562*NM - 0.012336071864875056*lm*NM + 
        0.006553890630785359*lm^2*NM + 0.019084891609994253*NL - 
        0.012336071864875056*lm*NL + 0.006553890630785359*lm^2*NL + 
        0.01320435040464518*NH - 0.012336071864875056*lm*NH + 
        0.006553890630785359*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(0.008009570592088554 + 0.02219883477201052*lm - 
          0.03586692785028477*lm^2) + CF*(0.3138703790930596 - 
          0.10124154119066486*lm + 0.058691336482284175*lm^2) + 
        0.01490687447654516*NM - 0.012335936733819877*lm*NM + 
        0.006521259609142686*lm^2*NM + 0.019055741682989933*NL - 
        0.012335936733819877*lm*NL + 0.006521259609142686*lm^2*NL + 
        0.013225833944115256*NH - 0.012335936733819877*lm*NH + 
        0.006521259609142686*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(0.007790634267372979 + 0.02242462676151065*lm - 
          0.03568825197159311*lm^2) + CF*(0.3128722153347891 - 
          0.1012876304178347*lm + 0.05839895777169781*lm^2) + 
        0.014864620395292592*NM - 0.012335643338494556*lm*NM + 
        0.006488773085744201*lm^2*NM + 0.019026496525552824*NL - 
        0.012335643338494556*lm*NL + 0.006488773085744201*lm^2*NL + 
        0.013247059360962316*NH - 0.012335643338494556*lm*NH + 
        0.006488773085744201*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(0.007574733697948072 + 0.022648522360562424*lm - 
          0.03551037482554963*lm^2) + CF*(0.3118758850225357 - 
          0.10133206210071677*lm + 0.058107886078172126*lm^2) + 
        0.014822832283505005*NM - 0.012335189975601348*lm*NM + 
        0.00645643178646357*lm^2*NM + 0.018997164404709943*NL - 
        0.012335189975601348*lm*NL + 0.00645643178646357*lm^2*NL + 
        0.013268026456676161*NH - 0.012335189975601348*lm*NH + 
        0.00645643178646357*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(0.007361787748638226 + 0.022870508116786828*lm - 
          0.03533330012174152*lm^2) + CF*(0.3108814864848298 - 
          0.10137482094037342*lm + 0.057818127471940664*lm^2) + 
        0.014781510004566704*NM - 0.012334575057670022*lm*NM + 
        0.006424236385771185*lm^2*NM + 0.018967753273932415*NL - 
        0.012334575057670022*lm*NL + 0.006424236385771185*lm^2*NL + 
        0.01328873508115023*NH - 0.012334575057670022*lm*NH + 
        0.006424236385771185*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(0.00715171759653402 + 0.023090571545866925*lm - 
          0.03515703129588202*lm^2) + CF*(0.30988911464397195 - 
          0.10141589272627945*lm + 0.05752968757507966*lm^2) + 
        0.014740653152890762*NM - 0.012333797109865858*lm*NM + 
        0.006392187508342185*lm^2*NM + 0.01893827078296505*NL - 
        0.012333797109865858*lm*NL + 0.006392187508342185*lm^2*NL + 
        0.013309185131750756*NH - 0.012333797109865858*lm*NH + 
        0.006392187508342185*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(0.006944446672175583 + 0.02330870110334864*lm - 
          0.03498157151840699*lm^2) + CF*(0.3088988610951261 - 
          0.10145526430573687*lm + 0.05724257157557507*lm^2) + 
        0.014700261066516833*NM - 0.012332854766851782*lm*NM + 
        0.006360285730619452*lm^2*NM + 0.018908724287386994*NL - 
        0.012332854766851782*lm*NL + 0.006360285730619452*lm^2*NL + 
        0.013329376552386075*NH - 0.012332854766851782*lm*NH + 
        0.006360285730619452*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(0.006739900601933559 + 0.023524886157047925*lm - 
          0.03480692370283065*lm^2) + CF*(0.3079108141841817 - 
          0.1014929235538463*lm + 0.056956784240995616*lm^2) + 
        0.014660332839275892*NM - 0.012331746769705063*lm*NM + 
        0.006328531582332846*lm^2*NM + 0.018879120857909184*NL - 
        0.012331746769705063*lm*NL + 0.006328531582332846*lm^2*NL + 
        0.013349309332576987*NH - 0.012331746769705063*lm*NH + 
        0.006328531582332846*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(0.006538007151579228 + 0.02373911696005758*lm - 
          0.03463309051386715*lm^2) + CF*(0.30692505908437756 - 
          0.10152885934403559*lm + 0.05667232993178261*lm^2) + 
        0.01462086733253431*NM - 0.012330471962888818*lm*NM + 
        0.006296925547975845*lm^2*NM + 0.018849467289414557*NL - 
        0.012330471962888818*lm*NL + 0.006296925547975845*lm^2*NL + 
        0.013368983506528992*NH - 0.012330471962888818*lm*NH + 
        0.006296925547975845*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(0.006338696171034243 + 0.023951384624346504*lm - 
          0.03446007437532435*lm^2) + CF*(0.3059416778716834 - 
          0.10156306151914578*lm + 0.05638921261416711*lm^2) + 
        0.01458186318652945*NM - 0.012329029291278552*lm*NM + 
        0.00626546806824079*lm^2*NM + 0.018819770109746763*NL - 
        0.012329029291278552*lm*NL + 0.00626546806824079*lm^2*NL + 
        0.013388399152207178*NH - 0.012329029291278552*lm*NH + 
        0.00626546806824079*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(0.006141899540289432 + 0.02416168109494404*lm - 
          0.034287877477776084*lm^2) + CF*(0.30496074959893477 - 
          0.10159552086307341*lm + 0.0561074358727245*lm^2) + 
        0.014543318831308681*NM - 0.012327417797243796*lm*NM + 
        0.0062341595414138334*lm^2*NM + 0.018790035588253148*NL - 
        0.012327417797243796*lm*NL + 0.0062341595414138334*lm^2*NL + 
        0.013407556390414488*NH - 0.012327417797243796*lm*NH + 
        0.0062341595414138334*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(0.005947551116481195 + 0.024369999124701794*lm - 
          0.03411650178601903*lm^2) + CF*(0.3039823503687213 - 
          0.10162622907296795*lm + 0.055827002922576585*lm^2) + 
        0.014505232497283449*NM - 0.012325636617784894*lm*NM + 
        0.006203000324730732*lm^2*NM + 0.018760269744087656*NL - 
        0.012325636617784894*lm*NL + 0.006203000324730732*lm^2*NL + 
        0.013426455383874061*NH - 0.012325636617784894*lm*NH + 
        0.006203000324730732*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(0.005755586682113232 + 0.024576332249625073*lm - 
          0.03394594904631989*lm^2) + CF*(0.3030065534050271 - 
          0.10165517873198197*lm + 0.05554791662125072*lm^2) + 
        0.014467602225409786*NM - 0.012323684981724863*lm*NM + 
        0.006171990735694525*lm^2*NM + 0.01873047835427933*NL - 
        0.012323684981724863*lm*NL + 0.006171990735694525*lm^2*NL + 
        0.013445096336316272*NH - 0.012323684981724863*lm*NH + 
        0.006171990735694525*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(0.00556594389441058 + 0.02478067476476596*lm - 
          0.03377622079345891*lm^2) + CF*(0.3020334291236252 - 
          0.10168236328257159*lm + 0.05527017948020549*lm^2) + 
        0.014430425877006355*NM - 0.012321562206956203*lm*NM + 
        0.006141131053356165*lm^2*NM + 0.018700666961571903*NL - 
        0.012321562206956203*lm*NL + 0.006141131053356165*lm^2*NL + 
        0.013463479491571069*NH - 0.012321562206956203*lm*NH + 
        0.006141131053356165*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(0.005378562235792295 + 0.024983021700669853*lm - 
          0.03360731835757511*lm^2) + CF*(0.30106304520122873 - 
          0.10170777700034364*lm + 0.05499379367603201*lm^2) + 
        0.014393701143220907*NM - 0.012319267697742478*lm*NM + 
        0.0061104215195591114*lm^2*NM + 0.018670840882040008*NL - 
        0.012319267697742478*lm*NL + 0.0061104215195591114*lm^2*NL + 
        0.013481605132666176*NH - 0.012319267697742478*lm*NH + 
        0.0061104215195591114*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(0.005193382965448533 + 0.02518336880036714*lm - 
          0.03343924287081877*lm^2) + CF*(0.3000954666434025 - 
          0.10173141496844632*lm + 0.054718761061339806*lm^2) + 
        0.01435742555415571*NM - 0.012316800942074402*lm*NM + 
        0.0060798623401488675*lm^2*NM + 0.018641005212487353*NL - 
        0.012316800942074402*lm*NL + 0.0060798623401488675*lm^2*NL + 
        0.013499473580931657*NH - 0.012316800942074402*lm*NH + 
        0.0060798623401488675*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(0.005010349072007252 + 0.025381712496901694*lm - 
          0.03327199527381639*lm^2) + CF*(0.29913075585123966 - 
          0.10175327305249855*lm + 0.05444508317533592*lm^2) + 
        0.014321596487662316*NM - 0.012314161509080135*lm*NM + 
        0.006049453686148435*lm^2*NM + 0.018611164837632265*NL - 
        0.012314161509080135*lm*NL + 0.006049453686148435*lm^2*NL + 
        0.01351708519511134*NH - 0.012314161509080135*lm*NH + 
        0.006049453686148435*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(0.004829405227275349 + 0.025578049891387556*lm - 
          0.033105576321953406*lm^2) + CF*(0.29816897268681075 - 
          0.10177334787605398*lm + 0.05417276125410558*lm^2) + 
        0.014286211177815738*NM - 0.012311349046489435*lm*NM + 
        0.0060191956949006194*lm^2*NM + 0.018581324437085756*NL - 
        0.012311349046489435*lm*NL + 0.0060191956949006194*lm^2*NL + 
        0.013534440370481543*NH - 0.012311349046489435*lm*NH + 
        0.0060191956949006194*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(0.0046504977410386054 + 0.025772378731585367*lm - 
          0.032939986591479495*lm^2) + CF*(0.29721017453739024 - 
          0.10179163679659431*lm + 0.05390179624060281*lm^2) + 
        0.014251266723077848*NM - 0.012308363278151272*lm*NM + 
        0.00598908847117809*lm^2*NM + 0.018551488492127347*NL - 
        0.012308363278151272*lm*NL + 0.00598908847117809*lm^2*NL + 
        0.013551539537977497*NH - 0.012308363278151272*lm*NH + 
        0.00598908847117809*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(0.0044735745169044985 + 0.02596469739098982*lm - 
          0.03277522648544147*lm^2) + CF*(0.2962544163784702 - 
          0.10180813788204683*lm + 0.05363218879435877*lm^2) + 
        0.014216760094159602*NM - 0.012305204001604439*lm*NM + 
        0.005959132088262086*lm^2*NM + 0.01852166129228366*NL - 
        0.012305204001604439*lm*NL + 0.005959132088262086*lm^2*NL + 
        0.013568383163327877*NH - 0.012305204001604439*lm*NH + 
        0.005959132088262086*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(0.004298585009171677 + 0.026155004848419514*lm - 
          0.03261129623944845*lm^2) + CF*(0.29530175083556887 - 
          0.10182284988782045*lm + 0.05336393930091565*lm^2) + 
        0.014182688141591439*NM - 0.012301871085700711*lm*NM + 
        0.0059293265889906275*lm^2*NM + 0.01849184694171483*NL - 
        0.012301871085700711*lm*NL + 0.0059293265889906275*lm^2*NL + 
        0.013584971746197763*NH - 0.012301871085700711*lm*NH + 
        0.0059293265889906275*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(0.004125480180709604 + 0.026343300668100506*lm - 
          0.03244819592727392*lm^2) + CF*(0.2943522282448436 - 
          0.10183577223435446*lm + 0.053097047880993696*lm^2) + 
        0.0141490476030109*NM - 0.012298364468280008*lm*NM + 
        0.005899671986777077*lm^2*NM + 0.01846204936541354*NL - 
        0.012298364468280008*lm*NL + 0.005899671986777077*lm^2*NL + 
        0.013601305819340376*NH - 0.012298364468280008*lm*NH + 
        0.005899671986777077*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(0.003954212461831738 + 0.02652958498023483*lm - 
          0.032285925466299166*lm^2) + CF*(0.29340589671251904 - 
          0.10184690498517367*lm + 0.05283151439939864*lm^2) + 
        0.014115835110176386*NM - 0.01229468415389705*lm*NM + 
        0.005870168266599849*lm^2*NM + 0.01843227231522162*NL - 
        0.01229468415389705*lm*NL + 0.005870168266599849*lm^2*NL + 
        0.013617385947757864*NH - 0.01229468415389705*lm*NH + 
        0.005870168266599849*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(0.0037847357101454104 + 0.026713858462045322*lm - 
          0.03212448462280244*lm^2) + CF*(0.2924628021731408 - 
          0.10185624882544388*lm + 0.05256733847367672*lm^2) + 
        0.014083047195715643*NM - 0.012290830211598889*lm*NM + 
        0.00584081538596408*lm^2*NM + 0.01840251937566878*NL - 
        0.012290830211598889*lm*NL + 0.00584081538596408*lm^2*NL + 
        0.013633212727871429*NH - 0.012290830211598889*lm*NH + 
        0.00584081538596408*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(0.003617005171361495 + 0.026896122319287997*lm - 
          0.03196387301709811*lm^2) + CF*(0.29152298844666613 - 
          0.10186380504102074*lm + 0.05230451948252419*lm^2) + 
        0.014050680299617379*NM - 0.012286802772752752*lm*NM + 
        0.005811613275836021*lm^2*NM + 0.018372793969638222*NL - 
        0.012286802772752752*lm*NL + 0.005811613275836021*lm^2*NL + 
        0.013648786786701006*NH - 0.012286802772752752*lm*NH + 
        0.005811613275836021*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(0.003450977441046836 + 0.027076378268223344*lm - 
          0.031804090128529916*lm^2) + CF*(0.2905864972944039 - 
          0.10186957549798574*lm + 0.05204305657395805*lm^2) + 
        0.014018730775474187*NM - 0.012282602028923565*lm*NM + 
        0.005782561841550894*lm^2*NM + 0.018343099363863597*NL - 
        0.012282602028923565*lm*NL + 0.005782561841550894*lm^2*NL + 
        0.013664108781054776*NH - 0.012282602028923565*lm*NH + 
        0.005782561841550894*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(0.0032866104273023868 + 0.0272546285180379*lm - 
          0.03164513530032232*lm^2) + CF*(0.2896533684738159 - 
          0.10187356262266191*lm + 0.051782948673254704*lm^2) + 
        0.013987194896484713*NM - 0.012278228229800485*lm*NM + 
        0.0057536609636949666*lm^2*NM + 0.01831343867426179*NL - 
        0.012278228229800485*lm*NL + 0.0057536609636949666*lm^2*NL + 
        0.013679179396728629*NH - 0.012278228229800485*lm*NH + 
        0.0057536609636949666*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(0.0031238633143499664 + 0.027430875753707465*lm - 
          0.03148700774429386*lm^2) + CF*(0.28872363979219257 - 
          0.10187576938210276*lm + 0.05152419449066268*lm^2) + 
        0.013956068861222802*NM - 0.012273681681171838*lm*NM + 
        0.00572491049896252*lm^2*NM + 0.018283814871105863*NL - 
        0.012273681681171838*lm*NL + 0.00572491049896252*lm^2*NL + 
        0.013693999347715832*NH - 0.012273681681171838*lm*NH + 
        0.00572491049896252*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(0.0029626965270105605 + 0.02760512311929345*lm - 
          0.03132970654543638*lm^2) + CF*(0.28779734715921695 - 
          0.10187619926504686*lm + 0.0512667925288959*lm^2) + 
        0.01392534879918116*NM - 0.012268962742947724*lm*NM + 
        0.005696310280988433*lm^2*NM + 0.018254230784042424*NL - 
        0.012268962742947724*lm*NL + 0.005696310280988433*lm^2*NL + 
        0.013708569375427025*NH - 0.012268962742947724*lm*NH + 
        0.005696310280988433*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(0.0028030716960571215 + 0.02777737420166384*lm - 
          0.031173230666363672*lm^2) + CF*(0.2868745246384291 - 
          0.10187485626333127*lm + 0.05101074109041328*lm^2) + 
        0.01389503077609679*NM - 0.012264071827229647*lm*NM + 
        0.005667860121157032*lm^2*NM + 0.01822468910695761*NL - 
        0.012264071827229647*lm*NL + 0.005667860121157032*lm^2*NL + 
        0.013722890247920682*NH - 0.012264071827229647*lm*NH + 
        0.005667860121157032*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(0.0026449516244248746 + 0.027947633014630345*lm - 
          0.03101757895163326*lm^2) + CF*(0.28595520449760703 - 
          0.10187174485375614*lm + 0.05075603828449079*lm^2) + 
        0.01386511079906537*NM - 0.012259009396426436*lm*NM + 
        0.0056395598093878655*lm^2*NM + 0.01819519240269574*NL - 
        0.012259009396426436*lm*NL + 0.0056395598093878655*lm^2*NL + 
        0.013736962759144173*NH - 0.012259009396426436*lm*NH + 
        0.0056395598093878655*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(0.0024883002542622134 + 0.02811590398349341*lm - 
          0.030862750131944748*lm^2) + CF*(0.28503941725807647 - 
          0.10186686998039335*lm + 0.0505026820340914*lm^2) + 
        0.013835584821451419*NM - 0.012253775961415768*lm*NM + 
        0.0056114091148990455*lm^2*NM + 0.018165743107634653*NL - 
        0.012253775961415768*lm*NL + 0.0056114091148990455*lm^2*NL + 
        0.013750787728185526*NH - 0.012253775961415768*lm*NH + 
        0.0056114091148990455*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(0.00233308263480536 + 0.028282191929986728*lm - 
          0.030708742828218165*lm^2) + CF*(0.284127191742965 - 
          0.10186023703733182*lm + 0.05025067008253882*lm^2) + 
        0.013806448747601*NM - 0.01224837207975055*lm*NM + 
        0.005583407786948757*lm^2*NM + 0.018136343536121622*NL - 
        0.01224837207975055*lm*NL + 0.005583407786948757*lm^2*NL + 
        0.013764365998535989*NH - 0.01224837207975055*lm*NH + 
        0.005583407786948757*lm^2*NH)}, {1., 6.697959533607682*^-8*CF*NC*
       (108.*CF*(39152.13306039918 - 14080.*lm + 6912.*lm^2) - 
        6.*CA*(-5422.708413722624 - 70784.*lm + 76032.*lm^2) + 
        205699.93545396117*NM - 182784.*lm*NM + 82944.*lm^2*NM + 
        270336.*NL - 182784.*lm*NL + 82944.*lm^2*NL + 
        205699.93545396117*NH - 182784.*lm*NH + 82944.*lm^2*NH)}}
 
CbarLTable["a", 2, 2] = {{0., -1.286008230452675*^-7*CF*NC*
       (CF*(-769577.7091909414 - 97666.17974587942*lm - 777600.*lm^2) + 
        4.*CA*(-6575.71205023619 + 127610.61095281024*lm + 59400.*lm^2) + 
        20.*((-5945.359133912704 - 1891.294943738554*lm - 2160.*lm^2)*NM + 
          (-5945.359133912704 - 1891.294943738554*lm - 2160.*lm^2)*NL + 
          (987.1190910339575 - 1891.294943738554*lm - 2160.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(0.008840611369134615 - 0.06612952241034928*lm - 
          0.03131158198618361*lm^2) + CF*(0.10449074134663003 + 
          0.009146394244340857*lm + 0.10247426831841909*lm^2) + 
        0.01487650141946247*NM + 0.004777894193508621*lm*NM + 
        0.005693014906578839*lm^2*NM + 0.014875672668710547*NL + 
        0.004777894193508621*lm*NL + 0.005693014906578839*lm^2*NL - 
        0.0025875104838619244*NH + 0.004777894193508621*lm*NH + 
        0.005693014906578839*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(0.013809262632629138 - 0.06664935795639187*lm - 
          0.032047458010752365*lm^2) + CF*(0.10950743420457441 + 
          0.005976296562963143*lm + 0.10488258985337137*lm^2) + 
        0.014526692990075604*NM + 0.004702124386277315*lm*NM + 
        0.005826810547409521*lm^2*NM + 0.014521381060391721*NL + 
        0.004702124386277315*lm*NL + 0.005826810547409521*lm^2*NL - 
        0.0026353166114350735*NH + 0.004702124386277315*lm*NH + 
        0.005826810547409521*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(0.018215937888496823 - 0.06721036502327712*lm - 
          0.03275874452039975*lm^2) + CF*(0.1140049535232778 + 
          0.003103720565103636*lm + 0.10721043661221737*lm^2) + 
        0.014250637083496661*NM + 0.004639530445792592*lm*NM + 
        0.00595613536734541*lm^2*NM + 0.014236238214308559*NL + 
        0.004639530445792592*lm*NL + 0.00595613536734541*lm^2*NL - 
        0.002682147365255063*NH + 0.004639530445792592*lm*NH + 
        0.00595613536734541*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(0.022055597062615607 - 0.06781123735320677*lm - 
          0.033442541438962435*lm^2) + CF*(0.11802728743904134 + 
          0.0005435892500906517*lm + 0.10944831743660433*lm^2) + 
        0.014046393461072624*NM + 0.0045905459626413275*lm*NM + 
        0.006080462079811351*lm^2*NM + 0.014018516472261613*NL + 
        0.0045905459626413275*lm*NL + 0.006080462079811351*lm^2*NL - 
        0.0027278693969137353*NH + 0.0045905459626413275*lm*NH + 
        0.006080462079811351*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(0.02534803167322552 - 0.06844737154535832*lm - 
          0.03409687050538397*lm^2) + CF*(0.12162866424148444 - 
          0.001706067296286493*lm + 0.11158975801762026*lm^2) + 
        0.01390854293041561*NM + 0.004554791734273817*lm*NM + 
        0.006199431000978904*lm^2*NM + 0.013863498113814491*NL + 
        0.004554791734273817*lm*NL + 0.006199431000978904*lm^2*NL - 
        0.002772365520814909*NH + 0.004554791734273817*lm*NH + 
        0.006199431000978904*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(0.02812427209377023 - 0.06911275111239357*lm - 
          0.0347203964001365*lm^2) + CF*(0.1248624772417904 - 
          0.0036560998016651647*lm + 0.11363038821862856*lm^2) + 
        0.013830340757088173*NM + 0.0045314828534614585*lm*NM + 
        0.006312799345479364*lm^2*NM + 0.013765352466989445*NL + 
        0.0045314828534614585*lm*NL + 0.006312799345479364*lm^2*NL - 
        0.00281553153646737*NH + 0.0045314828534614585*lm*NH + 
        0.006312799345479364*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(0.03042042311240445 - 0.0698008273134137*lm - 
          0.035312261860996376*lm^2) + CF*(0.12777774547099421 - 
          0.00532226557476259*lm + 0.11556740245416997*lm^2) + 
        0.01380465700686377*NM + 0.004519627014770271*lm*NM + 
        0.006420411247453887*lm^2*NM + 0.013717934408449756*NL + 
        0.004519627014770271*lm*NL + 0.006420411247453887*lm^2*NL - 
        0.0028572745221616728*NH + 0.004519627014770271*lm*NH + 
        0.006420411247453887*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(0.03227444929086939 - 0.07050498481168184*lm - 
          0.03587197777778099*lm^2) + CF*(0.13041806607945844 - 
          0.006722976979971641*lm + 0.11739920000001053*lm^2) + 
        0.013824440999311365*NM + 0.004518134612224237*lm*NM + 
        0.006522177777778363*lm^2*NM + 0.013715170177757115*NL + 
        0.004518134612224237*lm*NL + 0.006522177777778363*lm^2*NL - 
        0.0028975117527229397*NH + 0.004518134612224237*lm*NH + 
        0.006522177777778363*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(0.03372437638230334 - 0.07121880178998552*lm - 
          0.03639934460198911*lm^2) + CF*(0.13282153572519317 - 
          0.007877929895529023*lm + 0.119125127788328*lm^2) + 
        0.013882961056813687*NM + 0.004525884219206498*lm*NM + 
        0.006618062654907111*lm^2*NM + 0.013751252655313186*NL + 
        0.004525884219206498*lm*NL + 0.006618062654907111*lm^2*NL - 
        0.0029361699235442916*NH + 0.004525884219206498*lm*NH + 
        0.006618062654907111*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(0.034807252727444844 - 0.07193619708421274*lm - 
          0.03689439350758181*lm^2) + CF*(0.1350210683635084 - 
          0.008807232679543671*lm + 0.120745287842995*lm^2) + 
        0.013973926373096026*NM + 0.004541762955705699*lm*NM + 
        0.006708071546833056*lm^2*NM + 0.013820738713773848*NL + 
        0.004541762955705699*lm*NL + 0.006708071546833056*lm^2*NL - 
        0.0029731845380982906*NH + 0.004541762955705699*lm*NH + 
        0.006708071546833056*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(0.035558549152457306 - 0.07265151092527271*lm - 
          0.03735734090683814*lm^2) + CF*(0.13704486622620682 - 
          0.009530840826193017*lm + 0.12226038842237937*lm^2) + 
        0.01409154294528673*NM + 0.00456469169392175*lm*NM + 
        0.006792243801243298*lm^2*NM + 0.013918592821423386*NL + 
        0.00456469169392175*lm*NL + 0.006792243801243298*lm^2*NL - 
        0.003008499387771568*NH + 0.00456469169392175*lm*NH + 
        0.006792243801243298*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(0.03601182453187312 - 0.07335954493370372*lm - 
          0.037788552463506236*lm^2) + CF*(0.13891693345111986 - 
          0.010068187847287758*lm + 0.12367162624420223*lm^2) + 
        0.014230531208418681*NM + 0.004593640657547995*lm*NM + 
        0.0068706459024556795*lm^2*NM + 0.01404019997631349*NL + 
        0.004593640657547995*lm*NL + 0.0068706459024556795*lm^2*NL - 
        0.0030420660862857936*NH + 0.004593640657547995*lm*NH + 
        0.0068706459024556795*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(0.03619855763138362 - 0.07405557642336477*lm - 
          0.03818851412164146*lm^2) + CF*(0.14065758081940088 - 
          0.0104379466758873*lm + 0.1249805916708266*lm^2) + 
        0.014386121045894418*NM + 0.004627638726512925*lm*NM + 
        0.006943366203934811*lm^2*NM + 0.014181360830181806*NL + 
        0.004627638726512925*lm*NL + 0.006943366203934811*lm^2*NL - 
        0.0030738436379673874*NH + 0.004627638726512925*lm*NH + 
        0.006943366203934811*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(0.036148085126123976 - 0.07473535628941437*lm - 
          0.03855780847214449*lm^2) + CF*(0.1422838980992475 - 
          0.010657880128757388*lm + 0.12618919136338197*lm^2) + 
        0.014554033482013997*NM + 0.0046657785218766155*lm*NM + 
        0.007010510631298998*lm^2*NM + 0.014338276509400835*NL + 
        0.0046657785218766155*lm*NL + 0.007010510631298998*lm^2*NL - 
        0.0031037980283063066*NH + 0.0046657785218766155*lm*NH + 
        0.007010510631298998*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(0.035887608018768516 - 0.07539509640551477*lm - 
          0.03889709527641188*lm^2) + CF*(0.14381018440083262 - 
          0.010744753221669947*lm + 0.12729958454098433*lm^2) + 
        0.014730454766896635*NM + 0.004707218621337128*lm*NM + 
        0.0070721991411657956*lm^2*NM + 0.01450752766546044*NL + 
        0.004707218621337128*lm*NL + 0.0070721991411657956*lm^2*NL - 
        0.0031319018304031723*NH + 0.004707218621337128*lm*NH + 
        0.0070721991411657956*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(0.035442242003419965 - 0.07603145041992818*lm - 
          0.03920709528918721*lm^2) + CF*(0.1452483339881832 - 
          0.010714288928490948*lm + 0.12831413003734*lm^2) + 
        0.014912006437324642*NM + 0.004751183811084113*lm*NM + 
        0.007128562779852222*lm^2*NM + 0.014686050555102649*NL + 
        0.004751183811084113*lm*NL + 0.007128562779852222*lm^2*NL - 
        0.0031581338238771107*NH + 0.004751183811084113*lm*NH + 
        0.007128562779852222*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(0.03483509558596317 - 0.07664149055586855*lm - 
          0.03948857674030665*lm^2) + CF*(0.1466081785455014 - 
          0.010581154618691562*lm + 0.12923534205918538*lm^2) + 
        0.015095713632328235*NM + 0.004796963995872082*lm*NM + 
        0.0071797412255103*lm^2*NM + 0.01487111190348039*NL + 
        0.004796963995872082*lm*NL + 0.0071797412255103*lm^2*NL - 
        0.0031824786245387643*NH + 0.004796963995872082*lm*NH + 
        0.0071797412255103*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(0.034087365065314075 - 0.07722268218558562*lm - 
          0.03974234398663904*lm^2) + CF*(0.14789778861635666 - 
          0.010358970147156766*lm + 0.13006585304718232*lm^2) + 
        0.015278973118552457*NM + 0.004843912202123888*lm*NM + 
        0.007225880724843463*lm^2*NM + 0.015060283652523905*NL + 
        0.004843912202123888*lm*NL + 0.007225880724843463*lm^2*NL - 
        0.0032049263241377035*NH + 0.004843912202123888*lm*NH + 
        0.007225880724843463*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(0.03321843896103613 - 0.07777285738968594*lm - 
          0.03996922795411403*lm^2) + CF*(0.1491237376759001 - 
          0.010060331115121494*lm + 0.13080838239528225*lm^2) + 
        0.01545952194850098*NM + 0.004891441982296678*lm*NM + 
        0.007267132355293459*lm^2*NM + 0.01525141828224028*NL + 
        0.004891441982296678*lm*NL + 0.007267132355293459*lm^2*NL - 
        0.003225472140062142*NH + 0.004891441982296678*lm*NH + 
        0.007267132355293459*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(0.032246006811872785 - 0.07829018833296852*lm - 
          0.04017007806939026*lm^2) + CF*(0.1502913325114871 - 
          0.009696842592777397*lm + 0.1314657100452772*lm^2) + 
        0.015635407325356235*NM + 0.004939024441176695*lm*NM + 
        0.007303650558070957*lm^2*NM + 0.015442625124282615*NL + 
        0.004939024441176695*lm*NL + 0.007303650558070957*lm^2*NL - 
        0.003244116075172522*NH + 0.004939024441176695*lm*NH + 
        0.007303650558070957*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(0.031186168869548586 - 0.07877316102458776*lm - 
          0.04034575544037319*lm^2) + CF*(0.15140481352288884 - 
          0.009279159851257653*lm + 0.1320406541684941*lm^2) + 
        0.015804958015805257*NM + 0.004986185043061828*lm*NM + 
        0.007335591898249671*lm^2*NM + 0.015632247911196804*NL + 
        0.004986185043061828*lm*NL + 0.007335591898249671*lm^2*NL - 
        0.0032608625880922526*NH + 0.004986185043061828*lm*NH + 
        0.007335591898249671*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(0.030053544322113445 - 0.07922054984537079*lm - 
          0.04049712709028242*lm^2) + CF*(0.15246752834687097 - 
          0.00881703355825938*lm + 0.13253605229546975*lm^2) + 
        0.015966757496782225*NM + 0.005032500314630163*lm*NM + 
        0.007363114016414985*lm^2*NM + 0.015818843688611875*NL + 
        0.005032500314630163*lm*NL + 0.007363114016414985*lm^2*NL - 
        0.0032757202743222535*NH + 0.005032500314630163*lm*NH + 
        0.007363114016414985*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(0.028861376459826185 - 0.07963139309392607*lm - 
          0.04062506108521482*lm^2) + CF*(0.1534820819392884 - 
          0.00831935755423425*lm + 0.13295474536979396*lm^2) + 
        0.016119618917699835*NM + 0.005077594526283956*lm*NM + 
        0.0073863747427663305*lm^2*NM + 0.016001163140844255*NL + 
        0.005077594526283956*lm*NL + 0.0073863747427663305*lm^2*NL - 
        0.003288701558530726*NH + 0.005077594526283956*lm*NH + 
        0.0073863747427663305*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(0.027621633747476705 - 0.08000496970948873*lm - 
          0.0407304224228426*lm^2) + CF*(0.15445046595411 - 
          0.007794217816028021*lm + 0.13329956429293943*lm^2) + 
        0.016262561890017048*NM + 0.005121136411315364*lm*NM + 
        0.007405531349607746*lm^2*NM + 0.01617813232985856*NL + 
        0.005121136411315364*lm*NL + 0.007405531349607746*lm^2*NL - 
        0.003299822398320948*NH + 0.005121136411315364*lm*NH + 
        0.007405531349607746*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(0.026345106158907776 - 0.08034077726227846*lm - 
          0.04081406957191845*lm^2) + CF*(0.15537416996674683 - 
          0.007248941580532268*lm + 0.13357331859900584*lm^2) + 
        0.016394791069938457*NM + 0.005162835964929006*lm*NM + 
        0.007420739922166991*lm^2*NM + 0.016348835814733755*NL + 
        0.005162835964929006*lm*NL + 0.007420739922166991*lm^2*NL - 
        0.0033091019997137563*NH + 0.005162835964929006*lm*NH + 
        0.007420739922166991*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(0.025041496408917906 - 0.08063851125395967*lm - 
          0.04087685156998388*lm^2) + CF*(0.1562542768113504 - 
          0.006690145875942631*lm + 0.13377878695631087*lm^2) + 
        0.016515676470311116*NM + 0.005202441352293918*lm*NM + 
        0.00743215483090616*lm^2*NM + 0.01651250109806135*NL + 
        0.005202441352293918*lm*NL + 0.00743215483090616*lm^2*NL - 
        0.0033165625445079677*NH + 0.005202441352293918*lm*NH + 
        0.00743215483090616*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(0.023719505916802986 - 0.08089804573633731*lm - 
          0.04091960560107807*lm^2) + CF*(0.15709154404454698 - 
          0.006123784916313684*lm + 0.13391870923989185*lm^2) + 
        0.016624735419369097*NM + 0.005239735945200289*lm*NM + 
        0.007439928291105103*lm^2*NM + 0.016668484333238334*NL + 
        0.005239735945200289*lm*NL + 0.007439928291105103*lm^2*NL - 
        0.003322228929607556*NH + 0.005239735945200289*lm*NH + 
        0.007439928291105103*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(0.022386915476953196 - 0.08111941523197833*lm - 
          0.04094315498704879*lm^2) + CF*(0.15788647331380554 - 
          0.0055551959732451535*lm + 0.13399577995761422*lm^2) + 
        0.01672161607341918*NM + 0.005274535499720306*lm*NM + 
        0.007444209997645235*lm^2*NM + 0.016816257219813186*NL + 
        0.005274535499720306*lm*NL + 0.007444209997645235*lm^2*NL - 
        0.003326128518332883*NH + 0.005274535499720306*lm*NH + 
        0.007444209997645235*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(0.021050660711035524 - 0.08130279792335195*lm - 
          0.04094830753582166*lm^2) + CF*(0.15863936919760135 - 
          0.004989143459056006*lm + 0.13401264284450726*lm^2) + 
        0.01680608238545398*NM + 0.005306685481906913*lm*NM + 
        0.007445146824694847*lm^2*NM + 0.016955395011107963*NL + 
        0.005306685481906913*lm*NL + 0.007445146824694847*lm^2*NL - 
        0.0033282909036669124*NH + 0.005306685481906913*lm*NH + 
        0.007445146824694847*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(0.01971690244472233 - 0.08144850006540497*lm - 
          0.04093585419810143*lm^2) + CF*(0.15935038889584988 - 
          0.004429861047759338*lm + 0.13397188646651376*lm^2) + 
        0.016878000430327694*NM + 0.005336058544562555*lm*NM + 
        0.0074428825814729874*lm^2*NM + 0.017085565558030084*NL + 
        0.005336058544562555*lm*NL + 0.0074428825814729874*lm^2*NL - 
        0.003328747683327337*NH + 0.005336058544562555*lm*NH + 
        0.0074428825814729874*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(0.0183910921978863 - 0.08155694156881796*lm - 
          0.040906567990779664*lm^2) + CF*(0.1600195839812658 - 
          0.0038810917302694193*lm + 0.13387604069709708*lm^2) + 
        0.01693732598833442*NM + 0.005362552155141855*lm*NM + 
        0.007437557816505393*lm^2*NM + 0.017206519314434808*NL + 
        0.005362552155141855*lm*NL + 0.007437557816505393*lm^2*NL - 
        0.0033275322465024645*NH + 0.005362552155141855*lm*NH + 
        0.007437557816505393*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(0.01707803300666265 - 0.08162864269648334*lm - 
          0.04086120315105219*lm^2) + CF*(0.16064693527358404 - 
          0.003346125753598382*lm + 0.1337275739488981*lm^2) + 
        0.016984093291932074*NM + 0.005386086372670843*lm*NM + 
        0.007429309663827671*lm^2*NM + 0.017318080231993545*NL + 
        0.005386086372670843*lm*NL + 0.007429309663827671*lm^2*NL - 
        0.0033246795720425697*NH + 0.005386086372670843*lm*NH + 
        0.007429309663827671*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(0.015781935813186418 - 0.08166421181323309*lm - 
          0.04080049449010326*lm^2) + CF*(0.16123238176712804 - 
          0.0028278364341521507*lm + 0.13352889105851978*lm^2) + 
        0.01701840484433383*NM + 0.005406601769985427*lm*NM + 
        0.007418271725473321*lm^2*NM + 0.017420137475834714*NL + 
        0.005406601769985427*lm*NL + 0.007418271725473321*lm^2*NL - 
        0.0033202260378590574*NH + 0.005406601769985427*lm*NH + 
        0.007418271725473321*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(0.014506471667413083 - 0.08166433412794386*lm - 
          0.04072515691934364*lm^2) + CF*(0.1617758444262076 - 
          0.002328713865524747*lm + 0.13328233173603374*lm^2) + 
        0.017040422223276286*NM + 0.005424057496472253*lm*NM + 
        0.007404573985335208*lm^2*NM + 0.017512637895951245*NL + 
        0.005424057496472253*lm*NL + 0.007404573985335208*lm^2*NL - 
        0.0033142092412508355*NH + 0.005424057496472253*lm*NH + 
        0.007404573985335208*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(0.01325481998767528 - 0.08162976136742514*lm - 
          0.04063588512572094*lm^2) + CF*(0.16227724556051834 - 
          0.0018508965636538218*lm + 0.13299016950235942*lm^2) + 
        0.0170503577880829*NM + 0.0054384294757286525*lm*NM + 
        0.007388342750131079*lm^2*NM + 0.017595579193300372*NL + 
        0.0054384294757286525*lm*NL + 0.007388342750131079*lm^2*NL - 
        0.0033066678298502338*NH + 0.0054384294757286525*lm*NH + 
        0.007388342750131079*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(0.012029713124392553 - 0.08156130232262498*lm - 
          0.04053335337565044*lm^2) + CF*(0.16273652440240258 - 
          0.0013962011085662408*lm + 0.13265461104758328*lm^2) + 
        0.01704846721279162*NM + 0.005449708732062289*lm*NM + 
        0.007369700613754627*lm^2*NM + 0.017669003723510143*NL + 
        0.005449708732062289*lm*NL + 0.007369700613754627*lm^2*NL - 
        0.003297641342859195*NH + 0.005449708732062289*lm*NH + 
        0.007369700613754627*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(0.010833477466131414 - 0.08145981420941785*lm - 
          0.04041821542972474*lm^2) + CF*(0.1631536494278047 - 
          0.0009661498535541007*lm + 0.13227779595182643*lm^2) + 
        0.01703504277212386*NM + 0.005457899839461984*lm*NM + 
        0.007348766441768135*lm^2*NM + 0.01773299288505188*NL + 
        0.005457899839461984*lm*NL + 0.007348766441768135*lm^2*NL - 
        0.0032871700622297073*NH + 0.005457899839461984*lm*NH + 
        0.007348766441768135*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(0.009668071320309224 - 0.08132619478838585*lm - 
          0.040291104552615*lm^2) + CF*(0.16352862789116424 - 
          0.0005619967805274126*lm + 0.13186179671764908*lm^2) + 
        0.01701040730969487*NM + 0.005463019486539411*lm*NM + 
        0.007325655373202727*lm^2*NM + 0.01778766204257099*NL + 
        0.005463019486539411*lm*NL + 0.007325655373202727*lm^2*NL - 
        0.003275294873430072*NH + 0.005463019486539411*lm*NH + 
        0.007325655373202727*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(0.008535119793544118 - 0.08116137519042177*lm - 
          0.04015263360453158*lm^2) + CF*(0.16386151297912502 - 
          0.0001847515853121709*lm + 0.13140861906937606*lm^2) + 
        0.016974908817849278*NM + 0.005465095150928882*lm*NM + 
        0.007300478837187559*lm^2*NM + 0.017833155939745618*NL + 
        0.005465095150928882*lm*NL + 0.007300478837187559*lm^2*NL - 
        0.0032620571354300696*NH + 0.005465095150928882*lm*NH + 
        0.007300478837187559*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(0.007435946315457392 - 0.08096631339756677*lm - 
          0.04000339520230928*lm^2) + CF^2*(0.16415241007595457 + 
          0.00016479792055130145*lm + 0.1309202024802849*lm^2) + 
        CF*((0.016928916868869597 + 0.0054641638767091655*lm + 
            0.0072733445822380505*lm^2)*NM + (0.017869644559536633 + 
            0.0054641638767091655*lm + 0.0072733445822380505*lm^2)*NL + 
          (-0.0032474985595329687 + 0.0054641638767091655*lm + 
            0.0072733445822380505*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(0.006371603719473579 - 0.08074198833116289*lm - 
          0.039843961939662*lm^2) + CF^2*(0.16440147702523716 + 
          0.00048606500389455714*lm + 0.13039842089343925*lm^2) + 
        CF*((0.016872814624716508 + 0.005460271148554112*lm + 
            0.007244356716302181*lm^2)*NM + (0.01789731939298829 + 
            0.005460271148554112*lm + 0.007244356716302181*lm^2)*NL + 
          (-0.003231661096680148 + 0.005460271148554112*lm + 
            0.007244356716302181*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(0.005342899334486286 - 0.08048939450209289*lm - 
          0.03967488665744272*lm^2) + CF^2*(0.16460893012826577 + 
          0.0007786447125385359*lm + 0.12984508360617616*lm^2) + 
        CF*((0.01680699953281339 + 0.005453469856509481*lm + 
            0.007213615755898677*lm^2)*NM + (0.017916390080830333 + 
            0.005453469856509481*lm + 0.007213615755898677*lm^2)*NL + 
          (-0.0032145868328544974 + 0.005453469856509481*lm + 
            0.007213615755898677*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(0.004350420920281871 - 0.0802095371805508*lm - 
          0.0394967027558743*lm^2) + CF^2*(0.164775042803139 + 
          0.001042296000353692*lm + 0.12926193629195226*lm^2) + 
        CF*((0.016731877384206333 + 0.00544381934551766*lm + 
            0.007181218682886237*lm^2)*NM + (0.017927081395018904 + 
            0.00544381934551766*lm + 0.007181218682886237*lm^2)*NL + 
          (-0.0031963178922113583 + 0.00544381934551766*lm + 
            0.007181218682886237*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(0.0033945591810284584 - 0.07990342804540397*lm - 
          0.03930992454170627*lm^2) + CF^2*(0.16490014597221225 + 
          0.001276925190687957*lm + 0.12865066213649326*lm^2) + 
        CF*((0.01664785987274287 + 0.005431384544058773*lm + 
            0.007147259007582959*lm^2)*NM + (0.017929630530039445 + 
            0.005431384544058773*lm + 0.007147259007582959*lm^2)*NL + 
          (-0.003176896347570126 + 0.005431384544058773*lm + 
            0.007147259007582959*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(0.0024755286084325633 - 0.07957208127574769*lm - 
          0.03911504760412159*lm^2) + CF^2*(0.1649846271619734 + 
          0.0014825706966503384*lm + 0.1280128830680343*lm^2) + 
        CF*((0.016555361950775255 + 0.005416235166537559*lm + 
            0.007111826837113016*lm^2)*NM + (0.017924284676286432 + 
            0.005416235166537559*lm + 0.007111826837113016*lm^2)*NL + 
          (-0.003156364137906245 + 0.005416235166537559*lm + 
            0.007111826837113016*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(0.0015933865574749666 - 0.07921651004969976*lm - 
          0.03891254921398075*lm^2) + CF^2*(0.1650289289520373 + 
          0.0016593889196903357*lm + 0.12735016106393698*lm^2) + 
        CF*((0.0164547995044138 + 0.005398444984313504*lm + 
            0.007075008947996499*lm^2)*NM + (0.017911298850140984 + 
            0.005398444984313504*lm + 0.007075008947996499*lm^2)*NL + 
          (-0.0031347629924886526 + 0.005398444984313504*lm + 
            0.007075008947996499*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(0.0007480506899647486 - 0.07883772341782486*lm - 
          0.03870288874166281*lm^2) + CF^2*(0.16503354690445718 + 
          0.0018076412511299858*lm + 0.1266639995181692*lm^2) + 
        CF*((0.01634658731767591 + 0.00537809116054205*lm + 
            0.007036888862120512*lm^2)*NM + (0.017890933957497527 + 
            0.00537809116054205*lm + 0.007036888862120512*lm^2)*NL + 
          (-0.00311213436132027 + 0.00537809116054205*lm + 
            0.007036888862120512*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.00006068508807086343 - 0.07843672352080915*lm - 
          0.03848650808935487*lm^2) + CF^2*(0.16499902708577127 + 
          0.0019276821046873404*lm + 0.1259558446560705*lm^2) + 
        CF*((0.01623113729734984 + 0.005355253644263345*lm + 
            0.00699754692533725*lm^2)*NM + (0.017863455069455397 + 
            0.005355253644263345*lm + 0.00699754692533725*lm^2)*NL + 
          (-0.003088519351543157 + 0.005355253644263345*lm + 
            0.00699754692533725*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.0008331360781327049 - 0.0780145031231225*lm - 
          0.03826383213416357*lm^2) + CF^2*(0.16492596327828565 + 
          0.002019947911499916*lm + 0.1252270869845353*lm^2) + 
        CF*((0.0161088569331048 + 0.005330014619438966*lm + 
            0.00695706038802974*lm^2)*NM + (0.017829129890700617 + 
            0.005330014619438966*lm + 0.00695706038802974*lm^2)*NL + 
          (-0.0030639586694841416 + 0.005330014619438966*lm + 
            0.00695706038802974*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.001569713521334691 - 0.07757204343640577*lm - 
          0.038035269178883384*lm^2) + CF^2*(0.16481499396271654 + 
          0.002084947012653671*lm + 0.1244790627672547*lm^2) + 
        CF*((0.015980147969437208 + 0.00530245800489415*lm + 
            0.006915503487069706*lm^2)*NM + (0.017788227402767583 + 
            0.00530245800489415*lm + 0.006915503487069706*lm^2)*NL + 
          (-0.0030384925680251645 + 0.00530245800489415*lm + 
            0.006915503487069706*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.0022709125099483656 - 0.07711031220820756*lm - 
          0.03780121140766345*lm^2) + CF^2*(0.16466679914210514 + 
          0.0021232503877005697*lm + 0.12371305551598949*lm^2) + 
        CF*((0.015845405268221268 + 0.005272669001371816*lm + 
            0.006872947528666082*lm^2)*NM + (0.017741016665900382 + 
            0.005272669001371816*lm + 0.006872947528666082*lm^2)*NL + 
          (-0.003012160798994024 + 0.005272669001371816*lm + 
            0.006872947528666082*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.0029373009848942012 - 0.07663026205346754*lm - 
          0.03756203534417437*lm^2) + CF^2*(0.16448209706616587 + 
          0.002135483161070026*lm + 0.12293029749002521*lm^2) + 
        CF*((0.015705015842510783 + 0.005240733682143829*lm + 
            0.006829460971668067*lm^2)*NM + (0.01768776576463821 + 
            0.005240733682143829*lm + 0.006829460971668067*lm^2)*NL + 
          (-0.0029850025702822 + 0.005240733682143829*lm + 
            0.006829460971668067*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.00356950973259867 - 0.07613282900780793*lm - 
          0.03731810231019474*lm^2) + CF^2*(0.16426164090593762 + 
          0.002122316831619484*lm + 0.12213197119700096*lm^2) + 
        CF*((0.015559358043993351 + 0.005206738623853901*lm + 
            0.006785109510944498*lm^2)*NM + (0.01762874088353881 + 
            0.005206738623853901*lm + 0.006785109510944498*lm^2)*NL + 
          (-0.0029570565074079147 + 0.005206738623853901*lm + 
            0.006785109510944498*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.004168223301122794 - 0.0756189312832535*lm - 
          0.037069758882818604*lm^2) + CF^2*(0.16400621542055796 + 
          0.0020844621738073375*lm + 0.12131921088922452*lm^2) + 
        CF*((0.015408800888071401 + 0.005170770574484763*lm + 
            0.006739956160512473*lm^2)*NM + (0.017564205500636143 + 
            0.005170770574484763*lm + 0.006739956160512473*lm^2)*NL + 
          (-0.002928360619253801 + 0.005170770574484763*lm + 
            0.006739956160512473*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.004734171761576666 - 0.075089468208457*lm - 
          0.03681733734873374*lm^2) + CF^2*(0.16371663365111133 + 
          0.0020226627620929345*lm + 0.12049310405040134*lm^2) + 
        CF*((0.0152537035020566 + 0.005132916155549663*lm + 
            0.006694061336133407*lm^2)*NM + (0.01749441968731265 + 
            0.005132916155549663*lm + 0.006694061336133407*lm^2)*NL + 
          (-0.0028989522677199224 + 0.005132916155549663*lm + 
            0.006694061336133407*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.005268123246528619 - 0.07454531933686864*lm - 
          0.03656115615424111*lm^2) + CF^2*(0.16339373367057058 + 
          0.0019376890731640736*lm + 0.11965469286842545*lm^2) + 
        CF*((0.015094414683244914 + 0.00509326159580462*lm + 
            0.006647482937134747*lm^2)*NM + (0.017419639504259326 + 
            0.00509326159580462*lm + 0.006647482937134747*lm^2)*NL + 
          (-0.00286886814104424 + 0.00509326159580462*lm + 
            0.006647482937134747*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.0057708772024885275 - 0.0739873437075568*lm - 
          0.036301520349880566*lm^2) + CF^2*(0.16303837541387742 + 
          0.001830333123455893*lm + 0.1188049756905182*lm^2) + 
        CF*((0.014931272554913298 + 0.005051892493963586*lm + 
            0.006600276427251011*lm^2)*NM + (0.01734011648410685 + 
            0.005051892493963586*lm + 0.006600276427251011*lm^2)*NL + 
          (-0.002838144230553874 + 0.005051892493963586*lm + 
            0.006600276427251011*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.006243258298524143 - 0.07341637924456912*lm - 
          0.036038722028700156*lm^2) + CF^2*(0.16265143760791068 + 
          0.0017014036021532671*lm + 0.11794490845756414*lm^2) + 
        CF*((0.014764604309350445 + 0.005008893608073687*lm + 
            0.006552494914309119*lm^2)*NM + (0.01725609719214347 + 
            0.005008893608073687*lm + 0.006552494914309119*lm^2)*NL + 
          (-0.002806815810620779 + 0.005008893608073687*lm + 
            0.006552494914309119*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.006686110937678024 - 0.0728332422818237*lm - 
          0.035773040757358855*lm^2) + CF^2*(0.1622338148173801 + 
          0.0015517214624606885*lm + 0.1170754061149926*lm^2) + 
        CF*((0.014594726028111994 + 0.004964348669372508*lm + 
            0.0065041892286107*lm^2)*NM + (0.01716782285729794 + 
            0.004964348669372508*lm + 0.0065041892286107*lm^2)*NL + 
          (-0.002774917421607738 + 0.004964348669372508*lm + 
            0.0065041892286107*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.007100350924487659 - 0.07223872720154262*lm - 
          0.03550474399938691*lm^2) + CF^2*(0.16178652782422773 + 
          0.0013821159363798662*lm + 0.11619734399799352*lm^2) + 
        CF*((0.014421942570530736 + 0.004918340218604167*lm + 
            0.0064554079998885286*lm^2)*NM + (0.0170755290662632 + 
            0.004918340218604167*lm + 0.0064554079998885286*lm^2)*NL + 
          (-0.0027424828555990123 + 0.004918340218604167*lm + 
            0.0064554079998885286*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.007486725393446534 - 0.07163360617519011*lm - 
          0.035234087530047156*lm^2) + CF^2*(0.16131024965056084 + 
          0.0011934209405579973*lm + 0.11531155918924522*lm^2) + 
        CF*((0.014246547522485083 + 0.004870949462916218*lm + 
            0.006406197732735847*lm^2)*NM + (0.016979445514274518 + 
            0.004870949462916218*lm + 0.006406197732735847*lm^2)*NL + 
          (-0.0027095451447221113 + 0.004870949462916218*lm + 
            0.006406197732735847*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.007846176641680446 - 0.07101862899675998*lm - 
          0.03496131584234526*lm^2) + CF^2*(0.1608060386023758 + 
          0.0009864718429619728*lm + 0.1144188518476754*lm^2) + 
        CF*((0.014068823198055653 + 0.004822256151595474*lm + 
            0.006356602880426411*lm^2)*NM + (0.016879795806639515 + 
            0.004822256151595474*lm + 0.006356602880426411*lm^2)*NL + 
          (-0.0026761365518758354 + 0.004822256151595474*lm + 
            0.006356602880426411*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.008179583059432175 - 0.0703945229990747*lm - 
          0.03468666254382951*lm^2) + CF^2*(0.1602748248032345 + 
          0.0007621025621995233*lm + 0.1135199865070784*lm^2) + 
        CF*((0.013889040687574588 + 0.00477233846902824*lm + 
            0.006306665917059911*lm^2)*NM + (0.016776797305650962 + 
            0.00477233846902824*lm + 0.006306665917059911*lm^2)*NL + 
          (-0.0026422885636897477 + 0.00477233846902824*lm + 
            0.006306665917059911*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.00848782265739014 - 0.06976199304451752*lm - 
          0.034410350743901946*lm^2) + CF^2*(0.1597175412900239 + 
          0.0005211429732518908*lm + 0.1126156933436791*lm^2) + 
        CF*((0.01370745994602692 + 0.004721272943389512*lm + 
            0.0062564274079821725*lm^2)*NM + (0.01667066101800108 + 
            0.004721272943389512*lm + 0.0062564274079821725*lm^2)*NL + 
          (-0.002608031885549945 + 0.004721272943389512*lm + 
            0.0062564274079821725*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.008771770244036083 - 0.06912172158232112*lm - 
          0.03413259343143432*lm^2) + CF^2*(0.15913512184403347 + 
          0.0002644165952088607*lm + 0.11170666941196687*lm^2) + 
        CF*((0.013524329916522944 + 0.00466913436967689*lm + 
            0.006205926078442604*lm^2)*NM + (0.016561591518261823 + 
            0.00466913436967689*lm + 0.006205926078442604*lm^2)*NL + 
          (-0.002573396438534006 + 0.00466913436967689*lm + 
            0.006205926078442604*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.009032294925879645 - 0.06847436876518727*lm - 
          0.03385359384254499*lm^2) + CF^2*(0.15852849896346916 - 
          7.261461689102568*^-6*lm + 0.11079357984832908*lm^2) + 
        CF*((0.013339888684679512 + 0.0046159957458087614*lm + 
            0.006155198880462727*lm^2)*NM + (0.016449786904403022 + 
            0.0046159957458087614*lm + 0.006155198880462727*lm^2)*NL + 
          (-0.002538411358107763 + 0.0046159957458087614*lm + 
            0.006155198880462727*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.009270257899853841 - 0.06782057261861411*lm - 
          0.033573545818447924*lm^2) + CF^2*(0.15789860197044733 - 
          0.0002930863107900857*lm + 0.1098770590421932*lm^2) + 
        CF*((0.013154363654533418 + 0.004561928220603045*lm + 
            0.006104281057899623*lm^2)*NM + (0.016335438781692354 + 
            0.004561928220603045*lm + 0.006104281057899623*lm^2)*NL + 
          (-0.0025031049944443024 + 0.004561928220603045*lm + 
            0.006104281057899623*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.009486510519689982 - 0.06716094925686428*lm - 
          0.033292634153332806*lm^2) + CF^2*(0.15724635526526348 - 
          0.0005922648851349265*lm + 0.10895771177454373*lm^2) + 
        CF*((0.012967971757674283 + 0.004507001052542937*lm + 
            0.006053206209696874*lm^2)*NM + (0.016218732271661044 + 
            0.004507001052542937*lm + 0.006053206209696874*lm^2)*NL + 
          (-0.002467504914231432 + 0.004507001052542937*lm + 
            0.006053206209696874*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.009681892598599898 - 0.06649609314002237*lm - 
          0.033011034932277375*lm^2) + CF^2*(0.1565726766969184 - 
          0.0009040173331018241*lm + 0.10803611432381688*lm^2) + 
        CF*((0.012780919664447579 + 0.004451281578320046*lm + 
            0.00600200635132316*lm^2)*NM + (0.016099846043129525 + 
            0.004451281578320046*lm + 0.00600200635132316*lm^2)*NL + 
          (-0.002431637903848309 + 0.004451281578320046*lm + 
            0.00600200635132316*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.00985723094209676 - 0.06582657736706563*lm - 
          0.03272891585922904*lm^2) + CF^2*(0.15587847607751426 - 
          0.0012275782304501947*lm + 0.10711281553929504*lm^2) + 
        CF*((0.01259340402573058 + 0.004394835190223394*lm + 
            0.0059507119744052804*lm^2)*NM + (0.015978952362570707 + 
            0.004394835190223394*lm + 0.0059507119744052804*lm^2)*NL + 
          (-0.0023955299737884223 + 0.004394835190223394*lm + 
            0.0059507119744052804*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.010013338078140335 - 0.06515295400031121*lm - 
          0.03244643657512451*lm^2) + CF^2*(0.15516465381087932 - 
          0.0015621976243925416*lm + 0.10618833788222569*lm^2) + 
        CF*((0.012405611717266254 + 0.004337725321515373*lm + 
            0.005899352104568094*lm^2)*NM + (0.015856217161347042 + 
            0.004337725321515373*lm + 0.005899352104568094*lm^2)*NL + 
          (-0.002359206364224717 + 0.004337725321515373*lm + 
            0.005899352104568094*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.01015101117349308 - 0.06447575441700917*lm - 
          0.03216374896624316*lm^2) + CF^2*(0.15443209964559393 - 
          0.0019071419241746743*lm + 0.10526317843497761*lm^2) + 
        CF*((0.012217720098908895 + 0.004280013439003251*lm + 
            0.005847954357498756*lm^2)*NM + (0.015731800117593675 + 
            0.004280013439003251*lm + 0.005847954357498756*lm^2)*NL + 
          (-0.0023226915516085214 + 0.004280013439003251*lm + 
            0.005847954357498756*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.010271031115949384 - 0.06379548968422434*lm - 
          0.031880997462912834*lm^2) + CF^2*(0.15368169154089428 - 
          0.002261694651573102*lm + 0.10433780987862383*lm^2) + 
        CF*((0.012029897279864666 + 0.004221759042077488*lm + 
            0.005796544993256879*lm^2)*NM + (0.015605854750735115 + 
            0.004221759042077488*lm + 0.005796544993256879*lm^2)*NL + 
          (-0.0022860092562111663 + 0.004221759042077488*lm + 
            0.005796544993256879*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.01037416174780232 - 0.06311265095349544*lm - 
          0.031598319328706895*lm^2) + CF^2*(0.15291429464239578 - 
          0.0026251570637192663*lm + 0.1034126814394044*lm^2) + 
        CF*((0.011842302390300244 + 0.004163019667546335*lm + 
            0.0057451489688558*lm^2)*NM + (0.01547852852681937 + 
            0.004163019667546335*lm + 0.0057451489688558*lm^2)*NL + 
          (-0.002249182450511502 + 0.004163019667546335*lm + 
            0.0057451489688558*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.010461149235934619 - 0.06242770987207829*lm - 
          0.03131584494028743*lm^2) + CF^2*(0.15213076036196366 - 
          0.002996848659729136*lm + 0.10248821980457704*lm^2) + 
        CF*((0.011655085856601412 + 0.0041038508996502025*lm + 
            0.005693789989143169*lm^2)*NM + (0.01534996297303232 + 
            0.0041038508996502025*lm + 0.005693789989143169*lm^2)*NL + 
          (-0.0022122333683487834 + 0.0041038508996502025*lm + 
            0.005693789989143169*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.010532721565447857 - 0.061741119007872665*lm - 
          0.031033698058063983*lm^2) + CF^2*(0.1513319255567069 - 
          0.0033761075817493663*lm + 0.1015648300082094*lm^2) + 
        CF*((0.011468389679364598 + 0.004044306384689315*lm + 
            0.005642490556011633*lm^2)*NM + (0.01522029379991841 + 
            0.004044306384689315*lm + 0.005642490556011633*lm^2)*NL + 
          (-0.0021751835147598296 + 0.004044306384689315*lm + 
            0.005642490556011633*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.010589588144675822 - 0.06105331228540274*lm - 
          0.030751996087848392*lm^2) + CF^2*(0.1505186118017605 - 
          0.0037622909202237806*lm + 0.10064289628750384*lm^2) + 
        CF*((0.011282347712368357 + 0.003984437849744672*lm + 
            0.005591272015972435*lm^2)*NM + (0.015089651029982281 + 
            0.003984437849744672*lm + 0.005591272015972435*lm^2)*NL + 
          (-0.002138053676424805 + 0.003984437849744672*lm + 
            0.005591272015972435*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.010632439510514626 - 0.06036470543046946*lm - 
          0.030470850333695693*lm^2) + CF^2*(0.14969162475172645 - 
          0.004154774932432584*lm + 0.09972278291027681*lm^2) + 
        CF*((0.011097085941445409 + 0.003924295125015279*lm + 
            0.0055401546061264895*lm^2)*NM + (0.014958159131481396 + 
            0.003924295125015279*lm + 0.0055401546061264895*lm^2)*NL + 
          (-0.0021008639326548185 + 0.003924295125015279*lm + 
            0.0055401546061264895*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.010661947123902714 - 0.05967569642132182*lm - 
          0.030190366242128647*lm^2) + CF^2*(0.14885175358566846 - 
          0.004552955182657891*lm + 0.0988048349742392*lm^2) + 
        CF*((0.010912722762136957 + 0.0038639261693345283*lm + 
            0.005489157498568845*lm^2)*NM + (0.014825937156342998 + 
            0.0038639261693345283*lm + 0.005489157498568845*lm^2)*NL + 
          (-0.00206363366685328 + 0.0038639261693345283*lm + 
            0.005489157498568845*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.010678763246153815 - 0.05898666594440435*lm - 
          0.029910643637949232*lm^2) + CF^2*(0.1479997705306868 - 
          0.004956246611679446*lm + 0.09788937917874294*lm^2) + 
        CF*((0.01072936925525534 + 0.003803377098465431*lm + 
            0.005438298843263497*lm^2)*NM + (0.014693098881250869 + 
            0.003803377098465431*lm + 0.005438298843263497*lm^2)*NL + 
          (-0.002026381578392191 + 0.003803377098465431*lm + 
            0.005438298843263497*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.010683520887620854 - 0.05829797785293131*lm - 
          0.029631776951844675*lm^2) + CF^2*(0.14713643045919975 - 
          0.005364083542700709*lm + 0.09697672456967348*lm^2) + 
        CF*((0.010547129459499526 + 0.0037426922158085778*lm + 
            0.005387595809426304*lm^2)*NM + (0.014559752951049401 + 
            0.0037426922158085778*lm + 0.005387595809426304*lm^2)*NL + 
          (-0.0019891256948509906 + 0.0037426922158085778*lm + 
            0.005387595809426304*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.010676833820904988 - 0.05760997962671564*lm - 
          0.02935385543999874*lm^2) + CF^2*(0.14626247055521965 - 
          0.005775919630244606*lm + 0.0960671632581777*lm^2) + 
        CF*((0.010366100640456776 + 0.0036819140451882595*lm + 
            0.005337064625454317*lm^2)*NM + (0.014426003023705298 + 
            0.0036819140451882595*lm + 0.005337064625454317*lm^2)*NL + 
          (-0.0019518833845535166 + 0.0036819140451882595*lm + 
            0.005337064625454317*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.010659296651488539 - 0.05692300283184357*lm - 
          0.029076963395920846*lm^2) + CF^2*(0.1453786100450576 - 
          0.006191227758037566*lm + 0.09516097111392277*lm^2) + 
        CF*((0.010186373555393648 + 0.003621083365411362*lm + 
            0.005286720617440154*lm^2)*NM + (0.014291947916151486 + 
            0.003621083365411362*lm + 0.005286720617440154*lm^2)*NL + 
          (-0.0019146713693725158 + 0.003621083365411362*lm + 
            0.005286720617440154*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.010631484939278603 - 0.05623736357893528*lm - 
          0.028801180354706427*lm^2) + CF^2*(0.14448554998804006 - 
          0.006609499891417159*lm + 0.09425840843358467*lm^2) + 
        CF*((0.010008032713260484 + 0.0035602392463206303*lm + 
            0.00523657824631026*lm^2)*NM + (0.014157681750414378 + 
            0.0035602392463206303*lm + 0.00523657824631026*lm^2)*NL + 
          (-0.001877505737739037 + 0.0035602392463206303*lm + 
            0.00523657824631026*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.010593955365145727 - 0.05555336297886924*lm - 
          0.028526581289942066*lm^2) + CF^2*(0.14358397312305377 - 
          0.007030246889350224*lm + 0.09335972058526494*lm^2) + 
        CF*((0.009831156629677637 + 0.0034994190860888046*lm + 
            0.0051866511436258304*lm^2)*NM + (0.01402329409949515 + 
            0.0034994190860888046*lm + 0.0051866511436258304*lm^2)*NL + 
          (-0.0018404019578256677 + 0.0034994190860888046*lm + 
            0.0051866511436258304*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.01054724593699761 - 0.054871287594972944*lm - 
          0.028253236803468074*lm^2) + CF^2*(0.14267454376677813 - 
          0.007452998280732562*lm + 0.09246513862953187*lm^2) + 
        CF*((0.00965581807620968 + 0.0034386586495231304*lm + 
            0.005136952146085104*lm^2)*NM + (0.013888870132538674 + 
            0.0034386586495231304*lm + 0.005136952146085104*lm^2)*NL + 
          (-0.001803374890861045 + 0.0034386586495231304*lm + 
            0.005136952146085104*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.010491876230499571 - 0.0541914098907983*lm - 
          0.027981213308209834*lm^2) + CF^2*(0.14175790775982808 - 
          0.007877302009255792*lm + 0.09157487991777764*lm^2) + 
        CF*((0.009482084324006556 + 0.003377992107170969*lm + 
            0.005087493328765425*lm^2)*NM + (0.01375449075888093 + 
            0.003377992107170969*lm + 0.005087493328765425*lm^2)*NL + 
          (-0.0017664388045477125 + 0.003377992107170969*lm + 
            0.005087493328765425*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.010428347659905794 - 0.05351398867270447*lm - 
          0.027710573204287266*lm^2) + CF^2*(0.14083469245702956 - 
          0.008302724150769686*lm + 0.09068914866857651*lm^2) + 
        CF*((0.009310017381304877 + 0.0033174520750368164*lm + 
            0.00503828603714314*lm^2)*NM + (0.013620232770617408 + 
            0.0033174520750368164*lm + 0.00503828603714314*lm^2)*NL + 
          (-0.0017296073865223675 + 0.0033174520750368164*lm + 
            0.00503828603714314*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.010357143774932244 - 0.052839269526567534*lm - 
          0.027441375048609214*lm^2) + CF^2*(0.139905506758352 - 
          0.008728848606737487*lm + 0.08980813652272106*lm^2) + 
        CF*((0.009139674224752785 + 0.003257069654739073*lm + 
            0.004989340917928948*lm^2)*NM + (0.013486168983381855 + 
            0.003257069654739073*lm + 0.004989340917928948*lm^2)*NL + 
          (-0.0016928937578795846 + 0.003257069654739073*lm + 
            0.004989340917928948*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.01027873057993282 - 0.05216748524802387*lm - 
          0.027173673718156755*lm^2) + CF^2*(0.13897094117711414 - 
          0.009155276777075255*lm + 0.08893202307760392*lm^2) + 
        CF*((0.00897110702429027 + 0.0031968744739515383*lm + 
            0.004940667948755774*lm^2)*NM + (0.013352368375067048 + 
            0.0031968744739515383*lm + 0.004940667948755774*lm^2)*NL + 
          (-0.0016563104866758338 + 0.0031968744739515383*lm + 
            0.004940667948755774*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.010193556872040477 - 0.05149885626573417*lm - 
          0.026907520567156118*lm^2) + CF^2*(0.13803156794236796 - 
          0.0095816272153828*lm + 0.08806097640160185*lm^2) + 
        CF*((0.008804363361733963 + 0.0031368947269899213*lm + 
            0.004892276466755658*lm^2)*NM + (0.013218896222257508 + 
            0.0031368947269899213*lm + 0.004892276466755658*lm^2)*NL + 
          (-0.0016198696014245056 + 0.0031368947269899213*lm + 
            0.004892276466755658*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.01010205459515222 - 0.05083359105722819*lm - 
          0.02664296357833838*lm^2) + CF^2*(0.1370879411323418 - 
          0.010007535269311401*lm + 0.08719515352910742*lm^2) + 
        CF*((0.008639486442619276 + 0.0030771572154177315*lm + 
            0.004844175196061524*lm^2)*NM + (0.013085814234178523 + 
            0.0030771572154177315*lm + 0.004844175196061524*lm^2)*NL + 
          (-0.0015835826045444486 + 0.0030771572154177315*lm + 
            0.004844175196061524*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.010004639207044027 - 0.0501718865569566*lm - 
          0.026380047508479266*lm^2) + CF^2*(0.1361405968362258 - 
          0.010432652708570883*lm + 0.08633470093684123*lm^2) + 
        CF*((0.008476515301653161 + 0.003017687388558891*lm + 
            0.0047963722742689575*lm^2)*NM + (0.012953180683996994 + 
            0.003017687388558891*lm + 0.0047963722742689575*lm^2)*NL + 
          (-0.0015474604857450393 + 0.003017687388558891*lm + 
            0.0047963722742689575*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.009901710057074197 - 0.049513928556236785*lm - 
          0.026118814028408443*lm^2) + CF^2*(0.13519005334155929 - 
          0.01085664734285451*lm + 0.08547975500206399*lm^2) + 
        CF*((0.008315485001546394 + 0.0029585093838163045*lm + 
            0.004748875277892444*lm^2)*NM + (0.01282105053733753 + 
            0.0029585093838163045*lm + 0.004748875277892444*lm^2)*NL + 
          (-0.001511513735314447 + 0.0029585093838163045*lm + 
            0.004748875277892444*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.009793650772219442 - 0.04885989209483426*lm - 
          0.02585930185767349*lm^2) + CF^2*(0.13423681134472068 - 
          0.011279202631752857*lm + 0.08463044244329505*lm^2) + 
        CF*((0.008156426825313407 + 0.0028996460667065796*lm + 
            0.004701691246849725*lm^2)*NM + (0.012689475577902383 + 
            0.0028996460667065796*lm + 0.004701691246849725*lm^2)*NL + 
          (-0.0014757523573365183 + 0.0028996460667065796*lm + 
            0.004701691246849725*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.009680829649404409 - 0.04820994184397129*lm - 
          0.025601546894039404*lm^2) + CF^2*(0.13328135418215906 - 
          0.011700017288536613*lm + 0.08378688074412896*lm^2) + 
        CF*((0.00799936846208751 + 0.002841119070531117*lm + 
            0.004654826708007164*lm^2)*NM + (0.012558504530106372 + 
            0.002841119070531117*lm + 0.004654826708007164*lm^2)*NL + 
          (-0.0014401858827459099 + 0.002841119070531117*lm + 
            0.004654826708007164*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.009563600052286764 - 0.0475642324805991*lm - 
          0.025345582338000196*lm^2) + CF^2*(0.13232414808014506 - 
          0.012118804879511674*lm + 0.08294917856072791*lm^2) + 
        CF*((0.007844334186513922 + 0.0027829488356130145*lm + 
            0.004608287697818217*lm^2)*NM + (0.01242818317865814 + 
            0.0027829488356130145*lm + 0.004608287697818217*lm^2)*NL + 
          (-0.0014048233822865218 + 0.0027829488356130145*lm + 
            0.004608287697818217*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.009442300810847529 - 0.04692290905281114*lm - 
          0.025091438812474574*lm^2) + CF^2*(0.13136564242095922 - 
          0.012535293420486957*lm + 0.08211743611355315*lm^2) + 
        CF*((0.007691345031783486 + 0.0027251546480376613*lm + 
            0.0045620797840862865*lm^2)*NM + (0.012298554485037156 + 
            0.0027251546480376613*lm + 0.0045620797840862865*lm^2)*NL + 
          (-0.001369673479300224 + 0.0027251546480376613*lm + 
            0.0045620797840862865*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.009317256622310135 - 0.04628610733631137*lm - 
          0.02483914447785328*lm^2) + CF^2*(0.13040627002357472 - 
          0.012949224971745235*lm + 0.08129174556388345*lm^2) + 
        CF*((0.0075404189564126116 + 0.002667754677842631*lm + 
            0.004516208086882414*lm^2)*NM + (0.012169658700832014 + 
            0.002667754677842631*lm + 0.004516208086882414*lm^2)*NL + 
          (-0.0013347443623703413 + 0.002667754677842631*lm + 
            0.004516208086882414*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.009188759536235137 - 0.04565394942129541*lm - 
          0.02458872450966192*lm^2) + CF*(0.12944646122657816 - 
          0.013360366623191856*lm + 0.0804721893043481*lm^2) + 
        0.007391566450971028*NM + 0.0026107652975038455*lm*NM + 
        0.004470677183574894*lm^2*NM + 0.012041530288224595*NL + 
        0.0026107652975038455*lm*NL + 0.004470677183574894*lm^2*NL - 
        0.0013000437932354717*NH + 0.0026107652975038455*lm*NH + 
        0.004470677183574894*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.009057148551440743 - 0.04502656398085748*lm - 
          0.024340203855453983*lm^2) + CF*(0.1284865863954805 - 
          0.013768462411562642*lm + 0.07965884898148576*lm^2) + 
        0.007244809762045187*NM + 0.00255420412914176*lm*NM + 
        0.004425491610082542*lm^2*NM + 0.011914211383355935*NL + 
        0.00255420412914176*lm*NL + 0.004425491610082542*lm^2*NL - 
        0.001265579138018522*NH + 0.00255420412914176*lm*NH + 
        0.004425491610082542*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.008922685282034767 - 0.044404055214949195*lm - 
          0.024093603160726017*lm^2) + CF*(0.12752704737743348 - 
          0.014173307988608747*lm + 0.07885179216237606*lm^2) + 
        0.007100153002246794*NM + 0.00249808534073185*lm*NM + 
        0.004380655120132003*lm^2*NM + 0.011787730861556663*NL + 
        0.00249808534073185*lm*NL + 0.004380655120132003*lm^2*NL - 
        0.001231357349778926*NH + 0.00249808534073185*lm*NH + 
        0.004380655120132003*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.00878564199623163 - 0.043786525221634814*lm - 
          0.023848941802628698*lm^2) + CF*(0.12656821368714888 - 
          0.014574697488745472*lm + 0.07805108226314847*lm^2) + 
        0.006957603404684354*NM + 0.0024424230115897712*lm*NM + 
        0.004336171236841582*lm^2*NM + 0.011662119223668015*NL + 
        0.0024424230115897712*lm*NL + 0.004336171236841582*lm^2*NL - 
        0.001197385000969662*NH + 0.0024424230115897712*lm*NH + 
        0.004336171236841582*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.008646278794477758 - 0.043174068469378726*lm - 
          0.023606237206215606*lm^2) + CF*(0.12561043985225304 - 
          0.014972437093427481*lm + 0.07725677631125108*lm^2) + 
        0.006817165867425411*NM + 0.002387230285556157*lm*NM + 
        0.004292043128402838*lm^2*NM + 0.0115374047768671*NL + 
        0.002387230285556157*lm*NL + 0.004292043128402838*lm^2*NL - 
        0.001163668289785428*NH + 0.002387230285556157*lm*NH + 
        0.004292043128402838*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.008504843998085829 - 0.042566772100384266*lm - 
          0.023365504934965954*lm^2) + CF*(0.12465406574441956 - 
          0.015366344637649272*lm + 0.07646892524170676*lm^2) + 
        0.006678843085949049*NM + 0.002332519405201711*lm*NM + 
        0.004248273624539264*lm^2*NM + 0.011413613729639024*NL + 
        0.002332519405201711*lm*NL + 0.004248273624539264*lm^2*NL - 
        0.001130213051672846*NH + 0.002332519405201711*lm*NH + 
        0.004248273624539264*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.008361574532142896 - 0.041964716225037876*lm - 
          0.023126758777690385*lm^2) + CF*(0.12369941691503303 - 
          0.015756249221611555*lm + 0.07568757418153217*lm^2) + 
        0.006542635680129755*NM + 0.0022783017452520874*lm*NM + 
        0.004204865232307343*lm^2*NM + 0.011290770283615886*NL + 
        0.0022783017452520874*lm*NL + 0.004204865232307343*lm^2*NL - 
        0.001097024770631595*NH + 0.0022783017452520874*lm*NH + 
        0.004204865232307343*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.008216696302211866 - 0.04136797420757315*lm - 
          0.022890010831953977*lm^2) + CF*(0.12274680493424907 - 
          0.016141990828067526*lm + 0.07491276272275847*lm^2) + 
        0.006408542315914508*NM + 0.002224587845222296*lm*NM + 
        0.00416182015126436*lm^2*NM + 0.011168896722335989*NL + 
        0.002224587845222296*lm*NL + 0.00416182015126436*lm^2*NL - 
        0.001064108590302702*NH + 0.002224587845222296*lm*NH + 
        0.00416182015126436*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.008070424564412895 - 0.04077661294307985*lm - 
          0.02265527158414621*lm^2) + CF*(0.12179652773240825 - 
          0.016523419945797476*lm + 0.0741445251844785*lm^2) + 
        0.006276559821854522*NM + 0.0021713874412534113*lm*NM + 
        0.004119140288026584*lm^2*NM + 0.011048013496980182*NL + 
        0.0021713874412534113*lm*NL + 0.004119140288026584*lm^2*NL - 
        0.0010314693248409416*NH + 0.0021713874412534113*lm*NH + 
        0.004119140288026584*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.007922964288532654 - 0.040190693125993014*lm - 
          0.02242254998632312*lm^2) + CF*(0.1208488699428486 - 
          0.016900397199599872*lm + 0.07338289086433021*lm^2) + 
        0.006146683300652177*NM + 0.0021187094971470994*lm*NM + 
        0.004076827270240568*lm^2*NM + 0.010928139309145163*NL + 
        0.0021187094971470994*lm*NL + 0.004076827270240568*lm^2*NL - 
        0.0009991114695689384*NH + 0.0021187094971470994*lm*NH + 
        0.004076827270240568*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.007774510513865275 - 0.039610269510204896*lm - 
          0.022191853529942674*lm^2) + CF*(0.11990410324524331 - 
          0.017272792987131764*lm + 0.07262788427981239*lm^2) + 
        0.006018906235882339*NM + 0.002066562234595974*lm*NM + 
        0.004034882459989577*lm^2*NM + 0.010809291190716044*NL + 
        0.002066562234595974*lm*NL + 0.004034882459989577*lm^2*NL - 
        0.0009670392114111618*NH + 0.002066562234595974*lm*NH + 
        0.004034882459989577*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.007625248697539777 - 0.039035391160950006*lm - 
          0.021963188316610212*lm^2) + CF*(0.11896248670866601 - 
          0.017640487122880806*lm + 0.07187952539981524*lm^2) + 
        0.005893220594045598*NM + 0.0020149531626100347*lm*NM + 
        0.003993306966656403*lm^2*NM + 0.010691484580902489*NL + 
        0.0020149531626100347*lm*NL + 0.003993306966656403*lm^2*NL - 
        0.0009352564391065717*NH + 0.0020149531626100347*lm*NH + 
        0.003993306966656403*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.007475355055135097 - 0.038466101698619325*lm - 
          0.021736559125946735*lm^2) + CF*(0.11802426713365735 - 
          0.018003368489504814*lm + 0.07113782986673477*lm^2) + 
        0.005769616922108949*NM + 0.001963889106141459*lm*NM + 
        0.003952101659263043*lm^2*NM + 0.010574733400504346*NL + 
        0.001963889106141459*lm*NL + 0.003952101659263043*lm^2*NL - 
        0.0009037667531991653*NH + 0.001963889106141459*lm*NH + 
        0.003952101659263043*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.007324996893425899 - 0.03790243953466461*lm - 
          0.021511969480688908*lm^2) + CF*(0.11708967939263307 - 
          0.018361334696732495*lm + 0.07040280920952734*lm^2) + 
        0.0056480844406871875*NM + 0.0019133762339118337*lm*NM + 
        0.003911267178307074*lm^2*NM + 0.010459050123473946*NL + 
        0.0019133762339118337*lm*NL + 0.003911267178307074*lm^2*NL - 
        0.0008725734758061583*NH + 0.0019133762339118337*lm*NH + 
        0.003911267178307074*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.00717433293514046 - 0.037344438099758036*lm - 
          0.021289421709125855*lm^2) + CF*(0.11615894676803565 - 
          0.018714291747980408*lm + 0.06967447104804826*lm^2) + 
        0.005528611133015753*NM + 0.0018634200854475435*lm*NM + 
        0.003870803947113792*lm^2*NM + 0.01034444584584313*NL + 
        0.0018634200854475435*lm*NL + 0.003870803947113792*lm^2*NL - 
        0.0008416796601639514*NH + 0.0018634200854475435*lm*NH + 
        0.003870803947113792*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.007023513635646442 - 0.036792126064375485*lm - 
          0.021068917004974066*lm^2) + CF*(0.11523228128768948 - 
          0.019062153714806063*lm + 0.06895281928900603*lm^2) + 
        0.005411183829863047*NM + 0.00181402559733047*lm*NM + 
        0.003830712182722557*lm^2*NM + 0.010230930352083698*NL + 
        0.00181402559733047*lm*NL + 0.003830712182722557*lm^2*NL - 
        0.0008110880999524334*NH + 0.00181402559733047*lm*NH + 
        0.003830712182722557*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.006872681491511436 - 0.036245527551974355*lm - 
          0.02085045548478819*lm^2) + CF*(0.11430988405687338 - 
          0.019404842419285084*lm + 0.06823785431385225*lm^2) + 
        0.005295788290527352*NM + 0.0017651971286724503*lm*NM + 
        0.0037909919063251253*lm^2*NM + 0.010118512178970277*NL + 
        0.0017651971286724503*lm*NL + 0.0037909919063251253*lm^2*NL - 
        0.000780801338398527*NH + 0.0017651971286724503*lm*NH + 
        0.0037909919063251253*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.006721971340913254 - 0.03570466234493856*lm - 
          0.020634036243002012*lm^2) + CF*(0.11339194558667445 - 
          0.01974228712437141*lm + 0.06752957315891568*lm^2) + 
        0.0051824092800604425*NM + 0.0017169384858230748*lm*NM + 
        0.003751642953273093*lm^2*NM + 0.010007198677014741*NL + 
        0.0017169384858230748*lm*NL + 0.003751642953273093*lm^2*NL - 
        0.0007508216771602096*NH + 0.0017169384858230748*lm*NH + 
        0.003751642953273093*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.006571510655900057 - 0.035169546083464696*lm - 
          0.020419657404690487*lm^2) + CF*(0.11247864611823367 - 
          0.020074424232273205*lm + 0.06682796968807796*lm^2) + 
        0.005071030642856795*NM + 0.0016692529463214034*lm*NM + 
        0.0037126649826709976*lm^2*NM + 0.009896996069541168*NL + 
        0.0016692529463214034*lm*NL + 0.0037126649826709976*lm^2*NL - 
        0.0007211511849925428*NH + 0.0016692529463214034*lm*NH + 
        0.0037126649826709976*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.00642141982652302 - 0.03464019045756379*lm - 
          0.020207316176140487*lm^2) + CF*(0.11157015594253736 - 
          0.020401196990853458*lm + 0.06613303475827795*lm^2) + 
        0.004961635372744066*NM + 0.001622143282103056*lm*NM + 
        0.0036740574865709976*lm^2*NM + 0.009787909509470035*NL + 
        0.001622143282103056*lm*NL + 0.0036740574865709976*lm^2*NL - 
        0.0006917917061975085*NH + 0.001622143282103056*lm*NH + 
        0.0036740574865709976*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.006271812436884319 - 0.034116603392353353*lm - 
          0.019997008893314745*lm^2) + CF*(0.11066663571544842 - 
          0.020722555208042826*lm + 0.06544475637812099*lm^2) + 
        0.004854205679707138*NM + 0.001575611781974884*lm*NM + 
        0.003635819798784499*lm^2*NM + 0.009679943133879806*NL + 
        0.001575611781974884*lm*NL + 0.003635819798784499*lm^2*NL - 
        0.0006627448688596955*NH + 0.001575611781974884*lm*NH + 
        0.003635819798784499*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.0061227955331611735 - 0.03359878922681414*lm - 
          0.019788731068290388*lm^2) + CF*(0.10976823676770928 - 
          0.02103845497423305*lm + 0.06476311985985944*lm^2) + 
        0.004748723053374651*NM + 0.0015296602733700852*lm*NM + 
        0.0035979511033255246*lm^2*NM + 0.009573100116413536*NL + 
        0.0015296602733700852*lm*NL + 0.0035979511033255246*lm^2*NL - 
        0.0006340120928701005*NH + 0.0015296602733700852*lm*NH + 
        0.0035979511033255246*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.005974469883682536 - 0.03308674888618508*lm - 
          0.019582477433750498*lm^2) + CF*(0.10887510140968203 - 
          0.021348858392602123*lm + 0.06408810796500164*lm^2) + 
        0.004645168323393493*NM + 0.0014842901433971723*lm*NM + 
        0.0035604504425000905*lm^2*NM + 0.009467382717597214*NL + 
        0.0014842901433971723*lm*NL + 0.0035604504425000905*lm^2*NL - 
        0.0006055945977405012*NH + 0.0014842901433971723*lm*NH + 
        0.0035604504425000905*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.005826930231149033 - 0.03258048004816904*lm - 
          0.01937824198560432*lm^2) + CF*(0.10798736323062456 - 
          0.0216537333173068*lm + 0.06341970104379596*lm^2) + 
        0.004543521716813255*NM + 0.0014395023591966761*lm*NM + 
        0.0035233167246553313*lm^2*NM + 0.0093627923331358*NL + 
        0.0014395023591966761*lm*NL + 0.0035233167246553313*lm^2*NL - 
        0.0005774934102110383*NH + 0.0014395023591966761*lm*NH + 
        0.0035233167246553313*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.005680265537099058 - 0.032079977303120406*lm - 
          0.01917601802380886*lm^2) + CF*(0.10710514739233004 - 
          0.021953053099464607*lm + 0.062757877168829*lm^2) + 
        0.004443762912599152*NM + 0.0013952974876198412*lm*NM + 
        0.0034865487316016112*lm^2*NM + 0.009259329540251866*NL + 
        0.0013952974876198412*lm*NL + 0.0034865487316016112*lm^2*NL - 
        0.000549709371653796*NH + 0.0013952974876198412*lm*NH + 
        0.0034865487316016112*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.005534559218734619 - 0.03158523230838394*lm - 
          0.018975798191462036*lm^2) + CF*(0.10622857091698495 - 
          0.022246796340835113*lm + 0.062102612262966664*lm^2) + 
        0.004345871093388491*NM + 0.0013516757142438825*lm*NM + 
        0.0034501451257203703*lm^2*NM + 0.009156994142130635*NL + 
        0.0013516757142438825*lm*NL + 0.0034501451257203703*lm^2*NL - 
        0.0005222431452753105*NH + 0.0013516757142438825*lm*NH + 
        0.0034501451257203703*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.005389889378229857 - 0.031096233936952267*lm - 
          0.018777574512234912*lm^2) + CF*(0.10535774296912624 - 
          0.02253494665509972*lm + 0.061453880221859714*lm^2) + 
        0.004249824994602216*NM + 0.0013086368617386147*lm*NM + 
        0.003414104456769984*lm^2*NM + 0.00905578521053418*NL + 
        0.0013086368617386147*lm*NL + 0.003414104456769984*lm^2*NL - 
        0.0004950952231210572*NH + 0.0013086368617386147*lm*NH + 
        0.003414104456769984*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.005246329024653116 - 0.030612968420607144*lm - 
          0.018581338426208023*lm^2) + CF*(0.10449276513160113 - 
          0.02281749243662973*lm + 0.06081165303122626*lm^2) + 
        0.004155602951019702*NM + 0.0012661804075994423*lm*NM + 
        0.0033784251684014586*lm^2*NM + 0.008955701126646185*NL + 
        0.0012661804075994423*lm*NL + 0.0033784251684014586*lm^2*NL - 
        0.0004682659328850711*NH + 0.0012661804075994423*lm*NH + 
        0.0033784251684014586*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.005103946288640218 - 0.030135419487707454*lm - 
          0.018387080824174406*lm^2) + CF*(0.10363373167545467 - 
          0.023094426636624348*lm + 0.060175900879116236*lm^2) + 
        0.004063182940921471*NM + 0.001224305501261824*lm*NM + 
        0.0033431056043953466*lm^2*NM + 0.008856739620207521*NL + 
        0.001224305501261824*lm*NL + 0.0033431056043953466*lm^2*NL - 
        0.0004417554445279472*NH + 0.001224305501261824*lm*NH + 
        0.0033431056043953466*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.004962804629962309 - 0.029663568495784057*lm - 
          0.01819479208046961*lm^2) + CF*(0.10278072982368973 - 
          0.023365746546493146*lm + 0.05954659226335508*lm^2) + 
        0.00397254262790119*NM + 0.0011830109806123983*lm*NM + 
        0.003308144014630838*lm^2*NM + 0.008758897807001512*NL + 
        0.0011830109806123983*lm*NL + 0.003308144014630838*lm^2*NL - 
        0.0004155637767065434*NH + 0.0011830109806123983*lm*NH + 
        0.003308144014630838*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.00482296303813631 - 0.029197394559099008*lm - 
          0.018004462084386705*lm^2) + CF*(0.10193384000886226 - 
          0.023631453588351604*lm + 0.058923694094356494*lm^2) + 
        0.0038836594004449223*NM + 0.001142295387911987*lm*NM + 
        0.0032735385607975827*lm^2*NM + 0.008662172224746433*NL + 
        0.001142295387911987*lm*NL + 0.0032735385607975827*lm^2*NL - 
        0.00038969080301877484*NH + 0.001142295387911987*lm*NH + 
        0.0032735385607975827*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.004684476226229849 - 0.028736874671323916*lm - 
          0.017816080270232126*lm^2) + CF*(0.10109313612449106 - 
          0.023891553112493073*lm + 0.058307171793486955*lm^2) + 
        0.0037965104093723675*NM + 0.0011021569851456744*lm*NM + 
        0.0032392873218603864*lm^2*NM + 0.00856655886745142*NL + 
        0.0011021569851456744*lm*NL + 0.0032392873218603864*lm^2*NL - 
        0.00036413625806694096*NH + 0.0011021569851456744*lm*NH + 
        0.0032392873218603864*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.0045473948180155006 - 0.02828198382348906*lm - 
          0.01762963564607607*lm^2) + CF*(0.10025868577027634 - 
          0.0241460542016964*lm + 0.057696989387158046*lm^2) + 
        0.003711072603231549*NM + 0.0010625937688151187*lm*NM + 
        0.003205388299286558*lm^2*NM + 0.008472053218290592*NL + 
        0.0010625937688151187*lm*NL + 0.003205388299286558*lm^2*NL - 
        0.0003388997433430683*NH + 0.0010625937688151187*lm*NH + 
        0.003205388299286558*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.004411765528631409 - 0.02783269511735205*lm - 
          0.017445116821249215*lm^2) + CF*(0.09943055049113539 - 
          0.024394969482224863*lm + 0.05709310959681561*lm^2) + 
        0.003627322761735272*NM + 0.001023603484188158*lm*NM + 
        0.0031718394220453115*lm^2*NM + 0.008378650281048703*NL + 
        0.001023603484188158*lm*NL + 0.0031718394220453115*lm^2*NL - 
        0.00031398073293978666*NH + 0.001023603484188158*lm*NH + 
        0.0031718394220453115*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.004277631338906972 - 0.027388979874331525*lm - 
          0.017262512032635433*lm^2) + CF*(0.09860878601007556 - 
          0.024638314941369407*lm + 0.05649549392498869*lm^2) + 
        0.003545237527324551*NM + 0.0009851836390206727*lm*NM + 
        0.0031386385513882606*lm^2*NM + 0.008286344610190352*NL + 
        0.0009851836390206727*lm*NL + 0.0031386385513882606*lm^2*NL - 
        0.00028937857909027765*NH + 0.0009851836390206727*lm*NH + 
        0.0031386385513882606*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.004145031663513199 - 0.026950807740148373*lm - 
          0.01708180916980846*lm^2) + CF*(0.09779344245493717 - 
          0.024876109751386932*lm + 0.05590410273755495*lm^2) + 
        0.0034647934349411654*NM + 0.0009473315167655157*lm*NM + 
        0.0031057834854197196*lm^2*NM + 0.008195130339603235*NL + 
        0.0009473315167655157*lm*NL + 0.0031057834854197196*lm^2*NL - 
        0.0002650925175408516*NH + 0.0009473315167655157*lm*NH + 
        0.0031057834854197196*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.004014002513097836 - 0.026518146785313647*lm - 
          0.016902995799058473*lm^2) + CF*(0.09698456457904783 - 
          0.02510837609968291*lm + 0.055318895342373185*lm^2) + 
        0.0033859669400885376*NM + 0.0009100441892831655*lm*NM + 
        0.003073271963465177*lm^2*NM + 0.008105001210064588*NL + 
        0.0009100441892831655*lm*NL + 0.003073271963465177*lm^2*NL - 
        0.00024112167275971551*NH + 0.0009100441892831655*lm*NH + 
        0.003073271963465177*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.003884576650565257 - 0.02609096360159914*lm - 
          0.01672605918635299*lm^2) + CF*(0.09618219197584045 - 
          0.02533513902508665*lm + 0.05473983006442796*lm^2) + 
        0.003308734445257213*NM + 0.0008733185290685733*lm*NM + 
        0.003041101670245998*lm^2*NM + 0.008015950595478542*NL + 
        0.0008733185290685733*lm*NL + 0.003041101670245998*lm^2*NL - 
        0.000217465062985495*NH + 0.0008733185290685733*lm*NH + 
        0.003041101670245998*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.003756783741660663 - 0.02566922339462334*lm - 
          0.016550986319274576*lm^2) + CF*(0.09538635928749412 - 
          0.02555642626006687*lm + 0.05416686431762588*lm^2) + 
        0.0032330723247884032*NM + 0.0008371512210084743*lm*NM + 
        0.003009270239868104*lm^2*NM + 0.007927971527930684*NL + 
        0.0008371512210084743*lm*NL + 0.003009270239868104*lm^2*NL - 
        0.00019412160511906839*NH + 0.0008371512210084743*lm*NH + 
        0.003009270239868104*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.0036306505000172438 - 0.025252890072682232*lm - 
          0.016377763927976442*lm^2) + CF*(0.0945970964076657 - 
          0.025772268078735262*lm + 0.05359995467337744*lm^2) + 
        0.003158956948246292*NM + 0.0008015387736832124*lm*NM + 
        0.0029777752596320804*lm^2*NM + 0.007841056721604766*NL + 
        0.0008015387736832124*lm*NL + 0.0029777752596320804*lm^2*NL - 
        0.00017109011946225746*NH + 0.0008015387736832124*lm*NH + 
        0.0029777752596320804*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.0035062008268237446 - 0.024841926331951068*lm - 
          0.016206378505195285*lm^2) + CF*(0.09381442867838583 - 
          0.02598269715048597*lm + 0.05303905692609367*lm^2) + 
        0.0030863647023671144*NM + 0.0007664775302269044*lm*NM + 
        0.0029466142736718705*lm^2*NM + 0.0077551985956051004*NL + 
        0.0007664775302269044*lm*NL + 0.0029466142736718705*lm^2*NL - 
        0.00014836933430690405*NH + 0.0007664775302269044*lm*NH + 
        0.0029466142736718705*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.003383455945268358 - 0.02443629373818009*lm - 
          0.016036816325359287*lm^2) + CF*(0.09303837708119918 - 
          0.026187748399119613*lm + 0.0524841261557213*lm^2) + 
        0.00301527201165043*NM + 0.0007319636787595202*lm*NM + 
        0.0029157847864289613*lm^2*NM + 0.007670389295726865*NL + 
        0.0007319636787595202*lm*NL + 0.0029157847864289613*lm^2*NL - 
        0.00012595789037783806*NH + 0.0007319636787595202*lm*NH + 
        0.0029157847864289613*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.0032624345299130672 - 0.024035952805003855*lm - 
          0.0158690634628277*lm^2) + CF*(0.0922689584226343 - 
          0.026387458867301317*lm + 0.0519351167874361*lm^2) + 
        0.0029456553576554544*NM + 0.0006979932624042088*lm*NM + 
        0.002885284265968672*lm^2*NM + 0.007586620715215159*NL + 
        0.0006979932624042088*lm*NL + 0.002885284265968672*lm^2*NL - 
        0.00010385434513321693*NH + 0.0006979932624042088*lm*NH + 
        0.002885284265968672*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.003143152831150544 - 0.02364086306898061*lm - 
          0.015703105809297083*lm^2) + CF*(0.09150618551409247 - 
          0.026581867586203647*lm + 0.051391982648608635*lm^2) + 
        0.0028774912970628732*NM + 0.000664562188902935*lm*NM + 
        0.002855110147144924*lm^2*NM + 0.007503884514552369*NL + 
        0.000664562188902935*lm*NL + 0.002855110147144924*lm^2*NL - 
        0.00008205717692568545*NH + 0.000664562188902935*lm*NH + 
        0.002855110147144924*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.0030256247948934716 - 0.023250983161475055*lm - 
          0.01553892909040787*lm^2) + CF*(0.09075006734624921 - 
          0.02677101545018663*lm + 0.05085467702315303*lm^2) + 
        0.002810756478560166*NM + 0.0006316662398432301*lm*NM + 
        0.0028252598346196127*lm^2*NM + 0.007422172140312121*NL + 
        0.0006316662398432301*lm*NL + 0.0028252598346196127*lm^2*NL - 
        0.000060564789027770615*NH + 0.0006316662398432301*lm*NH + 
        0.0028252598346196127*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.002909862177643762 - 0.022866270877494526*lm - 
          0.015376518881583614*lm^2) + CF*(0.09000060925806559 - 
          0.026954945096368952*lm + 0.05032315270336456*lm^2) + 
        0.0027454276586061687*NM + 0.0005993010795085814*lm*NM + 
        0.0027957307057424755*lm^2*NM + 0.007341474843116799*NL + 
        0.0005993010795085814*lm*NL + 0.0027957307057424755*lm^2*NL - 
        0.00003937551352488943*NH + 0.0005993010795085814*lm*NH + 
        0.0027957307057424755*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.002795874657086567 - 0.022486683241585675*lm - 
          0.015215860623134098*lm^2) + CF*(0.08925781310050915 - 
          0.02713370078894616*lm + 0.04979736203934796*lm^2) + 
        0.002681481716128352*NM + 0.0005674622633647117*lm*NM + 
        0.002766520113297109*lm^2*NM + 0.007261783694734415*NL + 
        0.0005674622633647117*lm*NL + 0.002766520113297109*lm^2*NL - 
        0.000018487615079306285*NH + 0.0005674622633647117*lm*NH + 
        0.002766520113297109*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.002683669938351297 - 0.02211217657089555*lm - 
          0.015056939634652204*lm^2) + CF*(0.08852167739508675 - 
          0.027307328308113867*lm + 0.049277256986134485*lm^2) + 
        0.0026188956662041353*NM + 0.0005361452461937221*lm*NM + 
        0.0027376253881185825*lm^2*NM + 0.007183089604349351*NL + 
        0.0005361452461937221*lm*NL + 0.0027376253881185825*lm^2*NL + 
        2.1007054316656023*^-6*NH + 0.0005361452461937221*lm*NH + 
        0.0027376253881185825*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.0025732538560790776 - 0.021742706535497945*lm - 
          0.01489974112873332*lm^2) + CF*(0.08779219748729396 - 
          0.027475874843456215*lm + 0.04876278914858177*lm^2) + 
        0.002557646672775466*NM + 0.0005053453898877841*lm*NM + 
        0.002709043841587876*lm^2*NM + 0.007105383334040374*NL + 
        0.0005053453898877841*lm*NL + 0.002709043841587876*lm^2*NL + 
        0.000022391307399969946*NH + 0.0005053453898877841*lm*NH + 
        0.002709043841587876*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0024646304724331683 - 0.021378228216082994*lm - 
          0.014744250224044912*lm^2) + CF*(0.0870693656950865 - 
          0.027639388891662047*lm + 0.048253909824146984*lm^2) + 
        0.0024977120604438583*NM + 0.0004750579709137883*lm*NM + 
        0.002680772768008166*lm^2*NM + 0.007028655513498102*NL + 
        0.0004750579709137883*lm*NL + 0.002680772768008166*lm^2*NL + 
        0.000042386107090418615*NH + 0.0004750579709137883*lm*NH + 
        0.002680772768008166*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0023578021711859244 - 0.021018696159104955*lm - 
          0.014590451957772864*lm^2) + CF*(0.08635317145248142 - 
          0.027797920158433895*lm + 0.04775057004362028*lm^2) + 
        0.0024390693253911327*NM + 0.0004452781874600731*lm*NM + 
        0.0026528094468677935*lm^2*NM + 0.006952896654013034*NL + 
        0.0004452781874600731*lm*NL + 0.0026528094468677935*lm^2*NL + 
        0.00006208707436045569*NH + 0.0004452781874600731*lm*NH + 
        0.0026528094468677935*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.0022527697480128703 - 0.020664064429480333*lm - 
          0.014438331297470096*lm^2) + CF*(0.08564360144839561 - 
          0.02795151946445731*lm + 0.04725272060990213*lm^2) + 
        0.0023816961454692243*NM + 0.00041600116627607157*lm*NM + 
        0.002625151144994563*lm^2*NM + 0.0068780971617641105*NL + 
        0.00041600116627607157*lm*NL + 0.002625151144994563*lm^2*NL + 
        0.00008149622949297223*NH + 0.00041600116627607157*lm*NH + 
        0.002625151144994563*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.002149532497121394 - 0.020314286660925624*lm - 
          0.014287873152332006*lm^2) + CF*(0.08494063976083062 - 
          0.028100238655300733*lm + 0.046760312134904745*lm^2) + 
        0.0023255703895005814*NM + 0.0003872219692154347*lm*NM + 
        0.002597795118605819*lm^2*NM + 0.006804247350436728*NL + 
        0.0003872219692154347*lm*NL + 0.002597795118605819*lm^2*NL + 
        0.0001006156401391216*NH + 0.0003872219692154347*lm*NH + 
        0.002597795118605819*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.0020480882943384867 - 0.019969316104021233*lm - 
          0.014139062383922329*lm^2) + CF*(0.08424426798651265 - 
          0.02824413051511881*lm + 0.04627329507465489*lm^2) + 
        0.0022706701258289348*NM + 0.00035893559949290877*lm*NM + 
        0.0025707386152586053*lm^2*NM + 0.006731337453198085*NL + 
        0.00035893559949290877*lm*NL + 0.0025707386152586053*lm^2*NL + 
        0.00011944741836813802*NH + 0.00035893559949290877*lm*NH + 
        0.0025707386152586053*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.0019484336767788622 - 0.019629105672085378*lm - 
          0.013991883816372053*lm^2) + CF*(0.0835544653660966 - 
          0.028383248684034742*lm + 0.045791619762672174*lm^2) + 
        0.0022169736301585244*NM + 0.0003311370076649659*lm*NM + 
        0.0025439788757040094*lm^2*NM + 0.006659357634056724*NL + 
        0.0003311370076649659*lm*NL + 0.0025439788757040094*lm^2*NL + 
        0.00013799371782121495*NH + 0.0003311370076649659*lm*NH + 
        0.0025439788757040094*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.0018505639192116655 - 0.019293607984939207*lm - 
          0.013846322246073187*lm^2) + CF*(0.08287120890504321 - 
          0.02851764757908014*lm + 0.04531523644169407*lm^2) + 
        0.0021644593927182265*NM + 0.0003038210973439117*lm*NM + 
        0.0025175131356496706*lm^2*NM + 0.006588297998632149*NL + 
        0.0003038210973439117*lm*NL + 0.0025175131356496706*lm^2*NL + 
        0.00015625673096655466*NH + 0.0003038210973439117*lm*NH + 
        0.0025175131356496706*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.001754473107240895 - 0.0189627754106417*lm - 
          0.013702362450888279*lm^2) + CF*(0.08219447349027742 - 
          0.028647382318573545*lm + 0.04484409529381619*lm^2) + 
        0.0021131061247854593*NM + 0.000276982730654922*lm*NM + 
        0.0024913386274342327*lm^2*NM + 0.006518148604359452*NL + 
        0.000276982730654922*lm*NL + 0.0024913386274342327*lm^2*NL + 
        0.0001742386864527552*NH + 0.000276982730654922*lm*NH + 
        0.0024913386274342327*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.001660154207411544 - 0.018636560105270466*lm - 
          0.013559989198895788*lm^2) + CF*(0.081524232002736 - 
          0.028772508649821667*lm + 0.04437814646911349*lm^2) + 
        0.0020628927646032347*NM + 0.00025061673344519157*lm*NM + 
        0.002465452581617416*lm^2*NM + 0.006448899470152948*NL + 
        0.00025061673344519157*lm*NL + 0.002465452581617416*lm^2*NL + 
        0.00019194184655775727*NH + 0.00025061673344519157*lm*NH + 
        0.002465452581617416*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0015675991343504108 - 0.018314914050822056*lm - 
          0.013419187256690628*lm^2) + CF*(0.08086045542591128 - 
          0.028893082880030237*lm + 0.04391734011280569*lm^2) + 
        0.0020137984827222535*NM + 0.00022471790025411288*lm*NM + 
        0.002439852228489205*lm^2*NM + 0.006380540585551932*NL + 
        0.00022471790025411288*lm*NL + 0.002439852228489205*lm^2*NL + 
        0.00020936850473062858*NH + 0.00022471790025411288*lm*NH + 
        0.002439852228489205*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.001476798815047458 - 0.01799778909130299*lm - 
          0.013279941397258415*lm^2) + CF*(0.08020311295049731 - 
          0.029009161810314113*lm + 0.04346162639102754*lm^2) + 
        0.00196580268679855*NM + 0.00019928099905314127*lm*NM + 
        0.00241453479950153*lm^2*NM + 0.006313061919370786*NL + 
        0.00019928099905314127*lm*NL + 0.00241453479950153*lm^2*NL + 
        0.00022652098322352023*NH + 0.00019928099905314127*lm*NH + 
        0.00241453479950153*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0013877432503805864 - 0.0176851369670804*lm - 
          0.013142236407441261*lm^2) + CF*(0.0795521720752432 - 
          0.02912080267269927*lm + 0.04301095551526231*lm^2) + 
        0.0019188850258758433*NM + 0.00017430077576374782*lm*NM + 
        0.002389497528625684*lm^2*NM + 0.006246453427874833*NL + 
        0.00017430077576374782*lm*NL + 0.002389497528625684*lm^2*NL + 
        0.00024340163081118518*NH + 0.00017430077576374782*lm*NH + 
        0.002389497528625684*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0013004215739836943 - 0.017376909347558898*lm - 
          0.013006057095012189*lm^2) + CF*(0.07890759870411777 - 
          0.029228063070011894*lm + 0.04256527776549444*lm^2) + 
        0.0018730253941804486*NM + 0.00014977195856160733*lm*NM + 
        0.00236473765363858*lm^2*NM + 0.006180705062502522*NL + 
        0.00014977195856160733*lm*NL + 0.00236473765363858*lm^2*NL + 
        0.0002600128205955056*NH + 0.00014977195856160733*lm*NH + 
        0.00236473765363858*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0012148221085549527 - 0.017073057862248005*lm - 
          0.012871388295374658*lm^2) + CF*(0.0782693572398877 - 
          0.02933100091855283*lm + 0.042124543512135244*lm^2) + 
        0.0018282039344553601*NM + 0.00012568926197492256*lm*NM + 
        0.002340252417340847*lm^2*NM + 0.006115806777153736*NL + 
        0.00012568926197492256*lm*NL + 0.002340252417340847*lm^2*NL + 
        0.00027635694789253124*NH + 0.00012568926197492256*lm*NH + 
        0.002340252417340847*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.001130932419699311 - 0.01677353413028239*lm - 
          0.012738214877902962*lm^2) + CF*(0.07763741067421075 - 
          0.029429674393458227*lm + 0.04168870323677333*lm^2) + 
        0.0017844010408589225*NM + 0.00010204739078454275*lm*NM + 
        0.0023160390687096293*lm^2*NM + 0.006051748535063231*NL + 
        0.00010204739078454275*lm*NL + 0.0023160390687096293*lm^2*NL + 
        0.00029243642819958704*NH + 0.00010204739078454275*lm*NH + 
        0.0023160390687096293*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.0010487393673963956 - 0.016478289788455055*lm - 
          0.012606521751938654*lm^2) + CF*(0.07701172067434309 - 
          0.02952414187665008*lm + 0.04125770755179923*lm^2) + 
        0.0017415973614523558*NM + 0.00007884104373329693*lm*NM + 
        0.0022920948639888463*lm^2*NM + 0.005988520315277521*NL + 
        0.00007884104373329693*lm*NL + 0.0022920948639888463*lm^2*NL + 
        0.00030825369524006434*NH + 0.00007884104373329693*lm*NH + 
        0.0022920948639888463*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.0009682291551821557 - 0.016187276517821477*lm - 
          0.012476293872457614*lm^2) + CF*(0.07639224766655942 - 
          0.029614461907283007*lm + 0.04083150721895219*lm^2) + 
        0.001699773800299289*NM + 0.00005606491705172985*lm*NM + 
        0.002268417067719566*lm^2*NM + 0.005926112118752772*NL + 
        0.00005606491705172985*lm*NL + 0.002268417067719566*lm^2*NL + 
        0.0003238111990835635*NH + 0.00005606491705172985*lm*NH + 
        0.002268417067719566*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.000889387377129849 - 0.015900446068930842*lm - 
          0.012347516245421688*lm^2) + CF*(0.07577895091638173 - 
          0.02970069313459634*lm + 0.04041005316683461*lm^2) + 
        0.0016589115191994095*NM + 0.000033713707807200926*lm*NM + 
        0.002245002953713034*lm^2*NM + 0.005864513974090583*NL + 
        0.000033713707807200926*lm*NL + 0.002245002953713034*lm^2*NL + 
        0.00033911140433911163*NH + 0.000033713707807200926*lm*NH + 
        0.002245002953713034*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.0008121990627132588 - 0.015617750285738528*lm - 
          0.012220173932828373*lm^2) + CF*(0.07517178860571182 - 
          0.029782894273083213*lm + 0.03999329650743831*lm^2) + 
        0.0016189919390773063*NM + 0.00001178211708308432*lm*NM + 
        0.002221849805968795*lm^2*NM + 0.005803715942927898*NL + 
        0.00001178211708308432*lm*NL + 0.002221849805968795*lm^2*NL + 
        0.00035415678841923355*NH + 0.00001178211708308432*lm*NH + 
        0.002221849805968795*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.0007366487196323895 - 0.015339141128252085*lm - 
          0.01209425205747144*lm^2) + CF*(0.0745707179069602 - 
          0.0298611240598909*lm + 0.03958118855172472*lm^2) + 
        0.0015799967410466188*NM - 9.735147005409115*^-6*lm*NM + 
        0.002198954919540262*lm^2*NM + 0.0057437081249966035*NL - 
        9.735147005409115*^-6*lm*NL + 0.002198954919540262*lm^2*NL + 
        0.0003689498398727059*NH - 9.735147005409115*^-6*lm*NH + 
        0.002198954919540262*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.000662720374679292 - 0.015064570693961212*lm - 
          0.01196973580742488*lm^2) + CF*(0.07397569505426292 - 
          0.02993544121436932*lm + 0.0391736808242996*lm^2) + 
        0.0015419078671686606*NM - 0.000030843366452478845*lm*NM + 
        0.002176315601349978*lm^2*NM + 0.0056844806628677915*NL - 
        0.000030843366452478845*lm*NL + 0.002176315601349978*lm^2*NL + 
        0.0003834930567838796*NH - 0.000030843366452478845*lm*NH + 
        0.002176315601349978*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0005903976127191452 - 0.01479399123810043*lm - 
          0.011846610440262043*lm^2) + CF*(0.07338667541187545 - 
          0.030005904399686995*lm + 0.03877072507722123*lm^2) + 
        0.0015047075209237936*NM - 0.000051547810653948414*lm*NM + 
        0.002153929170956735*lm^2*NM + 0.005626023746395038*NL - 
        0.000051547810653948414*lm*NL + 0.002153929170956735*lm^2*NL + 
        0.0003977889452365058*NH - 0.000051547810653948414*lm*NH + 
        0.002153929170956735*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0005196636138592392 - 0.014527355192791405*lm - 
          0.011724861287021458*lm^2) + CF*(0.0728036135398311 - 
          0.030072572186436303*lm + 0.03837227330297932*lm^2) + 
        0.0014683781674129678*NM - 0.00007185373384454505*lm*NM + 
        0.002131792961276629*lm^2*NM + 0.005568327616870478*NL - 
        0.00007185373384454505*lm*NL + 0.002131792961276629*lm^2*NL + 
        0.0004118400178400543*NH - 0.00007185373384454505*lm*NH + 
        0.002131792961276629*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.00045050118887609853 - 0.014264615185110312*lm - 
          0.011604473755930223*lm^2) + CF*(0.07222646325694981 - 
          0.03013550301815228*lm + 0.037978277746680736*lm^2) + 
        0.0014329025333060146*NM - 0.00009176637267454055*lm*NM + 
        0.002109904319260041*lm^2*NM + 0.005511382570906921*NL - 
        0.00009176637267454055*lm*NL + 0.002109904319260041*lm^2*NL + 
        0.0004256487923165622*NH - 0.00009176637267454055*lm*NH + 
        0.002109904319260041*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.0003828928129686255 - 0.014005724054123909*lm - 
          0.011485433335895539*lm^2) + CF*(0.07165517770128109 - 
          0.03019475517867155*lm + 0.037588690917476304*lm^2) + 
        0.0013982636065524967*NM - 0.00011129094392024005*lm*NM + 
        0.0020882606065264616*lm^2*NM + 0.005455178964058685*NL - 
        0.00011129094392024005*lm*NL + 0.0020882606065264616*lm^2*NL + 
        0.0004392177901461024*NH - 0.00011129094392024005*lm*NH + 
        0.0020882606065264616*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.0003168206579028505 - 0.013750634866936513*lm - 
          0.011367725599774474*lm^2) + CF*(0.0710897093880627 - 
          0.030250386761260278*lm + 0.037203465599261916*lm^2) + 
        0.0013644446358701558*NM - 0.00013043264232299128*lm*NM + 
        0.002066859199958995*lm^2*NM + 0.0053997072141933255*NL - 
        0.00013043264232299128*lm*NL + 0.002066859199958995*lm^2*NL + 
        0.00045254953526901065*NH - 0.00013043264232299128*lm*NH + 
        0.002066859199958995*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.00025226662261164384 - 0.013499300933788528*lm - 
          0.011251336207431689*lm^2) + CF*(0.07053001026527551 - 
          0.030302455639442363*lm + 0.03682255486068553*lm^2) + 
        0.0013314291300252782*NM - 0.00014919663855156756*lm*NM + 
        0.002045697492260307*lm^2*NM + 0.005344957804625953*NL - 
        0.00014919663855156756*lm*NL + 0.002045697492260307*lm^2*NL + 
        0.000465646552843056*NH - 0.00014919663855156756*lm*NH + 
        0.002045697492260307*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0001892123623105645 - 0.013251675822245713*lm - 
          0.0111362509085944*lm^2) + CF*(0.06997603176687243 - 
          0.030351019439461252*lm + 0.036445912064490764*lm^2) + 
        0.0012992008569186018*NM - 0.0001675880772829545*lm*NM + 
        0.002024772892471709*lm^2*NM + 0.005290921287027312*NL - 
        0.0001675880772829545*lm*NL + 0.002024772892471709*lm^2*NL + 
        0.00047851136805379197*NH - 0.0001675880772829545*lm*NH + 
        0.002024772892471709*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.00012763931618890975 - 0.013007713370516968*lm - 
          0.011022455545513532*lm^2) + CF*(0.06942772486375746 - 
          0.030396135514310908*lm + 0.036073490876226105*lm^2) + 
        0.0012677438424897297*NM - 0.0001856120753967405*lm*NM + 
        0.002004082826457006*lm^2*NM + 0.005237588284116388*NL - 
        0.0001856120753967405*lm*NL + 0.002004082826457006*lm^2*NL + 
        0.0004911465049763676*NH - 0.0001856120753967405*lm*NH + 
        0.002004082826457006*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.00006752873373296971 - 0.012767367699937053*lm - 
          0.010909936055439676*lm^2) + CF*(0.06888504011258965 - 
          0.030437860919273616*lm + 0.03570524527234803*lm^2) + 
        0.001237042369452369*NM - 0.00020327372027847742*lm*NM + 
        0.0019836247373526683*lm^2*NM + 0.005184949492147809*NL - 
        0.00020327372027847742*lm*NL + 0.0019836247373526683*lm^2*NL + 
        0.0005035544854871272*NH - 0.00020327372027847742*lm*NH + 
        0.0019836247373526683*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-8.861699736493295*^-6 - 0.012530593226649287*lm - 
          0.010798678472922025*lm^2) + CF*(0.06834792770248407 - 
          0.03047625238890433*lm + 0.03534112954774481*lm^2) + 
        0.001207080975872119*NM - 0.00022057806822754026*lm*NM + 
        0.0019633960859858227*lm^2*NM + 0.0051329956832039305*NL - 
        0.00022057806822754026*lm*NL + 0.0019633960859858227*lm^2*NL + 
        0.0005157378282233712*NH - 0.00022057806822754026*lm*NH + 
        0.0019633960859858227*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(0.0000483808419485697 - 0.012297344672522081*lm - 
          0.01068866893193826*lm^2) + CF*(0.06781633749968054 - 
          0.030511366315403323*lm + 0.03498109832270703*lm^2) + 
        0.0011778444535979376*NM - 0.00023753014296516936*lm*NM + 
        0.0019433943512615019*lm^2*NM + 0.0050817177073010315*NL - 
        0.00023753014296516936*lm*NL + 0.0019433943512615019*lm^2*NL + 
        0.0005276990475896951*NH - 0.00023753014296516936*lm*NH + 
        0.0019433943512615019*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(0.00010421806586987047 - 0.012067577075331787*lm - 
          0.01057989366786292*lm^2) + CF*(0.06729021909024901 - 
          0.03054325872832075*lm + 0.03462510654936955*lm^2) + 
        0.0011493178465578706*NM - 0.0002541349342385324*lm*NM + 
        0.0019236170305205308*lm^2*NM + 0.005031106494318713*NL - 
        0.0002541349342385324*lm*NL + 0.0019236170305205308*lm^2*NL + 
        0.0005394406528093666*NH - 0.0002541349342385324*lm*NH + 
        0.0019236170305205308*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(0.0001586692435916557 - 0.011841245798243284*lm - 
          0.010472339019281565*lm^2) + CF*(0.06676952182089851 - 
          0.030571985275538786*lm + 0.03427310951764876*lm^2) + 
        0.0011214864489290865*NM - 0.0002703973965167898*lm*NM + 
        0.0019040616398693754*lm^2*NM + 0.00498115305576114*NL - 
        0.0002703973965167898*lm*NL + 0.0019040616398693754*lm^2*NL + 
        0.0005509651470192459*NH - 0.0002703973965167898*lm*NH + 
        0.0019040616398693754*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(0.0002117537234233777 - 0.011618306538618443*lm - 
          0.010365991429657714*lm^2) + CF*(0.0662541948379547 - 
          0.030597601205478716*lm + 0.03392506286069797*lm^2) + 
        0.0010943358031917543*NM - 0.00028632244777529106*lm*NM + 
        0.0018847257144832205*lm^2*NM + 0.004931848486358463*NL - 
        0.00028632244777529106*lm*NL + 0.0018847257144832205*lm^2*NL + 
        0.0005622750264067903*NH - 0.00028632244777529106*lm*NH + 
        0.0018847257144832205*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(0.0002634909112140628 - 0.011398715336181574*lm - 
          0.010260837448859243*lm^2) + CF*(0.06574418712456961 - 
          0.030620161350482237*lm + 0.03358092255990298*lm^2) + 
        0.0010678516980758214*NM - 0.00030191496836416676*lm*NM + 
        0.001865606808883499*lm^2*NM + 0.0048831839655163745*NL - 
        0.00030191496836416676*lm*NL + 0.001865606808883499*lm^2*NL + 
        0.0005733727793877334*NH - 0.00030191496836416676*lm*NH + 
        0.001865606808883499*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(0.0003139002521682475 - 0.011182428580569831*lm - 
          0.010156863734550717*lm^2) + CF*(0.0652394475362253 - 
          0.030639720111317947*lm + 0.033240644949438715*lm^2) + 
        0.0010420201664092703*NM - 0.00031717979995771737*lm*NM + 
        0.0018467024971910396*lm^2*NM + 0.004835150758621405*NL - 
        0.00031717979995771737*lm*NL + 0.0018467024971910396*lm^2*NL + 
        0.0005842608858230617*NH - 0.00031717979995771737*lm*NH + 
        0.0018467024971910396*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(0.0003630012136409074 - 0.010969403018295503*lm - 
          0.01005405705345777*lm^2) + CF*(0.06473992483459107 - 
          0.030656331442765736*lm + 0.03290418672040724*lm^2) + 
        0.0010168274828760045*NM - 0.00033212174458112777*lm*NM + 
        0.001828010373355958*lm^2*NM + 0.0047877402182092774*NL - 
        0.00033212174458112777*lm*NL + 0.001828010373355958*lm^2*NL + 
        0.0005949418162739523*NH - 0.00033212174458112777*lm*NH + 
        0.001828010373355958*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(0.0004108132688703671 - 0.010759595759146132*lm - 
          0.009952404282509496*lm^2) + CF*(0.06424556771979263 - 
          0.030670048840233378*lm + 0.032571504924576535*lm^2) + 
        0.0009922601616910779*NM - 0.00034674556371116534*lm*NM + 
        0.001809528051365363*lm^2*NM + 0.004740943785003274*NL - 
        0.00034674556371116534*lm*NL + 0.001809528051365363*lm^2*NL + 
        0.0006054180312933785*NH - 0.00034674556371116534*lm*NH + 
        0.001809528051365363*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(0.0004573558816096946 - 0.010552964282047397*lm - 
          0.009851892409864534*lm^2) + CF*(0.06375632486115007 - 
          0.030680925327361337*lm + 0.03224255697773847*lm^2) + 
        0.0009683049542005815*NM - 0.00036105597744763796*lm*NM + 
        0.0017912531654299152*lm^2*NM + 0.004694752988829328*NL - 
        0.00036105597744763796*lm*NL + 0.0017912531654299152*lm^2*NL + 
        0.0006156919807531199*NH - 0.00036105597744763796*lm*NH + 
        0.0017912531654299152*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(0.0005026484916185479 - 0.01034946644041277*lm - 
          0.009752508535826241*lm^2) + CF*(0.06327214492643891 - 
          0.030689013444573237*lm + 0.03191730066270406*lm^2) + 
        0.0009449488464131183*NM - 0.00037505766375251057*lm*NM + 
        0.0017731833701502256*lm^2*NM + 0.00464915944941421*NL - 
        0.00037505766375251057*lm*NL + 0.0017731833701502256*lm^2*NL + 
        0.000625766103204956*NH - 0.00037505766375251057*lm*NH + 
        0.0017731833701502256*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(0.0005467105009788617 - 0.01014906046700303*lm - 
          0.009654239873652255*lm^2) + CF*(0.06279297660972831 - 
          0.030694365238531043*lm + 0.03159569413195283*lm^2) + 
        0.0009221790564694173*NM - 0.0003887552577536899*lm*NM + 
        0.0017553163406640463*lm^2*NM + 0.0046041548770729265*NL - 
        0.0003887552577536899*lm*NL + 0.0017553163406640463*lm^2*NL + 
        0.0006356428252748548*NH - 0.0003887552577536899*lm*NH + 
        0.0017553163406640463*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(0.0005895612611991312 - 0.009951704978317842*lm - 
          0.009557073750263394*lm^2) + CF*(0.06231876865784754 - 
          0.030697032252455486*lm + 0.03127769590995293*lm^2) + 
        0.0008999830320562978*NM - 0.0004021533511105994*lm*NM + 
        0.0017376497727751626*lm^2*NM + 0.004559731073291201*NL - 
        0.0004021533511105994*lm*NL + 0.0017376497727751626*lm^2*NL + 
        0.0006453245610890042*NH - 0.0004021533511105994*lm*NH + 
        0.0017376497727751626*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(0.0006312200610733774 - 0.009757358978540782*lm - 
          0.009460997606856744*lm^2) + CF*(0.06184946989553144 - 
          0.030697065517273574*lm + 0.030963264895167524*lm^2) + 
        0.0008783484477708491*NM - 0.00041525649143877387*lm*NM + 
        0.0017201813830648625*lm^2*NM + 0.0045158799312086*NL - 
        0.00041525649143877387*lm*NL + 0.0017201813830648625*lm^2*NL + 
        0.000654813711730567*NH - 0.00041525649143877387*lm*NH + 
        0.0017201813830648625*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(0.000671706115262162 - 0.009565981863058303*lm - 
          0.009365998999427503*lm^2) + CF*(0.06138502924929316 - 
          0.030694515543556542*lm + 0.030652360361762738*lm^2) + 
        0.0008572632024403753*NM - 0.00042806918179080495*lm*NM + 
        0.0017029089089868187*lm^2*NM + 0.004472593436007685*NL - 
        0.00042806918179080495*lm*NL + 0.0017029089089868187*lm^2*NL + 
        0.0006641126647260753*NH - 0.00042806918179080495*lm*NH + 
        0.0017029089089868187*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(0.0007110385535642566 - 0.009377533421572446*lm - 
          0.009272065599204052*lm^2) + CF*(0.06092539577007161 - 
          0.03068943231421287*lm + 0.030344941961031442*lm^2) + 
        0.0008367154164033448*NM - 0.00044059588019107156*lm*NM + 
        0.0016858301089461912*lm^2*NM + 0.00442986366521427*NL - 
        0.00044059588019107156*lm*NL + 0.0016858301089461912*lm^2*NL + 
        0.0006732237935604085*NH - 0.00044059588019107156*lm*NH + 
        0.0016858301089461912*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(0.0007492364108487687 - 0.00919197384082621*lm - 
          0.009179185193000443*lm^2) + CF*(0.06047051865469932 - 
          0.030681865277902273*lm + 0.0300409697225469*lm^2) + 
        0.0008166934287562967*NM - 0.0004528409992217832*lm*NM + 
        0.0016689427623637167*lm^2*NM + 0.004387682788913703*NL - 
        0.0004528409992217832*lm*NL + 0.0016689427623637167*lm^2*NL + 
        0.0006821494572193365*NH - 0.0004528409992217832*lm*NH + 
        0.0016689427623637167*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(0.0007863186176186865 - 0.009009263706959902*lm - 
          0.009087345683490395*lm^2) + CF*(0.06002034726623506 - 
          0.030671863343137897*lm + 0.029740404055059476*lm^2) + 
        0.000797185794571373*NM - 0.00046480890565796056*lm*NM + 
        0.0016522446697255263*lm^2*NM + 0.004346043069887817*NL - 
        0.00046480890565796056*lm*NL + 0.0016522446697255263*lm^2*NL + 
        0.0006908919997586349*NH - 0.00046480890565796056*lm*NH + 
        0.0016522446697255263*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(0.0008223039911779166 - 0.008829364007515926*lm - 
          0.00899653508940669*lm^2) + CF*(0.05957483115320415 - 
          0.030659474873045062*lm + 0.029443205747149172*lm^2) + 
        0.0007781812820888847*NM - 0.00047650392014906586*lm*NM + 
        0.0016357336526193983*lm^2*NM + 0.004304936863677025*NL - 
        0.00047650392014906586*lm*NL + 0.0016357336526193983*lm^2*NL + 
        0.0006994537498988125*NH - 0.00047650392014906586*lm*NH + 
        0.0016357336526193983*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(0.0008572112273749721 - 0.008652236133108919*lm - 
          0.008906741545669694*lm^2) + CF*(0.05913392006778811 - 
          0.030644747680746227*lm + 0.02914933596764627*lm^2) + 
        0.000759668869889063*NM - 0.0004879303169450845*lm*NM + 
        0.0016194075537581262*lm^2*NM + 0.004264356618571814*NL - 
        0.0004879303169450845*lm*NL + 0.0016194075537581262*lm^2*NL + 
        0.0007078370206445182*NH - 0.0004879303169450845*lm*NH + 
        0.0016194075537581262*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(0.0008910588928975057 - 0.008477841878777374*lm - 
          0.008817953303448584*lm^2) + CF*(0.05869756398300389 - 
          0.03062772902534278*lm + 0.02885875626583173*lm^2) + 
        0.0007416377440469095*NM - 0.0004990923236649435*lm*NM + 
        0.0016032642369906518*lm^2*NM + 0.00422429487553771*NL - 
        0.0004990923236649435*lm*NL + 0.0016032642369906518*lm^2*NL + 
        0.000716044108927727*NH - 0.0004990923236649435*lm*NH + 
        0.0016032642369906518*lm^2*NH)}, 
     {1., 1.1960642024299431*^-11*CF*NC*
       (-10.*CA*(-7.724212598420302*^6 + 6.9445632*^7*lm + 
          7.299072*^7*lm^2) + 20.*CF*(2.43572681928521*^8 - 
          1.27954944*^8*lm + 1.1943936*^8*lm^2) + 6.05383301166257*^7*NM - 
        4.263936*^7*lm*NM + 1.327104*^8*lm^2*NM + 3.49876224*^8*NL - 
        4.263936*^7*lm*NL + 1.327104*^8*lm^2*NL + 6.05383301166257*^7*NH - 
        4.263936*^7*lm*NH + 1.327104*^8*lm^2*NH)}}
 
CbarLTable["a", 2, 3] = {{0., -9.720394788002078*^-11*CF*NC*
       (CF*(-6.680692866407926*^8 - 7.327430668528489*^8*lm - 
          1.1573604*^9*lm^2) + 35.*CA*(7.177114445052359*^6 + 
          1.9947862188032452*^7*lm + 6.73596*^6*lm^2) + 
        70.*(9.*(-252382.29040926497 - 114897.19381850964*lm - 68040.*lm^2)*
           NM + 9.*(-252382.29040926497 - 114897.19381850964*lm - 
            68040.*lm^2)*NL + (496876.36851328495 - 1.0340747443665867*^6*
             lm - 612360.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.021279133354592722 - 0.06909120560665435*lm - 
          0.023593106042430985*lm^2) + CF*(0.06788328191065007 + 
          0.06951165680719533*lm + 0.11582070239011573*lm^2) + 
        0.015339390182716527*NM + 0.007102475654201059*lm*NM + 
        0.004289655644078361*lm^2*NM + 0.015339206081390203*NL + 
        0.007102475654201059*lm*NL + 0.004289655644078361*lm^2*NL - 
        0.0034687820294009857*NH + 0.007102475654201059*lm*NH + 
        0.004289655644078361*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.018570290132865465 - 0.0703070236515214*lm - 
          0.02424144790884965*lm^2) + CF*(0.0704543365780966 + 
          0.06806983133111277*lm + 0.11900347155253466*lm^2) + 
        0.015273646864753328*NM + 0.007173503957732898*lm*NM + 
        0.004407535983427209*lm^2*NM + 0.01527134895779802*NL + 
        0.007173503957732898*lm*NL + 0.004407535983427209*lm^2*NL - 
        0.003553756577748008*NH + 0.007173503957732898*lm*NH + 
        0.004407535983427209*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.016335286809572195 - 0.07150904458206714*lm - 
          0.024856043365511903*lm^2) + CF*(0.07267637892736016 + 
          0.06694598766318116*lm + 0.12202057652160388*lm^2) + 
        0.015261349449704524*NM + 0.0072498327815797015*lm*NM + 
        0.004519280611911255*lm^2*NM + 0.015254591555192747*NL + 
        0.0072498327815797015*lm*NL + 0.004519280611911255*lm^2*NL - 
        0.0036352161035689804*NH + 0.0072498327815797015*lm*NH + 
        0.004519280611911255*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.014559057171814434 - 0.07268904414653894*lm - 
          0.025433543805283357*lm^2) + CF*(0.07460500027701349 + 
          0.06613802595320044*lm + 0.12485557868048193*lm^2) + 
        0.015297033705004272*NM + 0.007330741691536553*lm*NM + 
        0.004624280691869701*lm^2*NM + 0.015284049064876116*NL + 
        0.007330741691536553*lm*NL + 0.004624280691869701*lm^2*NL - 
        0.0037127691288717348*NH + 0.007330741691536553*lm*NH + 
        0.004624280691869701*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.013207286508865995 - 0.07383820751887846*lm - 
          0.02597195216929309*lm^2) + CF*(0.0762942163256088 + 
          0.06562549930645833*lm + 0.12749867428562062*lm^2) + 
        0.01537302227228982*NM + 0.007415090121281979*lm*NM + 
        0.004722173121689653*lm^2*NM + 0.015352959844918813*NL + 
        0.007415090121281979*lm*NL + 0.004722173121689653*lm^2*NL - 
        0.003786145233292824*NH + 0.007415090121281979*lm*NH + 
        0.004722173121689653*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.012238691352030586 - 0.07494821642381586*lm - 
          0.026470190895844514*lm^2) + CF*(0.07779075294665903 + 
          0.06537988881647652*lm + 0.12994457348869123*lm^2) + 
        0.01548125037731985*NM + 0.007501615010250434*lm*NM + 
        0.004812761981062639*lm^2*NM + 0.015454256006672325*NL + 
        0.007501615010250434*lm*NL + 0.004812761981062639*lm^2*NL - 
        0.00385515946186869*NH + 0.007501615010250434*lm*NH + 
        0.004812761981062639*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.011610311866247138 - 0.07601164208391778*lm - 
          0.02692784600584853*lm^2) + CF*(0.07913329112991759 + 
          0.06536945761784009*lm + 0.13219124402871096*lm^2) + 
        0.015613988579246113*NM + 0.0075890614684498555*lm*NM + 
        0.004895972001063369*lm^2*NM + 0.015581166587192384*NL + 
        0.0075890614684498555*lm*NL + 0.004895972001063369*lm^2*NL - 
        0.0039196913061130285*NH + 0.0075890614684498555*lm*NH + 
        0.004895972001063369*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.011280079296676545 - 0.07702207476053394*lm - 
          0.027344996996182765*lm^2) + CF*(0.08035306852351264 + 
          0.06556183109120986*lm + 0.13423907616307904*lm^2) + 
        0.01576414730821076*NM + 0.007676245692881233*lm*NM + 
        0.004971817635669594*lm^2*NM + 0.015727464481614696*NL + 
        0.007676245692881233*lm*NL + 0.004971817635669594*lm^2*NL - 
        0.00397967066579595*NH + 0.007676245692881233*lm*NH + 
        0.004971817635669594*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.01120810636808938 - 0.07797413645302267*lm - 
          0.027722096016617036*lm^2) + CF*(0.0814748467403515 + 
          0.06592544018276118*lm + 0.13609028953612*lm^2) + 
        0.01592539299710574*NM + 0.007762085235547287*lm*NM + 
        0.0050403810939303705*lm^2*NM + 0.015887557050801422*NL + 
        0.007762085235547287*lm*NL + 0.0050403810939303705*lm^2*NL - 
        0.004035067760350239*NH + 0.007762085235547287*lm*NH + 
        0.0050403810939303705*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.011357314029019882 - 0.07886343829932556*lm - 
          0.0280598783300593*lm^2) + CF*(0.08251791680225548 + 
          0.0664303356969204*lm + 0.13774849362029112*lm^2) + 
        0.016092171704270523*NM + 0.00784561197804547*lm*NM + 
        0.005101796060010782*lm^2*NM + 0.016056501838435336*NL + 
        0.00784561197804547*lm*NL + 0.005101796060010782*lm^2*NL - 
        0.0040858855171218705*NH + 0.00784561197804547*lm*NH + 
        0.005101796060010782*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.011693691418940751 - 0.07968651189395984*lm - 
          0.02835929401515857*lm^2) + CF*(0.08349702909724566 + 
          0.0670486317524615*lm + 0.13921835243805117*lm^2) + 
        0.016259685709183656*NM + 0.007925975448286582*lm*NM + 
        0.005156235275483376*lm^2*NM + 0.016229985139853152*NL + 
        0.007925975448286582*lm*NL + 0.005156235275483376*lm^2*NL - 
        0.004132153627259984*NH + 0.007925975448286582*lm*NH + 
        0.005156235275483376*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.012186346144968642 - 0.0804407294948809*lm - 
          0.028621454805250128*lm^2) + CF*(0.08442321276974259 + 
          0.06775472168841597*lm + 0.14050532358940973*lm^2) + 
        0.01642384649200257*NM + 0.008002440614383276*lm*NM + 
        0.005203900873681841*lm^2*NM + 0.016404282423580205*NL + 
        0.008002440614383276*lm*NL + 0.005203900873681841*lm^2*NL - 
        0.004173923784737734*NH + 0.008002440614383276*lm*NH + 
        0.005203900873681841*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.012807433353730547 - 0.08112422114890373*lm - 
          0.028847592105737913*lm^2) + CF*(0.0853044801236198 + 
          0.06852535107614281*lm + 0.14161545215544066*lm^2) + 
        0.01658121679774606*NM + 0.008074382531530748*lm*NM + 
        0.005245016746497803*lm^2*NM + 0.016576210693866472*NL + 
        0.008074382531530748*lm*NL + 0.005245016746497803*lm^2*NL - 
        0.00421126579919185*NH + 0.008074382531530748*lm*NH + 
        0.005245016746497803*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.013532015710601246 - 0.08173579312943231*lm - 
          0.0290390234954112*lm^2) + CF*(0.08614642354475331 + 
          0.06933960020437277*lm + 0.14255520625020043*lm^2) + 
        0.016728948890286446*NM + 0.00814127926426444*lm*NM + 
        0.005279822453711127*lm^2*NM + 0.016743078317606415*NL + 
        0.00814127926426444*lm*NL + 0.005279822453711127*lm^2*NL - 
        0.004244264374987262*NH + 0.00814127926426444*lm*NH + 
        0.005279822453711127*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.014337885943647505 - 0.08227485007324321*lm - 
          0.029197125804902246*lm^2) + CF*(0.08695271657835489 + 
          0.07017880954815424*lm + 0.1433313448604292*lm^2) + 
        0.01686472301493935*NM + 0.008202703959289983*lm*NM + 
        0.005308568328164045*lm^2*NM + 0.016902635369949175*NL + 
        0.008202703959289983*lm*NL + 0.005308568328164045*lm^2*NL - 
        0.004273016411454057*NH + 0.008202703959289983*lm*NH + 
        0.005308568328164045*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.015205371569359 - 0.08274132205289383*lm - 
          0.029323313380241852*lm^2) + CF*(0.08772553158960127 + 
          0.07102647020284676*lm + 0.14395081113936908*lm^2) + 
        0.01698668831725695*NM + 0.008258316615842087*lm*NM + 
        0.005331511523680337*lm^2*NM + 0.017053026163111575*NL + 
        0.008258316615842087*lm*NL + 0.005331511523680337*lm^2*NL - 
        0.0042976287195165*NH + 0.008258316615842087*lm*NH + 
        0.005331511523680337*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.01611713407251933 - 0.08313559714557738*lm - 
          0.029419020489096098*lm^2) + CF*(0.08846588582473201 + 
          0.07186809395085168*lm + 0.14442064603738083*lm^2) + 
        0.017093407420454804*NM + 0.008307855896760424*lm*NM + 
        0.00534891281619929*lm^2*NM + 0.01719274481847233*NL + 
        0.008307855896760424*lm*NL + 0.00534891281619929*lm^2*NL - 
        0.004318216076877203*NH + 0.008307855896760424*lm*NH + 
        0.00534891281619929*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.017057970205975406 - 0.0834584596570786*lm - 
          0.029485687072525055*lm^2) + CF*(0.0891739265404092 + 
          0.07269107285126061*lm + 0.1447479183560321*lm^2) + 
        0.017183805236267977*NM + 0.00835113119359527*lm*NM + 
        0.005361034013186374*lm^2*NM + 0.017320594268378824*NL + 
        0.00835113119359527*lm*NL + 0.005361034013186374*lm^2*NL - 
        0.004334899562536008*NH + 0.00835113119359527*lm*NH + 
        0.005361034013186374*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.01801462012503711 - 0.08371103392020919*lm - 
          0.029524747221902965*lm^2) + CF*(0.08984916457597278 + 
          0.07348453504721042*lm + 0.14493966818025092*lm^2) + 
        0.01725712220444448*NM + 0.008388015074639002*lm*NM + 
        0.005368135858527812*lm^2*NM + 0.017435648793547278*NL + 
        0.008388015074639002*lm*NL + 0.005368135858527812*lm^2*NL - 
        0.004347805124646555*NH + 0.008388015074639002*lm*NH + 
        0.005368135858527812*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.018975585151663605 - 0.08389473344723461*lm - 
          0.029537619891087944*lm^2) + CF*(0.0904906644827027 + 
          0.07423920130812175*lm + 0.14500286128352263*lm^2) + 
        0.017312871927614323*NM + 0.008418436189162801*lm*NM + 
        0.005370476343834172*lm^2*NM + 0.017537220036983953*NL + 
        0.008418436189162801*lm*NL + 0.005370476343834172*lm^2*NL - 
        0.00435706234533487*NH + 0.008418436189162801*lm*NH + 
        0.005370476343834172*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.019930956702762223 - 0.08401121513770086*lm - 
          0.029525701452121897*lm^2) + CF*(0.0910971981697797 + 
          0.0749472453182622*lm + 0.14494435258314387*lm^2) + 
        0.017350803033620684*NM + 0.008442372664214924*lm*NM + 
        0.0053683093549312545*lm^2*NM + 0.017624826340909082*NL + 
        0.008442372664214924*lm*NL + 0.0053683093549312545*lm^2*NL - 
        0.004362803373254432*NH + 0.008442372664214924*lm*NH + 
        0.0053683093549312545*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.020872257085480506 - 0.08406233820377924*lm - 
          0.02949035977794295*lm^2) + CF*(0.09166736800275538 + 
          0.07560215967065928*lm + 0.14477085709171994*lm^2) + 
        0.017370865021745598*NM + 0.008459846005791246*lm*NM + 
        0.005361883595989627*lm^2*NM + 0.017698165202260953*NL + 
        0.008459846005791246*lm*NL + 0.005361883595989627*lm^2*NL - 
        0.0043651620000669245*NH + 0.008459846005791246*lm*NH + 
        0.005361883595989627*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.02179229231547602 - 0.08405012746045282*lm - 
          0.029432929594058427*lm^2) + CF*(0.09219970439841355 + 
          0.0761986287845138*lm + 0.144488927098105*lm^2) + 
        0.01737317781096056*NM + 0.008470915499969638*lm*NM + 
        0.0053514417443742595*lm^2*NM + 0.01775708861849801*NL + 
        0.008470915499969638*lm*NL + 0.0053514417443742595*lm^2*NL - 
        0.004364272861208238*NH + 0.008470915499969638*lm*NH + 
        0.0053514417443742595*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.0226850167582899 - 0.083976740628469*lm - 
          0.029354708887180243*lm^2) + CF*(0.09269274219110363 + 
          0.07673240944082903*lm + 0.14410493453706663*lm^2) + 
        0.017358004693673903*NM + 0.008475673099051829*lm*NM + 
        0.0053372197976691346*lm^2*NM + 0.017801581088321645*NL + 
        0.008475673099051829*lm*NL + 0.0053372197976691346*lm^2*NL - 
        0.0043602707445606365*NH + 0.008475673099051829*lm*NH + 
        0.0053372197976691346*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.023545409167590986 - 0.0838444393081095*lm - 
          0.0292569561955207*lm^2) + CF*(0.09314507938718956 + 
          0.0772002192612555*lm + 0.14362505768710163*lm^2) + 
        0.017325728398624892*NM + 0.008474238771106028*lm*NM + 
        0.005319446581003764*lm^2*NM + 0.017831740035114122*NL + 
        0.008474238771106028*lm*NL + 0.005319446581003764*lm^2*NL - 
        0.004353289993238253*NH + 0.008474238771106028*lm*NH + 
        0.005319446581003764*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.02436935955603553 - 0.08365556329765372*lm - 
          0.029140888634982706*lm^2) + CF*(0.09355542136256097 + 
          0.07759963319524983*lm + 0.1430552714808242*lm^2) + 
        0.017276829975867602*NM + 0.008466756287346002*lm*NM + 
        0.005298343388178674*lm^2*NM + 0.017847758430173943*NL + 
        0.008466756287346002*lm*NL + 0.005298343388178674*lm^2*NL - 
        0.004343463990769974*NH + 0.008466756287346002*lm*NH + 
        0.005298343388178674*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.025153566256885695 - 0.08341250794942363*lm - 
          0.02900768053946324*lm^2) + CF*(0.09392261308015531 + 
          0.07792898789983456*lm + 0.14240134083009226*lm^2) + 
        0.017211870231454776*NM + 0.008453389419688838*lm*NM + 
        0.005274123734447861*lm^2*NM + 0.017849909405568784*NL + 
        0.008453389419688838*lm*NL + 0.005274123734447861*lm^2*NL - 
        0.004330924718651278*NH + 0.008453389419688838*lm*NH + 
        0.005274123734447861*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.025895442498196353 - 0.08311770427684619*lm - 
          0.028858462613119275*lm^2) + CF*(0.09424566149828609 + 
          0.07818729377274937*lm + 0.1416688164644037*lm^2) + 
        0.01713147345701656*NM + 0.008434318520027077*lm*NM + 
        0.005246993202385323*lm^2*NM + 0.01783853266089731*NL + 
        0.008434318520027077*lm*NL + 0.005246993202385323*lm^2*NL - 
        0.004315802377622233*NH + 0.008434318520027077*lm*NH + 
        0.005246993202385323*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.026593031803047278 - 0.08277360154697067*lm - 
          0.028694321508623066*lm^2) + CF*(0.09452374999579276 + 
          0.0783741543179742*lm + 0.14086303286051322*lm^2) + 
        0.01703631321831938*NM + 0.008409737452825694*lm*NM + 
        0.005217149365204193*lm^2*NM + 0.017814022483357284*NL + 
        0.008409737452825694*lm*NL + 0.005217149365204193*lm^2*NL - 
        0.004298225065178013*NH + 0.008409737452825694*lm*NH + 
        0.005217149365204193*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.027244931539708948 - 0.08238265211363353*lm - 
          0.028516299758847882*lm^2) + CF*(0.09475624634751709 + 
          0.07848969247117109*lm + 0.13998910790707142*lm^2) + 
        0.016927099986023257*NM + 0.008379850853323944*lm*NM + 
        0.0051847817743359784*lm^2*NM + 0.017776817215562565*NL + 
        0.008379850853323944*lm*NL + 0.0051847817743359784*lm^2*NL - 
        0.004278318502779748*NH + 0.008379850853323944*lm*NH + 
        0.0051847817743359784*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.027850223968276966 - 0.0819472982665269*lm - 
          0.028325396000608648*lm^2) + CF*(0.09494270553550177 + 
          0.07853448348326629*lm + 0.1390519440029879*lm^2) + 
        0.01680457041051326*NM + 0.00834487168468223*lm*NM + 
        0.005150072000110663*lm^2*NM + 0.01772739002010721*NL + 
        0.00834487168468223*lm*NL + 0.005150072000110663*lm^2*NL - 
        0.004256205807044768*NH + 0.00834487168468223*lm*NH + 
        0.005150072000110663*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.028408414160577624 - 0.08146996089053053*lm - 
          0.0281225654384497*lm^2) + CF*(0.09508286847080456 + 
          0.07850949394710088*lm + 0.1380562303342076*lm^2) + 
        0.016669478060317655*NM + 0.008305019068719671*lm*NM + 
        0.005113193716081763*lm^2*NM + 0.017666240803687054*NL + 
        0.008305019068719671*lm*NL + 0.005113193716081763*lm^2*NL - 
        0.004232007299884943*NH + 0.008305019068719671*lm*NH + 
        0.005113193716081763*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.02891937420469393 - 0.0809530297476573*lm - 
          0.027908720504352627*lm^2) + CF*(0.09517665752195197 + 
          0.07841602655032032*lm + 0.13700644611227653*lm^2) + 
        0.016522585459688537*NM + 0.008260516366335431*lm*NM + 
        0.0050743128189732045*lm^2*NM + 0.017593889176521157*NL + 
        0.008260516366335431*lm*NL + 0.0050743128189732045*lm^2*NL - 
        0.004205840353152185*NH + 0.008260516366335431*lm*NH + 
        0.0050743128189732045*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.029383293141731916 - 0.08039885521076731*lm - 
          0.0276847316758914*lm^2) + CF*(0.09522416959335883 + 
          0.0782556701441155*lm + 0.13590686459073958*lm^2) + 
        0.016364657274588076*NM + 0.008211589485222492*lm*NM + 
        0.0050335875774348*lm^2*NM + 0.017510868334805984*NL + 
        0.008211589485222492*lm*NL + 0.0050335875774348*lm^2*NL - 
        0.0041778192638587805*NH + 0.008211589485222492*lm*NH + 
        0.0050335875774348*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.029800632118209575 - 0.07980974129380712*lm - 
          0.02745142842099912*lm^2) + CF*(0.09522566736506241 + 
          0.0780302547295838*lm + 0.1347615577030866*lm^2) + 
        0.016196454506063704*NM + 0.00815846539401472*lm*NM + 
        0.004991168803818022*lm^2*NM + 0.017417719764973565*NL + 
        0.00815846539401472*lm*NL + 0.004991168803818022*lm^2*NL - 
        0.004148055156480962*NH + 0.00815846539401472*lm*NH + 
        0.004991168803818022*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.03017208427025974 - 0.07918793983774507*lm - 
          0.027209600242300278*lm^2) + CF*(0.09518156918762298 + 
          0.07774181097949825*lm + 0.13357440118947408*lm^2) + 
        0.01601872955279514*NM + 0.008101370823520528*lm*NM + 
        0.004947200044054596*lm^2*NM + 0.017314988678631016*NL + 
        0.008101370823520528*lm*NL + 0.004947200044054596*lm^2*NL - 
        0.004116655909238056*NH + 0.008101370823520528*lm*NH + 
        0.004947200044054596*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.03049853888228453 - 0.07853564572464014*lm - 
          0.02695999779804146*lm^2) + CF*(0.09509243801469369 + 
          0.07739253393177607*lm + 0.13234908009947624*lm^2) + 
        0.01583222199463666*NM + 0.008040531137164646*lm*NM + 
        0.0049018177814620836*lm^2*NM + 0.017203220096272936*NL + 
        0.008040531137164646*lm*NL + 0.0049018177814620836*lm^2*NL - 
        0.004083726101575587*NH + 0.008040531137164646*lm*NH + 
        0.0049018177814620836*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.030781049377314983 - 0.07785499300445593*lm - 
          0.02670333408013571*lm^2) + CF*(0.09495896963804527 + 
          0.076984750510902*lm + 0.13108909457521167*lm^2) + 
        0.015637654915501616*NM + 0.007976169354167197*lm*NM + 
        0.0048551516509337655*lm^2*NM + 0.01708295550623152*NL + 
        0.007976169354167197*lm*NL + 0.0048551516509337655*lm^2*NL - 
        0.0040493669803761635*NH + 0.007976169354167197*lm*NH + 
        0.0048551516509337655*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.0310208046900351 - 0.07714805183037404*lm - 
          0.026440285632813167*lm^2) + CF*(0.09478198034603011 + 
          0.07652089055422784*lm + 0.12979776583381009*lm^2) + 
        0.015435731508122903*NM + 0.007908505310326117*lm*NM + 
        0.004807324660511485*lm^2*NM + 0.016954730032918423*NL + 
        0.007908505310326117*lm*NL + 0.004807324660511485*lm^2*NL - 
        0.004013676442682719*NH + 0.007908505310326117*lm*NH + 
        0.004807324660511485*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.031219115027956285 - 0.07641682610853849*lm - 
          0.02617149379792103*lm^2) + CF^2*(0.09456241691854872 + 
          0.07600346104088498*lm + 0.12847824228070323*lm^2) + 
        CF*((0.015227157279040608 + 0.007837754942529406*lm + 
            0.004758453417803823*lm^2)*NM + (0.016819070055276733 + 
            0.007837754942529406*lm + 0.004758453417803823*lm^2)*NL + 
          (-0.003976749032949619 + 0.007837754942529406*lm + 
            0.004758453417803823*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.03137735707697383 - 0.07566325177744415*lm - 
          0.02589756597510286*lm^2) + CF^2*(0.09430127986893043 + 
          0.07543502324160806*lm + 0.1271335056959595*lm^2) + 
        CF*((0.015012565312233349 + 0.007764129684304888*lm + 
            0.004708648359109611*lm^2)*NM + (0.016676491222559372 + 
            0.007764129684304888*lm + 0.004708648359109611*lm^2)*NL + 
          (-0.003938675953042372 + 0.007764129684304888*lm + 
            0.004708648359109611*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.03149699410263293 - 0.0748891956406308*lm - 
          0.02561907688696472*lm^2) + CF^2*(0.09399969154070972 + 
          0.07481817252778915*lm + 0.12576637744509953*lm^2) + 
        CF*((0.014792604192070551 + 0.00768783596081707*lm + 
            0.004658013979448131*lm^2)*NM + (0.016527496820138668 + 
            0.00768783596081707*lm + 0.004658013979448131*lm^2)*NL + 
          (-0.0038995450833895122 + 0.00768783596081707*lm + 
            0.004658013979448131*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.03157953610833502 - 0.07409645468402827*lm - 
          0.02533656984094815*lm^2) + CF^2*(0.09365884000479166 + 
          0.07415552059736776*lm + 0.12437952467374548*lm^2) + 
        CF*((0.014567886410423824 + 0.0076090747727444105*lm + 
            0.004606649061990573*lm^2)*NM + (0.016372576443085075 + 
            0.0076090747727444105*lm + 0.004606649061990573*lm^2)*NL + 
          (-0.003859441013853618 + 0.0076090747727444105*lm + 
            0.004606649061990573*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.031626529542638254 - 0.07328675581627657*lm - 
          0.025050557981016238*lm^2) + CF^2*(0.09327997829127577 + 
          0.07344967989357709*lm + 0.12297546645226153*lm^2) + 
        CF*((0.01433899872574883 + 0.00752804135941843*lm + 
            0.004554646905639316*lm^2)*NM + (0.0162122049397811 + 
            0.00752804135941843*lm + 0.004554646905639316*lm^2)*NL + 
          (-0.0038184450830344597 + 0.00752804135941843*lm + 
            0.004554646905639316*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.03163954399043861 - 0.07246175597667663*lm - 
          0.02476152552345021*lm^2) + CF^2*(0.09286441431064456 + 
          0.07270325001003541*lm + 0.12155657984239193*lm^2) + 
        CF*((0.014106501747994769 + 0.007444924932481655*lm + 
            0.00450209554971822*lm^2)*NM + (0.016046841591907474 + 
            0.007444924932481655*lm + 0.00450209554971822*lm^2)*NL + 
          (-0.0037766354248496294 + 0.007444924932481655*lm + 
            0.00450209554971822*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.03162016056708376 - 0.07162304256116786*lm - 
          0.024469928972078222*lm^2) + CF^2*(0.09241350133006582 + 
          0.07191880589214482*lm + 0.12012510586292946*lm^2) + 
        CF*((0.0138709297518991 + 0.0073599084721281205*lm + 
            0.004449077994923313*lm^2)*NM + (0.01587692950079512 + 
            0.0073599084721281205*lm + 0.004449077994923313*lm^2)*NL + 
          (-0.003734087021352133 + 0.0073599084721281205*lm + 
            0.004449077994923313*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.031569961839810166 - 0.07077213412192779*lm - 
          0.024176198309137763*lm^2) + CF^2*(0.09192862903028504 + 
          0.07109888766022796*lm + 0.1186831553357672*lm^2) + 
        CF*((0.013632790685519567 + 0.007273168578731852*lm + 
            0.004395672419843229*lm^2)*NM + (0.01570289515341922 + 
            0.007273168578731852*lm + 0.004395672419843229*lm^2)*NL + 
          (-0.003690871760858219 + 0.007273168578731852*lm + 
            0.004395672419843229*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.03149052311716245 - 0.06991048130089525*lm - 
          0.023880738158728692*lm^2) + CF^2*(0.09141121515598992 + 
          0.07024599189429748*lm + 0.1172327145973954*lm^2) + 
        CF*((0.013392566344299311 + 0.007184875373349521*lm + 
            0.0043419523924961255*lm^2)*NM + (0.015525148144256614 + 
            0.007184875373349521*lm + 0.0043419523924961255*lm^2)*NL + 
          (-0.0036470585005446833 + 0.007184875373349521*lm + 
            0.0043419523924961255*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.03138340496230411 - 0.06903946796177349*lm - 
          0.02358392892046213*lm^2) + CF^2*(0.09086269776306571 + 
          0.06936256423383737*lm + 0.11577565106408683*lm^2) + 
        CF*((0.013150712684973025 + 0.007095192441207248*lm + 
            0.00428798707644766*lm^2)*NM + (0.015344081031868474 + 
            0.007095192441207248*lm + 0.00428798707644766*lm^2)*NL + 
          (-0.0036027131327689586 + 0.007095192441207248*lm + 
            0.00428798707644766*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.03125014679967031 - 0.0681604124889169*lm - 
          0.023286127871465674*lm^2) + CF^2*(0.09028452805787801 + 
          0.06845099315850912*lm + 0.11431371864174059*lm^2) + 
        CF*((0.012907660256273731 + 0.007004276812852336*lm + 
            0.004233841431175577*lm^2)*NM + (0.01516006931143676 + 
            0.007004276812852336*lm + 0.004233841431175577*lm^2)*NL + 
          (-0.0035578986544394916 + 0.007004276812852336*lm + 
            0.004233841431175577*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.031092261497020456 - 0.06727456922497731*lm - 
          0.022987670235380387*lm^2) + CF^2*(0.08967816381764468 + 
          0.06751360482731775*lm + 0.11284856297368553*lm^2) + 
        CF*((0.01266381472637781 + 0.006912278978172314*lm + 
            0.004179576406432798*lm^2)*NM + (0.014973471486602911 + 
            0.006912278978172314*lm + 0.004179576406432798*lm^2)*NL + 
          (-0.0035126752388354022 + 0.006912278978172314*lm + 
            0.004179576406432798*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.030911230816343494 - 0.0663831300223213*lm - 
          0.022688870217390463*lm^2) + CF^2*(0.08904506337608344 + 
          0.06655265886452762*lm + 0.111381726521735*lm^2) + 
        CF*((0.012419557489433776 + 0.006819342928959799*lm + 
            0.004125249130434629*lm^2)*NM + (0.01478462922585502 + 
            0.006819342928959799*lm + 0.004125249130434629*lm^2)*NL + 
          (-0.0034671003093378772 + 0.006819342928959799*lm + 
            0.004125249130434629*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.03070850163749084 - 0.06548722588605618*lm - 
          0.02239002200467157*lm^2) + CF^2*(0.08838668015491244 + 
          0.06557034499055032*lm + 0.10991465347747863*lm^2) + 
        CF*((0.012175246335729414 + 0.006725606226135802*lm + 
            0.004070913091758468*lm^2)*NM + (0.014593867590408266 + 
            0.006725606226135802*lm + 0.004070913091758468*lm^2)*NL + 
          (-0.0034212286145937844 + 0.006725606226135802*lm + 
            0.004070913091758468*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.03048548286790842 - 0.06458792868905044*lm - 
          0.022091400731936814*lm^2) + CF^2*(0.08770445771917079 + 
          0.06456878040518471*lm + 0.10844869450223528*lm^2) + 
        CF*((0.011931216171936758 + 0.006631200088139496*lm + 
            0.004016618314897602*lm^2)*NM + (0.014401495322042388 + 
            0.006631200088139496*lm + 0.004016618314897602*lm^2)*NL + 
          (-0.0033751123046839022 + 0.006631200088139496*lm + 
            0.004016618314897602*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.030243542960579784 - 0.06368625294162805*lm - 
          0.021793263412006873*lm^2) + CF^2*(0.08699982533273135 + 
          0.06355000783902114*lm + 0.10698511129530647*lm^2) + 
        CF*((0.011687779779740514 + 0.00653624949735227*lm + 
            0.003962411529455795*lm^2)*NM + (0.01420780518071802 + 
            0.00653624949735227*lm + 0.003962411529455795*lm^2)*NL + 
          (-0.0033288010079154996 + 0.00653624949735227*lm + 
            0.003962411529455795*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.029984007970234067 - 0.0627831576006805*lm - 
          0.021495849831539317*lm^2) + CF^2*(0.08627419398942511 + 
          0.06251599419657307*lm + 0.10552508099119302*lm^2) + 
        CF*((0.011445228602542854 + 0.006440873321750993*lm + 
            0.003908336333007149*lm^2)*NM + (0.01401307432300707 + 
            0.006440873321750993*lm + 0.003908336333007149*lm^2)*NL + 
          (-0.003282341907901921 + 0.006440873321750993*lm + 
            0.003908336333007149*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.02970816008524799 - 0.061879547904796654*lm - 
          0.021199383412226505*lm^2) + CF^2*(0.08552895289509731 + 
          0.06146862972181781*lm + 0.10406970038729375*lm^2) + 
        CF*((0.011203833551452554 + 0.006345184449282514*lm + 
            0.0038544333476775465*lm^2)*NM + (0.013817564713455799 + 
            0.006345184449282514*lm + 0.0038544333476775465*lm^2)*NL + 
          (-0.0032357798206308808 + 0.006345184449282514*lm + 
            0.0038544333476775465*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.029417236579338087 - 0.06097627722367742*lm - 
          0.020904072037916333*lm^2) + CF^2*(0.08476546637615677 + 
          0.06040972762335618*lm + 0.10261999000431654*lm^2) + 
        CF*((0.010963845822810432 + 0.00624928993272104*lm + 
            0.0038007403705302423*lm^2)*NM + (0.013621523561966295 + 
            0.00624928993272104*lm + 0.0038007403705302423*lm^2)*NL + 
          (-0.003189157271256857 + 0.00624928993272104*lm + 
            0.0038007403705302423*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.029112429133332146 - 0.06007414891159932*lm - 
          0.02061010884822971*lm^2) + CF^2*(0.0839850711910323 + 
          0.059341024102382685*lm + 0.10117689798221857*lm^2) + 
        CF*((0.010725497720887156 + 0.006153291143014488*lm + 
            0.0037472925178599474*lm^2)*NM + (0.013425183781144363 + 
            0.006153291143014488*lm + 0.0037472925178599474*lm^2)*NL + 
          (-0.003142514570387877 + 0.006153291143014488*lm + 
            0.0037472925178599474*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.02879497148707575 - 0.05917391815603266*lm - 
          0.020317672999345875*lm^2) + CF^2*(0.08318925023032858 + 
          0.05826417873213266*lm + 0.09974130381497066*lm^2) + 
        CF*((0.01048900347979356 + 0.006057283929347387*lm + 
            0.0036941223635174316*lm^2)*NM + (0.013228764458330577 + 
            0.006057283929347387*lm + 0.0036941223635174316*lm^2)*NL + 
          (-0.003095889889661615 + 0.006057283929347387*lm + 
            0.0036941223635174316*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.02846577405039421 - 0.05827629381372232*lm - 
          0.020026930392705075*lm^2) + CF^2*(0.08237889992027034 + 
          0.05718077514247882*lm + 0.09831402192782492*lm^2) + 
        CF*((0.010254560080250523 + 0.005961358784348338*lm + 
            0.003641260071400923*lm^2)*NM + (0.013032471337715758 + 
            0.005961358784348338*lm + 0.003641260071400923*lm^2)*NL + 
          (-0.003049319336435585 + 0.005961358784348338*lm + 
            0.003641260071400923*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.02812599239723311 - 0.057381940227614975*lm - 
          0.019738034372440042*lm^2) + CF^2*(0.08155546522657608 + 
          0.0560923219679233*lm + 0.0968958051010693*lm^2) + 
        CF*((0.010022348056611492 + 0.005865601013051309*lm + 
            0.0035887335222618256*lm^2)*NM + (0.012836497308551352 + 
            0.005865601013051309*lm + 0.0035887335222618256*lm^2)*NL + 
          (-0.0030028370274372855 + 0.005865601013051309*lm + 
            0.0035887335222618256*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.027776634246915174 - 0.056491479018977886*lm - 
          0.019451126392395313*lm^2) + CF^2*(0.08072015150863603 + 
          0.05500025402140619*lm + 0.09548734774448608*lm^2) + 
        CF*((0.009792532291864837 + 0.0057700909043838415*lm + 
            0.0035365684349809657*lm^2)*NM + (0.012641022896006765 + 
            0.0057700909043838415*lm + 0.0035365684349809657*lm^2)*NL + 
          (-0.0029564751612421404 + 0.0057700909043838415*lm + 
            0.0035365684349809657*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.027418662252077883 - 0.055605490849912835*lm - 
          0.019166336653629112*lm^2) + CF^2*(0.0798741278990714 + 
          0.053905933660158355*lm + 0.09408928902690655*lm^2) + 
        CF*((0.009565262796051152 + 0.005674903904103035*lm + 
            0.0034847884824780206*lm^2)*NM + (0.012446216751706922 + 
            0.005674903904103035*lm + 0.0034847884824780206*lm^2)*NL + 
          (-0.002910264089467271 + 0.005674903904103035*lm + 
            0.0034847884824780206*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.027052994677156366 - 0.0547245171522338*lm - 
          0.01888378471331746*lm^2) + CF^2*(0.07901852640704912 + 
          0.05281065231329612*lm + 0.09270221586537662*lm^2) + 
        CF*((0.009340675469739554 + 0.005580110788233511*lm + 
            0.0034334154024213566*lm^2)*NM + (0.01225223614141014 + 
            0.005580110788233511*lm + 0.0034334154024213566*lm^2)*NL + 
          (-0.002864232386584372 + 0.005580110788233511*lm + 
            0.0034334154024213566*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.026680507182179593 - 0.053849061819357995*lm - 
          0.018603580065996377*lm^2) + CF^2*(0.07815444320089111 + 
          0.05171563214401373*lm + 0.09132666577852766*lm^2) + 
        CF*((0.009118894803799063 + 0.005485777836181632*lm + 
            0.003382469102908432*lm^2)*NM + (0.012059227427664892 + 
            0.005485777836181632*lm + 0.003382469102908432*lm^2)*NL + 
          (-0.00281840691827305 + 0.005485777836181632*lm + 
            0.003382469102908432*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.026302028821027838 - 0.05297959285846501*lm - 
          0.018325822698086573*lm^2) + CF^2*(0.07728292831021825 + 
          0.050622027822103205*lm + 0.08996312960878863*lm^2) + 
        CF*((0.00890002476598854 + 0.005391967002808316*lm + 
            0.003331967763288468*lm^2)*NM + (0.011867326545618954 + 
            0.005391967002808316*lm + 0.003331967763288468*lm^2)*NL + 
          (-0.0027728129082489634 + 0.005391967002808316*lm + 
            0.003331967763288468*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.02591835297979018 - 0.05211654400071571*lm - 
          0.018050603616647013*lm^2) + CF^2*(0.07640500521730731 + 
          0.04953092838514311*lm + 0.08861205411808534*lm^2) + 
        CF*((0.008684169386747124 + 0.005298736088839912*lm + 
            0.003281927930299457*lm^2)*NM + (0.011676659470450596 + 
            0.005298736088839912*lm + 0.003281927930299457*lm^2)*NL + 
          (-0.002727474003508828 + 0.005298736088839912*lm + 
            0.003281927930299457*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.025530228121511206 - 0.051260316267797555*lm - 
          0.017778005353300295*lm^2) + CF^2*(0.0755216500855518 + 
          0.04844335916906974*lm + 0.087273844461656*lm^2) + 
        CF*((0.008471412767927554 + 0.005206138909083785*lm + 
            0.0032323646096909624*lm^2)*NM + (0.011487342675152853 + 
            0.005206138909083785*lm + 0.0032323646096909624*lm^2)*NL + 
          (-0.0026824123379612396 + 0.005206138909083785*lm + 
            0.0032323646096909624*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.025138364793638682 - 0.05041127949348293*lm - 
          0.017508102444264803*lm^2) + CF^2*(0.0746338035502751 + 
          0.04736028379099703*lm + 0.08594886654457266*lm^2) + 
        CF*((0.008261831495215219 + 0.005114225457993471*lm + 
            0.0031832913535026915*lm^2)*NM + (0.011299483577632255 + 
            0.005114225457993471*lm + 0.0031832913535026915*lm^2)*NL + 
          (-0.0026376485943979348 + 0.005114225457993471*lm + 
            0.0031832913535026915*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.024743434867910478 - 0.04956977379925694*lm - 
          0.01724096188741665*lm^2) + CF^2*(0.07374236702166356 + 
          0.04628260616910245*lm + 0.08463744926549992*lm^2) + 
        CF*((0.008055491398406469 + 0.005023042072198236*lm + 
            0.0031347203431666636*lm^2)*NM + (0.011113180976285974 + 
            0.005023042072198236*lm + 0.0031347203431666636*lm^2)*NL + 
          (-0.0025932020647957245 + 0.005023042072198236*lm + 
            0.0031347203431666636*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.024346073216866874 - 0.0487361110233958*lm - 
          0.016976643577289365*lm^2) + CF^2*(0.07284820391646092 + 
          0.04521117256616456*lm + 0.0833398866521478*lm^2) + 
        CF*((0.007852449094651777 + 0.0049326315896744246*lm + 
            0.0030866624685980666*lm^2)*NM + (0.010928525473399248 + 
            0.0049326315896744246*lm + 0.0030866624685980666*lm^2)*NL + 
          (-0.00254909070892257 + 0.0049326315896744246*lm + 
            0.0030866624685980666*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.023946878849483908 - 0.04791057610316208*lm - 
          0.016715200718901632*lm^2) + CF^2*(0.07195213986993587 + 
          0.044146773644936514*lm + 0.08205643989278982*lm^2) + 
        CF*((0.007652752380691244 + 0.004843033505291901*lm + 
            0.0030391274034366604*lm^2)*NM + (0.010745599885860584 + 
            0.004843033505291901*lm + 0.0030391274034366604*lm^2)*NL + 
          (-0.0025053312112540823 + 0.004843033505291901*lm + 
            0.0030391274034366604*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.023546416153540365 - 0.04709342841003131*lm - 
          0.01645668022128358*lm^2) + CF^2*(0.07105496322836204 + 
          0.04309014652498682*lm + 0.08078733926811939*lm^2) + 
        CF*((0.00745644078708117 + 0.004754284122518582*lm + 
            0.0029921236765970143*lm^2)*NM + (0.010564479642828332 + 
            0.004754284122518582*lm + 0.0029921236765970143*lm^2)*NL + 
          (-0.002461939036185326 + 0.004754284122518582*lm + 
            0.0029921236765970143*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.02314521614380882 - 0.04628490303808044*lm - 
          0.016201123071550666*lm^2) + CF^2*(0.07015742562390978 + 
          0.0420419768319439*lm + 0.07953278598761235*lm^2) + 
        CF*((0.007263546106933612 + 0.0046664167011103395*lm + 
            0.002945658740281939*lm^2)*NM + (0.010385233170100682 + 
            0.0046664167011103395*lm + 0.002945658740281939*lm^2)*NL + 
          (-0.002418928481553576 + 0.0046664167011103395*lm + 
            0.002945658740281939*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.022743777710368205 - 0.045485212045855934*lm - 
          0.015948564690351424*lm^2) + CF^2*(0.0692602426231547 + 
          0.04100290073125956*lm + 0.07829295393445244*lm^2) + 
        CF*((0.0070740929027145304 + 0.004579461600652816*lm + 
            0.00289973903460935*lm^2)*NM + (0.010207922261043922 + 
            0.004579461600652816*lm + 0.00289973903460935*lm^2)*NL + 
          (-0.002376312730478456 + 0.004579461600652816*lm + 
            0.00289973903460935*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.022342568860523347 - 0.044694545652199824*lm - 
          0.0156990352694916*lm^2) + CF^2*(0.06836409443783752 + 
          0.03997350693966789*lm + 0.07706799132295876*lm^2) + 
        CF*((0.0068880989893100476 + 0.004493446419856458*lm + 
            0.0028543700489984726*lm^2)*NM + (0.010032602434022722 + 
            0.004493446419856458*lm + 0.0028543700489984726*lm^2)*NL + 
          (-0.002334103901530589 + 0.004493446419856458*lm + 
            0.0028543700489984726*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.021942027949577232 - 0.04391307338665011*lm - 
          0.015452560092512741*lm^2) + CF^2*(0.06746962668922851 + 
          0.038954338708471425*lm + 0.07585802227233528*lm^2) + 
        CF*((0.006705575894562971 + 0.004408396131536741*lm + 
            0.002809556380456862*lm^2)*NM + (0.0098593232763528 + 
            0.004408396131536741*lm + 0.002809556380456862*lm^2)*NL + 
          (-0.002292313097253771 + 0.004408396131536741*lm + 
            0.002809556380456862*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.021542564896160223 - 0.043140945195148536*lm - 
          0.015209159838978414*lm^2) + CF^2*(0.06657745121768768 + 
          0.03794589577364531*lm + 0.07466314830043949*lm^2) + 
        CF*((0.006526529297634239 + 0.004324333213238613*lm + 
            0.0027653017889051664*lm^2)*NM + (0.009688128774861787 + 
            0.004324333213238613*lm + 0.0027653017889051664*lm^2)*NL + 
          (-0.0022509504510540455 + 0.004324333213238613*lm + 
            0.0027653017889051664*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.02114456237851335 - 0.04237829250188725*lm - 
          0.014968850873195983*lm^2) + CF^2*(0.06568814692983026 + 
          0.03694863626852053*lm + 0.07348344974114392*lm^2) + 
        CF*((0.0063509594459383095 + 0.004241277773487868*lm + 
            0.002721609249671997*lm^2)*NM + (0.009519057633200045 + 
            0.004241277773487868*lm + 0.002721609249671997*lm^2)*NL + 
          (-0.002210025172484094 + 0.004241277773487868*lm + 
            0.002721609249671997*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.02074837700866395 - 0.04162522922820769*lm - 
          0.014731645518076689*lm^2) + CF^2*(0.06480226067631534 + 
          0.0359629785954984*lm + 0.07231898708874011*lm^2) + 
        CF*((0.0061788615511443115 + 0.004159247673672908*lm + 
            0.0026784810032866708*lm^2)*NM + (0.009352143576090292 + 
            0.004159247673672908*lm + 0.0026784810032866708*lm^2)*NL + 
          (-0.002169545590960571 + 0.004159247673672908*lm + 
            0.0026784810032866708*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.020354340481959776 - 0.04088185276953218*lm - 
          0.01449755231481154*lm^2) + CF^2*(0.06392030815394134 + 
          0.03498930325386573*lm + 0.07116980227271119*lm^2) + 
        CF*((0.0060102261649825 + 0.004078258645578387*lm + 
            0.002635918602693007*lm^2)*NM + (0.009187415640744486 + 
            0.004078258645578387*lm + 0.002635918602693007*lm^2)*NL + 
          (-0.0021295191979108256 + 0.004078258645578387*lm + 
            0.002635918602693007*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.019962760699871043 - 0.04014824493136299*lm - 
          0.014266576269015448*lm^2) + CF^2*(0.06304277482630032 + 
          0.03402795462133265*lm + 0.07003591986607584*lm^2) + 
        CF*((0.005845039535534394 + 0.003998324404607878*lm + 
            0.002593922958002809*lm^2)*NM + (0.009024898455709278 + 
            0.003998324404607878*lm + 0.002593922958002809*lm^2)*NL + 
          (-0.002089952687428573 + 0.003998324404607878*lm + 
            0.002593922958002809*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.019573922864351362 - 0.03942447282542612*lm - 
          0.014038719083967435*lm^2) + CF^2*(0.06217011685775048 + 
          0.03307924268740622*lm + 0.06891734823038559*lm^2) + 
        CF*((0.005683283944490611 + 0.003919456758746169*lm + 
            0.00255249437890317*lm^2)*NM + (0.008864612507428113 + 
            0.003919456758746169*lm + 0.00255249437890317*lm^2)*NL + 
          (-0.0020508519954232783 + 0.003919456758746169*lm + 
            0.00255249437890317*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.019188090542472863 - 0.0387105897270695*lm - 
          0.013813979381550264*lm^2) + CF^2*(0.06130276205611355 + 
          0.032143444737150986*lm + 0.06781408060033765*lm^2) + 
        CF*((0.005524938026661882 + 0.0038416657133233194*lm + 
            0.0025116326148273208*lm^2)*NM + (0.008706574394829811 + 
            0.0038416657133233194*lm + 0.0025116326148273208*lm^2)*NL + 
          (-0.002012222337325887 + 0.0038416657133233194*lm + 
            0.0025116326148273208*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.01880550670021535 - 0.03800663589504885*lm - 
          0.013592352911469052*lm^2) + CF^2*(0.06044111081967765 + 
          0.031220806984275377*lm + 0.06672609611084807*lm^2) + 
        CF*((0.005369977071416073 + 0.0037649595716524073*lm + 
            0.0024713368929943727*lm^2)*NM + (0.008550797072270397 + 
            0.0037649595716524073*lm + 0.0024713368929943727*lm^2)*NL + 
          (-0.0019740682443747325 + 0.0037649595716524073*lm + 
            0.0024713368929943727*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.018426394704771407 - 0.03731263935484977*lm - 
          0.013373832749304955*lm^2) + CF^2*(0.059585537084936045 + 
          0.030311546152826545*lm + 0.06565336076931523*lm^2) + 
        CF*((0.005218373307868956 + 0.003689345031621126*lm + 
            0.0024316059544190827*lm^2)*NM + (0.00839729008116805 + 
            0.003689345031621126*lm + 0.0024316059544190827*lm^2)*NL + 
          (-0.001936393598540038 + 0.003689345031621126*lm + 
            0.0024316059544190827*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.01805095929477237 - 0.036628616646703395*lm - 
          0.013158409483937246*lm^2) + CF^2*(0.05873638927149749 + 
          0.029415851007079403*lm + 0.06459582837569193*lm^2) + 
        CF*((0.005070096173677235 + 0.0036148272783242306*lm + 
            0.00239243808798859*lm^2)*NM + (0.008246059770680426 + 
            0.0036148272783242306*lm + 0.00239243808798859*lm^2)*NL + 
          (-0.0018992016660397176 + 0.0036148272783242306*lm + 
            0.00239243808798859*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.017679387518190735 - 0.03595457353945535*lm - 
          0.012946071394844803*lm^2) + CF^2*(0.05789399122125435 + 
          0.028533883829472032*lm + 0.06355344139287449*lm^2) + 
        CF*((0.004925112568574266 + 0.0035414100728294482*lm + 
            0.002353831162699055*lm^2)*NM + (0.008097109507780139 + 
            0.0035414100728294482*lm + 0.002353831162699055*lm^2)*NL + 
          (-0.0018624951296349827 + 0.0035414100728294482*lm + 
            0.002353831162699055*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.017311849637760855 - 0.035290505711445035*lm - 
          0.012736804619776481*lm^2) + CF^2*(0.05705864312904153 + 
          0.027665781846673367*lm + 0.06252613176981181*lm^2) + 
        CF*((0.004783387092888853 + 0.003469095837173961*lm + 
            0.0023157826581411784*lm^2)*NM + (0.007950439877087824 + 
            0.003469095837173961*lm + 0.0023157826581411784*lm^2)*NL + 
          (-0.001826276119578391 + 0.003469095837173961*lm + 
            0.0023157826581411784*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.01694850000406103 - 0.034636399399545006*lm - 
          0.012530593313258797*lm^2) + CF^2*(0.05623062246261622 + 
          0.026811658604072874*lm + 0.06151382171963409*lm^2) + 
        CF*((0.004644882272529795 + 0.0033978857356920977*lm + 
            0.002278289693319781*lm^2)*NM + (0.00780604887082371 + 
            0.0033978857356920977*lm + 0.002278289693319781*lm^2)*NL + 
          (-0.00179054624335845 + 0.0033978857356920977*lm + 
            0.002278289693319781*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.016589477896301923 - 0.03399223201749881*lm - 
          0.012327419796389062*lm^2) + CF^2*(0.055410184869605354 + 
          0.02597160528915885*lm + 0.06051642445500085*lm^2) + 
        CF*((0.004509558769774731 + 0.0033277797527775216*lm + 
            0.0022413490538889204*lm^2)*NM + (0.007663932069238062 + 
            0.0033277797527775216*lm + 0.0022413490538889204*lm^2)*NL + 
          (-0.0017553066142354694 + 0.0033277797527775216*lm + 
            0.0022413490538889204*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.01623490833127398 - 0.03335797274468119*lm - 
          0.012127264698342464*lm^2) + CF^2*(0.0545975650699107 + 
          0.025145692004404946*lm + 0.0595338448827721*lm^2) + 
        CF*((0.004377375581778967 + 0.0032587767671851007*lm + 
            0.002204957217880448*lm^2)*NM + (0.0075240828118785935 + 
            0.0032587767671851007*lm + 0.002204957217880448*lm^2)*NL + 
          (-0.001720557878618656 + 0.0032587767671851007*lm + 
            0.002204957217880448*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.015884902840783793 - 0.03273358308638689*lm - 
          0.011930107090002563*lm^2) + CF^2*(0.053792977731855436 + 
          0.024333968990415428*lm + 0.058565980260012585*lm^2) + 
        CF*((0.004248290226640333 + 0.003190874622978841*lm + 
            0.002169110380000466*lm^2)*NM + (0.007386492360049222 + 
            0.003190874622978841*lm + 0.002169110380000466*lm^2)*NL + 
          (-0.0016863002422747074 + 0.003190874622978841*lm + 
            0.002169110380000466*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.01553956021810031 - 0.03211901740673451*lm - 
          0.011735924610106384*lm^2) + CF^2*(0.05299661833078783 + 
          0.023536467800191457*lm + 0.05761272081324952*lm^2) + 
        CF*((0.004122258917821242 + 0.0031240701972328954*lm + 
            0.002133804474564797*lm^2)*NM + (0.007251150050809628 + 
            0.0031240701972328954*lm + 0.002133804474564797*lm^2)*NL + 
          (-0.0016525334955463824 + 0.0031240701972328954*lm + 
            0.002133804474564797*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.015198967233987738 - 0.031514223435249795*lm - 
          0.011544693584277623*lm^2) + CF^2*(0.052208663989027355 + 
          0.022753202425474617*lm + 0.05667395032281742*lm^2) + 
        CF*((0.00399923672751508 + 0.003058359464592745*lm + 
            0.002099035197141386*lm^2)*NM + (0.007118043442859069 + 
            0.003058359464592745*lm + 0.002099035197141386*lm^2)*NL + 
          (-0.0016192570373704273 + 0.003058359464592745*lm + 
            0.002099035197141386*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.014863199322957746 - 0.030919142748169308*lm - 
          0.011356389137304471*lm^2) + CF^2*(0.05142927429621376 + 
          0.021984170376202344*lm + 0.05574954667404013*lm^2) + 
        CF*((0.0038791777395036603 + 0.002993737558803302*lm + 
            0.0020647980249644494*lm^2)*NM + (0.006987158454641087 + 
            0.002993737558803302*lm + 0.0020647980249644494*lm^2)*NL + 
          (-0.0015864698983936174 + 0.002993737558803302*lm + 
            0.0020647980249644494*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.014532321240421702 - 0.030333711225480117*lm - 
          0.011170985299002243*lm^2) + CF^2*(0.05065859210928494 + 
          0.021229353714174285*lm + 0.0548393823769201*lm^2) + 
        CF*((0.0037620351919792116 + 0.0029301988313099156*lm + 
            0.002031088236182226*lm^2)*NM + (0.0068584794949981855 + 
            0.0029301988313099156*lm + 0.002031088236182226*lm^2)*NL + 
          (-0.0015541707630204158 + 0.0029301988313099156*lm + 
            0.002031088236182226*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.014206387691471438 - 0.02975785948468568*lm - 
          0.010988455103985216*lm^2) + CF^2*(0.04989674433147747 + 
          0.02048872004208051*lm + 0.05394332505592742*lm^2) + 
        CF*((0.00364776161088445 + 0.0028677369070371815*lm + 
            0.0019979009279973117*lm^2)*NM + (0.006731989586697466 + 
            0.0028677369070371815*lm + 0.0019979009279973117*lm^2)*NL + 
          (-0.0015223579905485043 + 0.0028677369070371815*lm + 
            0.0019979009279973117*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.013885323239365217 - 0.029191479094041038*lm - 
          0.010808770186771054*lm^2) + CF*(0.04914367415723998 + 
          0.019762061269057933*lm + 0.05306123546233063*lm^2) + 
        0.0035362947225622853*NM + 0.0028063386350356476*lm*NM + 
        0.0019652309430492824*lm^2*NM + 0.006607656806201129*NL + 
        0.0028063386350356476*lm*NL + 0.0019652309430492824*lm^2*NL - 
        0.0014910285771833436*NH + 0.0028063386350356476*lm*NH + 
        0.0019652309430492824*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.013569426479946281 - 0.028634565667222767*lm - 
          0.010631902966145627*lm^2) + CF*(0.04839984440218305 + 
          0.01904967110868529*lm + 0.05219297819744217*lm^2) + 
        0.0034276169139739678*NM + 0.00274600960022168*lm*NM + 
        0.0019330732665719323*lm^2*NM + 0.0064854914825737105*NL + 
        0.00274600960022168*lm*NL + 0.0019330732665719323*lm^2*NL - 
        0.0014601825889313529*NH + 0.00274600960022168*lm*NH + 
        0.0019330732665719323*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.01325858049823985 - 0.028086995328247412*lm - 
          0.010457823414910403*lm^2) + CF*(0.04766513688890643 + 
          0.018351284645932848*lm + 0.05133840585501471*lm^2) + 
        0.003321662155822648*NM + 0.0026867342281318325*lm*NM + 
        0.0019014224390746187*lm^2*NM + 0.006365456698969837*NL + 
        0.0026867342281318325*lm*NL + 0.0019014224390746187*lm^2*NL - 
        0.001429816258834647*NH + 0.0026867342281318325*lm*NH + 
        0.0019014224390746187*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.012952806091546611 - 0.027548681705575482*lm - 
          0.010286501476849006*lm^2) + CF*(0.04693962277522197 + 
          0.017666821410162476*lm + 0.05049737088634967*lm^2) + 
        0.0032183813540392144*NM + 0.002628503770007342*lm*NM + 
        0.0018702729957907284*lm^2*NM + 0.006247531101035633*NL + 
        0.002628503770007342*lm*NL + 0.0018702729957907284*lm^2*NL - 
        0.001399926843636714*NH + 0.002628503770007342*lm*NH + 
        0.0018702729957907284*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.012652116669787977 - 0.027019534994052238*lm - 
          0.010117906517754141*lm^2) + CF*(0.04622336072870995 + 
          0.016996190681099598*lm + 0.04966972290533851*lm^2) + 
        0.0031177252326628478*NM + 0.0025713089865457297*lm*NM + 
        0.0018396193668643894*lm^2*NM + 0.006131692459880446*NL + 
        0.0025713089865457297*lm*NL + 0.0018396193668643894*lm^2*NL - 
        0.0013705113666890008*NH + 0.0025713089865457297*lm*NH + 
        0.0018396193668643894*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.012356518742512123 - 0.026499462271691254*lm - 
          0.009952007394769176*lm^2) + CF*(0.0455163975883602 + 
          0.016339292251395323*lm + 0.04885530902886687*lm^2) + 
        0.003019644421490901*NM + 0.0025151401894518235*lm*NM + 
        0.0018094558899580321*lm^2*NM + 0.006017917760500379*NL + 
        0.0025151401894518235*lm*NL + 0.0018094558899580321*lm^2*NL - 
        0.0013415666341033662*NH + 0.0025151401894518235*lm*NH + 
        0.0018094558899580321*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.01206601238150263 - 0.025988367798871675*lm - 
          0.009788772521504152*lm^2) + CF*(0.04481876900226563 + 
          0.015696017151153173*lm + 0.048053974196474926*lm^2) + 
        0.0029240895370607556*NM + 0.002459987280769096*lm*NM + 
        0.001779776822091664*lm^2*NM + 0.00590618328486685*NL + 
        0.002459987280769096*lm*NL + 0.001779776822091664*lm^2*NL - 
        0.0013130892501513917*NH + 0.002459987280769096*lm*NH + 
        0.001779776822091664*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.011780591660016207 - 0.025486153300778122*lm - 
          0.00962816992914868*lm^2) + CF*(0.044130500041772915 + 
          0.015066248335946943*lm + 0.04726556147036625*lm^2) + 
        0.002831011257356848*NM + 0.002405839790090543*lm*NM + 
        0.0017505763507543056*lm^2*NM + 0.005796464689953927*NL + 
        0.002405839790090543*lm*NL + 0.0017505763507543056*lm^2*NL - 
        0.0012850756319400406*NH + 0.002405839790090543*lm*NH + 
        0.0017505763507543056*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.011500245069641826 - 0.02499271823387719*lm - 
          0.009470167323793141*lm^2) + CF*(0.043451605792525404 + 
          0.014449861339811033*lm + 0.046489912316802696*lm^2) + 
        0.0027403603906154712*NM + 0.0023526869097445467*lm*NM + 
        0.0017218486043260256*lm^2*NM + 0.005688737080965559*NL + 
        0.0023526869097445467*lm*NL + 0.0017218486043260256*lm^2*NL - 
        0.0012575220233921912*NH + 0.0023526869097445467*lm*NH + 
        0.0017218486043260256*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.011224955915740013 - 0.024507960037190836*lm - 
          0.009314732140159085*lm^2) + CF*(0.04278209192285887 + 
          0.013846724894639202*lm + 0.04572686686987187*lm^2) + 
        0.0026520879385803714*NM + 0.0023005175280474714*lm*NM + 
        0.0016935876618471063*lm^2*NM + 0.005582975080011633*NL + 
        0.0023005175280474714*lm*NL + 0.0016935876618471063*lm^2*NL - 
        0.0012304245085596247*NH + 0.0023005175280474714*lm*NH + 
        0.0016935876618471063*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.01095470269238799 - 0.024031774369094646*lm - 
          0.00916183159192976*lm^2) + CF*(0.04212195523003298 + 
          0.013256701517383163*lm + 0.04497626417856427*lm^2) + 
        0.002566145154543508*NM + 0.0022493202607111484*lm*NM + 
        0.0016657875621690472*lm^2*NM + 0.005479152890470173*NL + 
        0.0022493202607111484*lm*NL + 0.0016657875621690472*lm^2*NL - 
        0.0012037790242951287*NH + 0.0022493202607111484*lm*NH + 
        0.0016657875621690472*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.010689459437724052 - 0.023564055330337612*lm - 
          0.009011432718862157*lm^2) + CF*(0.041471184164799405 + 
          0.01267964806639817*lm + 0.04423794243805059*lm^2) + 
        0.0024824835964875956*NM + 0.002199083480489976*lm*NM + 
        0.0016384423125203923*lm^2*NM + 0.005377244357261838*NL + 
        0.002199083480489976*lm*NL + 0.0016384423125203923*lm^2*NL - 
        0.001177581372309476*NH + 0.002199083480489976*lm*NH + 
        0.0016384423125203923*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.010429196070552864 - 0.02310469567395029*lm - 
          0.00886350243085288*lm^2) + CF*(0.04082975933482262 + 
          0.012115416268239153*lm + 0.043511739206005054*lm^2) + 
        0.0024010551756301663*NM + 0.0021497953451489727*lm*NM + 
        0.0016115458965187057*lm^2*NM + 0.005277223023252228*NL + 
        0.0021497953451489727*lm*NL + 0.0016115458965187057*lm^2*NL - 
        0.0011518272306381633*NH + 0.0021497953451489727*lm*NH + 
        0.0016115458965187057*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.010173878709042303 - 0.02265358700267914*lm - 
          0.008718007549121531*lm^2) + CF*(0.04019765398748155 + 
          0.011563853216168034*lm + 0.04279749160477843*lm^2) + 
        0.002321812200652808*NM + 0.0021014438238308947*lm*NM + 
        0.0015850922816584602*lm^2*NM + 0.005179062181987244*NL + 
        0.0021014438238308947*lm*NL + 0.0015850922816584602*lm^2*NL - 
        0.0011265121645419327*NH + 0.0021014438238308947*lm*NH + 
        0.0015850922816584602*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.00992346997231221 - 0.022210619954557292*lm - 
          0.00857491484466709*lm^2) + CF*(0.03957483447258923 + 
          0.011024801841590479*lm + 0.04209503651018389*lm^2) + 
        0.0022447074178839786*NM + 0.0020540167218973714*lm*NM + 
        0.001559075426303107*lm^2*NM + 0.005082734926957012*NL + 
        0.0020540167218973714*lm*NL + 0.001559075426303107*lm^2*NL - 
        0.001101631636864274*NH + 0.0020540167218973714*lm*NH + 
        0.001559075426303107*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.009677929265685808 - 0.02177568437719512*lm - 
          0.008434191074144925*lm^2) + CF*(0.03896126068557464 + 
          0.010498101359598918*lm + 0.041404210727620544*lm^2) + 
        0.002169694047689243*NM + 0.0020075017043159893*lm*NM + 
        0.0015334892862081681*lm^2*NM + 0.004988214197574503*NL + 
        0.0020075017043159893*lm*NL + 0.0015334892862081681*lm^2*NL - 
        0.0010771810178682865*NH + 0.0020075017043159893*lm*NH + 
        0.0015334892862081681*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.009437213050345674 - 0.02134866949134857*lm - 
          0.008295803013304667*lm^2) + CF*(0.0383568864916751 + 
          0.009983587689757812*lm + 0.04072485115622291*lm^2) + 
        0.0020967258173089864*NM + 0.001961886317662296*lm*NM + 
        0.0015083278206008486*lm^2*NM + 0.004895472822046019*NL + 
        0.001961886317662296*lm*NL + 0.0015083278206008486*lm^2*NL - 
        0.0010531555945744926*NH + 0.001961886317662296*lm*NH + 
        0.0015083278206008486*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.009201275098108022 - 0.020929464044298424*lm - 
          0.008159717488122031*lm^2) + CF*(0.03776166013169012 + 
          0.009481093853227242*lm + 0.04005679494168997*lm^2) + 
        0.002025756990370518*NM + 0.0019171580108028803*lm*NM + 
        0.0014835849978403692*lm^2*NM + 0.004804483557302179*NL + 
        0.0019171580108028803*lm*NL + 0.0014835849978403692*lm^2*NL - 
        0.0010295505796204278*NH + 0.0019171580108028803*lm*NH + 
        0.0014835849978403692*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.008970066732001684 - 0.020517956453550056*lm - 
          0.008025901403751007*lm^2) + CF*(0.03717552460984806 + 
          0.00899045034728175*lm + 0.03939987961841403*lm^2) + 
        0.0019567423932890142*NM + 0.0018733041543229178*lm*NM + 
        0.001459254800682001*lm^2*NM + 0.004715219126149831*NL + 
        0.0018733041543229178*lm*NL + 0.001459254800682001*lm^2*NL - 
        0.001006361119662078*NH + 0.0018733041543229178*lm*NH + 
        0.001459254800682001*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.008743537053311537 - 0.020114034941340526*lm - 
          0.007894321771416376*lm^2) + CF*(0.03659841806433583 + 
          0.008511485498243179*lm + 0.03875394324149857*lm^2) + 
        0.0018896374387598963*NM + 0.0018303120587589508*lm*NM + 
        0.0014353312311666138*lm^2*NM + 0.004627652251797492*NL + 
        0.0018303120587589508*lm*NL + 0.0014353312311666138*lm^2*NL - 
        0.000983582303336521*NH + 0.0018303120587589508*lm*NH + 
        0.0014353312311666138*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.008521633155720201 - 0.019717587660418093*lm - 
          0.007764945733360435*lm^2) + CF*(0.036030274121038916 + 
          0.008044025793808801*lm + 0.03811882450922396*lm^2) + 
        0.0018243981465339769*NM + 0.0017881689916950897*lm*NM + 
        0.001411808315156443*lm^2*NM + 0.004541755689899455*NL + 
        0.0017881689916950897*lm*NL + 0.001411808315156443*lm^2*NL - 
        0.0009612091688044111*NH + 0.0017881689916950897*lm*NH + 
        0.001411808315156443*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.008304300327156771 - 0.0193285028115382*lm - 
          0.007637740585951993*lm^2) + CF*(0.03547102223103533 + 
          0.007587896195719692*lm + 0.037494362876491605*lm^2) + 
        0.0017609811616560403*NM + 0.0017468621937783847*lm*NM + 
        0.001388680106536726*lm^2*NM + 0.0044575022582565346*NL + 
        0.0017468621937783847*lm*NL + 0.001388680106536726*lm^2*NL - 
        0.0009392367108902684*NH + 0.0017468621937783847*lm*NH + 
        0.001388680106536726*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.008091482239936831 - 0.018946668753099933*lm - 
          0.007512673801060191*lm^2) + CF*(0.034920587992381444 + 
          0.00714292043367864*lm + 0.03688039865975003*lm^2) + 
        0.0016993437703373543*NM + 0.0017063788937067203*lm*NM + 
        0.001365940691101853*lm^2*NM + 0.004374864864304613*NL + 
        0.0017063788937067203*lm*NL + 0.001365940691101853*lm^2*NL - 
        0.0009176598878378711*NH + 0.0017063788937067203*lm*NH + 
        0.001365940691101853*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.007883121129754474 - 0.01857197410332777*lm - 
          0.00738971304579047*lm^2) + CF*(0.03437889345672156 + 
          0.006708921281392365*lm + 0.03627677313388049*lm^2) + 
        0.0016394439136229995*NM + 0.0016667063222403126*lm*NM + 
        0.0013435841901437218*lm^2*NM + 0.004293816530515623*NL + 
        0.0016667063222403126*lm*NL + 0.0013435841901437218*lm^2*NL - 
        0.0008964736276973988*NH + 0.0016667063222403126*lm*NH + 
        0.0013435841901437218*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.00767915796406399 - 0.018204307835384792*lm - 
          0.007268826200674981*lm^2) + CF*(0.0338458574212455 + 
          0.006285720815579065*lm + 0.03568332862149536*lm^2) + 
        0.0015812401990057557*NM + 0.001627831725285669*lm*NM + 
        0.0013216047637590875*lm^2*NM + 0.004214330417829375*NL + 
        0.001627831725285669*lm*NL + 0.0013216047637590875*lm^2*NL - 
        0.0008756728343603556*NH + 0.001627831725285669*lm*NH + 
        0.0013216047637590875*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.007479532600366804 - 0.017843559365785914*lm - 
          0.007149981376405014*lm^2) + CF*(0.033321395706510715 + 
          0.005873140658749574*lm + 0.03509990857507916*lm^2) + 
        0.0015246919101296228*NM + 0.001589742376098758*lm*NM + 
        0.0012999966138918207*lm^2*NM + 0.004136379847228707*NL + 
        0.001589742376098758*lm*NL + 0.0012999966138918207*lm^2*NL - 
        0.0008552523932576948*NH + 0.001589742376098758*lm*NH + 
        0.0012999966138918207*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.007284183934897695 - 0.01748961863646275*lm - 
          0.007033146929188506*lm^2) + CF*(0.03280542142063618 + 
          0.005471002206538581*lm + 0.03452635765237994*lm^2) + 
        0.0014697590147178293*NM + 0.001552425586652085*lm*NM + 
        0.001278753987125183*lm^2*NM + 0.004059938319564757*NL + 
        0.001552425586652085*lm*NL + 0.001278753987125183*lm^2*NL - 
        0.0008352071767359797*NH + 0.001552425586652085*lm*NH + 
        0.001278753987125183*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.007093050042183571 - 0.01714237619081526*lm - 
          0.006918291474811393*lm^2) + CF*(0.032297845210366036 + 
          0.005079126840331466*lm + 0.03396252178543775*lm^2) + 
        0.001416402170852391*NM + 0.0015158687182084025*lm*NM + 
        0.0012578711772384353*lm^2*NM + 0.003984979533733747*NL + 
        0.0015158687182084025*lm*NL + 0.0012578711772384353*lm^2*NL - 
        0.0008155320491258488*NH + 0.0015158687182084025*lm*NH + 
        0.0012578711772384353*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.006906068305928001 - 0.01680172324406996*lm - 
          0.006805383901477496*lm^2) + CF*(0.03179857549949094 + 
          0.004697336125902304*lm + 0.0334082482436168*lm^2) + 
        0.00136458273172489*NM + 0.0014800591911418943*lm*NM + 
        0.001237342527541363*lm^2*NM + 0.003911477403301513*NL + 
        0.0014800591911418943*lm*NL + 0.001237342527541363*lm^2*NL - 
        0.0007962218715165029*NH + 0.0014800591911418943*lm*NH + 
        0.001237342527541363*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.006723175541655341 - 0.016467551748249307*lm - 
          0.006694393381497751*lm^2) + CF*(0.0313075187151044 + 
          0.004325451998749582*lm + 0.03286338569098896*lm^2) + 
        0.001314262748971146*NM + 0.0014449844940458492*lm*NM + 
        0.001217162432999591*lm^2*NM + 0.003839406071667101*NL + 
        0.0014449844940458492*lm*NL + 0.001217162432999591*lm^2*NL - 
        0.0007772715062494014*NH + 0.0014449844940458492*lm*NH + 
        0.001217162432999591*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.006544308111529509 - 0.016139754452042774*lm - 
          0.0065852893818959275*lm^2) + CF*(0.0308245795021608 + 
          0.003963296936787939*lm + 0.03232778423839819*lm^2) + 
        0.0012654049746958149*NM + 0.0014106321921640915*lm*NM + 
        0.0011973253421628958*lm^2*NM + 0.0037687399258520375*NL + 
        0.0014106321921640915*lm*NL + 0.0011973253421628958*lm^2*NL - 
        0.0007586758211438387*NH + 0.0014106321921640915*lm*NH + 
        0.0011973253421628958*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.006369402031744496 - 0.015818224955856226*lm - 
          0.006478041673994449*lm^2) + CF*(0.030349660926790364 + 
          0.0036106941210270723*lm + 0.0318012954905182*lm^2) + 
        0.0012179728622866628*NM + 0.0013769899351817555*lm*NM + 
        0.0011778257589080817*lm^2*NM + 0.0036994536089974307*NL + 
        0.0013769899351817555*lm*NL + 0.0011778257589080817*lm^2*NL - 
        0.0007404296934665766*NH + 0.0013769899351817555*lm*NH + 
        0.0011778257589080817*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.006198393072866198 - 0.015502857762303264*lm - 
          0.006372620342040632*lm^2) + CF*(0.02988266466881506 + 
          0.003267467584842521*lm + 0.03128377258819947*lm^2) + 
        0.00117193056611232*NM + 0.001344045464409373*lm*NM + 
        0.0011586582440073878*lm^2*NM + 0.0036315220316467927*NL + 
        0.001344045464409373*lm*NL + 0.0011586582440073878*lm^2*NL - 
        0.0007225280136572276*NH + 0.001344045464409373*lm*NH + 
        0.0011586582440073878*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.006031216853488467 - 0.015193548322389514*lm - 
          0.006268995790930475*lm^2) + CF*(0.029423491203897888 + 
          0.002933442352417559*lm + 0.03077507024638597*lm^2) + 
        0.0011272429401916779*NM + 0.0013117866193926944*lm*NM + 
        0.0011398174165328137*lm^2*NM + 0.003564920381888405*NL + 
        0.0013117866193926944*lm*NL + 0.0011398174165328137*lm^2*NL - 
        0.0007049656888206182*NH + 0.0013117866193926944*lm*NH + 
        0.0011398174165328137*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.005867808927550041 - 0.014890193077628929*lm - 
          0.006167138753084146*lm^2) + CF*(0.028972039975746124 + 
          0.0026084445669108175*lm + 0.030275044787867626*lm^2) + 
        0.00108387553591776*NM + 0.0012802013439791762*lm*NM + 
        0.0011212979551062084*lm^2*NM + 0.003499624134427197*NL + 
        0.0012802013439791762*lm*NL + 0.0011212979551062084*lm^2*NL - 
        0.0006877376459969143*NH + 0.0012802013439791762*lm*NH + 
        0.0011212979551062084*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.005708104865643513 - 0.014592689498319615*lm - 
          0.0060670202945244545*lm^2) + CF*(0.028528209558777454 + 
          0.0022923016088804175*lm + 0.02978355417312005*lm^2) + 
        0.0010417945989138588*NM + 0.0012492776918706348*lm*NM + 
        0.0011030945990044463*lm^2*NM + 0.0034356090586524046*NL + 
        0.0012492776918706348*lm*NL + 0.0011030945990044463*lm^2*NL - 
        0.0006708388352198594*NH + 0.0012492776918706348*lm*NH + 
        0.0011030945990044463*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.0055520403306325095 - 0.014300936118195755*lm - 
          0.005968611820206875*lm^2) + CF*(0.028091897811645967 + 
          0.0019848422054724786*lm + 0.029300458026470116*lm^2) + 
        0.0010009670650949446*NM + 0.001219003831690199*lm*NM + 
        0.0010852021491285229*lm^2*NM + 0.0033728512257637966*NL + 
        0.001219003831690199*lm*NL + 0.0010852021491285229*lm^2*NL - 
        0.0006542642323730536*NH + 0.001219003831690199*lm*NH + 
        0.0010852021491285229*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.005399551147878857 - 0.01401483256566164*lm - 
          0.005871885078647139*lm^2) + CF*(0.027663002022013237 + 
          0.0016858965308596803*lm + 0.028825617658813227*lm^2) + 
        0.0009613605560028502*NM + 0.0011893680515903818*lm*NM + 
        0.0010676154688449343*lm^2*NM + 0.0033113270150158898*NL + 
        0.0011893680515903818*lm*NL + 0.0010676154688449343*lm^2*NL - 
        0.0006380088418538045*NH + 0.0011893680515903818*lm*NH + 
        0.0010676154688449343*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.00525057337036767 - 0.013734279591803842*lm - 
          0.005776812165889936*lm^2) + CF*(0.027241419042937857 + 
          0.001395296298394212*lm + 0.028358896087096054*lm^2) + 
        0.0009229433734794587*NM + 0.0011603587634278205*lm*NM + 
        0.0010503294847072613*lm^2*NM + 0.0032510131191364256*NL + 
        0.0011603587634278205*lm*NL + 0.0010503294847072613*lm^2*NL - 
        0.0006220676990536859*NH + 0.0011603587634278205*lm*NH + 
        0.0010503294847072613*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.005105043339005026 - 0.013459179095367913*lm - 
          0.005683365528859985*lm^2) + CF*(0.026827045421245102 + 
          0.0011128748449188593*lm + 0.027900158050767197*lm^2) + 
        0.0008856844937380899*NM + 0.0011319645065290458*lm*NM + 
        0.0010333391870654518*lm^2*NM + 0.0031918865489723347*NL + 
        0.0011319645065290458*lm*NL + 0.0010333391870654518*lm^2*NL - 
        0.0006064358726645719*NH + 0.0011319645065290458*lm*NH + 
        0.0010333391870654518*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.004962897738350097 - 0.013189434144876845*lm - 
          0.0055915179681344665*lm^2) + CF*(0.026419777518226762 + 
          0.000838467207660154*lm + 0.02744927002538738*lm^2) + 
        0.0008495535608894676*NM + 0.001104173951070459*lm*NM + 
        0.0010166396305699029*lm^2*NM + 0.0031339246374135657*NL + 
        0.001104173951070459*lm*NL + 0.0010166396305699029*lm^2*NL - 
        0.0005911084668185447*NH + 0.001104173951070459*lm*NH + 
        0.0010166396305699029*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.004824073648031366 - 0.012924948998059753*lm - 
          0.005501242640173806*lm^2) + CF*(0.02601951162300964 + 
          0.0005719101941084285*lm + 0.027006100233580504*lm^2) + 
        0.0008145208799750505*NM + 0.0010769759010946117*lm*NM + 
        0.0010002259345770557*lm^2*NM + 0.0030771050426424006*NL + 
        0.0010769759010946117*lm*NL + 0.0010002259345770557*lm^2*NL - 
        0.000576080623069733*NH + 0.0010769759010946117*lm*NH + 
        0.0010002259345770557*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.004688508590084794 - 0.012665629118750911*lm - 
          0.005412513059045712*lm^2) + CF*(0.025626144058919925 + 
          0.00031304244527125105*lm + 0.02657051865349713*lm^2) + 
        0.000780557409557103*NM + 0.0010503592971838026*lm*NM + 
        0.0009840932834628566*lm^2*NM + 0.003021405750753295*NL + 
        0.0010503592971838026*lm*NL + 0.0009840932834628566*lm^2*NL - 
        0.0005613475222257989*NH + 0.0010503592971838026*lm*NH + 
        0.0009840932834628566*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.004556140572440518 - 0.012411381191411192*lm - 
          0.005325303097675554*lm^2) + CF*(0.02523957128315937 + 
          0.00006170449266905919*lm + 0.02614239702495272*lm^2) + 
        0.0007476347539116786*NM + 0.0010243132188109975*lm*NM + 
        0.0009682369268501007*lm^2*NM + 0.002966805077785802*NL + 
        0.0010243132188109975*lm*NL + 0.0009682369268501007*lm^2*NL - 
        0.0005469043860364653*NH + 0.0010243132188109975*lm*NH + 
        0.0009682369268501007*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.004426908128773853 - 0.012162113133416468*lm - 
          0.005239586988654359*lm^2) + CF*(0.024859689980098253 - 
          0.00018226119057517461*lm + 0.025721608853394126*lm^2) + 
        0.0007157251548676486*NM + 0.0009988268863871095*lm*NM + 
        0.000952652179755338*lm^2*NM + 0.0029132816712108007*NL + 
        0.0009988268863871095*lm*NL + 0.000952652179755338*lm^2*NL - 
        0.0005327464787461724*NH + 0.0009988268863871095*lm*NH + 
        0.000952652179755338*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.004300750354926005 - 0.011917734105250115*lm - 
          0.005155339324633978*lm^2) + CF*(0.024486397148479246 - 
          0.0004190101442167226*lm + 0.025308029411839527*lm^2) + 
        0.0006848014833320572*NM + 0.0009738896630227367*lm*NM + 
        0.0009373344226607233*lm^2*NM + 0.0028608145109080096*NL + 
        0.0009738896630227367*lm*NL + 0.0009373344226607233*lm^2*NL - 
        0.0005188691085176414*NH + 0.0009738896630227367*lm*NH + 
        0.0009373344226607233*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.004177606942089962 - 0.011678154518729885*lm - 
          0.005072535058337404*lm^2) + CF*(0.02411959018281573 - 
          0.0006486958806204801*lm + 0.024901535740929074*lm^2) + 
        0.0006548372305393797*NM + 0.0009494910560215715*lm*NM + 
        0.0009222791015158916*lm^2*NM + 0.002809382909670659*NL + 
        0.0009494910560215715*lm*NL + 0.0009222791015158916*lm^2*NL - 
        0.0005052676287328437*NH + 0.0009494910560215715*lm*NH + 
        0.0009222791015158916*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.0040574182069475365 - 0.011443286043392786*lm - 
          0.004991149502210651*lm^2) + CF*(0.023759166949257702 - 
          0.000871469849438141*lm + 0.024502006647215923*lm^2) + 
        0.0006258064990597212*NM + 0.0009256207181218436*lm*NM + 
        0.0009074817276746638*lm^2*NM + 0.0027589665132711685*NL + 
        0.0009256207181218436*lm*NL + 0.0009074817276746638*lm^2*NL - 
        0.0004919374391775927*NH + 0.0009256207181218436*lm*NH + 
        0.0009074817276746638*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.003940125118934427 - 0.011213041611155244*lm - 
          0.00491115832774118*lm^2) + CF*(0.02340502585618822 - 
          0.0010874814069408093*lm + 0.02410932269982034*lm^2) + 
        0.0005976839935985929*NM + 0.0009022684485013413*lm*NM + 
        0.0008929378777711237*lm^2*NM + 0.002709545300119784*NL + 
        0.0009022684485013413*lm*NL + 0.0008929378777711237*lm^2*NL - 
        0.00047887398711570823*NH + 0.0009022684485013413*lm*NH + 
        0.0008929378777711237*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0038256693248014386 - 0.010987335419359813*lm - 
          0.004832537564466467*lm^2) + CF*(0.02305706591980353 - 
          0.0012968777897305423*lm + 0.023723366225562658*lm^2) + 
        0.0005704450116186446*NM + 0.0008794241935607835*lm*NM + 
        0.0008786431935393577*lm^2*NM + 0.0026610995805463043*NL + 
        0.0008794241935607835*lm*NL + 0.0008786431935393577*lm^2*NL - 
        0.00046607276825844557*NH + 0.0008794241935607835*lm*NH + 
        0.0008786431935393577*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.003713993170631705 - 0.010766082932313967*lm - 
          0.004755263598694994*lm^2) + CF*(0.02271518682492016 - 
          0.0014998040925676022*lm + 0.023344021302684512*lm^2) + 
        0.0005440654338116013*NM + 0.0008570780474995656*lm*NM + 
        0.0008645933815809079*lm^2*NM + 0.0026136099957333064*NL + 
        0.0008570780474995656*lm*NL + 0.0008645933815809079*lm^2*NL - 
        0.0004535293276346385*NH + 0.0008570780474995656*lm*NH + 
        0.0008645933815809079*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.0036050397214657456 - 0.01054920088142097*lm - 
          0.004679313171960717*lm^2) + CF*(0.022379288981243015 - 
          0.0016964032500629317*lm + 0.0229711737532617*lm^2) + 
        0.0005185217144466503*NM + 0.0008352202526972007*lm*NM + 
        0.0008507842130837667*lm^2*NM + 0.002567057516327651*NL + 
        0.0008352202526972007*lm*NL + 0.0008507842130837667*lm^2*NL - 
        0.0004412392603667626*NH + 0.0008352202526972007*lm*NH + 
        0.0008507842130837667*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0034987527786786115 - 0.010336607263997667*lm - 
          0.00460466337923089*lm^2) + CF*(0.022049273575319193 - 
          0.0018868160219975727*lm + 0.022604711134406187*lm^2) + 
        0.0004937908716196348*NM + 0.000813841199913089*lm*NM + 
        0.0008372115234965255*lm^2*NM + 0.0025214234407555*NL + 
        0.000813841199913089*lm*NL + 0.0008372115234965255*lm^2*NL - 
        0.00042919821235790166*NH + 0.000813841199913089*lm*NH + 
        0.0008372115234965255*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.003395076895246071 - 0.010128221340868972*lm - 
          0.004531291666885975*lm^2) + CF*(0.021725042618393406 - 
          0.002071180982042436*lm + 0.022244522728349335*lm^2) + 
        0.00046985047742563604*NM + 0.0007929314283166121*lm*NM + 
        0.0008238712121610864*lm^2*NM + 0.0024766893932646064*NL + 
        0.0007929314283166121*lm*NL + 0.0008238712121610864*lm^2*NL - 
        0.0004174018808943769*NH + 0.0007929314283166121*lm*NH + 
        0.0008238712121610864*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.0032939573890298467 - 0.009923963632824183*lm - 
          0.004459175830489364*lm^2) + CF*(0.021406498990372124 - 
          0.0022496345096630213*lm + 0.021890499531493243*lm^2) + 
        0.0004466786480758547*NM + 0.0007724816253589243*lm*NM + 
        0.000810759241907157*lm^2*NM + 0.002432837321716248*NL + 
        0.0007724816253589243*lm*NL + 0.000810759241907157*lm^2*NL - 
        0.00040584601516859166*NH + 0.0007724816253589243*lm*NH + 
        0.000810759241907157*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.003195340354205267 - 0.009723755916015651*lm - 
          0.00438829401236358*lm^2) + CF*(0.021093546480095243 - 
          0.0024223107850044135*lm + 0.021542534242512117*lm^2) + 
        0.0004242540339781318*NM + 0.0007524826264972238*lm*NM + 
        0.0007978716386115599*lm^2*NM + 0.0023898494951478523*NL + 
        0.0007524826264972238*lm*NL + 0.0007978716386115599*lm^2*NL - 
        0.00039452641672643897*NH + 0.0007524826264972238*lm*NH + 
        0.0007978716386115599*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0030991726709483683 - 0.009527521216376051*lm - 
          0.004318624698988713*lm^2) + CF*(0.02078608982210581 - 
          0.0025893417865621117*lm + 0.021200521249580957*lm^2) + 
        0.0004025558097989726*NM + 0.0007329254147817288*lm*NM + 
        0.0007852044907252206*lm^2*NM + 0.002347708501126115*NL + 
        0.0007329254147817288*lm*NL + 0.0007852044907252206*lm^2*NL - 
        0.000383438939843427*NH + 0.0007329254147817288*lm*NH + 
        0.0007852044907252206*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.003005402013493417 - 0.009335183803126455*lm - 
          0.004250146718237931*lm^2) + CF*(0.020484034730100527 - 
          0.0027508572914540816*lm + 0.020864356616804386*lm^2) + 
        0.00038156366452354916*NM + 0.0007138011203150408*lm*NM + 
        0.0007727539487705328*lm^2*NM + 0.0023063972429092218*NL + 
        0.0007138011203150408*lm*NL + 0.0007727539487705328*lm^2*NL - 
        0.0003725794918334893*NH + 0.0007138011203150408*lm*NH + 
        0.0007727539487705328*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0029139768566660684 - 0.00914666918144339*lm - 
          0.004182839236464024*lm^2) + CF*(0.02018728792723596 - 
          0.0029069848781187817*lm + 0.0205339380699143*lm^2) + 
        0.0003612577915288552*NM + 0.0006951010195930733*lm*NM + 
        0.0007605162248116408*lm^2*NM + 0.0022658989364356696*NL + 
        0.0006951010195930733*lm*NL + 0.0007605162248116408*lm^2*NL - 
        0.00036194403329427*NH + 0.0006951010195930733*lm*NH + 
        0.0007605162248116408*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0028248464809918624 - 0.0089619040843495*lm - 
          0.004116681755450196*lm^2) + CF*(0.019895757173458112 - 
          0.0030578499312728857*lm + 0.020209164981300962*lm^2) + 
        0.0003416188786839626*NM + 0.0006768165347362271*lm*NM + 
        0.0007484875919000356*lm^2*NM + 0.0022261971071561074*NL + 
        0.0006768165347362271*lm*NL + 0.0007484875919000356*lm^2*NL - 
        0.00035152857829249986*NH + 0.0006768165347362271*lm*NH + 
        0.0007484875919000356*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.002737960976474504 - 0.008780816463888754*lm - 
          0.004051654109237462*lm^2) + CF*(0.019609351290015724 - 
          0.003203575648970991*lm + 0.01988993835443845*lm^2) + 
        0.0003226280984901819*NM + 0.0006589392326190386*lm*NM + 
        0.0007366643834977204*lm^2*NM + 0.00218727558672363*NL + 
        0.0006589392326190386*lm*NL + 0.0007366643834977204*lm^2*NL - 
        0.0003413291944929156*NH + 0.0006589392326190386*lm*NH + 
        0.0007366643834977204*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0026532712451333884 - 0.008603335481643885*lm - 
          0.003987736460840362*lm^2) + CF*(0.01932798018131081 - 
          0.0033442830516177894*lm + 0.019576160807761776*lm^2) + 
        0.000304267098272852*NM + 0.0006414608239060772*lm*NM + 
        0.0007250429928800658*lm^2*NM + 0.002149118509556977*NL + 
        0.0006414608239060772*lm*NL + 0.0007250429928800658*lm^2*NL - 
        0.00033134200323401683*NH + 0.0006414608239060772*lm*NH + 
        0.0007250429928800658*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.002570729002385048 - 0.008429391498650464*lm - 
          0.003924909298861956*lm^2) + CF*(0.019051554854233224 - 
          0.0034800909927909913*lm + 0.019267736558049604*lm^2) + 
        0.0002865179904354745*NM + 0.0006243731620014498*lm*NM + 
        0.0007136198725203556*lm^2*NM + 0.0021117103092902208*NL + 
        0.0006243731620014498*lm*NL + 0.0007136198725203556*lm^2*NL - 
        0.0003215631795538028*NH + 0.0006243731620014498*lm*NH + 
        0.0007136198725203556*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.0024902867773486585 - 0.008258916064759059*lm - 
          0.0038631534340184473*lm^2) + CF*(0.01877998743511953 - 
          0.0036111161717407563*lm + 0.018964571403363287*lm^2) + 
        0.0002693633427859641*NM + 0.0006076682419188659*lm*NM + 
        0.0007023915334578995*lm^2*NM + 0.0020750357151216427*NL + 
        0.0006076682419188659*lm*NL + 0.0007023915334578995*lm^2*NL - 
        0.0003119889521684858*NH + 0.0006076682419188659*lm*NH + 
        0.0007023915334578995*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.002411897912151423 - 0.008091841907493956*lm - 
          0.0038024499955831305*lm^2) + CF*(0.018513191184470392 - 
          0.0037374731474385083*lm + 0.018666572705589912*lm^2) + 
        0.0002527861689438986*NM + 0.0005913381990788379*lm*NM + 
        0.0006913545446514783*lm^2*NM + 0.0020390797480737146*NL + 
        0.0005913381990788379*lm*NL + 0.0006913545446514783*lm^2*NL - 
        0.00030261560340703934*NH + 0.0005913381990788379*lm*NH + 
        0.0006913545446514783*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.002335516560305522 - 0.0079281029204542*lm - 
          0.0037427804277588056*lm^2) + CF*(0.018251080509554457 - 
          0.0038592743540548148*lm + 0.018373649372634134*lm^2) + 
        0.000236769918836824*NM + 0.0005753753080392221*lm*NM + 
        0.0006805055323197828*lm^2*NM + 0.0020038277171753236*NL + 
        0.0005753753080392221*lm*NL + 0.0006805055323197828*lm^2*NL - 
        0.00029343946910430406*NH + 0.0005753753080392221*lm*NH + 
        0.0006805055323197828*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.002261097684224409 - 0.007767634151300132*lm - 
          0.003684126485987222*lm^2) + CF*(0.017993570975021123 - 
          0.00397663011775248*lm + 0.01808571184030091*lm^2) + 
        0.0002212984692928943*NM + 0.0005597719811649643*lm*NM + 
        0.0006698411792704041*lm^2*NM + 0.0019692652155766624*NL + 
        0.0005597719811649643*lm*NL + 0.0006698411792704041*lm^2*NL - 
        0.0002844569384552484*NH + 0.0005597719811649643*lm*NH + 
        0.0006698411792704041*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.0021885970519424838 - 0.007610371789366042*lm - 
          0.0036264702332036007*lm^2) + CF*(0.017740579311638888 - 
          0.0040896486746872015*lm + 0.017802672053908584*lm^2) + 
        0.00020635611473640114*NM + 0.0005445207672425792*lm*NM + 
        0.0006593582242188365*lm^2*NM + 0.001935378116606532*NL + 
        0.0005445207672425792*lm*NL + 0.0006593582242188365*lm^2*NL - 
        0.000275664453832856*NH + 0.0005445207672425792*lm*NH + 
        0.0006593582242188365*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.0021179712330986447 - 0.007456253152937284*lm - 
          0.0035697940360437763*lm^2) + CF*(0.017492023423270678 - 
          0.004198436190114016*lm + 0.017524443449669448*lm^2) + 
        0.00019192755799206918*NM + 0.0005296143500445827*lm*NM + 
        0.0006490534610988684*lm^2*NM + 0.0019021525697811442*NL + 
        0.0005296143500445827*lm*NL + 0.0006490534610988684*lm^2*NL - 
        0.00026705851057199655*NH + 0.0005296143500445827*lm*NH + 
        0.0006490534610988684*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0020491775942408233 - 0.007305216676227886*lm - 
          0.003514080561011045*lm^2) + CF*(0.017247822392192358 - 
          0.004303096778503398*lm + 0.017250940935872403*lm^2) + 
        0.00017799790120336166*NM + 0.0005150455468487953*lm*NM + 
        0.0006389237383656446*lm^2*NM + 0.0018695749967729215*NL + 
        0.0005150455468487953*lm*NL + 0.0006389237383656446*lm^2*NL - 
        0.00025863565672152206*NH + 0.0005150455468487953*lm*NH + 
        0.0006389237383656446*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.001982174293505413 - 0.007157201896092592*lm - 
          0.0034593127706093415*lm^2) + CF*(0.017007896482855663 - 
          0.004403732524576198*lm + 0.016982080873900404*lm^2) + 
        0.00016455263686944959*NM + 0.0005008073069171525*lm*NM + 
        0.0006289659582926076*lm^2*NM + 0.0018376320873471996*NL + 
        0.0005008073069171525*lm*NL + 0.0006289659582926076*lm^2*NL - 
        0.0002503924927667243*NH + 0.0005008073069171525*lm*NH + 
        0.0006289659582926076*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0019169202747224378 - 0.0070121494385052534*lm - 
          0.0034054739194489523*lm^2) + CF*(0.016772167144192093 - 
          0.00450044350517174*lm + 0.01671778105911304*lm^2) + 
        0.00015157763900494714*NM + 0.0004868927099383877*lm*NM + 
        0.0006191770762634459*lm^2*NM + 0.0018063107952742095*NL + 
        0.0004868927099383877*lm*NL + 0.0006191770762634459*lm^2*NL - 
        0.00024232567132418504*NH + 0.0004868927099383877*lm*NH + 
        0.0006191770762634459*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.001853375260994418 - 0.006870001004833569*lm - 
          0.0033525475503305823*lm^2) + CF*(0.01654055701054961 - 
          0.004593327811868227*lm + 0.016457960701622858*lm^2) + 
        0.0001390591544260031*NM + 0.000473294964438696*lm*NM + 
        0.0006095541000601059*lm^2*NM + 0.0017755983342231953*NL + 
        0.000473294964438696*lm*NL + 0.0006095541000601059*lm^2*NL - 
        0.00023443189681095206*NH + 0.000473294964438696*lm*NH + 
        0.0006095541000601059*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.0017914997477941135 - 0.006730699357938323*lm - 
          0.0033005174903131956*lm^2) + CF*(0.016312989901349675 - 
          0.004682481574279223*lm + 0.016202540406992053*lm^2) + 
        0.00012698379416585997*NM + 0.0004600074061642448*lm*NM + 
        0.0006000940891478537*lm^2*NM + 0.0017454821736450463*NL + 
        0.0004600074061642448*lm*NL + 0.0006000940891478537*lm^2*NL - 
        0.00022670792508987936*NH + 0.0004600074061642448*lm*NH + 
        0.0006000940891478537*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.0017312549956237386 - 0.00659418830812359*lm - 
          0.0032493678467707125*lm^2) + CF*(0.016089390819547945 - 
          0.004767998983954408*lm + 0.01595144215687441*lm^2) + 
        0.00011533852502254786*NM + 0.00044702349643916544*lm*NM + 
        0.0005907941539583114*lm^2*NM + 0.0017159500346493612*NL + 
        0.00044702349643916544*lm*NL + 0.0005907941539583114*lm^2*NL - 
        0.0002191505630928796*NH + 0.00044702349643916544*lm*NH + 
        0.0005907941539583114*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.0016726030222757218 - 0.006460412698962699*lm - 
          0.0031990830034422948*lm^2) + CF*(0.01586968594897781 - 
          0.0048499723188169435*lm + 0.01570458928962581*lm^2) + 
        0.00010411066124096769*NM + 0.0004343368205024391*lm*NM + 
        0.0005816514551713263*lm^2*NM + 0.0016869898858814386*NL + 
        0.0004343368205024391*lm*NL + 0.0005816514551713263*lm^2*NL - 
        0.0002117566684237496*NH + 0.0004343368205024391*lm*NH + 
        0.0005816514551713263*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0016155065947327505 - 0.0063293183930232125*lm - 
          0.0031496476164806345*lm^2) + CF*(0.01565380265065214 - 
          0.004928491968073798*lm + 0.015461906480904933*lm^2) + 
        0.00009328785633123347*NM + 0.0004219410858268835*lm*NM + 
        0.0005726632029964791*lm^2*NM + 0.0016585899394042768*NL + 
        0.0004219410858268835*lm*NL + 0.0005726632029964791*lm^2*NL - 
        0.0002045231489421474*NH + 0.0004219410858268835*lm*NH + 
        0.0005726632029964791*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.001559929220742585 - 0.006200852257512691*lm - 
          0.0031010466105023697*lm^2) + CF*(0.015441669458094913 - 
          0.005003646457539164*lm + 0.015223319724284359*lm^2) + 
        0.00008285809502478821*NM + 0.00040983012042324665*lm*NM + 
        0.0005638266564549762*lm^2*NM + 0.0016307386465902916*NL + 
        0.00040983012042324665*lm*NL + 0.0005638266564549762*lm^2*NL - 
        0.00019744696233021998*NH + 0.00040983012042324665*lm*NH + 
        0.0005638266564549762*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.0015058351401010047 - 0.006074962149865633*lm - 
          0.0030532651746444407*lm^2) + CF*(0.015233216071770717 - 
          0.005075522475314674*lm + 0.01498875631189089*lm^2) + 
        0.00007280968536947794*NM + 0.00039799787113222796*lm*NM + 
        0.0005551391226626256*lm^2*NM + 0.0016034246940270919*NL + 
        0.00039799787113222796*lm*NL + 0.0005551391226626256*lm^2*NL - 
        0.00019052511564330473*NH + 0.00039799787113222796*lm*NH + 
        0.0005551391226626256*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.001453189315674235 - 0.005951596903290644*lm - 
          0.0030062887586299663*lm^2) + CF*(0.015028373352676809 - 
          0.005144204897773564*lm + 0.014758144815092562*lm^2) + 
        0.00006313125096446244*NM + 0.0003864384019070669*lm*NM + 
        0.0005465979561145393*lm^2*NM + 0.0015766369994413276*NL + 
        0.0003864384019070669*lm*NL + 0.0005465979561145393*lm^2*NL - 
        0.00018375466484605544*NH + 0.0003864384019070669*lm*NH + 
        0.0005465979561145393*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.0014019574241902865 - 0.005830706312295622*lm - 
          0.002960103068846927*lm^2) + CF*(0.014827073315159096 - 
          0.005209776815799177*lm + 0.01453141506524855*lm^2) + 
        0.00005381172333555932*NM + 0.0003751458920891713*lm*NM + 
        0.0005382005579721685*lm^2*NM + 0.0015503647076442902*NL + 
        0.0003751458920891713*lm*NL + 0.0005382005579721685*lm^2*NL - 
        0.0001771327143352741*NH + 0.0003751458920891713*lm*NH + 
        0.0005382005579721685*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.0013521058468268284 - 0.005712241118207602*lm - 
          0.002914694064442732*lm^2) + CF*(0.014629249119010241 - 
          0.005272319561231265*lm + 0.01430849813453705*lm^2) + 
        0.00004484033445135712*NM + 0.00036411463467909706*lm*NM + 
        0.0005299443753532241*lm^2*NM + 0.0015245971865026596*NL + 
        0.00036411463467909706*lm*NL + 0.0005299443753532241*lm^2*NL - 
        0.00017065641645066395*NH + 0.00036411463467909706*lm*NH + 
        0.0005299443753532241*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.0013036016596214943 - 0.005596152994702713*lm - 
          0.0028700479534375053*lm^2) + CF*(0.014434835060905161 - 
          0.005331912733476518*lm + 0.014089326316875027*lm^2) + 
        0.00003620660938019258*NM + 0.0003533390346050374*lm*NM + 
        0.000521826900625001*lm^2*NM + 0.0014993240229375054*NL + 
        0.0003533390346050374*lm*NL + 0.000521826900625001*lm^2*NL - 
        0.00016432297097465528*NH + 0.0003533390346050374*lm*NH + 
        0.000521826900625001*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.0012564126237288968 - 0.0054823945333606966*lm - 
          0.002826151188858708*lm^2) + CF*(0.014243766565226265 - 
          0.005388634226242477*lm + 0.01387383310894275*lm^2) + 
        0.00002790035908786564*NM + 0.0003428136069908388*lm*NM + 
        0.0005138456707015833*lm^2*NM + 0.0014745350189543788*NL + 
        0.0003428136069908388*lm*NL + 0.0005138456707015833*lm^2*NL - 
        0.00015812962462239592*NH + 0.0003428136069908388*lm*NH + 
        0.0005138456707015833*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.001210507175547077 - 0.005370919229257389*lm - 
          0.0027829904648995272*lm^2) + CF*(0.014055980174328046 - 
          0.0054425602543566685*lm + 0.013661953191324952*lm^2) + 
        0.000019911673375762566*NM + 0.00033253297542541987*lm*NM + 
        0.0005059982663453686*lm^2*NM + 0.0014502201877070937*NL + 
        0.00033253297542541987*lm*NL + 0.0005059982663453686*lm^2*NL - 
        0.0001520736705229392*NH + 0.00033253297542541987*lm*NH + 
        0.0005059982663453686*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.001165854416734656 - 0.005261681466607631*lm - 
          0.0027405527131032555*lm^2) + CF*(0.013871413538288037 - 
          0.005493765380635284*lm + 0.013453622409779617*lm^2) + 
        0.000012230913958870254*NM + 0.0003224918702353449*lm*NM + 
        0.0004982823114733192*lm^2*NM + 0.0014263697495975535*NL + 
        0.0003224918702353449*lm*NL + 0.0004982823114733192*lm^2*NL - 
        0.0001461524476926087*NH + 0.0003224918702353449*lm*NH + 
        0.0004982823114733192*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.0011224241041385722 - 0.005154636504470157*lm - 
          0.0026988250985757146*lm^2) + CF*(0.013690005404188615 - 
          0.005542322542768099*lm + 0.013248777756644417*lm^2) + 
        4.848707682994064*^-6*NM + 0.00031268512676217724*lm*NM + 
        0.0004906954724683117*lm^2*NM + 0.0014029741284137635*NL + 
        0.00031268512676217724*lm*NL + 0.0004906954724683117*lm^2*NL - 
        0.000140363340501465*NH + 0.00031268512676217724*lm*NH + 
        0.0004906954724683117*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.0010801866396509825 - 0.005049740462525179*lm - 
          0.0026577950162276027*lm^2) + CF*(0.013511695604971756 - 
          0.005588303080188582*lm + 0.01304735735239005*lm^2) - 
        2.2440601196650154*^-6*NM + 0.00030310768364612446*lm*NM + 
        0.0004832354574959278*lm^2*NM + 0.0013800239475079616*NL + 
        0.00030310768364612446*lm*NL + 0.0004832354574959278*lm^2*NL - 
        0.00013470377813374975*NH + 0.00030310768364612446*lm*NH + 
        0.0004832354574959278*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.0010391130600126506 - 0.0049469503069345545*lm - 
          0.0026174500870484877*lm^2) + CF*(0.013336425047906527 - 
          0.005631776760900275*lm + 0.01284930042732894*lm^2) - 
        9.056252137560665*^-6*NM + 0.00029375458111737635*lm*NM + 
        0.0004759000158269978*lm^2*NM + 0.0013575100260166091*NL + 
        0.00029375458111737635*lm*NL + 0.0004759000158269978*lm^2*NL - 
        0.0001291712340431348*NH + 0.00029375458111737635*lm*NH + 
        0.0004759000158269978*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.000999175026578996 - 0.004846223836293675*lm - 
          0.0025777781544140143*lm^2) + CF*(0.01316413570270698 - 
          0.005672811808232551*lm + 0.01265454730348698*lm^2) - 
        0.000015596485450595434*NM + 0.00028462095929643354*lm*NM + 
        0.00046868693716618445*lm^2*NM + 0.001335423375123799*NL + 
        0.00028462095929643354*lm*NL + 0.00046868693716618445*lm^2*NL - 
        0.0001237632254035579*NH + 0.00028462095929643354*lm*NH + 
        0.00046868693716618445*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.0009603448150638476 - 0.0047475196676835*lm - 
          0.0025387672804277586*lm^2) + CF*(0.012994770589335954 - 
          0.005711474927500753*lm + 0.01246303937664536*lm^2) - 
        0.000021873137765892927*NM + 0.00027570205650462613*lm*NM + 
        0.0004615940509868652*lm^2*NM + 0.0013137551943694708*NL + 
        0.00027570205650462613*lm*NL + 0.0004615940509868652*lm^2*NL - 
        0.00011847731255638213*NH + 0.00027570205650462613*lm*NH + 
        0.0004615940509868652*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.0009225953052749071 - 0.004650797222830454*lm - 
          0.0025004057422990185*lm^2) + CF*(0.012828273765528354 - 
          0.0057478313325475495*lm + 0.012274719098558819*lm^2) - 
        0.000027894353519888376*NM + 0.00026699320758592933*lm*NM + 
        0.0004546192258725488*lm^2*NM + 0.001292496868003665*NL + 
        0.00026699320758592933*lm*NL + 0.0004546192258725488*lm^2*NL - 
        0.00011331109845457628*NH + 0.00026699320758592933*lm*NH + 
        0.0004546192258725488*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.0008858999708539392 - 0.0045560167143813*lm - 
          0.0024626820287577175*lm^2) + CF*(0.012664590314065569 - 
          0.005781944772144055*lm + 0.012089529959356067*lm^2) - 
        0.00003366804984817382*NM + 0.0002584898422410952*lm*NM + 
        0.0004477603688650395*lm^2*NM + 0.0012716399613878948*NL + 
        0.0002584898422410952*lm*NL + 0.0004477603688650395*lm^2*NL - 
        0.00010826222810457116*NH + 0.0002584898422410952*lm*NH + 
        0.0004477603688650395*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.0008502328690337602 - 0.004463139132299475*lm - 
          0.002425584836507463*lm^2) + CF*(0.01250366632983087 - 
          0.005813877556230852*lm + 0.011907416470127543*lm^2) - 
        0.00003920192242461992*NM + 0.00025018748337503707*lm*NM + 
        0.00044101542481953866*lm^2*NM + 0.00125117621744458*NL + 
        0.00025018748337503707*lm*NL + 0.00044101542481953866*lm^2*NL - 
        0.00010332838800641125*NH + 0.00025018748337503707*lm*NH + 
        0.00044101542481953866*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.0008155686304232208 - 0.004372126230388781*lm - 
          0.0023891030667177104*lm^2) + CF*(0.01234544890667391 - 
          0.005843690581980641*lm + 0.011728324145705123*lm^2) - 
        0.000044503451171373445*NM + 0.00024208174545832468*lm*NM + 
        0.0004343823757668564*lm^2*NM + 0.0012310975531553562*NL + 
        0.00024208174545832468*lm*NL + 0.0004343823757668564*lm^2*NL - 
        0.00009850730559278298*NH + 0.00024208174545832468*lm*NH + 
        0.0004343823757668564*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.0007818824488305387 - 0.004282940512949851*lm - 
          0.0023532258215558603*lm^2) + CF*(0.012189886124110831 - 
          0.005871443359665649*lm + 0.01155219948763786*lm^2) - 
        0.00004957990584139713*NM + 0.0002341683329035754*lm*NM + 
        0.0004278592402828837*lm^2*NM + 0.0012113960561089478*NL + 
        0.0002341683329035754*lm*NL + 0.0004278592402828837*lm^2*NL - 
        0.00009379674866746794*NH + 0.0002341683329035754*lm*NH + 
        0.0004278592402828837*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.0007491500711345537 - 0.0041955452215742236*lm - 
          0.0023179424007600297*lm^2) + CF*(0.012036927033884866 - 
          0.005897194038314313*lm + 0.011378989967367418*lm^2) - 
        0.00005443835147527936*NM + 0.00022644303845745535*lm*NM + 
        0.0004214440728654599*lm^2*NM + 0.0011920639810991862*NL + 
        0.00022644303845745535*lm*NL + 0.0004214440728654599*lm^2*NL - 
        0.00008919452484373511*NH + 0.00022644303845745535*lm*NH + 
        0.0004214440728654599*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.000717347787212728 - 0.004109904322080446*lm - 
          0.002283242298253141*lm^2) + CF*(0.011886521646410889 - 
          0.005920999431143052*lm + 0.01120864400960633*lm^2) - 
        0.000059085653734093356*NM + 0.00021890174160894098*lm*NM + 
        0.00041513496331875295*lm^2*NM + 0.0011730937467736421*NL + 
        0.00021890174160894098*lm*NL + 0.00041513496331875295*lm^2*NL - 
        0.0000846984809831562*NH + 0.00021890174160894098*lm*NH + 
        0.00041513496331875295*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.000686452419934021 - 0.004025982491596127*lm - 
          0.0022491151987988926*lm^2) + CF*(0.011738620917125915 - 
          0.00594291504075016*lm + 0.011041110975921836*lm^2) - 
        0.00006352848411013155*NM + 0.000211540407014428*lm*NM + 
        0.0004089300361452532*lm^2*NM + 0.0011544779323332493*NL + 
        0.000211540407014428*lm*NL + 0.0004089300361452532*lm^2*NL - 
        0.00008030650263529713*NH + 0.000211540407014428*lm*NH + 
        0.0004089300361452532*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.0006564413152241005 - 0.003943745105789479*lm - 
          0.0022155509747000804*lm^2) + CF*(0.011593176732766214 - 
          0.005962995084060005*lm + 0.010876341148527669*lm^2) - 
        0.00006777332501738005*NM + 0.00020435508294021728*lm*NM + 
        0.0004028274499454692*lm^2*NM + 0.0011362092742832003*NL + 
        0.00020435508294021728*lm*NL + 0.0004028274499454692*lm^2*NL - 
        0.00007601651347871113*NH + 0.00020435508294021728*lm*NH + 
        0.0004028274499454692*lm^2*NH)}, 
     {1., 3.81398023734038*^-16*CF*NC*
       (-3.*CA*(5.482394534265398*^11 + 3.37631379456*^12*lm + 
          1.907490816*^12*lm^2) + 2.*(35.*CF*(4.288786136813557*^11 - 
            2.24036388864*^11*lm + 4.013162496*^11*lm^2) + 
          3.*(35.*(-8.967818680840341*^8 + 2.463891456*^9*lm + 
              4.9545216*^9*lm^2)*NM + 131072.*(3.728303*^6 + 657930.*lm + 
              1.323*^6*lm^2)*NL + 35.*(-8.967818680840341*^8 + 
              2.463891456*^9*lm + 4.9545216*^9*lm^2)*NH)))}}
 
CbarLTable["a", 2, 4] = {{0., -1.7357847835717997*^-12*CF*NC*
       (3.*CF*(-1.0799698834635353*^10 - 2.098322000857385*^10*lm - 
          2.19469824*^10*lm^2) + 60.*CA*(3.243221734494542*^8 + 
          5.762396861766058*^8*lm + 1.6765056*^8*lm^2) + 
        280.*(9.*(-3.258726118232396*^6 - 1.570849550548077*^6*lm - 
            725760.*lm^2)*NM + 9.*(-3.258726118232396*^6 - 
            1.570849550548077*^6*lm - 725760.*lm^2)*NL + 
          (6.2874215955206975*^6 - 1.4137645954932693*^7*lm - 
            6.53184*^6*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.03199886203905038 - 0.06149756238956869*lm - 
          0.018057837871573123*lm^2) + CF*(0.058019938757754984 + 
          0.10927618177601008*lm + 0.11819675697756953*lm^2) + 
        0.01430492877707174*NM + 0.00700270175344185*lm*NM + 
        0.0032832432493769314*lm^2*NM + 0.014305060852576207*NL + 
        0.00700270175344185*lm*NL + 0.0032832432493769314*lm^2*NL - 
        0.0031510195789638934*NH + 0.00700270175344185*lm*NH + 
        0.0032832432493769314*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.030589081235242004 - 0.06293284183677195*lm - 
          0.018620929814961835*lm^2) + CF*(0.059536333719739085 + 
          0.10952631114316835*lm + 0.12188244969793201*lm^2) + 
        0.01439222203512083*NM + 0.0071333593850417465*lm*NM + 
        0.0033856236027203336*lm^2*NM + 0.014391523390660398*NL + 
        0.0071333593850417465*lm*NL + 0.0033856236027203336*lm^2*NL - 
        0.003241549275397152*NH + 0.0071333593850417465*lm*NH + 
        0.0033856236027203336*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.029568265195293528 - 0.06430712578262603*lm - 
          0.019143152136944726*lm^2) + CF*(0.06083255033603587 + 
          0.11004090636978035*lm + 0.12530063216909273*lm^2) + 
        0.014514759691487892*NM + 0.007262384358539836*lm*NM + 
        0.003480573115808132*lm^2*NM + 0.014512228756174434*NL + 
        0.007262384358539836*lm*NL + 0.003480573115808132*lm^2*NL - 
        0.003326503751651245*NH + 0.007262384358539836*lm*NH + 
        0.003480573115808132*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.028905917949670977 - 0.06560797589849325*lm - 
          0.01962110212337234*lm^2) + CF*(0.061963847065555556 + 
          0.11079381189404962*lm + 0.12842903208025533*lm^2) + 
        0.014664582296837177*NM + 0.007388302564565504*lm*NM + 
        0.003567473113340426*lm^2*NM + 0.014660011817121087*NL + 
        0.007388302564565504*lm*NL + 0.003567473113340426*lm^2*NL - 
        0.0034053597111381203*NH + 0.007388302564565504*lm*NH + 
        0.003567473113340426*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.028557910489362383 - 0.06682495180562327*lm - 
          0.020053121713900553*lm^2) + CF*(0.06297530655057008 + 
          0.1117436170432979*lm + 0.13125679667280363*lm^2) + 
        0.014832760060984228*NM + 0.007509599435822285*lm*NM + 
        0.003646022129800101*lm^2*NM + 0.014826932856617769*NL + 
        0.007509599435822285*lm*NL + 0.003646022129800101*lm^2*NL - 
        0.0034778133512552794*NH + 0.007509599435822285*lm*NH + 
        0.003646022129800101*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.028477297972880965 - 0.06794984602730814*lm - 
          0.020438705576045896*lm^2) + CF*(0.0639008388034815 + 
          0.11284480658427976*lm + 0.1337806183159368*lm^2) + 
        0.015010855603514879*NM + 0.007624899640260279*lm*NM + 
        0.0037161282865537998*lm^2*NM + 0.015005512745662124*NL + 
        0.007624899640260279*lm*NL + 0.0037161282865537998*lm^2*NL - 
        0.003543710418463006*NH + 0.007624899640260279*lm*NH + 
        0.0037161282865537998*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.028618635589228333 - 0.0689765553588555*lm - 
          0.02077815120971041*lm^2) + CF*(0.06476476241134435 + 
          0.11405260096803806*lm + 0.13600244428174085*lm^2) + 
        0.015191406681916377*NM + 0.007733024661346526*lm*NM + 
        0.0037778456744928016*lm^2*NM + 0.01518912245498066*NL + 
        0.007733024661346526*lm*NL + 0.0037778456744928016*lm^2*NL - 
        0.003603004741592808*NH + 0.007733024661346526*lm*NH + 
        0.0037778456744928016*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.028939826286794267 - 0.06990085485314852*lm - 
          0.021072328010007076*lm^2) + CF*(0.06558370099456913 + 
          0.11532522730603079*lm + 0.13792796515640995*lm^2) + 
        0.015368057129814944*NM + 0.007833005144537762*lm*NM + 
        0.003831332365455832*lm^2*NM + 0.015372079669918515*NL + 
        0.007833005144537762*lm*NL + 0.003831332365455832*lm^2*NL - 
        0.0036557306239837916*NH + 0.007833005144537762*lm*NH + 
        0.003831332365455832*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.029402854460366425 - 0.07072015368162923*lm - 
          0.021322515085708284*lm^2) + CF*(0.06636829979605556 + 
          0.11662495514407918*lm + 0.1395655532882724*lm^2) + 
        0.015535541966168527*NM + 0.007924074037983564*lm*NM + 
        0.0038768209246742335*lm^2*NM + 0.015549628135537629*NL + 
        0.007924074037983564*lm*NL + 0.0038768209246742335*lm^2*NL - 
        0.00370198318805065*NH + 0.007924074037983564*lm*NH + 
        0.0038768209246742335*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.02997397073460869 - 0.07143326061467616*lm - 
          0.021530282877111947*lm^2) + CF*(0.06712466377915378 + 
          0.11791848391155818*lm + 0.14092548792291454*lm^2) + 
        0.015689609953519146*NM + 0.008005651346807776*lm*NM + 
        0.003914596886747626*lm^2*NM + 0.015717868654603635*NL + 
        0.008005651346807776*lm*NL + 0.003914596886747626*lm^2*NL - 
        0.0037419037652978854*NH + 0.008005651346807776*lm*NH + 
        0.003914596886747626*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.030623595961584576 - 0.07204016900526401*lm - 
          0.02169740453799584*lm^2) + CF*(0.06785552487322243 + 
          0.11917697466948164*lm + 0.14201937515779095*lm^2) + 
        0.015826921394021046*NM + 0.008077325545883677*lm*NM + 
        0.003944982643271971*lm^2*NM + 0.015873672105765183*NL + 
        0.008077325545883677*lm*NL + 0.003944982643271971*lm^2*NL - 
        0.003775668712850275*NH + 0.008077325545883677*lm*NH + 
        0.003944982643271971*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.031326082541881885 - 0.07254186413654216*lm - 
          0.021825788484024743*lm^2) + CF*(0.06856117368837307 + 
          0.1203758845044031*lm + 0.14285970644088922*lm^2) + 
        0.015944939421361447*NM + 0.008138834160754007*lm*NM + 
        0.00396832517891359*lm^2*NM + 0.016014588715579543*NL + 
        0.008138834160754007*lm*NL + 0.00396832517891359*lm^2*NL - 
        0.0038034806737327217*NH + 0.008138834160754007*lm*NH + 
        0.00396832517891359*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.032059408102959305 - 0.07294015285203623*lm - 
          0.02191742650039819*lm^2) + CF*(0.06924019487795523 + 
          0.1214946940952913*lm + 0.14345951891169725*lm^2) + 
        0.016041823810755102*NM + 0.008190044799451634*lm*NM + 
        0.003984986636436034*lm^2*NM + 0.01613876038222566*NL + 
        0.008190044799451634*lm*NL + 0.003984986636436034*lm^2*NL - 
        0.003825561644924243*NH + 0.008190044799451634*lm*NH + 
        0.003984986636436034*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.03280484361339369 - 0.07323751414951822*lm - 
          0.021974353573434042*lm^2) + CF*(0.06989004192236804 + 
          0.12251658210430197*lm + 0.14383213248065918*lm^2) + 
        0.016116331667987482*NM + 0.008230937282919402*lm*NM + 
        0.003995337013351644*lm^2*NM + 0.01624483919253066*NL + 
        0.008230937282919402*lm*NL + 0.003995337013351644*lm^2*NL - 
        0.0038421474208098078*NH + 0.008230937282919402*lm*NH + 
        0.003995337013351644*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.033546619829843874 - 0.07343696894356405*lm - 
          0.021998616723578838*lm^2) + CF*(0.07050748189824109 + 
          0.12342807885512651*lm + 0.14399094582706148*lm^2) + 
        0.016167726905511468*NM + 0.008261587177671087*lm*NM + 
        0.003999748495196152*lm^2*NM + 0.016331913401223065*NL + 
        0.008261587177671087*lm*NL + 0.003999748495196152*lm^2*NL - 
        0.0038534831063315508*NH + 0.008261587177671087*lm*NH + 
        0.003999748495196152*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.03427160553292479 - 0.07354196707968458*lm - 
          0.021992250849531166*lm^2) + CF*(0.07108893561852336 + 
          0.1242187190725739*lm + 0.14394927828784035*lm^2) + 
        0.01619569909419363*NM + 0.00828215084269577*lm*NM + 
        0.003998591063551121*lm^2*NM + 0.016399441163306185*NL + 
        0.00828215084269577*lm*NL + 0.003998591063551121*lm^2*NL - 
        0.0038598194767375184*NH + 0.00828215084269577*lm*NH + 
        0.003998591063551121*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.03496900484043297 - 0.07355628972664839*lm - 
          0.021957260093609036*lm^2) + CF*(0.07163073395102205 + 
          0.12488070561622953*lm + 0.14372024788544097*lm^2) + 
        0.016200291569009255*NM + 0.008292851994753814*lm*NM + 
        0.003992229107928916*lm^2*NM + 0.016447191802008758*NL + 
        0.008292851994753814*lm*NL + 0.003992229107928916*lm^2*NL - 
        0.0038614100168006503*NH + 0.008292851994753814*lm*NH + 
        0.003992229107928916*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.03563007717631011 - 0.0734839653924239*lm - 
          0.021895603591476933*lm^2) + CF*(0.07212930725995269 + 
          0.12540859118634345*lm + 0.14331667805330356*lm^2) + 
        0.016181838294929335*NM + 0.008293969736131997*lm*NM + 
        0.003981018834813988*lm^2*NM + 0.016475194140815084*NL + 
        0.008293969736131997*lm*NL + 0.003981018834813988*lm^2*NL - 
        0.0038585085115619244*NH + 0.008293969736131997*lm*NH + 
        0.003981018834813988*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.03624788122423706 - 0.0733291979579008*lm - 
          0.02180918472496507*lm^2) + CF*(0.07258132172308987 + 
          0.12579898180248816*lm + 0.14275102729068045*lm^2) + 
        0.016140908819078925*NM + 0.008285827956816493*lm*NM + 
        0.003965306313630013*lm^2*NM + 0.01648369131479408*NL + 
        0.008285827956816493*lm*NL + 0.003965306313630013*lm^2*NL - 
        0.0038513670888429712*NH + 0.008285827956816493*lm*NH + 
        0.003965306313630013*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.03681704283564776 - 0.07309630527846481*lm - 
          0.02169984318597509*lm^2) + CF*(0.0729837736652347 + 
          0.12605026380250478*lm + 0.1420353372172915*lm^2) + 
        0.016078260565032008*NM + 0.008268786007594408*lm*NM + 
        0.0039454260338136525*lm^2*NM + 0.01647310144146403*NL + 
        0.008268786007594408*lm*NL + 0.0039454260338136525*lm^2*NL - 
        0.003840234634542608*NH + 0.008268786007594408*lm*NH + 
        0.0039454260338136525*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.03733354605615904 - 0.07278966705525917*lm - 
          0.021569349302262637*lm^2) + CF*(0.07333405092085916 + 
          0.12616235478362967*lm + 0.1411811954329918*lm^2) + 
        0.01599479771767435*NM + 0.008243230535143373*lm*NM + 
        0.003921699873138661*lm^2*NM + 0.016443983539631512*NL + 
        0.008243230535143373*lm*NL + 0.003921699873138661*lm^2*NL - 
        0.0038253555173493816*NH + 0.008243230535143373*lm*NH + 
        0.003921699873138661*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.03779454597703365 - 0.07241368082018274*lm - 
          0.021419400185370006*lm^2) + CF*(0.07362996850818042 + 
          0.1261364780606005*lm + 0.14019971030424003*lm^2) + 
        0.015891535974700433*NM + 0.008209568370691403*lm*NM + 
        0.003894436397340001*lm^2*NM + 0.016397008115871418*NL + 
        0.008209568370691403*lm*NL + 0.003894436397340001*lm^2*NL - 
        0.003806968571457789*NH + 0.008209568370691403*lm*NH + 
        0.003894436397340001*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.038198201881890645 - 0.07197272500910491*lm - 
          0.02125161734608566*lm^2) + CF*(0.07386978448990286 + 
          0.12597495968721295*lm + 0.13910149535619706*lm^2) + 
        0.01576957248701249*NM + 0.008168220367850493*lm*NM + 
        0.0038639304265610293*lm^2*NM + 0.016332931880864085*NL + 
        0.008168220367850493*lm*NL + 0.0038639304265610293*lm^2*NL - 
        0.0037853062951725986*NH + 0.008168220367850493*lm*NH + 
        0.0038639304265610293*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.03854352906268891 - 0.07147112821584682*lm - 
          0.021067545489746497*lm^2) + CF*(0.07405220075166624 + 
          0.12568104677354394*lm + 0.13789666138743162*lm^2) + 
        0.015630060365174676*NM + 0.008119616091204365*lm*NM + 
        0.003830462816317545*lm^2*NM + 0.01625257610485962*NL + 
        0.008119616091204365*lm*NL + 0.003830462816317545*lm^2*NL - 
        0.0037605942306154624*NH + 0.008119616091204365*lm*NH + 
        0.003830462816317545*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.038830267671092475 - 0.07091314382547573*lm - 
          0.020868652256888366*lm^2) + CF*(0.07417635249836806 + 
          0.1252587456610838*lm + 0.1365948147723602*lm^2) + 
        0.015474187186742105*NM + 0.008064189264194974*lm*NM + 
        0.003794300410343339*lm^2*NM + 0.016156808169160805*NL + 
        0.008064189264194974*lm*NL + 0.003794300410343339*lm^2*NL - 
        0.0037330504955978817*NH + 0.008064189264194974*lm*NH + 
        0.003794300410343339*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.039058767017900606 - 0.07030292932011072*lm - 
          0.020656328717386735*lm^2) + CF*(0.07424178951093631 + 
          0.1247126784451467*lm + 0.13520506069562227*lm^2) + 
        0.015303156996256935*NM + 0.0080023738921951*lm*NM + 
        0.0037556961304339516*lm^2*NM + 0.016046525916489227*NL + 
        0.0080023738921951*lm*NL + 0.0037556961304339516*lm^2*NL - 
        0.0037028854434442058*NH + 0.0080023738921951*lm*NH + 
        0.0037556961304339516*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.03922988381216268 - 0.06964452963464889*lm - 
          0.020431890460665424*lm^2) + CF*(0.07424845158944386 + 
          0.12404795632590378*lm + 0.13373601028799187*lm^2) + 
        0.015118175343996404*NM + 0.007934600983997054*lm*NM + 
        0.0037148891746664405*lm^2*NM + 0.015922644446241918*NL + 
        0.007934600983997054*lm*NL + 0.0037148891746664405*lm^2*NL - 
        0.003670301430392805*NH + 0.007934600983997054*lm*NH + 
        0.0037148891746664405*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.03934489292834636 - 0.06894186401456276*lm - 
          0.020196579152546124*lm^2) + CF*(0.07419664010649961 + 
          0.12327006830397162*lm + 0.13219579081666555*lm^2) + 
        0.014920436960081915*NM + 0.007861295802058587*lm*NM + 
        0.0036721053004629316*lm^2*NM + 0.01578608504040093*NL + 
        0.007861295802058587*lm*NL + 0.0036721053004629316*lm^2*NL - 
        0.003635492673362046*NH + 0.007861295802058587*lm*NH + 
        0.0036721053004629316*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.03940540939490599 - 0.06819871589414063*lm - 
          0.019951564452197264*lm^2) + CF*(0.07408698718636007 + 
          0.12238478379827895*lm + 0.1305920582325639*lm^2) + 
        0.014711115706720023*NM + 0.0077828755785914906*lm*NM + 
        0.003627557173126775*lm^2*NM + 0.01563776594204162*NL + 
        0.0077828755785914906*lm*NL + 0.003627557173126775*lm^2*NL - 
        0.0035986451834824143*NH + 0.0077828755785914906*lm*NH + 
        0.003627557173126775*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.03941332040446493 - 0.06741872537214343*lm - 
          0.019697946201440095*lm^2) + CF*(0.07392042369273535 + 
          0.12139806784221333*lm + 0.12893201150033515*lm^2) + 
        0.014491356492700003*NM + 0.007699747640882916*lm*NM + 
        0.003581444763898199*lm^2*NM + 0.015478594741033355*NL + 
        0.007699747640882916*lm*NL + 0.003581444763898199*lm^2*NL - 
        0.0035599367629753926*NH + 0.007699747640882916*lm*NH + 
        0.003581444763898199*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.03937072625025493 - 0.06660538391366362*lm - 
          0.01943675681417535*lm^2) + CF*(0.07369814693714742 + 
          0.12031600760138039*lm + 0.12722240823823866*lm^2) + 
        0.014262268870094033*NM + 0.0076123078950718175*lm*NM + 
        0.0035339557843955182*lm^2*NM + 0.015309462150799827*NL + 
        0.0076123078950718175*lm*NL + 0.0035339557843955182*lm^2*NL - 
        0.0035195370547870157*NH + 0.0076123078950718175*lm*NH + 
        0.0035339557843955182*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.03927988919211429 - 0.06576203095275016*lm - 
          0.019168963806526548*lm^2) + CF*(0.07342158879683207 + 
          0.11914474904754921*lm + 0.12546958127908286*lm^2) + 
        0.014024922061668011*NM + 0.007520939622956694*lm*NM + 
        0.0034852661466411904*lm^2*NM + 0.015131236986131918*NL + 
        0.007520939622956694*lm*NL + 0.0034852661466411904*lm^2*NL - 
        0.003477607635924454*NH + 0.007520939622956694*lm*NH + 
        0.0034852661466411904*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.03914318934479442 - 0.06489185211078899*lm - 
          0.018895472418947016*lm^2) + CF*(0.07309238474329512 + 
          0.1178904427149917*lm + 0.12367945583310774*lm^2) + 
        0.013780341184694843*NM + 0.00742601255129621*lm*NM + 
        0.0034355404398085485*lm^2*NM + 0.014944762175280613*NL + 
        0.00742601255129621*lm*NL + 0.0034355404398085485*lm^2*NL - 
        0.003434302146748739*NH + 0.00742601255129621*lm*NH + 
        0.0034355404398085485*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.038963086756458945 - 0.06399787878131101*lm - 
          0.01861712829039839*lm^2) + CF*(0.07271234411347387 + 
          0.11655919755508667*lm + 0.12185756699169854*lm^2) + 
        0.013529504433479495*NM + 0.007327882157501549*lm*NM + 
        0.0033849324164360707*lm^2*NM + 0.01475085166016447*NL + 
        0.007327882157501549*lm*NL + 0.0033849324164360707*lm^2*NL - 
        0.0033897664495865895*NH + 0.007327882157501549*lm*NH + 
        0.0033849324164360707*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.03874208889679021 - 0.06308298886338103*lm - 
          0.01833472015209271*lm^2) + CF*(0.07228342178082853 + 
          0.11515704199120332*lm + 0.12000907735915228*lm^2) + 
        0.013273340939744502*NM + 0.007226889179634602*lm*NM + 
        0.0033335854821986747*lm^2*NM + 0.014550288056763666*NL + 
        0.007226889179634602*lm*NL + 0.0033335854821986747*lm^2*NL - 
        0.003344138810971796*NH + 0.007226889179634602*lm*NH + 
        0.0033335854821986747*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.03848272278439044 - 0.06214990845348794*lm - 
          0.01804898251445273*lm^2) + CF*(0.07180769116319956 + 
          0.11368989135754408*lm + 0.11813879464005422*lm^2) + 
        0.013012728909285835*NM + 0.007123359302248415*lm*NM + 
        0.0032816331844459506*lm^2*NM + 0.014343820963885031*NL + 
        0.007123359302248415*lm*NL + 0.0032816331844459506*lm^2*NL - 
        0.00329755010263825*NH + 0.007123359302248415*lm*NH + 
        0.0032816331844459506*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.03818751091965295 - 0.06120121433033352*lm - 
          0.01776059832609184*lm^2) + CF*(0.0712873181682866 + 
          0.11216352098226184*lm + 0.11625118904351023*lm^2) + 
        0.012748493365090853*NM + 0.007017602992865834*lm*NM + 
        0.003229199695653062*lm^2*NM + 0.014132165822697216*NL + 
        0.007017602992865834*lm*NL + 0.003229199695653062*lm^2*NL - 
        0.003250124017083835*NH + 0.007017602992865834*lm*NH + 
        0.003229199695653062*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.03785894999563524 - 0.06023933708848793*lm - 
          0.017470201587915547*lm^2) + CF*(0.0707245351093756 + 
          0.11058354424651559*lm + 0.11435041039362905*lm^2) + 
        0.012481402290940203*NM + 0.006909915466819001*lm*NM + 
        0.003176400288711918*lm^2*NM + 0.01391600324196057*NL + 
        0.006909915466819001*lm*NL + 0.003176400288711918*lm^2*NL - 
        0.0032019772941247466*NH + 0.006909915466819001*lm*NH + 
        0.003176400288711918*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.03749949094623608 - 0.05926656479587871*lm - 
          0.01717837990903921*lm^2) + CF*(0.07012161264095329 + 
          0.10895539501713958*lm + 0.11244030485916574*lm^2) + 
        0.012212158975588335*NM + 0.00680057676079532*lm*NM + 
        0.003123341801643493*lm^2*NM + 0.013695978714901549*NL + 
        0.00680057676079532*lm*NL + 0.003123341801643493*lm^2*NL - 
        0.0031532199553778516*NH + 0.00680057676079532*lm*NH + 
        0.003123341801643493*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.0371116793046155 - 0.05828504706680603*lm - 
          0.01688567699421679*lm^2) + CF^2*(0.0694811484558381 + 
          0.10728431391135854*lm + 0.11052443123487354*lm^2) + 
        CF*((0.011941742007462095 + 0.006689851897782336*lm + 
            0.0030701230898575985*lm^2)*NM + (0.013472702663377205 + 
            0.006689851897782336*lm + 0.0030701230898575985*lm^2)*NL + 
          (-0.0031039555440565293 + 0.006689851897782336*lm + 
            0.0030701230898575985*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.03669768324901506 - 0.05729679945689246*lm - 
          0.016592595054977597*lm^2) + CF^2*(0.06880512817708642 + 
          0.10557533790766817*lm + 0.10860607672348972*lm^2) + 
        CF*((0.01167038740714647 + 0.006577991128200507*lm + 
            0.0030168354645413813*lm^2)*NM + (0.0132467507534943 + 
            0.006577991128200507*lm + 0.0030168354645413813*lm^2)*NL + 
          (-0.0030542813678531558 + 0.006577991128200507*lm + 
            0.0030168354645413813*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.03625985032344588 - 0.05630370809931496*lm - 
          0.016299597138751457*lm^2) + CF^2*(0.06809604099776355 + 
          0.10383329286785817*lm + 0.10668827218091863*lm^2) + 
        CF*((0.011398840247334662 + 0.006465230233883375*lm + 
            0.0029635631161366283*lm^2)*NM + (0.0130186644343266 + 
            0.006465230233883375*lm + 0.0029635631161366283*lm^2)*NL + 
          (-0.0030042887430174405 + 0.006465230233883375*lm + 
            0.0029635631161366283*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.0358003797525052 - 0.055307534513035675*lm - 
          0.01600710937199393*lm^2) + CF^2*(0.0673562243984096 + 
          0.10206278858145607*lm + 0.10477380679850572*lm^2) + 
        CF*((0.011127646089095004 + 0.006351790883231032*lm + 
            0.0029103835221807144*lm^2)*NM + (0.012788951657934559 + 
            0.006351790883231032*lm + 0.0029103835221807144*lm^2)*NL + 
          (-0.0029540632380314065 + 0.006351790883231032*lm + 
            0.0029103835221807144*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.035321387429618996 - 0.054309920523728704*lm - 
          0.015715523114756717*lm^2) + CF^2*(0.06658799251728861 + 
          0.1002682159859189*lm + 0.10286524220568033*lm^2) + 
        CF*((0.010857307792626806 + 0.006237881027345814*lm + 
            0.002857367839046676*lm^2)*NM + (0.012558087744641842 + 
            0.006237881027345814*lm + 0.002857367839046676*lm^2)*NL + 
          (-0.002903684915534523 + 0.006237881027345814*lm + 
            0.002857367839046676*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.03482490222254578 - 0.05331239324685516*lm - 
          0.015425197025331532*lm^2) + CF^2*(0.06579362581324315 + 
          0.09845374625399031*lm + 0.10096492598398821*lm^2) + 
        CF*((0.010588287277722456 + 0.006123695328277113*lm + 
            0.002804581277333006*lm^2)*NM + (0.012326516362559133 + 
            0.006123695328277113*lm + 0.002804581277333006*lm^2)*NL + 
          (-0.002853228571374199 + 0.006123695328277113*lm + 
            0.002804581277333006*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.0343128634899806 - 0.05231637009000933*lm - 
          0.015136459034566877*lm^2) + CF^2*(0.06497536210568201 + 
          0.09662333147407833*lm + 0.09907500458989228*lm^2) + 
        CF*((0.010321007345329541 + 0.006009415611672171*lm + 
            0.002752083460830341*lm^2)*NM + (0.01209465059475202 + 
            0.006009415611672171*lm + 0.002752083460830341*lm^2)*NL + 
          (-0.0028027639698410592 + 0.006009415611672171*lm + 
            0.002752083460830341*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.03378711963352462 - 0.05132316373837297*lm - 
          0.014849608230249762*lm^2) + CF^2*(0.06413538888961266 + 
          0.09478070668058357*lm + 0.09719743568890753*lm^2) + 
        CF*((0.010055853534859304 + 0.005895211337167042*lm + 
            0.00269992876913632*lm^2)*NM + (0.011862874071301766 + 
            0.005895211337167042*lm + 0.00269992876913632*lm^2)*NL + 
          (-0.002752356074327547 + 0.005895211337167042*lm + 
            0.00269992876913632*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.03324942752997083 - 0.05033398709298341*lm - 
          0.014564916652586152*lm^2) + CF^2*(0.0632758368243043 + 
          0.09292939301909975*lm + 0.09533399990783663*lm^2) + 
        CF*((0.009793175995024118 + 0.0057812400807704355*lm + 
            0.002648166664106573*lm^2)*NM + (0.011631542146871822 + 
            0.0057812400807704355*lm + 0.002648166664106573*lm^2)*NL + 
          (-0.0027020652727750877 + 0.0057812400807704355*lm + 
            0.002648166664106573*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.0327014527080624 - 0.049349958136643605*lm - 
          0.014282631002328386*lm^2) + CF^2*(0.0623987742977365 + 
          0.09107270185658226*lm + 0.09348631201524035*lm^2) + 
        CF*((0.00953329135096542 + 0.005667648024305491*lm + 
            0.002596842000423343*lm^2)*NM + (0.011400983107327678 + 
            0.005667648024305491*lm + 0.002596842000423343*lm^2)*NL + 
          (-0.0026519475974133688 + 0.005667648024305491*lm + 
            0.002596842000423343*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.03214477015019884 - 0.04837210470676652*lm - 
          0.014002974263505078*lm^2) + CF^2*(0.06150620297184065 + 
          0.0892137396691868*lm + 0.09165583154294232*lm^2) + 
        CF*((0.00927648455249529 + 0.0055545704476919104*lm + 
            0.002545995320637287*lm^2)*NM + (0.011171499391514713 + 
            0.0055545704476919104*lm + 0.002545995320637287*lm^2)*NL + 
          (-0.0026020549383966043 + 0.0055545704476919104*lm + 
            0.002545995320637287*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.03158086561459018 - 0.04740136915832924*lm - 
          0.013726147243025965*lm^2) + CF^2*(0.060600054218170774 + 
          0.08735541356074986*lm + 0.08984387286344268*lm^2) + 
        CF*((0.009023010691506888 + 0.005442132220483604*lm + 
            0.00249566313509563*lm^2)*NM + (0.01094336881652417 + 
            0.005442132220483604*lm + 0.00249566313509563*lm^2)*NL + 
          (-0.0025524352510368567 + 0.005442132220483604*lm + 
            0.00249566313509563*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.03101113738654182 - 0.046438612903483376*lm - 
          0.013452330029675285*lm^2) + CF^2*(0.059682186358351506 + 
          0.08550043728303224*lm + 0.08805161473969278*lm^2) + 
        CF*((0.008773096778836907 + 0.005330448289634102*lm + 
            0.002445878187213688*lm^2)*NM + (0.010716845796711089 + 
            0.005330448289634102*lm + 0.002445878187213688*lm^2)*NL + 
          (-0.002503132756414527 + 0.005330448289634102*lm + 
            0.002445878187213688*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.030436898379336615 - 0.04548462081728802*lm - 
          0.013181683375184687*lm^2) + CF^2*(0.0587543826288103 + 
          0.08365133764507607*lm + 0.08628010936484522*lm^2) + 
        CF*((0.00852694347290731 + 0.005219624160951779*lm + 
            0.0023966697045790337*lm^2)*NM + (0.010492162548405834 + 
            0.005219624160951779*lm + 0.0023966697045790337*lm^2)*NL + 
          (-0.002454188135216255 + 0.005219624160951779*lm + 
            0.0023966697045790337*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.029859378515624355 - 0.044540105501553566*lm - 
          0.012914350000201025*lm^2) + CF^2*(0.05781834979457754 + 
          0.0818104612135158*lm + 0.0845302909104067*lm^2) + 
        CF*((0.008284726753967022 + 0.005109756372136775*lm + 
            0.002348063636400186*lm^2)*NM + (0.010269530273714066 + 
            0.005109756372136775*lm + 0.002348063636400186*lm^2)*NL + 
          (-0.0024056387147094785 + 0.005109756372136775*lm + 
            0.002348063636400186*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.02927972732980976 - 0.04360571140095742*lm - 
          0.012650455828044242*lm^2) + CF^2*(0.056875717342894094 + 
          0.07997998121860612*lm + 0.08280298360174414*lm^2) + 
        CF*((0.008046599539675809 + 0.005000932955667971*lm + 
            0.002300082877826226*lm^2)*NM + (0.010049140318056024 + 
            0.005000932955667971*lm + 0.002300082877826226*lm^2)*NL + 
          (-0.00235751864881405 + 0.005000932955667971*lm + 
            0.002300082877826226*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.02869901674024762 - 0.04268201876745706*lm - 
          0.012390111149193719*lm^2) + CF^2*(0.055928037192865585 + 
          0.07816190459223415*lm + 0.08109890934017706*lm^2) + 
        CF*((0.007812693238459019 + 0.0048932338901374476*lm + 
            0.0022527474816715853*lm^2)*NM + (0.009831165297179483 + 
            0.0048932338901374476*lm + 0.0022527474816715853*lm^2)*NL + 
          (-0.0023098590912750292 + 0.0048932338901374476*lm + 
            0.0022527474816715853*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.028118243948020608 - 0.0417695474706206*lm - 
          0.012133411719454158*lm^2) + CF^2*(0.05497678386397681 + 
          0.07635807907441401*lm + 0.07941869489097267*lm^2) + 
        CF*((0.007583119238776285 + 0.004786731538916833*lm + 
            0.0022060748580825743*lm^2)*NM + (0.009615760190312768 + 
            0.004786731538916833*lm + 0.0022060748580825743*lm^2)*NL + 
          (-0.0022626883619782114 + 0.004786731538916833*lm + 
            0.0022060748580825743*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.027538334425486623 - 0.040868760652852255*lm - 
          0.011880439794739912*lm^2) + CF^2*(0.05402335505126757 + 
          0.07457020033384348*lm + 0.07776287865647942*lm^2) + 
        CF*((0.007357970331950589 + 0.0046814910752895214*lm + 
            0.002160079962679984*lm^2)*NM + (0.009403063396924018 + 
            0.0046814910752895214*lm + 0.002160079962679984*lm^2)*NL + 
          (-0.0022160321064782834 + 0.0046814910752895214*lm + 
            0.002160079962679984*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.026960144965775867 - 0.03998006822963912*lm - 
          0.011631265105384056*lm^2) + CF^2*(0.05306907256442874 + 
          0.07279981905615301*lm + 0.0761319170534229*lm^2) + 
        CF*((0.007137322070625113 + 0.004577570893399232*lm + 
            0.0021147754737061916*lm^2)*NM + (0.009193197755236738 + 
            0.004577570893399232*lm + 0.0021147754737061916*lm^2)*NL + 
          (-0.0021699134488417622 + 0.004577570893399232*lm + 
            0.0021147754737061916*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.026384609481701966 - 0.03910383023591299*lm - 
          0.011385945772829696*lm^2) + CF^2*(0.05211546901723333 + 
          0.07104834796060114*lm + 0.0745261905130671*lm^2) + 
        CF*((0.006921234058221435 + 0.004475023004552515*lm + 
            0.002070171958696308*lm^2)*NM + (0.008986271521234521 + 
            0.004475023004552515*lm + 0.002070171958696308*lm^2)*NL + 
          (-0.0021243531379202887 + 0.004475023004552515*lm + 
            0.002070171958696308*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.025812151442743327 - 0.03824036002042856*lm - 
          0.011144529171498994*lm^2) + CF^2*(0.05116310804964309 + 
          0.06931706871226362*lm + 0.07294600912253887*lm^2) + 
        CF*((0.006709751176784315 + 0.004373893418574021*lm + 
            0.0020262780311816352*lm^2)*NM + (0.008782379307382241 + 
            0.004373893418574021*lm + 0.0020262780311816352*lm^2)*NL + 
          (-0.0020793696871953147 + 0.004373893418574021*lm + 
            0.0020262780311816352*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.025243602693061445 - 0.037389927290727945*lm - 
          0.010907052738563254*lm^2) + CF^2*(0.050213417569906826 + 
          0.0676071387023119*lm + 0.0713916179251413*lm^2) + 
        CF*((0.006502904737986738 + 0.004274222510051601*lm + 
            0.0019831004979205917*lm^2)*NM + (0.008581602980708576 + 
            0.004274222510051601*lm + 0.0019831004979205917*lm^2)*NL + 
          (-0.0020349795083447137 + 0.004274222510051601*lm + 
            0.0019831004979205917*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.024679574976894318 - 0.036552761011808904*lm - 
          0.010673544734257384*lm^2) + CF^2*(0.04926742866775659 + 
          0.06591959767385859*lm + 0.06986320189695742*lm^2) + 
        CF*((0.006300713613192929 + 0.004176045369426356*lm + 
            0.0019406444971377063*lm^2)*NM + (0.008384012520245178 + 
            0.004176045369426356*lm + 0.0019406444971377063*lm^2)*NL + 
          (-0.00199119703869474 + 0.004176045369426356*lm + 
            0.0019406444971377063*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.02412062634431603 - 0.03572905216205606*lm - 
          0.010444024955296278*lm^2) + CF^2*(0.048326104540747296 + 
          0.064255374175134*lm + 0.06836089061648473*lm^2) + 
        CF*((0.00610318529730995 + 0.004079392138982955*lm + 
            0.001898913628235687*lm^2)*NM + (0.008189666834110057 + 
            0.004079392138982955*lm + 0.001898913628235687*lm^2)*NL + 
          (-0.0019480348627317812 + 0.004079392138982955*lm + 
            0.001898913628235687*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.023567264879542478 - 0.03491895635034465*lm - 
          0.01021850540386061*lm^2) + CF^2*(0.04739034431229445 + 
          0.0626152918255113*lm + 0.06688476264345126*lm^2) + 
        CF*((0.005910318620333575 + 0.003984288333880043*lm + 
            0.0018579100734292017*lm^2)*NM + (0.007998614536764372 + 
            0.003984288333880043*lm + 0.0018579100734292017*lm^2)*NL + 
          (-0.0019055038278506548 + 0.003984288333880043*lm + 
            0.0018579100734292017*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.0230235588483294 - 0.03412259629849726*lm - 
          0.00999699091452692*lm^2) + CF^2*(0.04646819992724666 + 
          0.06100007538317709*lm + 0.06543484962235803*lm^2) + 
        CF*((0.005729321859339922 + 0.003890755148431288*lm + 
            0.0018176347117321674*lm^2)*NM + (0.007810894687169669 + 
            0.003890755148431288*lm + 0.0018176347117321674*lm^2)*NL + 
          (-0.0018636131545262345 + 0.003890755148431288*lm + 
            0.0018176347117321674*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.02247908849634442 - 0.033340064193476605*lm - 
          0.009779479741422629*lm^2) + CF^2*(0.04553877658040505 + 
          0.05941035660609923*lm + 0.06401114012567538*lm^2) + 
        CF*((0.005538499379042077 + 0.0037988097479062124*lm + 
            0.001778087225713205*lm^2)*NM + (0.007626537488732465 + 
            0.0037988097479062124*lm + 0.001778087225713205*lm^2)*NL + 
          (-0.0018223705410961018 + 0.0037988097479062124*lm + 
            0.001778087225713205*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.021945147748384224 - 0.03257142391384087*lm - 
          0.009565964107791761*lm^2) + CF^2*(0.044624633168577905 + 
          0.05784667990042283*lm + 0.06261358325100062*lm^2) + 
        CF*((0.005359675353014392 + 0.003708465546168016*lm + 
            0.0017392662014166838*lm^2)*NM + (0.007445564952050316 + 
            0.003708465546168016*lm + 0.0017392662014166838*lm^2)*NL + 
          (-0.0017817822633324784 + 0.003708465546168016*lm + 
            0.0017392662014166838*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.02141819294683071 - 0.03181671313508092*lm - 
          0.009356430720062762*lm^2) + CF^2*(0.04371867703325105 + 
          0.056309507752568294*lm + 0.06124209198586535*lm^2) + 
        CF*((0.005185062452220627 + 0.0036197324695043218*lm + 
            0.001701169221829593*lm^2)*NM + (0.007267991521572527 + 
            0.0036197324695043218*lm + 0.001701169221829593*lm^2)*NL + 
          (-0.0017418532690169285 + 0.0036197324695043218*lm + 
            0.001701169221829593*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.02089877900843664 - 0.031075945318508474*lm - 
          0.009150861248415994*lm^2) + CF^2*(0.042822033741996786 + 
          0.05479922594315111*lm + 0.05989654635326832*lm^2) + 
        CF*((0.005015141706408496 + 0.003532617207037509*lm + 
            0.0016637929542574533*lm^2)*NM + (0.0070938246673635285 + 
            0.003532617207037509*lm + 0.0016637929542574533*lm^2)*NL + 
          (-0.0017025872676758912 + 0.003532617207037509*lm + 
            0.0016637929542574533*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.020387076543192755 - 0.030349111588377334*lm - 
          0.008949232775756454*lm^2) + CF^2*(0.04193507898588607 + 
          0.053316148542424946*lm + 0.05857679635040587*lm^2) + 
        CF*((0.00484969094033448 + 0.003447123448124964*lm + 
            0.0016271332319557187*lm^2)*NM + (0.006923065443211139 + 
            0.003447123448124964*lm + 0.0016271332319557187*lm^2)*NL + 
          (-0.0016639868156932529 + 0.003447123448124964*lm + 
            0.0016271332319557187*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.01988330974537019 - 0.029636182501901413*lm - 
          0.008751518216906869*lm^2) + CF^2*(0.04105831220280902 + 
          0.05186052268829689*lm + 0.05728266469248132*lm^2) + 
        CF*((0.0046886563281241436 + 0.00336325210717718*lm + 
            0.0015911851303467034*lm^2)*NM + (0.006755709012358496 + 
            0.00336325210717718*lm + 0.0015911851303467034*lm^2)*NL + 
          (-0.0016260533969571786 + 0.00336325210717718*lm + 
            0.0015911851303467034*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.01938767192887256 - 0.028937109716789283*lm - 
          0.008557686709748283*lm^2) + CF^2*(0.040192185660758266 + 
          0.05043253314910525*lm + 0.05601394937289785*lm^2) + 
        CF*((0.004531979808065866 + 0.003281001536333986*lm + 
            0.0015559430381360513*lm^2)*NM + (0.006591745142160047 + 
            0.003281001536333986*lm + 0.0015559430381360513*lm^2)*NL + 
          (-0.0015887874992548798 + 0.003281001536333986*lm + 
            0.0015559430381360513*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.01890032744385968 - 0.028251827560848822*lm - 
          0.00836770397994961*lm^2) + CF^2*(0.03933710646494332 + 
          0.04903230667430813*lm + 0.05477042605057927*lm^2) + 
        CF*((0.004379599343387443 + 0.0032003677264469837*lm + 
            0.0015214007236272018*lm^2)*NM + (0.006431158668970952 + 
            0.0032003677264469837*lm + 0.0015214007236272018*lm^2)*NL + 
          (-0.0015521886865602693 + 0.0032003677264469837*lm + 
            0.0015214007236272018*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.0184214136078885 - 0.0275802545081318*lm - 
          0.008181532680844742*lm^2) + CF^2*(0.03849343874540069 + 
          0.04765991613702864*lm + 0.05355185027462013*lm^2) + 
        CF*((0.004231449361695827 + 0.003121344496820221*lm + 
            0.0014875513965172259*lm^2)*NM + (0.0062739299345775995 + 
            0.003121344496820221*lm + 0.0014875513965172259*lm^2)*NL + 
          (-0.0015162556674147166 + 0.003121344496820221*lm + 
            0.0014875513965172259*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.017951042579102603 - 0.02692229456598949*lm - 
          0.00799913270993567*lm^2) + CF^2*(0.03766150587062063 + 
          0.046315384473058545*lm + 0.052357959555942565*lm^2) + 
        CF*((0.004087461230734049 + 0.0030439236741617356*lm + 
            0.001454387765442849*lm^2)*NM + (0.006120035195466485 + 
            0.0030439236741617356*lm + 0.001454387765442849*lm^2)*NL + 
          (-0.0014809863595635598 + 0.0030439236741617356*lm + 
            0.001454387765442849*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.01748930312825008 - 0.026277838577300365*lm - 
          0.00782046150342292*lm^2) + CF^2*(0.03684159259153449 + 
          0.044998688421453305*lm + 0.05118847529513185*lm^2) + 
        CF*((0.003947563680430674 + 0.002968095261196415*lm + 
            0.0014219020915314403*lm^2)*NM + (0.0059694470062108505 + 
            0.002968095261196415*lm + 0.0014219020915314403*lm^2)*NL + 
          (-0.001446377951006439 + 0.002968095261196415*lm + 
            0.0014219020915314403*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.01703626232272566 - 0.02564676544201118*lm - 
          0.007645474310090401*lm^2) + CF^2*(0.036033947133395756 + 
          0.04370976207227452*lm + 0.05004310457513717*lm^2) + 
        CF*((0.0038116831959909172 + 0.002893847595386072*lm + 
            0.0013900862381982548*lm^2)*NM + (0.00582213457823073 + 
            0.002893847595386072*lm + 0.0013900862381982548*lm^2)*NL + 
          (-0.0014124269576400498 + 0.002893847595386072*lm + 
            0.0013900862381982548*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.01659196712353012 - 0.025028943262006356*lm - 
          0.007474124445800555*lm^2) + CF^2*(0.035238783228860475 + 
          0.04244850022736317*lm + 0.04892154182705818*lm^2) + 
        CF*((0.003679744380577863 + 0.002821167498196069*lm + 
            0.0013589317174182828*lm^2)*NM + (0.005678064115153404 + 
            0.002821167498196069*lm + 0.0013589317174182828*lm^2)*NL + 
          (-0.0013791292776292993 + 0.002821167498196069*lm + 
            0.0013589317174182828*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.01615644589776803 - 0.024424230413188735*lm - 
          0.0073063635297875695*lm^2) + CF^2*(0.03445628208942002 + 
          0.041214761580271944*lm + 0.04782347037679136*lm^2) + 
        CF*((0.003551670289802202 + 0.0027500404153396715*lm + 
            0.001328429732688649*lm^2)*NM + (0.005537199125968795 + 
            0.0027500404153396715*lm + 0.001328429732688649*lm^2)*NL + 
          (-0.0013464802426681063 + 0.0027500404153396715*lm + 
            0.001328429732688649*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.015729709849366613 - 0.023832476548519395*lm - 
          0.007142141703871139*lm^2) + CF^2*(0.03368659431286179 + 
          0.04000837172165764*lm + 0.04674856387988382*lm^2) + 
        CF*((0.003427382739340872 + 0.0026804505484217755*lm + 
            0.0012985712188856616*lm^2)*NM + (0.005399500717138877 + 
            0.0026804505484217755*lm + 0.0012985712188856616*lm^2)*NL + 
          (-0.0013144746663055875 + 0.0026804505484217755*lm + 
            0.0012985712188856616*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.015311754370866137 - 0.023253523535626753*lm - 
          0.006981407835651084*lm^2) + CF^2*(0.03292984172516878 + 
          0.038829125976545524*lm + 0.04569648765153437*lm^2) + 
        CF*((0.0033068025875598777 + 0.0026123809783930433*lm + 
            0.001269346879209288*lm^2)*NM + (0.005264927864782455 + 
            0.0026123809783930433*lm + 0.001269346879209288*lm^2)*NL + 
          (-0.0012831068893916578 + 0.0026123809783930433*lm + 
            0.001269346879209288*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.014902560319187177 - 0.022687206332456532*lm - 
          0.006824109706683724*lm^2) + CF^2*(0.03218611915577683 + 
          0.037676792079934344*lm + 0.04466689989829347*lm^2) + 
        CF*((0.0031898499947317486 + 0.002545813781214045*lm + 
            0.0012407472193970408*lm^2)*NM + (0.005133437668017309 + 
            0.002545813781214045*lm + 0.0012407472193970408*lm^2)*NL + 
          (-0.0012523708229093076 + 0.002545813781214045*lm + 
            0.0012407472193970408*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.014502095218276652 - 0.022133353804295635*lm - 
          0.006670194186584377*lm^2) + CF^2*(0.031455496145493686 + 
          0.036551112697221826*lm + 0.043659452857643194*lm^2) + 
        CF*((0.0030764446597514672 + 0.002480730136116871*lm + 
            0.0012127625793789776*lm^2)*NM + (0.005004985584501298 + 
            0.002480730136116871*lm + 0.0012127625793789776*lm^2)*NL + 
          (-0.0012222599881967704 + 0.002480730136116871*lm + 
            0.0012127625793789776*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.014110314391718394 - 0.0215917894853652*lm - 
          0.0065196073939465865*lm^2) + CF^2*(0.030738018587135006 + 
          0.03545180779590245*lm + 0.04267379385128675*lm^2) + 
        CF*((0.0029665060375076604 + 0.002417110426839091*lm + 
            0.001185383162535743*lm^2)*NM + (0.004879525649172895 + 
            0.002417110426839091*lm + 0.001185383162535743*lm^2)*NL + 
          (-0.0011927675547641495 + 0.002417110426839091*lm + 
            0.001185383162535743*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.01372716202804251 - 0.021062332288041916*lm - 
          0.0063722948449175245*lm^2) + CF^2*(0.030033710298601926 + 
          0.03437857687492778*lm + 0.04170956625764198*lm^2) + 
        CF*((0.0028599535352571807 + 0.002354934336191995*lm + 
            0.0011585990627122772*lm^2)*NM + (0.004757010677150359 + 
            0.002354934336191995*lm + 0.0011585990627122772*lm^2)*NL + 
          (-0.0011638863757969442 + 0.002354934336191995*lm + 
            0.0011585990627122772*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.013352572181926413 - 0.0205447971626325*lm - 
          0.006228201590220494*lm^2) + CF^2*(0.0293425745294026 + 
          0.03333110105803033*lm + 0.04076641040871596*lm^2) + 
        CF*((0.0027567066926365703 + 0.0022941809343119107*lm + 
            0.0011324002891309989*lm^2)*NM + (0.004637392451707455 + 
            0.0022941809343119107*lm + 0.0011324002891309989*lm^2)*NL + 
          (-0.0011356090215316238 + 0.0022941809343119107*lm + 
            0.0011324002891309989*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.012986469713982643 - 0.020038995710494962*lm - 
          0.0060872723413693975*lm^2) + CF^2*(0.02866459540097097 + 
          0.032309045057199524*lm + 0.039843964416236055*lm^2) + 
        CF*((0.002656685344033528 + 0.002234828760930132*lm + 
            0.0011067767893398904*lm^2)*NM + (0.004520621898202748 + 
            0.002234828760930132*lm + 0.0011067767893398904*lm^2)*NL + 
          (-0.0011079278103688773 + 0.002234828760930132*lm + 
            0.0011067767893398904*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.012628771172099476 - 0.01954473675317154*lm - 
          0.005949451586776372*lm^2) + CF^2*(0.027999739282010137 + 
          0.03131205901236602*lm + 0.03894186493162716*lm^2) + 
        CF*((0.002559809765861577 + 0.002176855901983764*lm + 
            0.0010817184703229767*lm^2)*NM + (0.004406649244799161 + 
            0.002176855901983764*lm + 0.0010817184703229767*lm^2)*NL + 
          (-0.0010808348382821426 + 0.002176855901983764*lm + 
            0.0010817184703229767*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.012279385617004247 - 0.01906182686007336*lm - 
          0.0058146836984124305*lm^2) + CF^2*(0.02734795609981297 + 
          0.030339780213203917*lm + 0.03805974784415409*lm^2) + 
        CF*((0.0024660008084694952 + 0.0021202400608765774*lm + 
            0.0010572152178931692*lm^2)*NM + (0.004295424170770875 + 
            0.0021202400608765774*lm + 0.0010572152178931692*lm^2)*NL + 
          (-0.0010543220061395237 + 0.0021202400608765774*lm + 
            0.0010572152178931692*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.011938215395000944 - 0.01859007083713503*lm - 
          0.005682913029641812*lm^2) + CF^2*(0.0267091805893778 + 
          0.029391834708799858*lm + 0.037197248921291864*lm^2) + 
        CF*((0.002375180016399468 + 0.0020649586246859497*lm + 
            0.0010332569144803295*lm^2)*NM + (0.004186895943155969 + 
            0.0020649586246859497*lm + 0.0010332569144803295*lm^2)*NL + 
          (-0.0010283810453559986 + 0.0020649586246859497*lm + 
            0.0010332569144803295*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.011605156860160793 - 0.018129272178739744*lm - 
          0.005554084004813664*lm^2) + CF^2*(0.026083333481078195 + 
          0.02846783881076881*lm + 0.03635400439514398*lm^2) + 
        CF*((0.0022872697337197934 + 0.002010988725599105*lm + 
            0.0010098334554206664*lm^2)*NM + (0.004081013542475529 + 
            0.002010988725599105*lm + 0.0010098334554206664*lm^2)*NL + 
          (-0.001003003541845991 + 0.002010988725599105*lm + 
            0.0010098334554206664*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.011280101048890422 - 0.01767923348510147*lm - 
          0.005428141201159702*lm^2) + CF^2*(0.025470322629209053 + 
          0.0275674004952194*lm + 0.03552965149849987*lm^2) + 
        CF*((0.0022021931995546344 + 0.001958307297849261*lm + 
            0.0009869347638472186*lm^2)*NM + (0.003977725778203341 + 
            0.001958307297849261*lm + 0.0009869347638472186*lm^2)*NL + 
          (-0.0009781809584087284 + 0.001958307297849261*lm + 
            0.0009869347638472186*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.010962934309149902 - 0.017239756847180883*lm - 
          0.0053050294235133496*lm^2) + CF^2*(0.02487004408268323 + 
          0.02669012070878948*lm + 0.034723828953905564*lm^2) + 
        CF*((0.002119874632165425 + 0.0019068911304099638*lm + 
            0.0009645508042751545*lm^2)*NM + (0.003876981394634918 + 
            0.0019068911304099638*lm + 0.0009645508042751545*lm^2)*NL + 
          (-0.0009539046554801437 + 0.0019068911304099638*lm + 
            0.0009645508042751545*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.010653538886768472 - 0.016810644201105812*lm - 
          0.005184693772334633*lm^2) + CF^2*(0.02428238309974553 + 
          0.025835594583787196*lm + 0.03393617741891759*lm^2) + 
        CF*((0.002040239303063871 + 0.001856716915693869*lm + 
            0.0009426715949699331*lm^2)*NM + (0.0037787291677704353 + 
            0.001856716915693869*lm + 0.0009426715949699331*lm^2)*NL + 
          (-0.0009301659108069599 + 0.001856716915693869*lm + 
            0.0009426715949699331*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.010351793471172863 - 0.01639169765396504*lm - 
          0.0050670797054955564*lm^2) + CF^2*(0.023707215108532784 + 
          0.025003412567285478*lm + 0.033166339890516365*lm^2) + 
        CF*((0.001963213601985197 + 0.0018077612944905396*lm + 
            0.0009212872191810103*lm^2)*NM + (0.003682917993793201 + 
            0.0018077612944905396*lm + 0.0009212872191810103*lm^2)*NL + 
          (-0.0009069559373050373 + 0.0018077612944905396*lm + 
            0.0009212872191810103*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.01005757370274338 - 0.015982719782746627*lm - 
          0.004952133094252876*lm^2) + CF^2*(0.023144406615322546 + 
          0.02419316146882998*lm + 0.03241396207147337*lm^2) + 
        CF*((0.0018887250934184112 + 0.00176000089736649*lm + 
            0.0009003878353187048*lm^2)*NM + (0.00358949696969368 + 
            0.00176000089736649*lm + 0.0009003878353187048*lm^2)*NL + 
          (-0.000884265900054934 + 0.00176000089736649*lm + 
            0.0009003878353187048*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.009770752643913524 - 0.015583513908098052*lm - 
          0.004839800273808868*lm^2) + CF^2*(0.02259381606231461 + 
          0.023404425431233312*lm + 0.031678692701294406*lm^2) + 
        CF*((0.0018167025651561232 + 0.0017134123827397423*lm + 
            0.0008799636861470669*lm^2)*NM + (0.0034984154665587287 + 
            0.0017134123827397423*lm + 0.0008799636861470669*lm^2)*NL + 
          (-0.0008620869318309693 + 0.0017134123827397423*lm + 
            0.0008799636861470669*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.009491201216062542 - 0.015193884344495623*lm - 
          0.0047300280888359575*lm^2) + CF^2*(0.022055294636844018 + 
          0.022636786828742782*lm + 0.030960183854198995*lm^2) + 
        CF*((0.0017470760696262242 + 0.001667972471830553*lm + 
            0.0008600051070610833*lm^2)*NM + (0.003409623196016608 + 
            0.001667972471830553*lm + 0.0008600051070610833*lm^2)*NL + 
          (-0.0008404101476485473 + 0.001667972471830553*lm + 
            0.0008600051070610833*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.009218961855722555 - 0.014813832841384085*lm - 
          0.004622828139930053*lm^2) + CF*(0.02152815551683815 + 
          0.02189006872242679*lm + 0.030258511461360344*lm^2) + 
        0.001679916137078277*NM + 0.001623678798284367*lm*NM + 
        0.0008405142072600096*lm^2*NM + 0.0033231507660011887*NL + 
        0.001623678798284367*lm*NL + 0.0008405142072600096*lm^2*NL - 
        0.0008192309053058476*NH + 0.001623678798284367*lm*NH + 
        0.0008405142072600096*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.008953531260336137 - 0.014442744560017116*lm - 
          0.004518010205611973*lm^2) + CF*(0.02101338637116218 + 
          0.021163335847157266*lm + 0.029572430436732914*lm^2) + 
        0.0016148559865590273*NM + 0.0015804635914317465*lm*NM + 
        0.0008214564010203587*lm^2*NM + 0.003238775649385431*NL + 
        0.0015804635914317465*lm*NL + 0.0008214564010203587*lm^2*NL - 
        0.0007985312048681417*NH + 0.0015804635914317465*lm*NH + 
        0.0008214564010203587*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.00869497735548866 - 0.01408065783390938*lm - 
          0.004415598303000681*lm^2) + CF*(0.020510190559857075 + 
          0.020456449083139604*lm + 0.028902097983277183*lm^2) + 
        0.0015519929659073284*NM + 0.0015383282633222094*lm*NM + 
        0.0008028360550910329*lm^2*NM + 0.003156543236612592*NL + 
        0.0015383282633222094*lm*NL + 0.0008028360550910329*lm^2*NL - 
        0.0007783071428714479*NH + 0.0015383282633222094*lm*NH + 
        0.0008028360550910329*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.008443165860072231 - 0.013727382479935395*lm - 
          0.004315541486610815*lm^2) + CF*(0.020018399387223444 + 
          0.01976899093321142*lm + 0.028247180639634422*lm^2) + 
        0.0014912620630749692*NM + 0.0014972500242436022*lm*NM + 
        0.0007846439066565117*lm^2*NM + 0.0030764049141281057*NL + 
        0.0014972500242436022*lm*NL + 0.0007846439066565117*lm^2*NL - 
        0.0007585498767048909*NH + 0.0014972500242436022*lm*NH + 
        0.0007846439066565117*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.008197962129755222 - 0.013382730324364678*lm - 
          0.004217789509222807*lm^2) + CF*(0.019537840011522895 + 
          0.019100545713008347*lm + 0.027607349514912918*lm^2) + 
        0.0014325997005417688*NM + 0.0014572062882461515*lm*NM + 
        0.0007668708198586921*lm^2*NM + 0.0029983126826405616*NL + 
        0.0014572062882461515*lm*NL + 0.0007668708198586921*lm^2*NL - 
        0.0007392506050130363*NH + 0.0014572062882461515*lm*NH + 
        0.0007668708198586921*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.007959231423134833 - 0.013046515332365734*lm - 
          0.0041222928408231295*lm^2) + CF*(0.019068336038247435 + 
          0.018450700091043066*lm + 0.026982280412660483*lm^2) + 
        0.0013759437379486286*NM + 0.0014181746923057727*lm*NM + 
        0.000749507789240569*lm^2*NM + 0.002922219187985887*NL + 
        0.0014181746923057727*lm*NL + 0.000749507789240569*lm^2*NL - 
        0.0007204005765038879*NH + 0.0014181746923057727*lm*NH + 
        0.000749507789240569*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.007726839145760048 - 0.012718553723662152*lm - 
          0.004029002684900333*lm^2) + CF*(0.018609708072880128 + 
          0.017819043581084867*lm + 0.026371653937529455*lm^2) + 
        0.0013212334715085772*NM + 0.001380133113581471*lm*NM + 
        0.0007325459427091514*lm^2*NM + 0.002848077748226283*NL + 
        0.001380133113581471*lm*NL + 0.0007325459427091514*lm^2*NL - 
        0.0007019910980258154*NH + 0.001380133113581471*lm*NH + 
        0.0007325459427091514*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.00750065107342795 - 0.012398664075265482*lm - 
          0.0039378709922840175*lm^2) + CF*(0.01816177423538473 + 
          0.01720516898985262*lm + 0.025775155585859022*lm^2) + 
        0.0012684096304822609*NM + 0.001343059684891637*lm*NM + 
        0.0007159765440516396*lm^2*NM + 0.002775842377252208*NL + 
        0.001343059684891637*lm*NL + 0.0007159765440516396*lm^2*NL - 
        0.000684013541956855*NH + 0.001343059684891637*lm*NH + 
        0.0007159765440516396*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.007280533556078736 - 0.012086667412157324*lm - 
          0.0038488504727029567*lm^2) + CF*(0.017724350638553193 + 
          0.01660867282287018*lm + 0.02519247582132844*lm^2) + 
        0.0012174143709854988*NM + 0.0013069328085270938*lm*NM + 
        0.0006997909950369011*lm^2*NM + 0.0027054678051397856*NL + 
        0.0013069328085270938*lm*NL + 0.0006997909950369011*lm^2*NL - 
        0.0006664593529475765*NH + 0.0013069328085270938*lm*NH + 
        0.0006997909950369011*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.0070663537035407535 - 0.01178238728674358*lm - 
          0.003761894604228245*lm^2) + CF*(0.017297251832236064 + 
          0.016029155651176966*lm + 0.024623310136766698*lm^2) + 
        0.001168191267378752*NM + 0.0012717311685121312*lm*NM + 
        0.0006839808371324083*lm^2*NM + 0.002636909495500953*NL + 
        0.0012717311685121312*lm*NL + 0.0006839808371324083*lm^2*NL - 
        0.0006493200540565753*NH + 0.0012717311685121312*lm*NH + 
        0.0006839808371324083*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.0068579795543067664 - 0.011485649847856709*lm - 
          0.003676957640757509*lm^2) + CF*(0.01688029121538138 + 
          0.015466222441438084*lm + 0.02406735910314006*lm^2) + 
        0.0011206853014715651*NM + 0.0012374337414184904*lm*NM + 
        0.0006685377528650017*lm^2*NM + 0.002570123660049387*NL + 
        0.0012374337414184904*lm*NL + 0.0006685377528650017*lm^2*NL - 
        0.0006325872523155964*NH + 0.0012374337414184904*lm*NH + 
        0.0006685377528650017*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.0066552802284559325 - 0.011196283900037258*lm - 
          0.003593994617686917*lm^2) + CF*(0.016473281417712538 + 
          0.01491948285185716*lm + 0.023524328406678*lm^2) + 
        0.0010748428497592164*NM + 0.0012040198058312892*lm*NM + 
        0.0006534535668521667*lm^2*NM + 0.0025050672705917224*NL + 
        0.0012040198058312892*lm*NL + 0.0006534535668521667*lm^2*NL - 
        0.0006162526437593612*NH + 0.0012040198058312892*lm*NH + 
        0.0006534535668521667*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.006458126065772732 - 0.010914120953783484*lm - 
          0.003512961355908926*lm^2) + CF*(0.016076034652784756 + 
          0.014388551496160994*lm + 0.022993928875040242*lm^2) + 
        0.001030611668893882*NM + 0.0011714689505602208*lm*NM + 
        0.0006387202465288956*lm^2*NM + 0.0024416980686407853*NL + 
        0.0011714689505602208*lm*NL + 0.0006387202465288956*lm^2*NL - 
        0.0006003080179533103*NH + 0.0011714689505602208*lm*NH + 
        0.0006387202465288956*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.0062663887500539845 - 0.010638995267417755*lm - 
          0.0034338144642653227*lm^2) + CF*(0.015688363044072923 + 
          0.013873048177797546*lm + 0.02247587649337302*lm^2) + 
        0.0009879408795785479*NM + 0.0011397610816839799*lm*NM + 
        0.000624329902593695*lm^2*NM + 0.002379974572835432*NL + 
        0.0011397610816839799*lm*NL + 0.000624329902593695*lm^2*NL - 
        0.0005847452620507095*NH + 0.0011397610816839799*lm*NH + 
        0.000624329902593695*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.006079941420538118 - 0.010370743881180281*lm - 
          0.0033565113405772395*lm^2) + CF*(0.015310078925660546 + 
          0.013372598096367825*lm + 0.02196989241105102*lm^2) + 
        0.0009467809490586622*NM + 0.0011088764285107726*lm*NM + 
        0.0006102747891958617*lm^2*NM + 0.0023198560843401494*NL + 
        0.0011088764285107726*lm*NL + 0.0006102747891958617*lm^2*NL - 
        0.0005695563644088923*NH + 0.0011088764285107726*lm*NH + 
        0.0006102747891958617*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.005898658771336779 - 0.0101092066441246*lm - 
          0.0032810101713663248*lm^2) + CF*(0.014940995119020334 + 
          0.012886832028197149*lm + 0.021475702939852306*lm^2) + 
        0.0009070836723740305*NM + 0.0010787955485329266*lm*NM + 
        0.0005965473038847864*lm^2*NM + 0.0022613026903867176*NL + 
        0.0010787955485329266*lm*NL + 0.0005965473038847864*lm^2*NL - 
        0.0005547334177928066*NH + 0.0010787955485329266*lm*NH + 
        0.0005965473038847864*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.005722417139697626 - 0.009854226234355012*lm - 
          0.0032072699303741805*lm^2) + CF*(0.014580925187301117 + 
          0.012415386482842189*lm + 0.020993039544267362*lm^2) + 
        0.0008688021525217244*NM + 0.0010494993314490348*lm*NM + 
        0.00058313998734076*lm^2*NM + 0.0022042752661099968*NL + 
        0.0010494993314490348*lm*NL + 0.00058313998734076*lm^2*NL - 
        0.0005402686221925158*NH + 0.0010494993314490348*lm*NH + 
        0.00058313998734076*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.0055510945838785596 - 0.009605648173113709*lm - 
          0.0031352503759804803*lm^2) + CF*(0.014229683668463613 + 
          0.011957903837226558*lm + 0.020521638824599505*lm^2) + 
        0.0008318907796697288*NM + 0.001020969002322712*lm*NM + 
        0.0005700455229055418*lm^2*NM + 0.0021487354748202306*NL + 
        0.001020969002322712*lm*NL + 0.0005700455229055418*lm^2*NL - 
        0.0005261542872798546*NH + 0.001020969002322712*lm*NH + 
        0.0005700455229055418*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.005384570951367587 - 0.009363320833194643*lm - 
          0.0030649120476138546*lm^2) + CF*(0.013887086288538481 + 
          0.011514032448999453*lm + 0.020061242493472502*lm^2) + 
        0.0007963052095506742*NM + 0.0009931861239429276*lm*NM + 
        0.0005572567359297917*lm^2*NM + 0.002094645766845097*NL + 
        0.0009931861239429276*lm*NL + 0.0005572567359297917*lm^2*NL - 
        0.0005123828345280638*NH + 0.0009931861239429276*lm*NH + 
        0.0005572567359297917*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.005222727938138916 - 0.009127095442132095*lm - 
          0.002996216261243647*lm^2) + CF*(0.013552950156214291 + 
          0.011083426750618623*lm + 0.019611597346322052*lm^2) + 
        0.0007620023411552485*NM + 0.000966132598446975*lm*NM + 
        0.0005447665929533903*lm^2*NM + 0.002041969377066125*NL + 
        0.000966132598446975*lm*NL + 0.0005447665929533903*lm^2*NL - 
        0.0004989467990169197*NH + 0.000966132598446975*lm*NH + 
        0.0005447665929533903*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.00506544913959456 - 0.008896826080584353*lm - 
          0.0029291251040349966*lm^2) + CF*(0.013227093939900163 + 
          0.010665747325570575*lm + 0.019172455226410888*lm^2) + 
        0.0007289402938357282*NM + 0.000939790668263437*lm*NM + 
        0.0005325682007336357*lm^2*NM + 0.0019906703212659357*NL + 
        0.000939790668263437*lm*NL + 0.0005325682007336357*lm^2*NL - 
        0.00048583883094462663*NH + 0.000939790668263437*lm*NH + 
        0.0005325682007336357*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.004912620093801632 - 0.008672369676306944*lm - 
          0.0028636014282443704*lm^2) + CF*(0.012909338028347976 + 
          0.010260660968057129*lm + 0.018743572984872243*lm^2) + 
        0.0006970783839214787*NM + 0.0009141429164290116*lm*NM + 
        0.0005206548051353401*lm^2*NM + 0.0019407133913950847*NL + 
        0.0009141429164290116*lm*NL + 0.0005206548051353401*lm^2*NL - 
        0.00047305169686656033*NH + 0.0009141429164290116*lm*NH + 
        0.0005206548051353401*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.0047641283175985085 - 0.00845358599408514*lm - 
          0.002799608844427616*lm^2) + CF*(0.012599504675861859 + 
          0.00986784072739807*lm + 0.018324712436253485*lm^2) + 
        0.000666377100940215*NM + 0.0008891722663297508*lm*NM + 
        0.0005090197898959301*lm^2*NM + 0.0018920641498600353*NL + 
        0.0008891722663297508*lm*NL + 0.0005090197898959301*lm^2*NL - 
        0.0004605782806798254*NH + 0.0008891722663297508*lm*NH + 
        0.0005090197898959301*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.004619863336108022 - 0.008240337621972276*lm - 
          0.0027371117140278806*lm^2) + CF*(0.01229741813306823 + 
          0.009486965938324435*lm + 0.017915640310000674*lm^2) + 
        0.000636798083531267*NM + 0.0008648619809141273*lm*NM + 
        0.0004976566752777965*lm^2*NM + 0.0018446889229269616*NL + 
        0.0008648619809141273*lm*NL + 0.0004976566752777965*lm^2*NL - 
        0.00044841158437152205*NH + 0.0008648619809141273*lm*NH + 
        0.0004976566752777965*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.004479716706162742 - 0.008032489954158343*lm - 
          0.002676075141406234*lm^2) + CF*(0.012002904764167755 + 
          0.009117722238265768*lm + 0.017516128198295348*lm^2) + 
        0.0006083040951300198*NM + 0.0008411956614223884*lm*NM + 
        0.00048655911661931524*lm^2*NM + 0.0017985547933296337*NL + 
        0.0008411956614223884*lm*NL + 0.00048655911661931524*lm^2*NL - 
        0.00043654472854760216*NH + 0.0008411956614223884*lm*NH + 
        0.00048655911661931524*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.0043435820341160905 - 0.007829911170772582*lm - 
          0.00261646496537361*lm^2) + CF*(0.011715793151541112 + 
          0.008759801572667283*lm + 0.017125952500627265*lm^2) + 
        0.0005808589994960811*NM + 0.0008181572456738489*lm*NM + 
        0.0004757209027952018*lm^2*NM + 0.0017536295921635936*NL + 
        0.0008181572456738489*lm*NL + 0.0004757209027952018*lm^2*NL - 
        0.0004249709527582348*NH + 0.0008181572456738489*lm*NH + 
        0.0004757209027952018*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.004211354988483468 - 0.007632472214904139*lm - 
          0.0025582477502787185*lm^2) + CF*(0.01143591418853339 + 
          0.00841290218930906*lm + 0.016744894365460703*lm^2) + 
        0.0005544277361515406*NM + 0.0007957310059511318*lm*NM + 
        0.0004651359545961307*lm^2*NM + 0.0017098818901430995*NL + 
        0.0007957310059511318*lm*NL + 0.0004651359545961307*lm^2*NL - 
        0.00041368361563468497*NH + 0.0007957310059511318*lm*NH + 
        0.0004651359545961307*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.004082933307829603 - 0.00744004676710635*lm - 
          0.0025013907767027993*lm^2) + CF*(0.011163101161197057 + 
          0.008076728622539078*lm + 0.016372739629327414*lm^2) + 
        0.0005289762957898948*NM + 0.0007739015465178621*lm*NM + 
        0.0004547983230368726*lm^2*NM + 0.0016672809882919686*NL + 
        0.0007739015465178621*lm*NL + 0.0004547983230368726*lm^2*NL - 
        0.0004026761948518431*NH + 0.0007739015465178621*lm*NH + 
        0.0004547983230368726*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.003958216804291955 - 0.007252511217632688*lm - 
          0.002445862031808568*lm^2) + CF*(0.01089718981973077 + 
          0.007750991668274817*lm + 0.01600927875365608*lm^2) + 
        0.0005044716957108132*NM + 0.0007526538008039606*lm*NM + 
        0.0004447021876015578*lm^2*NM + 0.0016257969081343805*NL + 
        0.0007526538008039606*lm*NL + 0.0004447021876015578*lm^2*NL - 
        0.0003919422869297211*NH + 0.0007526538008039606*lm*NH + 
        0.0004447021876015578*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.003837107363105063 - 0.007069744636635967*lm - 
          0.0023916301993873834*lm^2) + CF*(0.010638018440310634 + 
          0.007435408350574196*lm + 0.015654306759626507*lm^2) + 
        0.00048088195533087447*NM + 0.0007319730282904507*lm*NM + 
        0.00043484185443406966*lm^2*NM + 0.0015854003814469652*NL + 
        0.0007319730282904507*lm*NL + 0.00043484185443406966*lm^2*NL - 
        0.0003814756068864493*NH + 0.0007319730282904507*lm*NH + 
        0.00043484185443406966*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.003719508938467242 - 0.006891628742546791*lm - 
          0.0023386646496455234*lm^2) + CF*(0.010385427877971913 + 
          0.007129701880525656*lm + 0.015307623161316154*lm^2) + 
        0.0004581760718156991*NM + 0.0007118448111235929*lm*NM + 
        0.0004252117544810043*lm^2*NM + 0.001546062839629034*NL + 
        0.0007118448111235929*lm*NL + 0.0004252117544810043*lm^2*NL - 
        0.00037126998775457*NH + 0.0007118448111235929*lm*NH + 
        0.0004252117544810043*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.0036053275460687997 - 0.006718047868832605*lm - 
          0.0022869354287675223*lm^2) + CF*(0.010139261611162343 + 
          0.006833601608159025*lm + 0.014969031897387419*lm^2) + 
        0.0004363239958745246*NM + 0.0006922550504861709*lm*NM + 
        0.00041580644159409496*lm^2*NM + 0.0015077564027436213*NL + 
        0.0006922550504861709*lm*NL + 0.00041580644159409496*lm^2*NL - 
        0.00036131937997172203*NH + 0.0006922550504861709*lm*NH + 
        0.00041580644159409496*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.003494471252580072 - 0.006548888929324883*lm - 
          0.0022364132482917444*lm^2) + CF*(0.00989936577855334 + 
          0.0065468429680333*lm + 0.014638341261545965*lm^2) + 
        0.0004152966077541887*NM + 0.0006731899627518891*lm*NM + 
        0.000406620590598499*lm^2*NM + 0.0014704538682780756*NL + 
        0.0006731899627518891*lm*NL + 0.000406620590598499*lm^2*NL - 
        0.00035161785065614544*NH + 0.0006731899627518891*lm*NH + 
        0.000406620590598499*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.0033868501623778133 - 0.006384041382288972*lm - 
          0.002187069474330789*lm^2) + CF*(0.009665589208662105 + 
          0.006269167419114598*lm + 0.014315363831983344*lm^2) + 
        0.00039506569346569*NM + 0.0006546360754470687*lm*NM + 
        0.00039764899533287066*lm^2*NM + 0.0014341286996692403*NL + 
        0.0006546360754470687*lm*NL + 0.00039764899533287066*lm^2*NL - 
        0.000342159582776808*NH + 0.0006546360754470687*lm*NH + 
        0.00039764899533287066*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.0032823764017699 - 0.006223397193398877*lm - 
          0.0021388761166668503*lm^2) + CF*(0.009437783442806028 + 
          0.00600032237951694*lm + 0.013999916400001202*lm^2) + 
        0.0003756039212729718*NM + 0.0006365802230421776*lm*NM + 
        0.00038888656666670007*lm^2*NM + 0.0013987550146348122*NL + 
        0.0006365802230421776*lm*NL + 0.00038888656666670007*lm^2*NL - 
        0.0003329388742273578*NH + 0.0006365802230421776*lm*NH + 
        0.00038888656666670007*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.003180964100960809 - 0.006066850797767721*lm - 
          0.0020918058177498977*lm^2) + CF*(0.00921580275188089 + 
          0.005740061156640376*lm + 0.013691819897999332*lm^2) + 
        0.0003568848184702984*NM + 0.0006190095425941547*lm*NM + 
        0.0003803283304999814*lm^2*NM + 0.0013643075733492166*NL + 
        0.0006190095425941547*lm*NL + 0.0003803283304999814*lm^2*NL - 
        0.0003239501368125408*NH + 0.0006190095425941547*lm*NH + 
        0.0003803283304999814*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.0030825293739838292 - 0.0059142990611738035*lm - 
          0.0020458318416243563*lm^2) + CF*(0.008999504147425766 + 
          0.005488142873204893*lm + 0.013390899326995788*lm^2) + 
        0.00033888274847155637*NM + 0.0006019114692590223*lm*NM + 
        0.000371969425749883*lm^2*NM + 0.0013307617664993*NL + 
        0.0006019114692590223*lm*NL + 0.000371969425749883*lm^2*NL - 
        0.0003151878951551921*NH + 0.0006019114692590223*lm*NH + 
        0.000371969425749883*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.002986990296810456 - 0.005765641240611961*lm - 
          0.0020009280628079796*lm^2) + CF*(0.008788747387410577 + 
          0.0052443323896445675*lm + 0.01309698368383405*lm^2) + 
        0.0003215728882320012*NM + 0.0005852737316928901*lm*NM + 
        0.0003638051023287236*lm^2*NM + 0.0012980936032522994*NL + 
        0.0005852737316928901*lm*NL + 0.0003638051023287236*lm^2*NL - 
        0.0003066467855313986*NH + 0.0005852737316928901*lm*NH + 
        0.0003638051023287236*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0028942668838328155 - 0.005620778944290361*lm - 
          0.0019570689551447005*lm^2) + CF*(0.008583394977156501 + 
          0.005008400223294458*lm + 0.012809905888219859*lm^2) + 
        0.0003049312060203641*NM + 0.0005690843473581514*lm*NM + 
        0.00035583071911721826*lm^2*NM + 0.0012662796991658829*NL + 
        0.0005690843473581514*lm*NL + 0.00035583071911721826*lm^2*NL - 
        0.00029832155464095804*NH + 0.0005690843473581514*lm*NH + 
        0.00035583071911721826*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.0028042810629012316 - 0.00547961609118387*lm - 
          0.0019142295806514754*lm^2) + CF*(0.00838331216577516 + 
          0.004780122464772531*lm + 0.012529502709718747*lm^2) + 
        0.0002889344395568257*NM + 0.0005533316177504449*lm*NM + 
        0.00034804174193663187*lm^2*NM + 0.001235297264067566*NL + 
        0.0005533316177504449*lm*NL + 0.00034804174193663187*lm^2*NL - 
        0.00029020705831980304*NH + 0.0005533316177504449*lm*NH + 
        0.00034804174193663187*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.002716956649086147 - 0.00534205887024667*lm - 
          0.001872385578377486*lm^2) + CF*(0.008188366938489384 + 
          0.004559280691930601*lm + 0.012255614694834454*lm^2) + 
        0.0002735600745301418*NM + 0.0005380041235608028*lm*NM + 
        0.0003404337415231793*lm^2*NM + 0.001205124089928486*NL + 
        0.0005380041235608028*lm*NL + 0.0003404337415231793*lm^2*NL - 
        0.0002822982602006346*NH + 0.0005380041235608028*lm*NH + 
        0.0003404337415231793*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.0026322193173214715 - 0.005208015699378881*lm - 
          0.0018315131532925044*lm^2) + CF*(0.007998430005176414 + 
          0.004345661881721506*lm + 0.01198808609427821*lm^2) + 
        0.00025878632350515593*NM + 0.0005230907197863244*lm*NM + 
        0.0003330023915077281*lm^2*NM + 0.0011757385387543406*NL + 
        0.0005230907197863244*lm*NL + 0.0003330023915077281*lm^2*NL - 
        0.00027459023032760276*NH + 0.0005230907197863244*lm*NH + 
        0.0003330023915077281*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.0025499965740750394 - 0.005077397184234498*lm - 
          0.001791589065219776*lm^2) + CF*(0.007813374785453736 + 
          0.004139058320304649*lm + 0.011726764790529443*lm^2) + 
        0.000244592105230044*NM + 0.0005085805308016961*lm*NM + 
        0.0003257434664035957*lm^2*NM + 0.0011471195305142671*NL + 
        0.0005085805308016961*lm*NL + 0.0003257434664035957*lm^2*NL - 
        0.0002670781437304931*NH + 0.0005085805308016961*lm*NH + 
        0.0003257434664035957*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.0024702177281811667 - 0.004950116076950988*lm - 
          0.0017525906178274236*lm^2) + CF*(0.007633077390607989 + 
          0.003939267511688393*lm + 0.011471502225779499*lm^2) + 
        0.000230957024350903*NM + 0.0004944629454029247*lm*NM + 
        0.0003186528396049861*lm^2*NM + 0.0011192465311265522*NL + 
        0.0004944629454029247*lm*NL + 0.0003186528396049861*lm^2*NL - 
        0.0002597572789635147*NH + 0.0004944629454029247*lm*NH + 
        0.0003186528396049861*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.0023928138609602455 - 0.004826087234874336*lm - 
          0.0017144956476911*lm^2) + CF*(0.007457416602648807 + 
          0.0037460920851856393*lm + 0.011222153330341746*lm^2) + 
        0.0002178613515396993*NM + 0.0004807276118337569*lm*NM + 
        0.00031172648139838184*lm^2*NM + 0.0010920995405182938*NL + 
        0.0004807276118337569*lm*NL + 0.00031172648139838184*lm^2*NL - 
        0.00025262301661344727*NH + 0.0004807276118337569*lm*NH + 
        0.00031172648139838184*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.002317717795740916 - 0.004705227579347229*lm - 
          0.0016772825134394435*lm^2) + CF*(0.007286273850751833 + 
          0.003559339701938009*lm + 0.010978576451603632*lm^2) + 
        0.000205286004040132*NM + 0.0004673644328044184*lm*NM + 
        0.00030496045698898973*lm^2*NM + 0.0010656590807744941*NL + 
        0.0004673644328044184*lm*NL + 0.00030496045698898973*lm^2*NL - 
        0.0002456708377815818*NH + 0.0004673644328044184*lm*NH + 
        0.00030496045698898973*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.0022448640668915032 - 0.004587456054622329*lm - 
          0.001640930084992773*lm^2) + CF*(0.007119533185338397 + 
          0.0033788229607445114*lm + 0.01074063328358906*lm^2) + 
        0.00019321252663462966*NM + 0.00045436356051151735*lm*NM + 
        0.00029835092454414053*lm^2*NM + 0.0010399061843905392*NL + 
        0.00045436356051151735*lm*NL + 0.00029835092454414053*lm^2*NL - 
        0.0002388963225435879*NH + 0.00045436356051151735*lm*NH + 
        0.00029835092454414053*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.0021741888884591553 - 0.004472693586957208*lm - 
          0.0016054177329044446*lm^2) + CF*(0.006957081250023619 + 
          0.0032043593034121916*lm + 0.010508188797192728*lm^2) + 
        0.00018162307303447772*NM + 0.00044171539166722423*lm*NM + 
        0.0002918941332553536*lm^2*NM + 0.001014822382640588*NL + 
        0.00044171539166722423*lm*NL + 0.0002918941332553536*lm^2*NL - 
        0.0002322951483911532*NH + 0.00044171539166722423*lm*NH + 
        0.0002918941332553536*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.002105630122507349 - 0.004360863043942535*lm - 
          0.0015707253178133223*lm^2) + CF*(0.006798807251649708 + 
          0.003035770919829002*lm + 0.010281111171141746*lm^2) + 
        0.00017050038769395983*NM + 0.0004294105625451466*lm*NM + 
        0.00028558642142060403*lm^2*NM + 0.0009903896940730817*NL + 
        0.0004294105625451466*lm*NL + 0.00028558642142060403*lm^2*NL - 
        0.00022586308865897242*NH + 0.0004294105625451466*lm*NH + 
        0.00028558642142060403*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.002039127247235187 - 0.00425188919411039*lm - 
          0.0015368331800149244*lm^2) + CF*(0.006644602928607144 + 
          0.002872884652942994*lm + 0.010059271723734052*lm^2) + 
        0.00015982778804838596*NM + 0.00041743994404967516*lm*NM + 
        0.0002794242145481681*lm^2*NM + 0.0009665906131433535*NL + 
        0.00041743994404967516*lm*NL + 0.0002794242145481681*lm^2*NL - 
        0.00021959601094040835*NH + 0.00041743994404967516*lm*NH + 
        0.0002794242145481681*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0019746213249551073 - 0.004145698666865229*lm - 
          0.0015037221291579808*lm^2) + CF*(0.006494362517633072 + 
          0.002715531903816769*lm + 0.009842544845397693*lm^2) + 
        0.00014958914717495977*NM + 0.0004057946368149717*lm*NM + 
        0.00027340402348326924*lm^2*NM + 0.0009434080989921737*NL + 
        0.0004057946368149717*lm*NL + 0.00027340402348326924*lm^2*NL - 
        0.00021348987549490777*NH + 0.0004057946368149717*lm*NH + 
        0.00027340402348326924*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.0019120549699992878 - 0.004042219912775914*lm - 
          0.001471373434072356*lm^2) + CF*(0.00634798271926361 + 
          0.002563548536911943*lm + 0.009630807932109966*lm^2) + 
        0.00013976887687460878*NM + 0.0003944659663392079*lm*NM + 
        0.00026752244255861017*lm^2*NM + 0.0009208255643780198*NL + 
        0.0003944659663392079*lm*NL + 0.00026752244255861017*lm^2*NL - 
        0.0002075407336500309*NH + 0.0003944659663392079*lm*NH + 
        0.00026752244255861017*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0018513723166190832 - 0.003941383164263446*lm - 
          0.0014397688127335835*lm^2) + CF*(0.006205362662104888 + 
          0.0024167747857451074*lm + 0.009423941319710728*lm^2) + 
        0.0001303519111721498*NM + 0.0003834454781591362*lm*NM + 
        0.00026177614776974243*lm^2*NM + 0.000898826864769875*NL + 
        0.0003834454781591362*lm*NL + 0.00026177614776974243*lm^2*NL - 
        0.0002017447262007389*NH + 0.0003834454781591362*lm*NH + 
        0.00026177614776974243*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.0017925189869362874 - 0.0038431203967154454*lm - 
          0.0014088904223685849*lm^2) + CF*(0.006066403866076394 + 
          0.002275055159044325*lm + 0.00922182821913983*lm^2) + 
        0.0001213236902314888*NM + 0.000372724933069582*lm*NM + 
        0.00025616189497610633*lm^2*NM + 0.0008773962876064567*NL + 
        0.000372724933069582*lm*NL + 0.00025616189497610633*lm^2*NL - 
        0.00019609808180838604*NH + 0.000372724933069582*lm*NH + 
        0.00025616189497610633*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.0017354420589998389 - 0.003747365290055166*lm - 
          0.001378720849706532*lm^2) + CF*(0.005931010204769584 + 
          0.002138238347523605*lm + 0.009024354652624572*lm^2) + 
        0.00011267014468195059*NM + 0.0003622963023919898*lm*NM + 
        0.00025067651812846035*lm^2*NM + 0.0008565185417269403*NL + 
        0.0003622963023919898*lm*NL + 0.00025067651812846035*lm^2*NL - 
        0.00019059711540167347*NH + 0.0003622963023919898*lm*NH + 
        0.00025067651812846035*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.0016800900349967498 - 0.00365405319078971*lm - 
          0.0013492431013782378*lm^2) + CF*(0.005799087867054706 + 
          0.002006177131381926*lm + 0.008831409390839375*lm^2) + 
        0.00010437768035129411*NM + 0.00035215176329572695*lm*NM + 
        0.000245316927523316*lm^2*NM + 0.0008361787469774711*NL + 
        0.00035215176329572695*lm*NL + 0.000245316927523316*lm^2*NL - 
        0.00018523822658164622*NH + 0.00035215176329572695*lm*NH + 
        0.000245316927523316*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0016264128096615369 - 0.003563121074559264*lm - 
          0.0013204405944669338*lm^2) + CF*(0.005670545318059401 + 
          0.0018787282886232434*lm + 0.008642883891056293*lm^2) + 
        0.00009643316340049138*NM + 0.0003422836941754518*lm*NM + 
        0.00024008010808489704*lm^2*NM + 0.0008163624239970441*NL + 
        0.0003422836941754518*lm*NL + 0.00024008010808489704*lm^2*NL - 
        0.00018001789803264782*NH + 0.0003422836941754518*lm*NH + 
        0.00024008010808489704*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.001574361638924228 - 0.0034745075092065237*lm - 
          0.0012922971472127973*lm^2) + CF*(0.005545293259633677 + 
          0.001755752504284465*lm + 0.008458672236301945*lm^2) + 
        0.00008882390585492457*NM + 0.00033268467008748103*lm*NM + 
        0.00023496311767505406*lm^2*NM + 0.0007970554841856769*NL + 
        0.00033268467008748103*lm*NL + 0.00023496311767505406*lm^2*NL - 
        0.00017493269394099157*NH + 0.00033268467008748103*lm*NH + 
        0.00023496311767505406*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0015238891088331106 - 0.0033881526183829904*lm - 
          0.0012647969698731478*lm^2) + CF*(0.005423244590407571 + 
          0.0016371142806495289*lm + 0.008278671075533331*lm^2) + 
        0.00008153765152628483*NM + 0.0003233474582477492*lm*NM + 
        0.0002299630854314814*lm^2*NM + 0.0007782442198571961*NL + 
        0.0003233474582477492*lm*NL + 0.0002299630854314814*lm^2*NL - 
        0.00016997925842296047*NH + 0.0003233474582477492*lm*NH + 
        0.0002299630854314814*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0014749491047847429 - 0.003303998045706538*lm - 
          0.0012379246557398045*lm^2) + CF*(0.005304314365539851 + 
          0.0015226818485195234*lm + 0.008102779564842358*lm^2) + 
        0.00007456256231913269*NM + 0.0003142650135936307*lm*NM + 
        0.00022507721013450993*lm^2*NM + 0.0007599152945784053*NL + 
        0.0003142650135936307*lm*NL + 0.00022507721013450993*lm^2*NL - 
        0.0001651543139636102*NH + 0.0003142650135936307*lm*NH + 
        0.00022507721013450993*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0014274967810903635 - 0.0032219869194825288*lm - 
          0.0012116651723147224*lm^2) + CF*(0.005188419756248761 + 
          0.0014123270796011001*lm + 0.007930899309696366*lm^2) + 
        0.00006788720491580004*NM + 0.00030543047441159837*lm*NM + 
        0.00022030275860267682*lm^2*NM + 0.0007420557336958902*NL + 
        0.00030543047441159837*lm*NL + 0.00022030275860267682*lm^2*NL - 
        0.00016045465986772094*NH + 0.00030543047441159837*lm*NH + 
        0.00022030275860267682*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.00138148853090469 - 0.003142063817998776*lm - 
          0.0011860038526446631*lm^2) + CF*(0.005075480009208776 + 
          0.0013059254000683243*lm + 0.007762934308219614*lm^2) + 
        0.0000615005378330746*NM + 0.00029683715803241733*lm*NM + 
        0.00021563706411721148*lm^2*NM + 0.0007246529150512568*NL + 
        0.00029683715803241733*lm*NL + 0.00021563706411721148*lm^2*NL - 
        0.00015587717072412203*NH + 0.00029683715803241733*lm*NH + 
        0.00021563706411721148*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0013368819565401685 - 0.0030641747354028556*lm - 
          0.0011609263868153383*lm^2) + CF*(0.004965416405890821 + 
          0.001203355705346462*lm + 0.007598790895518577*lm^2) + 
        0.00005539189884390569*NM + 0.0002884785565953169*lm*NM + 
        0.00021107752487551604*lm^2*NM + 0.0007076945598851661*NL + 
        0.0002884785565953169*lm*NL + 0.00021107752487551604*lm^2*NL - 
        0.0001514187948845004*NH + 0.0002884785565953169*lm*NH + 
        0.00021107752487551604*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.0012936358401870283 - 0.0029882670481685644*lm - 
          0.0011364188136051582*lm^2) + CF*(0.004858152221917217 + 
          0.0011045002761600573*lm + 0.007438377689051945*lm^2) + 
        0.00004955099275720187*NM + 0.000280348332882347*lm*NM + 
        0.00020662160247366513*lm^2*NM + 0.0006911687239301464*NL + 
        0.000280348332882347*lm*NL + 0.00020662160247366513*lm^2*NL - 
        0.00014707655295769732*NH + 0.000280348332882347*lm*NH + 
        0.00020662160247366513*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.0012517101150569805 - 0.002914289482156788*lm - 
          0.0011124675122984545*lm^2) + CF*(0.0047536126864968385 + 
          0.0010092446958819275*lm + 0.007281605535044429*lm^2) + 
        0.00004396787954865554*NM + 0.00027244031622390593*lm*NM + 
        0.00020226682041790082*lm^2*NM + 0.0006750637886918056*NL + 
        0.00027244031622390593*lm*NL + 0.00020226682041790082*lm^2*NL - 
        0.0001428475363203986*NH + 0.00027244031622390593*lm*NH + 
        0.00020226682041790082*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.001211065836966065 - 0.002842192080274609*lm - 
          0.0010890591946577848*lm^2) + CF*(0.004651724942000523 + 
          0.0009174777692144073*lm + 0.007128387455941864*lm^2) + 
        0.0000386329628354207*NM + 0.00026474849847622664*lm*NM + 
        0.00019801076266505178*lm^2*NM + 0.0006593684529177471*NL + 
        0.00026474849847622664*lm*NL + 0.00019801076266505178*lm^2*NL - 
        0.00013872890564502985*NH + 0.00026474849847622664*lm*NH + 
        0.00019801076266505178*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.001171665156370001 - 0.0027719261707351652*lm - 
          0.0010661808970547125*lm^2) + CF*(0.004552418003731699 + 
          0.0008290914422292621*lm + 0.006978638598903573*lm^2) + 
        0.000033536978687389525*NM + 0.00025726703007141887*lm*NM + 
        0.00019385107219176592*lm^2*NM + 0.0006440717242532019*NL + 
        0.00025726703007141887*lm*NL + 0.00019385107219176592*lm^2*NL - 
        0.0001347178894455817*NH + 0.00025726703007141887*lm*NH + 
        0.00019385107219176592*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.001133471290863399 - 0.0027034443359195697*lm - 
          0.0010438199727582362*lm^2) + CF*(0.004455622719942385 + 
          0.0007439807237881395*lm + 0.006832276185326638*lm^2) + 
        0.000028670984767755603*NM + 0.00024999021614049516*lm*NM + 
        0.00018978544959240658*lm^2*NM + 0.0006291629110821239*NL + 
        0.00024999021614049516*lm*NL + 0.00018978544959240658*lm^2*NL - 
        0.00013081178264200862*NH + 0.00024999021614049516*lm*NH + 
        0.00018978544959240658*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.0010964484981523504 - 0.002636700381841085*lm - 
          0.0010219640843798625*lm^2) + CF*(0.004361271732140261 + 
          0.0006620436083612359*lm + 0.006689219461395462*lm^2) + 
        0.000024026349795516124*NM + 0.00024291251270965055*lm*NM + 
        0.00018581165170542953*lm^2*NM + 0.0006146316145522581*NL + 
        0.00024291251270965055*lm*NL + 0.00018581165170542953*lm^2*NL - 
        0.000127007945143768*NH + 0.00024291251270965055*lm*NH + 
        0.00018581165170542953*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0010605620495082162 - 0.0025716493082107335*lm - 
          0.0010006011964741413*lm^2) + CF*(0.004269299435728305 + 
          0.0005831810002579634*lm + 0.006549389649648924*lm^2) + 
        0.000019594743322549724*NM + 0.0002360285229699189*lm*NM + 
        0.00018192749026802566*lm^2*NM + 0.0006004677207824814*NL + 
        0.0002360285229699189*lm*NL + 0.00018192749026802566*lm^2*NL - 
        0.00012330380045299684*NH + 0.0002360285229699189*lm*NH + 
        0.00018192749026802566*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0010257782037088703 - 0.002508247279102601*lm - 
          0.0009797195682933334*lm^2) + CF*(0.004179641941014569 + 
          0.0005072966392798348*lm + 0.006412709901556364*lm^2) + 
        0.000015368125817908927*NM + 0.00022933299362019747*lm*NM + 
        0.0001781308305987879*lm^2*NM + 0.0005866613932505202*NL + 
        0.00022933299362019747*lm*NL + 0.0001781308305987879*lm^2*NL - 
        0.00011969683428775574*NH + 0.00022933299362019747*lm*NH + 
        0.0001781308305987879*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0009920641814722083 - 0.0024464515942162314*lm - 
          0.0009593077466947353*lm^2) + CF*(0.004092237034625985 + 
          0.0004342970278024835*lm + 0.0062791052510928124*lm^2) + 
        0.000011338739051984793*NM + 0.0002228208112835083*lm*NM + 
        0.00017441959030813369*lm^2*NM + 0.0005732030653589822*NL + 
        0.0002228208112835083*lm*NL + 0.00017441959030813369*lm^2*NL - 
        0.00011618459322570884*NH + 0.0002228208112835083*lm*NH + 
        0.00017441959030813369*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.00095938814038542 - 0.0023862206607327503*lm - 
          0.000939354559199065*lm^2) + CF*(0.004007024141356684 + 
          0.00036409135929070654*lm + 0.00614850256930297*lm^2) + 
        7.499096773234742*^-6*NM + 0.0002164869989962536*lm*NM + 
        0.00017079173803619363*lm^2*NM + 0.0005600834331774859*NL + 
        0.0002164869989962536*lm*NL + 0.00017079173803619363*lm^2*NL - 
        0.0001127646833685514*NH + 0.0002164869989962536*lm*NH + 
        0.00017079173803619363*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.0009277191503322968 - 0.002327513965760655*lm - 
          0.0009198491071982058*lm^2) + CF*(0.003923944286478067 + 
          0.0002965914482476383*lm + 0.006020830519842801*lm^2) + 
        3.841975670211085*^-6*NM + 0.00021032671277012102*lm*NM + 
        0.0001672452922178556*lm^2*NM + 0.0005472934483585422*NL + 
        0.00021032671277012102*lm*NL + 0.0001672452922178556*lm^2*NL - 
        0.00010943476902744235*NH + 0.00021032671277012102*lm*NH + 
        0.0001672452922178556*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.0008970271694197422 - 0.0022702920493665618*lm - 
          0.0009007807593104971*lm^2) + CF*(0.0038429400585349295 + 
          0.00023171166159661224*lm + 0.00589601951548689*lm^2) + 
        3.604066116863363*^-7*NM + 0.000204335238226202*lm*NM + 
        0.00016377831987463584*lm^2*NM + 0.0005348243112247208*NL + 
        0.000204335238226202*lm*NL + 0.00016377831987463584*lm^2*NL - 
        0.00010619257142965066*NH + 0.000204335238226202*lm*NH + 
        0.00016377831987463584*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.0008672830204036342 - 0.0022145164781856436*lm - 
          0.0008821391448816822*lm^2) + CF*(0.0037639555726490933 + 
          0.00016936885149193554*lm + 0.005774001675589192*lm^2) - 
        2.9523338422596366*^-6*NM + 0.00019850798730080212*lm*NM + 
        0.0001603889354330331*lm^2*NM + 0.0005226674640245374*NL + 
        0.00019850798730080212*lm*NL + 0.0001603889354330331*lm^2*NL - 
        0.0001030358674465772*NH + 0.00019850798730080212*lm*NH + 
        0.0001603889354330331*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0008384583676132551 - 0.0021601498196059618*lm - 
          0.0008639141476295411*lm^2) + CF*(0.003686936434349447 + 
          0.00010948228955267207*lm + 0.0056547107844842695*lm^2) - 
        6.102731665246968*^-6*NM + 0.00019284049502234715*lm*NM + 
        0.0001570752995690075*lm^2*NM + 0.0005108145843544065*NL + 
        0.00019284049502234715*lm*NL + 0.0001570752995690075*lm^2*NL - 
        0.00009996248834327192*NH + 0.00019284049502234715*lm*NH + 
        0.0001570752995690075*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.0008105256943726646 - 0.0021071556165204474*lm - 
          0.000846095899430174*lm^2) + CF*(0.003611829703944857 + 
          0.000051973602511589827*lm + 0.005538082250815685*lm^2) - 
        9.09704333266718*^-6*NM + 0.00018732841635871875*lm*NM + 
        0.00015383561807821345*lm^2*NM + 0.0004992575787439322*NL + 
        0.00018732841635871875*lm*NL + 0.00015383561807821345*lm^2*NL - 
        0.00009697031854952637*NH + 0.00018732841635871875*lm*NH + 
        0.00015383561807821345*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.0007834582809166186 - 0.0020554983626398624*lm - 
          0.0008286747742438378*lm^2) + CF*(0.003538583861454156 - 
          3.2332907303341605*^-6*lm + 0.005424053067777847*lm^2) - 
        0.000011941303539693876*NM + 0.00018196752313429348*lm*NM + 
        0.00015066814077160687*lm^2*NM + 0.0004879885764017471*NL + 
        0.00018196752313429348*lm*NL + 0.00015066814077160687*lm^2*NL - 
        0.00009405729445258438*NH + 0.00018196752313429348*lm*NH + 
        0.00015066814077160687*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.0007572301827979405 - 0.00200514347835971*lm - 
          0.0008116413821781945*lm^2) + CF*(0.003467148772105342 - 
          0.00005621224065505578*lm + 0.005312561774257273*lm^2) - 
        0.000014641332676007372*NM + 0.0001767537010159023*lm*NM + 
        0.00014757116039603536*lm^2*NM + 0.000476999923119056*NL + 
        0.0001767537010159023*lm*NL + 0.00014757116039603536*lm^2*NL - 
        0.000091221403211481*NH + 0.0001767537010159023*lm*NH + 
        0.00014757116039603536*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.000731816209782621 - 0.0019560572871737455*lm - 
          0.0007949865636867844*lm^2) + CF*(0.0033974756524141605 - 
          0.00010703492729690015*lm + 0.005203548416858952*lm^2) - 
        0.0000172027440639016*NM + 0.00017168294656687966*lm*NM + 
        0.00014454301157941534*lm^2*NM + 0.0004662841753280013*NL + 
        0.00017168294656687966*lm*NL + 0.00014454301157941534*lm^2*NL - 
        0.0000884606815929875*NH + 0.00017168294656687966*lm*NH + 
        0.00014454301157941534*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.0007071919052283533 - 0.0019082069926264387*lm - 
          0.000778701383900505*lm^2) + CF*(0.003329517036850461 - 
          0.00015577091904423956*lm + 0.005096954512803306*lm^2) - 
        0.000019630950966330615*NM + 0.00016675136436832653*lm*NM + 
        0.00014158206980009183*lm^2*NM + 0.00045583409431193414*NL + 
        0.00016675136436832653*lm*NL + 0.00014158206980009183*lm^2*NL - 
        0.00008577321482911227*NH + 0.00016675136436832653*lm*NH + 
        0.00014158206980009183*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.0006833335259417025 - 0.0018615606557965132*lm - 
          0.0007627771270898474*lm^2) + CF*(0.0032632267450990395 - 
          0.00020248773008852653*lm + 0.004992723013679002*lm^2) - 
        0.000021931173371336825*NM + 0.0001619551642066741*lm*NM + 
        0.00013868675037997225*lm^2*NM + 0.0004456426405646517*NL + 
        0.0001619551642066741*lm*NL + 0.00013868675037997225*lm^2*NL - 
        0.00008315713549608038*NH + 0.0001619551642066741*lm*NH + 
        0.00013868675037997225*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.0006602180225086455 - 0.0018160871733034587*lm - 
          0.0007472052912556215*lm^2) + CF*(0.0031985598499201383 - 
          0.0002472508765368358*lm + 0.004890798270036796*lm^2) - 
        0.000024108444559184492*NM + 0.0001572906583266007*lm*NM + 
        0.0001358555075010221*lm^2*NM + 0.0004357029682956449*NL + 
        0.0001572906583266007*lm*NL + 0.0001358555075010221*lm^2*NL - 
        0.00008061062241469073*NH + 0.0001572906583266007*lm*NH + 
        0.0001358555075010221*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.000637823020092818 - 0.001771756255828736*lm - 
          0.0007319775828458847*lm^2) + CF*(0.0031354726456133564 - 
          0.0002901239312049963*lm + 0.004791125996809427*lm^2) - 
        0.00002616761745840057*NM + 0.00015275425874832578*lm*NM + 
        0.0001330868332447063*lm^2*NM + 0.00042600842007839234*NL + 
        0.00015275425874832578*lm*NL + 0.0001330868332447063*lm^2*NL - 
        0.00007813189957192727*NH + 0.00015275425874832578*lm*NH + 
        0.0001330868332447063*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.0006161267996954364 - 0.0017285384071432483*lm - 
          0.0007170859115967771*lm^2) + CF*(0.003073922617087406 - 
          0.00033116857710920944*lm + 0.004693653239542541*lm^2) - 
        0.000028113370796801327*NM + 0.00014834247464827854*lm*NM + 
        0.00013037925665395947*lm^2*NM + 0.00041655252163873356*NL + 
        0.00014834247464827854*lm*NL + 0.00013037925665395947*lm^2*NL - 
        0.00007571923506368051*NH + 0.00014834247464827854*lm*NH + 
        0.00013037925665395947*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.0005951082798705509 - 0.0016864049036325183*lm - 
          0.0007025223854949627*lm^2) + CF*(0.0030138684095369294 - 
          0.0003704446596747712*lm + 0.004598328341421575*lm^2) - 
        0.000029950215053457524*NM + 0.00014405190980211938*lm*NM + 
        0.00012773134281726596*lm^2*NM + 0.000407328976780358*NL + 
        0.00014405190980211938*lm*NL + 0.00012773134281726596*lm^2*NL - 
        0.00007337094005841666*NH + 0.00014405190980211938*lm*NH + 
        0.00012773134281726596*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.0005747469988890017 - 0.0016453277743109153*lm - 
          0.0006882793058593701*lm^2) + CF*(0.002955269798726496 - 
          0.0004080102376811365*lm + 0.004505100911079514*lm^2) - 
        0.00003168249821742423*NM + 0.0001398792600890725*lm*NM + 
        0.00012514169197443093*lm^2*NM + 0.0003983316624444557*NL + 
        0.0001398792600890725*lm*NL + 0.00012514169197443093*lm^2*NL - 
        0.00007108536778161532*NH + 0.0001398792600890725*lm*NH + 
        0.00012514169197443093*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.0005550230973442132 - 0.0016052797813162027*lm - 
          0.0006743491625399331*lm^2) + CF*(0.002898087661880864 - 
          0.000443921632963107*lm + 0.0044139217911704715*lm^2) - 
        0.00003331441135893358*NM + 0.00013582131105651515*lm*NM + 
        0.00012260893864362421*lm^2*NM + 0.00038955462390058876*NL + 
        0.00013582131105651515*lm*NL + 0.00012260893864362421*lm^2*NL - 
        0.00006886091252078107*NH + 0.00013582131105651515*lm*NH + 
        0.00012260893864362421*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.0005359173011927501 - 0.0015662344008756134*lm - 
          0.0006607246292310331*lm^2) + CF*(0.002842283949179653 - 
          0.0004782334788883807*lm + 0.004324743027694034*lm^2) - 
        0.000034849994018620315*NM + 0.00013187493554375678*lm*NM + 
        0.00012013175076927874*lm^2*NM + 0.0003809920700658603*NL + 
        0.00013187493554375678*lm*NL + 0.00012013175076927874*lm^2*NL - 
        0.00006669600865082042*NH + 0.00013187493554375678*lm*NH + 
        0.00012013175076927874*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.000517410905222384 - 0.0015281658047346287*lm - 
          0.000647398558897358*lm^2) + CF*(0.0027878216558537205 - 
          0.0005109987676320868*lm + 0.004237517840055434*lm^2) - 
        0.0000362931394202219*NM + 0.0001280370913639323*lm*NM + 
        0.00011770882889042873*lm^2*NM + 0.00037263836894948176*NL + 
        0.0001280370913639323*lm*NL + 0.00011770882889042873*lm^2*NL - 
        0.00006458912967956301*NH + 0.0001280370913639323*lm*NH + 
        0.00011770882889042873*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.0004994857569402697 - 0.0014910488420396186*lm - 
          0.0006343639793099017*lm^2) + CF*(0.002734664794879762 - 
          0.0005422688962692483*lm + 0.00415220059184663*lm^2) - 
        0.000037647599512066076*NM + 0.00012430481904292858*lm*NM + 
        0.00011533890532907305*lm^2*NM + 0.0003644880432198616*NL + 
        0.00012430481904292858*lm*NL + 0.00011533890532907305*lm^2*NL - 
        0.00006253878731319529*NH + 0.00012430481904292858*lm*NH + 
        0.00011533890532907305*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.0004821242408737134 - 0.0014548590216654968*lm - 
          0.0006216140886898444*lm^2) + CF*(0.002682778370268919 - 
          0.0005720937117063676*lm + 0.004068746762333526*lm^2) - 
        0.00003891698984253131*NM + 0.00012067523961425862*lm*NM + 
        0.00011302074339815351*lm^2*NM + 0.0003565357658913707*NL + 
        0.00012067523961425862*lm*NL + 0.00011302074339815351*lm^2*NL - 
        0.00006054353054136405*NH + 0.00012067523961425862*lm*NH + 
        0.00011302074339815351*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.0004653092632759126 - 0.0014195724949795587*lm - 
          0.0006091422514580699*lm^2) + CF*(0.002632128350944557 - 
          0.0006005215544735271*lm + 0.003987112918634639*lm^2) - 
        0.000040104794274538014*NM + 0.00011714555246879615*lm*NM + 
        0.00011075313662873997*lm^2*NM + 0.0003487763561279691*NL + 
        0.00011714555246879615*lm*NL + 0.00011075313662873997*lm^2*NL - 
        0.000058601944741699155*NH + 0.00011714555246879615*lm*NH + 
        0.00011075313662873997*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.0004490242372289793 - 0.0013851660390326926*lm - 
          0.0005969419940880996*lm^2) + CF*(0.0025826816452037813 - 
          0.00062759930139854*lm + 0.003907256688576652*lm^2) - 
        0.000041214369544001996*NM + 0.00011371303325828468*lm*NM + 
        0.00010853490801601812*lm^2*NM + 0.0003412047751609133*NL + 
        0.00011371303325828468*lm*NL + 0.00010853490801601812*lm^2*NL - 
        0.00005671265080349643*NH + 0.00011371303325828468*lm*NH + 
        0.00010853490801601812*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.00043325306813650125 - 0.0013516170401692046*lm - 
          0.0005850070010602383*lm^2) + CF*(0.0025344060757567237 - 
          0.0006533724071847787*lm + 0.003829136734212469*lm^2) - 
        0.000042248949667056405*NM + 0.00011037503185153577*lm*NM + 
        0.00010636490928367968*lm^2*NM + 0.00033381612231780087*NL + 
        0.00011037503185153577*lm*NL + 0.00010636490928367968*lm^2*NL - 
        0.00005487430427029499*NH + 0.00011037503185153577*lm*NH + 
        0.00010636490928367968*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.0004179801395978622 - 0.0013189034780465337*lm - 
          0.0005733311109147542*lm^2) + CF*(0.002487270355337173 - 
          0.000677884944914358*lm + 0.003752712725987482*lm^2) - 
        0.00004321165020072433*NM + 0.00010712897034223656*lm*NM + 
        0.00010424202016631894*lm^2*NM + 0.0003266056311602455*NL + 
        0.00010712897034223656*lm*NL + 0.00010424202016631894*lm^2*NL - 
        0.00005308559450107751*NH + 0.00010712897034223656*lm*NH + 
        0.00010424202016631894*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.00040319029965652756 - 0.0012870039100562056*lm - 
          0.000561908312401942*lm^2) + CF*(0.0024412440628776865 - 
          0.0007011796454983562*lm + 0.0036779453175399836*lm^2) - 
        0.000044105472361601425*NM + 0.00010397234110729048*lm*NM + 
        0.000102165147709444*lm^2*NM + 0.00031956866572751733*NL + 
        0.00010397234110729048*lm*NL + 0.000102165147709444*lm^2*NL - 
        0.0000513452438498165*NH + 0.00010397234110729048*lm*NH + 
        0.000102165147709444*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.00038886884741449763 - 0.0012558974561374385*lm - 
          0.0005507327407269384*lm^2) + CF*(0.0023962976202419463 - 
          0.0007232979360957248*lm + 0.003604796121121779*lm^2) - 
        0.0000449333070069871*NM + 0.0001009027049146229*lm*NM + 
        0.00010013322558671608*lm^2*NM + 0.000312700716883524*NL + 
        0.0001009027049146229*lm*NL + 0.00010013322558671608*lm^2*NL - 
        0.00004965200686308582*NH + 0.0001009027049146229*lm*NH + 
        0.00010013322558671608*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.0003750015200051468 - 0.0012255637839748952*lm - 
          0.0005397986738871943*lm^2) + CF*(0.002352402269506798 - 
          0.0007442799775224767*lm + 0.0035332276836252717*lm^2) - 
        0.00004569793848278317*NM + 0.00009791768907939056*lm*NM + 
        0.00009814521343403533*lm^2*NM + 0.00030599739876455075*NL + 
        0.00009791768907939056*lm*NL + 0.00009814521343403533*lm^2*NL - 
        0.00004800466949545246*NH + 0.00009791768907939056*lm*NH + 
        0.00009814521343403533*lm^2*NH)}, 
     {1., 8.026052688005851*^-20*CF*NC*
       (-1.*CA*(4.505010046308691*^15 + 1.490126144274432*^16*lm + 
          6.592288260096*^15*lm^2) + 
        2.*(9.*CF*(1.5986342232142902*^15 - 5.2894736842752*^14*lm + 
            2.397195730944*^15*lm^2) + 315.*(-9.176870355952709*^11 + 
            1.879098523648*^12*lm + 1.9025362944*^12*lm^2)*NM + 
          1.865515073011712*^15*NL + 5.9191603494912*^14*lm*NL + 
          5.99298932736*^14*lm^2*NL - 2.890714162125103*^14*NH + 
          5.9191603494912*^14*lm*NH + 5.99298932736*^14*lm^2*NH))}}

CbarSeries["a", 2, -1, "x0"] = SeriesData[x, 0, 
     {(CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 391*Pi^4 + 
           20*Pi^2*(-73 + 96*Log[2]^2) + 15*(869 + 936*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 144*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             128*Log[2]^4 - 156*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
             2712*Zeta[3]) - 10*lm*(-1233 + 44*Pi^2 + 648*Zeta[3])) + 
         2*(CF*(5670*lm^2 - 3240*lm^3 + 981*Pi^4 + 10*Pi^2*(259 + 576*
                Log[2]^2) + 15*(1025 + 2808*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 432*Im[PolyLog[2, (-1)^(1/3)]]^2 - 384*
                Log[2]^4 - 468*PolyGamma[2, 1] - 9216*PolyLog[4, 1/2] - 10464*
                Zeta[3]) + 135*lm*(95 + 8*Pi^2 - 144*Zeta[3])) - 
           15*(NL*(-219 - 162*lm - 84*lm^2 - 24*lm^3 + 28*Pi^2 + 8*lm*Pi^2 - 
               288*Zeta[3]) + NM*(-219 - 84*lm^2 - 24*lm^3 + 28*Pi^2 + 2*lm*
                (-81 + 4*Pi^2) + 8*PolyGamma[2, 1] - 272*Zeta[3]) - 
             NH*(-837 + 162*lm + 84*lm^2 + 24*lm^3 - 8*lm*Pi^2 - 1296*
                Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 216*PolyGamma[2, 1] + 
               2928*Zeta[3])))))/25920, 
      (CF*NC*(-3*CA*(18240*lm^2 + 2640*lm^3 + 647*Pi^4 + 
           30*Pi^2*(5 + 128*Log[2]^2) + 30*(2255 + 216*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 216*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             128*Log[2]^4 - 36*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 
             1540*Zeta[3]) - 180*lm*(-275 + 72*Zeta[3])) + 
         2*(CF*(1620*lm^2 - 6480*lm^3 + 1941*Pi^4 + 10*Pi^2*(59 + 1152*
                Log[2]^2) + 15*(1207 + 1296*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] - 1296*Im[PolyLog[2, (-1)^(1/3)]]^2 - 768*
                Log[2]^4 - 216*PolyGamma[2, 1] - 18432*PolyLog[4, 1/2] - 
               11784*Zeta[3]) - 270*lm*(-41 + 144*Zeta[3])) - 
           180*(NM*(-82 - 57*lm - 20*lm^2 - 4*lm^3 + 2*Pi^2 - 32*Zeta[3]) + 
             NL*(-82 - 57*lm - 20*lm^2 - 4*lm^3 + 2*Pi^2 - 32*Zeta[3]) - 
             NH*(178 + 57*lm + 20*lm^2 + 4*lm^3 - 216*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 36*PolyGamma[2, 1] + 200*
                Zeta[3])))))/25920, 
      (CF*NC*(-3*CA*(7140*lm^2 + 1320*lm^3 + 236*Pi^4 + 
           30*Pi^2*(51 + 64*Log[2]^2) + 15*(1523 + 1224*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 128*Log[2]^4 - 
             300*PolyGamma[2, 1] - 3072*PolyLog[4, 1/2] - 3968*Zeta[3]) + 
           10*lm*(1497 + 44*Pi^2 - 648*Zeta[3])) + 
         10*(CF*(1134*lm^2 - 648*lm^3 + 180*Pi^4 + 8*Pi^2*(-17 + 144*
                Log[2]^2) + 3*(1643 + 3672*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] - 384*Log[2]^4 - 900*PolyGamma[2, 1] - 9216*
                PolyLog[4, 1/2] - 13560*Zeta[3]) - 27*lm*(-47 + 8*Pi^2 + 144*
                Zeta[3])) + 3*(NM*(-1773 + 84*lm^2 + 24*lm^3 + 140*Pi^2 + lm*
                (210 + 8*Pi^2) - 40*PolyGamma[2, 1] + 16*Zeta[3]) + 
             NL*(387 + 210*lm + 84*lm^2 + 24*lm^3 - 4*Pi^2 + 8*lm*Pi^2 + 96*
                Zeta[3]) + NH*(339 + 210*lm + 84*lm^2 + 24*lm^3 + 8*lm*
                Pi^2 - 3888*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 792*
                PolyGamma[2, 1] + 6768*Zeta[3])))))/25920, 
      -(CF*NC*(-34875*CF + 82080*NM - 4320*NL - 351200*NH - 4380*CF*Pi^2 - 
          7200*NM*Pi^2 + 1440*NL*Pi^2 + 6300*Sqrt[3]*CF*Pi^3 + 
          8400*Sqrt[3]*NH*Pi^3 + 648*CF*Pi^4 - 64800*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 120960*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 51840*CF*Im[PolyLog[2, (-1)^(1/3)]]^
            2 + 233280*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          311040*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          4860*Sqrt[3]*CF*Pi*Log[3]^2 + 6480*Sqrt[3]*NH*Pi*Log[3]^2 - 
          2880*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
            4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          11520*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          25920*CF*PolyGamma[2, 1] + 1440*NM*PolyGamma[2, 1] - 
          24480*NH*PolyGamma[2, 1] - 34560*CF*Zeta[3] - 83520*NM*Zeta[3] + 
          17280*NL*Zeta[3] - 198720*NH*Zeta[3] - 
          6*CA*(-430*Pi^2 + 525*Sqrt[3]*Pi^3 + 54*Pi^4 + 405*Sqrt[3]*Pi*
             Log[3]^2 - 120*(22 + 45*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              36*Im[PolyLog[2, (-1)^(1/3)]]^2 - 162*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 18*PolyGamma[2, 1] + 
              21*Zeta[3])) - 120*Log[x]*(-3*CA*(608*lm + 132*lm^2 + 
              3*(241 - 9*Pi^2 + 36*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                96*Zeta[3])) + 2*(135*NL + 120*lm*NL + 36*lm^2*NL - 
              889*NH + 120*lm*NH + 36*lm^2*NH - 12*NL*Pi^2 + 
              3*NM*(189 + 40*lm + 12*lm^2 - 4*Pi^2) + 432*Sqrt[3]*NH*Im[
                PolyLog[2, (-1)^(1/3)]] - 3*CF*(60 - 18*lm + 108*lm^2 + 
                29*Pi^2 - 108*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                288*Zeta[3])))))/25920, 
      -(CF*NC*(-25083*CF - 3888*CF*lm - 21336*NM + 432*lm*NM - 504*NL + 
          432*lm*NL - 72184*NH + 432*lm*NH + 1728*CF*Pi^2 - 
          1632*NM*Pi^2 + 96*NL*Pi^2 + 980*Sqrt[3]*CF*Pi^3 + 
          1680*Sqrt[3]*NH*Pi^3 - 54864*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 65664*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 36288*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 62208*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 756*Sqrt[3]*CF*Pi*
           Log[3]^2 + 1296*Sqrt[3]*NH*Pi*Log[3]^2 - 
          576*(9*CF*(-1 + 12*lm) + 2*CA*(76 + 33*lm) - 
            4*(2*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          2304*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          15552*CF*PolyGamma[2, 1] - 3456*NM*PolyGamma[2, 1] - 
          16128*NH*PolyGamma[2, 1] + 109152*CF*Zeta[3] - 3456*NM*Zeta[3] + 
          3456*NL*Zeta[3] - 122112*NH*Zeta[3] - 
          2*CA*(1188*lm + 57*Pi^2 + 245*Sqrt[3]*Pi^3 + 189*Sqrt[3]*Pi*
             Log[3]^2 - 36*(381*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              4*(-4 + 63*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                27*PolyGamma[2, 1] + 179*Zeta[3]))) - 
          24*Log[x]*(3*CA*(-687 - 608*lm - 132*lm^2 + 61*Pi^2 - 
              84*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3]) + 
            2*(135*NL + 120*lm*NL + 36*lm^2*NL - 889*NH + 120*lm*NH + 
              36*lm^2*NH - 12*NL*Pi^2 + 3*NM*(-47 + 40*lm + 12*lm^2 + 
                20*Pi^2) + 432*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] - 
              3*CF*(165 - 18*lm + 108*lm^2 + 71*Pi^2 - 84*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 288*Zeta[3])))))/10368, 
      -(CF*NC*(-259200*(15*CA*(53 + 22*lm) + 2*(30*CF*(-2 + 9*lm) - 130*NM - 
              30*lm*NM - 45*NL - 30*lm*NL - 8*NH - 30*lm*NH))*Log[x]^2 + 
          5184000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 - 
          1080*Log[x]*(8*(25*NL*(3 + 40*lm + 12*lm^2 - 8*Pi^2) + 
              25*NM*(217 + 40*lm + 12*lm^2 + 16*Pi^2) + NH*(-14923 + 
                1000*lm + 300*lm^2 + 8000*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) - 50*CF*(1317 - 72*lm + 432*lm^2 + 
              98*Pi^2 - 792*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1152*Zeta[3]) + 25*CA*(-1851 - 2432*lm - 528*lm^2 + 106*Pi^2 - 
              792*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1152*Zeta[3])) - 
          225*CA*(-560*Pi^2 + 7700*Sqrt[3]*Pi^3 + 432*Pi^4 + 
            5940*Sqrt[3]*Pi*Log[3]^2 + 15*(-10411 - 4560*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              19008*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              2304*PolyGamma[2, 1] + 1216*Zeta[3])) + 
          2*(16*(2*NH*(87500*Sqrt[3]*Pi^3 + 67500*Sqrt[3]*Pi*Log[3]^2 + 
                9*(-324269 + 72000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                  360000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                  18750*PolyGamma[2, 1] - 175500*Zeta[3])) + 4500*NM*(-82 + 
                12*Pi^2 - 21*PolyGamma[2, 1] - 402*Zeta[3]) + 
              3375*NL*(-75 + 4*Pi^2 + 96*Zeta[3])) + 
            225*CF*(72*Pi^2 + 7700*Sqrt[3]*Pi^3 + 432*Pi^4 + 
              5940*Sqrt[3]*Pi*Log[3]^2 + 15*(-10821 - 4560*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 2304*Im[PolyLog[2, (-1)^(1/3)]]^
                  2 + 19008*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                2304*PolyGamma[2, 1] + 1408*Zeta[3])))))/7776000, 
      -(CF*NC*(-86400*(120*CA*(26 + 11*lm) + 5*CF*(-133 + 432*lm) - 
            2*(502*NM + 120*lm*NM + 195*NL + 120*lm*NL + 36*NH + 
              120*lm*NH))*Log[x]^2 + 3456000*(40*CA + 49*CF - 11*NM - 
            4*NL)*Log[x]^3 - 125*CA*(7920*lm + 78948*Pi^2 + 
            17920*Sqrt[3]*Pi^3 + 13824*Sqrt[3]*Pi*Log[3]^2 - 
            9*(207425 + 68224*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              73728*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              25920*PolyGamma[2, 1] - 220416*Zeta[3])) + 
          360*Log[x]*(-2*(2*(75*NL*(35 + 112*lm + 36*lm^2 - 20*Pi^2) + 
                NM*(12521 + 8400*lm + 2700*lm^2 + 12300*Pi^2) + 
                NH*(-134107 + 8400*lm + 2700*lm^2 + 73200*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]])) + 75*CF*(-8011 + 252*lm - 
                648*lm^2 + 112*Pi^2 + 1024*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 1728*Zeta[3])) + 75*CA*(-3227 + 3472*lm + 
              792*lm^2 + 172*Pi^2 + 1024*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              1728*Zeta[3])) + 8*(125*CF*(-511485 - 1620*lm + 21600*Pi^2 + 
              4480*Sqrt[3]*Pi^3 - 153504*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              165888*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              3456*Sqrt[3]*Pi*Log[3]^2 + 58320*PolyGamma[2, 1] + 
              525096*Zeta[3]) + 2*(NH*(11250*lm + 533750*Sqrt[3]*Pi^3 + 
                411750*Sqrt[3]*Pi*Log[3]^2 + 9*(-2131739 + 1238000*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]] + 2196000*Sqrt[3]*
                   Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 354000*PolyGamma[
                    2, 1] - 2592000*Zeta[3])) + 3*NM*(-1964849 + 3750*lm + 
                46500*Pi^2 - 468000*PolyGamma[2, 1] - 1746000*Zeta[3]) + 
              1125*NL*(-553 + 10*lm + 20*Pi^2 + 720*Zeta[3])))))/23328000, 
      -(CF*NC*(-90542867625*CF - 64412699904*NM - 11113200000*NL - 
          213683340384*NH + 178737300*CF*Pi^2 + 5000940000*NM*Pi^2 + 
          333396000*NL*Pi^2 + 3727552500*Sqrt[3]*CF*Pi^3 + 
          7034930000*Sqrt[3]*NH*Pi^3 + 150028200*CF*Pi^4 - 
          33784128000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
          32154192000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          12002256000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 138025944000*Sqrt[3]*
           CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 260493408000*Sqrt[3]*
           NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2875540500*Sqrt[3]*CF*
           Pi*Log[3]^2 + 5426946000*Sqrt[3]*NH*Pi*Log[3]^2 - 
          9525600*(35*CA*(637 + 264*lm) + 2*(35*CF*(-43 + 216*lm) - 
              2*(2583*NM + 420*lm*NM + 595*NL + 420*lm*NL + 153*NH + 
                420*lm*NH)))*Log[x]^2 + 3556224000*(22*CA + 86*CF - 
            3*(7*NM + NL))*Log[x]^3 + 18003384000*CF*PolyGamma[2, 1] - 
          5000940000*NM*PolyGamma[2, 1] - 11002068000*NH*PolyGamma[2, 1] + 
          21337344000*CF*Zeta[3] - 46008648000*NM*Zeta[3] + 
          12002256000*NL*Zeta[3] - 110020680000*NH*Zeta[3] - 
          7560*Log[x]*(-600642*NM + 882000*lm*NM + 264600*lm^2*NM - 
            815850*NL + 882000*lm*NL + 264600*lm^2*NL - 20925882*NH + 
            882000*lm*NH + 264600*lm^2*NH + 2381400*NM*Pi^2 - 
            264600*NL*Pi^2 + 11485600*Sqrt[3]*NH*Im[PolyLog[2, (-1)^
                (1/3)]] + 3675*CA*(-500 - 1824*lm - 396*lm^2 + 43*Pi^2 - 
              828*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 864*Zeta[3]) - 
            2450*CF*(5651 - 162*lm + 972*lm^2 + 123*Pi^2 - 2484*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 2592*Zeta[3])) - 
          77175*CA*(1692*Pi^2 + 24150*Sqrt[3]*Pi^3 + 972*Pi^4 + 
            18630*Sqrt[3]*Pi*Log[3]^2 + 5*(-116717 - 43776*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 15552*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 178848*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              23328*PolyGamma[2, 1] + 27216*Zeta[3]))))/6001128000, 
      (2188945*CF^2*NC)/62208 + (7*CF^2*lm*NC)/288 + (136898029*CF*NM*NC)/
        16669800 - (7*CF*lm*NM*NC)/2592 + (3757*CF*NC*NL)/5184 - 
       (7*CF*lm*NC*NL)/2592 + (4452593609*CF*NC*NH)/222264000 - 
       (7*CF*lm*NC*NH)/2592 - (5273*CF^2*NC*Pi^2)/17280 - 
       (131*CF*NM*NC*Pi^2)/324 - (11*CF*NC*NL*Pi^2)/648 - 
       (123445*CF^2*NC*Pi^3)/(139968*Sqrt[3]) - (10535*CF*NC*NH*Pi^3)/
        (5832*Sqrt[3]) + (61829*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2592*Sqrt[3]) - (694*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27*Sqrt[3]) - (3527*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (108*Sqrt[3]) - (602*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (9*Sqrt[3]) - (3527*CF^2*NC*Pi*Log[3]^2)/(5184*Sqrt[3]) - 
       (301*CF*NC*NH*Pi*Log[3]^2)/(216*Sqrt[3]) + 
       (CF*NC*(70*CA*(809 + 660*lm) + 35*CF*(2279 + 2160*lm) - 
          4*(5*(2861 + 420*lm)*NM + 12*(35*(8 + 5*lm)*NL + 
              (66 + 175*lm)*NH)))*Log[x]^2)/7560 - 
       (CF*NC*(345*CA + 4*(7*CF - 46*NM - 5*NL))*Log[x]^3)/27 - 
       (7*CF^2*NC*PolyGamma[2, 1])/2 + (43*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (76*CF*NC*NH*PolyGamma[2, 1])/27 + 
       (CA*CF*NC*(124740*lm + 1131003*Pi^2 + 1234450*Sqrt[3]*Pi^3 + 
          952290*Sqrt[3]*Pi*Log[3]^2 - 135*(1038271 + 247316*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 338592*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 108864*PolyGamma[2, 1] - 
            1107216*Zeta[3])))/8398080 + 
       (CF*NC*Log[x]*(2*(24*(3675*NL*(-26 + 55*lm + 18*lm^2 - 14*Pi^2) + 
              5*NM*(-154442 + 40425*lm + 13230*lm^2 + 177870*Pi^2) + 
              NH*(-5299507 + 202125*lm + 66150*lm^2 + 2949800*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 1225*CF*(-362181 + 5184*lm - 
              11664*lm^2 + 23742*Pi^2 + 28216*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 31104*Zeta[3])) - 
          1225*CA*(-276525 + 61704*lm + 14256*lm^2 + 25758*Pi^2 + 
            28216*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 31104*Zeta[3])))/
        19051200 - (2675*CF^2*NC*Zeta[3])/72 + (131*CF*NM*NC*Zeta[3])/27 - 
       (7*CF*NC*NL*Zeta[3])/9 + (182*CF*NC*NH*Zeta[3])/9, 
      (74711*CF^2*NC)/3888 + (3415153639*CF*NM*NC)/222264000 + 
       (6883*CF*NC*NL)/2592 + (57474588853*CF*NC*NH)/1200225600 + 
       (27091*CF^2*NC*Pi^2)/120960 + (35*CF*NM*NC*Pi^2)/54 - 
       (CF*NC*NL*Pi^2)/18 - (329245*CF^2*NC*Pi^3)/(139968*Sqrt[3]) - 
       (32795*CF*NC*NH*Pi^3)/(6561*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (171331*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(7776*Sqrt[3]) - 
       (10678*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(729*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (9407*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(108*Sqrt[3]) - 
       (14992*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) - 
       (9407*CF^2*NC*Pi*Log[3]^2)/(5184*Sqrt[3]) - 
       (937*CF*NC*NH*Pi*Log[3]^2)/(243*Sqrt[3]) + 
       (CF*NC*(315*CA*(4057 + 1760*lm) + 2*(315*CF*(-101 + 1440*lm) - 
            8*(3*(-611 + 2100*lm)*NM + 210*(41 + 30*lm)*NL + 
              5*(527 + 1260*lm)*NH)))*Log[x]^2)/30240 - 
       (CF*NC*(1025*CA + 4010*CF - 24*(92*NM + 5*NL))*Log[x]^3)/54 - 
       4*CF^2*NC*PolyGamma[2, 1] + (23*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (41*CF*NC*NH*PolyGamma[2, 1])/18 + 
       (CF*NC*Log[x]*(2*(8*(27*NM*(-7993673 + 294000*lm + 88200*lm^2 + 
                2704800*Pi^2) - 5*(26460*NL*(115 - 60*lm - 18*lm^2 + 
                  24*Pi^2) - NH*(-52968051 + 1587600*lm + 476280*lm^2 + 
                  29384320*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
            3675*CF*(-445737 + 7776*lm - 46656*lm^2 + 11484*Pi^2 + 
              150512*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 124416*Zeta[3])) - 
          3675*CA*(-106869 + 262656*lm + 57024*lm^2 + 11484*Pi^2 + 
            150512*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 124416*Zeta[3])))/
        114307200 - (1603*CF^2*NC*Zeta[3])/216 - (13*CF*NM*NC*Zeta[3])/9 - 
       (8*CF*NC*NL*Zeta[3])/3 + (71*CF*NC*NH*Zeta[3])/3 + 
       (CA*CF*NC*(-883791*Pi^2 + 3292450*Sqrt[3]*Pi^3 + 104976*Pi^4 + 
          2539890*Sqrt[3]*Pi*Log[3]^2 - 
          45*(685324*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            186624*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
            3*(-599701 + 903072*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                   Sqrt[3])]] + 124416*PolyGamma[2, 1] + 230832*Zeta[3]))))/
        8398080, (10864813831*CF^2*NC)/349920000 + (9*CF^2*lm*NC)/800 + 
       (21007793549*CF*NM*NC)/2000376000 - (CF*lm*NM*NC)/800 + 
       (43361*CF*NC*NL)/43200 - (CF*lm*NC*NL)/800 + (81967377167*CF*NC*NH)/
        3000564000 - (CF*lm*NC*NH)/800 + (280619*CF^2*NC*Pi^2)/60480 + 
       (47*CF*NM*NC*Pi^2)/180 - (19*CF*NC*NL*Pi^2)/1080 - 
       (31409*CF^2*NC*Pi^3)/(26244*Sqrt[3]) - (135905*CF*NC*NH*Pi^3)/
        (52488*Sqrt[3]) + (3073733*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (109350*Sqrt[3]) - (20102*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (729*Sqrt[3]) - (17948*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (405*Sqrt[3]) - (7766*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81*Sqrt[3]) - 
       (4487*CF^2*NC*Pi*Log[3]^2)/(4860*Sqrt[3]) - 
       (3883*CF*NC*NH*Pi*Log[3]^2)/(1944*Sqrt[3]) + 
       (CF*NC*(21*CA*(-161837 + 52800*lm) + 2*(21*CF*(270319 + 43200*lm) - 
            40*(18*(-31 + 140*lm)*NM + 5*(798*NL + 504*lm*NL + 205*NH + 
                504*lm*NH))))*Log[x]^2)/151200 + 
       (CF*NC*(-2889*CA + 2650*CF + 1920*NM + 80*NL)*Log[x]^3)/90 - 
       (9*CF^2*NC*PolyGamma[2, 1])/2 + (20*CF*NM*NC*PolyGamma[2, 1])/9 + 
       (31*CF*NC*NH*PolyGamma[2, 1])/9 + 
       (CF*NC*Log[x]*(80*(13230*NL*(-337 + 273*lm + 90*lm^2 - 90*Pi^2) + 
            9*NM*(-13448069 + 401310*lm + 132300*lm^2 + 4806900*Pi^2) + 
            NH*(-135717597 + 3611790*lm + 1190700*lm^2 + 76106800*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) + 98*CF*(-566753889 + 4082400*lm - 
            8748000*lm^2 + 70696800*Pi^2 + 28716800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3]) - 
          49*CA*(-501267117 + 46040400*lm + 10692000*lm^2 + 72640800*Pi^2 + 
            28716800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3])))/
        571536000 - (11579*CF^2*NC*Zeta[3])/180 + (13*CF*NM*NC*Zeta[3])/9 - 
       CF*NC*NL*Zeta[3] + (220*CF*NC*NH*Zeta[3])/9 + 
       (CA*CF*NC*(433026*lm - 147363705*Pi^2 + 12563600*Sqrt[3]*Pi^3 + 
          9691920*Sqrt[3]*Pi*Log[3]^2 + 12*(-75789849 - 24589864*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 38767680*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 11809800*
             PolyGamma[2, 1] + 163573020*Zeta[3])))/62985600, 
      (1343619557*CF^2*NC)/77760000 - (19847245633*CF*NM*NC)/1000188000 + 
       (224057*CF*NC*NL)/64800 + (727155677979443*CF*NC*NH)/
        11981252052000 + (3827*CF^2*NC*Pi^2)/1890 + (347*CF*NM*NC*Pi^2)/27 - 
       (CF*NC*NL*Pi^2)/18 - (147931*CF^2*NC*Pi^3)/(52488*Sqrt[3]) - 
       (518035*CF*NC*NH*Pi^3)/(78732*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (3967543*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(145800*Sqrt[3]) - 
       (78716*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (42266*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(405*Sqrt[3]) - 
       (59204*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (243*Sqrt[3]) - (21133*CF^2*NC*Pi*Log[3]^2)/(9720*Sqrt[3]) - 
       (14801*CF*NC*NH*Pi*Log[3]^2)/(2916*Sqrt[3]) + 
       (CF*NC*(77*CA*(71629 + 39600*lm) + 16*(231*CF*(719 + 1350*lm) - 
            5*(11*(-23153 + 630*lm)*NM + 10*(231*(4 + 3*lm)*NL + 
                (314 + 693*lm)*NH))))*Log[x]^2)/138600 - 
       (CF*NC*(4049*CA + 8*(1579*CF - 45*(50*NM + NL)))*Log[x]^3)/135 - 
       5*CF^2*NC*PolyGamma[2, 1] + (31*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (49*CF*NC*NH*PolyGamma[2, 1])/18 + 
       (CF*NC*Log[x]*(20*(2401245*NL*(-3487 + 1200*lm + 360*lm^2 - 
              600*Pi^2) + 16335*NM*(-18167027 + 176400*lm + 52920*lm^2 + 
              5309640*Pi^2) + NH*(-125789175753 + 2881494000*lm + 
              864448200*lm^2 + 70204103200*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]])) + 17787*CF*(-146505813 + 1458000*lm - 
            8748000*lm^2 + 12873600*Pi^2 + 33812800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 23328000*Zeta[3]) - 
          71148*CA*(-10412301 + 6156000*lm + 1336500*lm^2 + 1609200*Pi^2 + 
            4226600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 2916000*Zeta[3])))/
        51866892000 - (2212*CF^2*NC*Zeta[3])/135 - (383*CF*NM*NC*Zeta[3])/
        9 - (10*CF*NC*NL*Zeta[3])/3 + 29*CF*NC*NH*Zeta[3] + 
       (CA*CF*NC*(-5561996625*Pi^2 + 2588792500*Sqrt[3]*Pi^3 + 
          68890500*Pi^4 + 1997068500*Sqrt[3]*Pi*Log[3]^2 - 
          126*(198377150*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            43740000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
            9*(-42122011 + 84532000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                   Sqrt[3])]] + 12150000*PolyGamma[2, 1] + 39816000*Zeta[
                3]))))/5511240000, (-16299117387979*CF^2*NC)/288054144000 + 
       (11*CF^2*lm*NC)/1800 - (58127084691343*CF*NM*NC)/11981252052000 - 
       (11*CF*lm*NM*NC)/16200 + (496307*CF*NC*NL)/388800 - 
       (11*CF*lm*NC*NL)/16200 + (627562212403691*CF*NC*NH)/17971878078000 - 
       (11*CF*lm*NC*NH)/16200 + (9219307*CF^2*NC*Pi^2)/302400 + 
       (1537*CF*NM*NC*Pi^2)/270 - (29*CF*NC*NL*Pi^2)/1620 - 
       (956165*CF^2*NC*Pi^3)/(629856*Sqrt[3]) - (1621585*CF*NC*NH*Pi^3)/
        (472392*Sqrt[3]) + (1703699*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (52488*Sqrt[3]) - (564802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (19683*Sqrt[3]) - (27319*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(486*Sqrt[3]) - 
       (92662*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (729*Sqrt[3]) - (27319*CF^2*NC*Pi*Log[3]^2)/(23328*Sqrt[3]) - 
       (46331*CF*NC*NH*Pi*Log[3]^2)/(17496*Sqrt[3]) + 
       (CF*NC*(165*CA*(-2686829 + 129360*lm) + 
          4*(33*CF*(7376777 + 264600*lm) - 10*((-4076683 + 97020*lm)*NM + 
              13860*(11 + 7*lm)*NL + (40757 + 97020*lm)*NH)))*Log[x]^2)/
        2494800 + (CF*NC*(-28461*CA + 8*(5637*CF + 2230*NM + 35*NL))*
         Log[x]^3)/270 - (11*CF^2*NC*PolyGamma[2, 1])/2 + 
       (77*CF*NM*NC*PolyGamma[2, 1])/27 + (110*CF*NC*NH*PolyGamma[2, 1])/
        27 + (CF*NC*Log[x]*(5*(4*(7203735*NL*(-2159 + 1088*lm + 360*lm^2 - 
                440*Pi^2) + 45*NM*(-21561451811 + 174170304*lm + 
                57629880*lm^2 + 6025524120*Pi^2) + NH*(-390384828501 + 
                7837663680*lm + 2593344600*lm^2 + 219757199200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 363*CF*(-36001150329 + 
              122880240*lm - 257191200*lm^2 + 8261394120*Pi^2 + 
              1070904800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              685843200*Zeta[3])) - 363*CA*(-84964986417 + 3375237600*lm + 
            785862000*lm^2 + 20828121300*Pi^2 + 2677262000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1714608000*Zeta[3])))/
        311201352000 - (78547*CF^2*NC*Zeta[3])/540 - (461*CF*NM*NC*Zeta[3])/
        27 - (11*CF*NC*NL*Zeta[3])/9 + (86*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(21329012024471/720135360000 + (121*lm)/32400 - 
         (865423*Pi^2)/56700 + (956165*Pi^3)/(1259712*Sqrt[3]) - 
         (1703699*Im[PolyLog[2, (-1)^(1/3)]])/(104976*Sqrt[3]) + 
         (27319*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(972*Sqrt[3]) + 
         (27319*Pi*Log[3]^2)/(46656*Sqrt[3]) + (11*PolyGamma[2, 1])/4 + 
         (77227*Zeta[3])/1080), 
      -(CF*NC*(-63111634185600*(1001*CA*(-64709 + 277200*lm) + 
            2*(1001*CF*(686599 + 226800*lm) - 40*(26*(-4919443 + 24255*lm)*
                 NM + 7*(2145*(55 + 42*lm)*NL + 2*(21514 + 45045*lm)*
                   NH))))*Log[x]^2 + 30323877993497088000*
           (1371*CA + 1783*CF - 11380*NM - 70*NL)*Log[x]^3 + 
          2162160*Log[x]*(-2*(80*(13689*NM*(-49882031113 + 160083000*lm + 
                  48024900*lm^2 + 18249462000*Pi^2) - 7*(626107482*NL*
                   (1947 - 500*lm - 150*lm^2 + 300*Pi^2) - 
                  NH*(-17056099700859 + 313053741000*lm + 93916122300*lm^2 + 
                    9555768622400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
              9018009*CF*(-1786358067 + 8748000*lm - 52488000*lm^2 + 
                315981000*Pi^2 + 235314400*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 139968000*Zeta[3])) + 9018009*CA*
             (-1407506217 + 295488000*lm + 64152000*lm^2 + 315981000*Pi^2 + 
              235314400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 139968000*Zeta[
                3])) - 1289575287*CA*(-2921846288400*Pi^2 + 
            288260140000*Sqrt[3]*Pi^3 + 6613488000*Pi^4 + 
            222372108000*Sqrt[3]*Pi*Log[3]^2 - 21*(136031507200*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 25194240000*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 3*(58450855853 + 169426368000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 25194240000*
                 PolyGamma[2, 1] + 190084320000*Zeta[3]))) + 
          2*(-320*(533871*NM*(-538266941649491 + 158773777192800*Pi^2 + 
                4326563241000*PolyGamma[2, 1] - 446634451494000*Zeta[3]) - 
              7*(5*NH*(-2251539187836033519 + 83696588421446000*Sqrt[3]*
                   Pi^3 + 84439876691089920*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]] + 3099165102691257600*Sqrt[3]*
                   Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 64565939639401200*
                   Sqrt[3]*Pi*Log[3]^2 - 96454299421279800*PolyGamma[2, 1] - 
                  1045767667409665200*Zeta[3]) + 22562409221352*NL*
                 (-28751 + 375*Pi^2 + 27000*Zeta[3]))) + 1289575287*CF*
             (-2922889244400*Pi^2 + 288260140000*Sqrt[3]*Pi^3 + 
              6613488000*Pi^4 + 222372108000*Sqrt[3]*Pi*Log[3]^2 - 
              21*(136031507200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                25194240000*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3*(58607564483 + 
                  169426368000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[
                        3])]] + 25194240000*PolyGamma[2, 1] + 190084320000*
                   Zeta[3]))))))/682287254853684480000, 
      (-797195647130731*CF^2*NC)/1361055830400 + (13*CF^2*lm*NC)/3528 - 
       (1459954832124653173*CF*NM*NC)/13161405379122000 - 
       (13*CF*lm*NM*NC)/31752 + (21047903*CF*NC*NL)/13608000 - 
       (13*CF*lm*NC*NL)/31752 + (921366545631722017*CF*NC*NH)/
        21536845165836000 - (13*CF*lm*NC*NH)/31752 + 
       (320382179*CF^2*NC*Pi^2)/1905120 + (4253*CF*NM*NC*Pi^2)/126 - 
       (41*CF*NC*NL*Pi^2)/2268 - (980020*CF^2*NC*Pi^3)/(531441*Sqrt[3]) - 
       (6132245*CF*NC*NH*Pi^3)/(1417176*Sqrt[3]) + 
       (1600466429*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(43401015*Sqrt[3]) - 
       (8613718*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
       (3136064*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (45927*Sqrt[3]) - (350414*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (196004*CF^2*NC*Pi*Log[3]^2)/(137781*Sqrt[3]) - 
       (175207*CF*NC*NH*Pi*Log[3]^2)/(52488*Sqrt[3]) + 
       (CF*NC*(143*CA*(-159372823 + 1552320*lm) + 
          143*CF*(325055279 + 2540160*lm) - 
          28*((-325941659 + 1441440*lm)*NM + 385*(234*(25 + 16*lm)*NL + 
              (1597 + 3744*lm)*NH)))*Log[x]^2)/22702680 + 
       (CF*NC*(-169321*CA + 318332*CF + 88256*NM + 448*NL)*Log[x]^3)/378 - 
       (13*CF^2*NC*PolyGamma[2, 1])/2 + (94*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (127*CF*NC*NH*PolyGamma[2, 1])/27 - (6941*CF^2*NC*Zeta[3])/14 - 
       (2617*CF*NM*NC*Zeta[3])/27 - (13*CF*NC*NL*Zeta[3])/9 + 
       (296*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (32059870513395661/108884466432000 + (143*lm)/63504 - 
         (213637439*Pi^2)/2540160 + (490010*Pi^3)/(531441*Sqrt[3]) - 
         (1600466429*Im[PolyLog[2, (-1)^(1/3)]])/(86802030*Sqrt[3]) + 
         (1568032*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(45927*Sqrt[3]) + 
         (98002*Pi*Log[3]^2)/(137781*Sqrt[3]) + (13*PolyGamma[2, 1])/4 + 
         (62105*Zeta[3])/252) + CF*Log[x]*((-56782313976329*NM*NC)/
          292183491600 + (95*lm*NM*NC)/189 + (lm^2*NM*NC)/6 - 
         (14809*NC*NL)/10800 + (95*lm*NC*NL)/189 + (lm^2*NC*NL)/6 - 
         (7543006819409*NC*NH)/239059220400 + (95*lm*NC*NH)/189 + 
         (lm^2*NC*NH)/6 + (3211*NM*NC*Pi^2)/54 - (13*NC*NL*Pi^2)/54 + 
         (350414*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(6561*Sqrt[3]) + 
         CF*NC*(-336265978891/675126900 + (61*lm)/84 - (3*lm^2)/2 + 
           (27575*Pi^2)/126 + (3136064*Im[PolyLog[2, (-1)^(1/3)]])/
            (137781*Sqrt[3]) - 4*Zeta[3]) + CA*NC*(749520229441/3086294400 - 
           (743*lm)/189 - (11*lm^2)/12 - (82907*Pi^2)/756 - 
           (1568032*Im[PolyLog[2, (-1)^(1/3)]])/(137781*Sqrt[3]) + 
           2*Zeta[3])), (-25976928869179973*CF^2*NC)/136105583040000 - 
       (987721958435857643*CF*NM*NC)/584951350183200 + 
       (26782633*CF*NC*NL)/5292000 + (20730024426972390631*CF*NC*NH)/
        236905296824196000 + (88876727*CF^2*NC*Pi^2)/1587600 + 
       (19993*CF*NM*NC*Pi^2)/45 - (CF*NC*NL*Pi^2)/18 - 
       (7883069*CF^2*NC*Pi^3)/(2125764*Sqrt[3]) - (21209965*CF*NC*NH*Pi^3)/
        (2125764*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (65228707633*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1736040600*Sqrt[3]) - (221164*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (59049*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (31532276*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (229635*Sqrt[3]) - (2423996*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (7883069*CF^2*NC*Pi*Log[3]^2)/(2755620*Sqrt[3]) - 
       (605999*CF*NC*NH*Pi*Log[3]^2)/(78732*Sqrt[3]) + 
       (CF*NC*(143*CA*(-70707943 + 7761600*lm) + 
          4*(143*CF*(44058419 + 3175200*lm) - 140*(630*(-570937 + 572*lm)*
               NM + 15015*(31 + 24*lm)*NL + (178679 + 360360*lm)*NH)))*
         Log[x]^2)/37837800 + 
       (CF*NC*(-57649*CA + 8*(4376*CF + 90545*NM + 140*NL))*Log[x]^3)/315 - 
       7*CF^2*NC*PolyGamma[2, 1] + (47*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (65*CF*NC*NH*PolyGamma[2, 1])/18 - (1157*CF^2*NC*Zeta[3])/7 - 
       (10039*CF*NM*NC*Zeta[3])/9 - (14*CF*NC*NL*Zeta[3])/3 + 
       (119*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*
        (12986649161482279/136105583040000 - (19749431*Pi^2)/705600 + 
         (7883069*Pi^3)/(4251528*Sqrt[3]) + Pi^4/80 - 
         (65228707633*Im[PolyLog[2, (-1)^(1/3)]])/(3472081200*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (15766138*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(229635*Sqrt[3]) + 
         (7883069*Pi*Log[3]^2)/(5511240*Sqrt[3]) + (7*PolyGamma[2, 1])/2 + 
         (1157*Zeta[3])/14) + CF*Log[x]*((-15894510038087*NM*NC)/
          16232416200 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (205031*NC*NL)/37800 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (288255311502329*NC*NH)/3944477136600 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (5177*NM*NC*Pi^2)/9 - (7*NC*NL*Pi^2)/9 + 
         (2423996*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CF*NC*(-6745576831067/27005076000 + lm/2 - 3*lm^2 + (1391*Pi^2)/18 + 
           (31532276*Im[PolyLog[2, (-1)^(1/3)]])/(688905*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(3080502264331/27005076000 - (76*lm)/9 - 
           (11*lm^2)/6 - (1391*Pi^2)/36 - 
           (15766138*Im[PolyLog[2, (-1)^(1/3)]])/(688905*Sqrt[3]) + 
           4*Zeta[3])), (-9431281586988054657931*CF^2*NC)/
        2608654046777856000 + (15*CF^2*lm*NC)/6272 - 
       (95639596186170803321*CF*NM*NC)/140388324043968000 - 
       (5*CF*lm*NM*NC)/18816 + (7687021*CF*NC*NL)/4233600 - 
       (5*CF*lm*NC*NL)/18816 + (18074599182648023711*CF*NC*NH)/
        355357945236294000 - (5*CF*lm*NC*NH)/18816 + 
       (1380301583*CF^2*NC*Pi^2)/1451520 + (1338251*CF*NM*NC*Pi^2)/7560 - 
       (55*CF*NC*NL*Pi^2)/3024 - (1330809445*CF^2*NC*Pi^3)/
        (612220032*Sqrt[3]) - (22385825*CF*NC*NH*Pi^3)/(4251528*Sqrt[3]) + 
       (42186871637*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1020366720*Sqrt[3]) - (25772162*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) - 
       (38023127*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (472392*Sqrt[3]) - (1279190*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (38023127*CF^2*NC*Pi*Log[3]^2)/(22674816*Sqrt[3]) - 
       (639595*CF*NC*NH*Pi*Log[3]^2)/(157464*Sqrt[3]) + 
       (CF*NC*(13*CA*(-26546935249 + 51226560*lm) + 
          2*(13*CF*(26650826509 + 41912640*lm) - 
            56*(5*(-229302977 + 216216*lm)*NM + 12*(10010*(14 + 9*lm)*NL + 
                (38713 + 90090*lm)*NH))))*Log[x]^2)/60540480 + 
       (CF*NC*(-572213*CA + 16*(70510*CF + 15386*NM + 21*NL))*Log[x]^3)/
        252 - (15*CF^2*NC*PolyGamma[2, 1])/2 + (37*CF*NM*NC*PolyGamma[2, 1])/
        9 + (16*CF*NC*NH*PolyGamma[2, 1])/3 - (2344933*CF^2*NC*Zeta[3])/
        1008 - (4183*CF*NM*NC*Zeta[3])/9 - (5*CF*NC*NL*Zeta[3])/3 + 
       (334*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*(9440878302360171545341/
          5217308093555712000 + (55*lm)/37632 - (51124349*Pi^2)/107520 + 
         (1330809445*Pi^3)/(1224440064*Sqrt[3]) - 
         (42186871637*Im[PolyLog[2, (-1)^(1/3)]])/(2040733440*Sqrt[3]) + 
         (38023127*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(944784*Sqrt[3]) + 
         (38023127*Pi*Log[3]^2)/(45349632*Sqrt[3]) + (15*PolyGamma[2, 1])/4 + 
         (2341573*Zeta[3])/2016) + CF*Log[x]*((-29108658290821*NM*NC)/
          48697248600 + (253*lm*NM*NC)/504 + (lm^2*NM*NC)/6 - 
         (26321*NC*NL)/15120 + (253*lm*NC*NL)/504 + (lm^2*NC*NL)/6 - 
         (60486399210323*NC*NH)/1577790854640 + (253*lm*NC*NH)/504 + 
         (lm^2*NC*NH)/6 + (491*NM*NC*Pi^2)/2 - (5*NC*NL*Pi^2)/18 + 
         (1279190*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) + 
         CF*NC*(-11195734117734871/9410728884480 + (41*lm)/56 - (3*lm^2)/2 + 
           (2277323*Pi^2)/2016 + (38023127*Im[PolyLog[2, (-1)^(1/3)]])/
            (1417176*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(173017545026353/294085277640 - (3959*lm)/1008 - 
           (11*lm^2)/12 - (759481*Pi^2)/1344 - 
           (38023127*Im[PolyLog[2, (-1)^(1/3)]])/(2834352*Sqrt[3]) + 
           2*Zeta[3])), (-1237087645615681639*CF^2*NC)/1088844664320000 - 
       (1381201167664216321127*CF*NM*NC)/140388324043968000 + 
       (868673371*CF*NC*NL)/148176000 + (152943961647297193529488559*CF*NC*
         NH)/1508434777393268332608000 + (163558708009*CF^2*NC*Pi^2)/
        558835200 + (268246*CF*NM*NC*Pi^2)/105 - (CF*NC*NL*Pi^2)/18 - 
       (93852211*CF^2*NC*Pi^3)/(22674816*Sqrt[3]) - 
       (168930020*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (1187181918493*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (27776649600*Sqrt[3]) + (269356144*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (93852211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (612360*Sqrt[3]) - (77225152*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (93852211*CF^2*NC*Pi*Log[3]^2)/(29393280*Sqrt[3]) - 
       (4826572*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) + 
       CF*((7421698933*CF*NC)/2116800 + 54*CF*lm*NC + 
         CA*(-7108378093/4233600 + 33*lm)*NC + (3313318565*NM*NC)/108108 - 
         6*lm*NM*NC - (23*NC*NL)/3 - 6*lm*NC*NL - (208261*NC*NH)/68068 - 
         6*lm*NC*NH)*Log[x]^2 + (CF*NC*(-482913*CA + 767446*CF + 
          840*(9028*NM + 3*NL))*Log[x]^3)/630 - 8*CF^2*NC*PolyGamma[2, 1] + 
       (55*CF*NM*NC*PolyGamma[2, 1])/18 + (73*CF*NC*NH*PolyGamma[2, 1])/
        18 - (752711*CF^2*NC*Zeta[3])/1008 - (53813*CF*NM*NC*Zeta[3])/9 - 
       (16*CF*NC*NL*Zeta[3])/3 + 45*CF*NC*NH*Zeta[3] + 
       CA*CF*NC*(1237065858603656539/2177689328640000 - 
         (4956290953*Pi^2)/33868800 + (93852211*Pi^3)/(45349632*Sqrt[3]) + 
         Pi^4/80 - (1187181918493*Im[PolyLog[2, (-1)^(1/3)]])/
          (55553299200*Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (93852211*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1224720*Sqrt[3]) + 
         (93852211*Pi*Log[3]^2)/(58786560*Sqrt[3]) + 4*PolyGamma[2, 1] + 
         (752711*Zeta[3])/2016) + CF*Log[x]*((-467658725140813*NM*NC)/
          194788994400 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (1725523*NC*NL)/264600 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (2119146828289999919*NC*NH)/24623004077511840 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (27088*NM*NC*Pi^2)/9 - (8*NC*NL*Pi^2)/9 + 
         (77225152*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-102376997267579/144027072000 + lm/2 - 3*lm^2 + 
           (246769*Pi^2)/672 + (93852211*Im[PolyLog[2, (-1)^(1/3)]])/
            (1837080*Sqrt[3]) - 8*Zeta[3]) + 
         CA*NC*(99259606070099/288054144000 - (76*lm)/9 - (11*lm^2)/6 - 
           (246769*Pi^2)/1344 - (93852211*Im[PolyLog[2, (-1)^(1/3)]])/
            (3674160*Sqrt[3]) + 4*Zeta[3])), 
      (-13271154288958771534191059*CF^2*NC)/614058529368316032000 + 
       (17*CF^2*lm*NC)/10368 - (298488495896649420669199*CF*NM*NC)/
        79583981080155552000 - (17*CF*lm*NM*NC)/93312 + 
       (8337740303*CF*NC*NL)/4000752000 - (17*CF*lm*NC*NL)/93312 + 
       (267609898454451710118586171*CF*NC*NH)/4525304332179804997824000 - 
       (17*CF*lm*NC*NH)/93312 + (407432416177*CF^2*NC*Pi^2)/71850240 + 
       (64494629*CF*NM*NC*Pi^2)/68040 - (71*CF*NC*NL*Pi^2)/3888 - 
       (323663900*CF^2*NC*Pi^3)/(129140163*Sqrt[3]) - 
       (6448947085*CF*NC*NH*Pi^3)/(1033121304*Sqrt[3]) + 
       (1096578581*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) - 
       (14325583078*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (502211745*Sqrt[3]) - (147960640*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (368511262*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) - (9247540*CF^2*NC*Pi*Log[3]^2)/(4782969*Sqrt[3]) - 
       (184255631*CF*NC*NH*Pi*Log[3]^2)/(38263752*Sqrt[3]) + 
       (CF*NC*(51*CA*(-1765274666509 + 634233600*lm) + 
          34*CF*(5299678078327 + 1556755200*lm) - 
          96*(104*(-3014261947 + 589050*lm)*NM + 
            45*(68068*(31 + 20*lm)*NL + (586983 + 1361360*lm)*NH)))*
         Log[x]^2)/2646483840 + (CF*NC*(-4155323*CA + 8285940*CF + 
          1523904*NM + 480*NL)*Log[x]^3)/324 - (17*CF^2*NC*PolyGamma[2, 1])/
        2 + (128*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (161*CF*NC*NH*PolyGamma[2, 1])/27 - (8351741*CF^2*NC*Zeta[3])/648 - 
       (62753*CF*NM*NC*Zeta[3])/27 - (17*CF*NC*NL*Zeta[3])/9 + 
       (124*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*(26547470654962169600071063/
          2456234117473264128000 + (187*lm)/186624 - (7407912007*Pi^2)/
          2612736 + (161831950*Pi^3)/(129140163*Sqrt[3]) - 
         (1096578581*Im[PolyLog[2, (-1)^(1/3)]])/(47829690*Sqrt[3]) + 
         (73980320*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) + 
         (4623770*Pi*Log[3]^2)/(4782969*Sqrt[3]) + (17*PolyGamma[2, 1])/4 + 
         (8349293*Zeta[3])/1296) + CF*Log[x]*((-24237898398323971*NM*NC)/
          12990927549600 + (325*lm*NM*NC)/648 + (lm^2*NM*NC)/6 - 
         (3348547*NC*NL)/1587600 + (325*lm*NC*NL)/648 + (lm^2*NC*NL)/6 - 
         (50304016191669287587*NC*NH)/1108035183488032800 + 
         (325*lm*NC*NH)/648 + (lm^2*NC*NH)/6 + (63575*NM*NC*Pi^2)/54 - 
         (17*NC*NL*Pi^2)/54 + (368511262*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CF*NC*(-103334087302961851123/
            61344508428403200 + (53*lm)/72 - (3*lm^2)/2 + 
           (1383743*Pi^2)/216 + (147960640*Im[PolyLog[2, (-1)^(1/3)]])/
            (4782969*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(102492934161788597929/122689016856806400 - (5087*lm)/1296 - 
           (11*lm^2)/12 - (461293*Pi^2)/144 - 
           (73980320*Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
           2*Zeta[3])), (-11691438699770394343*CF^2*NC)/1837425371040000 - 
       (20266695258426189258461219*CF*NM*NC)/344863918014007392000 + 
       (17773683199*CF*NC*NL)/2667168000 + (5379812629449540599603099357017*
         CF*NC*NH)/46558593621631923720112224000 + 
       (676938452893*CF^2*NC*Pi^2)/419126400 + (2162163*CF*NM*NC*Pi^2)/140 - 
       (CF*NC*NL*Pi^2)/18 - (6285375307*CF^2*NC*Pi^3)/(1377495072*Sqrt[3]) - 
       (260630405*CF*NC*NH*Pi^3)/(19131876*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (8980049695609*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (187492384800*Sqrt[3]) + (11544469999*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1506635235*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (6285375307*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (37200870*Sqrt[3]) - (29786332*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (6285375307*CF^2*NC*Pi*Log[3]^2)/(1785641760*Sqrt[3]) - 
       (7446583*CF*NC*NH*Pi*Log[3]^2)/(708588*Sqrt[3]) + 
       CF*((30759873601*CF*NC)/1587600 + 60*CF*lm*NC + 
         CA*(-30498792151/3175200 + (110*lm)/3)*NC + (425733296543*NM*NC)/
          2297295 - (20*lm*NM*NC)/3 - (76*NC*NL)/9 - (20*lm*NC*NL)/3 - 
         (30331346*NC*NH)/8729721 - (20*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-10958861*CA + 8*(2604659*CF + 1575*(15586*NM + NL)))*
         Log[x]^3)/2835 - 9*CF^2*NC*PolyGamma[2, 1] + 
       (7*CF*NM*NC*PolyGamma[2, 1])/2 + (9*CF*NC*NH*PolyGamma[2, 1])/2 - 
       (322871*CF^2*NC*Zeta[3])/84 - 34591*CF*NM*NC*Zeta[3] - 
       6*CF*NC*NL*Zeta[3] + (151*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(46765640330382369187/14699402968320000 - 
         (676937815753*Pi^2)/838252800 + (6285375307*Pi^3)/
          (2754990144*Sqrt[3]) + Pi^4/80 - 
         (8980049695609*Im[PolyLog[2, (-1)^(1/3)]])/(374984769600*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (6285375307*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (74401740*Sqrt[3]) + (6285375307*Pi*Log[3]^2)/
          (3571283520*Sqrt[3]) + (9*PolyGamma[2, 1])/2 + 
         (322871*Zeta[3])/168) + CF*Log[x]*((-6847913712539657*NM*NC)/
          3752934625440 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (8063141*NC*NL)/1058400 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (1473224840628345757741*NC*NH)/14814840786636290400 + 
         (10*lm*NC*NH)/9 + (lm^2*NC*NH)/3 + (51955*NM*NC*Pi^2)/3 - 
         NC*NL*Pi^2 + (29786332*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (177147*Sqrt[3]) + CF*NC*(-18602536652193953/8749644624000 + lm/2 - 
           3*lm^2 + (8686045*Pi^2)/4536 + 
           (6285375307*Im[PolyLog[2, (-1)^(1/3)]])/(111602610*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(18413160290415713/17499289248000 - (76*lm)/9 - 
           (11*lm^2)/6 - (8686045*Pi^2)/9072 - 
           (6285375307*Im[PolyLog[2, (-1)^(1/3)]])/(223205220*Sqrt[3]) + 
           4*Zeta[3])), (-1105113378050190113979711101*CF^2*NC)/
        8289790146472266432000 + (19*CF^2*lm*NC)/16200 - 
       (18612536241450591605263911781*CF*NM*NC)/887033105121778763148000 - 
       (19*CF*lm*NM*NC)/145800 + (12546276727*CF*NC*NL)/5334336000 - 
       (19*CF*lm*NC*NL)/145800 + (314635151822295437157920006509*CF*NC*NH)/
        4655859362163192372011222400 - (19*CF*lm*NC*NH)/145800 + 
       (39852315673*CF^2*NC*Pi^2)/1122660 + (362878219*CF*NM*NC*Pi^2)/
        68040 - (89*CF*NC*NL*Pi^2)/4860 - (11741221807*CF^2*NC*Pi^3)/
        (4132485216*Sqrt[3]) - (7493666215*CF*NC*NH*Pi^3)/
        (1033121304*Sqrt[3]) + (1138890086981*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22599528525*Sqrt[3]) - 
       (82894255321*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3013270470*Sqrt[3]) - (1677317401*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(15943230*Sqrt[3]) - 
       (428209498*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1594323*Sqrt[3]) - (1677317401*CF^2*NC*Pi*Log[3]^2)/
        (765275040*Sqrt[3]) - (214104749*CF*NC*NH*Pi*Log[3]^2)/
        (38263752*Sqrt[3]) + 
       (CF*NC*(323*CA*(-41445408955207 + 2616213600*lm) + 
          4*(323*CF*(20725352206759 + 1070269200*lm) - 
            30*((-33520210102381 + 1280359080*lm)*NM + 
              9*(12932920*(17 + 11*lm)*NL + (61415051 + 142262120*lm)*
                 NH))))*Log[x]^2)/62853991200 + 
       (CF*NC*(-62918603*CA + 40*(3144131*CF + 506424*NM + 33*NL))*
         Log[x]^3)/810 - (19*CF^2*NC*PolyGamma[2, 1])/2 + 
       (145*CF*NM*NC*PolyGamma[2, 1])/27 + (178*CF*NC*NH*PolyGamma[2, 1])/
        27 - (4664909*CF^2*NC*Zeta[3])/60 - (336769*CF*NM*NC*Zeta[3])/27 - 
       (19*CF*NC*NL*Zeta[3])/9 + (410*CF*NC*NH*Zeta[3])/9 + 
       CA*CF*NC*(22103051936572918287449725537/331591605858890657280000 + 
         (209*lm)/291600 - (637637733067*Pi^2)/35925120 + 
         (11741221807*Pi^3)/(8264970432*Sqrt[3]) - 
         (1138890086981*Im[PolyLog[2, (-1)^(1/3)]])/(45199057050*Sqrt[3]) + 
         (1677317401*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (31886460*Sqrt[3]) + (1677317401*Pi*Log[3]^2)/
          (1530550080*Sqrt[3]) + (19*PolyGamma[2, 1])/4 + 
         (13993967*Zeta[3])/360) + CF*Log[x]*((-135334072439665202657*NM*NC)/
          24386569196109120 + (203*lm*NM*NC)/405 + (lm^2*NM*NC)/6 - 
         (1048577*NC*NL)/423360 + (203*lm*NC*NL)/405 + (lm^2*NC*NL)/6 - 
         (8433896558829508446637*NC*NH)/160000280495671936320 + 
         (203*lm*NC*NH)/405 + (lm^2*NC*NH)/6 + (337705*NM*NC*Pi^2)/54 - 
         (19*NC*NL*Pi^2)/54 + (428209498*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (4782969*Sqrt[3]) + CF*NC*(453603886594730245709/
            38340317767752000 + (133*lm)/180 - (3*lm^2)/2 + 
           (125814793*Pi^2)/3240 + (1677317401*Im[PolyLog[2, (-1)^(1/3)]])/
            (47829690*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-64879476896879392469/10954376505072000 - (1589*lm)/405 - 
           (11*lm^2)/12 - (125817073*Pi^2)/6480 - 
           (1677317401*Im[PolyLog[2, (-1)^(1/3)]])/(95659380*Sqrt[3]) + 
           2*Zeta[3])), (-8712529907884594412407*CF^2*NC)/
        238130328086784000 - (432300689267173203540730968661*CF*NM*NC)/
        1182710806829038350864000 + (716802637*CF*NC*NL)/96018048 + 
       (1485007036190725135275677291183*CF*NC*NH)/
        11428018434400563094936636800 + (1136068605167*CF^2*NC*Pi^2)/
        121080960 + (277064201*CF*NM*NC*Pi^2)/2835 - (CF*NC*NL*Pi^2)/18 - 
       (7719229835*CF^2*NC*Pi^3)/(1549681956*Sqrt[3]) - 
       (18039985355*CF*NC*NH*Pi^3)/(1162261467*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (805494956957113*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(15186883168800*Sqrt[3]) + 
       (583615586572*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (40679151345*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (6175383868*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (33480783*Sqrt[3]) - (8246850448*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (1543845967*CF^2*NC*Pi*Log[3]^2)/(401769396*Sqrt[3]) - 
       (515428153*CF*NC*NH*Pi*Log[3]^2)/(43046721*Sqrt[3]) + 
       (CF*NC*(46189*CA*(-89227180169 + 64033200*lm) + 
          8*(46189*CF*(22342692101 + 13097700*lm) - 
            210*((-51188868194333 + 320089770*lm)*NM + 
              77*(62985*(83 + 66*lm)*NL + (2204663 + 4157010*lm)*NH))))*
         Log[x]^2)/73329656400 + 
       (CF*NC*(-60885269*CA + 4*(30121177*CF + 315*(956438*NM + 11*NL)))*
         Log[x]^3)/2835 - 10*CF^2*NC*PolyGamma[2, 1] + 
       (71*CF*NM*NC*PolyGamma[2, 1])/18 + (89*CF*NC*NH*PolyGamma[2, 1])/
        18 - (60817447*CF^2*NC*Zeta[3])/2835 - (1912429*CF*NM*NC*Zeta[3])/
        9 - (20*CF*NC*NL*Zeta[3])/3 + (167*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(8712526937497682750881/476260656173568000 - 
         (262169644397*Pi^2)/55883520 + (7719229835*Pi^3)/
          (3099363912*Sqrt[3]) + Pi^4/80 - (805494956957113*
           Im[PolyLog[2, (-1)^(1/3)]])/(30373766337600*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (3087691934*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33480783*Sqrt[3]) + (1543845967*Pi*Log[3]^2)/(803538792*Sqrt[3]) + 
         5*PolyGamma[2, 1] + (60817447*Zeta[3])/5670) + 
       CF*Log[x]*((114087406467310200917*NM*NC)/2540267624594700 + 
         (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - (8301673*NC*NL)/952560 + 
         (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - (462986820091944640069*NC*NH)/
          4090916262673430190 + (10*lm*NC*NH)/9 + (lm^2*NC*NH)/3 + 
         (956444*NM*NC*Pi^2)/9 - (10*NC*NL*Pi^2)/9 + 
         (8246850448*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(-431618677417980389/78746801616000 + lm/2 - 3*lm^2 + 
           (30386831*Pi^2)/2835 + (6175383868*Im[PolyLog[2, (-1)^(1/3)]])/
            (100442349*Sqrt[3]) - 8*Zeta[3]) + 
         CA*NC*(429914282754869669/157493603232000 - (76*lm)/9 - 
           (11*lm^2)/6 - (30386831*Pi^2)/5670 - 
           (3087691934*Im[PolyLog[2, (-1)^(1/3)]])/(100442349*Sqrt[3]) + 
           4*Zeta[3])), (-18772678005881945710169942797515463*CF^2*NC)/
        21992979054393852289424640000 + (21*CF^2*lm*NC)/24200 - 
       (288893496044904970861055127877*CF*NM*NC)/2365421613658076701728000 - 
       (7*CF*lm*NM*NC)/72600 + (2174001437191*CF*NC*NL)/829870272000 - 
       (7*CF*lm*NC*NL)/72600 + (95753622254599831985650248980183*CF*NC*NH)/
        1257082027784061940443030048000 - (7*CF*lm*NC*NH)/72600 + 
       (65984593299283*CF^2*NC*Pi^2)/285405120 + (7856440621*CF*NM*NC*Pi^2)/
        249480 - (109*CF*NC*NL*Pi^2)/5940 - (121892695295*CF^2*NC*Pi^3)/
        (38354628411*Sqrt[3]) - (77133964985*CF*NC*NH*Pi^3)/
        (9298091736*Sqrt[3]) + (811597559346683*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(14766531938235*Sqrt[3]) - 
       (303262542683*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (11622614670*Sqrt[3]) - (55722374992*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(473513931*Sqrt[3]) - 
       (4407655142*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) - (3482648437*CF^2*NC*Pi*Log[3]^2)/
        (1420541793*Sqrt[3]) - (2203827571*CF*NC*NH*Pi*Log[3]^2)/
        (344373768*Sqrt[3]) + 
       (CF*NC*(10944*CA*(-4868636775242 + 51476425*lm) + 
          19*CF*(5608789542587981 + 48518870400*lm) - 
          220*((-65977786931443 + 465585120*lm)*NM + 
            385*(50388*(37 + 24*lm)*NL + (522073 + 1209312*lm)*NH)))*
         Log[x]^2)/38410772400 + (CF*NC*(-489368405*CA + 
          176*(5560429*CF + 801745*NM + 10*NL))*Log[x]^3)/990 - 
       (21*CF^2*NC*PolyGamma[2, 1])/2 + 6*CF*NM*NC*PolyGamma[2, 1] + 
       (65*CF*NC*NH*PolyGamma[2, 1])/9 - (97889317*CF^2*NC*Zeta[3])/198 - 
       71231*CF*NM*NC*Zeta[3] - (7*CF*NC*NL*Zeta[3])/3 + 
       (448*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (103250365373019977674613455970369773/
          241922769598332375183671040000 + (7*lm)/13200 - 
         (126893469413*Pi^2)/1097712 + (121892695295*Pi^3)/
          (76709256822*Sqrt[3]) - (811597559346683*
           Im[PolyLog[2, (-1)^(1/3)]])/(29533063876470*Sqrt[3]) + 
         (27861187496*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (473513931*Sqrt[3]) + (3482648437*Pi*Log[3]^2)/
          (2841083586*Sqrt[3]) + (21*PolyGamma[2, 1])/4 + 
         (97888393*Zeta[3])/396) + CF*Log[x]*((-486819467538865729013*NM*NC)/
          40644281993515200 + (248*lm*NM*NC)/495 + (lm^2*NM*NC)/6 - 
         (3405575*NC*NL)/1197504 + (248*lm*NC*NL)/495 + (lm^2*NC*NL)/6 - 
         (61970516842134034517029*NC*NH)/1028573231757891019200 + 
         (248*lm*NC*NH)/495 + (lm^2*NC*NH)/6 + (641429*NM*NC*Pi^2)/18 - 
         (7*NC*NL*Pi^2)/18 + (4407655142*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(604254058361228332395829763/
            3290864494959457416000 + (163*lm)/220 - (3*lm^2)/2 + 
           (8155892*Pi^2)/33 + (55722374992*Im[PolyLog[2, (-1)^(1/3)]])/
            (1420541793*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-604303801072088090300814941/6581728989918914832000 - 
           (353*lm)/90 - (11*lm^2)/12 - (24467753*Pi^2)/198 - 
           (27861187496*Im[PolyLog[2, (-1)^(1/3)]])/(1420541793*Sqrt[3]) + 
           2*Zeta[3])), (-571641291421723119318810223*CF^2*NC)/
        2614849600138953408000 - (5583620407674685374750118660001*CF*NM*NC)/
        2365421613658076701728000 + (24010979218757*CF*NC*NL)/
        2904545952000 + (19898499025168750678933605234429374317*CF*NC*NH)/
        137654253288438134664333119346144000 + (379067607962611*CF^2*NC*Pi^2)/
        6659452800 + (7280849551*CF*NM*NC*Pi^2)/11340 - 
       (CF*NC*NL*Pi^2)/18 - (2207095956887*CF^2*NC*Pi^3)/
        (409116036384*Sqrt[3]) - (730732792195*CF*NC*NH*Pi^3)/
        (41841412812*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (320685066962980003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5512838590274400*Sqrt[3]) + (7910294803553*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(366112362105*Sqrt[3]) - 
       2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (2207095956887*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (11048658390*Sqrt[3]) - (83512319108*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) - 
       (2207095956887*CF^2*NC*Pi*Log[3]^2)/(530335602720*Sqrt[3]) - 
       (20878079777*CF*NC*NH*Pi*Log[3]^2)/(1549681956*Sqrt[3]) + 
       CF*((131214382678789*CF*NC)/192099600 + 72*CF*lm*NC + 
         CA*(-131176476495859/384199200 + 44*lm)*NC + 
         (336294736512809*NM*NC)/43648605 - 8*lm*NM*NC - 10*NC*NL - 
         8*lm*NC*NL - (1440235306*NC*NH)/334639305 - 8*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-3949524763*CA + 8*(985306522*CF + 
            10395*(1024665*NM + 2*NL)))*Log[x]^3)/31185 - 
       11*CF^2*NC*PolyGamma[2, 1] + (79*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (97*CF*NC*NH*PolyGamma[2, 1])/18 - (15794857151*CF^2*NC*Zeta[3])/
        124740 - (12295487*CF*NM*NC*Zeta[3])/9 - (22*CF*NC*NL*Zeta[3])/3 + 
       61*CF*NC*NH*Zeta[3] + CA*CF*NC*(1143282529402482809767511123/
          10459398400555813632000 - (1137202804254373*Pi^2)/39956716800 + 
         (2207095956887*Pi^3)/(818232072768*Sqrt[3]) + Pi^4/80 - 
         (320685066962980003*Im[PolyLog[2, (-1)^(1/3)]])/(11025677180548800*
           Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (2207095956887*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (22097316780*Sqrt[3]) + (2207095956887*Pi*Log[3]^2)/
          (1060671205440*Sqrt[3]) + (11*PolyGamma[2, 1])/2 + 
         (15794857151*Zeta[3])/249480) + CF*Log[x]*
        ((11633615997360355138781*NM*NC)/20322140996757600 + 
         (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - (205622009*NC*NL)/20956320 + 
         (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - (436122968371073459021224807*NC*
           NH)/3427926009479523399687840 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (6147997*NM*NC*Pi^2)/9 - (11*NC*NL*Pi^2)/9 + 
         (83512319108*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(-817384986196954618369/
            314435978852688000 + lm/2 - 3*lm^2 + (15792735311*Pi^2)/249480 + 
           (2207095956887*Im[PolyLog[2, (-1)^(1/3)]])/(33145975170*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(810579220173261169249/628871957705376000 - 
           (76*lm)/9 - (11*lm^2)/6 - (15792735311*Pi^2)/498960 - 
           (2207095956887*Im[PolyLog[2, (-1)^(1/3)]])/(66291950340*Sqrt[3]) + 
           4*Zeta[3])), (-8435319185976749796369746822905411923997*CF^2*NC)/
        1493413449007465585246319697024000 + (23*CF^2*lm*NC)/34848 - 
       (4256479554517097769148782289674731*CF*NM*NC)/
        5756016954675563845984915200 - (23*CF*lm*NM*NC)/313632 + 
       (50316679953851*CF*NC*NL)/17427275712000 - (23*CF*lm*NC*NL)/313632 + 
       (922657079935349238011889552479478917*CF*NC*NH)/
        10867441049087221157710509422064000 - (23*CF*lm*NC*NH)/313632 + 
       (2662268459038477*CF^2*NC*Pi^2)/1712430720 + 
       (144978652039*CF*NM*NC*Pi^2)/748440 - (131*CF*NC*NL*Pi^2)/7128 - 
       (7062533480555*CF^2*NC*Pi^3)/(2008387814976*Sqrt[3]) - 
       (2351369083385*CF*NC*NH*Pi^3)/(251048476872*Sqrt[3]) + 
       (299007745816817*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5020969537440*Sqrt[3]) - (53395521054971*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2196674172630*Sqrt[3]) - 
       (201786670873*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1549681956*Sqrt[3]) - (134363947622*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (201786670873*CF^2*NC*Pi*Log[3]^2)/(74384733888*Sqrt[3]) - 
       (67181973811*CF*NC*NH*Pi*Log[3]^2)/(9298091736*Sqrt[3]) + 
       (CF*NC*(161*CA*(-61422302388488201 + 104623627680*lm) + 
          2*(483*CF*(20474171336258273 + 28533716640*lm) - 
            220*((-5600632782891093 + 6960497544*lm)*NM + 
              19*(28180152*(20 + 13*lm)*NL + (158047699 + 366341976*lm)*
                 NH))))*Log[x]^2)/1060137318240 + 
       (4*CF*NC*(-242497472*CA + 484986279*CF + 63477535*NM + 143*NL)*
         Log[x]^3)/297 - (23*CF^2*NC*PolyGamma[2, 1])/2 + 
       (179*CF*NM*NC*PolyGamma[2, 1])/27 + (212*CF*NC*NH*PolyGamma[2, 1])/
        27 - (7760125201*CF^2*NC*Zeta[3])/2376 - (11540315*CF*NM*NC*Zeta[3])/
        27 - (23*CF*NC*NL*Zeta[3])/9 + 54*CF*NC*NH*Zeta[3] + 
       CA*CF*NC*(1687065567070391514597142712549425215233/
          597365379602986234098527878809600 + (23*lm)/57024 - 
         (42258230533331*Pi^2)/54362880 + (7062533480555*Pi^3)/
          (4016775629952*Sqrt[3]) - (299007745816817*
           Im[PolyLog[2, (-1)^(1/3)]])/(10041939074880*Sqrt[3]) + 
         (201786670873*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3099363912*Sqrt[3]) + (201786670873*Pi*Log[3]^2)/
          (148769467776*Sqrt[3]) + (23*PolyGamma[2, 1])/4 + 
         (7760113057*Zeta[3])/4752) + CF*Log[x]*
        ((1481129253096210031697161*NM*NC)/64502475523708622400 + 
         (595*lm*NM*NC)/1188 + (lm^2*NM*NC)/6 - (403698833*NC*NL)/
          125737920 + (595*lm*NC*NL)/1188 + (lm^2*NC*NL)/6 - 
         (73600383153641163093542273*NC*NH)/1082502950361954757796160 + 
         (595*lm*NC*NH)/1188 + (lm^2*NC*NH)/6 + (11541479*NM*NC*Pi^2)/54 - 
         (23*NC*NL*Pi^2)/54 + (134363947622*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1162261467*Sqrt[3]) + 
         CF*NC*(1913721593089873659204941652991/1069201874412327714458400 + 
           (49*lm)/66 - (3*lm^2)/2 + (7759880527*Pi^2)/4752 + 
           (201786670873*Im[PolyLog[2, (-1)^(1/3)]])/(4649045868*Sqrt[3]) - 
           4*Zeta[3]) + CA*NC*(-478434629021524093398149297101/
            534600937206163857229200 - (847*lm)/216 - (11*lm^2)/12 - 
           (7759884575*Pi^2)/9504 - (201786670873*Im[PolyLog[2, (-1)^(1/3)]])/
            (9298091736*Sqrt[3]) + 2*Zeta[3])), 
      (-14158418842049395348636897249*CF^2*NC)/10459398400555813632000 - 
       (45290666473631572392138206008860841*CF*NM*NC)/
        2878008477337781922992457600 + (3017970807529*CF*NC*NL)/
        332812557000 + (949174648718464354081315421873069691349*CF*NC*NH)/
        5956193651903573134514413817862000000 + 
       (595893116393269*CF^2*NC*Pi^2)/1664863200 + 
       (4304761859*CF*NM*NC*Pi^2)/990 - (CF*NC*NL*Pi^2)/18 - 
       (527712448861*CF^2*NC*Pi^3)/(90914674752*Sqrt[3]) - 
       (1830872948485*CF*NC*NH*Pi^3)/(94143178827*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (174457410482445239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2756419295137200*Sqrt[3]) + 
       (1065379495087414*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (36245123848395*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (527712448861*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2455257420*Sqrt[3]) - (836970490736*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) - 
       (527712448861*CF^2*NC*Pi*Log[3]^2)/(117852356160*Sqrt[3]) - 
       (52310655671*CF*NC*NH*Pi*Log[3]^2)/(3486784401*Sqrt[3]) + 
       CF*((206270348453821*CF*NC)/48024900 + 78*CF*lm*NC + 
         CA*(-8594170099709/4002075 + (143*lm)/3)*NC + 
         (104766708178475723*NM*NC)/2007835830 - (26*lm*NM*NC)/3 - 
         (97*NC*NL)/9 - (26*lm*NC*NL)/3 - (3643755277*NC*NH)/772244550 - 
         (26*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-97276299457*CA + 194475620474*CF + 
          55440*(40949092*NM + 13*NL))*Log[x]^3)/124740 - 
       12*CF^2*NC*PolyGamma[2, 1] + (29*CF*NM*NC*PolyGamma[2, 1])/6 + 
       (35*CF*NC*NH*PolyGamma[2, 1])/6 - (194545599667*CF^2*NC*Zeta[3])/
        249480 - (27299215*CF*NM*NC*Zeta[3])/3 - 8*CF*NC*NL*Zeta[3] + 
       (199*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*(14158418752869337216927976257/
          20918796801111627264000 - (5363038035302581*Pi^2)/29967537600 + 
         (527712448861*Pi^3)/(181829349504*Sqrt[3]) + Pi^4/80 - 
         (174457410482445239*Im[PolyLog[2, (-1)^(1/3)]])/(5512838590274400*
           Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (527712448861*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (4910514840*Sqrt[3]) + (527712448861*Pi*Log[3]^2)/
          (235704712320*Sqrt[3]) + 6*PolyGamma[2, 1] + (194545599667*Zeta[3])/
          498960) + CF*Log[x]*((4789620735231557345821963*NM*NC)/
          895867715607064200 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (209555729*NC*NL)/19209960 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (10499217928058273286712770533*NC*NH)/74161860782008919704785000 + 
         (10*lm*NC*NH)/9 + (lm^2*NC*NH)/3 + 4549900*NM*NC*Pi^2 - 
         (4*NC*NL*Pi^2)/3 + (836970490736*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*(9387488663552795654233/
            69874661967264000 + lm/2 - 3*lm^2 + (194540965807*Pi^2)/498960 + 
           (527712448861*Im[PolyLog[2, (-1)^(1/3)]])/(7365772260*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(-9389001089689243348393/139749323934528000 - 
           (76*lm)/9 - (11*lm^2)/6 - (194540965807*Pi^2)/997920 - 
           (527712448861*Im[PolyLog[2, (-1)^(1/3)]])/(14731544520*Sqrt[3]) + 
           4*Zeta[3])), (-1220760884761173518330677488530628843511427*CF^2*
         NC)/31768977006158813358876255373056000 + (25*CF^2*lm*NC)/48672 - 
       (1389347069639619810983966314847314393*CF*NM*NC)/
        299792549722685616978381000000 - (25*CF*lm*NM*NC)/438048 + 
       (817625476519723*CF*NC*NL)/259178444388864 - (25*CF*lm*NC*NL)/
        438048 + (2074154813083318630385863387703007392291*CF*NC*NH)/
        22123004992784700213910679894916000000 - (25*CF*lm*NC*NH)/438048 + 
       (10859238672343433*CF^2*NC*Pi^2)/1011890880 + 
       (11992630968821*CF*NM*NC*Pi^2)/9729720 - (155*CF*NC*NL*Pi^2)/8424 - 
       (56636164104625*CF^2*NC*Pi^3)/(14686335897012*Sqrt[3]) - 
       (7879910502485*CF*NC*NH*Pi^3)/(753145430616*Sqrt[3]) + 
       (2358065489381246003*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (36752555582272530*Sqrt[3]) - (1608093181426357*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(72490247696790*Sqrt[3]) - 
       (6472704469100*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (45328197213*Sqrt[3]) - (450280600142*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) - 
       (1618176117275*CF^2*NC*Pi*Log[3]^2)/(543938366556*Sqrt[3]) - 
       (225140300071*CF*NC*NH*Pi*Log[3]^2)/(27894275208*Sqrt[3]) + 
       (CF*NC*(230*CA*(-438441725754534083 + 116512676280*lm) + 
          115*CF*(1753767845559363617 + 381314213280*lm) - 
          338*(9*(-7614806288726687 + 1601692400*lm)*NM + 
            514829700*(43 + 28*lm)*NL + (6212452331 + 14415231600*lm)*NH))*
         Log[x]^2)/1566111947400 + (CF*NC*(-31212796587*CA + 62425407902*CF + 
          7490845648*NM + 2912*NL)*Log[x]^3)/1404 - 
       (25*CF^2*NC*PolyGamma[2, 1])/2 + (196*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (229*CF*NC*NH*PolyGamma[2, 1])/27 - (200082880*CF^2*NC*Zeta[3])/9 - 
       (72026203*CF*NM*NC*Zeta[3])/27 - (25*CF*NC*NL*Zeta[3])/9 + 
       (524*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (110978280513888543787655306994660167562937/
          5776177637483420610704773704192000 + (275*lm)/876096 - 
         (10859238710394953*Pi^2)/2023781760 + (56636164104625*Pi^3)/
          (29372671794024*Sqrt[3]) - (2358065489381246003*
           Im[PolyLog[2, (-1)^(1/3)]])/(73505111164545060*Sqrt[3]) + 
         (3236352234550*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (45328197213*Sqrt[3]) + (1618176117275*Pi*Log[3]^2)/
          (1087876733112*Sqrt[3]) + (25*PolyGamma[2, 1])/4 + 
         (100041415*Zeta[3])/9) + CF*Log[x]*
        ((11191934907169751210237537*NM*NC)/17720460308711160000 + 
         (703*lm*NM*NC)/1404 + (lm^2*NM*NC)/6 - (64318606241*NC*NL)/
          17980522560 + (703*lm*NC*NL)/1404 + (lm^2*NC*NL)/6 - 
         (585564026791961955267276552391*NC*NH)/
          7712833521328927649297640000 + (703*lm*NC*NH)/1404 + 
         (lm^2*NC*NH)/6 + (72027481*NM*NC*Pi^2)/54 - (25*NC*NL*Pi^2)/54 + 
         (450280600142*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*(1404014238663981623071664146859849/
            90979359495448976430278400 + (29*lm)/39 - (3*lm^2)/2 + 
           (31212772105*Pi^2)/2808 + (6472704469100*Im[PolyLog[2, (-1)^
                (1/3)]])/(135984591639*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-127637794895084006147588729717539/
            16541701726445268441868800 - (11009*lm)/2808 - (11*lm^2)/12 - 
           (10404258235*Pi^2)/1872 - (3236352234550*Im[PolyLog[2, (-1)^
                (1/3)]])/(135984591639*Sqrt[3]) + 2*Zeta[3])), 
      (-1254930976475510748175080322068467629*CF^2*NC)/
        145183206571081452267766272000 - 
       (387580682114654268834585224108344419557*CF*NM*NC)/
        3597510596672227403740572000000 + (53290677158054729*CF*NC*NL)/
        5399550924768000 + (242991055738358681272651231692006543579367*CF*NC*
         NH)/1393749314545436113476372833379708000000 + 
       (1806718791167570677*CF^2*NC*Pi^2)/779155977600 + 
       (753269498897*CF*NM*NC*Pi^2)/24948 - (CF*NC*NL*Pi^2)/18 - 
       (8026811781667363*CF^2*NC*Pi^3)/(1292397558937056*Sqrt[3]) - 
       (72760055686325*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (15485856622421048596781*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(226395742386798784800*Sqrt[3]) + 
       (12288050751590843*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (326206114635555*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (8026811781667363*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (34902711854010*Sqrt[3]) - (8315434935580*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) - 
       (8026811781667363*CF^2*NC*Pi*Log[3]^2)/(1675330168992480*Sqrt[3]) - 
       (2078858733895*CF*NC*NH*Pi*Log[3]^2)/(125524238436*Sqrt[3]) + 
       CF*((301119717551975657*CF*NC)/10821610800 + 84*CF*lm*NC + 
         CA*(-301117226352845237/21643221600 + (154*lm)/3)*NC + 
         (1818712657025974019*NM*NC)/5019589575 - (28*lm*NM*NC)/3 - 
         (104*NC*NL)/9 - (28*lm*NC*NL)/3 - (11042158514*NC*NH)/
          2151252675 - (28*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-2014326031639*CA + 8*(503545618306*CF + 
            45045*(140295457*NM + 7*NL)))*Log[x]^3)/405405 - 
       13*CF^2*NC*PolyGamma[2, 1] + (95*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (113*CF*NC*NH*PolyGamma[2, 1])/18 - (8057255281373*CF^2*NC*Zeta[3])/
        1621620 - (561181243*CF*NM*NC*Zeta[3])/9 - (26*CF*NC*NL*Zeta[3])/
        3 + (215*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*
        (313732743856712893339903271691071683/72591603285540726133883136000 - 
         (1806718790630003647*Pi^2)/1558311955200 + (8026811781667363*Pi^3)/
          (2584795117874112*Sqrt[3]) + Pi^4/80 - 
         (15485856622421048596781*Im[PolyLog[2, (-1)^(1/3)]])/
          (452791484773597569600*Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (8026811781667363*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (69805423708020*Sqrt[3]) + (8026811781667363*Pi*Log[3]^2)/
          (3350660337984960*Sqrt[3]) + (13*PolyGamma[2, 1])/2 + 
         (8057255281373*Zeta[3])/3243240) + CF*Log[x]*
        ((12191955673125727028156455639*NM*NC)/268760314682119260000 + 
         (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - (35977343141*NC*NL)/
          2996753760 + (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (37908374415382889884351317071*NC*NH)/242711544377483737215660000 + 
         (10*lm*NC*NH)/9 + (lm^2*NC*NH)/3 + (280590923*NM*NC*Pi^2)/9 - 
         (13*NC*NL*Pi^2)/9 + (8315434935580*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CF*NC*(2179336691119395143888980397/1311470706766120275375 + lm/2 - 
           3*lm^2 + (8057222627213*Pi^2)/3243240 + 
           (8026811781667363*Im[PolyLog[2, (-1)^(1/3)]])/(104708135562030*
             Sqrt[3]) - 8*Zeta[3]) + CA*NC*(-278958730030655431062773001571/
            335736500932126790496000 - (76*lm)/9 - (11*lm^2)/6 - 
           (8057222627213*Pi^2)/6486480 - (8026811781667363*
             Im[PolyLog[2, (-1)^(1/3)]])/(209416271124060*Sqrt[3]) + 
           4*Zeta[3])), (-965322761237629689476217031464099105371003587417*
         CF^2*NC)/3607642670183386633282842391823741952000 + 
       (27*CF^2*lm*NC)/66248 - (193674677209700578027020970465375954811*CF*
         NM*NC)/6475519074010009326733029600000 - (3*CF*lm*NM*NC)/66248 + 
       (4106121836154133*CF*NC*NL)/1199900205504000 - 
       (3*CF*lm*NC*NL)/66248 + (143172799918095402427880481500001233028509*
         CF*NC*NH)/1393749314545436113476372833379708000000 - 
       (3*CF*lm*NC*NH)/66248 + (357525010881681491*CF^2*NC*Pi^2)/
        4722157440 + (26165851753259*CF*NM*NC*Pi^2)/3243240 - 
       (181*CF*NC*NL*Pi^2)/9828 - (37935493821445*CF^2*NC*Pi^3)/
        (9037745167392*Sqrt[3]) - (78514052459885*CF*NC*NH*Pi^3)/
        (6778308875544*Sqrt[3]) + (34904048196398681*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(507431733877530*Sqrt[3]) - 
       (12882253197050653*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (652412229271110*Sqrt[3]) - (7587098764289*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(48814981614*Sqrt[3]) - 
       (4486517283422*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) - (7587098764289*CF^2*NC*Pi*Log[3]^2)/
        (2343119117472*Sqrt[3]) - (2243258641711*CF*NC*NH*Pi*Log[3]^2)/
        (251048476872*Sqrt[3]) + CF*((13551293325220121831*CF*NC)/
          14915351880 + 30*CF*lm*NC + CA*(-83001664842879085993/
            182713060530 + (55*lm)/3)*NC + (35342928216366209*NM*NC)/
          365061060 - (10*lm*NM*NC)/3 - (46*NC*NL)/9 - (10*lm*NC*NL)/3 - 
         (86420704759*NC*NH)/60235074900 - (10*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-253991771913*CA + 56*(9071130379*CF + 1005660747*NM + 
            65*NL))*Log[x]^3)/1638 - (27*CF^2*NC*PolyGamma[2, 1])/2 + 
       (71*CF*NM*NC*PolyGamma[2, 1])/9 + (82*CF*NC*NH*PolyGamma[2, 1])/9 - 
       (507983878891*CF^2*NC*Zeta[3])/3276 - (154716617*CF*NM*NC*Zeta[3])/
        9 - 3*CF*NC*NL*Zeta[3] + (562*CF*NC*NH*Zeta[3])/9 + 
       CA*CF*NC*(120665348246421629937668014192924740624779225369/
          901910667545846658320710597955935488000 + (33*lm)/132496 - 
         (44690626382361031*Pi^2)/1180539360 + (37935493821445*Pi^3)/
          (18075490334784*Sqrt[3]) - (34904048196398681*
           Im[PolyLog[2, (-1)^(1/3)]])/(1014863467755060*Sqrt[3]) + 
         (7587098764289*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (97629963228*Sqrt[3]) + (7587098764289*Pi*Log[3]^2)/
          (4686238234944*Sqrt[3]) + (27*PolyGamma[2, 1])/4 + 
         (507983859235*Zeta[3])/6552) + CF*Log[x]*
        ((197091684878248082480481023*NM*NC)/29319307056231192000 + 
         (410*lm*NM*NC)/819 + (lm^2*NM*NC)/6 - (1125475189*NC*NL)/
          285405120 + (410*lm*NC*NL)/819 + (lm^2*NC*NL)/6 - 
         (5832581951332213508873437273987*NC*NH)/
          69415501691960348843678760000 + (410*lm*NC*NH)/819 + 
         (lm^2*NC*NH)/6 + (154717081*NM*NC*Pi^2)/18 - (NC*NL*Pi^2)/2 + 
         (4486517283422*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (42701307919075849317640868790938680033/
            336896568211647559721320915200 + (271*lm)/364 - (3*lm^2)/2 + 
           (507983482765*Pi^2)/6552 + (7587098764289*Im[PolyLog[2, (-1)^
                (1/3)]])/(146444944842*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-3050093838227336307514918844804485691/
            48128081173092508531617273600 - (6421*lm)/1638 - (11*lm^2)/12 - 
           (507983489317*Pi^2)/13104 - (7587098764289*
             Im[PolyLog[2, (-1)^(1/3)]])/(292889889684*Sqrt[3]) + 
           2*Zeta[3])), (-49363391623612831068304440491477057113*CF^2*NC)/
        871099239426488713606597632000 - 
       (12210274978883505862517340298376923965283*CF*NM*NC)/
        16188797685025023316832574000000 + (53502220916122679*CF*NC*NL)/
        5013868715856000 + (1932382509869290246063073287418898528229419269*CF*
         NC*NH)/10197645609734592411472577109989309523600000 + 
       (25507959100648121953*CF^2*NC*Pi^2)/1655706452400 + 
       (86792316146951*CF*NM*NC*Pi^2)/405405 - (CF*NC*NL*Pi^2)/18 - 
       (12822202237069477*CF^2*NC*Pi^3)/(1938596338405584*Sqrt[3]) - 
       (59794539973805*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (49921924769551111019623*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(679187227160396354400*Sqrt[3]) + 
       (590296417557925244*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (12722038470786645*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (1831743176724211*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7479152540145*Sqrt[3]) - (27334646845168*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (1831743176724211*CF^2*NC*Pi*Log[3]^2)/(358999321926960*Sqrt[3]) - 
       (1708415427823*CF*NC*NH*Pi*Log[3]^2)/(94143178827*Sqrt[3]) + 
       CF*((31755939033980999*CF*NC)/171771600 + 90*CF*lm*NC + 
         CA*(-95267690001011897/1030629600 + 55*lm)*NC + 
         (12895602278186476183*NM*NC)/5019589575 - 10*lm*NM*NC - 
         (37*NC*NL)/3 - 10*lm*NC*NL - (161503790213*NC*NH)/29113619535 - 
         10*lm*NC*NH)*Log[x]^2 + (CF*NC*(-26401703696243*CA + 
          52802754239986*CF + 1081080*(655987222*NM + 5*NL))*Log[x]^3)/
        810810 - 14*CF^2*NC*PolyGamma[2, 1] + (103*CF*NM*NC*PolyGamma[2, 1])/
        18 + (121*CF*NC*NH*PolyGamma[2, 1])/18 - 
       (26401677598819*CF^2*NC*Zeta[3])/810810 - 
       (3935922701*CF*NM*NC*Zeta[3])/9 - (28*CF*NC*NL*Zeta[3])/3 + 
       77*CF*NC*NH*Zeta[3] + CA*CF*NC*
        (49363391618214058590109637233635179527/
          1742198478852977427213195264000 - (6001872729334065491*Pi^2)/
          779155977600 + (12822202237069477*Pi^3)/(3877192676811168*
           Sqrt[3]) + Pi^4/80 - (49921924769551111019623*
           Im[PolyLog[2, (-1)^(1/3)]])/(1358374454320792708800*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + (1831743176724211*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14958305080290*Sqrt[3]) + 
         (1831743176724211*Pi*Log[3]^2)/(717998643853920*Sqrt[3]) + 
         7*PolyGamma[2, 1] + (26401677598819*Zeta[3])/1621620) + 
       CF*Log[x]*((5326591271797365964638558649*NM*NC)/
          14397874000827817500 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (36459356321*NC*NL)/2782699920 + (10*lm*NC*NL)/9 + 
         (lm^2*NC*NL)/3 - (187233555601190184965935206834653*NC*NH)/
          1094595692305099750828759446750 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (1967961676*NM*NC*Pi^2)/9 - (14*NC*NL*Pi^2)/9 + 
         (27334646845168*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CF*NC*(15518235268760835733170668055091/
            1007209502796380371488000 + lm/2 - 3*lm^2 + (26401660005529*Pi^2)/
            1621620 + (1831743176724211*Im[PolyLog[2, (-1)^(1/3)]])/
            (22437457620435*Sqrt[3]) - 8*Zeta[3]) + 
         CA*NC*(-15518257070666107676535389238121/2014419005592760742976000 - 
           (76*lm)/9 - (11*lm^2)/6 - (26401660005529*Pi^2)/3243240 - 
           (1831743176724211*Im[PolyLog[2, (-1)^(1/3)]])/(44874915240870*
             Sqrt[3]) + 4*Zeta[3])), 
      (-202272062190318611587321577108138887966834663158317*CF^2*NC)/
        106431765838015121392741198185359520000000 + (29*CF^2*lm*NC)/88200 - 
       (175826788861413233056953054675764445058745971*CF*NM*NC)/
        888364320165169410767016706393500000 - (29*CF*lm*NM*NC)/793800 + 
       (1553833941721187149*CF*NC*NL)/421164972131904000 - 
       (29*CF*lm*NC*NL)/793800 + 
       (1005973490063742315894303338157670985459736829*CF*NC*NH)/
        8997922596824640363064038626461155462000000 - 
       (29*CF*lm*NC*NH)/793800 + (279994266547818689*CF^2*NC*Pi^2)/
        514594080 + (47839981884509*CF*NM*NC*Pi^2)/884520 - 
       (209*CF*NC*NL*Pi^2)/11340 - (11538960484093*CF^2*NC*Pi^3)/
        (2541865828329*Sqrt[3]) - (776341008915395*CF*NC*NH*Pi^3)/
        (61004779879896*Sqrt[3]) + (4670580095401235789*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(63610192353933225*Sqrt[3]) - 
       (259754910922719635*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15266446164943974*Sqrt[3]) - (26374766820784*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(156905298045*Sqrt[3]) - 
       (44362343366594*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (94143178827*Sqrt[3]) - (1648422926299*CF^2*NC*Pi*Log[3]^2)/
        (470715894135*Sqrt[3]) - (22181171683297*CF*NC*NH*Pi*Log[3]^2)/
        (2259436291848*Sqrt[3]) + CF*((9176812182289817897647*CF*NC)/
          1405485081000 + 32*CF*lm*NC + CA*(-2294203017781615387123/
            702742540500 + (176*lm)/9)*NC + (261631449787988498147*NM*NC)/
          403111655100 - (32*lm*NM*NC)/9 - (49*NC*NL)/9 - 
         (32*lm*NC*NL)/9 - (471107126561*NC*NH)/308261853900 - 
         (32*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-1043083623234*CA + 5*(417233418081*CF + 43003883132*NM + 
            448*NL))*Log[x]^3)/945 - (29*CF^2*NC*PolyGamma[2, 1])/2 + 
       (230*CF*NM*NC*PolyGamma[2, 1])/27 + (263*CF*NC*NH*PolyGamma[2, 1])/
        27 - (1043083727227*CF^2*NC*Zeta[3])/945 - 
       (3071704571*CF*NM*NC*Zeta[3])/27 - (29*CF*NC*NL*Zeta[3])/9 + 
       (200*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*
        (8899970770975544351873867845339631317547482193650573/
          9365995393745330682561225440311637760000000 + (319*lm)/1587600 - 
         (197643011694421597*Pi^2)/726485760 + (11538960484093*Pi^3)/
          (5083731656658*Sqrt[3]) - (4670580095401235789*
           Im[PolyLog[2, (-1)^(1/3)]])/(127220384707866450*Sqrt[3]) + 
         (13187383410392*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (156905298045*Sqrt[3]) + (1648422926299*Pi*Log[3]^2)/
          (941431788270*Sqrt[3]) + (29*PolyGamma[2, 1])/4 + 
         (1043083721137*Zeta[3])/1890) + CF*Log[x]*
        ((726531015511186262450757328681331*NM*NC)/
          12205480930973764073640000 + (473*lm*NM*NC)/945 + 
         (lm^2*NM*NC)/6 - (719538439547*NC*NL)/166961995200 + 
         (473*lm*NC*NL)/945 + (lm^2*NC*NL)/6 - 
         (407472540272413203786584693065823*NC*NH)/
          4415175901734856137796676760000 + (473*lm*NC*NH)/945 + 
         (lm^2*NC*NH)/6 + (3071706077*NM*NC*Pi^2)/54 - 
         (29*NC*NL*Pi^2)/54 + (44362343366594*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(2121342685929056528063721300232099122197/
            2082465050758810465310362800000 + (313*lm)/420 - (3*lm^2)/2 + 
           (2086167208969*Pi^2)/3780 + (26374766820784*
             Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) - 
           4*Zeta[3]) + CA*NC*(-29698798127367637331192848128939527765983/
            58309021421246693028690158400000 - (3704*lm)/945 - (11*lm^2)/12 - 
           (2086167213029*Pi^2)/7560 - (13187383410392*
             Im[PolyLog[2, (-1)^(1/3)]])/(470715894135*Sqrt[3]) + 
           2*Zeta[3])), (-2482854373020446051451701702439653655799*CF^2*NC)/
        6533244295698665352049482240000 - 
       (12749288292170970463415877766656343074774910691*CF*NM*NC)/
        2368971520440451762045377883716000000 + (2147421885961769*CF*NC*NL)/
        187184432058624 + 
       (5599501284799585910329505318598424319236102271938079*CF*NC*NH)/
        27341825432364291827716159021532236801581084000000 + 
       (277073062013661987413*CF^2*NC*Pi^2)/2649130323840 + 
       (167044862773043*CF*NM*NC*Pi^2)/108108 - (CF*NC*NL*Pi^2)/18 - 
       (81595161787869383*CF^2*NC*Pi^3)/(11631578030433504*Sqrt[3]) - 
       (2343639723637835*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (32028096941882667260849*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(407512336296237812640*Sqrt[3]) + 
       (6360811121607106481*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (114498346237079805*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (81595161787869383*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(314124406686090*Sqrt[3]) - 
       (267844539844324*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) - (81595161787869383*CF^2*NC*Pi*Log[3]^2)/
        (15077971520932320*Sqrt[3]) - (66961134961081*CF*NC*NH*Pi*Log[3]^2)/
        (3389154437772*Sqrt[3]) + CF*((40746038270091120619*CF*NC)/
          32464832400 + 96*CF*lm*NC + CA*(-40746029728955097199/64929664800 + 
           (176*lm)/3)*NC + (8097370258195025898173*NM*NC)/436704293025 - 
         (32*lm*NM*NC)/3 - (118*NC*NL)/9 - (32*lm*NC*NL)/3 - 
         (11529979440794*NC*NH)/1933976154825 - (32*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-88592316314797*CA + 4*(44296066017851*CF + 
            180180*(3518653717*NM + 4*NL)))*Log[x]^3)/405405 - 
       15*CF^2*NC*PolyGamma[2, 1] + (37*CF*NM*NC*PolyGamma[2, 1])/6 + 
       (43*CF*NC*NH*PolyGamma[2, 1])/6 - (354369209715137*CF^2*NC*Zeta[3])/
        1621620 - (9383076353*CF*NM*NC*Zeta[3])/3 - 10*CF*NC*NL*Zeta[3] + 
       (247*CF*NC*NH*Zeta[3])/3 + CA*CF*NC*
        (1241427186492660825249888890337844876367/
          6533244295698665352049482240000 - (30785895779145084727*Pi^2)/
          588695627520 + (81595161787869383*Pi^3)/(23263156060867008*
           Sqrt[3]) + Pi^4/80 - (32028096941882667260849*
           Im[PolyLog[2, (-1)^(1/3)]])/(815024672592475625280*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + (81595161787869383*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(628248813372180*Sqrt[3]) + 
         (81595161787869383*Pi*Log[3]^2)/(30155943041864640*Sqrt[3]) + 
         (15*PolyGamma[2, 1])/2 + (354369209715137*Zeta[3])/3243240) + 
       CF*Log[x]*((6028964005475087711215614027073411*NM*NC)/
          2034246821828960678940000 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (184385278873*NC*NL)/12985932960 + (10*lm*NC*NL)/9 + 
         (lm^2*NC*NL)/3 - (140986422502032928765714381282051581439*NC*NH)/
          757372651419744619593435236395260000 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (4691538293*NM*NC*Pi^2)/3 - (5*NC*NL*Pi^2)/3 + 
         (267844539844324*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CF*NC*(97949050939674658761071776239847/
            755407127097285278616000 + lm/2 - 3*lm^2 + (354369171997457*Pi^2)/
            3243240 + (81595161787869383*Im[PolyLog[2, (-1)^(1/3)]])/
            (942373220058270*Sqrt[3]) - 8*Zeta[3]) + 
         CA*NC*(-195898134582917398631368881523709/
            3021628508389141114464000 - (76*lm)/9 - (11*lm^2)/6 - 
           (354369171997457*Pi^2)/6486480 - (81595161787869383*
             Im[PolyLog[2, (-1)^(1/3)]])/(1884746440116540*Sqrt[3]) + 
           4*Zeta[3])), 
      (-180363732955748973799375944518012619700506178059432419*CF^2*NC)/
        13136720812006437840475485033164375040000000 + 
       (31*CF^2*lm*NC)/115200 - 
       (49821436788017855144607885870649195357159040974771*CF*NM*NC)/
        37225862276276834343609944193643968000000 - (31*CF*lm*NM*NC)/
        1036800 + (6665611044172040369*CF*NC*NL)/1684659888527616000 - 
       (31*CF*lm*NC*NL)/1036800 + 
       (26461497442643781855486404756374167200669423848358317*CF*NC*NH)/
        218734603458914334621729272172257894412648672000000 - 
       (31*CF*lm*NC*NH)/1036800 + (168216693614401429211*CF^2*NC*Pi^2)/
        42343741440 + (7201915572916327*CF*NM*NC*Pi^2)/19459440 - 
       (239*CF*NC*NL*Pi^2)/12960 - (85784143008121985*CF^2*NC*Pi^3)/
        (17569376605410048*Sqrt[3]) - (2541981074845975*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) + (13731330070163355212323*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(175869459820154580480*Sqrt[3]) - 
       (41664813905506237*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2973983019144930*Sqrt[3]) - (2450975514517771*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13556617751088*Sqrt[3]) - 
       (145256061419770*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) - (2450975514517771*CF^2*NC*Pi*Log[3]^2)/
        (650717652052224*Sqrt[3]) - (72628030709885*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) + CF*((1378325535421622638400299*CF*NC)/
          28912835952000 + 34*CF*lm*NC + CA*(-1378325532991854972594709/
            57825671904000 + (187*lm)/9)*NC + (1442976739166667536970179*NM*
           NC)/324907994010600 - (34*lm*NM*NC)/9 - (52*NC*NL)/9 - 
         (34*lm*NC*NL)/9 - (18815557559749*NC*NH)/11603856928950 - 
         (34*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-8633752445387*CA + 32*(539609521658*CF + 51978637790*NM + 
            85*NL))*Log[x]^3)/1080 - (31*CF^2*NC*PolyGamma[2, 1])/2 + 
       (247*CF*NM*NC*PolyGamma[2, 1])/27 + (280*CF*NC*NH*PolyGamma[2, 1])/
        27 - (11511670096831*CF^2*NC*Zeta[3])/1440 - 
       (20791453645*CF*NM*NC*Zeta[3])/27 - (31*CF*NC*NL*Zeta[3])/9 + 
       (638*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (1984001063657981641841250723203081425733354069173669609/
          289007857864141632490460670729616250880000000 + (341*lm)/2073600 - 
         (168216693615985590427*Pi^2)/84687482880 + (85784143008121985*Pi^3)/
          (35138753210820096*Sqrt[3]) - (13731330070163355212323*
           Im[PolyLog[2, (-1)^(1/3)]])/(351738919640309160960*Sqrt[3]) + 
         (2450975514517771*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27113235502176*Sqrt[3]) + (2450975514517771*Pi*Log[3]^2)/
          (1301435304104448*Sqrt[3]) + (31*PolyGamma[2, 1])/4 + 
         (11511670086911*Zeta[3])/2880) + CF*Log[x]*
        ((443222372027841777676249270736826919*NM*NC)/
          902266705743522098059080000 + (1081*lm*NM*NC)/2160 + 
         (lm^2*NM*NC)/6 - (2732296003763*NC*NL)/584366983200 + 
         (1081*lm*NC*NL)/2160 + (lm^2*NC*NL)/6 - 
         (10895863787820184436094854144320758487*NC*NH)/
          108196093059963517084776462342180000 + (1081*lm*NC*NH)/2160 + 
         (lm^2*NC*NH)/6 + (20791455265*NM*NC*Pi^2)/54 - 
         (31*NC*NL*Pi^2)/54 + (145256061419770*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(7294173216204447044634541230200242213209889/
            899624901927806121014076729600000 + (179*lm)/240 - (3*lm^2)/2 + 
           (11511669896881*Pi^2)/2880 + (2450975514517771*
             Im[PolyLog[2, (-1)^(1/3)]])/(40669853253264*Sqrt[3]) - 
           4*Zeta[3]) + CA*NC*(-47364761253477940389608200246759920229141/
            11683440284776702870312684800000 - (16931*lm)/4320 - 
           (11*lm^2)/12 - (34535009700563*Pi^2)/17280 - 
           (2450975514517771*Im[PolyLog[2, (-1)^(1/3)]])/(81339706506528*
             Sqrt[3]) + 2*Zeta[3])), 
      (-7336332198765315243294141903029893248427577*CF^2*NC)/
        2822361535741823432085376327680000 - 
       (2938529970976154162370844894641576596526018094510069*CF*NM*NC)/
        75278965936470931672633442702702246400000 + 
       (1723070395140088261*CF*NC*NL)/140388324043968000 + 
       (1889204285218561831365520608780241713705859044586243*CF*NC*NH)/
        8577827586624091553793304791068937035790144000000 + 
       (971027397075194181058097*CF^2*NC*Pi^2)/1342226030745600 + 
       (9181301259003317*CF*NM*NC*Pi^2)/810810 - (CF*NC*NL*Pi^2)/18 - 
       (18625805765066051675*CF^2*NC*Pi^3)/(2512420854573636864*Sqrt[3]) - 
       (634360742598380*CF*NC*NH*Pi^3)/(22876792454961*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (73655172889849360475987099*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(880226646399873675302400*Sqrt[3]) + 
       (2484848721959335334*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (38166115412359935*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (3725161153013210335*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13570174368839088*Sqrt[3]) - 
       (289993482330688*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282429536481*Sqrt[3]) - (3725161153013210335*CF^2*NC*Pi*Log[3]^2)/
        (651368369704276224*Sqrt[3]) - (18124592645668*CF*NC*NH*Pi*Log[3]^2)/
        (847288609443*Sqrt[3]) + CF*((4509415152368004764323*CF*NC)/
          519437318400 + 102*CF*lm*NC + CA*(-4509415007169188521843/
            1038874636800 + (187*lm)/3)*NC + (327034082429104577596921*NM*
           NC)/2406725881560 - (34*lm*NM*NC)/3 - (125*NC*NL)/9 - 
         (34*lm*NC*NL)/3 - (5803036854457*NC*NH)/910106425800 - 
         (34*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-1213579268549237*CA + 2427157710973174*CF + 
          360360*(102347157092*NM + 17*NL))*Log[x]^3)/810810 - 
       16*CF^2*NC*PolyGamma[2, 1] + (119*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (137*CF*NC*NH*PolyGamma[2, 1])/18 - (19417267825645621*CF^2*NC*
         Zeta[3])/12972960 - (204694313461*CF*NM*NC*Zeta[3])/9 - 
       (32*CF*NC*NL*Zeta[3])/3 + (263*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(7336332198752027642204351173838739614417537/
          5644723071483646864170752655360000 - (51106705109189099969323*Pi^2)/
          141286950604800 + (18625805765066051675*Pi^3)/(5024841709147273728*
           Sqrt[3]) + Pi^4/80 - (73655172889849360475987099*
           Im[PolyLog[2, (-1)^(1/3)]])/(1760453292799747350604800*Sqrt[3]) + 
         Im[PolyLog[2, (-1)^(1/3)]]^2 + (3725161153013210335*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(27140348737678176*
           Sqrt[3]) + (3725161153013210335*Pi*Log[3]^2)/(1302736739408552448*
           Sqrt[3]) + 8*PolyGamma[2, 1] + (19417267825645621*Zeta[3])/
          25945920) + CF*Log[x]*((12281110678034333530729325072566948721*NM*
           NC)/521309652207368323323024000 + (10*lm*NM*NC)/9 + 
         (lm^2*NM*NC)/3 - (1489700423573*NC*NL)/97394497200 + 
         (10*lm*NC*NL)/9 + (lm^2*NC*NL)/3 - 
         (5129003127239481491393258988296000963*NC*NH)/
          25457904249403180490535638198160000 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (102347157104*NM*NC*Pi^2)/9 - 
         (16*NC*NL*Pi^2)/9 + (289993482330688*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(1364864836467485222856402378413028047/
            1305343515624108961448448000 + lm/2 - 3*lm^2 + 
           (19417267503663961*Pi^2)/25945920 + (3725161153013210335*
             Im[PolyLog[2, (-1)^(1/3)]])/(40710523106517264*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(-1364864864723937517630805329852335167/
            2610687031248217922896896000 - (76*lm)/9 - (11*lm^2)/6 - 
           (19417267503663961*Pi^2)/51891840 - (3725161153013210335*
             Im[PolyLog[2, (-1)^(1/3)]])/(81421046213034528*Sqrt[3]) + 
           4*Zeta[3])), 
      (-1085577100111210297942500734065837144621000432356988189882123*CF^2*
         NC)/10784377347536281920459063306589654436349849600000 + 
       (33*CF^2*lm*NC)/147968 - 
       (1301624352503339365451321873892475402121476421960261*CF*NM*NC)/
        141148061130882996886187705067566712000000 - (11*CF*lm*NM*NC)/
        443904 + (62317482191187116063*CF*NC*NL)/14753536599529728000 - 
       (11*CF*lm*NC*NL)/443904 + 
       (34186304585340486670855152268773705447087248791966007*CF*NC*NH)/
        262481524150697201546075126606709473295178406400000 - 
       (11*CF*lm*NC*NH)/443904 + (13406375285032982206111*CF^2*NC*Pi^2)/
        455900949504 + (18951637912864141*CF*NM*NC*Pi^2)/7351344 - 
       (271*CF*NC*NL*Pi^2)/14688 - (54879966525810335*CF^2*NC*Pi^3)/
        (10500447736827099*Sqrt[3]) - (8275555744911035*CF*NC*NH*Pi^3)/
        (549043018919064*Sqrt[3]) + (147844329201929736598601*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1786861191375867436830*Sqrt[3]) - 
       (7383083447552713669*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (686990077422478830*Sqrt[3]) - (25087984697513296*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129635157244779*Sqrt[3]) - 
       (472888899709202*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (847288609443*Sqrt[3]) - (1567999043594581*CF^2*NC*Pi*Log[3]^2)/
        (388905471734337*Sqrt[3]) - (236444449854601*CF*NC*NH*Pi*Log[3]^2)/
        (20334926626632*Sqrt[3]) + CF*((134130784756446630098513321*CF*NC)/
          380107416648960 + 36*CF*lm*NC + 
         CA*(-26826156944524550116277353/152042966659584 + 22*lm)*NC + 
         (418803599497334153287774*NM*NC)/13537833083775 - 4*lm*NM*NC - 
         (55*NC*NL)/9 - 4*lm*NC*NL - (3852670911*NC*NH)/2247176360 - 
         4*lm*NC*NH)*Log[x]^2 + (CF*NC*(-71929189664327*CA + 
          136*(1057782199129*CF + 95654837120*NM + 24*NL))*Log[x]^3)/1224 - 
       (33*CF^2*NC*PolyGamma[2, 1])/2 + (88*CF*NM*NC*PolyGamma[2, 1])/9 + 
       11*CF*NC*NH*PolyGamma[2, 1] - (143858379636065*CF^2*NC*Zeta[3])/
        2448 - (47827418035*CF*NM*NC*Zeta[3])/9 - (11*CF*NC*NL*Zeta[3])/3 + 
       (676*CF*NC*NH*Zeta[3])/9 + CA*CF*NC*
        (155082442886056381911008262137665569267361249656017169809989/
          3081250670724651977274018087597044124671385600000 + 
         (121*lm)/887808 - (3527993496065794411321*Pi^2)/239947868160 + 
         (54879966525810335*Pi^3)/(21000895473654198*Sqrt[3]) - 
         (147844329201929736598601*Im[PolyLog[2, (-1)^(1/3)]])/
          (3573722382751734873660*Sqrt[3]) + 
         (12543992348756648*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (129635157244779*Sqrt[3]) + (1567999043594581*Pi*Log[3]^2)/
          (777810943468674*Sqrt[3]) + (33*PolyGamma[2, 1])/4 + 
         (143858379618113*Zeta[3])/4896) + CF*Log[x]*
        ((30687992944697810980531934497640108477*NM*NC)/
          7819644783110524849845360000 + (1225*lm*NM*NC)/2448 + 
         (lm^2*NM*NC)/6 - (137974369751*NC*NL)/27367048800 + 
         (1225*lm*NC*NL)/2448 + (lm^2*NC*NL)/6 - 
         (198604896185110630219810415777306069173*NC*NH)/
          1817694363407387087024244567348624000 + (1225*lm*NC*NH)/2448 + 
         (lm^2*NC*NH)/6 + (15942472871*NM*NC*Pi^2)/6 - 
         (11*NC*NL*Pi^2)/18 + (472888899709202*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(595449807632971120231690621271687567994471730253/
            9260594800460527760739543602225664000 + (203*lm)/272 - 
           (3*lm^2)/2 + (71929189637099*Pi^2)/2448 + 
           (25087984697513296*Im[PolyLog[2, (-1)^(1/3)]])/(388905471734337*
             Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-85064258258991492088460055061518212367661101149/
            2645884228703007931639869600635904000 - (19187*lm)/4896 - 
           (11*lm^2)/12 - (23976396546697*Pi^2)/1632 - 
           (12543992348756648*Im[PolyLog[2, (-1)^(1/3)]])/(388905471734337*
             Sqrt[3]) + 2*Zeta[3])), 
      (-1066004772882894108784584801913392329332035055223*CF^2*NC)/
        58931614456673208717800679066040320000 - 
       (162147110527926322206438103538001321813469362033633887*CF*NM*NC)/
        564592244523531987544750820270266848000000 + 
       (2121923770858544264477*CF*NC*NL)/162288902594827008000 + 
       (4178208282550277395287526735483292529813522948506138891*CF*NC*NH)/
        17717502880172061104360071045952889447424542432000000 + 
       (29015796168754861965454691*CF^2*NC*Pi^2)/5704460630668800 + 
       (272731976519776483*CF*NM*NC*Pi^2)/3243240 - (CF*NC*NL*Pi^2)/18 - 
       (83393261348425731475*CF^2*NC*Pi^3)/(10677788631937956672*Sqrt[3]) - 
       (221441698813151845*CF*NC*NH*Pi^3)/(7412080755407364*Sqrt[3]) - 
       (CF^2*NC*Pi^4)/40 + (5644369598415380314977127109*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(63596375202390873040598400*Sqrt[3]) + 
       (126525377540213926429*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1686248371855175310*Sqrt[3]) - 2*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
         2 - (16678652269685146295*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(57673241067566124*Sqrt[3]) - 
       (25307622721503068*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (22876792454961*Sqrt[3]) - (16678652269685146295*CF^2*NC*Pi*Log[3]^2)/
        (2768315571243173952*Sqrt[3]) - (6326905680375767*CF*NC*NH*Pi*
         Log[3]^2)/(274521509459532*Sqrt[3]) + 
       CF*((2290720749841587080987083*CF*NC)/37529346254400 + 108*CF*lm*NC + 
         CA*(-2290720738733899707784663/75058692508800 + 66*lm)*NC + 
         (27322307134999755624127799*NM*NC)/27075666167550 - 12*lm*NM*NC - 
         (44*NC*NL)/3 - 12*lm*NC*NL - (10214475243391*NC*NH)/
          1504203675975 - 12*lm*NC*NH)*Log[x]^2 + 
       (2*CF*NC*(-35956479371803996*CA + 71912954832846137*CF + 
          9189180*(125832373414*NM + 3*NL))*Log[x]^3)/6891885 - 
       17*CF^2*NC*PolyGamma[2, 1] + (127*CF*NM*NC*PolyGamma[2, 1])/18 + 
       (145*CF*NC*NH*PolyGamma[2, 1])/18 - (575303667832669733*CF^2*NC*
         Zeta[3])/55135080 - (1509988480199*CF*NM*NC*Zeta[3])/9 - 
       (34*CF*NC*NL*Zeta[3])/3 + 93*CF*NC*NH*Zeta[3] + 
       CA*CF*NC*(1066004772882649135173651308377572378311798163773/
          117863228913346417435601358132080640000 - 
         (29015796168752606564266651*Pi^2)/11408921261337600 + 
         (83393261348425731475*Pi^3)/(21355577263875913344*Sqrt[3]) + 
         Pi^4/80 - (5644369598415380314977127109*Im[PolyLog[2, (-1)^(1/3)]])/
          (127192750404781746081196800*Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^
          2 + (16678652269685146295*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (115346482135132248*Sqrt[3]) + (16678652269685146295*Pi*Log[3]^2)/
          (5536631142486347904*Sqrt[3]) + (17*PolyGamma[2, 1])/2 + 
         (575303667832669733*Zeta[3])/110270160) + 
       CF*Log[x]*((1460418057650392152568241353484832270521*NM*NC)/
          7819644783110524849845360000 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (217125395491261*NC*NL)/13245651619200 + (10*lm*NC*NL)/9 + 
         (lm^2*NC*NL)/3 - (53247787217487685977028400858389755301403*NC*NH)/
          245388739059997256748273016592064240000 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (754994240497*NM*NC*Pi^2)/9 - 
         (17*NC*NL*Pi^2)/9 + (25307622721503068*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(13241661293007674861282576131375933659799/
            1603288173065311831899056256000 + lm/2 - 3*lm^2 + 
           (575303666378256773*Pi^2)/110270160 + (16678652269685146295*
             Im[PolyLog[2, (-1)^(1/3)]])/(173019723202698372*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(-13241661327714305432786954602982508612799/
            3206576346130623663798112512000 - (76*lm)/9 - (11*lm^2)/6 - 
           (575303666378256773*Pi^2)/220540320 - (16678652269685146295*
             Im[PolyLog[2, (-1)^(1/3)]])/(346039446405396744*Sqrt[3]) + 
           4*Zeta[3])), 
      (-810647391694885791522040871621001552205945578621961352659359655183*
         CF^2*NC)/1084311176266530139586836348012316834182381996838400000 + 
       (35*CF^2*lm*NC)/187272 - 
       (4973319297638452068214136262080577962536752774501193*CF*NM*NC)/
        76989851525936180119738748218672752000000 - (35*CF*lm*NM*NC)/
        1685448 + (124947504048043781197*CF*NC*NL)/27820954730541772800 - 
       (35*CF*lm*NC*NL)/1685448 + 
       (77023540614868705180640678627137609046046673444315783*CF*NC*NH)/
        551756145057261418474881105237287214625677792000000 - 
       (35*CF*lm*NC*NH)/1685448 + (141240779455107417169853*CF^2*NC*Pi^2)/
        641110710240 + (223475669130450697*CF*NM*NC*Pi^2)/12252240 - 
       (305*CF*NC*NL*Pi^2)/16524 - (2973081702881764705*CF^2*NC*Pi^3)/
        (533669814389330208*Sqrt[3]) - (2171273899360646605*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) + (116740005016122999651521*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1335508710509298845520*Sqrt[3]) - 
       (2417607846178170142489*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (333877177627324711380*Sqrt[3]) - (84945191510907563*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(411782264189298*Sqrt[3]) - 
       (124072794249179806*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (205891132094649*Sqrt[3]) - (84945191510907563*CF^2*NC*Pi*Log[3]^2)/
        (19765548681086304*Sqrt[3]) - (62036397124589903*CF*NC*NH*Pi*
         Log[3]^2)/(4941387170271576*Sqrt[3]) + 
       CF*((1347893352408410226843954979*CF*NC)/509855621370480 + 
         38*CF*lm*NC + CA*(-2695786704721034637163504643/2039422485481920 + 
           (209*lm)/9)*NC + (71114210657960773974159703*NM*NC)/
          324907994010600 - (38*lm*NM*NC)/9 - (58*NC*NL)/9 - 
         (38*lm*NC*NL)/9 - (4106084174191*NC*NH)/2272083874200 - 
         (38*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-1205190939312391*CA + 24*(100432578250605*CF + 
            8559381724540*NM + 323*NL))*Log[x]^3)/2754 - 
       (35*CF^2*NC*PolyGamma[2, 1])/2 + (281*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (314*CF*NC*NH*PolyGamma[2, 1])/27 - (2410381879359223*CF^2*NC*
         Zeta[3])/5508 - (1006986083561*CF*NM*NC*Zeta[3])/27 - 
       (35*CF*NC*NL*Zeta[3])/9 + (238*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*
        (3242589566818529549466165569825049388376070512403985209371092542607/
          8674489410132241116694690784098534673459055974707200000 + 
         (385*lm)/3370896 - (564963117820525406917007*Pi^2)/5128885681920 + 
         (2973081702881764705*Pi^3)/(1067339628778660416*Sqrt[3]) - 
         (116740005016122999651521*Im[PolyLog[2, (-1)^(1/3)]])/
          (2671017421018597691040*Sqrt[3]) + 
         (84945191510907563*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (823564528378596*Sqrt[3]) + (84945191510907563*Pi*Log[3]^2)/
          (39531097362172608*Sqrt[3]) + (35*PolyGamma[2, 1])/4 + 
         (2410381879316383*Zeta[3])/11016) + 
       CF*Log[x]*((1447922526181478749894049130474926020211*NM*NC)/
          46917868698663149099072160000 + (689*lm*NM*NC)/1377 + 
         (lm^2*NM*NC)/6 - (1364309895989*NC*NL)/252298126080 + 
         (689*lm*NC*NL)/1377 + (lm^2*NC*NL)/6 - 
         (520995793108570012029176323592063365444217*NC*NH)/
          4416997303079950621468914298657156320000 + (689*lm*NC*NH)/1377 + 
         (lm^2*NC*NH)/6 + (1006986085409*NM*NC*Pi^2)/54 - 
         (35*NC*NL*Pi^2)/54 + (124072794249179806*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(15308923735416538461026229088022848520174705038422233/
            30035581660943664225988617230868662976000 + (457*lm)/612 - 
           (3*lm^2)/2 + (267820208721737*Pi^2)/1224 + 
           (84945191510907563*Im[PolyLog[2, (-1)^(1/3)]])/(1235346792567894*
             Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-15308923736022046926888610593316510629939234527561483/
            60071163321887328451977234461737325952000 - (5396*lm)/1377 - 
           (11*lm^2)/12 - (803460626169971*Pi^2)/7344 - 
           (84945191510907563*Im[PolyLog[2, (-1)^(1/3)]])/(2470693585135788*
             Sqrt[3]) + 2*Zeta[3])), 
      (-152529203173020134716714428468030653929903242668197*CF^2*NC)/
        1193365192747632476535463751087316480000 - 
       (603984392014789018308837408449378770310627232235645847*CF*NM*NC)/
        282296122261765993772375410135133424000000 + 
       (2126868122200011021697*CF*NC*NL)/153272852450669952000 + 
       (4112589570600883291072108538968375997734537846738790463149*CF*NC*NH)/
        16350206600210928542656591312177865147011251275856000000 + 
       (1862750963579932404485888999*CF^2*NC*Pi^2)/51340145676019200 + 
       (2902907432631322559*CF*NM*NC*Pi^2)/4594590 - (CF*NC*NL*Pi^2)/18 - 
       (7096193645302230083165*CF^2*NC*Pi^3)/(864900879186974490432*
         Sqrt[3]) - (534486167793774665*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) - (CF^2*NC*Pi^4)/40 + 
       (483301720230438059355260926669*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5151306391393660716288470400*Sqrt[3]) + 
       (121061101205397890224462*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1418978004916130023365*Sqrt[3]) - 2*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (1419238729060446016633*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4671532526472856044*
         Sqrt[3]) - (244336533848582704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (1419238729060446016633*CF^2*NC*Pi*Log[3]^2)/(224233561270697090112*
         Sqrt[3]) - (15271033365536419*CF*NC*NH*Pi*Log[3]^2)/
        (617673396283947*Sqrt[3]) + CF*((49019762198470414929615379*CF*NC)/
          112588038763200 + 114*CF*lm*NC + 
         CA*(-49019762163296105673509359/225176077526400 + (209*lm)/3)*NC + 
         (205280086086709926669460273*NM*NC)/27075666167550 - 
         (38*lm*NM*NC)/3 - (139*NC*NL)/9 - (38*lm*NC*NL)/3 - 
         (379893465977227*NC*NH)/52726297273650 - (38*lm*NC*NH)/3)*
        Log[x]^2 + (2*CF*NC*(-84860664494744807*CA + 169721327545512079*CF + 
          510510*(5639540532910*NM + 19*NL))*Log[x]^3)/2297295 - 
       18*CF^2*NC*PolyGamma[2, 1] + (15*CF*NM*NC*PolyGamma[2, 1])/2 + 
       (17*CF*NC*NH*PolyGamma[2, 1])/2 - (4073311893517732823*CF^2*NC*
         Zeta[3])/55135080 - 1253231229445*CF*NM*NC*Zeta[3] - 
       12*CF*NC*NL*Zeta[3] + (295*CF*NC*NH*Zeta[3])/3 + 
       CA*CF*NC*(305058406346031445343452890591967797625562930531639/
          4773460770990529906141855004349265920000 - 
         (1862750963579914353781417199*Pi^2)/102680291352038400 + 
         (7096193645302230083165*Pi^3)/(1729801758373948980864*Sqrt[3]) + 
         Pi^4/80 - (483301720230438059355260926669*
           Im[PolyLog[2, (-1)^(1/3)]])/(10302612782787321432576940800*
           Sqrt[3]) + Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (1419238729060446016633*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9343065052945712088*Sqrt[3]) + (1419238729060446016633*Pi*
           Log[3]^2)/(448467122541394180224*Sqrt[3]) + 9*PolyGamma[2, 1] + 
         (4073311893517732823*Zeta[3])/110270160) + 
       CF*Log[x]*((723696361736592192880151284727217884647*NM*NC)/
          488727798944407803115335000 + (10*lm*NM*NC)/9 + (lm^2*NM*NC)/3 - 
         (24309100393829*NC*NL)/1389975787200 + (10*lm*NC*NL)/9 + 
         (lm^2*NC*NL)/3 - (578608122123089282212167432246349698260419*NC*
           NH)/2486377182531436020062065655781927221250 + (10*lm*NC*NH)/9 + 
         (lm^2*NC*NH)/3 + (1879846844308*NM*NC*Pi^2)/3 - 2*NC*NL*Pi^2 + 
         (244336533848582704*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CF*NC*(8387698997628001673683313576506347218798009/
            129866342018290258383823556736000 + lm/2 - 3*lm^2 + 
           (4073311891977353983*Pi^2)/110270160 + (1419238729060446016633*
             Im[PolyLog[2, (-1)^(1/3)]])/(14014597579418568132*Sqrt[3]) - 
           8*Zeta[3]) + CA*NC*(-8387699000439286404445138374742501273093649/
            259732684036580516767647113472000 - (76*lm)/9 - (11*lm^2)/6 - 
           (4073311891977353983*Pi^2)/220540320 - (1419238729060446016633*
             Im[PolyLog[2, (-1)^(1/3)]])/(28029195158837136264*Sqrt[3]) + 
           4*Zeta[3])), (-742486893662815728035163542442782283456494380919694\
3675724677906763*CF^2*NC)/
        1322047851276838886768976937683466514404187675289600000 + 
       (37*CF^2*lm*NC)/233928 - 
       (271671483787898720742680163120857679126838282477967609579*CF*NM*NC)/
        591688778521044119278019240672065379001600000 - 
       (37*CF*lm*NM*NC)/2105352 + (28434896312523988059615449*CF*NC*NL)/
        5975801971346720088576000 - (37*CF*lm*NC*NL)/2105352 + 
       (37616988673159748625722823855811743112385355109551735905461*CF*NC*
         NH)/252406314390756209377261128381745793206986191571027000000 - 
       (37*CF*lm*NC*NH)/2105352 + (281240294095621743627229*CF^2*NC*Pi^2)/
        168596588160 + (274124184277650184837*CF*NM*NC*Pi^2)/2095133040 - 
       (341*CF*NC*NL*Pi^2)/18468 - (5623972674062722070*CF^2*NC*Pi^3)/
        (950599356880994433*Sqrt[3]) - (2333910961446246875*CF*NC*NH*Pi^3)/
        (133417453597332552*Sqrt[3]) + (141525642188735787559329619*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1536753179324168815304295*Sqrt[3]) - 
       (361688661632908811401*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (103198400357536728972*Sqrt[3]) - (2570958936714387232*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(11735794529394993*Sqrt[3]) - 
       (133366340654071250*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (205891132094649*Sqrt[3]) - (160684933544649202*CF^2*NC*Pi*Log[3]^2)/
        (35207383588184979*Sqrt[3]) - (66683170327035625*CF*NC*NH*Pi*
         Log[3]^2)/(4941387170271576*Sqrt[3]) + 
       CF*((296575483613074274983617813217*CF*NC)/14815804526883360 + 
         40*CF*lm*NC + CA*(-74143870902902303619129724873/7407902263441680 + 
           (220*lm)/9)*NC + (11833641990669891029852989*NM*NC)/
          7537050644760 - (40*lm*NM*NC)/9 - (61*NC*NL)/9 - 
         (40*lm*NC*NL)/9 - (1201997514602383*NC*NH)/632715567283800 - 
         (40*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-10145314200697205*CA + 152*(133490976320059*CF + 
            10758766704078*NM + 60*NL))*Log[x]^3)/3078 - 
       (37*CF^2*NC*PolyGamma[2, 1])/2 + (298*CF*NM*NC*PolyGamma[2, 1])/27 + 
       (331*CF*NC*NH*PolyGamma[2, 1])/27 - (3381771400377175*CF^2*NC*
         Zeta[3])/1026 - (7172511134269*CF*NM*NC*Zeta[3])/27 - 
       (37*CF*NC*NL*Zeta[3])/9 + (752*CF*NC*NH*Zeta[3])/9 + 
       CA*CF*NC*
        (20418389575762052420317862108885349242099154230900473801262918389067/
          7271263182022613877229373157259065829223032214092800000 + 
         (407*lm)/4210704 - (478108499962567655577863*Pi^2)/573228399744 + 
         (2811986337031361035*Pi^3)/(950599356880994433*Sqrt[3]) - 
         (141525642188735787559329619*Im[PolyLog[2, (-1)^(1/3)]])/
          (3073506358648337630608590*Sqrt[3]) + 
         (1285479468357193616*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (11735794529394993*Sqrt[3]) + (80342466772324601*Pi*Log[3]^2)/
          (35207383588184979*Sqrt[3]) + (37*PolyGamma[2, 1])/4 + 
         (3381771400368739*Zeta[3])/2052) + CF*Log[x]*
        ((106701616798934650141640257406848999767937*NM*NC)/
          442969394817033455976757152000 + (770*lm*NM*NC)/1539 + 
         (lm^2*NM*NC)/6 - (1829669133913763*NC*NL)/316914479481600 + 
         (770*lm*NC*NL)/1539 + (lm^2*NC*NL)/6 - 
         (766555278599716023346691540723841892404525811*NC*NH)/
          6046869307916452400790943674861647002080000 + 
         (770*lm*NC*NH)/1539 + (lm^2*NC*NH)/6 + (7172511136231*NM*NC*Pi^2)/
          54 - (37*NC*NL*Pi^2)/54 + (133366340654071250*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(15670596911166415697046631248886428541033042235398127/
            3873366865777802852672740231130121696000 + (511*lm)/684 - 
           (3*lm^2)/2 + (2536328550155333*Pi^2)/1539 + 
           (2570958936714387232*Im[PolyLog[2, (-1)^(1/3)]])/
            (35207383588184979*Sqrt[3]) - 4*Zeta[3]) + 
         CA*NC*(-3637817140110984102474700029865836530562025964171371/
            1798348901968265610169486535881842216000 - (12061*lm)/3078 - 
           (11*lm^2)/12 - (1268164275078721*Pi^2)/1539 - 
           (1285479468357193616*Im[PolyLog[2, (-1)^(1/3)]])/
            (35207383588184979*Sqrt[3]) + 2*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["a", 2, -1, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(20*(NM*(-25 + 5*lm + 8*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
           NH*(-25 + 5*lm + 8*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
           NL*(-1 + 5*lm + 8*lm^2 + 4*lm^3 + 32*Zeta[3])) + 
         CF*(2340*lm^2 - 720*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 + 
           lm*(3030 - 4320*Zeta[3]) - 15*(-51 + 64*Log[2]^4 + 
             1536*PolyLog[4, 1/2] + 576*Zeta[3])) - 
         2*CA*(860*lm^2 + 220*lm^3 - 5*lm*(-85 + 216*Zeta[3]) + 
           4*(11*Pi^4 + 60*Pi^2*Log[2]^2 - 10*(9 + 6*Log[2]^4 + 144*
                PolyLog[4, 1/2] + 28*Zeta[3])))))/720, 
      -(CF*NC*(-20*(NM*(-66 - 11*lm - 4*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
            NH*(6 - 11*lm - 4*lm^2 + 4*lm^3 + 14*Zeta[3]) + 
            NL*(-6 - 11*lm - 4*lm^2 + 4*lm^3 + 32*Zeta[3])) + 
          2*CA*(200*lm^2 + 220*lm^3 + 44*Pi^4 + 240*Pi^2*Log[2]^2 - 
            5*(157 + 48*Log[2]^4 + 1152*PolyLog[4, 1/2] + 8*Zeta[3]) - 
            5*lm*(259 + 216*Zeta[3])) + CF*(-4500*lm^2 + 720*lm^3 - 
            176*Pi^4 - 960*Pi^2*Log[2]^2 + 30*lm*(55 + 144*Zeta[3]) + 
            15*(151 + 64*Log[2]^4 + 1536*PolyLog[4, 1/2] + 288*Zeta[3]))))/
       720, (CF*NC*(-2*CA*(-5340*lm^2 + 660*lm^3 + 132*Pi^4 + 
           720*Pi^2*Log[2]^2 - 5*(134 + 144*Log[2]^4 + 3456*PolyLog[4, 1/2] - 
             3693*Zeta[3]) - 15*lm*(587 + 216*Zeta[3])) + 
         3*CF*(10980*lm^2 - 720*lm^3 + 176*Pi^4 + 960*Pi^2*Log[2]^2 - 
           30*lm*(907 + 144*Zeta[3]) - 5*(-2761 + 192*Log[2]^4 + 
             4608*PolyLog[4, 1/2] + 516*Zeta[3])) + 
         10*(2*NL*(89 + 15*lm - 120*lm^2 + 12*lm^3 + 96*Zeta[3]) + 
           NM*(-1064 + 30*lm - 240*lm^2 + 24*lm^3 + 651*Zeta[3]) + 
           NH*(-200 + 30*lm - 240*lm^2 + 24*lm^3 + 651*Zeta[3]))))/8640, 
      (CF*NC*(-182*NM + 512*lm*NM - 48*lm^2*NM - 20*NL + 512*lm*NL - 
         48*lm^2*NL + 142*NH + 512*lm*NH - 48*lm^2*NH + 
         2*CA*(-923 - 1240*lm + 132*lm^2 - 216*Zeta[3]) + 315*NM*Zeta[3] - 
         315*NH*Zeta[3] + 6*CF*(1411 - 1020*lm + 72*lm^2 + 144*Zeta[3])))/
       1728, -(CF*NC*(74362*NM + 36480*lm*NM - 3456*lm^2*NM + 73632*NL + 
          36480*lm*NL - 3456*lm^2*NL + 132682*NH + 36480*lm*NH - 
          3456*lm^2*NH + 23625*NM*Zeta[3] - 89775*NH*Zeta[3] + 
          216*CF*(-42280 - 2024*lm + 144*lm^2 + 34945*Zeta[3]) + 
          12*CA*(-157534 - 14704*lm + 1584*lm^2 + 88695*Zeta[3])))/622080, 
      (CF*NC*(58846*NM + 14592*lm*NM - 1728*lm^2*NM + 41712*NL + 
         14592*lm*NL - 1728*lm^2*NL + 84358*NH + 14592*lm*NH - 
         1728*lm^2*NH - 4725*NM*Zeta[3] - 61425*NH*Zeta[3] + 
         216*CF*(-42583 - 860*lm + 72*lm^2 + 34801*Zeta[3]) + 
         12*CA*(-136028 - 5680*lm + 792*lm^2 + 89991*Zeta[3])))/622080, 
      -(CF*NC*(4*CA*(-1289563274 - 18855360*lm + 4276800*lm^2 + 
            956289375*Zeta[3]) + 3*(23963776*NL + 5890560*lm*NL - 
            1036800*lm^2*NL + 52003150*NH + 5890560*lm*NH - 
            1036800*lm^2*NH - 38863125*NH*Zeta[3] - 
            5*NM*(-8700470 - 1178112*lm + 207360*lm^2 + 2480625*Zeta[3]) + 
            40*CF*(-413430946 - 2141856*lm + 233280*lm^2 + 340898895*Zeta[
                3]))))/1741824000, (CF*NC*(210465970*NM + 13393920*lm*NM - 
         4147200*lm^2*NM + 91254272*NL + 13393920*lm*NL - 
         4147200*lm^2*NL + 208209950*NH + 13393920*lm*NH - 
         4147200*lm^2*NH - 88144875*NM*Zeta[3] - 156610125*NH*Zeta[3] + 
         480*CF*(-306006034 - 523296*lm + 77760*lm^2 + 253252215*Zeta[3]) + 
         16*CA*(-736696954 - 2789760*lm + 1425600*lm^2 + 577549575*Zeta[3])))/
       3483648000, -(CF*NC*(68447124410*NM + 1111326720*lm*NM - 
          1083801600*lm^2*NM + 22619447296*NL + 1111326720*lm*NL - 
          1083801600*lm^2*NL + 54250432810*NH + 1111326720*lm*NH - 
          1083801600*lm^2*NH - 35987088375*NM*Zeta[3] - 
          40849113375*NH*Zeta[3] + 80*CA*(-66627036362 + 18428928*lm + 
            74511360*lm^2 + 53778210255*Zeta[3]) + 
          224*CF*(-373194339074 - 197061120*lm + 43545600*lm^2 + 
            309564720675*Zeta[3])))/1365590016000, 
      (CF*NC*(29348274480*NM - 377180160*lm*NM - 361267200*lm^2*NM + 
         7026018304*NL - 377180160*lm*NL - 361267200*lm^2*NL + 
         17977005830*NH - 377180160*lm*NH - 361267200*lm^2*NH - 
         18086733000*NM*Zeta[3] - 13540739625*NH*Zeta[3] + 
         40*CA*(-76864904054 + 115084032*lm + 49674240*lm^2 + 
           62991674865*Zeta[3]) + 336*CF*(-174043367914 - 23765760*lm + 
           9676800*lm^2 + 144556286175*Zeta[3])))/682795008000, 
      -(CF*NC*(CA*(-83905321596007294 + 136102540492800*lm + 
            31652425728000*lm^2 + 69300386897356125*Zeta[3]) + 
          2*(9*CF*(-104934337820644594 - 1360532275200*lm + 2877493248000*lm^
                2 + 87219084379084875*Zeta[3]) - 
            140*(4096*(-88196026 + 15190245*lm + 5017950*lm^2)*NL + 
              126*NH*(-8015638046 + 493803520*lm + 163123200*lm^2 + 
                6041314125*Zeta[3]) + 63*NM*(-34835624842 + 987607040*lm + 
                326246400*lm^2 + 24017907375*Zeta[3])))))/16223209390080000, 
      (CF*NC*(CA*(-23940468021259774 + 33260606668800*lm + 
           5364817920000*lm^2 + 19851326221348125*Zeta[3]) + 
         2*(9*CF*(-34818855030300274 + 695981260800*lm + 487710720000*lm^2 + 
             28952205820468875*Zeta[3]) - 
           35*(20480*(-10344155 + 3352356*lm + 680400*lm^2)*NL + 
             63*NH*(-10654723882 + 1089781760*lm + 221184000*lm^2 + 
               8038713375*Zeta[3]) + 45*NM*(-43510490610 + 1525694464*lm + 
               309657600*lm^2 + 32387337675*Zeta[3])))))/4055802347520000, 
      -(CF*NC*(88*CF*(-233137819210741159334 + 5571787021516800*lm + 
            1728544333824000*lm^2 + 193898583153934745625*Zeta[3]) + 
          CA*(-682939434718039132024 + 743298036616396800*lm + 
            92957273063424000*lm^2 + 567390649832815000500*Zeta[3]) - 
          405*(65536*(-7872001343 + 4281289320*lm + 636774600*lm^2)*NL + 
            165*NM*(-45576511731102 + 1700476223488*lm + 252919152640*lm^2 + 
              35684556432525*Zeta[3]) + 33*NH*(-59269410399958 + 
              8502381117440*lm + 1264595763200*lm^2 + 44770339238625*Zeta[
                3]))))/102076433482383360000, 
      (CF*NC*(20*CA*(-7688035440156200786 + 6296867016523776*lm + 
           651739540193280*lm^2 + 6393182828757732315*Zeta[3]) + 
         88*CF*(-59599877816739847154 + 1184984605163520*lm + 
           242382473625600*lm^2 + 49574557990020969675*Zeta[3]) - 
         3*(77*NM*(-2225614506434486 + 86066593136640*lm + 
             10259575603200*lm^2 + 1801374438488625*Zeta[3]) + 
           15*(196608*(-2449903843 + 2247154294*lm + 267872220*lm^2)*NL + 
             11*NH*(40164410130432*lm + 4787801948160*lm^2 + 605*
                (-358697165846 + 271243623105*Zeta[3]))))))/
       20415286696476672000, CA*CF*NC*(8137948726789662553322093/
          966051366477276119040000 - (180677197*lm)/35416180800 - 
         (359*lm^2)/786240 - (201759841381*Zeta[3])/28789702656) - 
       (CF*NC*(208*CF*(-24036008282616569817921598 + 355354155306359193600*
             lm + 55523393363902464000*lm^2 + 19994192343656281033408125*
             Zeta[3]) - 1155*(143*NM*(-1775705464457587286 + 
              76916144241377280*lm + 7769244775219200*lm^2 + 
              1472007539744366625*Zeta[3]) + 3*(6291456*(-334236296029 + 
                582748446280*lm + 58863004200*lm^2)*NL + 1001*NH*(
                -16149292585949822 + 3662673535303680*lm + 369964036915200*
                 lm^2 + 12221071653916125*Zeta[3])))))/
        15456821863636417904640000, 
      CA*CF*NC*(-904759698559763296230907/96605136647727611904000 + 
         (12309719*lm)/2951348400 + (131*lm^2)/393120 + 
         (785225165737*Zeta[3])/100763959296) + 
       (CF*NC*(832*CF*(-2986248089576051290597298 + 31378572116573552640*lm + 
            4052125086724915200*lm^2 + 2484177698984925797728875*Zeta[3]) - 
          2079*(25165824*(-14975724971 + 80502341920*lm + 7159752600*lm^2)*
             NL + 1365*NM*(-22251607378379922 + 1484181515272192*lm + 
              132000786677760*lm^2 + 18991749073772475*Zeta[3]) + 
            143*NH*(-52873008634963114 + 14167187191234560*lm + 
              1260007509196800*lm^2 + 40022904548001375*Zeta[3]))))/
        6182728745454567161856000, 
      CA*CF*NC*(906977100909448861666152731/87588657227273034792960000 - 
         (235975067*lm)/69470200800 - (829*lm^2)/3341520 - 
         (1012100973225191*Zeta[3])/117461986836480) - 
       (CF*NC*(16*CF*(-25931095266594906712158877766 + 
            190284676363403258757120*lm + 21334840700890093977600*lm^2 + 
            21571778268117618924386428425*Zeta[3]) - 
          1001*(91*NM*(21864207173250558286 + 5171026654742446080*lm + 
              416381483247206400*lm^2 - 14906907514060687125*Zeta[3]) + 
            11*(18790481920*(274112963 + 2276604369*lm + 183316770*lm^2)*
               NL + 13*NH*(-10692892861520395018 + 3290653325745192960*lm + 
                264970034793676800*lm^2 + 8092056379803771375*Zeta[3])))))/
        840851109381821134012416000, 
      (CF*NC*(20*CA*(-171032595217594654881416986 + 41572354174714537574400*
            lm + 2826426231823741747200*lm^2 + 142316812405933171385754375*
            Zeta[3]) + 24*CF*(-7501746787898003151522821162 + 
           38294444473278529536000*lm + 3854217588850556928000*lm^2 + 
           6240681662686851296302761375*Zeta[3]) - 
         5005*(16777216*(610871968823 + 1644531045300*lm + 122399877600*lm^2)*
            NL + NM*(1228024351299215092358 + 27590652565703884800*lm + 
             2053529184868761600*lm^2 - 997101733057969163625*Zeta[3]) + 
           7150*NH*(-11171764004241286 + 3858832526671872*lm + 
             287206879002624*lm^2 + 8448112640392425*Zeta[3]))))/
       300303967636364690718720000, 
      -(CF*NC*(16*CA*(-61691695627763332758642509706158 + 
            11206269045502339234922496000*lm + 719082938072492534661120000*
             lm^2 + 51332711950155908561117448745125*Zeta[3]) + 
          544*CF*(-104992698859425693075920518707506 + 
            374163319040096675561472000*lm + 34608269746804453539840000*
             lm^2 + 87343625574743061945099805000875*Zeta[3]) - 
          6435*(134217728*(20185617797366027 + 34662469473531900*lm + 
              2422020659058000*lm^2)*NL + 51*NM*
             (11192133136681246434191942 + 91221919600133485363200*lm + 
              6374080588780929024000*lm^2 - 9210700051087453172879625*Zeta[
                3]) + 21879*NH*(-559060526520734102994 + 
              212638507226418380800*lm + 14857996710445056000*lm^2 + 
              422274369803522110875*Zeta[3]))))/
       79150516141981368803351592960000, 
      (CF*NC*(256*CA*(-8405453694767260232902424552954 + 
           1152513248743173031723008000*lm + 70534994413124623269888000*
            lm^2 + 6993847876325104151726374380375*Zeta[3]) + 
         8704*CF*(-15662304422122556857599369125798 + 
           39266420401250727100416000*lm + 3394732351433805398016000*lm^2 + 
           13029541689331621723576900217625*Zeta[3]) - 
         2145*(5368709120*(3276784331854547 + 4295440619149680*lm + 
             285091810043040*lm^2)*NL + 26775*NM*
            (229916192216429873679662 + 861287440763672592384*lm + 
             57164332422609764352*lm^2 - 190172902209989397864165*Zeta[3]) + 
           7293*NH*(-7671203627784077290634 + 3162069275530965811200*lm + 
             209869052600490393600*lm^2 + 5785943536738113123375*Zeta[3]))))/
       158301032283962737606703185920000, 
      -(CF*NC*(60*CA*(-52463966020004461580681025793100906 + 
            5488627902400549455068349333504*lm + 
            322933752133721649735857602560*lm^2 + 
            43651969735329983919241304215676415*Zeta[3]) + 
          17*(152*CF*(-84198818097238673905920885167761774 + 
              149983866817211159539278151680*lm + 
              12270210114847290378367795200*lm^2 + 
              70045496849309303977563648096281925*Zeta[3]) - 
            91*(8589934592*(3833544852107046607 + 4168393386212175120*lm + 
                265107386849104800*lm^2)*NL + 969*NM*(
                19355335714681577542100593154 + 36951730176767780097884160*
                 lm + 2350108475634521368166400*lm^2 - 
                16049371640689426206576283875*Zeta[3]) + 12597*NH*(
                -6447433535203056973892582 + 2842440782828290776760320*lm + 
                180777575048809336012800*lm^2 + 4855155404205621495605625*
                 Zeta[3])))))/213347577910172713563807440437248000, 
      CA*CF*NC*(-193357699858617699988146217993803421/
          12122021472168904179761786388480000 + (1956683341*lm)/
          1519923787200 + (4651*lm^2)/63488880 + 
         (3538472654473423753*Zeta[3])/266623048520564736) + 
       (CF*NC*(152*CF*(-165006668212532865232882884152125298 + 
            211153057795440315525287116800*lm + 16495764609826207523930112000*
             lm^2 + 137270155556388297643783195622884875*Zeta[3]) - 
          455*(77309411328*(136541669967220101 + 129100853719697860*lm + 
              7920083607836400*lm^2)*NL + 19*NM*
             (509193421890110564924133661982 + 525300579105898982874808320*
               lm + 32226157967914446933196800*lm^2 - 
              422790012276214205956818610125*Zeta[3]) + 
            4199*NH*(-5095654526175947451507442 + 2376925697311760103505920*
               lm + 145819719311830076620800*lm^2 + 3830892752140654033708875*
               Zeta[3]))))/20916429206879677800373278474240000, 
      CA*CF*NC*((-1427281133*lm)/1319933815200 - (174599*lm^2)/2920488480 + 
         (20332129450156685052077322862558519502 - 
           16916293361590136111915301756750103125*Zeta[3])/
          1183704763405124923939545667338240000) - 
       (CF*NC*(224*CF*(-192889793358877916206303896515917671514 + 
            179354348784355968343763205488640*lm + 
            13470640481300330143453859020800*lm^2 + 
            160466395085374957384810067550479967975*Zeta[3]) - 
          46189*(8589934592*(16771252081088730647 + 14208503811441619680*lm + 
              845016788733717600*lm^2)*NL + 9405*NM*
             (22410366796620613341091435234 + 12977152407279767599972352*lm + 
              771785108385381891440640*lm^2 - 18621904924505977129228468275*
               Zeta[3]) + 12597*NH*(-19802927612291108046002974 + 
              9688824195480369475092480*lm + 576219651056959330713600*lm^2 + 
              14863707628166678958802125*Zeta[3]))))/
        30843964120727826589510447103213568000, 
      (CF*NC*(1824*CA*(-21808410102882177117873113806376173534 + 
           1082651327683207500113815535616000*lm + 
           58359043437709542787978887168000*lm^2 + 
           18144229046856671570433847432920838125*Zeta[3]) + 
         13*(64*CF*(-4221524925143431643112156438099662458714 + 
             2884708521761111037511137755136000*lm + 
             209357967017797170980651532288000*lm^2 + 
             3511917618680826982083588955902357654375*Zeta[3]) - 
           124355*(34359738368*(7770219096268330489 + 6020440531827321600*
                lm + 348428648911543200*lm^2)*NL + 
             3*NM*(206526948407792526807998008240714 + 
               68953587177896515710065049600*lm + 
               3990639072172117442376499200*lm^2 - 
               171690964481843535965034599175375*Zeta[3]) + 
             12597*NH*(-32223493229382697881478582 + 
               16421430621075616982630400*lm + 950378440622080838860800*
                lm^2 + 24149379661137238779896625*Zeta[3])))))/
       2159077488450947861265731297224949760000, 
      -(CF*NC*(8*CA*(-22479284030063019326667891257463770815531738 + 
            889546735067755606884720243100562227200*lm + 
            46875776456155621581774928967683276800*lm^2 + 
            18702107391586174563933251469295961720286375*Zeta[3]) + 
          3*(14352*CF*(-398702544684310223338433347113015525188962 + 
              202438868453996559957122609892556800*lm + 
              14252288372196905315224970801971200*lm^2 + 
              331683620808049842552175162915956483109875*Zeta[3]) - 
            124355*(1099511627776*(4092317746924697321443 + 
                2942806765678668989100*lm + 166223123500011898320*lm^2)*NL + 
              23*NM*(716365243483112805267886365262517638 + 
                140680445963546919546366669619200*lm + 
                7946272047543876551182217379840*lm^2 - 
                595692677698855316676928549440347625*Zeta[3]) + 
              37145*NH*(-165019942123055634142227902710 + 
                87108635271546080214468526080*lm + 
                4920292289500852353673199616*lm^2 + 
                123497054483011919108351377425*Zeta[3])))))/
       9137215931124411348876574849855987384320000, 
      (CF*NC*(6072*CF*(-29531592328876297304614866043930338508034 + 
           11259565805886178903733485279641600*lm + 
           771322599913401360889169187962880*lm^2 + 
           24567553332763883802254903447432668790115*Zeta[3]) + 
         36*CA*(-48303683659192206793889286111035311875842 + 
           1540017187819666276485210343420723200*lm + 
           79503362798481332864983624077803520*lm^2 + 
           40186765845219336707452190668027308481635*Zeta[3]) - 
         2261*(1511828488192*(4083160186991730041461 + 2755158178512631830120*
              lm + 152237703090819265920*lm^2)*NL + 
           92*NM*(385957394323033673225722336009539926 + 
             45275289388593224335928454021120*lm + 
             2501709744669737570331965521920*lm^2 - 
             320994918407355416203177999702526625*Zeta[3]) + 
           52003*NH*(-147138134323424191808559333634 + 
             80097814044393143451443527680*lm + 4425846518654997913015418880*
              lm^2 + 109973705605149738030591787875*Zeta[3]))))/
       83065599373858284989787044089599885312000}, 0, 26, 1]
 
CbarSeries["a", 2, 0, "x0"] = SeriesData[x, 0, 
     {(CF*NC*(-3*(CF*(-29160*lm + 3424*Pi^4 + 20*Pi^2*(367 + 1152*Log[2]^2) + 
             45*(747 + 1056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1536*
                Im[PolyLog[2, (-1)^(1/3)]]^2 - 512*Log[2]^4 - 176*
                PolyGamma[2, 1] - 12288*PolyLog[4, 1/2] - 5760*Zeta[3])) - 
           80*(NH*(574 + 27*lm^2 + 4*lm*(3 + Pi^2) + 864*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 144*PolyGamma[2, 1] - 2064*
                Zeta[3]) + NL*(-164 + 27*lm^2 + 30*Pi^2 + 4*lm*(3 + Pi^2) - 
               48*Zeta[3]) + NM*(-164 + 27*lm^2 + 30*Pi^2 + 4*lm*
                (3 + Pi^2) + 4*PolyGamma[2, 1] - 40*Zeta[3]))) + 
         4*CA*(-8910*lm^2 + 1476*Pi^4 - 60*lm*(417 + 22*Pi^2) + 
           Pi^2*(-5605 + 8640*Log[2]^2) + 90*(482 + 198*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 288*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             96*Log[2]^4 - 33*PolyGamma[2, 1] - 2304*PolyLog[4, 1/2] - 
             738*Zeta[3]))))/233280, 
      (CF*NC*(12*CA*(-7505*Pi^2 + 351*Pi^4 - 1980*lm*(7 + Pi^2) - 
           60*(754 + 675*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             468*Im[PolyLog[2, (-1)^(1/3)]]^2 - 120*PolyGamma[2, 1] - 
             1018*Zeta[3])) + 240*(NL*(351 + 29*Pi^2 + 18*lm*(7 + Pi^2) - 
             216*Zeta[3]) + NM*(351 + 29*Pi^2 + 18*lm*(7 + Pi^2) + 
             18*PolyGamma[2, 1] - 180*Zeta[3]) + 
           3*NH*(1421 + 6*lm*(7 + Pi^2) - 1116*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 186*PolyGamma[2, 1] + 772*Zeta[3])) - 
         CF*(35260*Pi^2 + 1512*Pi^4 + 15*(10217 - 64800*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 44928*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 11520*PolyGamma[2, 1] + 61920*Zeta[3]))))/233280, 
      (CF*NC*(CF*(-12700*Pi^2 + 1424*Pi^4 + 15*(-8747 + 19392*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 11520*Im[PolyLog[2, (-1)^(1/3)]]^
               2 - 3008*PolyGamma[2, 1] - 31584*Zeta[3])) - 
         40*CA*(3645 + 469*Pi^2 + 5*Pi^4 + 44*lm*(33 + 2*Pi^2) + 
           3636*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
           2160*Im[PolyLog[2, (-1)^(1/3)]]^2 - 564*PolyGamma[2, 1] - 
           7752*Zeta[3]) + 80*(NL*(303 + 132*lm + 16*Pi^2 + 8*lm*Pi^2 - 
             96*Zeta[3]) + NM*(1887 - 176*Pi^2 + 4*lm*(33 + 2*Pi^2) + 
             32*PolyGamma[2, 1] - 32*Zeta[3]) + NH*(4671 + 132*lm + 
             8*lm*Pi^2 - 5472*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             816*PolyGamma[2, 1] + 5664*Zeta[3]))))/77760, 
      -(CF*NC*(1038015*CF - 2032560*NM - 194400*lm*NM - 632880*NL - 
          194400*lm*NL - 29455920*NH - 194400*lm*NH - 46692*CF*Pi^2 - 
          46800*NM*Pi^2 - 12960*lm*NM*Pi^2 + 82800*NL*Pi^2 - 
          12960*lm*NL*Pi^2 - 12960*lm*NH*Pi^2 + 266000*Sqrt[3]*CF*Pi^3 + 
          800800*Sqrt[3]*NH*Pi^3 + 31104*CF*Pi^4 - 10484640*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 8527680*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 7464960*CF*Im[PolyLog[2, (-1)^(1/3)]]^
            2 + 9849600*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          29652480*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          205200*Sqrt[3]*CF*Pi*Log[3]^2 + 617760*Sqrt[3]*NH*Pi*Log[3]^2 + 
          77760*(159*CF - 2*CA*(76 + 33*lm) + 4*(5*NM + 3*lm*NM + 5*NL + 
              3*lm*NL + 3*lm*NH))*Log[x]^2 + 311040*(11*CA + 36*CF - 
            2*(NM + NL))*Log[x]^3 + 2612160*CF*PolyGamma[2, 1] - 
          12960*NM*PolyGamma[2, 1] - 1277280*NH*PolyGamma[2, 1] + 
          10343520*CF*Zeta[3] - 1736640*NM*Zeta[3] + 1088640*NL*Zeta[3] - 
          15134400*NH*Zeta[3] + 2160*Log[x]*
           (8*(NM*(-125 + 15*lm + 9*Pi^2) + NL*(37 + 15*lm + 9*Pi^2) + 
              NH*(1033 + 15*lm - 572*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
            2*CA*(1225 + 330*lm + 42*Pi^2 - 380*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 648*Zeta[3]) + CF*(4335 + 88*Pi^2 - 
              1520*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 2592*Zeta[3])) - 
          20*CA*(-22941*Pi^2 + 6650*Sqrt[3]*Pi^3 + 1296*Pi^4 - 
            3564*lm*(15 + Pi^2) + 5130*Sqrt[3]*Pi*Log[3]^2 + 
            18*(-11823 - 14562*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              10368*Im[PolyLog[2, (-1)^(1/3)]]^2 + 13680*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3628*PolyGamma[2, 1] + 
              19964*Zeta[3]))))/699840, 
      -(CF*NC*(-7531245*CF - 475200*NM - 185760*lm*NM - 602640*NL - 
          185760*lm*NL - 29365200*NH - 185760*lm*NH + 648612*CF*Pi^2 - 
          249120*NM*Pi^2 - 5760*lm*NM*Pi^2 + 92160*NL*Pi^2 - 
          5760*lm*NL*Pi^2 - 5760*lm*NH*Pi^2 + 296800*Sqrt[3]*CF*Pi^3 + 
          739200*Sqrt[3]*NH*Pi^3 + 9360*CF*Pi^4 - 10128960*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 15546240*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 5909760*CF*Im[PolyLog[2, (-1)^(1/3)]]^
            2 + 10990080*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          27371520*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          228960*Sqrt[3]*CF*Pi*Log[3]^2 + 570240*Sqrt[3]*NH*Pi*Log[3]^2 + 
          77760*(165*CF - 2*CA*(76 + 33*lm) + 2*(7*NM + 6*lm*NM + 10*NL + 
              6*lm*NL + 6*lm*NH))*Log[x]^2 + 311040*(11*CA + 36*CF - 
            2*(NM + NL))*Log[x]^3 + 2334720*CF*PolyGamma[2, 1] + 
          313920*NM*PolyGamma[2, 1] - 2614080*NH*PolyGamma[2, 1] - 
          4*CA*(6930*Pi^2 + 37100*Sqrt[3]*Pi^3 + 2322*Pi^4 - 
            1980*lm*(129 + 4*Pi^2) + 28620*Sqrt[3]*Pi*Log[3]^2 - 
            15*(126099 + 84408*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              49248*Im[PolyLog[2, (-1)^(1/3)]]^2 - 91584*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 19456*PolyGamma[2, 1] - 
              149792*Zeta[3])) + 15594720*CF*Zeta[3] - 1480320*NM*Zeta[3] + 
          1002240*NL*Zeta[3] - 26275200*NH*Zeta[3] + 
          2160*Log[x]*(4*(NL*(73 + 33*lm + 18*Pi^2) + NM*(-356 + 33*lm + 
                24*Pi^2) + NH*(1909 + 33*lm - 1056*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) - 2*CA*(1811 + 363*lm + 50*Pi^2 - 
              424*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 648*Zeta[3]) + 
            CF*(6711 + 216*Pi^2 - 1696*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              2592*Zeta[3]))))/699840, 
      -(CF*NC*(-1320944625*CF - 537192000*NM - 26730000*lm*NM - 
          202581000*NL - 26730000*lm*NL - 8159365872*NH - 
          26730000*lm*NH - 40549500*CF*Pi^2 + 5238000*NM*Pi^2 - 
          972000*lm*NM*Pi^2 + 24678000*NL*Pi^2 - 972000*lm*NL*Pi^2 - 
          972000*lm*NH*Pi^2 + 89390000*Sqrt[3]*CF*Pi^3 + 
          270970000*Sqrt[3]*NH*Pi^3 + 8116200*CF*Pi^4 - 1908864000*Sqrt[3]*
           CF*Im[PolyLog[2, (-1)^(1/3)]] + 1321992000*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 1271376000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 3309984000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 10033632000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 68958000*Sqrt[3]*CF*Pi*
           Log[3]^2 + 209034000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          1166400*(3430*CF - 5*CA*(674 + 297*lm) + 3*(330*NM + 90*lm*NM + 
              135*NL + 90*lm*NL + 8*NH + 90*lm*NH))*Log[x]^2 + 
          104976000*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 + 
          596904000*CF*PolyGamma[2, 1] - 972000*NM*PolyGamma[2, 1] - 
          196404000*NH*PolyGamma[2, 1] - 50*CA*(-1047708*Pi^2 + 
            893900*Sqrt[3]*Pi^3 + 96714*Pi^4 - 53460*lm*(55 + 2*Pi^2) + 
            689580*Sqrt[3]*Pi*Log[3]^2 - 15*(1744767 + 1272576*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 847584*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 2206656*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              397936*PolyGamma[2, 1] - 1680176*Zeta[3])) + 
          1999596000*CF*Zeta[3] - 1121688000*NM*Zeta[3] + 
          326592000*NL*Zeta[3] - 3917928000*NH*Zeta[3] - 
          2160*Log[x]*(2*(450*NM*(235 - 39*lm + 11*Pi^2) - 225*NL*(343 + 
                78*lm + 54*Pi^2) - 2*NH*(696849 + 8775*lm - 387100*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + 50*CA*(19335 + 3861*lm + 
              312*Pi^2 - 5108*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              5832*Zeta[3]) - 25*CF*(64245 + 204*Pi^2 - 20432*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 23328*Zeta[3]))))/52488000, 
      -(CF*NC*(-31857937875*CF - 5231104848*NM - 196992000*lm*NM - 
          1701486000*NL - 196992000*lm*NL - 67236928848*NH - 
          196992000*lm*NH + 739586700*CF*Pi^2 - 177552000*NM*Pi^2 - 
          3888000*lm*NM*Pi^2 + 185328000*NL*Pi^2 - 3888000*lm*NL*Pi^2 - 
          3888000*lm*NH*Pi^2 + 771610000*Sqrt[3]*CF*Pi^3 + 
          2052680000*Sqrt[3]*NH*Pi^3 + 39657600*CF*Pi^4 - 
          16637184000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] + 
          23283072000*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          8398080000*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 28571616000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 76007808000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 595242000*Sqrt[3]*CF*Pi*
           Log[3]^2 + 1583496000*Sqrt[3]*NH*Pi*Log[3]^2 - 
          388800*(15*CA*(4981 + 2332*lm) - 4*(17345*CF + 2*(2881 + 795*lm)*
               NM + 3*(815*NL + 530*lm*NL + 54*NH + 530*lm*NH)))*
           Log[x]^2 + 15552000*(835*CA + 2038*CF - 248*NM - 106*NL)*
           Log[x]^3 + 4195944000*CF*PolyGamma[2, 1] + 443232000*NM*
           PolyGamma[2, 1] - 4408704000*NH*PolyGamma[2, 1] - 
          200*CA*(754920*Pi^2 + 1929025*Sqrt[3]*Pi^3 + 114696*Pi^4 - 
            35640*lm*(152 + 3*Pi^2) + 1488105*Sqrt[3]*Pi*Log[3]^2 - 
            180*(551793 + 231072*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              116640*Im[PolyLog[2, (-1)^(1/3)]]^2 - 396828*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 58277*PolyGamma[2, 1] - 
              479380*Zeta[3])) + 4320*Log[x]*
           (4*(6*NM*(-43307 + 5325*lm - 5325*Pi^2) + 225*NL*(657 + 142*lm + 
                106*Pi^2) + 2*NH*(1319154 + 15975*lm - 733100*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) - 25*CF*(-431103 + 5058*Pi^2 + 
              88184*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 93312*Zeta[3]) + 
            25*CA*(-230568 - 28116*lm + 2259*Pi^2 + 44092*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 46656*Zeta[3])) + 
          32733684000*CF*Zeta[3] - 8164800000*NM*Zeta[3] + 
          2519424000*NL*Zeta[3] - 50465664000*NH*Zeta[3]))/472392000, 
      (13050011*CF^2*NC)/139968 + (156953*CF*NM*NC)/2916 + 
       (245*CF*lm*NM*NC)/324 + (68617*CF*NC*NL)/5832 + 
       (245*CF*lm*NC*NL)/324 + (14700359881*CF*NC*NH)/37507050 + 
       (245*CF*lm*NC*NH)/324 + (44873*CF^2*NC*Pi^2)/15120 - 
       (365*CF*NM*NC*Pi^2)/972 + (CF*lm*NM*NC*Pi^2)/54 - 
       (985*CF*NC*NL*Pi^2)/972 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (2127965*CF^2*NC*Pi^3)/(157464*Sqrt[3]) - 
       (3318875*CF*NC*NH*Pi^3)/(78732*Sqrt[3]) - (91*CF^2*NC*Pi^4)/270 + 
       (954433*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(4374*Sqrt[3]) - 
       (251669*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2187*Sqrt[3]) - 
       (392*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (121598*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(243*Sqrt[3]) - 
       (379300*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (243*Sqrt[3]) - (60799*CF^2*NC*Pi*Log[3]^2)/(5832*Sqrt[3]) - 
       (94825*CF*NC*NH*Pi*Log[3]^2)/(2916*Sqrt[3]) - 
       (CF*NC*(-21*CA*(10679 + 4818*lm) + 2*(109543*CF + 33236*NM + 
            9198*lm*NM + 13055*NL + 9198*lm*NL + 1458*NH + 9198*lm*NH))*
         Log[x]^2)/1134 - (4*CF*NC*(1614*CA + 6329*CF - 1360*NM - 219*NL)*
         Log[x]^3)/81 - (550750*CF^2*NC*PolyGamma[2, 1])/19683 + 
       (289*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (248999*CF*NC*NH*PolyGamma[2, 1])/39366 + 
       (CA*CF*NC*(-18593874*Pi^2 + 21279650*Sqrt[3]*Pi^3 + 1732104*Pi^4 - 
          160380*lm*(245 + 6*Pi^2) + 16415730*Sqrt[3]*Pi*Log[3]^2 - 
          15*(42179067 + 22906392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            13716864*Im[PolyLog[2, (-1)^(1/3)]]^2 - 52530336*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
            8812000*PolyGamma[2, 1] - 32937536*Zeta[3])))/9447840 + 
       (CF*NC*Log[x]*(-36400140*NM - 6747300*lm*NM - 42569730*NL - 
          6747300*lm*NL - 667207236*NH - 6747300*lm*NH + 
          29820420*NM*Pi^2 - 5794740*NL*Pi^2 + 371714000*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 245*CF*(-1608423 + 17946*Pi^2 + 
            486392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 419904*Zeta[3]) - 
          245*CA*(-968970 - 151470*lm + 45*Pi^2 + 243196*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 209952*Zeta[3])))/2143260 - 
       (3419053*CF^2*NC*Zeta[3])/39366 + (539*CF*NM*NC*Zeta[3])/9 - 
       (148*CF*NC*NL*Zeta[3])/9 + (3508115*CF*NC*NH*Zeta[3])/19683, 
      -(CF*NC*(-13522934265876*CF - 4505691010977*NM - 46439284500*lm*NM - 
          807283685250*NL - 46439284500*lm*NL - 27469369346337*NH - 
          46439284500*lm*NH - 347370849000*CF*Pi^2 + 31950450000*NM*Pi^2 - 
          666792000*lm*NM*Pi^2 + 61733826000*NL*Pi^2 - 
          666792000*lm*NL*Pi^2 - 666792000*lm*NH*Pi^2 + 
          321421870000*Sqrt[3]*CF*Pi^3 + 907890130000*Sqrt[3]*NH*Pi^3 + 
          15669612000*CF*Pi^4 - 5649965286000*Sqrt[3]*CF*
           Im[PolyLog[2, (-1)^(1/3)]] + 6931286376000*Sqrt[3]*NH*
           Im[PolyLog[2, (-1)^(1/3)]] + 2448460224000*CF*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 11901792672000*Sqrt[3]*CF*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 33617874528000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 247954014000*Sqrt[3]*CF*Pi*
           Log[3]^2 + 700372386000*Sqrt[3]*NH*Pi*Log[3]^2 - 
          4762800*(7*CA*(265759 + 173580*lm) - 2*(412748*CF + 
              2*(239093 + 55230*lm)*NM + 3*(54215*NL + 36820*lm*NL + 
                6282*NH + 36820*lm*NH)))*Log[x]^2 + 
          1333584000*(5675*CA + 10497*CF - 3620*NM - 526*NL)*Log[x]^3 + 
          292773824000*CF*PolyGamma[2, 1] + 375737292000*NM*
           PolyGamma[2, 1] - 1493127020000*NH*PolyGamma[2, 1] + 
          3780*Log[x]*(303195342*NM + 48510000*lm*NM + 332646300*NL + 
            48510000*lm*NL + 5313981402*NH + 48510000*lm*NH - 
            308876400*NM*Pi^2 + 46393200*NL*Pi^2 - 2964539200*Sqrt[3]*NH*
             Im[PolyLog[2, (-1)^(1/3)]] - 49*CF*(-121823229 + 6249600*Pi^2 + 
              21419200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 17496000*Zeta[
                3]) + 49*CA*(-64332027 - 5445000*lm + 3147300*Pi^2 + 
              10709600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 8748000*Zeta[
                3])) + 11820326056000*CF*Zeta[3] - 2529142056000*NM*
           Zeta[3] + 1060199280000*NL*Zeta[3] - 18427823176000*NH*Zeta[3] - 
          686*CA*(-309122325*Pi^2 + 234272500*Sqrt[3]*Pi^3 + 12198600*Pi^4 - 
            111375*lm*(3343 + 48*Pi^2) + 180724500*Sqrt[3]*Pi*Log[3]^2 + 
            4*(-2815576677 - 1029512625*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              446148000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 2168694000*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 53348000*PolyGamma[2, 
                1] + 2222011000*Zeta[3]))))/81015228000, 
      (151113298457*CF^2*NC)/755827200 + (581480323*CF*NM*NC)/5832000 + 
       (1307*CF*lm*NM*NC)/1296 + (635521*CF*NC*NL)/23328 + 
       (1307*CF*lm*NC*NL)/1296 + (25991162462681*CF*NC*NH)/32406091200 + 
       (1307*CF*lm*NC*NH)/1296 + (862261*CF^2*NC*Pi^2)/68040 + 
       (20569*CF*NM*NC*Pi^2)/972 + (CF*lm*NM*NC*Pi^2)/54 - 
       (424*CF*NC*NL*Pi^2)/243 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (78812545*CF^2*NC*Pi^3)/(2834352*Sqrt[3]) - 
       (31881955*CF*NC*NH*Pi^3)/(354294*Sqrt[3]) - (71*CF^2*NC*Pi^4)/120 + 
       (182761439*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(472392*Sqrt[3]) - 
       (8049679*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(59049*Sqrt[3]) - 
       (206*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (2251787*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2187*Sqrt[3]) - (7287304*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (2251787*CF^2*NC*Pi*Log[3]^2)/(104976*Sqrt[3]) - 
       (910913*CF*NC*NH*Pi*Log[3]^2)/(13122*Sqrt[3]) - 
       (CF*NC*(-35*CA*(244327 + 121968*lm) + 
          4*(1833930*CF + 7*(-121483 + 27720*lm)*NM + 
            5*(53284*NL + 38808*lm*NL + 8247*NH + 38808*lm*NH)))*
         Log[x]^2)/22680 - (CF*NC*(48233*CA + 187524*CF - 87960*NM - 
          5544*NL)*Log[x]^3)/243 - (12142822*CF^2*NC*PolyGamma[2, 1])/
        177147 + (3457*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (3392447*CF*NC*NH*PolyGamma[2, 1])/354294 + 
       (CA*CF*NC*(-159412135860*Pi^2 + 110337563000*Sqrt[3]*Pi^3 + 
          7396084080*Pi^4 - 101039400*lm*(1307 + 24*Pi^2) + 
          85117548600*Sqrt[3]*Pi*Log[3]^2 - 21*(147663588399 + 
            73104575600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            38925100800*Im[PolyLog[2, (-1)^(1/3)]]^2 - 194554396800*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 38857030400*
             PolyGamma[2, 1] - 138309707200*Zeta[3])))/23808556800 + 
       (CF*NC*Log[x]*(4*(-3969*NM*(8904427 + 265500*lm - 4216800*Pi^2) - 
            5*(39690*NL*(43783 + 5310*lm + 5544*Pi^2) + NH*(25570201317 + 
                210753900*lm - 14283115840*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]]))) + 245*CF*(-1299215559 + 55180440*Pi^2 + 
            360285920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            251942400*Zeta[3]) - 245*CA*(-767362677 - 94624200*lm + 
            21767940*Pi^2 + 180142960*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            125971200*Zeta[3])))/771573600 - (76103431*CF^2*NC*Zeta[3])/
        354294 + (1241*CF*NM*NC*Zeta[3])/9 - (310*CF*NC*NL*Zeta[3])/9 + 
       (61855331*CF*NC*NH*Zeta[3])/177147, 
      (19431702232841*CF^2*NC)/102876480000 + (172626453169*CF*NM*NC)/
        1500282000 + (53303*CF*lm*NM*NC)/72900 + (78248*CF*NC*NL)/3645 + 
       (53303*CF*lm*NC*NL)/72900 + (27025847579749*CF*NC*NH)/40507614000 + 
       (53303*CF*lm*NC*NH)/72900 + (46977013*CF^2*NC*Pi^2)/816480 + 
       (39382*CF*NM*NC*Pi^2)/3645 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (4519*CF*NC*NL*Pi^2)/3645 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (3664171*CF^2*NC*Pi^3)/(157464*Sqrt[3]) - 
       (12272960*CF*NC*NH*Pi^3)/(177147*Sqrt[3]) - (1661*CF^2*NC*Pi^4)/
        4860 + (239873027*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (656100*Sqrt[3]) - (22737016*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (59049*Sqrt[3]) - (412*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (1046906*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1215*Sqrt[3]) - (5610496*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (523453*CF^2*NC*Pi*Log[3]^2)/(29160*Sqrt[3]) - 
       (350656*CF*NC*NH*Pi*Log[3]^2)/(6561*Sqrt[3]) + 
       (CF*NC*(83316331*CF + 21*CA*(-583109 + 1152800*lm) - 
          40*((-166357 + 110040*lm)*NM + 3*(70*(751 + 524*lm)*NL + 
              (8091 + 36680*lm)*NH)))*Log[x]^2)/170100 - 
       (4*CF*NC*(93614*CA + 63895*CF - 85600*NM - 5240*NL)*Log[x]^3)/1215 + 
       (81881485*CF^2*NC*PolyGamma[2, 1])/531441 - 
       (11360*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (16913660*CF*NC*NH*PolyGamma[2, 1])/531441 + 
       (CF*NC*Log[x]*(-80*(27*NM*(324645547 + 6582660*lm - 128007600*Pi^2) + 
            79380*NL*(20240 + 2239*lm + 2620*Pi^2) + 
            NH*(24566883681 + 177731820*lm - 13745715200*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) + 63*CF*(-36913648833 + 
            5424501600*Pi^2 + 5862673600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            3919104000*Zeta[3]) - 252*CA*(-4818137343 - 310325400*lm + 
            680409450*Pi^2 + 732834200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            489888000*Zeta[3])))/3857868000 - (209114516*CF^2*NC*Zeta[3])/
        2657205 - (19144*CF*NM*NC*Zeta[3])/243 - (2104*CF*NC*NL*Zeta[3])/
        81 + (219599848*CF*NC*NH*Zeta[3])/531441 + 
       (CA*CF*NC*(-9116991455589 - 2442063205260*Pi^2 + 323179882200*Sqrt[3]*
           Pi^3 + 14788494000*Pi^4 - 6286896*lm*(53303 + 600*Pi^2) - 
          5077632235536*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          1907329939200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 11966889352320*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 249310194840*Sqrt[3]*Pi*
           Log[3]^2 - 6419508424000*PolyGamma[2, 1] + 3463578892480*Zeta[3]))/
        83329948800, (4279949973273679*CF^2*NC)/19443654720000 - 
       (767322198401*CF*NM*NC)/2000376000 + (40931*CF*lm*NM*NC)/32400 + 
       (30875599*CF*NC*NL)/583200 + (40931*CF*lm*NC*NL)/32400 + 
       (930737930066283187*CF*NC*NH)/646987610808000 + 
       (40931*CF*lm*NC*NH)/32400 + (91062877*CF^2*NC*Pi^2)/1360800 + 
       (1102157*CF*NM*NC*Pi^2)/4860 + (CF*lm*NM*NC*Pi^2)/54 - 
       (3236*CF*NC*NL*Pi^2)/1215 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (52465399*CF^2*NC*Pi^3)/(1062882*Sqrt[3]) - 
       (88203220*CF*NC*NH*Pi^3)/(531441*Sqrt[3]) - (124*CF^2*NC*Pi^4)/135 + 
       (5581112581*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(8857350*Sqrt[3]) - 
       (20434829*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(177147*Sqrt[3]) - 
       (896*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (59960456*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (32805*Sqrt[3]) - (40321472*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (7495057*CF^2*NC*Pi*Log[3]^2)/(196830*Sqrt[3]) - 
       (2520092*CF*NC*NH*Pi*Log[3]^2)/(19683*Sqrt[3]) - 
       (CF*NC*(30708579*CF - 11*CA*(23812193 + 19404000*lm) + 
          10*(11*(-14457727 + 352800*lm)*NM + 7700*(677 + 504*lm)*NL + 
            3*(329741 + 1293600*lm)*NH))*Log[x]^2)/623700 - 
       (CF*NC*(595041*CA + 4*(443713*CF - 600*(880*NM + 21*NL)))*Log[x]^3)/
        1215 - (389105077*CF^2*NC*PolyGamma[2, 1])/1594323 + 
       (32833*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (43020887*CF*NC*NH*PolyGamma[2, 1])/3188646 + 
       (CF*NC*Log[x]*(20*(-29403*NM*(1592694247 + 19959660*lm - 
              1026354000*Pi^2) - 28814940*NL*(207826 + 20367*lm + 
              25200*Pi^2) + NH*(-85407958363767 - 586873882980*lm + 
              47813201497600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          121*CF*(-9820984460937 + 1091748067200*Pi^2 + 2350449875200*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1388832480000*Zeta[3]) - 
          1210*CA*(-563346833673 - 53352171180*lm + 50985535860*Pi^2 + 
            117522493760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            69441624000*Zeta[3])))/1400406084000 - 
       (5911733794*CF^2*NC*Zeta[3])/7971615 + (6409*CF*NM*NC*Zeta[3])/9 - 
       (562*CF*NC*NL*Zeta[3])/9 + (963397967*CF*NC*NH*Zeta[3])/1594323 + 
       (CA*CF*NC*(-13363586029449081 - 2943870979429800*Pi^2 + 
          719825274280000*Sqrt[3]*Pi^3 + 41479796736000*Pi^4 - 
          14852791800*lm*(40931 + 600*Pi^2) - 9188743753358400*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 4355378657280000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 26654101584768000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 555293783016000*Sqrt[3]*Pi*
           Log[3]^2 + 10677043312880000*PolyGamma[2, 1] + 
          34427928045952000*Zeta[3]))/87496446240000, 
      (-142361579031276407*CF^2*NC)/174992892480000 - 
       (145647127928741*CF*NM*NC)/1540446692400 + (89*CF*lm*NM*NC)/100 + 
       (34680169*CF*NC*NL)/874800 + (89*CF*lm*NC*NL)/100 + 
       (1693204772304460579*CF*NC*NH)/1455722124318000 + 
       (89*CF*lm*NC*NH)/100 + (355909649*CF^2*NC*Pi^2)/816480 + 
       (827933*CF*NM*NC*Pi^2)/7290 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (6653*CF*NC*NL*Pi^2)/3645 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (1529631355*CF^2*NC*Pi^3)/
        (38263752*Sqrt[3]) - (596230285*CF*NC*NH*Pi^3)/(4782969*Sqrt[3]) - 
       (857*CF^2*NC*Pi^4)/1620 + (18699517387*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(31886460*Sqrt[3]) - 
       (831722342*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) - 
       (580*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (87407506*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (59049*Sqrt[3]) - (272562416*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (43703753*CF^2*NC*Pi*Log[3]^2)/(1417176*Sqrt[3]) - 
       (17035151*CF*NC*NH*Pi*Log[3]^2)/(177147*Sqrt[3]) + 
       (CF*NC*(27405891183*CF + 165*CA*(-72611839 + 8454600*lm) - 
          40*(14*(-12244669 + 452925*lm)*NM + 17325*(515 + 366*lm)*NL + 
            (1640659 + 6340950*lm)*NH))*Log[x]^2)/5613300 + 
       (4*CF*NC*(-387482*CA + 278093*CF + 352770*NM + 9150*NL)*Log[x]^3)/
        1215 + (8407442752*CF^2*NC*PolyGamma[2, 1])/4782969 - 
       (109465*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (240672191*CF*NC*NH*PolyGamma[2, 1])/4782969 + 
       (CF*NC*Log[x]*(40*(-1134*NM*(234022733191 + 1509582690*lm - 
              82012807800*Pi^2) - 5*(12966723*NL*(295933 + 26404*lm + 
                36600*Pi^2) + 2*NH*(28816666006629 + 171186677046*lm - 
                16160225644640*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
          121*CF*(-84521914828989 + 54423972640800*Pi^2 + 17131871176000*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 9721827360000*Zeta[3]) - 
          242*CA*(-22136687901519 - 1556242518600*lm + 13622764169700*Pi^2 + 
            4282967794000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            2430456840000*Zeta[3])))/12603654756000 + 
       (CA*CF*NC*(153212789812306437 - 86050232313601500*Pi^2 + 
          2623317773825000*Sqrt[3]*Pi^3 + 106737562890000*Pi^4 - 
          89116750800*lm*(21627 + 200*Pi^2) - 38483606782446000*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 12686984704800000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 97137709567920000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2023702282665000*Sqrt[3]*
           Pi*Log[3]^2 - 346050343672320000*PolyGamma[2, 1] - 
          415333386872376000*Zeta[3]))/393734008080000 + 
       (50535894598*CF^2*NC*Zeta[3])/23914845 - (289502*CF*NM*NC*Zeta[3])/
        243 - (3668*CF*NC*NL*Zeta[3])/81 + (3242239426*CF*NC*NH*Zeta[3])/
        4782969, (-1437203417285683*CF^2*NC)/2160406080000 - 
       (40118865069119*CF*NM*NC)/7715736000 + (49231*CF*lm*NM*NC)/32400 + 
       (133440827*CF*NC*NL)/1458000 + (49231*CF*lm*NC*NL)/32400 + 
       (1116344145913337213879*CF*NC*NH)/473810593648392000 + 
       (49231*CF*lm*NC*NH)/32400 + (1162751087*CF^2*NC*Pi^2)/3061800 + 
       (1657429*CF*NM*NC*Pi^2)/972 + (CF*lm*NM*NC*Pi^2)/54 - 
       (9157*CF*NC*NL*Pi^2)/2430 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (2028172321*CF^2*NC*Pi^3)/
        (25509168*Sqrt[3]) - (1769251085*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) - 
       (1423*CF^2*NC*Pi^4)/1080 + (1263618227*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1312200*Sqrt[3]) - 
       (7074311*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
       (1226*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (289738903*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (98415*Sqrt[3]) - (202200124*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (289738903*CF^2*NC*Pi*Log[3]^2)/(4723920*Sqrt[3]) - 
       (50550031*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) + 
       (CF*NC*(3861*CA*(-11705377 + 7099400*lm) + 
          20*(7714718440*CF - 1001*(-49095943 + 248940*lm)*NM - 
            329579250*NL - 249188940*lm*NL - 71979253*NH - 
            249188940*lm*NH))*Log[x]^2)/48648600 - 
       (CF*NC*(1784733*CA + 1944868*CF - 10967880*NM - 82980*NL)*Log[x]^3)/
        1215 - (21946635265*CF^2*NC*PolyGamma[2, 1])/14348907 + 
       (298369*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (518719631*CF*NC*NH*PolyGamma[2, 1])/28697814 - 
       (591575492231*CF^2*NC*Zeta[3])/143489070 + (193285*CF*NM*NC*Zeta[3])/
        27 - (308*CF*NC*NL*Zeta[3])/3 + (13779235463*CF*NC*NH*Zeta[3])/
        14348907 + (CA*CF*NC*(10800178503621021 - 7474405946870835*Pi^2 + 
          521747329577250*Sqrt[3]*Pi^3 + 26522360266500*Pi^4 - 
          6683756310*lm*(49231 + 600*Pi^2) - 6319278936133380*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 2681766077256000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 19319558260917600*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 402490797102450*Sqrt[3]*Pi*
           Log[3]^2 + 30110783583580000*PolyGamma[2, 1] + 
          82493131334205200*Zeta[3]))/39373400808000 + 
       CF*Log[x]*((-1236564641*NM*NC)/1530900 - (119*lm*NM*NC)/10 - 
         (2348089*NC*NL)/16200 - (119*lm*NC*NL)/10 - 
         (2408325362255269*NC*NH)/1183343140980 - (119*lm*NC*NH)/10 + 
         (182647*NM*NC*Pi^2)/81 - (461*NC*NL*Pi^2)/27 + 
         (202200124*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(59049*Sqrt[3]) + 
         CF*NC*(-19834128852169/11573604000 + (2355179*Pi^2)/4860 + 
           (289738903*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
           168*Zeta[3]) + CA*NC*(11016108144371/11573604000 + (1309*lm)/20 - 
           (2307809*Pi^2)/9720 - (289738903*Im[PolyLog[2, (-1)^(1/3)]])/
            (590490*Sqrt[3]) + 84*Zeta[3])), 
      (-46798481297260189253191*CF^2*NC)/4891226337708480000 - 
       (269921069086340710823*CF*NM*NC)/118452648412098000 + 
       (3748219*CF*lm*NM*NC)/3572100 + (7076227577*CF*NC*NL)/107163000 + 
       (3748219*CF*lm*NC*NL)/3572100 + (17889784115108038251103*CF*NC*NH)/
        9594664521379938000 + (3748219*CF*lm*NC*NH)/3572100 + 
       (89148353527*CF^2*NC*Pi^2)/28576800 + (18706174*CF*NM*NC*Pi^2)/
        25515 + (2*CF*lm*NM*NC*Pi^2)/243 - (7139*CF*NC*NL*Pi^2)/2835 + 
       (2*CF*lm*NC*NL*Pi^2)/243 + (2*CF*lm*NC*NH*Pi^2)/243 - 
       (903690824*CF^2*NC*Pi^3)/(14348907*Sqrt[3]) - 
       (2935892155*CF*NC*NH*Pi^3)/(14348907*Sqrt[3]) - 
       (367*CF^2*NC*Pi^4)/486 + (5176122769199*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5859137025*Sqrt[3]) - 
       (15601294504*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (23914845*Sqrt[3]) - (776*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (14459053184*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6200145*Sqrt[3]) - (1342122128*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (903690824*CF^2*NC*Pi*Log[3]^2)/(18600435*Sqrt[3]) - 
       (83882633*CF*NC*NH*Pi*Log[3]^2)/(531441*Sqrt[3]) + 
       (CF*NC*(18840288042017*CF + 1768*CA*(-5184775669 + 114726150*lm) - 
          280*((-15676918927 + 131711580*lm)*NM + 180180*(1015 + 731*lm)*
             NL + (38053931 + 131711580*lm)*NH))*Log[x]^2)/510810300 + 
       (4*CF*NC*(-15005786*CA + 35*(680065*CF + 297928*NM + 2924*NL))*
         Log[x]^3)/8505 + (708942044887*CF^2*NC*PolyGamma[2, 1])/43046721 - 
       (334612*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (3215856056*CF*NC*NH*PolyGamma[2, 1])/43046721 + 
       (CF*NC*Log[x]*(560*(-972*NM*(258822046569509 + 616657896855*lm - 
              101646037543050*Pi^2) - 7*(134165889*NL*(8534541 + 638220*lm + 
                1023400*Pi^2) + 10*NH*(1709836049895351 + 8562735367758*lm - 
                960576938841520*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) + 
          169*CF*(715722090916607553 + 884939337738363600*Pi^2 + 
            68582181062348800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            33878623984128000*Zeta[3]) - 2366*CA*(25073540164921827 - 
            780272927002800*lm + 31615771144696200*Pi^2 + 2449363609369600*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1209950856576000*Zeta[3])))/
        44730370729044000 + CA*CF*NC*(5825534331168888616751/
          1222806584427120000 - (66889335329*Pi^2)/42865200 + 
         (451845412*Pi^3)/(14348907*Sqrt[3]) + (1867*Pi^4)/4860 - 
         (11*lm*(3748219 + 29400*Pi^2))/7144200 - 
         (5176122769199*Im[PolyLog[2, (-1)^(1/3)]])/(11718274050*Sqrt[3]) + 
         (388*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (7229526592*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6200145*Sqrt[3]) + (451845412*Pi*Log[3]^2)/(18600435*Sqrt[3]) - 
         (708942044887*PolyGamma[2, 1])/86093442 - (19350352773524*Zeta[3])/
          1506635235) + (38702956199683*CF^2*NC*Zeta[3])/1506635235 - 
       (828536*CF*NM*NC*Zeta[3])/81 - (1952*CF*NC*NL*Zeta[3])/27 + 
       (44562249568*CF*NC*NH*Zeta[3])/43046721, 
      (-326187458188583248376809*CF^2*NC)/44021037039376320000 - 
       (583670639631198401*CF*NM*NC)/14377502462400 + 
       (2820319*CF*lm*NM*NC)/1587600 + (5202867223*CF*NC*NL)/35721000 + 
       (2820319*CF*lm*NC*NL)/1587600 + (1247158185958866050456221*CF*NC*NH)/
        345407922769677768000 + (2820319*CF*lm*NC*NH)/1587600 + 
       (700259312801*CF^2*NC*Pi^2)/314344800 + (410004143*CF*NM*NC*Pi^2)/
        34020 + (CF*lm*NM*NC*Pi^2)/54 - (86059*CF*NC*NL*Pi^2)/17010 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (123498173299*CF^2*NC*Pi^3)/(1033121304*Sqrt[3]) - 
       (223146037135*CF*NC*NH*Pi^3)/(516560652*Sqrt[3]) - 
       (161*CF^2*NC*Pi^4)/90 + (73857966185033*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(52732233225*Sqrt[3]) + 
       (36527185937*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (215233605*Sqrt[3]) - (536*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (246996346598*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (55801305*Sqrt[3]) - (25502404244*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (123498173299*CF^2*NC*Pi*Log[3]^2)/(1339231320*Sqrt[3]) - 
       (6375601061*CF*NC*NH*Pi*Log[3]^2)/(19131876*Sqrt[3]) + 
       (CF*NC*(130*CA*(-14800675697 + 1131786810*lm) + 
          7*(599118368953*CF - 10*(13*(-26992040909 + 29397060*lm)*NM + 
              210210*(2377 + 1818*lm)*NL + (120986911 + 382161780*lm)*NH)))*
         Log[x]^2)/170270100 + (CF*NC*(-17100009*CA + 
          4*(3049673*CF + 38171560*NM + 74235*NL))*Log[x]^3)/2835 - 
       (1636962707776*CF^2*NC*PolyGamma[2, 1])/129140163 + 
       (2689633*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (6024448391*CF*NC*NH*PolyGamma[2, 1])/258280326 - 
       (27794197884233*CF^2*NC*Zeta[3])/903981141 + 
       (1988893*CF*NM*NC*Zeta[3])/27 - (472*CF*NC*NL*Zeta[3])/3 + 
       (185194467131*CF*NC*NH*Zeta[3])/129140163 + 
       CA*CF*NC*(19958265939350109636667/5502629629922040000 - 
         (95461477759*Pi^2)/85730400 + (123498173299*Pi^3)/
          (2066242608*Sqrt[3]) + (491*Pi^4)/540 - 
         (11*lm*(2820319 + 29400*Pi^2))/3175200 - 
         (73857966185033*Im[PolyLog[2, (-1)^(1/3)]])/(105464466450*Sqrt[3]) + 
         (268*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (123498173299*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55801305*Sqrt[3]) + (123498173299*Pi*Log[3]^2)/
          (2678462640*Sqrt[3]) + (818481353888*PolyGamma[2, 1])/129140163 + 
         (27881627368907*Zeta[3])/1807962282) + 
       CF*Log[x]*((14318358982489*NM*NC)/1296672300 - (30271*lm*NM*NC)/
          1890 - (25735601*NC*NL)/113400 - (30271*lm*NC*NL)/1890 - 
         (1516453380658006573*NC*NH)/479253972096900 - 
         (30271*lm*NC*NH)/1890 + (1090777*NM*NC*Pi^2)/81 - 
         (707*NC*NL*Pi^2)/27 + (25502404244*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(-2749442464410112841/794030249628000 + (110489*Pi^2)/42 + 
           (246996346598*Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) - 
           224*Zeta[3]) + CA*NC*(92659472642891521/49626890601750 + 
           (332981*lm)/3780 - (4450231*Pi^2)/3402 - 
           (123498173299*Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) + 
           112*Zeta[3])), (-3640590939846997182176536799*CF^2*NC)/
        48357109187754887520000 - (29957244327208779988643*CF*NM*NC)/
        1895242374593568000 + (34546727*CF*lm*NM*NC)/28576800 + 
       (43797339659*CF*NC*NL)/428652000 + (34546727*CF*lm*NC*NL)/28576800 + 
       (79232984894653663711607*CF*NC*NH)/28196565124055328000 + 
       (34546727*CF*lm*NC*NH)/28576800 + (479417473387*CF^2*NC*Pi^2)/
        20956320 + (105072451*CF*NM*NC*Pi^2)/25515 + (2*CF*lm*NM*NC*Pi^2)/
        243 - (37631*CF*NC*NL*Pi^2)/11340 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (96317780155*CF^2*NC*Pi^3)/
        (1033121304*Sqrt[3]) - (81148096015*CF*NC*NH*Pi^3)/
        (258280326*Sqrt[3]) - (2479*CF^2*NC*Pi^4)/2430 + 
       (107009205744479*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (84371573160*Sqrt[3]) - (163689371498*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(215233605*Sqrt[3]) - 
       (1000*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (38527112062*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (11160261*Sqrt[3]) - (18548136232*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (19263556031*CF^2*NC*Pi*Log[3]^2)/(267846264*Sqrt[3]) - 
       (2318517029*CF*NC*NH*Pi*Log[3]^2)/(9565938*Sqrt[3]) + 
       (CF*NC*(3*CA*(-92695972958359 + 405301696800*lm) + 
          4*(139810968848349*CF - 70*((-358560192187 + 789548760*lm)*NM + 
              49*(12870*(1721 + 1252*lm)*NL + (5050391 + 16113240*lm)*
                 NH))))*Log[x]^2)/2043241200 + 
       (CF*NC*(-400630505*CA + 760134782*CF + 280*(684788*NM + 2191*NL))*
         Log[x]^3)/8505 + (57827043583072*CF^2*NC*PolyGamma[2, 1])/
        387420489 - (3023857*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (40984127897*CF*NC*NH*PolyGamma[2, 1])/387420489 + 
       CA*CF*NC*(14554046575456320432538225043/386856873502039100160000 - 
         (392275288261*Pi^2)/34292160 + (96317780155*Pi^3)/
          (2066242608*Sqrt[3]) + (31*Pi^4)/60 - 
         (11*lm*(34546727 + 235200*Pi^2))/57153600 - 
         (107009205744479*Im[PolyLog[2, (-1)^(1/3)]])/(168743146320*
           Sqrt[3]) + (500*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (19263556031*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (11160261*Sqrt[3]) + (19263556031*Pi*Log[3]^2)/
          (535692528*Sqrt[3]) - (28913521791536*PolyGamma[2, 1])/387420489 - 
         (3405397575971173*Zeta[3])/27119434230) + 
       (3405376148270053*CF^2*NC*Zeta[3])/13559717115 - 
       (6899882*CF*NM*NC*Zeta[3])/81 - (2924*CF*NC*NL*Zeta[3])/27 + 
       (580742640406*CF*NC*NH*Zeta[3])/387420489 + 
       CF*Log[x]*((-31139718149377867*NM*NC)/2629651424400 - 
         (56123*lm*NM*NC)/5670 - (2906639*NC*NL)/18900 - 
         (56123*lm*NC*NL)/5670 - (629234157870898457*NC*NH)/
          273859412626800 - (56123*lm*NC*NH)/5670 + (1374434*NM*NC*Pi^2)/
          243 - (4382*NC*NL*Pi^2)/243 + (18548136232*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(11868549181700960429117/268382224374264000 + 
           (21994073*Pi^2)/945 + (38527112062*Im[PolyLog[2, (-1)^(1/3)]])/
            (33480783*Sqrt[3]) - 168*Zeta[3]) + 
         CA*NC*(-1693003997446704793607/76680635535504000 + 
           (617353*lm)/11340 - (65987399*Pi^2)/5670 - 
           (19263556031*Im[PolyLog[2, (-1)^(1/3)]])/(33480783*Sqrt[3]) + 
           84*Zeta[3])), (-19464537138228495146754020671*CF^2*NC)/
        386856873502039100160000 - (371660972971835556283481*CF*NM*NC)/
        1263494916395712000 + (12916651*CF*lm*NM*NC)/6350400 + 
       (218039556151*CF*NC*NL)/1000188000 + (12916651*CF*lm*NC*NL)/
        6350400 + (3400203583988983307102272553*CF*NC*NH)/
        646472047454257856832000 + (12916651*CF*lm*NC*NH)/6350400 + 
       (50606751021923*CF^2*NC*Pi^2)/3772137600 + (147477079*CF*NM*NC*Pi^2)/
        1701 + (CF*lm*NM*NC*Pi^2)/54 - (444721*CF*NC*NL*Pi^2)/68040 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (78390759931*CF^2*NC*Pi^3)/(459165024*Sqrt[3]) - 
       (82326756575*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) - 
       (2519*CF^2*NC*Pi^4)/1080 + (3304330176311389*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1687431463200*Sqrt[3]) + 
       (50288308493*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (100442349*Sqrt[3]) - (2042*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (78390759931*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (12400290*Sqrt[3]) - (37635088720*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (78390759931*CF^2*NC*Pi*Log[3]^2)/(595213920*Sqrt[3]) - 
       (2352193045*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       (CF*NC*(3657931098042266*CF + 765*CA*(-2345843230853 + 
            38032874880*lm) - 280*(17*(-5059015957189 + 1111350240*lm)*NM + 
            4084080*(5995 + 4626*lm)*NL + (6416759551 + 18892954080*lm)*
             NH))*Log[x]^2)/23156733600 + 
       (CF*NC*(-535499025*CA + 28*(30687113*CF + 218648940*NM + 92520*NL))*
         Log[x]^3)/17010 - (130659260597032*CF^2*NC*PolyGamma[2, 1])/
        1162261467 + (24212737*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (67973462879*CF*NC*NH*PolyGamma[2, 1])/2324522934 - 
       (41553921261829891*CF^2*NC*Zeta[3])/162716605380 + 
       (19392823*CF*NM*NC*Zeta[3])/27 - (686*CF*NC*NL*Zeta[3])/3 + 
       (2373728026523*CF*NC*NH*Zeta[3])/1162261467 + 
       CA*CF*NC*(3877136152263122711928695501/154742749400815640064000 - 
         (50601721094503*Pi^2)/7544275200 + (78390759931*Pi^3)/
          (918330048*Sqrt[3]) + (2551*Pi^4)/2160 - 
         (11*lm*(12916651 + 117600*Pi^2))/12700800 - 
         (3304330176311389*Im[PolyLog[2, (-1)^(1/3)]])/(3374862926400*
           Sqrt[3]) + (1021*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (78390759931*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (24800580*Sqrt[3]) + (78390759931*Pi*Log[3]^2)/
          (1190427840*Sqrt[3]) + (65329630298516*PolyGamma[2, 1])/
          1162261467 + (41575737340032691*Zeta[3])/325433210760) + 
       CF*Log[x]*((7534344673366717*NM*NC)/50088598560 - 
         (26119*lm*NM*NC)/1260 - (133032269*NC*NL)/396900 - 
         (26119*lm*NC*NL)/1260 - (738218436214614121411*NC*NH)/
          158290740498290400 - (26119*lm*NC*NH)/1260 + (7288990*NM*NC*Pi^2)/
          81 - (1028*NC*NL*Pi^2)/27 + (37635088720*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(-185805844186878933811/29820247152696000 + 
           (1032756059*Pi^2)/68040 + (78390759931*Im[PolyLog[2, (-1)^(1/3)]])/
            (37200870*Sqrt[3]) - 288*Zeta[3]) + 
         CA*NC*(393779531752692818891/119280988610784000 + (287309*lm)/2520 - 
           (1031360959*Pi^2)/136080 - (78390759931*Im[PolyLog[2, (-1)^
                (1/3)]])/(74401740*Sqrt[3]) + 144*Zeta[3])), 
      (-186073827189143801478295864669*CF^2*NC)/326410487017345490760000 - 
       (20275999675755693543535819*CF*NM*NC)/221698233009004752000 + 
       (176010259*CF*lm*NM*NC)/128595600 + (1346761247147*CF*NC*NL)/
        9001692000 + (176010259*CF*lm*NC*NL)/128595600 + 
       (5694155922685557071682257497*CF*NC*NH)/1409806349640631557014400 + 
       (176010259*CF*lm*NC*NH)/128595600 + (981072641571487*CF^2*NC*Pi^2)/
        5658206400 + (1685213171*CF*NM*NC*Pi^2)/76545 + 
       (2*CF*lm*NM*NC*Pi^2)/243 - (646951*CF*NC*NL*Pi^2)/153090 + 
       (2*CF*lm*NC*NL*Pi^2)/243 + (2*CF*lm*NC*NH*Pi^2)/243 - 
       (816165276421*CF^2*NC*Pi^3)/(6198727824*Sqrt[3]) - 
       (533030300600*CF*NC*NH*Pi^3)/(1162261467*Sqrt[3]) - 
       (143*CF^2*NC*Pi^4)/108 + (39930614659694239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(22780324753200*Sqrt[3]) - 
       (33657049925288*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (40679151345*Sqrt[3]) - (1252*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        9 - (816165276421*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (167403915*Sqrt[3]) - (243670994560*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (816165276421*CF^2*NC*Pi*Log[3]^2)/(8035387920*Sqrt[3]) - 
       (15229437160*CF*NC*NH*Pi*Log[3]^2)/(43046721*Sqrt[3]) + 
       (CF*NC*(51*CA*(-2122266244502057 + 1735897363200*lm) + 
          16*(13543516585238126*CF - 105*((-16364013615623 + 9581251680*lm)*
               NM + 65*(94248*(2133 + 1564*lm)*NL + (49198063 + 147403872*
                   lm)*NH))))*Log[x]^2)/104205301200 + 
       (2*CF*NC*(-4392928501*CA + 15*(579295351*CF + 94624432*NM + 
            87584*NL))*Log[x]^3)/25515 + (4689436048052137*CF^2*NC*
         PolyGamma[2, 1])/3486784401 - (81708104*CF*NM*NC*PolyGamma[2, 1])/
        243 + (503352146804*CF*NC*NH*PolyGamma[2, 1])/3486784401 + 
       CA*CF*NC*(2976946550243342934291187360393/10445135584555055704320000 - 
         (981081540549337*Pi^2)/11316412800 + (816165276421*Pi^3)/
          (12397455648*Sqrt[3]) + (6499*Pi^4)/9720 + 
         lm*(-1936112849/257191200 - (11*Pi^2)/243) - 
         (39930614659694239*Im[PolyLog[2, (-1)^(1/3)]])/(45560649506400*
           Sqrt[3]) + (626*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (816165276421*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (334807830*Sqrt[3]) + (816165276421*Pi*Log[3]^2)/
          (16070775840*Sqrt[3]) - (4689436048052137*PolyGamma[2, 1])/
          6973568802 - (572382584011582487*Zeta[3])/488149816140) + 
       (572381134628486417*CF^2*NC*Zeta[3])/244074908070 - 
       (176666584*CF*NM*NC*Zeta[3])/243 - (12520*CF*NC*NL*Zeta[3])/81 + 
       (7263057328120*CF*NC*NH*Zeta[3])/3486784401 + 
       CF*Log[x]*((-20009865651662319967*NM*NC)/379984630825800 - 
         (321871*lm*NM*NC)/25515 - (398876729*NC*NL)/1786050 - 
         (321871*lm*NC*NL)/25515 - (642442426445481400903*NC*NH)/
          191775320219082600 - (321871*lm*NC*NH)/25515 + 
         (6766840*NM*NC*Pi^2)/243 - (6256*NC*NL*Pi^2)/243 + 
         (243670994560*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(341647915961929933534537/
            805146673122792000 + (17531046787*Pi^2)/102060 + 
           (816165276421*Im[PolyLog[2, (-1)^(1/3)]])/(502211745*Sqrt[3]) - 
           (640*Zeta[3])/3) + CA*NC*(-12199430380859164835461/
            57510476651628000 + (3540581*lm)/51030 - (17531325037*Pi^2)/
            204120 - (816165276421*Im[PolyLog[2, (-1)^(1/3)]])/
            (1004423490*Sqrt[3]) + (320*Zeta[3])/3)), 
      (-474001900682390619334067590223*CF^2*NC)/1492162226365007957760000 - 
       (108957147466675287265399*CF*NM*NC)/50539796655828480 + 
       (130989059*CF*lm*NM*NC)/57153600 + (11206357838813*CF*NC*NL)/
        36006768000 + (130989059*CF*lm*NC*NL)/57153600 + 
       (3701518171785598710332592470486923*CF*NC*NH)/
        502832811113624776177212019200 + (130989059*CF*lm*NC*NH)/57153600 + 
       (2018074489732853*CF^2*NC*Pi^2)/24518894400 + 
       (10961232419*CF*NM*NC*Pi^2)/17010 + (CF*lm*NM*NC*Pi^2)/54 - 
       (185947*CF*NC*NL*Pi^2)/22680 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (121037561357*CF^2*NC*Pi^3)/
        (516560652*Sqrt[3]) - (698953043285*CF*NC*NH*Pi^3)/
        (774840978*Sqrt[3]) - (398*CF^2*NC*Pi^4)/135 + 
       (3774217718792746*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1423770297075*Sqrt[3]) + (5850418182649*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5811307335*Sqrt[3]) - 
       (2528*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (484150245428*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (55801305*Sqrt[3]) - (159760695608*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4782969*Sqrt[3]) - 
       (121037561357*CF^2*NC*Pi*Log[3]^2)/(669615660*Sqrt[3]) - 
       (19970086951*CF*NC*NH*Pi*Log[3]^2)/(28697814*Sqrt[3]) + 
       (CF*NC*(969*CA*(-333500683420493 + 1193706914400*lm) + 
          10*(64907392759129183*CF - 42*(323*(-37615818255791 + 1550268720*
                 lm)*NM + 232792560*(2768 + 2151*lm)*NL + 3*(59937338609 + 
                166912265520*lm)*NH)))*Log[x]^2)/659966907600 + 
       (CF*NC*(-9390793855*CA + 4*(4453105283*CF + 3780*(8724808*NM + 
              717*NL)))*Log[x]^3)/51030 - (10558129202565295*CF^2*NC*
         PolyGamma[2, 1])/10460353203 + (217922689*CF*NM*NC*PolyGamma[2, 1])/
        54 + (749489149751*CF*NC*NH*PolyGamma[2, 1])/20920706406 - 
       (1611912877680472139*CF^2*NC*Zeta[3])/732224724210 + 
       (183078503*CF*NM*NC*Zeta[3])/27 - (2870*CF*NC*NL*Zeta[3])/9 + 
       (29309094477527*CF*NC*NH*Zeta[3])/10460353203 + 
       CA*CF*NC*(3315274027329299283880172610119/20890271169110111408640000 - 
         (155232536688811*Pi^2)/3772137600 + (121037561357*Pi^3)/
          (1033121304*Sqrt[3]) + (67*Pi^4)/45 + lm*(-1440879649/114307200 - 
           (11*Pi^2)/108) - (1887108859396373*Im[PolyLog[2, (-1)^(1/3)]])/
          (1423770297075*Sqrt[3]) + (1264*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (242075122714*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55801305*Sqrt[3]) + (121037561357*Pi*Log[3]^2)/
          (1339231320*Sqrt[3]) + (10558129202565295*PolyGamma[2, 1])/
          20920706406 + (1612045166280646079*Zeta[3])/1464449448420) + 
       CF*Log[x]*((2528254436181176371*NM*NC)/1753100949600 - 
         (295271*lm*NM*NC)/11340 - (6762602587*NC*NL)/14288400 - 
         (295271*lm*NC*NL)/11340 - (7910585092780607258829719*NC*NH)/
          1200002103717539522400 - (295271*lm*NC*NH)/11340 + 
         (5816704*NM*NC*Pi^2)/9 - (478*NC*NL*Pi^2)/9 + 
         (159760695608*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (14348907*Sqrt[3]) + CF*NC*(-2196375342929060423309/
            536764448748528000 + (9310578197*Pi^2)/102060 + 
           (484150245428*Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) - 
           360*Zeta[3]) + CA*NC*(35148791066649365939/15336127107100800 + 
           (3247981*lm)/22680 - (9307710227*Pi^2)/204120 - 
           (242075122714*Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) + 
           180*Zeta[3])), (-337255346000040808604143119133733887*CF^2*NC)/
        76975426690378483012986240000 - (722579899257995172484905912403*CF*
         NM*NC)/1451508717472001612424000 + (196578107*CF*lm*NM*NC)/
        128595600 + (7557354154157*CF*NC*NL)/36006768000 + 
       (196578107*CF*lm*NC*NL)/128595600 + 
       (658970398969670259434539952779297*CF*NC*NH)/
        117851440104755806916534067000 + (196578107*CF*lm*NC*NH)/128595600 + 
       (99292523714656171*CF^2*NC*Pi^2)/73556683200 + 
       (17211061439*CF*NM*NC*Pi^2)/153090 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (160459*CF*NC*NL*Pi^2)/30618 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (9998601989267*CF^2*NC*Pi^3)/
        (55788550416*Sqrt[3]) - (2242922187520*CF*NC*NH*Pi^3)/
        (3486784401*Sqrt[3]) - (8101*CF^2*NC*Pi^4)/4860 + 
       (160523025417564923*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (68340974259600*Sqrt[3]) - (101569197370174*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(122037454035*Sqrt[3]) - 
       (1532*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (9998601989267*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1506635235*Sqrt[3]) - (1025335857152*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(43046721*Sqrt[3]) - 
       (9998601989267*CF^2*NC*Pi*Log[3]^2)/(72318491280*Sqrt[3]) - 
       (64083491072*CF*NC*NH*Pi*Log[3]^2)/(129140163*Sqrt[3]) + 
       (CF*NC*(19*CA*(-843748512217979297 + 121673197245600*lm) + 
          40*(801708967258963289*CF - 84*(33*(-24081260241707 + 3790815210*
                 lm)*NM + 5*(17459442*(1942 + 1433*lm)*NL + 
                (8779762469 + 25019380386*lm)*NH))))*Log[x]^2)/
        1979900722800 + (2*CF*NC*(-33606761233*CA + 67069520131*CF + 
          1260*(5688041*NM + 1433*NL))*Log[x]^3)/25515 + 
       (379914452492534080*CF^2*NC*PolyGamma[2, 1])/31381059609 - 
       (735473893*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (6000777141179*CF*NC*NH*PolyGamma[2, 1])/31381059609 + 
       CA*CF*NC*(84312964537019400711315385927671319/
          38487713345189241506493120000 - (7637896170638317*Pi^2)/
          11316412800 + (9998601989267*Pi^3)/(111577100832*Sqrt[3]) + 
         (1633*Pi^4)/1944 + lm*(-2162359177/257191200 - (11*Pi^2)/243) - 
         (160523025417564923*Im[PolyLog[2, (-1)^(1/3)]])/
          (136681948519200*Sqrt[3]) + (766*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (9998601989267*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3013270470*Sqrt[3]) + (9998601989267*Pi*Log[3]^2)/
          (144636982560*Sqrt[3]) - (189957226246267040*PolyGamma[2, 1])/
          31381059609 - (47400250799086773587*Zeta[3])/4393348345260) + 
       (47400225008504820857*CF^2*NC*Zeta[3])/2196674172630 - 
       (1538829422*CF*NM*NC*Zeta[3])/243 - (17204*CF*NC*NL*Zeta[3])/81 + 
       (87900327441370*CF*NC*NH*Zeta[3])/31381059609 + 
       CF*Log[x]*((-636872063863878095677*NM*NC)/2078400783759300 - 
         (79882*lm*NM*NC)/5103 - (4444725727*NC*NL)/14288400 - 
         (79882*lm*NC*NL)/5103 - (6337237921657781374205899*NC*NH)/
          1350002366682231962700 - (79882*lm*NC*NH)/5103 + 
         (1264456*NM*NC*Pi^2)/9 - (2866*NC*NL*Pi^2)/81 + 
         (1025335857152*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (129140163*Sqrt[3]) + CF*NC*(388787273926008182582689681/
            104709324839619099600 + (134371070423*Pi^2)/102060 + 
           (9998601989267*Im[PolyLog[2, (-1)^(1/3)]])/(4519905705*Sqrt[3]) - 
           264*Zeta[3]) + CA*NC*(-1110792830364137864751982211/
            598338999083537712000 + (439351*lm)/5103 - (134371465013*Pi^2)/
            204120 - (9998601989267*Im[PolyLog[2, (-1)^(1/3)]])/
            (9039811410*Sqrt[3]) + 132*Zeta[3])), 
      (-1180736709631998967794461591266146871*CF^2*NC)/
        593810434468634011814465280000 - (1106771287793894172242925191*CF*NM*
         NC)/68214840925847616000 + (29148631*CF*lm*NM*NC)/11430720 + 
       (30822837543397*CF*NC*NL)/72013536000 + (29148631*CF*lm*NC*NL)/
        11430720 + (2031407707376475330377765953871874641*CF*NC*NH)/
        203647288501018034351770867776000 + (29148631*CF*lm*NC*NH)/
        11430720 + (91389923976247*CF^2*NC*Pi^2)/179625600 + 
       (167712144043*CF*NM*NC*Pi^2)/34020 + (CF*lm*NM*NC*Pi^2)/54 - 
       (227863*CF*NC*NL*Pi^2)/22680 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (938545665489299*CF^2*NC*Pi^3)/
        (3012581722464*Sqrt[3]) - (464670546715655*CF*NC*NH*Pi^3)/
        (376572715308*Sqrt[3]) - (1309*CF^2*NC*Pi^4)/360 + 
       (1841907185701550873*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (527201801431200*Sqrt[3]) + (5694512247016018*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3295011258945*Sqrt[3]) - 
       (1022*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (134077952212757*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (11622614670*Sqrt[3]) - (53105205338932*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1162261467*Sqrt[3]) - 
       (134077952212757*CF^2*NC*Pi*Log[3]^2)/(557885504160*Sqrt[3]) - 
       (13276301334733*CF*NC*NH*Pi*Log[3]^2)/(13947137604*Sqrt[3]) + 
       ((1121033901515123*CF^2*NC)/183783600 + 
         CA*CF*(-211679237836399007/69470200800 + 2365*lm)*NC + 
         CF*NC*((376340843516719/6361740 - 430*lm)*NM - 
           (5*(2971 + 2322*lm)*NL)/27 - (84625734073*NH)/523783260 - 
           430*lm*NH))*Log[x]^2 + (CF*NC*(-19077105185*CA + 37680936356*CF + 
          330170213520*NM + 4876200*NL)*Log[x]^3)/17010 - 
       (854891456413424395*CF^2*NC*PolyGamma[2, 1])/94143178827 + 
       (1961314561*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (8110478440751*CF*NC*NH*PolyGamma[2, 1])/188286357654 - 
       (36303929618271496477*CF^2*NC*Zeta[3])/1882863576540 + 
       (1699349753*CF*NM*NC*Zeta[3])/27 - (3872*CF*NC*NL*Zeta[3])/9 + 
       (351117082581791*CF*NC*NH*Zeta[3])/94143178827 + 
       CA*CF*NC*(1652755178735567383769075496466612007/
          1662669216512175233080502784000 - (3564186270188693*Pi^2)/
          14010796800 + (938545665489299*Pi^3)/(6025163444928*Sqrt[3]) + 
         (3959*Pi^4)/2160 - (11*lm*(29148631 + 211680*Pi^2))/22861440 - 
         (1841907185701550873*Im[PolyLog[2, (-1)^(1/3)]])/
          (1054403602862400*Sqrt[3]) + (511*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (134077952212757*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (23245229340*Sqrt[3]) + (134077952212757*Pi*Log[3]^2)/
          (1115771008320*Sqrt[3]) + (854891456413424395*PolyGamma[2, 1])/
          188286357654 + (36304376949464915437*Zeta[3])/3765727153080) + 
       CF*Log[x]*((15419953234674569699*NM*NC)/1217899457775 - 
         (362219*lm*NM*NC)/11340 - (18430374479*NC*NL)/28576800 - 
         (362219*lm*NC*NL)/11340 - (1313580670873048244913998159*NC*NH)/
          145800255601681051971600 - (362219*lm*NC*NH)/11340 + 
         (43673597*NM*NC*Pi^2)/9 - (215*NC*NL*Pi^2)/3 + 
         (53105205338932*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*(260470293578938227021062923/
            8077576487627759112000 + (5440274653*Pi^2)/9720 + 
           (134077952212757*Im[PolyLog[2, (-1)^(1/3)]])/(34867844010*
             Sqrt[3]) - 440*Zeta[3]) + CA*NC*(-3574887885532893834108041909/
            226172141653577255136000 + (3984409*lm)/22680 - 
           (1813303651*Pi^2)/6480 - (134077952212757*Im[PolyLog[2, (-1)^
                (1/3)]])/(69735688020*Sqrt[3]) + 220*Zeta[3])), 
      (-244914610878804807371021431801079082725747*CF^2*NC)/
        7127655097535631202311980372160000 - 
       (81637656649346320719207471430213*CF*NM*NC)/
        31933191784384035473328000 + (5255245711*CF*lm*NM*NC)/3112013520 + 
       (619849824302833*CF*NC*NL)/2178409464000 + (5255245711*CF*lm*NC*NL)/
        3112013520 + (9801891992644491026835741024223081*CF*NC*NH)/
        1305431336544987399690838896000 + (5255245711*CF*lm*NC*NH)/
        3112013520 + (135561834169063444*CF^2*NC*Pi^2)/12642554925 + 
       (435414964562*CF*NM*NC*Pi^2)/841995 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (10714489*CF*NC*NL*Pi^2)/1683990 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (245252440080460*CF^2*NC*Pi^3)/
        (1035574967097*Sqrt[3]) - (27415663019605*CF*NC*NH*Pi^3)/
        (31381059609*Sqrt[3]) - (2489*CF^2*NC*Pi^4)/1215 + 
       (8562694906440676831*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2790874536326415*Sqrt[3]) - (826857678530428*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1098337086315*Sqrt[3]) - 
       (1840*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (784807808257472*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (89494132959*Sqrt[3]) - (12532874523248*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (49050488016092*CF^2*NC*Pi*Log[3]^2)/(268482398877*Sqrt[3]) - 
       (783304657703*CF*NC*NH*Pi*Log[3]^2)/(1162261467*Sqrt[3]) + 
       (CF*NC*(280228876799850650051*CF + 216*CA*(-648657775075365589 + 
            15691867491300*lm) - 1848*((-7312528266111951 + 333475342200*lm)*
             NM + 65*(13430340*(515 + 382*lm)*NL + (1875657367 + 
                5130389880*lm)*NH)))*Log[x]^2)/2177890795080 + 
       (2*CF*NC*(-2905234552533*CA + 11*(528017236703*CF + 
            12600*(2752736*NM + 191*NL)))*Log[x]^3)/280665 + 
       (30773939978725510003*CF^2*NC*PolyGamma[2, 1])/282429536481 - 
       (6619414612*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (69809319099968*CF*NC*NH*PolyGamma[2, 1])/282429536481 + 
       CA*CF*NC*(1077622910461527426067593666146485741524577/
          62723364858313554580345427275008000 - (4337979453238971233*Pi^2)/
          809123515200 + (122626220040230*Pi^3)/(1035574967097*Sqrt[3]) + 
         (167*Pi^4)/162 + lm*(-5255245711/565820640 - (11*Pi^2)/243) - 
         (8562694906440676831*Im[PolyLog[2, (-1)^(1/3)]])/
          (5581749072652830*Sqrt[3]) + (920*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (392403904128736*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (89494132959*Sqrt[3]) + (24525244008046*Pi*Log[3]^2)/
          (268482398877*Sqrt[3]) - (30773939978725510003*PolyGamma[2, 1])/
          564859072962 - (4288953166001396605267*Zeta[3])/43494148618074) + 
       (4288952749585195947040*CF^2*NC*Zeta[3])/21747074309037 - 
       (13568649848*CF*NM*NC*Zeta[3])/243 - (22928*CF*NC*NL*Zeta[3])/81 + 
       (1035638546431312*CF*NC*NH*Zeta[3])/282429536481 + 
       CF*Log[x]*((-25934649459818327516779*NM*NC)/11431204310676150 - 
         (5336809*lm*NM*NC)/280665 - (32937870631*NC*NL)/78586200 - 
         (5336809*lm*NC*NL)/280665 - (212634312660322399203106*NC*NH)/
          33379179395989251825 - (5336809*lm*NC*NH)/280665 + 
         (18353500*NM*NC*Pi^2)/27 - (3820*NC*NL*Pi^2)/81 + 
         (12532874523248*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(711727091713664996261903252660533/
            22453239362658882003626400 + (581005834891*Pi^2)/56133 + 
           (784807808257472*Im[PolyLog[2, (-1)^(1/3)]])/(268482398877*
             Sqrt[3]) - 320*Zeta[3]) + 
         CA*NC*(-1016749545478717031620512564755653/
            64152112464739662867504000 + (5336809*lm)/51030 - 
           (1162012261835*Pi^2)/224532 - (392403904128736*
             Im[PolyLog[2, (-1)^(1/3)]])/(268482398877*Sqrt[3]) + 
           160*Zeta[3])), (-11687979888062414508925750133439186639927587*CF^2*
         NC)/940850472874703318705181409125120000 - 
       (5327142774161298097859288149500173*CF*NM*NC)/
        42577589045845380631104000 + (3884300191*CF*lm*NM*NC)/1383117120 + 
       (710814497039137*CF*NC*NL)/1244805408000 + (3884300191*CF*lm*NC*NL)/
        1383117120 + (97831720901470671098094390947738275622491*CF*NC*NH)/
        7433329677575659271873988444691776000 + (3884300191*CF*lm*NC*NH)/
        1383117120 + (843405448553435777*CF^2*NC*Pi^2)/269707838400 + 
       (962255942849*CF*NM*NC*Pi^2)/24948 + (CF*lm*NM*NC*Pi^2)/54 - 
       (3013853*CF*NC*NL*Pi^2)/249480 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (5015849609581619*CF^2*NC*Pi^3)/
        (12426899605164*Sqrt[3]) - (1854561533860595*CF*NC*NH*Pi^3)/
        (1129718145924*Sqrt[3]) - (1187*CF^2*NC*Pi^4)/270 + 
       (1507731147445777534937*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (334904944359169800*Sqrt[3]) + (26766217386718744*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(9885033776835*Sqrt[3]) - 
       (3656*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (20063398438326476*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1342411994385*Sqrt[3]) - (211949889584068*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3486784401*Sqrt[3]) - 
       (5015849609581619*CF^2*NC*Pi*Log[3]^2)/(16108943932620*Sqrt[3]) - 
       (52987472396017*CF*NC*NH*Pi*Log[3]^2)/(41841412812*Sqrt[3]) + 
       (CF*NC*(6264436392944238071014*CF + 69*CA*(-45385458193993946533 + 
            7515336495466800*lm) - 4620*(23*(-727290685741797787 + 
              887288842440*lm)*NM + 3*(4908043140*(1765 + 1386*lm)*NL + 
              (2653884273377 + 6802547792040*lm)*NH)))*Log[x]^2)/
        166971627622800 + (CF*NC*(-3871463193317*CA + 7720797756172*CF + 
          83160*(1012826396*NM + 2541*NL))*Log[x]^3)/561330 - 
       (69242358895547518642*CF^2*NC*PolyGamma[2, 1])/847288609443 + 
       (17651844001*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (86409708949607*CF*NC*NH*PolyGamma[2, 1])/1694577218886 - 
       (10102847927858141350403*CF^2*NC*Zeta[3])/59310202661010 + 
       (15626290577*CF*NM*NC*Zeta[3])/27 - (5084*CF*NC*NL*Zeta[3])/9 + 
       (4102725083360675*CF*NC*NH*Zeta[3])/847288609443 + 
       CA*CF*NC*(1062508119241409128915712829204225076901623/
          171063722340855148855487528931840000 - (64877260828917899*Pi^2)/
          41493513600 + (5015849609581619*Pi^3)/(24853799210328*Sqrt[3]) + 
         (239*Pi^4)/108 + lm*(-3884300191/251475840 - (11*Pi^2)/108) - 
         (1507731147445777534937*Im[PolyLog[2, (-1)^(1/3)]])/
          (669809888718339600*Sqrt[3]) + (1828*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          9 + (10031699219163238*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1342411994385*Sqrt[3]) + (5015849609581619*Pi*Log[3]^2)/
          (32217887865240*Sqrt[3]) + (34621179447773759321*PolyGamma[2, 1])/
          847288609443 + (10102866070922357825783*Zeta[3])/118620405322020) + 
       CF*Log[x]*((493941820049004344802067*NM*NC)/4572481724270460 - 
         (4795009*lm*NM*NC)/124740 - (38340050257*NC*NL)/44906400 - 
         (4795009*lm*NC*NL)/124740 - (2771247694268792864893990808051*NC*
           NH)/231385005639867829478929200 - (4795009*lm*NC*NH)/124740 + 
         (1012827749*NM*NC*Pi^2)/27 - (847*NC*NL*Pi^2)/9 + 
         (211949889584068*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (10460353203*Sqrt[3]) + CF*NC*(-20549038146974292856202336648687/
            192456337394218988602512000 + (351808626929*Pi^2)/102060 + 
           (20063398438326476*Im[PolyLog[2, (-1)^(1/3)]])/(4027235983155*
             Sqrt[3]) - 528*Zeta[3]) + 
         CA*NC*(72460308340473735625307523389479/
            1347194361759532920217584000 + (4795009*lm)/22680 - 
           (351803663159*Pi^2)/204120 - (10031699219163238*
             Im[PolyLog[2, (-1)^(1/3)]])/(4027235983155*Sqrt[3]) + 
           264*Zeta[3])), (-44640157597104055834314497506399884794922721*CF^2*
         NC)/162839504920621728237435243887040000 - 
       (81782373913258822133682238213621439*CF*NM*NC)/
        7064202626192737447345123200 + (5753536021*CF*lm*NM*NC)/3112013520 + 
       (14709005500788223*CF*NC*NL)/39211370352000 + 
       (5753536021*CF*lm*NC*NL)/3112013520 + 
       (12648464163607231410443056392862356325469*CF*NC*NH)/
        1286537828811171797055113384658192000 + (5753536021*CF*lm*NC*NH)/
        3112013520 + (1166203874327617423*CF^2*NC*Pi^2)/13485391920 + 
       (53361819289*CF*NM*NC*Pi^2)/31185 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (6392072*CF*NC*NL*Pi^2)/841995 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (8539190564761534*CF^2*NC*Pi^3)/
        (27960524111619*Sqrt[3]) - (5873543017292615*CF*NC*NH*Pi^3)/
        (5083731656658*Sqrt[3]) - (200*CF^2*NC*Pi^4)/81 + 
       (5911352245974314037749*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1507072249616264100*Sqrt[3]) - (10054022047537388*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(17793060798303*Sqrt[3]) - 
       (2176*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (136627049036184544*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (12081707949465*Sqrt[3]) - (1342524118238312*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (8539190564761534*CF^2*NC*Pi*Log[3]^2)/(36245123848395*Sqrt[3]) - 
       (167815514779789*CF*NC*NH*Pi*Log[3]^2)/(188286357654*Sqrt[3]) + 
       (CF*NC*(299*CA*(-434631896687397670117 + 1694266669141200*lm) + 
          6*(43318530490603860820861*CF - 1540*(6*(-92760137215200043 + 
                1661372602890*lm)*NM + 13*(283156335*(3635 + 2708*lm)*NL + 
                2*(145040896813 + 383393677590*lm)*NH))))*Log[x]^2)/
        250457441434200 + (2*CF*NC*(-23255127666629*CA + 
          20*(2325353712130*CF + 231*(337860236*NM + 7447*NL)))*Log[x]^3)/
        280665 + (2492699586365205179728*CF^2*NC*PolyGamma[2, 1])/
        2541865828329 - (19858314293*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (795635793934133*CF*NC*NH*PolyGamma[2, 1])/2541865828329 + 
       CA*CF*NC*(44640150991770430225184302757170803105493513/
          325679009841243456474870487774080000 - (1166203901948324537*Pi^2)/
          26970783840 + (4269595282380767*Pi^3)/(27960524111619*Sqrt[3]) + 
         (1508*Pi^4)/1215 + lm*(-5753536021/565820640 - (11*Pi^2)/243) - 
         (5911352245974314037749*Im[PolyLog[2, (-1)^(1/3)]])/
          (3014144499232528200*Sqrt[3]) + (1088*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          9 + (68313524518092272*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (12081707949465*Sqrt[3]) + (4269595282380767*Pi*Log[3]^2)/
          (36245123848395*Sqrt[3]) - (1246349793182602589864*PolyGamma[2, 1])/
          2541865828329 - (878603302193719736370334*Zeta[3])/
          978618343906665) + (1757206576672001436667958*CF^2*NC*Zeta[3])/
        978618343906665 - (40166886034*CF*NM*NC*Zeta[3])/81 - 
       (9932*CF*NC*NL*Zeta[3])/27 + (11932251240115630*CF*NC*NH*Zeta[3])/
        2541865828329 + CF*Log[x]*((-2799652590480118881554529811*NM*NC)/
          145130569928344400400 - (6370429*lm*NM*NC)/280665 - 
         (777457277813*NC*NL)/1414551600 - (6370429*lm*NC*NL)/280665 - 
         (1348594657256192242518375480451*NC*NH)/
          160189619289139266562335600 - (6370429*lm*NC*NH)/280665 + 
         (675744386*NM*NC*Pi^2)/243 - (14894*NC*NL*Pi^2)/243 + 
         (1342524118238312*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CF*NC*(5695898810470759437845572906943617/
            21197114083629014478948000 + (23254860558596*Pi^2)/280665 + 
           (136627049036184544*Im[PolyLog[2, (-1)^(1/3)]])/
            (36245123848395*Sqrt[3]) - (1144*Zeta[3])/3) + 
         CA*NC*(-8950694109437507157799055845490267/
            66619501405691188362408000 + (6370429*lm)/51030 - 
           (23254862516321*Pi^2)/561330 - (68313524518092272*
             Im[PolyLog[2, (-1)^(1/3)]])/(36245123848395*Sqrt[3]) + 
           (572*Zeta[3])/3)), (-13694031097291190045954144906942587695329369*
         CF^2*NC)/178266405386785891965192266992128000 - 
       (26632033942398714569857603020251*CF*NM*NC)/27067761631179517248000 + 
       (4241818891*CF*lm*NM*NC)/1383117120 + (2543208704573857*CF*NC*NL)/
        3423214872000 + (4241818891*CF*lm*NC*NL)/1383117120 + 
       (142000165812943391556980223062415497025149621*CF*NC*NH)/
        8362495887272616680858237000278248000000 + (4241818891*CF*lm*NC*NH)/
        1383117120 + (10131504093764964271*CF^2*NC*Pi^2)/539415676800 + 
       (86169567931501*CF*NM*NC*Pi^2)/280665 + (CF*lm*NM*NC*Pi^2)/54 - 
       (44043*CF*NC*NL*Pi^2)/3080 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (457911527872978669*CF^2*NC*Pi^3)/
        (894736771571808*Sqrt[3]) - (10847056386106885*CF*NC*NH*Pi^3)/
        (5083731656658*Sqrt[3]) - (5647*CF^2*NC*Pi^4)/1080 + 
       (9801385426079527582103*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1722368285275730400*Sqrt[3]) + (354972373143599023*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(88965303991515*Sqrt[3]) - 
       (4298*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (65415932553282667*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3451916556990*Sqrt[3]) - (2479327173967288*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (65415932553282667*CF^2*NC*Pi*Log[3]^2)/(165691994735520*Sqrt[3]) - 
       (309915896745911*CF*NC*NH*Pi*Log[3]^2)/(188286357654*Sqrt[3]) + 
       (CF*NC*(75263821999545595283314*CF + 3933*CA*(-9567838721674919899 + 
            338518854273600*lm) - 1848*(7475*(-89064835298323565 + 
              17523907632*lm)*NM + 4461857400*(37237 + 29358*lm)*NL + 
            (52751205391733 + 130991209549200*lm)*NH))*Log[x]^2)/
        333943255245600 + (CF*NC*(-23533279423955*CA + 
          8*(5879508968801*CF + 6930*(11989297382*NM + 4893*NL)))*Log[x]^3)/
        561330 - (5608585573977085183066*CF^2*NC*PolyGamma[2, 1])/
        7625597484987 + (158866611841*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (908593470705407*CF*NC*NH*PolyGamma[2, 1])/15251194969974 - 
       (17766740230808098534826687*CF^2*NC*Zeta[3])/11743420126879980 + 
       (142881010439*CF*NM*NC*Zeta[3])/27 - (6526*CF*NC*NL*Zeta[3])/9 + 
       (46946490780684947*CF*NC*NH*Zeta[3])/7625597484987 + 
       CA*CF*NC*(34234849482603469808043063697633795518997541/
          891332026933929459825961334960640000 - (10131501410911396261*Pi^2)/
          1078831353600 + (457911527872978669*Pi^3)/(1789473543143616*
           Sqrt[3]) + (631*Pi^4)/240 + lm*(-4241818891/251475840 - 
           (11*Pi^2)/108) - (9801385426079527582103*
           Im[PolyLog[2, (-1)^(1/3)]])/(3444736570551460800*Sqrt[3]) + 
         (2149*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (65415932553282667*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (6903833113980*Sqrt[3]) + (65415932553282667*Pi*Log[3]^2)/
          (331383989471040*Sqrt[3]) + (2804292786988542591533*
           PolyGamma[2, 1])/7625597484987 + (17766744772177136243326607*
           Zeta[3])/23486840253759960) + CF*Log[x]*
        ((12845309573117550299124503*NM*NC)/14069174536216800 - 
         (5679739*lm*NM*NC)/124740 - (30281808589*NC*NL)/27442800 - 
         (5679739*lm*NC*NL)/124740 - (231398245915641235600995621546451*NC*
           NH)/14874750362562931895074020000 - (5679739*lm*NC*NH)/124740 + 
         (23978600690*NM*NC*Pi^2)/81 - (3262*NC*NL*Pi^2)/27 + 
         (2479327173967288*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CF*NC*(-4474514073105074993212906395607817/
            638144697675568225366224000 + (47062528470869*Pi^2)/2245320 + 
           (65415932553282667*Im[PolyLog[2, (-1)^(1/3)]])/(10355749670970*
             Sqrt[3]) - 624*Zeta[3]) + 
         CA*NC*(58118783497103327498999976552613/16575186952612161697824000 + 
           (5679739*lm)/22680 - (47062389404249*Pi^2)/4490640 - 
           (65415932553282667*Im[PolyLog[2, (-1)^(1/3)]])/(20711499341940*
             Sqrt[3]) + 312*Zeta[3])), 
      (-104188562354691370352805722045659647242318736214283*CF^2*NC)/
        46994292677388852196710710104019796480000 - 
       (129609466554086337851253692008698330187*CF*NM*NC)/
        3735876388851928457730594000000 + (1056589131859*CF*lm*NM*NC)/
        525930284880 + (8804962347281750941*CF*NC*NL)/18223484371092000 + 
       (1056589131859*CF*lm*NC*NL)/525930284880 + 
       (1549769526415609081087780418519102514860647*CF*NC*NH)/
        122977880695185539424385838239386000000 + 
       (1056589131859*CF*lm*NC*NH)/525930284880 + 
       (927924654578901396163*CF^2*NC*Pi^2)/1314825712200 - 
       (28623090768647*CF*NM*NC*Pi^2)/10945935 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (195444247*CF*NC*NL*Pi^2)/21891870 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (748035965192813965*CF^2*NC*Pi^3)/
        (1938596338405584*Sqrt[3]) - (3797979736279400*CF*NC*NH*Pi^3)/
        (2541865828329*Sqrt[3]) - (14233*CF^2*NC*Pi^4)/4860 + 
       (66880536300427297661065*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (13583744543207927088*Sqrt[3]) - (3095244011160872*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) - 
       (2540*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (149607193038562793*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10470813556203*Sqrt[3]) - (1736219308013440*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (149607193038562793*CF^2*NC*Pi*Log[3]^2)/(502599050697744*Sqrt[3]) - 
       (108513706750840*CF*NC*NH*Pi*Log[3]^2)/(94143178827*Sqrt[3]) + 
       (CF*NC*(55148395905916316871023270*CF + 1045*CA*
           (-26386771504999098885929 + 16038129328341120*lm) - 
          144144*(3*(472548728444015519 + 7046760120400*lm)*NM + 
            17*(3018315300*(551 + 412*lm)*NL + (484269713971 + 1243545903600*
                 lm)*NH)))*Log[x]^2)/6511893477289200 + 
       (2*CF*NC*(-2453123132584343*CA + 104*(47174904131263*CF + 
            2310*(153921703*NM + 2369*NL)))*Log[x]^3)/3648645 + 
       (201908788912545985723813*CF^2*NC*PolyGamma[2, 1])/22876792454961 - 
       (536174773808*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (8911332207541292*CF*NC*NH*PolyGamma[2, 1])/22876792454961 + 
       CA*CF*NC*(26047140176956274257670316582854007472050576155423/
          23497146338694426098355355052009898240000 - 
         (7423397260090155623249*Pi^2)/21037211395200 + 
         (748035965192813965*Pi^3)/(3877192676811168*Sqrt[3]) + 
         (14297*Pi^4)/9720 + lm*(-1056589131859/95623688160 - 
           (11*Pi^2)/243) - (66880536300427297661065*
           Im[PolyLog[2, (-1)^(1/3)]])/(27167489086415854176*Sqrt[3]) + 
         (1270*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (149607193038562793*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (20941627112406*Sqrt[3]) + (149607193038562793*Pi*Log[3]^2)/
          (1005198101395488*Sqrt[3]) - (201908788912545985723813*
           PolyGamma[2, 1])/45753584909922 - (67896132586281786968855551*
           Zeta[3])/8327152453605804) + (67896132422154640151797945*CF^2*NC*
         Zeta[3])/4163576226802902 - (1074811434616*CF*NM*NC*Zeta[3])/243 - 
       (37912*CF*NC*NL*Zeta[3])/81 + (134905146767784712*CF*NC*NH*Zeta[3])/
        22876792454961 + CF*Log[x]*((-315373252407283933122626983369*NM*NC)/
          1814132124104305005000 - (97426327*lm*NM*NC)/3648645 - 
         (35633475663431*NC*NL)/50570219700 - (97426327*lm*NC*NL)/3648645 - 
         (16661476393412018606990331343049*NC*NH)/
          1531224302028537106845855000 - (97426327*lm*NC*NH)/3648645 + 
         (1231405552*NM*NC*Pi^2)/243 - (18952*NC*NL*Pi^2)/243 + 
         (1736219308013440*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (94143178827*Sqrt[3]) + CF*NC*
          (133129724472327594348288536835742889981/
            58513614478865102477913632640 + (178408633597195*Pi^2)/265356 + 
           (149607193038562793*Im[PolyLog[2, (-1)^(1/3)]])/
            (31412440668609*Sqrt[3]) - 448*Zeta[3]) + 
         CA*NC*(-10805983495950782716009571789186229553/
            9498963389426152999661304000 + (97426327*lm)/663390 - 
           (178408635984853*Pi^2)/530712 - (149607193038562793*
             Im[PolyLog[2, (-1)^(1/3)]])/(62824881337218*Sqrt[3]) + 
           224*Zeta[3])), 
      (-11154499739091092954405144838917933077052828289957091*CF^2*NC)/
        24108072143500481176912594283362155594240000 - 
       (214253429215249098519345851842884872101*CF*NM*NC)/
        27265343469515828744139072000 + (777314733379*CF*lm*NM*NC)/
        233746793280 + (7665211206593329421*CF*NC*NL)/8099326387152000 + 
       (777314733379*CF*lm*NC*NL)/233746793280 + 
       (323552212731065163816346985251554709251611459*CF*NC*NH)/
        15052492597090710025544826600500846400000 + 
       (777314733379*CF*lm*NC*NH)/233746793280 + 
       (19022158773691026901*CF^2*NC*Pi^2)/177397119900 + 
       (18075839609055143*CF*NM*NC*Pi^2)/7297290 + (CF*lm*NM*NC*Pi^2)/54 - 
       (18058613*CF*NC*NL*Pi^2)/1081080 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (160349996509063237*CF^2*NC*Pi^3)/
        (251644717004571*Sqrt[3]) - (62199857593727875*CF*NC*NH*Pi^3)/
        (22876792454961*Sqrt[3]) - (92*CF^2*NC*Pi^4)/15 + 
       (623746321272598501211413*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (88163726602551449850*Sqrt[3]) + (1414647427950529745*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(251644717004571*Sqrt[3]) - 
       (1664*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (2565599944145011792*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (108735371545185*Sqrt[3]) - (28434220614275600*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (160349996509063237*CF^2*NC*Pi*Log[3]^2)/(326206114635555*Sqrt[3]) - 
       (1777138788392225*CF*NC*NH*Pi*Log[3]^2)/(847288609443*Sqrt[3]) + 
       (CF*NC*(465506031193637514534969*CF + 
          13*CA*(-17903909576590550907689 + 139724331648501600*lm) - 
          10010*(8645*(-124266425148891661 + 3816397728*lm)*NM + 
            11600829240*(3595 + 2844*lm)*NL + (13652152242271 + 
              32992758358560*lm)*NH))*Log[x]^2)/361771859849400 + 
       (CF*NC*(-598825327968399*CA + 4*(299368232704579*CF + 
            60060*(96097537811*NM + 6162*NL)))*Log[x]^3)/2432430 - 
       (454294905670022522235385*CF^2*NC*PolyGamma[2, 1])/68630377364883 + 
       (1429799525569*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (9447003217598999*CF*NC*NH*PolyGamma[2, 1])/137260754729766 - 
       (842191572490528298853493583*CF^2*NC*Zeta[3])/62453643402043530 + 
       (1301669637839*CF*NM*NC*Zeta[3])/27 - (8218*CF*NC*NL*Zeta[3])/9 + 
       (527709721532817695*CF*NC*NH*Zeta[3])/68630377364883 + 
       CA*CF*NC*(429018641496350908057478401324782474853471540416653/
          1854467087961575475147122637181704276480000 - 
         (17903207236010497553*Pi^2)/333923990400 + (160349996509063237*Pi^3)/
          (503289434009142*Sqrt[3]) + (416*Pi^4)/135 + 
         lm*(-777314733379/42499416960 - (11*Pi^2)/108) - 
         (623746321272598501211413*Im[PolyLog[2, (-1)^(1/3)]])/
          (176327453205102899700*Sqrt[3]) + 
         (832*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1282799972072505896*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (108735371545185*Sqrt[3]) + (160349996509063237*Pi*Log[3]^2)/
          (652412229271110*Sqrt[3]) + (454294905670022522235385*
           PolyGamma[2, 1])/137260754729766 + (842191602537670068947769683*
           Zeta[3])/124907286804087060) + CF*Log[x]*
        ((39205870288109177569975480337*NM*NC)/5092300699240154400 - 
         (86301367*lm*NM*NC)/1621620 - (1745134892057*NC*NL)/1248647400 - 
         (86301367*lm*NC*NL)/1621620 - (3713169677713181386469293958617453*
           NC*NH)/187421854568292941877932652000 - (86301367*lm*NC*NH)/
          1621620 + (192195083864*NM*NC*Pi^2)/81 - (4108*NC*NL*Pi^2)/27 + 
         (28434220614275600*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CF*NC*
          (-44980054989423315639432423151201314738233/
            375218552845722469639621169304000 + (54437665734083*Pi^2)/
            442260 + (2565599944145011792*Im[PolyLog[2, (-1)^(1/3)]])/
            (326206114635555*Sqrt[3]) - 728*Zeta[3]) + 
         CA*NC*(5622563577685441091154950754060253092949/
            93804638211430617409905292326000 + (86301367*lm)/294840 - 
           (54437631458933*Pi^2)/884520 - (1282799972072505896*
             Im[PolyLog[2, (-1)^(1/3)]])/(326206114635555*Sqrt[3]) + 
           364*Zeta[3])), 
      (-214208679945487968617454921887366405464336780522409809*CF^2*NC)/
        11817682423284549596525781511452037056000000 + 
       (53927612478539509197751761299718185473*CF*NM*NC)/
        449688824584028425467571500000 + (1140854601499*CF*lm*NM*NC)/
        525930284880 + (50835797322391049*CF*NC*NL)/83307357124992 + 
       (1140854601499*CF*lm*NC*NL)/525930284880 + 
       (149234496936046368371907555544392067541501753*CF*NC*NH)/
        9407807873181693765965516625313029000000 + 
       (1140854601499*CF*lm*NC*NH)/525930284880 + 
       (51981335549020812430819*CF^2*NC*Pi^2)/8940814842960 - 
       (596668716397703*CF*NM*NC*Pi^2)/4378374 + (2*CF*lm*NM*NC*Pi^2)/243 - 
       (227039107*CF*NC*NL*Pi^2)/21891870 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (8359581077503128107*CF^2*NC*Pi^3)/
        (17447367045650256*Sqrt[3]) - (43372210177226245*CF*NC*NH*Pi^3)/
        (22876792454961*Sqrt[3]) - (3331*CF^2*NC*Pi^4)/972 + 
       (18592960816554565576291999*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (3056342522221783594800*Sqrt[3]) + (2100275150321947534*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(8807565095159985*Sqrt[3]) - 
       (2932*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (8359581077503128107*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (471186610029135*Sqrt[3]) - (19827296081017712*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (8359581077503128107*CF^2*NC*Pi*Log[3]^2)/(22616957281398480*
         Sqrt[3]) - (1239206005063607*CF*NC*NH*Pi*Log[3]^2)/
        (847288609443*Sqrt[3]) + 
       (CF*NC*(51*CA*(-4454086183092961156676299 + 410711159025367200*lm) + 
          2*(227158422584010175204958159*CF - 144144*
             (6*(6156464929115056726 + 2201740716175*lm)*NM + 
              7250518275*(2429 + 1822*lm)*NL + 2*(2637056836823 + 
                6605222148525*lm)*NH)))*Log[x]^2)/6511893477289200 + 
       (4*CF*NC*(-10059128464912386*CA + 5*(4023643906132135*CF - 
            78078*(724648667*NM - 911*NL)))*Log[x]^3)/3648645 + 
       (16354613305973007102289408*CF^2*NC*PolyGamma[2, 1])/205891132094649 - 
       (4825573344977*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (98321839291729175*CF*NC*NH*PolyGamma[2, 1])/205891132094649 + 
       CA*CF*NC*(3825154993293919935258853097081265843550826482887089/
          422060086545876771304492196837572752000000 - 
         (12230902487222997314813*Pi^2)/4207442279040 + 
         (8359581077503128107*Pi^3)/(34894734091300512*Sqrt[3]) + 
         (5573*Pi^4)/3240 + lm*(-1140854601499/95623688160 - (11*Pi^2)/243) - 
         (18592960816554565576291999*Im[PolyLog[2, (-1)^(1/3)]])/
          (6112685044443567189600*Sqrt[3]) + 
         (1466*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (8359581077503128107*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (942373220058270*Sqrt[3]) + (8359581077503128107*Pi*Log[3]^2)/
          (45233914562796960*Sqrt[3]) - (8177306652986503551144704*
           PolyGamma[2, 1])/205891132094649 - (304691395692335852766059903341*
           Zeta[3])/4121940464534872980) + (304691395583918640918016114651*
         CF^2*NC*Zeta[3])/2060970232267436490 - 
       (9613463873950*CF*NM*NC*Zeta[3])/243 - (47380*CF*NC*NL*Zeta[3])/81 + 
       (1500719133994930738*CF*NC*NH*Zeta[3])/205891132094649 + 
       CF*Log[x]*((-2894944988043896075423383499359*NM*NC)/
          1814132124104305005000 - (113210392*lm*NM*NC)/3648645 - 
         (179281649017199*NC*NL)/202280878800 - (113210392*lm*NC*NL)/
          3648645 - (3232961324177042344538795154202727*NC*NH)/
          234277318210366177347415815000 - (113210392*lm*NC*NH)/3648645 - 
         (18840823820*NM*NC*Pi^2)/243 - (23686*NC*NL*Pi^2)/243 + 
         (19827296081017712*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CF*NC*
          (28954931272931937044007542374286521768741/
            1501474801303411243055706960000 + (80473005612774869*Pi^2)/
            14594580 + (8359581077503128107*Im[PolyLog[2, (-1)^(1/3)]])/
            (1413559830087405*Sqrt[3]) - 520*Zeta[3]) + 
         CA*NC*(-709395810856552995175529156512182051634997/
            73572265263867150909729641040000 + (56605196*lm)/331695 - 
           (80473005778690619*Pi^2)/29189160 - (8359581077503128107*
             Im[PolyLog[2, (-1)^(1/3)]])/(2827119660174810*Sqrt[3]) + 
           260*Zeta[3])), 
      (-954536080361005699492464912129422109161021946465305227*CF^2*NC)/
        361621082152507217653688914250432333913600000 - 
       (587823961941912040485211528249470367596539*CF*NM*NC)/
        9250741534300013323904328000000 + (837783244339*CF*lm*NM*NC)/
        233746793280 + (49870517574882075179*CF*NC*NL)/42116497213190400 + 
       (837783244339*CF*lm*NC*NL)/233746793280 + 
       (1734071931734180661538266318967453261464479713831*CF*NC*NH)/
        64785042697137410614061078110520319326400000 + 
       (837783244339*CF*lm*NC*NH)/233746793280 + 
       (9351825557262485652221*CF^2*NC*Pi^2)/17030123510400 + 
       (58969801157831279*CF*NM*NC*Pi^2)/2918916 + (CF*lm*NM*NC*Pi^2)/54 - 
       (772539*CF*NC*NL*Pi^2)/40040 + (CF*lm*NC*NL*Pi^2)/54 + 
       (CF*lm*NC*NH*Pi^2)/54 - (245304599271964937059*CF^2*NC*Pi^3)/
        (314052606821704608*Sqrt[3]) - (935073207022949855*CF*NC*NH*Pi^3)/
        (274521509459532*Sqrt[3]) - (7679*CF^2*NC*Pi^4)/1080 + 
       (476956174672487463045325523*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (55014165399992104706400*Sqrt[3]) + (40431659384393732734*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5284539057095991*Sqrt[3]) - 
       (5738*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (245304599271964937059*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (8481358980524430*Sqrt[3]) - (106865509374051412*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (245304599271964937059*CF^2*NC*Pi*Log[3]^2)/(407105231065172640*
         Sqrt[3]) - (26716377343512853*CF*NC*NH*Pi*Log[3]^2)/
        (10167463313316*Sqrt[3]) + 
       (CF*NC*(87*CA*(-4767851056333168259248957 + 9000723085559805600*lm) + 
          22*(37709453539884828281764999*CF - 
            1092*(203*(-6258380708235698317711 + 29193932968200*lm)*NM + 
              85*(5327982660*(16493 + 13086*lm)*NL + (29536772791147 + 
                  69721981088760*lm)*NH))))*Log[x]^2)/125896607227591200 + 
       (CF*NC*(-9796494480879227*CA + 8*(2449035783454556*CF + 
            45045*(1559388977578*NM + 15267*NL)))*Log[x]^3)/7297290 - 
       (36797881397001118329056197*CF^2*NC*PolyGamma[2, 1])/617673396283947 + 
       (12868195752577*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (97273551318022607*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 - 
       (114614463670590124537365660407*CF^2*NC*Zeta[3])/951217030277278380 + 
       (11828603303381*CF*NM*NC*Zeta[3])/27 - (10180*CF*NC*NL*Zeta[3])/9 + 
       (5841422620029150071*CF*NC*NH*Zeta[3])/617673396283947 + 
       CA*CF*NC*(477267903853110151791623899983627602432384369037330341/
          361621082152507217653688914250432333913600000 - 
         (9351825431979366443831*Pi^2)/34060247020800 + 
         (245304599271964937059*Pi^3)/(628105213643409216*Sqrt[3]) + 
         (7711*Pi^4)/2160 + lm*(-837783244339/42499416960 - (11*Pi^2)/108) - 
         (476956174672487463045325523*Im[PolyLog[2, (-1)^(1/3)]])/
          (110028330799984209412800*Sqrt[3]) + 
         (2869*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (245304599271964937059*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (16962717961048860*Sqrt[3]) + (245304599271964937059*Pi*Log[3]^2)/
          (814210462130345280*Sqrt[3]) + (36797881397001118329056197*
           PolyGamma[2, 1])/1235346792567894 + 
         (114614464231972580282736224327*Zeta[3])/1902434060554556760) + 
       CF*Log[x]*((11224303480346844583254464583157*NM*NC)/
          172774488009933810000 - (99729067*lm*NM*NC)/1621620 - 
         (112973475737449*NC*NL)/64929664800 - (99729067*lm*NC*NL)/
          1621620 - (345015022726416710961011430541509389*NC*NH)/
          13907804090464796834059531794000 - (99729067*lm*NC*NH)/1621620 + 
         (1559388988631*NM*NC*Pi^2)/81 - (5089*NC*NL*Pi^2)/27 + 
         (106865509374051412*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (2541865828329*Sqrt[3]) + 
         CF*NC*(-697001721798728398191969767255483598490333/
            450262263414866963567545403164800 + (1507146701720069*Pi^2)/
            2245320 + (245304599271964937059*Im[PolyLog[2, (-1)^(1/3)]])/
            (25444076941573290*Sqrt[3]) - 840*Zeta[3]) + 
         CA*NC*(3485011887109493989196047214797496142801749/
            4502622634148669635675454031648000 + (99729067*lm)/294840 - 
           (1507146487273529*Pi^2)/4490640 - (245304599271964937059*
             Im[PolyLog[2, (-1)^(1/3)]])/(50888153883146580*Sqrt[3]) + 
           420*Zeta[3])), 
      (-12164936161988662310010437269905649840915808892523585405159*CF^2*NC)/
        81364743484314123972080005706347275130560000000 + 
       (697112789168027551161766020240685786305119101*CF*NM*NC)/
        182749231576834850214929151029520000 + (6125695978607*CF*lm*NM*NC)/
        2629651424400 + (119688722489832637741*CF*NC*NL)/
        157936864549464000 + (6125695978607*CF*lm*NC*NL)/2629651424400 + 
       (36596470063902718869293562638744805705259301719*CF*NC*NH)/
        1861779025669050305024670351410520070800000 + 
       (6125695978607*CF*lm*NC*NH)/2629651424400 + 
       (2876918739149937870867187*CF^2*NC*Pi^2)/59605432286400 - 
       (21267944517401182*CF*NM*NC*Pi^2)/10945935 + (2*CF*lm*NM*NC*Pi^2)/
        243 - (52195631*CF*NC*NL*Pi^2)/4378374 + (2*CF*lm*NC*NL*Pi^2)/243 + 
       (2*CF*lm*NC*NH*Pi^2)/243 - (414158369511628466035*CF^2*NC*Pi^3)/
        (706618365348835368*Sqrt[3]) - (1461722255819234885*CF*NC*NH*Pi^3)/
        (617673396283947*Sqrt[3]) - (3211*CF^2*NC*Pi^4)/810 + 
       (917682596342780018683346231*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (123781872149982235589400*Sqrt[3]) + 
       (2809997129553259688708*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3091455348401154735*Sqrt[3]) - 
       (3352*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (165663347804651386414*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7633223082471987*Sqrt[3]) - (668215888374507376*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (82831673902325693207*CF^2*NC*Pi*Log[3]^2)/(183197353979327688*
         Sqrt[3]) - (41763493023406711*CF*NC*NH*Pi*Log[3]^2)/
        (22876792454961*Sqrt[3]) + 
       (CF*NC*(136721965708503382929205407003*CF + 
          29*CA*(-2357275228806287102268081251 + 32220607744387062000*lm) - 
          700700*(7*(1122119382531926876551 + 34636889069640*lm)*NM + 
            232908956280*(1384 + 1041*lm)*NL + (98914096197463 + 
              242458223487480*lm)*NH))*Log[x]^2)/236056138551733500 + 
       (4*CF*NC*(-83204027073850411*CA + 166408005346200637*CF - 
          180180*(29835036974*NM - 2429*NL))*Log[x]^3)/3648645 + 
       (1324723693598185609116929455*CF^2*NC*PolyGamma[2, 1])/
        1853020188851841 - (43430160596140*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (1070733794134224200*CF*NC*NH*PolyGamma[2, 1])/1853020188851841 + 
       CA*CF*NC*(276475821832439261565382469354779414401039111875127623711/
          3698397431105187453276363895743057960480000000 - 
         (719229684826692012249203*Pi^2)/29802716143200 + 
         (414158369511628466035*Pi^3)/(1413236730697670736*Sqrt[3]) + 
         (1933*Pi^4)/972 + lm*(-6125695978607/478118440800 - (11*Pi^2)/243) - 
         (917682596342780018683346231*Im[PolyLog[2, (-1)^(1/3)]])/
          (247563744299964471178800*Sqrt[3]) + 
         (1676*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (82831673902325693207*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (7633223082471987*Sqrt[3]) + (82831673902325693207*Pi*Log[3]^2)/
          (366394707958655376*Sqrt[3]) - (1324723693598185609116929455*
           PolyGamma[2, 1])/3706040377703682 - 
         (1241451026485637416958967454580*Zeta[3])/1854873209040692841) + 
       (2482902052845074756695425548089*CF^2*NC*Zeta[3])/
        1854873209040692841 - (86144278958408*CF*NM*NC*Zeta[3])/243 - 
       (58304*CF*NC*NL*Zeta[3])/81 + (16461607607715475648*CF*NC*NH*
         Zeta[3])/1853020188851841 + CF*Log[x]*
        ((-20572090088674608019169250522413*NM*NC)/1401139392586273937025 - 
         (26033495*lm*NM*NC)/729729 - (53407538905417*NC*NL)/48697248600 - 
         (26033495*lm*NC*NL)/729729 - (54196371162031359286183866876954649*
           NC*NH)/3147772227575612301199864444500 - (26033495*lm*NC*NH)/
          729729 - (13260014476*NM*NC*Pi^2)/9 - (9716*NC*NL*Pi^2)/81 + 
         (668215888374507376*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (22876792454961*Sqrt[3]) + 
         CF*NC*(82957292742705866860553521023881903214371525839/
            506545046341725334013488578560400000 + (66563218938086357*Pi^2)/
            1459458 + (165663347804651386414*Im[PolyLog[2, (-1)^(1/3)]])/
            (22899669247415961*Sqrt[3]) - (1792*Zeta[3])/3) + 
         CA*NC*(-41478646332063447437041800652658767877227999307/
            506545046341725334013488578560400000 + (26033495*lm)/132678 - 
           (33281609479341967*Pi^2)/1459458 - (82831673902325693207*
             Im[PolyLog[2, (-1)^(1/3)]])/(22899669247415961*Sqrt[3]) + 
           (896*Zeta[3])/3)), 
      (-7137872084057581276870242214033500831583269230915473991*CF^2*NC)/
        531795709047804731843660168015341667520000000 - 
       (36301177475683860837522517273649765043562261*CF*NM*NC)/
        69935605999308100728716719680000 + (4491344171519*CF*lm*NM*NC)/
        1168733966400 + (846230725432851487*CF*NC*NL)/580117041504000 + 
       (4491344171519*CF*lm*NC*NL)/1168733966400 + 
       (5390451515576657931273534635780997833181996303015932107*CF*NC*NH)/
        164050952594185750966296954129193420809486504000000 + 
       (4491344171519*CF*lm*NC*NH)/1168733966400 + 
       (118953754185585140102909*CF^2*NC*Pi^2)/56625160672080 + 
       (2426178079213501133*CF*NM*NC*Pi^2)/14594580 + 
       (CF*lm*NM*NC*Pi^2)/54 - (71576651*CF*NC*NL*Pi^2)/3243240 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (6180471544352604445*CF^2*NC*Pi^3)/(6542762642118846*Sqrt[3]) - 
       (384747837669725215*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) - 
       (2203*CF^2*NC*Pi^4)/270 + (144277444763889883868238767*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(13753541349998026176600*Sqrt[3]) + 
       (3478933047671618904992*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (343495038711239415*Sqrt[3]) - 
       (6536*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (9888754470964167112*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (282711966017481*Sqrt[3]) - (43971181447968596*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (1236094308870520889*CF^2*NC*Pi*Log[3]^2)/(1696271796104886*Sqrt[3]) - 
       (10992795361992149*CF*NC*NH*Pi*Log[3]^2)/(3389154437772*Sqrt[3]) + 
       (CF*NC*(122980253016144100117003293349*CF + 412641*CA*
           (-149015928101821355819077 + 89805857656515000*lm) - 
          10010*(4495*(-216288923178107989712653 + 149744396201400*lm)*NM + 
            330924808714500*(2557 + 2034*lm)*NL + (291074899979683829 + 
              673101060925293000*lm)*NH))*Log[x]^2)/4878493530069159000 + 
       (CF*NC*(-44990478778363805*CA + 28*(3213573137265187*CF + 
            12870*(12777334503872*NM + 18645*NL)))*Log[x]^3)/7297290 - 
       (2980628326650694717256121652*CF^2*NC*PolyGamma[2, 1])/
        5559060566555523 + (115813761799393*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (993128743854295367*CF*NC*NH*PolyGamma[2, 1])/11118121133111046 - 
       (60015258052051072821184539224881*CF^2*NC*Zeta[3])/
        55646196271220785230 + (107295539045189*CF*NM*NC*Zeta[3])/27 - 
       (4144*CF*NC*NL*Zeta[3])/3 + (63802277500647919307*CF*NC*NH*Zeta[3])/
        5559060566555523 + CA*CF*NC*
        (3568935802366205416498979950017885169148308056960717433/
          531795709047804731843660168015341667520000000 - 
         (25042895514458932096487*Pi^2)/23842172914560 + 
         (6180471544352604445*Pi^3)/(13085525284237692*Sqrt[3]) + 
         (737*Pi^4)/180 + lm*(-4491344171519/212497084800 - (11*Pi^2)/108) - 
         (144277444763889883868238767*Im[PolyLog[2, (-1)^(1/3)]])/
          (27507082699996052353200*Sqrt[3]) + 
         (3268*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (4944377235482083556*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (282711966017481*Sqrt[3]) + (1236094308870520889*Pi*Log[3]^2)/
          (3392543592209772*Sqrt[3]) + (1490314163325347358628060826*
           PolyGamma[2, 1])/5559060566555523 + 
         (60015258091837416165029978185501*Zeta[3])/111292392542441570460) + 
       CF*Log[x]*((21738552923454392791389262103831*NM*NC)/
          39581064525912109200 - (114119443*lm*NM*NC)/1621620 - 
         (113370067813397*NC*NL)/53124271200 - (114119443*lm*NC*NL)/
          1621620 - (11590880182501936773956167966661127091651*NC*NH)/
          378686325709872309796717618197630000 - (114119443*lm*NC*NH)/
          1621620 + (12777334518277*NM*NC*Pi^2)/81 - (6215*NC*NL*Pi^2)/27 + 
         (43971181447968596*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (847288609443*Sqrt[3]) + CF*NC*
          (-4857057817237472602335867654572118923514247/
            275895994739501815911486153900000 + (44990428785740083*Pi^2)/
            14594580 + (9888754470964167112*Im[PolyLog[2, (-1)^(1/3)]])/
            (848135898052443*Sqrt[3]) - 960*Zeta[3]) + 
         CA*NC*(4857058295606974732811048908222643298820297/
            551791989479003631822972307800000 + (114119443*lm)/294840 - 
           (44990427090696733*Pi^2)/29189160 - (4944377235482083556*
             Im[PolyLog[2, (-1)^(1/3)]])/(848135898052443*Sqrt[3]) + 
           480*Zeta[3])), 
      (-29582428942370491180825056840902227001906522767063728412840193489*
         CF^2*NC)/23812856746067246034660711110065244317910734080000000 + 
       (790533689240121845298087205577178782723978375810809913*CF*NM*NC)/
        15243990602135363663708272147297204896000000 + 
       (52377572736127*CF*lm*NM*NC)/21037211395200 + 
       (502254769581035189729*CF*NC*NL)/541497821312448000 + 
       (52377572736127*CF*lm*NC*NL)/21037211395200 + 
       (425697990778795895368522370562469118437708949004755231941*CF*NC*NH)/
        17717502880172061104360071045952889447424542432000000 + 
       (52377572736127*CF*lm*NC*NH)/21037211395200 + 
       (2740267896799584895017594821*CF^2*NC*Pi^2)/6795019280649600 - 
       (15347378049368707*CF*NM*NC*Pi^2)/694980 + (2*CF*lm*NM*NC*Pi^2)/
        243 - (1189044607*CF*NC*NL*Pi^2)/87567480 + (2*CF*lm*NC*NL*Pi^2)/
        243 + (2*CF*lm*NC*NH*Pi^2)/243 - (3000523635829423573895*CF^2*NC*
         Pi^3)/(4239710192093012208*Sqrt[3]) - 
       (10791878621866449415*CF*NC*NH*Pi^3)/(3706040377703682*Sqrt[3]) - 
       (11033*CF^2*NC*Pi^4)/2430 + (2651791944769018844902768357*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(297076493159957365414560*Sqrt[3]) + 
       (2380994199596893199444*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1324909435029066315*Sqrt[3]) - 
       (3800*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (600104727165884714779*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (22899669247415961*Sqrt[3]) - (2466715113569474152*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (600104727165884714779*CF^2*NC*Pi*Log[3]^2)/(1099184123875966128*
         Sqrt[3]) - (308339389196184269*CF*NC*NH*Pi*Log[3]^2)/
        (137260754729766*Sqrt[3]) + 
       (CF*NC*(31*CA*(-9138793400289540640909456373983 + 
            18151959343566288240000*lm) + 
          26*(21792507395755549313001256152861*CF - 
            3080*((387450337419260409994957567 + 1277610434226126000*lm)*
               NM + 90252220558500*(18775 + 14156*lm)*NL + 
              (531199019434676317 + 1277610434226126000*lm)*NH)))*Log[x]^2)/
        117083844721659816000 + (CF*NC*(-5544697106593221179*CA + 
          11089393712188371284*CF - 240240*(2212323219784*NM - 17695*NL))*
         Log[x]^3)/7297290 + (107302619356816791223012725952*CF^2*NC*
         PolyGamma[2, 1])/16677181699666569 - 
       (130290481995545*CF*NM*NC*PolyGamma[2, 1])/81 + 
       (11527280966240253041*CF*NC*NH*PolyGamma[2, 1])/16677181699666569 + 
       CA*CF*NC*
        (29582428942286015876855772712818376084579785776934137379358195739/
          47625713492134492069321422220130488635821468160000000 - 
         (144224626148365937784247559*Pi^2)/715265187436800 + 
         (3000523635829423573895*Pi^3)/(8479420384186024416*Sqrt[3]) + 
         (2213*Pi^4)/972 + lm*(-52377572736127/3824947526400 - 
           (11*Pi^2)/243) - (2651791944769018844902768357*
           Im[PolyLog[2, (-1)^(1/3)]])/(594152986319914730829120*Sqrt[3]) + 
         (1900*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (600104727165884714779*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (45799338494831922*Sqrt[3]) + (600104727165884714779*Pi*Log[3]^2)/
          (2198368247751932256*Sqrt[3]) - (53651309678408395611506362976*
           PolyGamma[2, 1])/16677181699666569 - 
         (404270710851679971186487586800313*Zeta[3])/66775435525464942276) + 
       (404270710848812749399357129155425*CF^2*NC*Zeta[3])/
        33387717762732471138 - (257631199149226*CF*NM*NC*Zeta[3])/81 - 
       (23596*CF*NC*NL*Zeta[3])/27 + (178364282344682356486*CF*NC*NH*
         Zeta[3])/16677181699666569 + CF*Log[x]*
        ((-14212444660223182724759094840905590210327*NM*NC)/
          105565204571992085472912360000 - (593189347*lm*NM*NC)/14594580 - 
         (439816248985793*NC*NL)/328706428050 - (593189347*lm*NC*NL)/
          14594580 - (371197169948359773769047419714280227410427*NC*NH)/
          17527767075714089767733786899433160000 - (593189347*lm*NC*NH)/
          14594580 - (4424646373558*NM*NC*Pi^2)/243 - (35390*NC*NL*Pi^2)/
          243 + (2466715113569474152*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (68630377364883*Sqrt[3]) + 
         CF*NC*(111346151756647183999414898615712108609391872521299/
            79875821995010813607251980231743075000 + 
           (277234853677613708*Pi^2)/729729 + (600104727165884714779*
             Im[PolyLog[2, (-1)^(1/3)]])/(68699007742247883*Sqrt[3]) - 
           680*Zeta[3]) + CA*NC*
          (-7126153711588309430089589156909918728370246583697411/
            10224105215361384141728253469663113600000 + (593189347*lm)/
            2653560 - (138617426845104145*Pi^2)/729729 - 
           (600104727165884714779*Im[PolyLog[2, (-1)^(1/3)]])/
            (137398015484495766*Sqrt[3]) + 340*Zeta[3])), 
      (-3049168887947731391068437346255262933782420663290879240091869973*CF^2*
         NC)/61233060204172918374841828568739199674627601920000000 - 
       (529451107761385523773521260869742736468654077761*CF*NM*NC)/
        123822830832459184658633181580800000 + (19175368043651*CF*lm*NM*NC)/
        4674935865600 + (165931306866454623359*CF*NC*NL)/93592216029312000 + 
       (19175368043651*CF*lm*NC*NL)/4674935865600 + 
       (2540730850235250292641482610463936663863648252898167548071*CF*NC*NH)/
        63783010368619419975696255765430402010728352755200000 + 
       (19175368043651*CF*lm*NC*NH)/4674935865600 - 
       (2241641030152567284264083*CF^2*NC*Pi^2)/3020008569177600 + 
       (8044890580655300633*CF*NM*NC*Pi^2)/5837832 + 
       (CF*lm*NM*NC*Pi^2)/54 - (162357487*CF*NC*NL*Pi^2)/6486480 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (172316750127000761787305*CF^2*NC*Pi^3)/(152629566915348439488*
         Sqrt[3]) - (85439975832993917450*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) - (3341*CF^2*NC*Pi^4)/360 + 
       (671171778400369835080506877931*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (53473768768792325774620800*Sqrt[3]) + 
       (218765385334910869158241*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (16693858881366235569*Sqrt[3]) - 
       (2462*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (34463350025400152357461*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(824388092906974596*
         Sqrt[3]) - (39058274666511505120*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (34463350025400152357461*CF^2*NC*Pi*Log[3]^2)/(39570628459534780608*
         Sqrt[3]) - (2441142166656969070*CF*NC*NH*Pi*Log[3]^2)/
        (617673396283947*Sqrt[3]) - 
       (CF*NC*(-31*CA*(11213863868181314714293058239 + 
            23068734767907244416000*lm) + 2*(347628911282415483726331933279*
             CF + 200200*(85405*(-37746626598851768433877 + 3802291549056*lm)*
               NM + 19253807052480*(21155 + 16866*lm)*NL + 
              (142999239755163947 + 324734709747127680*lm)*NH)))*Log[x]^2)/
        78055896481106544000 + (CF*NC*(-72161422841227771*CA + 
          8*(18040259094498247*CF + 60060*(52774351454989*NM + 11244*NL)))*
         Log[x]^3)/4864860 - (241430893727345223049742672380*CF^2*NC*
         PolyGamma[2, 1])/50031545098999707 + 
       (1042323856224769*CF*NM*NC*PolyGamma[2, 1])/54 + 
       (10063868459416151711*CF*NC*NH*PolyGamma[2, 1])/100063090197999414 - 
       (19363500749446091890637116379514121*CF^2*NC*Zeta[3])/
        2003263065763948268280 + (971958054585455*CF*NM*NC*Zeta[3])/27 - 
       1666*CF*NC*NL*Zeta[3] + (688736218666780621643*CF*NC*NH*Zeta[3])/
        50031545098999707 + CA*CF*NC*
        (21344181757830454608932202029153811072069996248263477538134437811/
          857262842858420857247785599962348795444786426880000000 + 
         (6724923182053013713204609*Pi^2)/18120051415065600 + 
         (172316750127000761787305*Pi^3)/(305259133830696878976*Sqrt[3]) + 
         (2011*Pi^4)/432 + lm*(-19175368043651/849988339200 - 
           (11*Pi^2)/108) - (671171778400369835080506877931*
           Im[PolyLog[2, (-1)^(1/3)]])/(106947537537584651549241600*
           Sqrt[3]) + (1231*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (34463350025400152357461*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1648776185813949192*Sqrt[3]) + (34463350025400152357461*Pi*
           Log[3]^2)/(79141256919069561216*Sqrt[3]) + 
         (120715446863672611524871336190*PolyGamma[2, 1])/50031545098999707 + 
         (19363500751162171120355990977531561*Zeta[3])/
          4006526131527896536560) + CF*Log[x]*
        ((11246990236626031737070397637875419*NM*NC)/
          2416528150003055088000 - (258944561*lm*NM*NC)/3243240 - 
         (1509787089025213*NC*NL)/584366983200 - (258944561*lm*NC*NL)/
          3243240 - (16466769932205561197268850923786680245539359*NC*NH)/
          441699730307995062146891429865715632000 - (258944561*lm*NC*NH)/
          3243240 + (105548702928322*NM*NC*Pi^2)/81 - (7496*NC*NL*Pi^2)/
          27 + (39058274666511505120*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (617673396283947*Sqrt[3]) + 
         CF*NC*(-133996731509926589352289024021807693468470286344287/
            718882397955097322465267822085687675000 + 
           (144322765264391569*Pi^2)/19459440 + (34463350025400152357461*
             Im[PolyLog[2, (-1)^(1/3)]])/(2473164278720923788*Sqrt[3]) - 
           1088*Zeta[3]) + CA*NC*
          (17151581821363197503003115579771303837004158405487411/
            184033893876504914551108562453936044800000 + (258944561*lm)/
            589680 - (144322762548198089*Pi^2)/38918880 - 
           (34463350025400152357461*Im[PolyLog[2, (-1)^(1/3)]])/
            (4946328557441847576*Sqrt[3]) + 544*Zeta[3])), 
      (-112729132520133897285797711394927554580936811951147971641797287458006\
2009*CF^2*NC)/108539548744279666972642318436032915101656437883523840000000 + 
       (17892835736690987336781705847419068019740288317367407*CF*NM*NC)/
        30858280571124217942729295844731184000000 + 
       (8055887845000739*CF*lm*NM*NC)/3039877046606400 + 
       (613928563585093504674649*CF*NC*NL)/547725046257541152000 + 
       (8055887845000739*CF*lm*NC*NL)/3039877046606400 + 
       (2313512330929967368969656359664397661677597985143030891537*CF*NC*NH)/
        79728762960774274969620319706788002513410440944000000 + 
       (8055887845000739*CF*lm*NC*NH)/3039877046606400 + 
       (782700535249684847449967124829*CF^2*NC*Pi^2)/231030655542086400 - 
       (449611611465865627*CF*NM*NC*Pi^2)/1969110 + (2*CF*lm*NM*NC*Pi^2)/
        243 - (11420188657*CF*NC*NL*Pi^2)/744323580 + 
       (2*CF*lm*NC*NL*Pi^2)/243 + (2*CF*lm*NC*NH*Pi^2)/243 - 
       (1096073817061074307871225*CF^2*NC*Pi^3)/(1297351318780461735648*
         Sqrt[3]) - (59011011222623661040*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) - (5011*CF^2*NC*Pi^4)/972 + 
       (82160484490833587266175937559267*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (7726959587090491074432705600*Sqrt[3]) + 
       (244827501466312360817176*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (83469294406831177845*Sqrt[3]) - 
       (4276*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (219214763412214861574245*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7007298789709284066*
         Sqrt[3]) - (26976462273199387904*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (219214763412214861574245*CF^2*NC*Pi*Log[3]^2)/(336350341906045635168*
         Sqrt[3]) - (1686028892074961744*CF*NC*NH*Pi*Log[3]^2)/
        (617673396283947*Sqrt[3]) + 
       (CF*NC*(80919494821936243309439028903993794*CF + 
          3*CA*(-13486582465308430883383173166186769 + 
            3826072623385700303616000*lm) - 2722720*
           (19*(105423662816180388961891619 + 40341792566275200*lm)*NM + 
            144403552893600*(7025 + 5308*lm)*NL + (324082841722718831 + 
              766494058759228800*lm)*NH))*Log[x]^2)/1990425360268216872000 + 
       (CF*NC*(-394919577758505758817*CA + 170*(4646112647836340669*CF - 
            48048*(5943272915509*NM - 5308*NL)))*Log[x]^3)/62026965 + 
       (8691512169820522402325259845377*CF^2*NC*PolyGamma[2, 1])/
        150094635296999121 - (1172614338217352*CF*NM*NC*PolyGamma[2, 1])/
        81 + (122844723596420005796*CF*NC*NH*PolyGamma[2, 1])/
        150094635296999121 + CA*CF*NC*(11272913252027044942015557439277797370\
62154325619160217668072442685626259/
          217079097488559333945284636872065830203312875767047680000000 - 
         (782700535250396911069278709369*Pi^2)/462061311084172800 + 
         (1096073817061074307871225*Pi^3)/(2594702637560923471296*Sqrt[3]) + 
         (2791*Pi^4)/1080 + lm*(-8055887845000739/552704917564800 - 
           (11*Pi^2)/243) - (82160484490833587266175937559267*
           Im[PolyLog[2, (-1)^(1/3)]])/(15453919174180982148865411200*
           Sqrt[3]) + (2138*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (219214763412214861574245*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (14014597579418568132*Sqrt[3]) + (219214763412214861574245*Pi*
           Log[3]^2)/(672700683812091270336*Sqrt[3]) - 
         (8691512169820522402325259845377*PolyGamma[2, 1])/
          300189270593998242 - (29897843571272349559197257517624691*Zeta[3])/
          546344472481076800440) + (29897843571243315734730655109137111*CF^2*
         NC*Zeta[3])/273172236240538400220 - 
       (2313531220222696*CF*NM*NC*Zeta[3])/81 - (28312*CF*NC*NL*Zeta[3])/
        27 + (1911757193844626205208*CF*NC*NH*Zeta[3])/150094635296999121 + 
       CF*Log[x]*((-310231867029039716007342558632776366399*NM*NC)/
          252548336296631783428020000 - (5698392577*lm*NM*NC)/124053930 - 
         (36038152509581851*NC*NL)/22352037107400 - (5698392577*lm*NC*NL)/
          124053930 - (2029038104056070243697316024587092676253439*NC*NH)/
          78874951840713403954802041047449220000 - (5698392577*lm*NC*NH)/
          124053930 - (47546183242888*NM*NC*Pi^2)/243 - 
         (42464*NC*NL*Pi^2)/243 + (26976462273199387904*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(2234898403159153059115013812598990895891927660485464797809/
            187910107766278799313841286550622072743600000 + 
           (143607119062363619737*Pi^2)/45110520 + 
           (219214763412214861574245*Im[PolyLog[2, (-1)^(1/3)]])/
            (21021896369127852198*Sqrt[3]) - 768*Zeta[3]) + 
         CA*NC*(-34920287548861152900972367805884627670421131735793221531/
            5872190867696212478557540204706939773237500 + 
           (5698392577*lm)/22555260 - (143607119063303422237*Pi^2)/90221040 - 
           (219214763412214861574245*Im[PolyLog[2, (-1)^(1/3)]])/
            (42043792738255704396*Sqrt[3]) + 384*Zeta[3])), 
      (279439706914771427353016896170575259117398990698851104979552350119301*
         CF^2*NC)/
        6202259928244552398436703910630452291523225021915648000000 - 
       (360505994125069875671601765049183893674422016788370707123*CF*NM*NC)/
        10162660401423575775805514764864803264000000 + 
       (5891435825671139*CF*lm*NM*NC)/1351056465158400 + 
       (12341844461978755698671*CF*NC*NL)/5796032235529536000 + 
       (5891435825671139*CF*lm*NC*NL)/1351056465158400 + 
       (5076840745272328881642735426074379651160026107617017832699*CF*NC*NH)/
        106305017281032366626160426275717336684547254592000000 + 
       (5891435825671139*CF*lm*NC*NH)/1351056465158400 - 
       (1582673901392181754364179487*CF^2*NC*Pi^2)/11001459787718400 + 
       (814895572136186027957*CF*NM*NC*Pi^2)/70887960 + 
       (CF*lm*NM*NC*Pi^2)/54 - (3106983839*CF*NC*NL*Pi^2)/110270160 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (54137904739814262259690*CF^2*NC*Pi^3)/(40542228711889429239*
         Sqrt[3]) - (68612722957659264685*CF*NC*NH*Pi^3)/
        (11118121133111046*Sqrt[3]) - (1414*CF^2*NC*Pi^4)/135 + 
       (2051559525003153183504253291571*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (137981421198044483472012600*Sqrt[3]) + 
       (462795339460718172245842*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) - 
       (8288*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (24748756452486519890144*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(500521342122091719*
         Sqrt[3]) - (15682908104607831928*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (1546797278280407493134*CF^2*NC*Pi*Log[3]^2)/(1501564026366275157*
         Sqrt[3]) - (1960363513075978991*CF*NC*NH*Pi*Log[3]^2)/
        (411782264189298*Sqrt[3]) - 
       (CF*NC*(-9*CA*(12726369148668793212456030737861 + 
            161137629042553372809600*lm) + 
          56*(4090618591902579966939704314156*CF + 
            2431*(7*(-19208539148974858707189600761 + 276697836423122400*lm)*
               NM + 818286799730400*(2963 + 2367*lm)*NL + 
              (866793853643686537 + 1936884854961856800*lm)*NH)))*Log[x]^2)/
        132695024017881124800 + (CF*NC*(36948414493931917075*CA - 
          224*(329896779165530854*CF - 109395*(438932154554296*NM + 
              13413*NL)))*Log[x]^3)/248107860 - 
       (19555902383972011252600199354131*CF^2*NC*PolyGamma[2, 1])/
        450283905890997363 + (9380914706057473*CF*NM*NC*PolyGamma[2, 1])/
        54 + (101306582558480802551*CF*NC*NH*PolyGamma[2, 1])/
        900567811781994726 - (1898355654392172207221491468948231441*CF^2*NC*
         Zeta[3])/21892803504420291789060 + (8795671833678239*CF*NM*NC*
         Zeta[3])/27 - (5962*CF*NC*NL*Zeta[3])/3 + 
       (7357881883717398305831*CF*NC*NH*Zeta[3])/450283905890997363 + 
       CA*CF*NC*
        (-1956078002910198998095868025172388173432459409427245014543618066447\
907/86831638995423733578113854748826332081325150306819072000000 + 
         (1582673901520070442152049067*Pi^2)/22002919575436800 + 
         (27068952369907131129845*Pi^3)/(40542228711889429239*Sqrt[3]) + 
         (709*Pi^4)/135 + lm*(-5891435825671139/245646630028800 - 
           (11*Pi^2)/108) - (2051559525003153183504253291571*
           Im[PolyLog[2, (-1)^(1/3)]])/(275962842396088966944025200*
           Sqrt[3]) + (4144*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (12374378226243259945072*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (500521342122091719*Sqrt[3]) + (773398639140203746567*Pi*Log[3]^2)/
          (1501564026366275157*Sqrt[3]) + (19555902383972011252600199354131*
           PolyGamma[2, 1])/900567811781994726 + 
         (1898355654414420160649427912137425081*Zeta[3])/
          43785607008840583578120) + CF*Log[x]*
        ((163693442783274449744525245654746322574551*NM*NC)/
          4139811943999689626388720000 - (4956771697*lm*NM*NC)/55135080 - 
         (61439562741297121*NC*NL)/19868477428800 - (4956771697*lm*NC*NL)/
          55135080 - (33047405924039081043704831149501370594075221*NC*NH)/
          736166217179991770244819049776192720000 - (4956771697*lm*NC*NH)/
          55135080 + (877864309131508*NM*NC*Pi^2)/81 - (8942*NC*NL*Pi^2)/
          27 + (15682908104607831928*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (205891132094649*Sqrt[3]) + 
         CF*NC*(-81034626751528452998092024583307139802960925279860884909/
            42950881775149439843163722640142188055680000 - 
           (5278345277236907717*Pi^2)/70887960 + (24748756452486519890144*
             Im[PolyLog[2, (-1)^(1/3)]])/(1501564026366275157*Sqrt[3]) - 
           1224*Zeta[3]) + CA*NC*
          (283621193989417801523681441532522133993676457413047270529/
            300656172426046078902146058480995316389760000 + 
           (4956771697*lm)/10024560 + (5278345289005038377*Pi^2)/141775920 - 
           (12374378226243259945072*Im[PolyLog[2, (-1)^(1/3)]])/
            (1501564026366275157*Sqrt[3]) + 612*Zeta[3])), 
      (-127903084336773348550026050628518847292733495112937851342138370193514\
792011*CF^2*NC)/
        1465283908047775504130671298886444353872361911427571840000000 + 
       (3779069685091912108141851689188547395397933232027535183*CF*NM*NC)/
        635166275088973485987844672804050204000000 + 
       (316417702408057*CF*lm*NM*NC)/112588038763200 + 
       (586895497002894177310783*CF*NC*NL)/438180037006032921600 + 
       (316417702408057*CF*lm*NC*NL)/112588038763200 + 
       (37318493479421556557126477322695270876639009678906906439613*CF*NC*
         NH)/1076338299970452712089874316041638033931040952744000000 + 
       (316417702408057*CF*lm*NC*NH)/112588038763200 + 
       (6606154947858440504720216304617*CF^2*NC*Pi^2)/231030655542086400 - 
       (396699232056856807*CF*NM*NC*Pi^2)/176715 + (2*CF*lm*NM*NC*Pi^2)/
        243 - (12813180257*CF*NC*NL*Pi^2)/744323580 + 
       (2*CF*lm*NC*NL*Pi^2)/243 + (2*CF*lm*NC*NH*Pi^2)/243 - 
       (34973322270358478153187125*CF^2*NC*Pi^3)/(35028485607072466862496*
         Sqrt[3]) - (1914631662195989369570*CF*NC*NH*Pi^3)/
        (450283905890997363*Sqrt[3]) - (3137*CF^2*NC*Pi^4)/540 + 
       (523469201089177048674307395713819*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (41725581770288651801936610240*Sqrt[3]) + 
       (9799794915554507452371638*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2253670948984441801815*Sqrt[3]) - 
       (4780*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (6994664454071695630637425*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(189197067322150669782*
         Sqrt[3]) - (875260188432452283232*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (6994664454071695630637425*CF^2*NC*Pi*Log[3]^2)/
        (9081459231463232149536*Sqrt[3]) - (54703761777028267702*CF*NC*NH*Pi*
         Log[3]^2)/(16677181699666569*Sqrt[3]) + 
       (CF*NC*(CA*(-1024465993846488531278285635811715539 + 
            40887907506292012678512000*lm) + 
          22*(93133272172743570710065052646319219*CF - 
            2227680*(2*(1641084182866405610631276457 + 75844957750011450*lm)*
               NM + 102285849966300*(1959 + 1483*lm)*NL + 
              (65102925524724539 + 151689915500022900*lm)*NH)))*Log[x]^2)/
        5971276080804650616000 + (CF*NC*(-3325905009792361583823*CA + 
          6651810012864079267922*CF - 2042040*(238780961813801*NM - 
            25211*NL))*Log[x]^3)/62026965 + 
       (704012485776199264322116698533632*CF^2*NC*PolyGamma[2, 1])/
        1350851717672992089 - (31660587132814301*CF*NM*NC*PolyGamma[2, 1])/
        243 + (1297321655980719880787*CF*NC*NH*PolyGamma[2, 1])/
        1350851717672992089 + CA*CF*NC*(3197577108420500372213903086818321825\
5267276859000207638982691234065725159/
          732641954023887752065335649443222176936180955713785920000000 - 
         (6606154947859209061663040635277*Pi^2)/462061311084172800 + 
         (34973322270358478153187125*Pi^3)/(70056971214144933724992*
           Sqrt[3]) + (28297*Pi^4)/9720 + 
         lm*(-316417702408057/20470552502400 - (11*Pi^2)/243) - 
         (523469201089177048674307395713819*Im[PolyLog[2, (-1)^(1/3)]])/
          (83451163540577303603873220480*Sqrt[3]) + 
         (2390*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (6994664454071695630637425*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (378394134644301339564*Sqrt[3]) + (6994664454071695630637425*Pi*
           Log[3]^2)/(18162918462926464299072*Sqrt[3]) - 
         (352006242888099632161058349266816*PolyGamma[2, 1])/
          1350851717672992089 - (5347709909405366935906352411649397669*
           Zeta[3])/10817620555125320648712) + 
       (5347709909404666929015738962659518361*CF^2*NC*Zeta[3])/
        5408810277562660324356 - (62366050415999950*CF*NM*NC*Zeta[3])/243 - 
       (100852*CF*NC*NL*Zeta[3])/81 + (20294047304848504552906*CF*NC*NH*
         Zeta[3])/1350851717672992089 + CF*Log[x]*
        ((-49055500812174425729266446274970045588057*NM*NC)/
          4398550190499670228038015000 - (6394538027*lm*NM*NC)/124053930 - 
         (68725122355657003*NC*NL)/35763259371840 - (6394538027*lm*NC*NL)/
          124053930 - (57585917751545179761338411481276644358095363*NC*NH)/
          1863420737236854168432198219745987822500 - (6394538027*lm*NC*NH)/
          124053930 - (477561923529104*NM*NC*Pi^2)/243 - 
         (50422*NC*NL*Pi^2)/243 + (875260188432452283232*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CF*NC*(2064113800844924752943732513239386631585996581035300805881213/
            20294291638758110325894858947467183856308800000 + 
           (52171058970857949293*Pi^2)/1945944 + (6994664454071695630637425*
             Im[PolyLog[2, (-1)^(1/3)]])/(567591201966452009346*Sqrt[3]) - 
           (2584*Zeta[3])/3) + CA*NC*
          (-2064113800841371015041338517771047777346089644779134789494613/
            40588583277516220651789717894934367712617600000 + 
           (6394538027*lm)/22555260 - (17390352990302109875*Pi^2)/1297296 - 
           (6994664454071695630637425*Im[PolyLog[2, (-1)^(1/3)]])/
            (1135182403932904018692*Sqrt[3]) + (1292*Zeta[3])/3)), 
      (2263329505650812054155478867562712354330093681618992187909219815406607\
6749*CF^2*NC)/5861135632191102016522685195545777415489447645710287360000000 - 
       (601796430276490722164572555445141863028679396372762068581*CF*NM*NC)/
        2032532080284715155161102952972960652800000 + 
       (6241246398783139*CF*lm*NM*NC)/1351056465158400 + 
       (4189226638168681509916457*CF*NC*NL)/1655346806467235481600 + 
       (6241246398783139*CF*lm*NC*NL)/1351056465158400 + 
       (197816519249370366113461972639360586409767590899543719799343129*CF*NC*
         NH)/3489264890137813838431257838749253845293377112277877248000 + 
       (6241246398783139*CF*lm*NC*NH)/1351056465158400 - 
       (16062609026209309686969958451*CF^2*NC*Pi^2)/7108635555141120 + 
       (1594691745563432619427*CF*NM*NC*Pi^2)/16540524 + 
       (CF*lm*NM*NC*Pi^2)/54 - (10422972437*CF*NC*NL*Pi^2)/330810480 + 
       (CF*lm*NC*NL*Pi^2)/54 + (CF*lm*NC*NH*Pi^2)/54 - 
       (109630321828403941075019155*CF^2*NC*Pi^3)/(70056971214144933724992*
         Sqrt[3]) - (13253079629284919345075*CF*NC*NH*Pi^3)/
        (1801135623563989452*Sqrt[3]) - (12679*CF^2*NC*Pi^4)/1080 + 
       (7283649186176832862825342466793161*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(417255817702886518019366102400*
         Sqrt[3]) + (318289405262897586276516931*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(15324962453094204252342*Sqrt[3]) - 
       (9242*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (21926064365680788215003831*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(378394134644301339564*
         Sqrt[3]) - (1514637671918276496580*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (21926064365680788215003831*CF^2*NC*Pi*Log[3]^2)/
        (18162918462926464299072*Sqrt[3]) - (378659417979569124145*CF*NC*NH*
         Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) + 
       ((-53970567169558603068901620060050941*CF^2*NC)/
          1990425360268216872000 + CA*CF*(53970567232201307262925816707432571/
            3980850720536433744000 + (38731*lm)/3)*NC + 
         CF*NC*((225538337964791687154199059503/194944796406360 - 
             (7042*lm)/3)*NM - ((79195 + 63378*lm)*NL)/27 - 
           (7687281233717862001*NH)/7212957467035320 - (7042*lm*NH)/3))*
        Log[x]^2 - (CF*NC*(-274494747306158521061*CA + 
          24*(22874563129764044161*CF - 1531530*(815986076422618*NM + 
              3521*NL)))*Log[x]^3)/82702620 - 
       (1584028093016413923731054688713647*CF^2*NC*PolyGamma[2, 1])/
        4052555153018976267 + (84428232354556417*CF*NM*NC*PolyGamma[2, 1])/
        54 + (1013748547710638125679*CF*NC*NH*PolyGamma[2, 1])/
        8105110306037952534 - (2147276887128099463669156187891613140849*CF^2*
         NC*Zeta[3])/2758493241556956765421560 + 
       (79532315896446977*CF*NM*NC*Zeta[3])/27 - (21128*CF*NC*NL*Zeta[3])/
        9 + (77879812923649035974543*CF*NC*NH*Zeta[3])/4052555153018976267 + 
       CA*CF*NC*(-22633295065093733716353548134285805644519330215018199336584\
197391943109749/
          11722271264382204033045370391091554830978895291420574720000000 + 
         (16062609026303367473682396923*Pi^2)/14217271110282240 + 
         (109630321828403941075019155*Pi^3)/(140113942428289867449984*
           Sqrt[3]) + (4237*Pi^4)/720 + 
         lm*(-6241246398783139/245646630028800 - (11*Pi^2)/108) - 
         (7283649186176832862825342466793161*Im[PolyLog[2, (-1)^(1/3)]])/
          (834511635405773036038732204800*Sqrt[3]) + 
         (4621*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (21926064365680788215003831*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (756788269288602679128*Sqrt[3]) + (21926064365680788215003831*Pi*
           Log[3]^2)/(36325836925852928598144*Sqrt[3]) + 
         (1584028093016413923731054688713647*PolyGamma[2, 1])/
          8105110306037952534 + (2147276887131395352260734981419483493649*
           Zeta[3])/5516986483113913530843120) + 
       CF*Log[x]*((1185102479313256318301840612456518028816831*NM*NC)/
          3518840152399736182430412000 - (1848066179*lm*NM*NC)/18378360 - 
         (494995289910359863*NC*NL)/135105646515840 - (1848066179*lm*NC*NL)/
          18378360 - (43680142600447685941797354846579120379981597003*NC*NH)/
          816327356568721074106777396106322345280800 - (1848066179*lm*NC*NH)/
          18378360 + (2447958229277243*NM*NC*Pi^2)/27 - 
         (3521*NC*NL*Pi^2)/9 + (1514637671918276496580*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CF*NC*(-14460016162741098941224500382130603604599381004493207012373/
            780549678413773474072879190287199379088800000 - 
           (548989496539429290439*Pi^2)/330810480 + 
           (21926064365680788215003831*Im[PolyLog[2, (-1)^(1/3)]])/
            (1135182403932904018692*Sqrt[3]) - 1368*Zeta[3]) + 
         CA*NC*(68356440052266160987853621679277092536219788393091323954111/
            7379742414093858300325403253624430493203200000 + 
           (1848066179*lm)/3341520 + (548989496604138134639*Pi^2)/661620960 - 
           (21926064365680788215003831*Im[PolyLog[2, (-1)^(1/3)]])/
            (2270364807865808037384*Sqrt[3]) + 684*Zeta[3])), 
      (-123103710942627266818508682988811030118049413303237345595376778529890\
245419247*CF^2*NC)/
        167042365517446407470896528073054656341449257902743189760000000 + 
       (75218725696525204880145215522410692628802320087442011251967*CF*NM*
         NC)/1291227183896258487722098844610443678256000000 + 
       (3260089878440858779*CF*lm*NM*NC)/1097395613824910400 + 
       (169098395753435446542542549*CF*NC*NL)/106710749488334287296000 + 
       (3260089878440858779*CF*lm*NC*NL)/1097395613824910400 + 
       (13423200680789319921164721453642065145156008682786957707850620389*CF*
         NC*NH)/
        327118583450420047352930422382742547996254104276050992000000 + 
       (3260089878440858779*CF*lm*NC*NH)/1097395613824910400 + 
       (59094353903738568786500962911059*CF^2*NC*Pi^2)/243865691961091200 - 
       (1484182912523111374898*CF*NM*NC*Pi^2)/69324255 + 
       (2*CF*lm*NM*NC*Pi^2)/243 - (90477045881*CF*NC*NL*Pi^2)/4714049340 + 
       (2*CF*lm*NC*NL*Pi^2)/243 + (2*CF*lm*NC*NH*Pi^2)/243 - 
       (291839319007475381018749055*CF^2*NC*Pi^3)/(249577959950391326395284*
         Sqrt[3]) - (6834100269089428798645*CF*NC*NH*Pi^3)/
        (1350851717672992089*Sqrt[3]) - (1580*CF^2*NC*Pi^4)/243 + 
       (414487715043381752344081732842189553*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(28243003160764131188435843056200*
         Sqrt[3]) + (698246629573099900698030326*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(114937218398206531892565*Sqrt[3]) - 
       (5312*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (233471455205980304814999244*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5392116418681294088787*
         Sqrt[3]) - (3124160123012310307952*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (58367863801495076203749811*CF^2*NC*Pi*Log[3]^2)/
        (64705397024175529065444*Sqrt[3]) - (195260007688269394247*CF*NC*NH*
         Pi*Log[3]^2)/(50031545098999707*Sqrt[3]) + 
       (CF*NC*(74*CA*(-20619460501667229399230145201226637251 + 
            114237920231300631313548000*lm) + 
          143*(21340420659223707208174062086923997471*CF - 
            271320*(23*(302134462464421204967365799561 + 1722398490799786800*
                 lm)*NM + 19*(210905189094600*(13037 + 9886*lm)*NL + 
                (906943740972469267 + 2085008699389215600*lm)*NH))))*
         Log[x]^2)/1049451771201417345762000 + 
       (CF*NC*(-178169510009582410366151*CA + 
          190*(1875468526140311864687*CF - 408408*(384591309735172*NM - 
              4943*NL)))*Log[x]^3)/392837445 + 
       (57025011348093949136423593154744587*CF^2*NC*PolyGamma[2, 1])/
        12157665459056928801 - (284945284196472004*CF*NM*NC*PolyGamma[2, 1])/
        243 + (13589510821687725782864*CF*NC*NH*PolyGamma[2, 1])/
        12157665459056928801 + CA*CF*NC*(860865111486967565911470344549909001\
502187076857149164519969490914134273479/
          2336256860383865838753797595427337850929360250388016640000000 - 
         (177283061711218328379421269325907*Pi^2)/1463194151766547200 + 
         (291839319007475381018749055*Pi^3)/(499155919900782652790568*
           Sqrt[3]) + (3958*Pi^4)/1215 + 
         lm*(-3260089878440858779/199526475240892800 - (11*Pi^2)/243) - 
         (414487715043381752344081732842189553*Im[PolyLog[2, (-1)^(1/3)]])/
          (56486006321528262376871686112400*Sqrt[3]) + 
         (2656*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (116735727602990152407499622*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (5392116418681294088787*Sqrt[3]) + (58367863801495076203749811*Pi*
           Log[3]^2)/(129410794048351058130888*Sqrt[3]) - 
         (57025011348093949136423593154744587*PolyGamma[2, 1])/
          24315330918113857602 - (350921763131243797855618729555534547316803*
           Zeta[3])/78617057384373267814514460) + 
       (350921763131237687563214244099886074776273*CF^2*NC*Zeta[3])/
        39308528692186633907257230 - (560660376956494040*CF*NM*NC*Zeta[3])/
        243 - (118640*CF*NC*NL*Zeta[3])/81 + 
       (213577346568930343960240*CF*NC*NH*Zeta[3])/12157665459056928801 + 
       CF*Log[x]*((-79176273641626687506806163010637693454434633*NM*NC)/
          785428070973136766371831635000 - (45160094201*lm*NM*NC)/
          785674890 - (65504208309383539079*NC*NL)/28878831942760800 - 
         (45160094201*lm*NC*NL)/785674890 - 
         (1125267001688934126295258129053151082658639810619*NC*NH)/
          30612275871327040279004152353987087948030000 - 
         (45160094201*lm*NC*NH)/785674890 - (170929470989036*NM*NC*Pi^2)/
          9 - (19772*NC*NL*Pi^2)/81 + (3124160123012310307952*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(50031545098999707*Sqrt[3]) + 
         CF*NC*
          (1008371031925363453572813883870096710097316757605219191100769463/
            1156774623409212288576006960005629479809601600000 + 
           (356339020013202087934601*Pi^2)/1571349780 + 
           (233471455205980304814999244*Im[PolyLog[2, (-1)^(1/3)]])/
            (16176349256043882266361*Sqrt[3]) - 960*Zeta[3]) + 
         CA*NC*
          (-1008371031925158352251153854365287774382877578731083826318215263/
            2313549246818424577152013920011258959619203200000 + 
           (45160094201*lm)/142849980 - (118779673337749414097617*Pi^2)/
            1047566520 - (116735727602990152407499622*
             Im[PolyLog[2, (-1)^(1/3)]])/(16176349256043882266361*Sqrt[3]) + 
           480*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["a", 2, 0, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-(CA*(-2992 + 4336*lm + 792*lm^2 + 921*Zeta[3])) + 
         2*(-42*NL + 224*lm*NL + 72*lm^2*NL - 264*NH + 224*lm*NH + 
           72*lm^2*NH + CF*(2798 + 972*lm - 1383*Zeta[3]) + 
           NM*(-264 + 224*lm + 72*lm^2 - 63*Zeta[3]) - 63*NH*Zeta[3])))/
       5184, -(CF*NC*(1944*CF - 16*CA*(271 + 99*lm) + 1834*NM + 288*lm*NM + 
          448*NL + 288*lm*NL - 938*NH + 288*lm*NH - 819*NM*Zeta[3] + 
          819*NH*Zeta[3]))/5184, (CF*NC*(163154*NM - 24960*lm*NM + 
         172416*NL - 24960*lm*NL - 435598*NH - 24960*lm*NH + 
         48*CA*(231709 + 2860*lm - 207990*Zeta[3]) + 95445*NM*Zeta[3] + 
         449253*NH*Zeta[3] - 288*CF*(-208631 + 174894*Zeta[3])))/2239488, 
      (CF*NC*(45142*NM + 45696*lm*NM - 52992*NL + 45696*lm*NL + 
         466150*NH + 45696*lm*NH - 48*CA*(248201 + 5236*lm - 
           207990*Zeta[3]) - 115857*NM*Zeta[3] - 428841*NH*Zeta[3] + 
         288*CF*(-208145 + 174894*Zeta[3])))/2239488, 
      -(CF*NC*(CA*(-97251775922 - 780299520*lm + 80226585675*Zeta[3]) + 
          2*(8*(48*(30063 + 184730*lm)*NL + 5*NH*(19196890 + 1773408*lm - 
                16702875*Zeta[3]) + 10*NM*(2332970 + 886704*lm - 
                1951425*Zeta[3])) + 15*CF*(-33018695314 + 27512038395*Zeta[
                3]))))/7838208000, (CF*NC*(886625110*NM + 218588160*lm*NM + 
         207740416*NL + 218588160*lm*NL + 2659322250*NH + 
         218588160*lm*NH - 12*CA*(25334775494 + 100186240*lm - 
           20918475225*Zeta[3]) - 523742625*NM*Zeta[3] - 
         2257203375*NH*Zeta[3] + 120*CF*(-29523492274 + 
           24573819195*Zeta[3])))/15676416000, 
      -(CF*NC*(1470555545634*NM + 248928583680*lm*NM + 389020196864*NL + 
          248928583680*lm*NL + 3438970766434*NH + 248928583680*lm*NH - 
          20*CA*(36623705448866 + 68455360512*lm - 30321589155795*Zeta[3]) - 
          793458169875*NM*Zeta[3] - 2883739957875*NH*Zeta[3] + 
          56*CF*(-197137749008378 + 164020547503575*Zeta[3])))/
       24580620288000, (CF*NC*(755663349448*NM + 86606929920*lm*NM + 
         184418062336*NL + 86606929920*lm*NL + 1368492601854*NH + 
         86606929920*lm*NH - 10*CA*(53647804428230 + 47633811456*lm - 
           44503991626185*Zeta[3]) - 420241027500*NM*Zeta[3] - 
         1139553316125*NH*Zeta[3] + 84*CF*(-116428892433178 + 
           96859256509575*Zeta[3])))/12290310144000, 
      -(CF*NC*(CA*(-18017963679061517966 - 7537750843392000*lm + 
            14965278256792891125*Zeta[3]) + 
          2*(5*(1638400*(228896141 + 83648691*lm)*NL + 63*NH*(
                39951005160794 + 2175397068800*lm - 33108851766375*Zeta[3]) + 
              63*NM*(29425953216002 + 2175397068800*lm - 17675242459875*
                 Zeta[3])) + 9*CF*(-21698735585807410786 + 
              18051075507071509875*Zeta[3]))))/292017769021440000, 
      (CF*NC*(5*(524288*(575190409 + 165334050*lm)*NL + 
           63*NH*(30247453919186 + 1375915212800*lm - 24975420190875*
              Zeta[3]) + 63*NM*(31078507105662 + 1375915212800*lm - 
             20340569836125*Zeta[3])) - 2*CA*(6183412514848078766 + 
           1191886553088000*lm - 5139467196031657125*Zeta[3]) + 
         36*CF*(-8703897663303447106 + 7240714779875479875*Zeta[3])))/
       146008884510720000, 
      -(CF*NC*(5*(458752*(6356686342363 + 1406204286300*lm)*NL + 
            99*NM*(270664696998673802 + 6516151805542400*lm - 
              191054089462611375*Zeta[3]) + 495*NH*(36032074526549266 + 
              1303230361108480*lm - 29664124866250875*Zeta[3])) - 
          11*CA*(18949379961850144947694 + 1612747571871744000*lm - 
            15756539971776560389125*Zeta[3]) + 
          22*CF*(-276815049608240164930066 + 230281468807580730106875*
             Zeta[3])))/1837375802682900480000, 
      (CF*NC*(29915711483381164518*NM + 344962829848412160*lm*NM + 
         2160189843670630400*NL + 344962829848412160*lm*NL + 
         13089595463788094262*NH + 344962829848412160*lm*NH - 
         77*CA*(710149456342973655634 + 24640202132029440*lm - 
           590626853444486749275*Zeta[3]) - 22377870405455189625*NM*
          Zeta[3] - 10750642718775584625*NH*Zeta[3] + 
         22*CF*(-82806986596815075268546 + 68887129818574967667075*Zeta[3])))/
       367475160536580096000, 
      -(CF*NC*(-13*CA*(39447030669596335539266602 + 468644813069510246400*
             lm - 32811867128254565514153375*Zeta[3]) + 
          2*(35*(5*(1048576*(30750991842073 + 3018259107864*lm)*NL + 
                1287*NH*(153788277670943718 + 2459109605507072*lm - 
                  126070995352527225*Zeta[3])) + 429*NM*(
                8234363889106067834 + 36886644082606080*lm - 
                6413751020786484375*Zeta[3])) + 
            13*CF*(-742326103790985947362319318 + 617543059932501164098646625*
               Zeta[3]))))/2675219168706303098880000, 
      (CF*NC*(-13*CA*(25011482024733326690419118 + 53711465294462976000*lm - 
           20805808711065289364809125*Zeta[3]) + 
         2*(35*(6553600*(8573692655105 + 276738570108*lm)*NL + 
             429*NM*(4696633944057202402 + 4227584832307200*lm - 
               3755701130960653875*Zeta[3]) + 1287*NH*(277966952004864782 + 
               1409194944102400*lm - 227544291060211125*Zeta[3])) + 
           13*CF*(-527489030968046897410670162 + 438820490186355836185270875*
              Zeta[3]))))/1337609584353151549440000, 
      -(CF*NC*(4*CA*(-5751763650572442861998522170114 + 
            8948630460955770224640000*lm + 4784772376745656172083511179875*
             Zeta[3]) + 5*(120*CF*(-1800141774731437698341573647418 + 
              1497548103799474089266171523255*Zeta[3]) - 
            7*(201326592*(-21390484715131109 + 923601627448500*lm)*NL + 
              715*NH*(-40859587888546732656494 + 260063731496307916800*lm + 
                33413530078117177913925*Zeta[3]) + 143*NM*(
                -1802776469841063555239206 + 1300318657481539584000*lm + 
                1465266773199548663969625*Zeta[3])))))/
       75676599844363902061117440000, 
      (CF*NC*(3388*CF*(-31122122383062098156374139234 + 
           25890691399148824720305253875*Zeta[3]) + 
         2*CA*(-1015124476321469497027458010306 + 2646530185128252014592000*
            lm + 844476103176714071866399471875*Zeta[3]) - 
         5*(1001*NM*(-142070435195197993598462 + 192282639914867097600*lm + 
             116601491897561213668125*Zeta[3]) + 
           4*(8388608*(-42153208815430579 + 5736199693524300*lm)*NL + 
             715*NH*(-3693241617912631308238 + 67298923970203484160*lm + 
               3018159312193139239125*Zeta[3])))))/
       5405471417454564432936960000, 
      -(CF*NC*(CA*(-4577144985217408740870623941727932478 + 
            11828352869309020075743353241600*lm + 
            3807734786846096708639170339681600125*Zeta[3]) + 
          2*(17*CF*(-7693504504838173727336493462059865506 + 
              6400278556807632284073726039670945875*Zeta[3]) - 
            210*(3221225472*(-6107373448431822962 + 1589612128095997005*lm)*
               NL + 2431*NH*(-69376245149479722267691306 + 
                2106334462206068454850560*lm + 56672752382677571895129375*
                 Zeta[3]) + 2431*NM*(2106334462206068454850560*lm + 
                17*(-79534975002466455152771054 + 65647589067324794490085125*
                   Zeta[3]))))))/9972965033889652469222300712960000, 
      (CF*NC*(8*CA*(-692272751990806019229495077957223134 + 
           1520596888891977819020171673600*lm + 
           575905464019438168376965678058710125*Zeta[3]) + 
         272*CF*(-1274336166209828555041809467663314178 + 
           1060129214171990921778560880340075875*Zeta[3]) - 
         105*(17179869184*(-2759782951804832977 + 1226117930316158880*lm)*
            NL + 2431*NM*(-5201384843872733278002226754 + 
             8664971471406185651896320*lm + 4307010043829276812713559875*
              Zeta[3]) + 2431*NH*(8664971471406185651896320*lm + 
             2431*(-83685878753324097445826 + 68350128846116225983875*
                Zeta[3])))))/9972965033889652469222300712960000, 
      -(CF*NC*(16*CA*(-799193443555735610636555667375110075662 + 
            1393314629035984572735251546112000*lm + 
            664854747709004531633824123968159571125*Zeta[3]) + 
          608*CF*(-1435411925706560618750087135655164304262 + 
            1194129479119241104436631475842980603625*Zeta[3]) - 
          385*(42949672960*(-322655677182137619329 + 245124036375575633640*
               lm)*NL + 205751*NH*(-935559212108876897594151346 + 
              51168631972462428841574400*lm + 764096365815621712103104875*
               Zeta[3]) + 4199*NM*(2507262966650659013237145600*lm + 
              5491*(-225908920283927713429120582 + 
                187383231808307048864975625*Zeta[3])))))/
       19201282011915544220742669639352320000, 
      (CF*NC*(16*CA*(-950663786222003441745223526832791656774 + 
           1270897492733894565002306440396800*lm + 
           790864702350696667916703133135297439625*Zeta[3]) + 
         608*CF*(-1854818433183925103557670732844389931422 + 
           1543036917367664268127028600851562986125*Zeta[3]) - 
         35*(230945*NM*(-80904725266179144658387123594 + 
             457394783853744072758919168*lm + 67095097174610249496440864175*
              Zeta[3]) + 7*(8589934592*(-1206503344316206320437 + 
               1756757736557012372040*lm)*NL + 46189*NH*
              (326710559895531480542085120*lm + 4199*
                (-1171296446879529231277138 + 956694491011720120534875*
                  Zeta[3]))))))/19201282011915544220742669639352320000, 
      -(CF*NC*(380*CA*(-143488945793525631704190489407542715753026 + 
            144565978491303649774131677673553920*lm + 
            119369620768756136453230784999582895358275*Zeta[3]) + 
          8*CF*(-547021615320587712403309002961952638930995586 + 
            455071278694566333786643495824293422411171875*Zeta[3]) - 
          1155*(11544872091648*(-168799091993375618309 + 
              749058777277707884130*lm)*NL + 4199*NH*
             (2059487442914356941085747445760*lm + 4199*(
                -6322363893456520441287598298 + 5164557211226664844151934375*
                 Zeta[3])) + 4199*NM*(2059487442914356941085747445760*lm - 
              247*(-5228676462240746694277890360902 + 
                4349017428585376324948713167625*Zeta[3])))))/
       58295092188175592254174745025073643520000, 
      (CF*NC*(38*CA*(-420679877509428350244099020426654596726786 + 
           317038728333812382691958162718720000*lm + 
           349967019702244164386850117491236652347875*Zeta[3]) + 
         7*(4*CF*(-49445472320316691828197104093426348569245398 + 
             41134051083161471209719691692880712231078625*Zeta[3]) - 
           165*(755914244096*(332278846759342029997 + 2508873193163305741500*
                lm)*NL + 16796*NM*(275591401896782690024028188248102 + 
               112913371239745061602197504000*lm - 
               229208316154264808536148542193625*Zeta[3]) + 
             4199*NH*(451653484958980246408790016000*lm + 4199*
                (-1222807213871565942832841422 + 998985924674075846902519125*
                  Zeta[3]))))))/14573773047043898063543686256268410880000, 
      -(CF*NC*(12*CA*(-17519791326579665184035651697827660619989447074 + 
            9862331411881126102706757189966495744000*lm + 
            14574855991506516693719625942346509251303137875*Zeta[3]) + 
          552*CF*(-35491316841683189428338427370094255774752477522 + 
            29525487363178447214956304530316625602866054875*Zeta[3]) - 
          385*(1649267441664*(14267172387919507142625059 + 
              33888030852362151866801400*lm)*NL + 7429*NM*
             (47024857258351945408695902713822010722 + 
              7523277149940237919044472563302400*lm - 
              39113899835269001800891464580624549875*Zeta[3]) + 
            7429*NH*(7523277149940237919044472563302400*lm + 
              7429*(-10389678315198101181545720997446 + 
                8488689647467838452021216463625*Zeta[3])))))/
       164469886760239404279778347297407772917760000, 
      (CF*NC*(2*CA*(-16607476450937968151066806609057446414479818514 + 
           6999943055267617443381925754563461120000*lm + 
           13815892205011861425256445655558625559759146875*Zeta[3]) + 
         92*CF*(-36103934700896726402947500190073809387358141762 + 
           30035128998272860763120317781313198641589991875*Zeta[3]) - 
         105*(1374389534720*(11650723883498061406223441 + 
             17638541635264005133477800*lm)*NL + 14858*NM*
            (22645473063819151110128606288545784686 + 
             1631594227435041321830949322752000*lm - 
             18837092164090899752450815893915565125*Zeta[3]) + 
           22287*NH*(1087729484956694214553966215168000*lm + 
             7429*(-1380616637958267679539769839994 + 
               1128060716296408363966254132375*Zeta[3])))))/
       22427711830941736947242501904191969034240000}, 0, 24, 1]
 
CbarSeries["a", 2, 1, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(CA*(427680*lm^2 - 238820*Pi^2 + 11664*Pi^4 - 
            2160*lm*(-835 + 44*Pi^2) - 15*(-92141 + 70560*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 62208*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 11760*PolyGamma[2, 1] - 97344*Zeta[3])) + 
          2*(CF*(-349920*lm^2 - 24236*Pi^2 + 2160*Pi^4 + 77760*lm*(-14 + 
                Pi^2) + 15*(-42661 + 70560*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 62208*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                11760*PolyGamma[2, 1] - 43968*Zeta[3])) + 
            60*(NL*(-1221 - 648*lm^2 + 68*Pi^2 + 36*lm*(-53 + 4*Pi^2) - 
                1728*Zeta[3]) + NM*(-1221 - 648*lm^2 + 68*Pi^2 + 
                36*lm*(-53 + 4*Pi^2) + 144*PolyGamma[2, 1] - 1440*Zeta[3]) + 
              3*NH*(-3239 - 216*lm^2 + 12*lm*(-53 + 4*Pi^2) - 6672*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 1112*PolyGamma[2, 1] + 
                14640*Zeta[3])))))/3732480, 
      (CF*NC*(3*CA*(190080*lm^2 - 227020*Pi^2 + 8856*Pi^4 - 
           3840*lm*(-30 + 11*Pi^2) + 5*(-258855 - 402144*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] + 141696*Im[PolyLog[2, (-1)^(1/3)]]^
               2 + 70816*PolyGamma[2, 1] + 615776*Zeta[3])) - 
         2*(-1920*(NL*(-27*lm^2 + 6*lm*(3 + Pi^2) + 8*(24 + Pi^2 - 
                 9*Zeta[3])) + NM*(192 - 27*lm^2 + 8*Pi^2 + 6*lm*
                (3 + Pi^2) + 6*PolyGamma[2, 1] - 60*Zeta[3]) + 
             NH*(5787 - 27*lm^2 + 6*lm*(3 + Pi^2) - 3036*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 506*PolyGamma[2, 1] + 628*
                Zeta[3])) + CF*(466560*lm^2 + 93796*Pi^2 + 8136*Pi^4 - 
             25920*lm*(9 + 4*Pi^2) + 15*(118523 - 402144*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 141696*Im[PolyLog[2, 
                   (-1)^(1/3)]]^2 + 70816*PolyGamma[2, 1] + 497312*
                Zeta[3])))))/3732480, 
      (CF*NC*(CF*(-524880*lm^2 - 176500*Pi^2 + 17292*Pi^4 + 
           2160*lm*(111 + 10*Pi^2) + 15*(-140831 + 416640*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 133056*Im[PolyLog[2, (-1)^(1/3)]]^
               2 - 69016*PolyGamma[2, 1] - 617072*Zeta[3])) + 
         CA*(320760*lm^2 - 72860*Pi^2 - 6726*Pi^4 - 
           60*lm*(-3471 + 220*Pi^2) - 15*(99085 + 208320*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 66528*Im[PolyLog[2, (-1)^(1/3)]]^
               2 - 34508*PolyGamma[2, 1] - 343816*Zeta[3])) + 
         30*(NM*(20583 - 1944*lm^2 - 2188*Pi^2 + 4*lm*(303 + 20*Pi^2) - 
             784*PolyGamma[2, 1] - 2528*Zeta[3]) + 
           NL*(9855 + 1212*lm - 1944*lm^2 - 364*Pi^2 + 80*lm*Pi^2 - 
             960*Zeta[3]) + NH*(321063 + 1212*lm - 1944*lm^2 + 80*lm*Pi^2 - 
             189168*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             29304*PolyGamma[2, 1] + 68208*Zeta[3]))))/933120, 
      -(CF*NC*(3732480*(9*CF*(17 + 6*lm) - CA*(76 + 33*lm) + 
            2*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          7464960*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          CA*(35925120*lm^2 - 18429660*Pi^2 + 3316600*Sqrt[3]*Pi^3 + 
            821664*Pi^4 - 207360*lm*(-435 + 11*Pi^2) + 2558520*Sqrt[3]*Pi*
             Log[3]^2 - 15*(2462967 + 17718144*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 10575360*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              8187264*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              3563296*PolyGamma[2, 1] - 26674592*Zeta[3])) - 
          2160*Log[x]*(2*(-8*(9*NM*(-28 + 99*lm + 18*lm^2 + 18*Pi^2) + 
                9*NL*(188 + 99*lm + 18*lm^2 + 18*Pi^2) + NH*(28374 + 
                  891*lm + 162*lm^2 - 16072*Sqrt[3]*Im[PolyLog[2, 
                     (-1)^(1/3)]])) + CF*(-131469 - 66096*lm - 11664*lm^2 + 
                1194*Pi^2 + 18952*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                31104*Zeta[3])) + CA*(197997 + 96552*lm + 14256*lm^2 + 
              1038*Pi^2 - 18952*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              31104*Zeta[3])) + 4*(CF*(14696640*lm^2 - 2470212*Pi^2 + 
              1658300*Sqrt[3]*Pi^3 + 244944*Pi^4 - 116640*lm*(-177 + 
                8*Pi^2) + 1279260*Sqrt[3]*Pi*Log[3]^2 + 15*(3462003 - 
                8859072*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 5287680*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 + 4093632*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1781648*PolyGamma[2, 
                  1] + 10573792*Zeta[3])) - 
            160*(-(NH*(10206*lm^2 + 70315*Sqrt[3]*Pi^3 - 324*lm*
                  (-39 + 2*Pi^2) + 54243*Sqrt[3]*Pi*Log[3]^2 + 
                 12*(-201960 + 38229*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                   216972*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                   4117*PolyGamma[2, 1] - 77678*Zeta[3]))) + 27*NL*(675 - 
                378*lm^2 - 277*Pi^2 + 12*lm*(-39 + 2*Pi^2) - 2232*Zeta[3]) + 
              27*NM*(-378*lm^2 - 121*Pi^2 + 12*lm*(-39 + 2*Pi^2) + 
                6*(789 - 17*PolyGamma[2, 1] + 242*Zeta[3]))))))/16796160, 
      -(CF*NC*(16796160*(-2*CA*(76 + 33*lm) + CF*(299 + 108*lm) + 
            4*(4*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          67184640*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          2160*Log[x]*(2*(-8*(9*NM*(-713 + 870*lm + 162*lm^2 + 176*Pi^2) + 
                2*(9*NL*(815 + 435*lm + 81*lm^2 + 81*Pi^2) + 
                  NH*(110310 + 3915*lm + 729*lm^2 - 62416*Sqrt[3]*
                     Im[PolyLog[2, (-1)^(1/3)]]))) + CF*(-1429041 - 
                581256*lm - 104976*lm^2 + 3834*Pi^2 + 231656*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 279936*Zeta[3])) + 
            CA*(2034147 + 852336*lm + 128304*lm^2 + 3870*Pi^2 - 
              231656*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 279936*Zeta[3])) - 
          5*CA*(57736800*lm^2 - 6779052*Pi^2 + 8107960*Sqrt[3]*Pi^3 + 
            497016*Pi^4 - 3888*lm*(-35037 + 484*Pi^2) + 6254712*Sqrt[3]*Pi*
             Log[3]^2 + 3*(-83803005 - 164938656*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 86686848*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              100075392*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              33882992*PolyGamma[2, 1] + 270996928*Zeta[3])) + 
          2*(CF*(236196000*lm^2 + 38976876*Pi^2 + 40539800*Sqrt[3]*Pi^3 + 
              1116504*Pi^4 - 699840*lm*(-423 + 11*Pi^2) + 31273560*Sqrt[3]*Pi*
               Log[3]^2 - 15*(6223311 + 164938656*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] - 86686848*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
                100075392*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
                33882992*PolyGamma[2, 1] - 235211776*Zeta[3])) - 
            20*(-(NH*(-330457887 + 1312200*lm^2 + 8738240*Sqrt[3]*Pi^3 - 
                 972*lm*(-1467 + 44*Pi^2) + 109832688*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] + 323564544*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6740928*Sqrt[3]*Pi*
                  Log[3]^2 - 15423936*PolyGamma[2, 1] - 187145472*Zeta[3])) + 
              243*NL*(12293 - 5400*lm^2 - 4772*Pi^2 + 4*lm*(-1467 + 
                  44*Pi^2) - 33216*Zeta[3]) + 81*NM*(228879 - 16200*lm^2 - 
                2828*Pi^2 + 12*lm*(-1467 + 44*Pi^2) - 13128*PolyGamma[2, 1] + 
                68784*Zeta[3])))))/100776960, (7477337*CF^2*NC)/373248 - 
       (163*CF^2*lm*NC)/8 - (51*CF^2*lm^2*NC)/4 + (7127*CF*NM*NC)/216 - 
       (73*CF*lm*NM*NC)/36 - (17*CF*lm^2*NM*NC)/12 + (154*CF*NC*NL)/27 - 
       (73*CF*lm*NC*NL)/36 - (17*CF*lm^2*NC*NL)/12 + 
       (404189651*CF*NC*NH)/729000 - (73*CF*lm*NC*NH)/36 - 
       (17*CF*lm^2*NC*NH)/12 + (5612087*CF^2*NC*Pi^2)/1088640 + 
       (CF^2*lm*NC*Pi^2)/2 - (47*CF*NM*NC*Pi^2)/108 + 
       (CF*lm*NM*NC*Pi^2)/18 - (50*CF*NC*NL*Pi^2)/27 + 
       (CF*lm*NC*NL*Pi^2)/18 + (CF*lm*NC*NH*Pi^2)/18 - 
       (2340835*CF^2*NC*Pi^3)/(209952*Sqrt[3]) - (1573565*CF*NC*NH*Pi^3)/
        (26244*Sqrt[3]) - (2245*CF^2*NC*Pi^4)/5184 + 
       (787147*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(1944*Sqrt[3]) - 
       (104360*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(729*Sqrt[3]) - 
       (1051*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (66881*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(162*Sqrt[3]) - 
       (179836*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (81*Sqrt[3]) - (66881*CF^2*NC*Pi*Log[3]^2)/(7776*Sqrt[3]) - 
       (44959*CF*NC*NH*Pi*Log[3]^2)/(972*Sqrt[3]) - 
       (CF*NC*(10*CF*(5105 + 1944*lm) - 5*CA*(5155 + 2376*lm) + 
          24*(280*NM + 90*lm*NM + 135*NL + 90*lm*NL + 4*NH + 90*lm*NH))*
         Log[x]^2)/180 - 4*CF*NC*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3 - 
       (368717*CF^2*NC*PolyGamma[2, 1])/11664 - 
       (16*CF*NM*NC*PolyGamma[2, 1])/27 + (8668*CF*NC*NH*PolyGamma[2, 1])/
        6561 + (CA*CF*NC*(785220480*lm^2 - 393612372*Pi^2 + 
          187266800*Sqrt[3]*Pi^3 + 26300376*Pi^4 - 1399680*lm*
           (-1517 + 22*Pi^2) + 144462960*Sqrt[3]*Pi*Log[3]^2 - 
          135*(28507709 + 50377408*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            32690304*Im[PolyLog[2, (-1)^(1/3)]]^2 - 51364608*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 11798944*
             PolyGamma[2, 1] - 76658720*Zeta[3])))/100776960 - 
       (1943173*CF^2*NC*Zeta[3])/11664 + (1012*CF*NM*NC*Zeta[3])/27 - 
       (50*CF*NC*NL*Zeta[3])/3 + (1513244*CF*NC*NH*Zeta[3])/6561 + 
       (CF*NC*Log[x]*(2*(4*(-2025*NM*(133 + 218*lm + 36*lm^2 - 2*Pi^2) - 
              4050*NL*(252 + 109*lm + 18*lm^2 + 24*Pi^2) - NH*(15927519 + 
                441450*lm + 72900*lm^2 - 8991800*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) + 25*CF*(-1524099 - 653184*lm - 
              104976*lm^2 + 22779*Pi^2 + 267524*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 279936*Zeta[3])) + 
          25*CA*(940248*lm + 128304*lm^2 + 1053*Pi^2 + 
            4*(568533 - 66881*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              69984*Zeta[3]))))/291600, 
      -(CF*NC*(-16329600*(5*CA*(27851 + 13530*lm) - 
            6*(5*CF*(8683 + 3690*lm) + 6490*NM + 2050*lm*NM + 3100*NL + 
              2050*lm*NL + 108*NH + 2050*lm*NH))*Log[x]^2 + 
          1632960000*(595*CA + 1744*CF - 182*NM - 82*NL)*Log[x]^3 + 
          11340*Log[x]*(2*(8*(150*NM*(169 + 7002*lm + 1215*lm^2 - 
                  600*Pi^2) + 75*NL*(33115 + 14004*lm + 2430*lm^2 + 
                  3270*Pi^2) + NH*(36228357 + 1050300*lm + 182250*lm^2 - 
                  20430400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
              25*CF*(-9255801 - 3112344*lm - 524880*lm^2 + 151350*Pi^2 + 
                1602808*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1399680*
                 Zeta[3])) + 25*CA*(-12722367 - 4513536*lm - 641520*lm^2 + 
              86670*Pi^2 + 1602808*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              1399680*Zeta[3])) - 175*CA*(666860040*lm^2 - 147065706*Pi^2 + 
            210368550*Sqrt[3]*Pi^3 + 16637724*Pi^4 - 160380*lm*
             (-10717 + 100*Pi^2) + 162284310*Sqrt[3]*Pi*Log[3]^2 + 
            5*(-1392223077 - 1370381496*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              768844224*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1557929376*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 310714132*PolyGamma[2, 
                1] + 2402280008*Zeta[3])) + 
          2*(50*CF*(1909644660*lm^2 - 177915123*Pi^2 + 736289925*Sqrt[3]*Pi^
                3 + 50067234*Pi^4 - 918540*lm*(-3059 + 50*Pi^2) + 
              567995085*Sqrt[3]*Pi*Log[3]^2 - 35*(450421893 + 685190748*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 384422112*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 778964688*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 155357066*
                 PolyGamma[2, 1] - 1068240388*Zeta[3])) - 
            7*(-(NH*(-649075063419 + 1515591000*lm^2 + 21451920000*Sqrt[3]*
                  Pi^3 - 9112500*lm*(-217 + 4*Pi^2) + 138352350000*Sqrt[3]*
                  Im[PolyLog[2, (-1)^(1/3)]] + 794333952000*Sqrt[3]*
                  Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 16548624000*Sqrt[3]*
                  Pi*Log[3]^2 - 18772688000*PolyGamma[2, 1] - 364778896000*
                  Zeta[3])) + 10125*NL*(807823 - 149688*lm^2 - 210828*Pi^2 + 
                900*lm*(-217 + 4*Pi^2) - 1926720*Zeta[3]) + 10125*NM*(
                4218679 - 149688*lm^2 + 30420*Pi^2 + 900*lm*(-217 + 4*Pi^2) - 
                114840*PolyGamma[2, 1] + 4703760*Zeta[3])))))/13226976000, 
      (1340742607*CF^2*NC)/5038848 - (2765*CF^2*lm*NC)/54 - 31*CF^2*lm^2*NC + 
       (357959*CF*NM*NC)/1944 - (1243*CF*lm*NM*NC)/243 - 
       (31*CF*lm^2*NM*NC)/9 + (187483*CF*NC*NL)/5832 - 
       (1243*CF*lm*NC*NL)/243 - (31*CF*lm^2*NC*NL)/9 + 
       (14165580976427*CF*NC*NH)/6751269000 - (1243*CF*lm*NC*NH)/243 - 
       (31*CF*lm^2*NC*NH)/9 + (672193*CF^2*NC*Pi^2)/27216 + 
       (8*CF^2*lm*NC*Pi^2)/9 + (569*CF*NM*NC*Pi^2)/81 + 
       (8*CF*lm*NM*NC*Pi^2)/81 - (19*CF*NC*NL*Pi^2)/3 + 
       (8*CF*lm*NC*NL*Pi^2)/81 + (8*CF*lm*NC*NH*Pi^2)/81 - 
       (23400545*CF^2*NC*Pi^3)/(472392*Sqrt[3]) - (28819105*CF*NC*NH*Pi^3)/
        (118098*Sqrt[3]) - (2659*CF^2*NC*Pi^4)/1620 + 
       (23865631*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) - 
       (4360492*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(19683*Sqrt[3]) - 
       (2348*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (1337174*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (729*Sqrt[3]) - (6587224*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(729*Sqrt[3]) - 
       (668587*CF^2*NC*Pi*Log[3]^2)/(17496*Sqrt[3]) - 
       (823403*CF*NC*NH*Pi*Log[3]^2)/(4374*Sqrt[3]) - 
       (CF*NC*(-105*CA*(66775 + 32384*lm) + 8*(35*CF*(49393 + 19872*lm) + 
            70*(1927 + 1104*lm)*NM + 109760*NL + 77280*lm*NL + 7047*NH + 
            77280*lm*NH))*Log[x]^2)/11340 - 
       (2*CF*NC*(10841*CA + 42828*CF - 8712*NM - 1472*NL)*Log[x]^3)/81 - 
       (72553385*CF^2*NC*PolyGamma[2, 1])/708588 + 
       (2903*CF*NM*NC*PolyGamma[2, 1])/162 - 
       (3646175*CF*NC*NH*PolyGamma[2, 1])/354294 + 
       (CA*CF*NC*(7517331360*lm^2 - 5389663212*Pi^2 + 3276076300*Sqrt[3]*
           Pi^3 + 357005880*Pi^4 - 816480*lm*(-25391 + 264*Pi^2) + 
          2527258860*Sqrt[3]*Pi*Log[3]^2 - 35*(2380843791 + 
            2291100576*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            1478901888*Im[PolyLog[2, (-1)^(1/3)]]^2 - 3465955008*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 580427080*
             PolyGamma[2, 1] - 3603412400*Zeta[3])))/396809280 + 
       (CF*NC*Log[x]*(16*(-66150*NM*(13190 + 5154*lm + 810*lm^2 - 
              4977*Pi^2) - 33075*NL*(28603 + 10308*lm + 1620*lm^2 + 
              2748*Pi^2) - 4*NH*(3579483066 + 85234275*lm + 13395375*lm^2 - 
              2017337350*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          1225*CF*(-110157753 - 41127264*lm - 6298560*lm^2 + 2416392*Pi^2 + 
            21394784*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 16796160*Zeta[3]) - 
          1225*CA*(-80470851 - 29390688*lm - 3849120*lm^2 + 496584*Pi^2 + 
            10697392*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 8398080*Zeta[3])))/
        128595600 - (183843983*CF^2*NC*Zeta[3])/354294 + 
       (16547*CF*NM*NC*Zeta[3])/81 - (1864*CF*NC*NL*Zeta[3])/27 + 
       (153170473*CF*NC*NH*Zeta[3])/177147, 
      (91967891621*CF^2*NC)/167961600 - (255851*CF^2*lm*NC)/5184 - 
       (513*CF^2*lm^2*NC)/16 + (4196773849*CF*NM*NC)/17496000 - 
       (228149*CF*lm*NM*NC)/46656 - (57*CF*lm^2*NM*NC)/16 + 
       (7613743*CF*NC*NL)/186624 - (228149*CF*lm*NC*NL)/46656 - 
       (57*CF*lm^2*NC*NL)/16 + (42674595222437*CF*NC*NH)/18003384000 - 
       (228149*CF*lm*NC*NH)/46656 - (57*CF*lm^2*NC*NH)/16 + 
       (36192409*CF^2*NC*Pi^2)/1088640 + (131*CF^2*lm*NC*Pi^2)/216 + 
       (142031*CF*NM*NC*Pi^2)/23328 + (131*CF*lm*NM*NC*Pi^2)/1944 - 
       (158129*CF*NC*NL*Pi^2)/23328 + (131*CF*lm*NC*NL*Pi^2)/1944 + 
       (131*CF*lm*NC*NH*Pi^2)/1944 - (39826465*CF^2*NC*Pi^3)/
        (629856*Sqrt[3]) - (80296895*CF*NC*NH*Pi^3)/(314928*Sqrt[3]) - 
       (4771*CF^2*NC*Pi^4)/3240 + (313468153*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(209952*Sqrt[3]) - 
       (54614827*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(52488*Sqrt[3]) - 
       (2470*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (1137899*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (486*Sqrt[3]) - (2294197*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(243*Sqrt[3]) - 
       (1137899*CF^2*NC*Pi*Log[3]^2)/(23328*Sqrt[3]) - 
       (2294197*CF*NC*NH*Pi*Log[3]^2)/(11664*Sqrt[3]) - 
       (CF*NC*(-105*CA*(711985 + 438196*lm) + 
          2*(35*CF*(1916237 + 1075572*lm) + 28*(395371 + 149385*lm)*NM + 
            6024585*NL + 4182780*lm*NL + 425736*NH + 4182780*lm*NH))*
         Log[x]^2)/136080 - (CF*NC*(181521*CA + 497269*CF - 
          2*(62110*NM + 9959*NL))*Log[x]^3)/486 - 
       (512761793*CF^2*NC*PolyGamma[2, 1])/5668704 + 
       (18527*CF*NM*NC*PolyGamma[2, 1])/972 + 
       (135524341*CF*NC*NH*PolyGamma[2, 1])/2834352 + 
       (CF*NC*Log[x]*(2*(-11041239825*NL - 3854207700*lm*NL - 
            642978000*lm^2*NL - 159669355536*NH - 3854207700*lm*NH - 
            642978000*lm^2*NH - 1092709800*NL*Pi^2 - 
            294*NM*(37973077 + 13109550*lm + 2187000*lm^2 - 15494100*Pi^2) + 
            89932522400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            490*CF*(-247666413 - 72759870*lm - 11809800*lm^2 + 9460890*Pi^2 + 
              45515960*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 31492800*Zeta[
                3])) - 245*CA*(-665148891 - 209787660*lm - 28868400*lm^2 + 
            15943140*Pi^2 + 91031920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            62985600*Zeta[3])))/171460800 - (2346854351*CF^2*NC*Zeta[3])/
        2834352 + (116891*CF*NM*NC*Zeta[3])/486 - (6260*CF*NC*NL*Zeta[3])/
        81 + (1795725613*CF*NC*NH*Zeta[3])/1417176 + 
       (CA*CF*NC*(22214233800*lm^2 - 20625906825*Pi^2 + 11947939500*Sqrt[3]*
           Pi^3 + 895853520*Pi^4 - 12150*lm*(-4836607 + 34584*Pi^2) + 
          9216981900*Sqrt[3]*Pi*Log[3]^2 + 4*(-99562882131 - 
            70530334425*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            38893608000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 110603782800*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 12819044825*
             PolyGamma[2, 1] + 130548260950*Zeta[3])))/1133740800, 
      (87226533345713*CF^2*NC)/90699264000 - (44191*CF^2*lm*NC)/432 - 
       (245*CF^2*lm^2*NC)/4 + (165778861*CF*NM*NC)/388800 - 
       (39781*CF*lm*NM*NC)/3888 - (245*CF*lm^2*NM*NC)/36 + 
       (1388927*CF*NC*NL)/11664 - (39781*CF*lm*NC*NL)/3888 - 
       (245*CF*lm^2*NC*NL)/36 + (146934138513269*CF*NC*NH)/24304568400 - 
       (39781*CF*lm*NC*NH)/3888 - (245*CF*lm^2*NC*NH)/36 + 
       (13074689*CF^2*NC*Pi^2)/108864 + (25*CF^2*lm*NC*Pi^2)/18 + 
       (26471*CF*NM*NC*Pi^2)/162 + (25*CF*lm*NM*NC*Pi^2)/162 - 
       (5195*CF*NC*NL*Pi^2)/324 + (25*CF*lm*NC*NL*Pi^2)/162 + 
       (25*CF*lm*NC*NH*Pi^2)/162 - (10410691655*CF^2*NC*Pi^3)/
        (68024448*Sqrt[3]) - (774023425*CF*NC*NH*Pi^3)/(1062882*Sqrt[3]) - 
       (23005*CF^2*NC*Pi^4)/5184 + (33573293953*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(11337408*Sqrt[3]) - 
       (10576519*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(177147*Sqrt[3]) - 
       (22025*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (297448333*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (52488*Sqrt[3]) - (176919640*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (297448333*CF^2*NC*Pi*Log[3]^2)/(2519424*Sqrt[3]) - 
       (22114955*CF*NC*NH*Pi*Log[3]^2)/(39366*Sqrt[3]) - 
       (CF*NC*(-7*CA*(21790603 + 12392160*lm) + 
          2*(7*CF*(21339223 + 10139040*lm) + 40*(-1560727*NM + 
              197148*lm*NM + 271306*NL + 197148*lm*NL + 26310*NH + 
              197148*lm*NH)))*Log[x]^2)/90720 - 
       (CF*NC*(491703*CA + 1927994*CF - 835704*NM - 56328*NL)*Log[x]^3)/
        486 - (5224442713*CF^2*NC*PolyGamma[2, 1])/25509168 + 
       (24883*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (82498949*CF*NC*NH*PolyGamma[2, 1])/1594323 + 
       (CF*NC*Log[x]*(2*(160*(-11907*NM*(4846327 + 1062300*lm + 
                162000*lm^2 - 3906000*Pi^2) - 4*(59535*NL*(173147 + 
                  53115*lm + 8100*lm^2 + 16782*Pi^2) + NH*(153916586133 + 
                  3162201525*lm + 482233500*lm^2 - 86690623600*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]]))) + 49*CF*(-1140124926981 - 
              381167856000*lm - 56687040000*lm^2 + 51301819800*Pi^2 + 
              237958666400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              151165440000*Zeta[3])) - 49*CA*(-1633592154981 - 
            542504304000*lm - 69284160000*lm^2 + 37367616600*Pi^2 + 
            237958666400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            151165440000*Zeta[3])))/37035532800 - 
       (33449527247*CF^2*NC*Zeta[3])/25509168 + (60836*CF*NM*NC*Zeta[3])/
        81 - (5644*CF*NC*NL*Zeta[3])/27 + (3872379062*CF*NC*NH*Zeta[3])/
        1594323 + (CA*CF*NC*(427760403840000*lm^2 - 684162236808000*Pi^2 + 
          291499366340000*Sqrt[3]*Pi^3 + 26768092680000*Pi^4 - 
          1469664000*lm*(-808031 + 6600*Pi^2) + 224870939748000*Sqrt[3]*Pi*
           Log[3]^2 + 7*(-1073747360121417 - 805759054872000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 499412822400000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 1541972158272000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 167182166816000*
             PolyGamma[2, 1] + 1304497308256000*Zeta[3])))/11428107264000, 
      (536548978547391727*CF^2*NC)/466647713280000 - (4048343*CF^2*lm*NC)/
        43200 - (957*CF^2*lm^2*NC)/16 + (1224886694191*CF*NM*NC)/
        2000376000 - (3617693*CF*lm*NM*NC)/388800 - (319*CF*lm^2*NM*NC)/
        48 + (208846991*CF*NC*NL)/1555200 - (3617693*CF*lm*NC*NL)/388800 - 
       (319*CF*lm^2*NC*NL)/48 + (582995182576189*CF*NC*NH)/91142131500 - 
       (3617693*CF*lm*NC*NH)/388800 - (319*CF*lm^2*NC*NH)/48 + 
       (1769029789*CF^2*NC*Pi^2)/5443200 + (67*CF^2*lm*NC*Pi^2)/72 + 
       (4554491*CF*NM*NC*Pi^2)/38880 + (67*CF*lm*NM*NC*Pi^2)/648 - 
       (68453*CF*NC*NL*Pi^2)/4320 + (67*CF*lm*NC*NL*Pi^2)/648 + 
       (67*CF*lm*NC*NH*Pi^2)/648 - (36105988499*CF^2*NC*Pi^3)/
        (204073344*Sqrt[3]) - (18312195965*CF*NC*NH*Pi^3)/
        (25509168*Sqrt[3]) - (60541*CF^2*NC*Pi^4)/15552 + 
       (2921143064983*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (850305600*Sqrt[3]) - (8350760057*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4251528*Sqrt[3]) - 
       (21667*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (5157998357*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (787320*Sqrt[3]) - (523205599*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (5157998357*CF^2*NC*Pi*Log[3]^2)/(37791360*Sqrt[3]) - 
       (523205599*CF*NC*NH*Pi*Log[3]^2)/(944784*Sqrt[3]) - 
       (CF*NC*(-11*CA*(17011523 + 61582500*lm) + 
          CF*(120948377 + 1108485000*lm) + 30*(60*(-273888 + 68425*lm)*NM + 
            5746685*NL + 4105500*lm*NL + 589584*NH + 4105500*lm*NH))*
         Log[x]^2)/680400 - (CF*NC*(3885749*CA + 7052505*CF - 4219020*NM - 
          293250*NL)*Log[x]^3)/2430 + (26226492271*CF^2*NC*PolyGamma[2, 1])/
        153055008 + (31465*CF*NM*NC*PolyGamma[2, 1])/108 + 
       (7384843183*CF*NC*NH*PolyGamma[2, 1])/76527504 - 
       (167287242823*CF^2*NC*Zeta[3])/95659380 + (43645*CF*NM*NC*Zeta[3])/
        54 - (5866*CF*NC*NL*Zeta[3])/27 + (124567819879*CF*NC*NH*Zeta[3])/
        38263752 + (CA*CF*NC*(-1233646368316107129 + 61405005971232000*lm^2 - 
          275234118505375680*Pi^2 + 49537416220628000*Sqrt[3]*Pi^3 + 
          3408785931297600*Pi^4 - 1592219280960*lm*(-103079 + 600*Pi^2) - 
          961873988437602240*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          505542800181888000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          1834299754912396800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          38214578227341600*Sqrt[3]*Pi*Log[3]^2 - 143930989583248000*
           PolyGamma[2, 1] + 1642451736399846400*Zeta[3]))/1679931767808000 - 
       (CF*NC*Log[x]*(-80*(-1458*NM*(4724400217 + 512325870*lm + 
              83349000*lm^2 - 1989189300*Pi^2) - 535815*NL*
             (4698613 + 1394084*lm + 226800*lm^2 + 466600*Pi^2) - 
            4*NH*(9105815611623 + 186742779615*lm + 30380710500*lm^2 - 
              5127414870200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          CA*(-1238861917727403 - 396720083642400*lm - 53470050480000*lm^2 + 
            103209964111800*Pi^2 + 202193535594400*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 116661928320000*Zeta[3]) + 
          CF*(1812533543995602 + 552401946331200*lm + 87496446240000*lm^2 - 
            218707666455600*Pi^2 - 404387071188800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 233323856640000*Zeta[3])))/
        555532992000, (54803164854690599*CF^2*NC)/38887309440000 - 
       (26777*CF^2*lm*NC)/150 - (213*CF^2*lm^2*NC)/2 - 
       (949050133*CF*NM*NC)/370440 - (48229*CF*lm*NM*NC)/2700 - 
       (71*CF*lm^2*NM*NC)/6 + (10924411*CF*NC*NL)/32400 - 
       (48229*CF*lm*NC*NL)/2700 - (71*CF*lm^2*NC*NL)/6 + 
       (14120594893414541293*CF*NC*NH)/970481416212000 - 
       (48229*CF*lm*NC*NH)/2700 - (71*CF*lm^2*NC*NH)/6 + 
       (652322227*CF^2*NC*Pi^2)/907200 + 2*CF^2*lm*NC*Pi^2 + 
       (332317*CF*NM*NC*Pi^2)/180 + (2*CF*lm*NM*NC*Pi^2)/9 - 
       (18317*CF*NC*NL*Pi^2)/540 + (2*CF*lm*NC*NL*Pi^2)/9 + 
       (2*CF*lm*NC*NH*Pi^2)/9 - (2154649427*CF^2*NC*Pi^3)/
        (5668704*Sqrt[3]) - (11412442685*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) - 
       (31811*CF^2*NC*Pi^4)/3240 + (223723307371*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(35429400*Sqrt[3]) + 
       (454474739*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) - 
       (3698*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (307807061*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (21870*Sqrt[3]) - (1304279164*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (307807061*CF^2*NC*Pi*Log[3]^2)/(1049760*Sqrt[3]) - 
       (326069791*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) - 
       (CF*NC*(-11*CA*(806520611 + 1111017600*lm) + 
          20*(11*CF*(75429289 + 90901440*lm) + 
            72*(132*(-543517 + 11690*lm)*NM + 2310*(901 + 668*lm)*NL + 
              (262327 + 1543080*lm)*NH)))*Log[x]^2)/4989600 - 
       (CF*NC*(2899777*CA + 8541668*CF - 1440*(6417*NM + 167*NL))*Log[x]^3)/
        810 + (9462562151*CF^2*NC*PolyGamma[2, 1])/38263752 + 
       (89800*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (164529833*CF*NC*NH*PolyGamma[2, 1])/1062882 - 
       (117349919893*CF^2*NC*Zeta[3])/47829690 + (99554*CF*NM*NC*Zeta[3])/
        27 - 518*CF*NC*NL*Zeta[3] + (3022462795*CF*NC*NH*Zeta[3])/531441 + 
       CA*CF*NC*(-166301784077084839/155549237760000 + (781*lm^2)/12 - 
         (3868289507*Pi^2)/10886400 + (2154649427*Pi^3)/(11337408*Sqrt[3]) + 
         (32963*Pi^4)/6480 + lm*(977819/5400 - (11*Pi^2)/9) - 
         (223723307371*Im[PolyLog[2, (-1)^(1/3)]])/(70858800*Sqrt[3]) + 
         (1849*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (307807061*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(43740*Sqrt[3]) + 
         (307807061*Pi*Log[3]^2)/(2099520*Sqrt[3]) - 
         (9462562151*PolyGamma[2, 1])/76527504 + (293942225261*Zeta[3])/
          191318760) + CF*Log[x]*((227592373*NM*NC)/264600 - 
         (21077*lm*NM*NC)/90 - 35*lm^2*NM*NC - (950237*NC*NL)/1080 - 
         (21077*lm*NC*NL)/90 - 35*lm^2*NC*NL - (915374536857523*NC*NH)/
          70020304200 - (21077*lm*NC*NH)/90 - 35*lm^2*NC*NH + 
         (25259*NM*NC*Pi^2)/9 - (773*NC*NL*Pi^2)/9 + 
         (1304279164*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(59049*Sqrt[3]) + 
         CF*NC*(-16777886132183/2571912000 - (10801*lm)/5 - 315*lm^2 + 
           (293921*Pi^2)/360 + (307807061*Im[PolyLog[2, (-1)^(1/3)]])/
            (65610*Sqrt[3]) - 840*Zeta[3]) + 
         CA*NC*(48497219600167/10287648000 + (275947*lm)/180 + (385*lm^2)/2 - 
           (1184227*Pi^2)/3240 - (307807061*Im[PolyLog[2, (-1)^(1/3)]])/
            (131220*Sqrt[3]) + 420*Zeta[3])), 
      (-5999694031750213147*CF^2*NC)/2099914709760000 - 
       (1363523*CF^2*lm*NC)/8640 - (1599*CF^2*lm^2*NC)/16 - 
       (124696999035079*CF*NM*NC)/108020304000 - (1219613*CF*lm*NM*NC)/
        77760 - (533*CF*lm^2*NM*NC)/48 + (1637765129*CF*NC*NL)/4665600 - 
       (1219613*CF*lm*NC*NL)/77760 - (533*CF*lm^2*NC*NL)/48 + 
       (102471844507921035527*CF*NC*NH)/6987466196726400 - 
       (1219613*CF*lm*NC*NH)/77760 - (533*CF*lm^2*NC*NH)/48 + 
       (94146054329*CF^2*NC*Pi^2)/32659200 + (95*CF^2*lm*NC*Pi^2)/72 + 
       (8863727*CF*NM*NC*Pi^2)/7776 + (95*CF*lm*NM*NC*Pi^2)/648 - 
       (246865*CF*NC*NL*Pi^2)/7776 + (95*CF*lm*NC*NL*Pi^2)/648 + 
       (95*CF*lm*NC*NH*Pi^2)/648 - (754401002621*CF^2*NC*Pi^3)/
        (1836660096*Sqrt[3]) - (388045492625*CF*NC*NH*Pi^3)/
        (229582512*Sqrt[3]) - (652769*CF^2*NC*Pi^4)/77760 + 
       (53635840311967*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (7652750400*Sqrt[3]) - (118524259553*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(38263752*Sqrt[3]) - 
       (41587*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (107771571803*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7085880*Sqrt[3]) - (11087014075*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (107771571803*CF^2*NC*Pi*Log[3]^2)/(340122240*Sqrt[3]) - 
       (11087014075*CF*NC*NH*Pi*Log[3]^2)/(8503056*Sqrt[3]) - 
       (CF*NC*(-99*CA*(-3596470057 + 727958000*lm) + 
          2*(11*CF*(-33697376443 + 5360418000*lm) + 
            20*(22*(-412211981 + 14890050*lm)*NM + 5*(693*(129897 + 
                  94540*lm)*NL + 2*(5858561 + 32758110*lm)*NH))))*Log[x]^2)/
        29937600 - (CF*NC*(38487621*CA + 5174288*CF - 
          60*(770438*NM + 23635*NL))*Log[x]^3)/4860 + 
       (5968802159057*CF^2*NC*PolyGamma[2, 1])/1377495072 + 
       (139613*CF*NM*NC*PolyGamma[2, 1])/48 + 
       (59610141349*CF*NC*NH*PolyGamma[2, 1])/344373768 - 
       (10796942105*CF^2*NC*Zeta[3])/344373768 + (93517*CF*NM*NC*Zeta[3])/
        24 - (4585*CF*NC*NL*Zeta[3])/9 + (1230895476529*CF*NC*NH*Zeta[3])/
        172186884 + CF*Log[x]*((-100253922337*NM*NC)/21432600 - 
         (141857*lm*NM*NC)/648 - 35*lm^2*NM*NC - (11008019*NC*NL)/12960 - 
         (141857*lm*NC*NL)/648 - 35*lm^2*NC*NL - (3112511535385489*NC*NH)/
          252073095120 - (141857*lm*NC*NH)/648 - 35*lm^2*NC*NH + 
         (766723*NM*NC*Pi^2)/324 - (27415*NC*NL*Pi^2)/324 + 
         (11087014075*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(75146066175721/208324872000 - (145637*lm)/72 - 315*lm^2 + 
           (22985771*Pi^2)/7776 + (107771571803*Im[PolyLog[2, (-1)^(1/3)]])/
            (21257640*Sqrt[3]) - 840*Zeta[3]) + 
         CA*NC*(890329241086813/833299488000 + (1877947*lm)/1296 + 
           (385*lm^2)/2 - (2511631*Pi^2)/1728 - 
           (107771571803*Im[PolyLog[2, (-1)^(1/3)]])/(42515280*Sqrt[3]) + 
           420*Zeta[3])) + (CA*CF*NC*(288557811171630000*lm^2 - 
          6809741514086919975*Pi^2 + 323449429873753750*Sqrt[3]*Pi^3 + 
          20385730171894500*Pi^4 - 30380710500*lm*(-25504183 + 125400*Pi^2) + 
          249518131616895750*Sqrt[3]*Pi*Log[3]^2 + 
          4*(1333521063112971339 - 1379781992025351075*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 682259008084290000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 2994217579402749000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 2559123925695688750*
             PolyGamma[2, 1] + 261957388946575000*Zeta[3])))/
        4724808096960000, (-99958111568964839459*CF^2*NC)/12599488258560000 - 
       (3074951*CF^2*lm*NC)/10800 - (679*CF^2*lm^2*NC)/4 - 
       (12734213214043*CF*NM*NC)/300056400 - (2769401*CF*lm*NM*NC)/97200 - 
       (679*CF*lm^2*NM*NC)/36 + (43105349*CF*NC*NL)/54000 - 
       (2769401*CF*lm*NC*NL)/97200 - (679*CF*lm^2*NC*NL)/36 + 
       (709726659498697718536051*CF*NC*NH)/23027194851311851200 - 
       (2769401*CF*lm*NC*NH)/97200 - (679*CF*lm^2*NC*NH)/36 + 
       (538313745083*CF^2*NC*Pi^2)/107775360 + (49*CF^2*lm*NC*Pi^2)/18 + 
       (27334921*CF*NM*NC*Pi^2)/1620 + (49*CF*lm*NM*NC*Pi^2)/162 - 
       (309197*CF*NC*NL*Pi^2)/4860 + (49*CF*lm*NC*NL*Pi^2)/162 + 
       (49*CF*lm*NC*NH*Pi^2)/162 - (4492406193695*CF^2*NC*Pi^3)/
        (5509980288*Sqrt[3]) - (662008389875*CF*NC*NH*Pi^3)/
        (172186884*Sqrt[3]) - (164339*CF^2*NC*Pi^4)/8640 + 
       (56043064642121*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (4591650240*Sqrt[3]) + (247992799306*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) - 
       (80465*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (128354462677*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4251528*Sqrt[3]) - (75658101700*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (128354462677*CF^2*NC*Pi*Log[3]^2)/(204073344*Sqrt[3]) - 
       (18914525425*CF*NC*NH*Pi*Log[3]^2)/(6377292*Sqrt[3]) - 
       (CF*NC*(-1573*CA*(-2055262717 + 668556000*lm) + 
          48*(143*CF*(-959417371 + 250708500*lm) + 
            5*(1716*(-94236337 + 464275*lm)*NM + 70070*(15127 + 11370*lm)*
               NL + (160405811 + 796695900*lm)*NH)))*Log[x]^2)/194594400 - 
       (CF*NC*(18235392*CA + 17368133*CF - 94300380*NM - 795900*NL)*
         Log[x]^3)/1215 + (14798317537453*CF^2*NC*PolyGamma[2, 1])/
        2066242608 + (1719193*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (94908930977*CF*NC*NH*PolyGamma[2, 1])/258280326 + 
       (12087510289501*CF^2*NC*Zeta[3])/10331213040 + 
       (842113*CF*NM*NC*Zeta[3])/27 - (10052*CF*NC*NL*Zeta[3])/9 + 
       (1515695295499*CF*NC*NH*Zeta[3])/129140163 + 
       (CA*CF*NC*(742349700236879719389 + 23526394450796160000*lm^2 - 
          563606289974158704000*Pi^2 + 30817906488747700000*Sqrt[3]*Pi^3 + 
          2211739542877032000*Pi^4 - 1166619283200*lm*(-56129611 + 
            323400*Pi^2) - 461346508133940072000*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 253454455681257600000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 1141143051697629120000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 23773813577033940000*
           Sqrt[3]*Pi*Log[3]^2 - 812131666455420640000*PolyGamma[2, 1] + 
          5297483266228384000*Zeta[3]))/226790788654080000 + 
       CF*Log[x]*((18294496403*NM*NC)/476280 - (119749*lm*NM*NC)/270 - 
         (196*lm^2*NM*NC)/3 - (3827497*NC*NL)/2025 - (119749*lm*NC*NL)/
          270 - (196*lm^2*NC*NL)/3 - (4485824216277290897*NC*NH)/
          159751324032300 - (119749*lm*NC*NH)/270 - (196*lm^2*NC*NH)/3 + 
         (522449*NM*NC*Pi^2)/27 - (15029*NC*NL*Pi^2)/81 + 
         (75658101700*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(-15694687763488121/2499898464000 - (122689*lm)/30 - 
           588*lm^2 + (206843209*Pi^2)/38880 + 
           (128354462677*Im[PolyLog[2, (-1)^(1/3)]])/(12754584*Sqrt[3]) - 
           1568*Zeta[3]) + CA*NC*(5984598327750919/999959385600 + 
           (1564199*lm)/540 + (1078*lm^2)/3 - (200005909*Pi^2)/77760 - 
           (128354462677*Im[PolyLog[2, (-1)^(1/3)]])/(25509168*Sqrt[3]) + 
           784*Zeta[3])), (-7013797359580211947235063*CF^2*NC)/
        117389432105003520000 - (1556865523*CF^2*lm*NC)/6350400 - 
       (2475*CF^2*lm^2*NC)/16 - (10548789116362584971*CF*NM*NC)/
        431325073872000 - (1393144273*CF*lm*NM*NC)/57153600 - 
       (275*CF*lm^2*NM*NC)/16 + (2690994500669*CF*NC*NL)/3429216000 - 
       (1393144273*CF*lm*NC*NL)/57153600 - (275*CF*lm^2*NC*NL)/16 + 
       (125295475069515359989889*CF*NC*NH)/4186762700238518400 - 
       (1393144273*CF*lm*NC*NH)/57153600 - (275*CF*lm^2*NC*NH)/16 + 
       (21675689988847*CF^2*NC*Pi^2)/838252800 + (383*CF^2*lm*NC*Pi^2)/216 + 
       (1339103873*CF*NM*NC*Pi^2)/163296 + (383*CF*lm*NM*NC*Pi^2)/1944 - 
       (15575017*CF*NC*NL*Pi^2)/272160 + (383*CF*lm*NC*NL*Pi^2)/1944 + 
       (383*CF*lm*NC*NH*Pi^2)/1944 - (2311693237703*CF^2*NC*Pi^3)/
        (2754990144*Sqrt[3]) - (2420553981265*CF*NC*NH*Pi^3)/
        (688747536*Sqrt[3]) - (309097*CF^2*NC*Pi^4)/19440 + 
       (7361263771636039*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (562477154400*Sqrt[3]) - (2351434665077*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(573956280*Sqrt[3]) - 
       2019*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (2311693237703*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (74401740*Sqrt[3]) - (69158685179*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (2311693237703*CF^2*NC*Pi*Log[3]^2)/(3571283520*Sqrt[3]) - 
       (69158685179*CF*NC*NH*Pi*Log[3]^2)/(25509168*Sqrt[3]) - 
       (CF*NC*(-117*CA*(-10038976629923 + 355215876400*lm) + 
          2*(39*CF*(-30346416972077 + 871893514800*lm) + 
            140*(130*(-21399169283 + 207593694*lm)*NM + 
              77*(4095*(116083 + 85588*lm)*NL + 2*(36571879 + 175241430*lm)*
                 NH))))*Log[x]^2)/8172964800 + 
       (CF*NC*(-1804350437*CA + 28*(79964811*CF + 60383410*NM + 748895*NL))*
         Log[x]^3)/34020 + (192608255582081*CF^2*NC*PolyGamma[2, 1])/
        4132485216 + (34140079*CF*NM*NC*PolyGamma[2, 1])/1296 + 
       (294580521055*CF*NC*NH*PolyGamma[2, 1])/1033121304 + 
       CA*CF*NC*(6890228582185931580399167/234778864210007040000 + 
         (3025*lm^2)/32 - (17730183287813*Pi^2)/1371686400 + 
         (2311693237703*Pi^3)/(5509980288*Sqrt[3]) + (2335*Pi^4)/288 + 
         lm*(29077172003/114307200 - (4213*Pi^2)/3888) - 
         (7361263771636039*Im[PolyLog[2, (-1)^(1/3)]])/(1124954308800*
           Sqrt[3]) + (2019*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 + 
         (2311693237703*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (148803480*Sqrt[3]) + (2311693237703*Pi*Log[3]^2)/
          (7142567040*Sqrt[3]) - (192608255582081*PolyGamma[2, 1])/
          8264970432 - (554065257559925*Zeta[3])/28927396512) + 
       (565060212773993*CF^2*NC*Zeta[3])/14463698256 + 
       (22101055*CF*NM*NC*Zeta[3])/648 - (28429*CF*NC*NL*Zeta[3])/27 + 
       (7259423061835*CF*NC*NH*Zeta[3])/516560652 + 
       CF*Log[x]*((-73493482319069*NM*NC)/3890016900 - (9051901*lm*NM*NC)/
          22680 - 63*lm^2*NM*NC - (265062989*NC*NL)/151200 - 
         (9051901*lm*NC*NL)/22680 - 63*lm^2*NC*NL - 
         (1490899963158568283*NC*NH)/58091390557200 - (9051901*lm*NC*NH)/
          22680 - 63*lm^2*NC*NH + (12098515*NM*NC*Pi^2)/972 - 
         (170191*NC*NL*Pi^2)/972 + (69158685179*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(181608478857184573883/2117413999008000 - (9290041*lm)/2520 - 
           567*lm^2 + (12281603*Pi^2)/504 + (2311693237703*
             Im[PolyLog[2, (-1)^(1/3)]])/(223205220*Sqrt[3]) - 
           1512*Zeta[3]) + CA*NC*(-4907129812073525221/120995085657600 + 
           (119574671*lm)/45360 + (693*lm^2)/2 - (330280393*Pi^2)/27216 - 
           (2311693237703*Im[PolyLog[2, (-1)^(1/3)]])/(446410440*Sqrt[3]) + 
           756*Zeta[3])), (-2339284402296246799391309*CF^2*NC)/
        22010518519688160000 - (14081894*CF^2*lm*NC)/33075 - 
       254*CF^2*lm^2*NC - (548619459150266851*CF*NM*NC)/1331250228000 - 
       (12681719*CF*lm*NM*NC)/297675 - (254*CF*lm^2*NM*NC)/9 + 
       (2477806637*CF*NC*NL)/1488375 - (12681719*CF*lm*NC*NL)/297675 - 
       (254*CF*lm^2*NC*NL)/9 + (2050147162733167406204689*CF*NC*NH)/
        34540792276967776800 - (12681719*CF*lm*NC*NH)/297675 - 
       (254*CF*lm^2*NC*NH)/9 + (969245833957*CF^2*NC*Pi^2)/26195400 + 
       (32*CF^2*lm*NC*Pi^2)/9 + (138913979*CF*NM*NC*Pi^2)/945 + 
       (32*CF*lm*NM*NC*Pi^2)/81 - (930656*CF*NC*NL*Pi^2)/8505 + 
       (32*CF*lm*NC*NL*Pi^2)/81 + (32*CF*lm*NC*NH*Pi^2)/81 - 
       (1626028923761*CF^2*NC*Pi^3)/(1033121304*Sqrt[3]) - 
       (966262641260*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) - 
       (5431*CF^2*NC*Pi^4)/162 + (4616439100224953*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(210928932900*Sqrt[3]) + 
       (1990940414516*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (215233605*Sqrt[3]) - (33752*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        9 - (3252057847522*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (55801305*Sqrt[3]) - (441720064576*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (1626028923761*CF^2*NC*Pi*Log[3]^2)/(1339231320*Sqrt[3]) - 
       (27607504036*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) - 
       (CF*NC*(-65*CA*(-512610795311 + 28029466080*lm) + 
          12*(52*CF*(-107175403547 + 4777749900*lm) + 
            35*(39*(-18277516723 + 20223280*lm)*NM + 280280*(3707 + 2814*lm)*
               NL + (180053443 + 788707920*lm)*NH)))*Log[x]^2)/170270100 + 
       (CF*NC*(-713654997*CA + 40*(14808545*CF + 42*(2968437*NM + 
              6566*NL)))*Log[x]^3)/8505 + (170886461793079*CF^2*NC*
         PolyGamma[2, 1])/2324522934 + (7951723*CF*NM*NC*PolyGamma[2, 1])/
        27 - (880230993293*CF*NC*NH*PolyGamma[2, 1])/1162261467 + 
       CA*CF*NC*(571203909259724800091099/11005259259844080000 + 
         (1397*lm^2)/9 - (17421867797531*Pi^2)/943034400 + 
         (1626028923761*Pi^3)/(2066242608*Sqrt[3]) + (27667*Pi^4)/1620 + 
         lm*(257113609/595350 - (176*Pi^2)/81) - 
         (4616439100224953*Im[PolyLog[2, (-1)^(1/3)]])/(421857865800*
           Sqrt[3]) + (16876*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (1626028923761*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (55801305*Sqrt[3]) + (1626028923761*Pi*Log[3]^2)/
          (2678462640*Sqrt[3]) - (170886461793079*PolyGamma[2, 1])/
          4649045868 - (1325340654315226*Zeta[3])/40679151345) + 
       (2740954372005947*CF^2*NC*Zeta[3])/40679151345 + 
       (8336198*CF*NM*NC*Zeta[3])/27 - (19568*CF*NC*NL*Zeta[3])/9 + 
       (25647787043510*CF*NC*NH*Zeta[3])/1162261467 + 
       CF*Log[x]*((2494219450693*NM*NC)/5145525 - (242108*lm*NM*NC)/315 - 
         112*lm^2*NM*NC - (11551991*NC*NL)/3150 - (242108*lm*NC*NL)/315 - 
         112*lm^2*NC*NL - (1870035151172128207*NC*NH)/34232426578350 - 
         (242108*lm*NC*NH)/315 - 112*lm^2*NC*NH + (3957104*NM*NC*Pi^2)/
          27 - (29288*NC*NL*Pi^2)/81 + (441720064576*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(3023068918534414117/56716446402000 - (247988*lm)/35 - 
           1008*lm^2 + (7892207*Pi^2)/210 + (3252057847522*
             Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) - 
           2688*Zeta[3]) + CA*NC*(-3423567994388527157/158806049925600 + 
           (1578554*lm)/315 + 616*lm^2 - (633636007*Pi^2)/34020 - 
           (1626028923761*Im[PolyLog[2, (-1)^(1/3)]])/(167403915*Sqrt[3]) + 
           1344*Zeta[3])), (-180050312771922359149768372529*CF^2*NC)/
        290142655126529325120000 - (13518929*CF^2*lm*NC)/37632 - 
       (3621*CF^2*lm^2*NC)/16 - (197373311092535441167453*CF*NM*NC)/
        1010795933116569600 - (12099497*CF*lm*NM*NC)/338688 - 
       (1207*CF*lm^2*NM*NC)/48 + (7584179191*CF*NC*NL)/4838400 - 
       (12099497*CF*lm*NC*NL)/338688 - (1207*CF*lm^2*NC*NL)/48 + 
       (33734279495867074375387099*CF*NC*NH)/602893828834346649600 - 
       (12099497*CF*lm*NC*NH)/338688 - (1207*CF*lm^2*NC*NH)/48 + 
       (3593154679315783*CF^2*NC*Pi^2)/15088550400 + (55*CF^2*lm*NC*Pi^2)/
        24 + (2743541573*CF*NM*NC*Pi^2)/54432 + (55*CF*lm*NM*NC*Pi^2)/216 - 
       (1299421*CF*NC*NL*Pi^2)/13608 + (55*CF*lm*NC*NL*Pi^2)/216 + 
       (55*CF*lm*NC*NH*Pi^2)/216 - (25805698187759*CF^2*NC*Pi^3)/
        (16529940864*Sqrt[3]) - (6885979073155*CF*NC*NH*Pi^3)/
        (1033121304*Sqrt[3]) - (356369*CF^2*NC*Pi^4)/12960 + 
       (66016971916297991*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2892739651200*Sqrt[3]) - (22148963558089*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5165606520*Sqrt[3]) - 
       (19747*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (3686528312537*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (63772920*Sqrt[3]) - (393484518466*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (3686528312537*CF^2*NC*Pi*Log[3]^2)/(3061100160*Sqrt[3]) - 
       (196742259233*CF*NC*NH*Pi*Log[3]^2)/(38263752*Sqrt[3]) - 
       (CF*NC*(CA*(5749360207508917 - 39769419690000*lm) + 
          CF*(-11516642414451029 + 65077232220000*lm) + 
          210*(25*(-466456956403 + 1377295920*lm)*NM + 
            33*(12740*(110029 + 81900*lm)*NL + 3*(81465409 + 347802000*lm)*
               NH)))*Log[x]^2)/4086482400 + 
       (CF*NC*(-15001226947*CA + 27084259459*CF + 
          4200*(2133233*NM + 9555*NL))*Log[x]^3)/34020 + 
       (49795640454665989*CF^2*NC*PolyGamma[2, 1])/111577100832 + 
       (50297077*CF*NM*NC*PolyGamma[2, 1])/216 + 
       (24559087359769*CF*NC*NH*PolyGamma[2, 1])/55788550416 + 
       CA*CF*NC*(359082953028098299109590918663/1160570620506117300480000 + 
         (13277*lm^2)/96 - (3592883633022503*Pi^2)/30177100800 + 
         (25805698187759*Pi^3)/(33059881728*Sqrt[3]) + (361649*Pi^4)/25920 - 
         (5*lm*(-50465351 + 189728*Pi^2))/677376 - 
         (66016971916297991*Im[PolyLog[2, (-1)^(1/3)]])/(5785479302400*
           Sqrt[3]) + (19747*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (3686528312537*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (127545840*Sqrt[3]) + (3686528312537*Pi*Log[3]^2)/
          (6122200320*Sqrt[3]) - (49795640454665989*PolyGamma[2, 1])/
          223154201664 - (87643335244321169*Zeta[3])/390519852912) + 
       (87900598031930171*CF^2*NC*Zeta[3])/195259926456 + 
       (37414387*CF*NM*NC*Zeta[3])/108 - (3965*CF*NC*NL*Zeta[3])/2 + 
       (709544339944369*CF*NC*NH*Zeta[3])/27894275208 + 
       CF*Log[x]*((-135717487736335553*NM*NC)/1402480759680 - 
         (6093845*lm*NM*NC)/9072 - 105*lm^2*NM*NC - (17086927*NC*NL)/
          5184 - (6093845*lm*NC*NL)/9072 - 105*lm^2*NC*NL - 
         (67830800882456511869*NC*NH)/1394193373372800 - 
         (6093845*lm*NC*NH)/9072 - 105*lm^2*NC*NH + (5342375*NM*NC*Pi^2)/
          81 - (17815*NC*NL*Pi^2)/54 + (393484518466*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(2198259033127722657563321/2147057794994112000 - 
           (6252605*lm)/1008 - 945*lm^2 + (3924922555*Pi^2)/18144 + 
           (3686528312537*Im[PolyLog[2, (-1)^(1/3)]])/(191318760*Sqrt[3]) - 
           2520*Zeta[3]) + CA*NC*(-38947824131317271200441/
            76680635535504000 + (80368135*lm)/18144 + (1155*lm^2)/2 - 
           (1307233625*Pi^2)/12096 - (3686528312537*Im[PolyLog[2, (-1)^
                (1/3)]])/(382637520*Sqrt[3]) + 1260*Zeta[3])), 
      (-264326945049764743741193327503*CF^2*NC)/290142655126529325120000 - 
       (142642901*CF^2*lm*NC)/235200 - (1449*CF^2*lm^2*NC)/4 - 
       (171382866593230633764421*CF*NM*NC)/46796108014656000 - 
       (128442701*CF*lm*NM*NC)/2116800 - (161*CF*lm^2*NM*NC)/4 + 
       (156049357841*CF*NC*NL)/49392000 - (128442701*CF*lm*NC*NL)/2116800 - 
       (161*CF*lm^2*NC*NL)/4 + (11086999913247821647460033293*CF*NC*NH)/
        104430099973380115334400 - (128442701*CF*lm*NC*NH)/2116800 - 
       (161*CF*lm^2*NC*NH)/4 + (36652402250145811*CF^2*NC*Pi^2)/
        130767436800 + (9*CF^2*lm*NC*Pi^2)/2 + (4880524333*CF*NM*NC*Pi^2)/
        3780 + (CF*lm*NM*NC*Pi^2)/2 - (49359*CF*NC*NL*Pi^2)/280 + 
       (CF*lm*NC*NL*Pi^2)/2 + (CF*lm*NC*NH*Pi^2)/2 - 
       (92759574932743*CF^2*NC*Pi^3)/(33059881728*Sqrt[3]) - 
       (64549621675*CF*NC*NH*Pi^3)/(4782969*Sqrt[3]) - 
       (475643*CF^2*NC*Pi^4)/8640 + (1497601153254843179*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(40498355116800*Sqrt[3]) + 
       (4407588058751*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (215233605*Sqrt[3]) - (23713*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        4 - (92759574932743*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (892820880*Sqrt[3]) - (29508398480*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59049*Sqrt[3]) - 
       (92759574932743*CF^2*NC*Pi*Log[3]^2)/(42855402240*Sqrt[3]) - 
       (1844274905*CF*NC*NH*Pi*Log[3]^2)/(177147*Sqrt[3]) + 
       CF*((2545795231842319*CF*NC)/778377600 - 31932*CF*lm*NC + 
         CA*(-17805143961169189/10897286400 + 19514*lm)*NC + 
         (2789893522973*NM*NC)/180180 - 3548*lm*NM*NC - (13918*NC*NL)/3 - 
         3548*lm*NC*NL - (21035471*NC*NH)/23562 - 3548*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-13002842017*CA + 6*(3585309793*CF + 
            10080*(1819356*NM + 887*NL)))*Log[x]^3)/22680 + 
       (37122703799426129*CF^2*NC*PolyGamma[2, 1])/55788550416 + 
       (48611711*CF*NM*NC*PolyGamma[2, 1])/18 - 
       (9866866418471*CF*NC*NH*PolyGamma[2, 1])/6973568802 + 
       CA*CF*NC*(2104896196506648622728944790977/4642282482024469201920000 + 
         (1771*lm^2)/8 - (939486497686589*Pi^2)/6706022400 + 
         (92759574932743*Pi^3)/(66119763456*Sqrt[3]) + (96511*Pi^4)/3456 + 
         lm*(2605686511/4233600 - (11*Pi^2)/4) - 
         (1497601153254843179*Im[PolyLog[2, (-1)^(1/3)]])/
          (80996710233600*Sqrt[3]) + (23713*Im[PolyLog[2, (-1)^(1/3)]]^2)/8 + 
         (92759574932743*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1785641760*Sqrt[3]) + (92759574932743*Pi*Log[3]^2)/
          (85710804480*Sqrt[3]) - (37122703799426129*PolyGamma[2, 1])/
          111577100832 - (2976586212802259089*Zeta[3])/7810397058240) + 
       (2991469213670700529*CF^2*NC*Zeta[3])/3905198529120 + 
       (26996141*CF*NM*NC*Zeta[3])/9 - 3914*CF*NC*NL*Zeta[3] + 
       (134662671525913*CF*NC*NH*Zeta[3])/3486784401 + 
       CF*Log[x]*((323343025482637891*NM*NC)/64929664800 - 
         (174397*lm*NM*NC)/140 - 180*lm^2*NM*NC - (435475591*NC*NL)/
          66150 - (174397*lm*NC*NL)/140 - 180*lm^2*NC*NL - 
         (155457156501565802179*NC*NH)/1578397697276400 - 
         (174397*lm*NC*NH)/140 - 180*lm^2*NC*NH + (3638890*NM*NC*Pi^2)/3 - 
         (1954*NC*NL*Pi^2)/3 + (29508398480*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(177147*Sqrt[3]) + 
         CF*NC*(2671135043767674726029959/4294115589988224000 - 
           (1607373*lm)/140 - 1620*lm^2 + (16851036337*Pi^2)/60480 + 
           (92759574932743*Im[PolyLog[2, (-1)^(1/3)]])/(2678462640*Sqrt[3]) - 
           4320*Zeta[3]) + CA*NC*(-2598039483773650097710843/
            8588231179976448000 + (2271167*lm)/280 + 990*lm^2 - 
           (50447559931*Pi^2)/362880 - (92759574932743*
             Im[PolyLog[2, (-1)^(1/3)]])/(5356925280*Sqrt[3]) + 
           2160*Zeta[3])), (-53025177194087887516094167989751*CF^2*NC)/
        8952973358190047746560000 - (12790900169*CF^2*lm*NC)/25401600 - 
       (5073*CF^2*lm^2*NC)/16 - (700874502171842718841307*CF*NM*NC)/
        561553296175872000 - (11448584369*CF*lm*NM*NC)/228614400 - 
       (1691*CF*lm^2*NM*NC)/48 + (828581783190499*CF*NC*NL)/288054144000 - 
       (11448584369*CF*lm*NC*NL)/228614400 - (1691*CF*lm^2*NC*NL)/48 + 
       (85963978742013951283695167075869*CF*NC*NH)/
        879719162175754091576985600 - (11448584369*CF*lm*NC*NH)/228614400 - 
       (1691*CF*lm^2*NC*NH)/48 + (175375325860545289*CF^2*NC*Pi^2)/
        78460462080 + (23*CF^2*lm*NC*Pi^2)/8 + (72583338491*CF*NM*NC*Pi^2)/
        272160 + (23*CF*lm*NM*NC*Pi^2)/72 - (10219201*CF*NC*NL*Pi^2)/
        68040 + (23*CF*lm*NC*NL*Pi^2)/72 + (23*CF*lm*NC*NH*Pi^2)/72 - 
       (2413775132698765*CF^2*NC*Pi^3)/(892616806656*Sqrt[3]) - 
       (328420892069515*CF*NC*NH*Pi^3)/(27894275208*Sqrt[3]) - 
       (1151953*CF^2*NC*Pi^4)/25920 + (1647999557550131053*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(43738223526144*Sqrt[3]) - 
       (2495476308562471*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (976299632280*Sqrt[3]) - (60995*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        12 - (482755026539753*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (4821232752*Sqrt[3]) - (18766908118258*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(43046721*Sqrt[3]) - 
       (482755026539753*CF^2*NC*Pi*Log[3]^2)/(231419172096*Sqrt[3]) - 
       (9383454059129*CF*NC*NH*Pi*Log[3]^2)/(1033121304*Sqrt[3]) - 
       (CF*NC*(CA*(7431840231912850821 - 9599021838806400*lm) + 
          2*(17*CF*(-437298893142397189 + 461985008284800*lm) + 
            840*(51*(-20698532558027 + 20369709360*lm)*NM + 
              9189180*(150781 + 113052*lm)*NL + (266252429813 + 
                1038855177360*lm)*NH)))*Log[x]^2)/555761606400 + 
       (CF*NC*(-273195002611*CA + 48*(11145363116*CF + 
            315*(6171011*NM + 9421*NL)))*Log[x]^3)/68040 + 
       (4188283064252104055*CF^2*NC*PolyGamma[2, 1])/1004193907488 + 
       (147316519*CF*NM*NC*PolyGamma[2, 1])/72 + 
       (324220905083681*CF*NC*NH*PolyGamma[2, 1])/502096953744 + 
       CA*CF*NC*(2318755435109261214878842758943/783385168841629177824000 + 
         (18601*lm^2)/96 - (13490191430982949*Pi^2)/12070840320 + 
         (2413775132698765*Pi^3)/(1785233613312*Sqrt[3]) + 
         (1165201*Pi^4)/51840 + lm*(238688955259/457228800 - 
           (253*Pi^2)/144) - (1647999557550131053*Im[PolyLog[2, (-1)^(1/3)]])/
          (87476447052288*Sqrt[3]) + (60995*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          24 + (482755026539753*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9642465504*Sqrt[3]) + (482755026539753*Pi*Log[3]^2)/
          (462838344192*Sqrt[3]) - (4188283064252104055*PolyGamma[2, 1])/
          2008387814976 - (151920517800556252043*Zeta[3])/70293573524160) + 
       (151996808240332823483*CF^2*NC*Zeta[3])/35146786762080 + 
       (123443909*CF*NM*NC*Zeta[3])/36 - (20845*CF*NC*NL*Zeta[3])/6 + 
       (10839485538512585*CF*NC*NH*Zeta[3])/251048476872 + 
       CF*Log[x]*((-40392250455087733*NM*NC)/47703427200 - 
         (16083593*lm*NM*NC)/15120 - 165*lm^2*NM*NC - (329705034013*NC*NL)/
          57153600 - (16083593*lm*NC*NL)/15120 - 165*lm^2*NC*NL - 
         (2055942918888285229672799*NC*NH)/23933559963341508480 - 
         (16083593*lm*NC*NH)/15120 - 165*lm^2*NC*NH + (3088277*NM*NC*Pi^2)/
          9 - (10411*NC*NL*Pi^2)/18 + (18766908118258*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(129140163*Sqrt[3]) + 
         CF*NC*(1197248359963952717963416117/115941120929682048000 - 
           (16499393*lm)/1680 - 1485*lm^2 + (362912722163*Pi^2)/181440 + 
           (482755026539753*Im[PolyLog[2, (-1)^(1/3)]])/(14463698256*
             Sqrt[3]) - 3960*Zeta[3]) + CA*NC*(-1195749460288195456986616231/
            231882241859364096000 + (211846723*lm)/30240 + (1815*lm^2)/2 - 
           (1088572636369*Pi^2)/1088640 - (482755026539753*
             Im[PolyLog[2, (-1)^(1/3)]])/(28927396512*Sqrt[3]) + 
           1980*Zeta[3])), (-135077045350086616033901947428991*CF^2*NC)/
        18801244052199100267776000 - (158451841*CF^2*lm*NC)/190512 - 
       (995*CF^2*lm^2*NC)/2 - (1368141504563700417661037*CF*NM*NC)/
        42116497213190400 - (142655221*CF*lm*NM*NC)/1714608 - 
       (995*CF*lm^2*NM*NC)/18 + (401439898274161*CF*NC*NL)/72013536000 - 
       (142655221*CF*lm*NC*NL)/1714608 - (995*CF*lm^2*NC*NL)/18 + 
       (25319807532876883873847676857191037*CF*NC*NH)/
        141421728125706968299840880400 - (142655221*CF*lm*NC*NH)/1714608 - 
       (995*CF*lm^2*NC*NH)/18 + (20898668858294327*CF^2*NC*Pi^2)/
        9807557760 + (50*CF^2*lm*NC*Pi^2)/9 + (58963125062*CF*NM*NC*Pi^2)/
        5103 + (50*CF*lm*NM*NC*Pi^2)/81 - (5507255*CF*NC*NL*Pi^2)/20412 + 
       (50*CF*lm*NC*NL*Pi^2)/81 + (50*CF*lm*NC*NH*Pi^2)/81 - 
       (393308296214345*CF^2*NC*Pi^3)/(83682825624*Sqrt[3]) - 
       (958898926267625*CF*NC*NH*Pi^3)/(41841412812*Sqrt[3]) - 
       (55445*CF^2*NC*Pi^4)/648 + (4881749933656182199*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(82009169111520*Sqrt[3]) + 
       (2950615980880970*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (73222472421*Sqrt[3]) - (80450*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        9 - (157323318485738*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (903981141*Sqrt[3]) - (109588448716300*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(129140163*Sqrt[3]) - 
       (78661659242869*CF^2*NC*Pi*Log[3]^2)/(21695547384*Sqrt[3]) - 
       (27397112179075*CF*NC*NH*Pi*Log[3]^2)/(1549681956*Sqrt[3]) - 
       (CF*NC*(-323*CA*(-1384362662638031 + 3635794850688*lm) + 
          8*(969*CF*(-115387385526181 + 247895103456*lm) + 
            28*(2584*(-8430761902456 + 368891523*lm)*NM + 23279256*(53234 + 
                40947*lm)*NL + (259269390683 + 953215695432*lm)*NH)))*
         Log[x]^2)/35198235072 + (CF*NC*(-86523462451*CA + 
          32*(5170743481*CF + 27032787558*NM + 2579661*NL))*Log[x]^3)/
        20412 + (4420472044525691363*CF^2*NC*PolyGamma[2, 1])/753145430616 + 
       (4003275685*CF*NM*NC*PolyGamma[2, 1])/162 - 
       (231286901651590*CF*NC*NH*PolyGamma[2, 1])/94143178827 + 
       CA*CF*NC*(53979860035196626024587556192819/
          15040995241759280214220800 + (10945*lm^2)/36 - 
         (1160951153584639*Pi^2)/1089728640 + (393308296214345*Pi^3)/
          (167365651248*Sqrt[3]) + (18695*Pi^4)/432 + 
         lm*(2896123511/3429216 - (275*Pi^2)/81) - 
         (4881749933656182199*Im[PolyLog[2, (-1)^(1/3)]])/
          (164018338223040*Sqrt[3]) + (40225*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          9 + (78661659242869*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (903981141*Sqrt[3]) + (78661659242869*Pi*Log[3]^2)/
          (43391094768*Sqrt[3]) - (4420472044525691363*PolyGamma[2, 1])/
          1506290861232 - (4948480855885850879*Zeta[3])/1318004503578) + 
       (19810339584562811225*CF^2*NC*Zeta[3])/2636009007156 + 
       (2290299595*CF*NM*NC*Zeta[3])/81 - (178838*CF*NC*NL*Zeta[3])/27 + 
       (6011385284492200*CF*NC*NH*Zeta[3])/94143178827 + 
       CF*Log[x]*((3368763102466766047*NM*NC)/70124037984 - 
         (6518195*lm*NM*NC)/3402 - 275*lm^2*NM*NC - (317604118409*NC*NL)/
          28576800 - (6518195*lm*NC*NL)/3402 - 275*lm^2*NC*NL - 
         (1083313633346684500141915607*NC*NH)/6480011360074713420960 - 
         (6518195*lm*NC*NH)/3402 - 275*lm^2*NC*NH + (95356135*NM*NC*Pi^2)/
          9 - (29773*NC*NL*Pi^2)/27 + (109588448716300*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(387420489*Sqrt[3]) + 
         CF*NC*(6287083578194321758931821/1242226295675164800 - 
           (3337060*lm)/189 - 2475*lm^2 + (10744920076*Pi^2)/5103 + 
           (157323318485738*Im[PolyLog[2, (-1)^(1/3)]])/(2711943423*
             Sqrt[3]) - 6600*Zeta[3]) + CA*NC*(-87550156286744020532868353/
            34782336278904614400 + (84797845*lm)/6804 + (3025*lm^2)/2 - 
           (85919904737*Pi^2)/81648 - (78661659242869*
             Im[PolyLog[2, (-1)^(1/3)]])/(2711943423*Sqrt[3]) + 
           3300*Zeta[3])), (-103762400757418639368292885893790663207*CF^2*NC)/
        1847410240569083592311669760000 - (31163400361*CF^2*lm*NC)/45722880 - 
       (6867*CF^2*lm^2*NC)/16 - (508097388786249959895609904067*CF*NM*NC)/
        74490606291025596672000 - (27892785601*CF*lm*NM*NC)/411505920 - 
       (763*CF*lm^2*NM*NC)/16 + (474369913111711*CF*NC*NL)/96018048000 - 
       (27892785601*CF*lm*NC*NL)/411505920 - (763*CF*lm^2*NC*NL)/16 + 
       (860182402484846910152581919970307663*CF*NC*NH)/
        5324112117673674100699891968000 - (27892785601*CF*lm*NC*NH)/
        411505920 - (763*CF*lm^2*NC*NH)/16 + 
       (998002956453682847*CF^2*NC*Pi^2)/47076277248 + 
       (761*CF^2*lm*NC*Pi^2)/216 + (2426639640907*CF*NM*NC*Pi^2)/2449440 + 
       (761*CF*lm*NM*NC*Pi^2)/1944 - (69031283*CF*NC*NL*Pi^2)/306180 + 
       (761*CF*lm*NC*NL*Pi^2)/1944 + (761*CF*lm*NC*NH*Pi^2)/1944 - 
       (11853936513143479*CF^2*NC*Pi^3)/(2677850419968*Sqrt[3]) - 
       (1644576909874885*CF*NC*NH*Pi^3)/(83682825624*Sqrt[3]) - 
       (1059979*CF^2*NC*Pi^4)/15552 + (195120918791358035611*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3280366764460800*Sqrt[3]) + 
       (8112738654733739*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2928898896840*Sqrt[3]) - (270677*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/36 - (11853936513143479*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(72318491280*Sqrt[3]) - 
       (93975823421422*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) - (11853936513143479*CF^2*NC*Pi*Log[3]^2)/
        (3471287581440*Sqrt[3]) - (46987911710711*CF*NC*NH*Pi*Log[3]^2)/
        (3099363912*Sqrt[3]) - 
       (CF*NC*(CA*(4027377449607784678831 - 914875459177680000*lm) + 
          2*(19*CF*(-211978800289850208389 + 39396550873680000*lm) + 
            840*(57*(-3927921683057303 + 1737061326000*lm)*NM + 
              17*(10270260*(752047 + 567100*lm)*NL + (1604834475407 + 
                  5824264446000*lm)*NH))))*Log[x]^2)/31678411564800 + 
       (CF*NC*(-3851221884662*CA + 7671173647575*CF + 625026298680*NM + 
          357273000*NL)*Log[x]^3)/102060 + (38921780505808806865*CF^2*NC*
         PolyGamma[2, 1])/1004193907488 + (69775964851*CF*NM*NC*
         PolyGamma[2, 1])/3888 + (114050379140599*CF*NC*NH*PolyGamma[2, 1])/
        125524238436 + CA*CF*NC*(2964412721316855766876117695214592891/
          105566299461090490989238272000 + (8393*lm^2)/32 - 
         (4989999945830280739*Pi^2)/470762772480 + (11853936513143479*Pi^3)/
          (5355700839936*Sqrt[3]) + (5348599*Pi^4)/155520 + 
         lm*(581552281451/823011840 - (8371*Pi^2)/3888) - 
         (195120918791358035611*Im[PolyLog[2, (-1)^(1/3)]])/
          (6560733528921600*Sqrt[3]) + (270677*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          72 + (11853936513143479*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (144636982560*Sqrt[3]) + (11853936513143479*Pi*Log[3]^2)/
          (6942575162880*Sqrt[3]) - (38921780505808806865*PolyGamma[2, 1])/
          2008387814976 - (1398077874165485123923*Zeta[3])/70293573524160) + 
       (1398198346719687316003*CF^2*NC*Zeta[3])/35146786762080 + 
       (63897980503*CF*NM*NC*Zeta[3])/1944 - (931601*CF*NC*NL*Zeta[3])/
        162 + (4368991205023393*CF*NC*NH*Zeta[3])/62762119218 + 
       CF*Log[x]*((-19737104083424558931193*NM*NC)/2026584697737600 - 
         (655460959*lm*NM*NC)/408240 - (495*lm^2*NM*NC)/2 - 
         (45428328769*NC*NL)/4762800 - (655460959*lm*NC*NL)/408240 - 
         (495*lm^2*NC*NL)/2 - (1092608148284510085172110671*NC*NH)/
          7623542776558486377600 - (655460959*lm*NC*NH)/408240 - 
         (495*lm^2*NC*NH)/2 + 1531687*NM*NC*Pi^2 - (77570*NC*NL*Pi^2)/81 + 
         (93975823421422*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(10089467831000290476035404293757/
            100520951846034335616000 - (672300859*lm)/45360 - (4455*lm^2)/2 + 
           (30789401717927*Pi^2)/1632960 + (11853936513143479*
             Im[PolyLog[2, (-1)^(1/3)]])/(216955473840*Sqrt[3]) - 
           5940*Zeta[3]) + CA*NC*(-10087467981861754991740722318691/
            201041903692068671232000 + (8624622149*lm)/816480 + 
           (5445*lm^2)/4 - (30788594137727*Pi^2)/3265920 - 
           (11853936513143479*Im[PolyLog[2, (-1)^(1/3)]])/(433910947680*
             Sqrt[3]) + 2970*Zeta[3])), 
      (-197365437476830463508474929693370470467*CF^2*NC)/
        3562862606811804070886791680000 - (4215344201*CF^2*lm*NC)/3810240 - 
       (2651*CF^2*lm^2*NC)/4 - (302371853588995336350613002497*CF*NM*NC)/
        1034591754042022176000 - (3794471441*CF*lm*NM*NC)/34292160 - 
       (2651*CF*lm^2*NM*NC)/36 + (66840582445417*CF*NC*NL)/7201353600 - 
       (3794471441*CF*lm*NC*NL)/34292160 - (2651*CF*lm^2*NC*NL)/36 + 
       (9252650851990205719003121555327440753*CF*NC*NH)/
        32154835026476531739753294912000 - (3794471441*CF*lm*NC*NH)/
        34292160 - (2651*CF*lm^2*NC*NH)/36 + 
       (6306433713274124473*CF^2*NC*Pi^2)/392302310400 + 
       (121*CF^2*lm*NC*Pi^2)/18 + (10714553476297*CF*NM*NC*Pi^2)/102060 + 
       (121*CF*lm*NM*NC*Pi^2)/162 - (80885519*CF*NC*NL*Pi^2)/204120 + 
       (121*CF*lm*NC*NL*Pi^2)/162 + (121*CF*lm*NC*NH*Pi^2)/162 - 
       (541432574670350669*CF^2*NC*Pi^3)/(72301961339136*Sqrt[3]) - 
       (41860256399628835*CF*NC*NH*Pi^3)/(1129718145924*Sqrt[3]) - 
       (1099571*CF^2*NC*Pi^4)/8640 + (8152083490535012850161*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(88569902640441600*Sqrt[3]) + 
       (103033198266635813*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1412147682405*Sqrt[3]) - (466961*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/36 - (541432574670350669*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1952599264560*Sqrt[3]) - 
       (4784029302814724*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (3486784401*Sqrt[3]) - (541432574670350669*CF^2*NC*Pi*Log[3]^2)/
        (93724764698880*Sqrt[3]) - (1196007325703681*CF*NC*NH*Pi*Log[3]^2)/
        (41841412812*Sqrt[3]) - 
       (CF*NC*(CA*(53531348398402419319 - 30096837535564800*lm) + 
          2*(CF*(-53533873575513464479 + 24624685256371200*lm) + 
            3360*(56*(-1860469572218969 + 14541220980*lm)*NM + 
              134774640*(7819 + 6042*lm)*NL + (236075621009 + 814308374880*
                 lm)*NH)))*Log[x]^2)/555761606400 + 
       (CF*NC*(-6510256805209*CA + 2*(6443283669541*CF + 
            30240*(1285770237*NM + 22154*NL)))*Log[x]^3)/204120 + 
       (697758167001960832121*CF^2*NC*PolyGamma[2, 1])/13556617751088 + 
       (18303666113*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (3413763069581111*CF*NC*NH*PolyGamma[2, 1])/847288609443 + 
       CA*CF*NC*(276258965071956691363628025714375019451/
          9976015299073051398483016704000 + (29161*lm^2)/72 - 
         (573303401248605323*Pi^2)/71327692800 + (541432574670350669*Pi^3)/
          (144603922678272*Sqrt[3]) + (3329689*Pi^4)/51840 + 
         lm*(77092497691/68584320 - (1331*Pi^2)/324) - 
         (8152083490535012850161*Im[PolyLog[2, (-1)^(1/3)]])/
          (177139805280883200*Sqrt[3]) + (466961*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/72 + (541432574670350669*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3905198529120*Sqrt[3]) + 
         (541432574670350669*Pi*Log[3]^2)/(187449529397760*Sqrt[3]) - 
         (697758167001960832121*PolyGamma[2, 1])/27113235502176 - 
         (67435194580853164731643*Zeta[3])/1897926485152320) + 
       (67444457496002018637763*CF^2*NC*Zeta[3])/948963242576160 + 
       (21183666910*CF*NM*NC*Zeta[3])/81 - (287870*CF*NC*NL*Zeta[3])/27 + 
       (85401700941578462*CF*NC*NH*Zeta[3])/847288609443 + 
       CF*Log[x]*((229906122012052477928437*NM*NC)/506646174434400 - 
         (96126899*lm*NM*NC)/34020 - (1210*lm^2*NM*NC)/3 - 
         (63776274559*NC*NL)/3572100 - (96126899*lm*NC*NL)/34020 - 
         (1210*lm^2*NC*NL)/3 - (388746622648730267751679537*NC*NH)/
          1438818311858694591825 - (96126899*lm*NC*NH)/34020 - 
         (1210*lm^2*NC*NH)/3 + (857186065*NM*NC*Pi^2)/9 - 
         (47938*NC*NL*Pi^2)/27 + (4784029302814724*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(10460353203*Sqrt[3]) + 
         CF*NC*(100287814605317011633341913041977/2714065699842927061632000 - 
           (98413799*lm)/3780 - 3630*lm^2 + (26004253641971*Pi^2)/1632960 + 
           (541432574670350669*Im[PolyLog[2, (-1)^(1/3)]])/
            (5857797793680*Sqrt[3]) - 9680*Zeta[3]) + 
         CA*NC*(-14310961761570228595139301313439/775447342812264874752000 + 
           (1249495489*lm)/68040 + (6655*lm^2)/3 - (26001749019011*Pi^2)/
            3265920 - (541432574670350669*Im[PolyLog[2, (-1)^(1/3)]])/
            (11715595587360*Sqrt[3]) + 4840*Zeta[3])), 
      (-4391483645705444466565602121485899687059531*CF^2*NC)/
        8211058672361047145063401388728320 - (1653844326217*CF^2*lm*NC)/
        1844156160 - (9039*CF^2*lm^2*NC)/16 - 
       (918191503636480169087091797092601*CF*NM*NC)/
        34062071236676304504883200 - (1480205497777*CF*lm*NM*NC)/
        16597405440 - (3013*CF*lm^2*NM*NC)/48 + 
       (18696693728147317*CF*NC*NL)/2323636761600 - 
       (1480205497777*CF*lm*NC*NL)/16597405440 - (3013*CF*lm^2*NC*NL)/48 + 
       (374475963158082291054632251956053221457*CF*NC*NH)/
        1466260477207329847332750247987200 - (1480205497777*CF*lm*NC*NH)/
        16597405440 - (3013*CF*lm^2*NC*NH)/48 + 
       (1307665670794001431777*CF^2*NC*Pi^2)/6472988121600 + 
       (305*CF^2*lm*NC*Pi^2)/72 - (1942288830479*CF*NM*NC*Pi^2)/997920 + 
       (305*CF*lm*NM*NC*Pi^2)/648 - (36583405*CF*NC*NL*Pi^2)/112266 + 
       (305*CF*lm*NC*NL*Pi^2)/648 + (305*CF*lm*NC*NH*Pi^2)/648 - 
       (8257494464385373967*CF^2*NC*Pi^3)/(1192982362095744*Sqrt[3]) - 
       (212299352357888075*CF*NC*NH*Pi^3)/(6778308875544*Sqrt[3]) - 
       (3896927*CF^2*NC*Pi^4)/38880 + (1454002199166365984993833*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(16075437329240150400*Sqrt[3]) + 
       (666383474352417173*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (47448162128808*Sqrt[3]) - (193261*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/18 - (8257494464385373967*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(32217887865240*Sqrt[3]) - 
       (12131391563307890*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) - (8257494464385373967*CF^2*NC*Pi*Log[3]^2)/
        (1546458617531520*Sqrt[3]) - (6065695781653945*CF*NC*NH*Pi*Log[3]^2)/
        (251048476872*Sqrt[3]) - 
       (CF*NC*(CA*(211169964405238649090053 - 8017009606982376000*lm) + 
          2*(CF*(-211171935662980789431643 + 6559371496621944000*lm) + 
            69300*((29388231952573537 + 10516869483120*lm)*NM + 
              128035908*(108427 + 82140*lm)*NL + (3075987883883 + 
                10516869483120*lm)*NH)))*Log[x]^2)/174231263606400 + 
       (CF*NC*(-805014246667651*CA + 176*(9141134361862*CF + 
            945*(151764797*NM + 75295*NL)))*Log[x]^3)/2245320 + 
       (29244840300331306131019*CF^2*NC*PolyGamma[2, 1])/81339706506528 + 
       (203821658057*CF*NM*NC*PolyGamma[2, 1])/1296 + 
       (12556150398058309*CF*NC*NH*PolyGamma[2, 1])/10167463313316 + 
       CA*CF*NC*(172520499161545254545883294673408349075703227/
          645154609971225132826410109114368000 + (33143*lm^2)/96 - 
         (1307665018915889965657*Pi^2)/12945976243200 + 
         (8257494464385373967*Pi^3)/(2385964724191488*Sqrt[3]) + 
         (3926207*Pi^4)/77760 + lm*(2806174733137/3017710080 - 
           (3355*Pi^2)/1296) - (1454002199166365984993833*
           Im[PolyLog[2, (-1)^(1/3)]])/(32150874658480300800*Sqrt[3]) + 
         (193261*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 + 
         (8257494464385373967*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (64435775730480*Sqrt[3]) + (8257494464385373967*Pi*Log[3]^2)/
          (3092917235063040*Sqrt[3]) - (29244840300331306131019*
           PolyGamma[2, 1])/162679413013056 - (1411332880854630532566751*
           Zeta[3])/7828946751253320) + (352838330114646746603479*CF^2*NC*
         Zeta[3])/978618343906665 + (200219539469*CF*NM*NC*Zeta[3])/648 - 
       (490685*CF*NC*NL*Zeta[3])/54 + (546970260759194779*CF*NC*NH*Zeta[3])/
        5083731656658 + CF*Log[x]*((-83608653698596015062583583*NM*NC)/
          731597075883273600 - (697886689*lm*NM*NC)/299376 - 
         (715*lm^2*NM*NC)/2 - (315544447819*NC*NL)/20956320 - 
         (697886689*lm*NC*NL)/299376 - (715*lm^2*NC*NL)/2 - 
         (479345334276983600668248065737*NC*NH)/2099523680664207148391040 - 
         (697886689*lm*NC*NH)/299376 - (715*lm^2*NC*NH)/2 + 
         (227748313*NM*NC*Pi^2)/81 - (40865*NC*NL*Pi^2)/27 + 
         (12131391563307890*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*
          (1114005506624504280745520394745998889/
            1154738024365313931615072000 - (715724509*lm)/33264 - 
           (6435*lm^2)/2 + (1609849325555561*Pi^2)/8981280 + 
           (8257494464385373967*Im[PolyLog[2, (-1)^(1/3)]])/
            (96653663595720*Sqrt[3]) - 8580*Zeta[3]) + 
         CA*NC*(-15595601238030494198950898397693026471/
            32332664682228790085222016000 + (834102769*lm)/54432 + 
           (7865*lm^2)/4 - (1609842403760681*Pi^2)/17962560 - 
           (8257494464385373967*Im[PolyLog[2, (-1)^(1/3)]])/
            (193307327191440*Sqrt[3]) + 4290*Zeta[3])), 
      (-1188817454660613075323832609573460546746140347*CF^2*NC)/
        2822551418624109956115544227375360000 - (918957439*CF^2*lm*NC)/
        640332 - 861*CF^2*lm^2*NC - (33331198293230244009580489738271*CF*NM*
         NC)/12515458273323157152000 - (827069797*CF*lm*NM*NC)/5762988 - 
       (287*CF*lm^2*NM*NC)/3 + (142722111777151*CF*NC*NL)/9681819840 - 
       (827069797*CF*lm*NC*NL)/5762988 - (287*CF*lm^2*NC*NL)/3 + 
       (4954538928102605056083291483241155555499211*CF*NC*NH)/
        11149994516363488907810982667037664000 - (827069797*CF*lm*NC*NH)/
        5762988 - (287*CF*lm^2*NC*NH)/3 + (4589936845218652861*CF^2*NC*Pi^2)/
        38529691200 + 8*CF^2*lm*NC*Pi^2 + (60090734999699*CF*NM*NC*Pi^2)/
        62370 + (8*CF*lm*NM*NC*Pi^2)/9 - (17544503*CF*NC*NL*Pi^2)/31185 + 
       (8*CF*lm*NC*NL*Pi^2)/9 + (8*CF*lm*NC*NH*Pi^2)/9 - 
       (1707532654729613275*CF^2*NC*Pi^3)/(149122795261968*Sqrt[3]) - 
       (97472267203186645*CF*NC*NH*Pi^3)/(1694577218886*Sqrt[3]) - 
       (295817*CF^2*NC*Pi^4)/1620 + (11056273084416194539253*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(80377186646200752*Sqrt[3]) + 
       (3678080381471336482*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29655101330505*Sqrt[3]) - (54700*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (341506530945922655*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(805447196631*Sqrt[3]) - 
       (22279375360728376*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) - (341506530945922655*CF^2*NC*Pi*Log[3]^2)/
        (38661465438288*Sqrt[3]) - (2784921920091047*CF*NC*NH*Pi*Log[3]^2)/
        (62762119218*Sqrt[3]) + CF*((1037498224277633868131*CF*NC)/
          725963598360 - 137808*CF*lm*NC + 
         CA*(-1037487410769166796717/1451927196720 + 84216*lm)*NC + 
         (1009280825389142531*NM*NC)/87297210 - 15312*lm*NM*NC - 
         (59224*NC*NL)/3 - 15312*lm*NC*NL - (3133656042509*NC*NH)/
          669278610 - 15312*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-22277392972639*CA + 44451561893612*CF + 
          1496880*(217352167*NM + 638*NL))*Log[x]^3)/93555 + 
       (1527031833783001027165*CF^2*NC*PolyGamma[2, 1])/3389154437772 + 
       (111547577131*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (32081650918218427*CF*NC*NH*PolyGamma[2, 1])/5083731656658 + 
       CA*CF*NC*(148596568685428817146022779924254346457834507/
          705637854656027489028886056843840000 + (3157*lm^2)/6 - 
         (4589922841968110371*Pi^2)/77059382400 + (1707532654729613275*Pi^3)/
          (298245590523936*Sqrt[3]) + (298121*Pi^4)/3240 + 
         lm*(1528757245/1047816 - (44*Pi^2)/9) - 
         (11056273084416194539253*Im[PolyLog[2, (-1)^(1/3)]])/
          (160754373292401504*Sqrt[3]) + (27350*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 + (341506530945922655*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1610894393262*Sqrt[3]) + (341506530945922655*Pi*Log[3]^2)/
          (77322930876576*Sqrt[3]) - (1527031833783001027165*PolyGamma[2, 1])/
          6778308875544 - (21628601510709269229848*Zeta[3])/65241222927111) + 
       (43258166433724819928047*CF^2*NC*Zeta[3])/65241222927111 + 
       (64602430855*CF*NM*NC*Zeta[3])/27 - (49400*CF*NC*NL*Zeta[3])/3 + 
       (389169910770214541*CF*NC*NH*Zeta[3])/2541865828329 + 
       CF*Log[x]*((5404061950389335516794363*NM*NC)/1270133812297350 - 
         (41845756*lm*NM*NC)/10395 - 572*lm^2*NM*NC - (80121979387*NC*NL)/
          2910600 - (41845756*lm*NC*NL)/10395 - 572*lm^2*NC*NL - 
         (300645302058091486034584539727*NC*NH)/717102290206201950864450 - 
         (41845756*lm*NC*NH)/10395 - 572*lm^2*NC*NH + 
         (7824689914*NM*NC*Pi^2)/9 - (8228*NC*NL*Pi^2)/3 + 
         (22279375360728376*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*(25020060963124322965070613128251949/
            101039577131964969016318800 - (42836746*lm)/1155 - 5148*lm^2 + 
           (8908328112841*Pi^2)/74844 + (341506530945922655*
             Im[PolyLog[2, (-1)^(1/3)]])/(2416341589893*Sqrt[3]) - 
           13728*Zeta[3]) + CA*NC*(-125070015280281203344218653303017663/
            1010395771319649690163188000 + (24706658*lm)/945 + 3146*lm^2 - 
           (8908152784303*Pi^2)/149688 - (341506530945922655*
             Im[PolyLog[2, (-1)^(1/3)]])/(4832683179786*Sqrt[3]) + 
           6864*Zeta[3])), (-1572626029641316579601753039339898021501870283*
         CF^2*NC)/307914700213539267939877552077312000 - 
       (2125815555989*CF^2*lm*NC)/1844156160 - (11625*CF^2*lm^2*NC)/16 + 
       (4803738905198801813848152057821759*CF*NM*NC)/
        170310356183381522524416000 - (1902499770989*CF*lm*NM*NC)/
        16597405440 - (3875*CF*lm^2*NM*NC)/48 + 
       (655923815373743123*CF*NC*NL)/52281827136000 - 
       (1902499770989*CF*lm*NC*NL)/16597405440 - (3875*CF*lm^2*NC*NL)/48 + 
       (1891964637749680668349123686652534277296003*CF*NC*NH)/
        4865452152594976977953883345616435200 - (1902499770989*CF*lm*NC*NH)/
        16597405440 - (3875*CF*lm^2*NC*NH)/48 + 
       (567256230398430117577*CF^2*NC*Pi^2)/294226732800 + 
       (361*CF^2*lm*NC*Pi^2)/72 - (937037751268447*CF*NM*NC*Pi^2)/8981280 + 
       (361*CF*lm*NM*NC*Pi^2)/648 - (2049708497*CF*NC*NL*Pi^2)/4490640 + 
       (361*CF*lm*NC*NL*Pi^2)/648 + (361*CF*lm*NC*NH*Pi^2)/648 - 
       (1695135480407061631*CF^2*NC*Pi^3)/(162679413013056*Sqrt[3]) - 
       (1953330823136320985*CF*NC*NH*Pi^3)/(40669853253264*Sqrt[3]) - 
       (2768557*CF^2*NC*Pi^4)/19440 + (146032758903647919255067*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1096052545175464800*Sqrt[3]) + 
       (3501368072296780277*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (101674633133160*Sqrt[3]) - (133991*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - (1695135480407061631*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4393348345260*Sqrt[3]) - 
       (55809452089609171*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31381059609*Sqrt[3]) - (1695135480407061631*CF^2*NC*Pi*Log[3]^2)/
        (210880720572480*Sqrt[3]) - (55809452089609171*CF*NC*NH*Pi*Log[3]^2)/
        (1506290861232*Sqrt[3]) - 
       (CF*NC*(-23*CA*(-1007716889645834374221893 + 6136516252980313200*lm) + 
          44*(23*CF*(-45805383102527692715909 + 228217546598441400*lm) + 
            315*(69*(2623148447338447297 + 26833338812280*lm)*NM + 
              7362064710*(330719 + 251492*lm)*NL + (569342796101999 + 
                1851500378047320*lm)*NH)))*Log[x]^2)/2003659531473600 + 
       (CF*NC*(-7676434908483589*CA + 616*(24920304849224*CF - 
            858565712610*NM + 31122135*NL))*Log[x]^3)/2245320 + 
       (2439015096470154687785933*CF^2*NC*PolyGamma[2, 1])/732057358558752 + 
       (223095526247*CF*NM*NC*PolyGamma[2, 1])/162 + 
       (596573236481573027*CF*NC*NH*PolyGamma[2, 1])/366028679279376 + 
       CA*CF*NC*(172988547147350472326659267544870743455920390753/
          67741234046978638946773061457008640000 + (42625*lm^2)/96 - 
         (567256185811233946087*Pi^2)/588453465600 + 
         (1695135480407061631*Pi^3)/(325358826026112*Sqrt[3]) + 
         (557177*Pi^4)/7776 + lm*(3607820310989/3017710080 - 
           (3971*Pi^2)/1296) - (146032758903647919255067*
           Im[PolyLog[2, (-1)^(1/3)]])/(2192105090350929600*Sqrt[3]) + 
         (133991*Im[PolyLog[2, (-1)^(1/3)]]^2)/18 + 
         (1695135480407061631*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (8786696690520*Sqrt[3]) + (1695135480407061631*Pi*Log[3]^2)/
          (421761441144960*Sqrt[3]) - (2439015096470154687785933*
           PolyGamma[2, 1])/1464114717117504 - (41566383788857984872854677*
           Zeta[3])/25622007549556320) + (41566482587912197988634697*CF^2*NC*
         Zeta[3])/12811003774778160 + (232642938350*CF*NM*NC*Zeta[3])/81 - 
       (373009*CF*NC*NL*Zeta[3])/27 + (29379317511885519467*CF*NC*NH*
         Zeta[3])/183014339639688 + CF*Log[x]*
        ((-471950069544474533237034233*NM*NC)/365798537941636800 - 
         (4906358899*lm*NM*NC)/1496880 - (1001*lm^2*NM*NC)/2 - 
         (86283323171279*NC*NL)/3772137600 - (4906358899*lm*NC*NL)/
          1496880 - (1001*lm^2*NC*NL)/2 - (91098976063558058781910615899889*
           NC*NH)/260308131344851308163795350 - (4906358899*lm*NC*NH)/
          1496880 - (1001*lm^2*NC*NH)/2 - (19078535477*NM*NC*Pi^2)/324 - 
         (745657*NC*NL*Pi^2)/324 + (55809452089609171*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(40671558254943623811213275731856846711/
            4408999729394835011621184000 - (5031223639*lm)/166320 - 
           (9009*lm^2)/2 + (348922609110193*Pi^2)/204120 + 
           (1695135480407061631*Im[PolyLog[2, (-1)^(1/3)]])/
            (13180045035780*Sqrt[3]) - 12012*Zeta[3]) + 
         CA*NC*(-223692548109485036442275241952797332897/
            48498997023343185127833024000 + (5859871459*lm)/272160 + 
           (11011*lm^2)/4 - (348922372568293*Pi^2)/408240 - 
           (1695135480407061631*Im[PolyLog[2, (-1)^(1/3)]])/
            (26360090071560*Sqrt[3]) + 6006*Zeta[3])), 
      (-182498418343086472981524099939718380179256486571*CF^2*NC)/
        58063914897410261954376909820293120000 - (840462271157*CF^2*lm*NC)/
        461039040 - (4381*CF^2*lm^2*NC)/4 - 
       (347454979712611156014928515052583819*CF*NM*NC)/
        14192529681948460210368000 - (756303436397*CF*lm*NM*NC)/4149351360 - 
       (4381*CF*lm^2*NM*NC)/36 + (6473293066293724973*CF*NC*NL)/
        287550049248000 - (756303436397*CF*lm*NC*NL)/4149351360 - 
       (4381*CF*lm^2*NC*NL)/36 + 
       (28793550535927393495603235242810675503923471*CF*NC*NH)/
        43403957892418425679195001731548000000 - (756303436397*CF*lm*NC*NH)/
        4149351360 - (4381*CF*lm^2*NC*NH)/36 + 
       (12564213198491502794773*CF^2*NC*Pi^2)/14672106408960 + 
       (169*CF^2*lm*NC*Pi^2)/18 + (1426894404030923*CF*NM*NC*Pi^2)/160380 + 
       (169*CF*lm*NM*NC*Pi^2)/162 - (1743238471*CF*NC*NL*Pi^2)/2245320 + 
       (169*CF*lm*NC*NL*Pi^2)/162 + (169*CF*lm*NC*NH*Pi^2)/162 - 
       (363258446934803033539*CF^2*NC*Pi^3)/(21473682517723392*Sqrt[3]) - 
       (1315841165902381475*CF*NC*NH*Pi^3)/(15251194969974*Sqrt[3]) - 
       (1318109*CF^2*NC*Pi^4)/5184 + (57776227926621381652417871*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(289357871926322707200*Sqrt[3]) + 
       (588794488168712010169*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2935855031719995*Sqrt[3]) - 
       (898313*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (363258446934803033539*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (579921981574320*Sqrt[3]) - (300763695063401480*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(94143178827*Sqrt[3]) - 
       (363258446934803033539*CF^2*NC*Pi*Log[3]^2)/(27836255115567360*
         Sqrt[3]) - (37595461882925185*CF*NC*NH*Pi*Log[3]^2)/
        (564859072962*Sqrt[3]) - 
       (CF*NC*(-161*CA*(-85252072615978950790879 + 2096644943871878400*lm) + 
          6*(23*CF*(-198921954723183463581451 + 4002685801937222400*lm) + 
            2464*(115*(-167762747400395804971 + 36099258675480*lm)*NM + 
              34*(853002150*(183977 + 143142*lm)*NL + (39064979066717 + 
                  122100433755300*lm)*NH))))*Log[x]^2)/2671546041964800 + 
       (CF*NC*(-3901801301810567*CA + 10*(779960623488355*CF + 
            11088*(648390289881*NM + 310141*NL)))*Log[x]^3)/2245320 + 
       (4326807923359548251963455*CF^2*NC*PolyGamma[2, 1])/1098086037838128 + 
       (1529167908442*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (653124443998203106*CF*NC*NH*PolyGamma[2, 1])/68630377364883 + 
       CA*CF*NC*(10557681459721155667323151440059624804720203093/
          6718138913749947664142782954414080000 + (48191*lm^2)/72 - 
         (56851609055636434841*Pi^2)/132779243520 + 
         (363258446934803033539*Pi^3)/(42947365035446784*Sqrt[3]) + 
         (6633809*Pi^4)/51840 + lm*(1398970901837/754427520 - 
           (1859*Pi^2)/324) - (57776227926621381652417871*
           Im[PolyLog[2, (-1)^(1/3)]])/(578715743852645414400*Sqrt[3]) + 
         (898313*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 + 
         (363258446934803033539*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1159843963148640*Sqrt[3]) + (363258446934803033539*Pi*Log[3]^2)/
          (55672510231134720*Sqrt[3]) - (4326807923359548251963455*
           PolyGamma[2, 1])/2196172075676256 - (5194008386972365625658238699*
           Zeta[3])/1691052498270717120) + (5194026709883706290518802179*CF^2*
         NC*Zeta[3])/845526249135358560 + (1761568501646*CF*NM*NC*Zeta[3])/
        81 - (663208*CF*NC*NL*Zeta[3])/27 + (15451330333242990172*CF*NC*NH*
         Zeta[3])/68630377364883 + CF*Log[x]*
        ((661389508553815639192235261*NM*NC)/16627206270074400 - 
         (2085099991*lm*NM*NC)/374220 - (2366*lm^2*NM*NC)/3 - 
         (425343404963053*NC*NL)/10373378400 - (2085099991*lm*NC*NL)/
          374220 - (2366*lm^2*NC*NL)/3 - (21232882665646763376466704658102*
           NC*NH)/33777006662394200886305625 - (2085099991*lm*NC*NH)/
          374220 - (2366*lm^2*NC*NH)/3 + (24014462312*NM*NC*Pi^2)/3 - 
         (331435*NC*NL*Pi^2)/81 + (300763695063401480*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(282429536481*Sqrt[3]) + 
         CF*NC*(211299654676872078741732743194842749741/
            145496991070029555383499072000 - (2134289131*lm)/41580 - 
           7098*lm^2 + (15606256320015763*Pi^2)/17962560 + 
           (363258446934803033539*Im[PolyLog[2, (-1)^(1/3)]])/
            (1739765944722960*Sqrt[3]) - 18928*Zeta[3]) + 
         CA*NC*(-42257449789741436005476303586327856149/
            58198796428011822153399628800 + (2460726151*lm)/68040 + 
           (13013*lm^2)/3 - (15606194108093683*Pi^2)/35925120 - 
           (363258446934803033539*Im[PolyLog[2, (-1)^(1/3)]])/
            (3479531889445920*Sqrt[3]) + 9464*Zeta[3])), 
      (-69732723081427631002030775534747037649254900303362929*CF^2*NC)/
        1428626497392621106780005587162201812992000 - 
       (123490049114111*CF^2*lm*NC)/84998833920 - (14661*CF^2*lm^2*NC)/16 + 
       (62035694292303944106472408816044222733*CF*NM*NC)/
        25373462494080036545566156800 - (110509133446391*CF*lm*NM*NC)/
        764989505280 - (1629*CF*lm^2*NM*NC)/16 + 
       (1099969630754946348499*CF*NC*NL)/58315149987494400 - 
       (110509133446391*CF*lm*NC*NL)/764989505280 - (1629*CF*lm^2*NC*NL)/
        16 + (19184232001876379318469975607781250642556741351*CF*NC*NH)/
        33449983549090466723432948001112992000000 - 
       (110509133446391*CF*lm*NC*NH)/764989505280 - (1629*CF*lm^2*NC*NH)/
        16 + (17542396368607007977961603*CF^2*NC*Pi^2)/953686916582400 + 
       (1265*CF^2*lm*NC*Pi^2)/216 - (10537468106241581*CF*NM*NC*Pi^2)/
        6368544 + (1265*CF*lm*NM*NC*Pi^2)/1944 - (1982789191*CF*NC*NL*Pi^2)/
        3184272 + (1265*CF*lm*NC*NL*Pi^2)/1944 + (1265*CF*lm*NC*NH*Pi^2)/
        1944 - (471261664985335844977*CF^2*NC*Pi^3)/(31017541414489344*
         Sqrt[3]) - (2899295092355961355*CF*NC*NH*Pi^3)/
        (40669853253264*Sqrt[3]) - (1698941*CF^2*NC*Pi^4)/8640 + 
       (148234602157338289891818467*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (776213973897595833600*Sqrt[3]) + (532919592262655171867*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7828946751253320*Sqrt[3]) - 
       (724927*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (67323094997905120711*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (119666440642320*Sqrt[3]) - (82837002638741753*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(31381059609*Sqrt[3]) - 
       (67323094997905120711*CF^2*NC*Pi*Log[3]^2)/(5743989150831360*
         Sqrt[3]) - (82837002638741753*CF*NC*NH*Pi*Log[3]^2)/
        (1506290861232*Sqrt[3]) - 
       (CF*NC*(CA*(11499016393186124217431667719 - 10864238877392852952000*
             lm) + 6*(CF*(-3833006387527231802920900513 + 
              2962974239288959896000*lm) + 24024*
             (125*(114815110126697261167 + 109630156483848*lm)*NM + 
              3*(4833678850*(1238789 + 945020*lm)*NL + (1465935925222031 + 
                  4567923186827000*lm)*NH))))*Log[x]^2)/104190295636627200 + 
       (CF*NC*(-476103943049591394*CA + 13*(73245203121795781*CF - 
            23100*(235164327862*NM - 614263*NL)))*Log[x]^3)/14594580 + 
       (67746648036970958383202389*CF^2*NC*PolyGamma[2, 1])/
        2196172075676256 + (2928016428104*CF*NM*NC*PolyGamma[2, 1])/243 + 
       (2302816920616824385*CF*NC*NH*PolyGamma[2, 1])/1098086037838128 + 
       CA*CF*NC*(69732704165042500615227390516487705261634405054111947/
          2857252994785242213560011174324403625984000 + (17919*lm^2)/32 - 
         (114656184056279744683391*Pi^2)/12466495641600 + 
         (471261664985335844977*Pi^3)/(62035082828978688*Sqrt[3]) + 
         (15371429*Pi^4)/155520 + lm*(209636125818071/139089000960 - 
           (13915*Pi^2)/3888) - (148234602157338289891818467*
           Im[PolyLog[2, (-1)^(1/3)]])/(1552427947795191667200*Sqrt[3]) + 
         (724927*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 + 
         (67323094997905120711*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (239332881284640*Sqrt[3]) + (67323094997905120711*Pi*Log[3]^2)/
          (11487978301662720*Sqrt[3]) - (67746648036970958383202389*
           PolyGamma[2, 1])/4392344151352512 - 
         (319568313632135294960901529223*Zeta[3])/21983682477519322560) + 
       (319568435517880905821173450103*CF^2*NC*Zeta[3])/
        10991841238759661280 + (6443978631583*CF*NM*NC*Zeta[3])/243 - 
       (1646855*CF*NC*NL*Zeta[3])/81 + (127625128279971984265*CF*NC*NH*
         Zeta[3])/549043018919064 + CF*Log[x]*
        ((-325460060522388818105975743357*NM*NC)/23220891188535104064 - 
         (4761640649*lm*NM*NC)/1061424 - (1365*lm^2*NM*NC)/2 - 
         (10887479339067433*NC*NL)/323649406080 - (4761640649*lm*NC*NL)/
          1061424 - (1365*lm^2*NC*NL)/2 - 
         (54066031734302238433042269862948223*NC*NH)/
          104123252537940523265518140000 - (4761640649*lm*NC*NH)/1061424 - 
         (1365*lm^2*NC*NH)/2 - (1175818198405*NM*NC*Pi^2)/972 - 
         (3292445*NC*NL*Pi^2)/972 + (82837002638741753*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(4886264939341981489992592305855600065317921/
            55587933754921847354017951008000 - (4882377629*lm)/117936 - 
           (12285*lm^2)/2 + (3808820938249050821*Pi^2)/233513280 + 
           (67323094997905120711*Im[PolyLog[2, (-1)^(1/3)]])/
            (358999321926960*Sqrt[3]) - 16380*Zeta[3]) + 
         CA*NC*(-305391354592183966734448312047953145928891/
            6948491719365230919252243876000 + (62519953459*lm)/2122848 + 
           (15015*lm^2)/4 - (3808820543555031101*Pi^2)/467026560 - 
           (67323094997905120711*Im[PolyLog[2, (-1)^(1/3)]])/
            (717998643853920*Sqrt[3]) + 8190*Zeta[3])), 
      (-27694389153199087440898689102074685693194443587960961*CF^2*NC)/
        1215533049252125101356937526892209525760000 - 
       (904258406153*CF^2*lm*NC)/397528560 - (2737*CF^2*lm^2*NC)/2 - 
       (9769527136411687050372783552515137886257*CF*NM*NC)/
        43170127160066728844886864000 - (813588767093*CF*lm*NM*NC)/
        3577757040 - (2737*CF*lm^2*NM*NC)/18 + 
       (230900397752092903949*CF*NC*NL)/6942279760416000 - 
       (813588767093*CF*lm*NC*NL)/3577757040 - (2737*CF*lm^2*NC*NL)/18 + 
       (108621235814381939100164481724784032211346186797*CF*NC*NH)/
        112893694478180325191586199503756348000000 - 
       (813588767093*CF*lm*NC*NH)/3577757040 - (2737*CF*lm^2*NC*NH)/18 + 
       (8307116523722895964957*CF^2*NC*Pi^2)/1419176959200 + 
       (98*CF^2*lm*NC*Pi^2)/9 + (120357178846993481*CF*NM*NC*Pi^2)/1459458 + 
       (98*CF*lm*NM*NC*Pi^2)/81 - (2180635583*CF*NC*NL*Pi^2)/2084940 + 
       (98*CF*lm*NC*NL*Pi^2)/81 + (98*CF*lm*NC*NH*Pi^2)/81 - 
       (3811322086069369057207*CF^2*NC*Pi^3)/(157026303410852304*Sqrt[3]) - 
       (34499362350675597655*CF*NC*NH*Pi^3)/(274521509459532*Sqrt[3]) - 
       (1118383*CF^2*NC*Pi^4)/3240 + (2221087591302098639377574479*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7859166485713157815200*Sqrt[3]) + 
       (8225598928021324412224*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (26422695285479955*Sqrt[3]) - 
       (300398*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (544474583724195579601*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (605811355751745*Sqrt[3]) - (3942784268648639732*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(847288609443*Sqrt[3]) - 
       (544474583724195579601*CF^2*NC*Pi*Log[3]^2)/(29078945076083760*
         Sqrt[3]) - (985696067162159933*CF*NC*NH*Pi*Log[3]^2)/
        (10167463313316*Sqrt[3]) - 
       (CF*NC*(CA*(3630163868160817208512013 - 19007225537332032000*lm) + 
          17*CF*(-427078316460873326546113 + 1829572511614848000*lm) + 
          1144*(5*(-17882668327603381853737 + 604171186819200*lm)*NM + 
            1015072558500*(3815 + 2976*lm)*NL + 2*(502442877056009 + 
              1510427967048000*lm)*NH))*Log[x]^2)/103363388528400 + 
       (CF*NC*(-12708604943337401*CA + 25414320615587446*CF + 
          514800*(599975484789*NM + 45136*NL))*Log[x]^3)/1042470 + 
       (170126086337883253862137873*CF^2*NC*PolyGamma[2, 1])/
        4941387170271576 + (13971960697639*CF*NM*NC*PolyGamma[2, 1])/81 - 
       (17172685645786621825*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 + 
       CA*CF*NC*(55388697380581432884222586234557760091271018603957329/
          4862132197008500405427750107568838103040000 + (30107*lm^2)/36 - 
         (9493846295809546869643*Pi^2)/3243833049600 + 
         (3811322086069369057207*Pi^3)/(314052606821704608*Sqrt[3]) + 
         (74977*Pi^4)/432 + lm*(1505975101733/650501280 - (539*Pi^2)/81) - 
         (2221087591302098639377574479*Im[PolyLog[2, (-1)^(1/3)]])/
          (15718332971426315630400*Sqrt[3]) + 
         (150199*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (544474583724195579601*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1211622711503490*Sqrt[3]) + (544474583724195579601*Pi*Log[3]^2)/
          (58157890152167520*Sqrt[3]) - (170126086337883253862137873*
           PolyGamma[2, 1])/9882774340543152 - (50052276544785237780029678531*
           Zeta[3])/1766545913372088420) + (100104607804573506043481595817*
         CF^2*NC*Zeta[3])/1766545913372088420 + 
       (15944431141928*CF*NM*NC*Zeta[3])/81 - (960442*CF*NC*NL*Zeta[3])/
        27 + (198894074235218970923*CF*NC*NH*Zeta[3])/617673396283947 + 
       CF*Log[x]*((7186156971187284010084977324851*NM*NC)/
          19350742657112586720 - (2614989503*lm*NM*NC)/347490 - 
         (3185*lm^2*NM*NC)/3 - (1142525397295339*NC*NL)/19264845600 - 
         (2614989503*lm*NC*NL)/347490 - (3185*lm^2*NC*NL)/3 - 
         (2573235827508343257623558975125672223*NC*NH)/
          2811327818524394128168989780000 - (2614989503*lm*NC*NH)/347490 - 
         (3185*lm^2*NC*NH)/3 + 74071051465*NM*NC*Pi^2 - 
         (480025*NC*NL*Pi^2)/81 + (3942784268648639732*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2541865828329*Sqrt[3]) + 
         CF*NC*(230837451487028961138304488906736475048339/
            37837164992845963325003815392000 - (1338237964*lm)/19305 - 
           9555*lm^2 + (12708444368032753*Pi^2)/2084940 + 
           (544474583724195579601*Im[PolyLog[2, (-1)^(1/3)]])/
            (1817434067255235*Sqrt[3]) - 25480*Zeta[3]) + 
         CA*NC*(-8393926461066280602164757168165576639469/
            2751793817661524605454822937600 + (3084522203*lm)/63180 + 
           (35035*lm^2)/6 - (25416867972034361*Pi^2)/8339760 - 
           (544474583724195579601*Im[PolyLog[2, (-1)^(1/3)]])/
            (3634868134510470*Sqrt[3]) + 12740*Zeta[3])), 
      (-155619828557344187663031964785368589350371656959386965473*CF^2*NC)/
        333804075833083585526482074692706769766400000 - 
       (561188934864611*CF^2*lm*NC)/311662391040 - (18183*CF^2*lm^2*NC)/16 + 
       (42844434909021519067745056837196475011651*CF*NM*NC)/
        1065929065680659971478688000000 - (502158130111691*CF*lm*NM*NC)/
        2804961519360 - (6061*CF*lm^2*NM*NC)/48 + 
       (2569726128106895663*CF*NC*NL)/93453766005600 - 
       (502158130111691*CF*lm*NC*NL)/2804961519360 - (6061*CF*lm^2*NC*NL)/
        48 + (2230069542282857726225951626942453454251052624413*CF*NC*NH)/
        2709448667476327804598068788090152352000000 - 
       (502158130111691*CF*lm*NC*NH)/2804961519360 - (6061*CF*lm^2*NC*NH)/
        48 + (501503140487875968856467239*CF^2*NC*Pi^2)/2861060749747200 + 
       (487*CF^2*lm*NC*Pi^2)/72 - (69802885109058659*CF*NM*NC*Pi^2)/
        3335904 + (487*CF*lm*NM*NC*Pi^2)/648 - (48485527637*CF*NC*NL*Pi^2)/
        58378320 + (487*CF*lm*NC*NL*Pi^2)/648 + (487*CF*lm*NC*NH*Pi^2)/
        648 - (162482302227318109548775*CF^2*NC*Pi^3)/(7537262563720910592*
         Sqrt[3]) - (338963575610361655975*CF*NC*NH*Pi^3)/
        (3294258113514384*Sqrt[3]) - (20604989*CF^2*NC*Pi^4)/77760 + 
       (70586164757467683936977330899*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (264067993919962102590720*Sqrt[3]) + (76202348416004300704451*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(634144686851518920*Sqrt[3]) - 
       (959815*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (32496460445463621909755*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(40710523106517264*Sqrt[3]) - 
       (9684673588867475885*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2541865828329*Sqrt[3]) - (32496460445463621909755*CF^2*NC*Pi*
         Log[3]^2)/(1954105109112828672*Sqrt[3]) - 
       (9684673588867475885*CF*NC*NH*Pi*Log[3]^2)/(122009559759792*
         Sqrt[3]) - (CF*NC*(-35*CA*(-3130811459378178435876764953 + 
            446507319005773945920*lm) + 
          10*CF*(-21915681023754040186507873339 + 2557269190669432599360*
             lm) + 144144*((181498016870319071405177 + 19712303057046600*lm)*
             NM + 3*(33835751950*(253879 + 194196*lm)*NL + 
              3*(729304112913491 + 2190255895227400*lm)*NH)))*Log[x]^2)/
        104190295636627200 + (CF*NC*(-4539369081936316645*CA + 
          9078707074705656143*CF - 180180*(5361967979262*NM - 1472653*NL))*
         Log[x]^3)/14594580 + (16922422691716507672280465761*CF^2*NC*
         PolyGamma[2, 1])/59296646043258912 + 
       (15169278743371*CF*NM*NC*PolyGamma[2, 1])/144 + 
       (39119357578667736863*CF*NC*NH*PolyGamma[2, 1])/14824161510814728 + 
       CA*CF*NC*(505764422852758935364440942664947293542230030517754305571/
          2169726492915043305922133485502594003481600000 + (66671*lm^2)/96 - 
         (501503139620515102586789459*Pi^2)/5722121499494400 + 
         (162482302227318109548775*Pi^3)/(15074525127441821184*Sqrt[3]) + 
         (20698493*Pi^4)/155520 + lm*(952938820952171/509993003520 - 
           (5357*Pi^2)/1296) - (70586164757467683936977330899*
           Im[PolyLog[2, (-1)^(1/3)]])/(528135987839924205181440*Sqrt[3]) + 
         (959815*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 + 
         (32496460445463621909755*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (81421046213034528*Sqrt[3]) + (32496460445463621909755*Pi*Log[3]^2)/
          (3908210218225657344*Sqrt[3]) - (16922422691716507672280465761*
           PolyGamma[2, 1])/118593292086517824 - 
         (15417141962955652450148706305317*Zeta[3])/118711885378604341824) + 
       (15417142887332494764332395760341*CF^2*NC*Zeta[3])/
        59355942689302170912 + (52657171942393*CF*NM*NC*Zeta[3])/216 - 
       (785710*CF*NC*NL*Zeta[3])/27 + (2431457823891308455451*CF*NC*NH*
         Zeta[3])/7412080755407364 + CF*Log[x]*
        ((-357399366185434250043022429600967*NM*NC)/2418842832139073340000 - 
         (116764804249*lm*NM*NC)/19459440 - 910*lm^2*NM*NC - 
         (1996650727005793*NC*NL)/41493513600 - (116764804249*lm*NC*NL)/
          19459440 - 910*lm^2*NC*NL - 
         (12637512540123893070838670974511189173*NC*NH)/
          16867966911146364769013938680000 - (116764804249*lm*NC*NH)/
          19459440 - 910*lm^2*NC*NH - (5361966194843*NM*NC*Pi^2)/324 - 
         (1570933*NC*NL*Pi^2)/324 + (9684673588867475885*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(4102748772283985161767618825241316925958211063/
            4911951964525821420736858943616000 - (119716152649*lm)/2162160 - 
           8190*lm^2 + (7262987475050784385*Pi^2)/46702656 + 
           (32496460445463621909755*Im[PolyLog[2, (-1)^(1/3)]])/
            (122131569319551792*Sqrt[3]) - 21840*Zeta[3]) + 
         CA*NC*(-45130232173070139158401558925705547473478717937/
            108062943219568071256210896759552000 + (139302373849*lm)/
            3538080 + 5005*lm^2 - (7262987362892698345*Pi^2)/93405312 - 
           (32496460445463621909755*Im[PolyLog[2, (-1)^(1/3)]])/
            (244263138639103584*Sqrt[3]) + 10920*Zeta[3])), 
      (-207298096148851903867746157766790397229735304485024993531*CF^2*NC)/
        1314985753281844427831596051819753941504000000 - 
       (4839670905865*CF^2*lm*NC)/1731457728 - (6735*CF^2*lm^2*NC)/4 - 
       (503426565064322854907579967894373050456077*CF*NM*NC)/
        239834039778148493582704800000 - (4353780580945*CF*lm*NM*NC)/
        15583119552 - (2245*CF*lm^2*NM*NC)/12 + 
       (3353137624651224326641*CF*NC*NL)/70194162021984000 - 
       (4353780580945*CF*lm*NC*NL)/15583119552 - (2245*CF*lm^2*NC*NL)/12 + 
       (4496747390290817806846615674542086060378156214717317*CF*NC*NH)/
        3304037177554007941317114983636536285646400000 - 
       (4353780580945*CF*lm*NC*NH)/15583119552 - (2245*CF*lm^2*NC*NH)/12 + 
       (26512397292395285528685115*CF^2*NC*Pi^2)/724802056602624 + 
       (25*CF^2*lm*NC*Pi^2)/2 + (82819149380662505*CF*NM*NC*Pi^2)/108108 + 
       (25*CF*lm*NM*NC*Pi^2)/18 - (895161455*CF*NC*NL*Pi^2)/648648 + 
       (25*CF*lm*NC*NL*Pi^2)/18 + (25*CF*lm*NC*NH*Pi^2)/18 - 
       (85325596236678263190695*CF^2*NC*Pi^3)/(2512420854573636864*Sqrt[3]) - 
       (146975621134924049125*CF*NC*NH*Pi^3)/(823564528378596*Sqrt[3]) - 
       (2376965*CF^2*NC*Pi^4)/5184 + (34440613447508508739754965691*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(88022664639987367530240*Sqrt[3]) + 
       (13749717990987687157103*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29442431889534807*Sqrt[3]) - 
       (525275*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (17065119247335652638139*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13570174368839088*Sqrt[3]) - 
       (16797213843991319900*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2541865828329*Sqrt[3]) - (17065119247335652638139*CF^2*NC*Pi*
         Log[3]^2)/(651368369704276224*Sqrt[3]) - 
       (4199303460997829975*CF*NC*NH*Pi*Log[3]^2)/(30502389939948*Sqrt[3]) + 
       CF*((7622293212232046694138953131*CF*NC)/17365049272771200 - 
         426594*CF*lm*NC + CA*(-7622292316748630618513851531/
            34730098545542400 + (782089*lm)/3)*NC + 
         (9228951812529689022047*NM*NC)/1003917915 - (142198*lm*NM*NC)/3 - 
         60627*NC*NL - (142198*lm*NC*NL)/3 - (57560326287623*NC*NH)/
          3528923580 - (142198*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-155526520323761645*CA + 22*(14138404283183935*CF + 
            39312*(6186662398167*NM + 71099*NL)))*Log[x]^3)/1945944 + 
       (8910834833631139521868024087*CF^2*NC*PolyGamma[2, 1])/
        29648323021629456 + (85088429986967*CF*NM*NC*PolyGamma[2, 1])/54 - 
       (24412133681407659527*CF*NC*NH*PolyGamma[2, 1])/1235346792567894 + 
       CA*CF*NC*(2280278384925850060651766152603206486127164232825390921591/
          28929686572200577412295113140034586713088000000 + (24695*lm^2)/24 - 
         (1395389294460637237041685*Pi^2)/76294953326592 + 
         (85325596236678263190695*Pi^3)/(5024841709147273728*Sqrt[3]) + 
         (2388485*Pi^4)/10368 + lm*(8064215789425/2833294464 - 
           (275*Pi^2)/36) - (34440613447508508739754965691*
           Im[PolyLog[2, (-1)^(1/3)]])/(176045329279974735060480*Sqrt[3]) + 
         (525275*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (17065119247335652638139*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (27140348737678176*Sqrt[3]) + (17065119247335652638139*Pi*Log[3]^2)/
          (1302736739408552448*Sqrt[3]) - (8910834833631139521868024087*
           PolyGamma[2, 1])/59296646043258912 - 
         (30935057679697544449981044260657*Zeta[3])/118711885378604341824) + 
       (30935060247313615751442725673569*CF^2*NC*Zeta[3])/
        59355942689302170912 + (47968464841127*CF*NM*NC*Zeta[3])/27 - 
       50216*CF*NC*NL*Zeta[3] + (277722121807111366693*CF*NC*NH*Zeta[3])/
        617673396283947 + CF*Log[x]*((186193334394138507616931508313487*NM*
           NC)/53752062936423852000 - (1075881995*lm*NM*NC)/108108 - 
         1400*lm^2*NM*NC - (16290421300292837*NC*NL)/194788994400 - 
         (1075881995*lm*NC*NL)/108108 - 1400*lm^2*NC*NL - 
         (921649125303446301895306258075900605233*NC*NH)/
          709298008613704638537036121494000 - (1075881995*lm*NC*NH)/108108 - 
         1400*lm^2*NC*NH + (6186662454335*NM*NC*Pi^2)/9 - 
         (75299*NC*NL*Pi^2)/9 + (16797213843991319900*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(-82959209678338258380302669731817628558057883/
            11256556585371674089188635079120000 - (1101107195*lm)/12012 - 
           12600*lm^2 + (622104379173811049*Pi^2)/15567552 + 
           (17065119247335652638139*Im[PolyLog[2, (-1)^(1/3)]])/
            (40710523106517264*Sqrt[3]) - 33600*Zeta[3]) + 
         CA*NC*(30167642074411213384972302609134821211610437/
            8186586607543035701228098239360000 + (1268510795*lm)/19656 + 
           7700*lm^2 - (622104270389943857*Pi^2)/31135104 - 
           (17065119247335652638139*Im[PolyLog[2, (-1)^(1/3)]])/
            (81421046213034528*Sqrt[3]) + 16800*Zeta[3])), 
      (-510760526513326808606285519175901930055094926446018129801871*CF^2*NC)/
        114867873154325822078230596291313800184320000000 - 
       (3427630945646837*CF^2*lm*NC)/1558311955200 - (22227*CF^2*lm^2*NC)/
        16 + (3874211696695876120474671621908045873247983*CF*NM*NC)/
        7511880343642116082568928000000 - (3066833030769437*CF*lm*NM*NC)/
        14024807596800 - (7409*CF*lm^2*NM*NC)/48 + 
       (1541314034365694470823*CF*NC*NL)/39484216137366000 - 
       (3066833030769437*CF*lm*NC*NL)/14024807596800 - 
       (7409*CF*lm^2*NC*NL)/48 + 
       (686019672773379481107365779498416803336136933812651411*CF*NC*NH)/
        594726691959721429437080697054576531416352000000 - 
       (3066833030769437*CF*lm*NC*NH)/14024807596800 - 
       (7409*CF*lm^2*NC*NH)/48 + (45324522638763459425687428597*CF^2*NC*
         Pi^2)/27180077122598400 + (557*CF^2*lm*NC*Pi^2)/72 - 
       (9340564957624487897*CF*NM*NC*Pi^2)/38918880 + 
       (557*CF*lm*NM*NC*Pi^2)/648 - (63423502003*CF*NC*NL*Pi^2)/58378320 + 
       (557*CF*lm*NC*NL*Pi^2)/648 + (557*CF*lm*NC*NH*Pi^2)/648 - 
       (506632536173849218056175*CF^2*NC*Pi^3)/(16958840768372048832*
         Sqrt[3]) - (4297766123802290374165*CF*NC*NH*Pi^3)/
        (29648323021629456*Sqrt[3]) - (679829*CF^2*NC*Pi^4)/1944 + 
       (155511663119382000550866225593*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (424394990228510522020800*Sqrt[3]) + (14630572898829676302173573*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(74194928361627713640*Sqrt[3]) - 
       (311878*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (14475215319252834801605*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13085525284237692*Sqrt[3]) - 
       (122793317822922582119*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (14475215319252834801605*CF^2*NC*Pi*Log[3]^2)/(628105213643409216*
         Sqrt[3]) - (122793317822922582119*CF*NC*NH*Pi*Log[3]^2)/
        (1098086037838128*Sqrt[3]) - 
       (CF*NC*(-493*CA*(-76651762605560727886290536741 + 
            1612532449794316050000*lm) + 
          4*(3944*CF*(-4790735189227043909813693366 + 82459045728118434375*
               lm) + 15015*(26999*(6708050825552162129623 + 89137343295000*
                 lm)*NM + 2037953367450*(1540263 + 1180900*lm)*NL + 
              (827573073484026871 + 2406619131621705000*lm)*NH)))*Log[x]^2)/
        3776898216827736000 + (CF*NC*(-86433816758177636483*CA + 
          20*(8643377037033775193*CF - 18018*(63850267365526*NM - 
              2066575*NL)))*Log[x]^3)/29189160 + 
       (1407974268569179165420608675731*CF^2*NC*PolyGamma[2, 1])/
        533669814389330208 + (397506606980401*CF*NM*NC*PolyGamma[2, 1])/
        432 + (434333712005766229615*CF*NC*NH*PolyGamma[2, 1])/
        133417453597332552 + CA*CF*NC*
        (510760523631288522542384370842734527598943497394440151590871/
          229735746308651644156461192582627600368640000000 + 
         (81499*lm^2)/96 - (2385501190927734834481743823*Pi^2)/
          2861060749747200 + (506632536173849218056175*Pi^3)/
          (33917681536744097664*Sqrt[3]) + (3412513*Pi^4)/19440 + 
         lm*(5822017108015037/2549965017600 - (6127*Pi^2)/1296) - 
         (155511663119382000550866225593*Im[PolyLog[2, (-1)^(1/3)]])/
          (848789980457021044041600*Sqrt[3]) + 
         (155939*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (14475215319252834801605*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (26171050568475384*Sqrt[3]) + (14475215319252834801605*Pi*Log[3]^2)/
          (1256210427286818432*Sqrt[3]) - (1407974268569179165420608675731*
           PolyGamma[2, 1])/1067339628778660416 - 
         (3092254217674684521315542342866343*Zeta[3])/
          2671017421018597691040) + (3092254246285011456545127673951643*CF^2*
         NC*Zeta[3])/1335508710509298845520 + 
       (482640360508441*CF*NM*NC*Zeta[3])/216 - (365942*CF*NC*NL*Zeta[3])/
        9 + (30199053579124554338083*CF*NC*NH*Zeta[3])/66708726798666276 + 
       CF*Log[x]*((-124621057312668438508767167868119*NM*NC)/
          81840546952073910000 - (153113689451*lm*NM*NC)/19459440 - 
         1190*lm^2*NM*NC - (471234335207973979*NC*NL)/7012403798400 - 
         (153113689451*lm*NC*NL)/19459440 - 1190*lm^2*NC*NL - 
         (134711714977761074465448733340807141195239*NC*NH)/
          127673641550466834936666501868920000 - (153113689451*lm*NC*NH)/
          19459440 - 1190*lm^2*NC*NH - (63850264694921*NM*NC*Pi^2)/324 - 
         (2195095*NC*NL*Pi^2)/324 + (122793317822922582119*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(5661732241981574999891424400220239295120521041191/
            715122418364788706842572110908800000 - (156973145051*lm)/
            2162160 - 10710*lm^2 + (86433811391042118401*Pi^2)/58378320 + 
           (14475215319252834801605*Im[PolyLog[2, (-1)^(1/3)]])/
            (39256575852713076*Sqrt[3]) - 28560*Zeta[3]) + 
         CA*NC*(-5661732165648982613006686569140499480107356626341/
            1430244836729577413685144221817600000 + (182585895851*lm)/
            3538080 + 6545*lm^2 - (86433811196341532321*Pi^2)/116756640 - 
           (14475215319252834801605*Im[PolyLog[2, (-1)^(1/3)]])/
            (78513151705426152*Sqrt[3]) + 14280*Zeta[3])), 
      (-368422483244372988542631891449097279694054166333382282322837*CF^2*NC)/
        366141345679413557874360025678562738087520000000 - 
       (20630202601189*CF^2*lm*NC)/6087156075 - 2044*CF^2*lm^2*NC - 
       (947482269489222728200618822223310197618019583*CF*NM*NC)/
        48566393055075069950497722000000 - (18556511431639*CF*lm*NM*NC)/
        54784404675 - (2044*CF*lm^2*NM*NC)/9 + 
       (1057400957310630506293*CF*NC*NL)/15793686454946400 - 
       (18556511431639*CF*lm*NC*NL)/54784404675 - (2044*CF*lm^2*NC*NL)/9 + 
       (1251394025353389229719489959746686715754969955817731907549*CF*NC*NH)/
        664406358006452291413502664223233354278420341200000 - 
       (18556511431639*CF*lm*NC*NH)/54784404675 - (2044*CF*lm^2*NC*NH)/9 + 
       (7611555120518842597144231*CF^2*NC*Pi^2)/40446543337200 + 
       (128*CF^2*lm*NC*Pi^2)/9 + (25996715578630821224*CF*NM*NC*Pi^2)/
        3648645 + (128*CF*lm*NM*NC*Pi^2)/81 - (6525212696*CF*NC*NL*Pi^2)/
        3648645 + (128*CF*lm*NC*NL*Pi^2)/81 + (128*CF*lm*NC*NH*Pi^2)/81 - 
       (295676378373515589631925*CF^2*NC*Pi^3)/(6359565288139518312*
         Sqrt[3]) - (1377953336283460235320*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (80689*CF^2*NC*Pi^4)/135 + 
       (591843206651785148874408093853*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1114036849349840120304600*Sqrt[3]) + 
       (18933975662533596092444608*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) - 
       (507824*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (118270551349406235852770*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68699007742247883*Sqrt[3]) - 
       (629921525158153250432*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (59135275674703117926385*CF^2*NC*Pi*Log[3]^2)/(1648776185813949192*
         Sqrt[3]) - (39370095322384578152*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) + CF*((170202703737204530499314696*CF*NC)/
          75369137468625 - (1773472*CF*lm*NC)/3 + 
         CA*(-6127297135311768037644766241/5426577897741000 + 
           (9754096*lm)/27)*NC + (3862591994749758611708989*NM*NC)/
          45176306175 - (1773472*lm*NM*NC)/27 - (6792112*NC*NL)/81 - 
         (1773472*lm*NC*NL)/27 - (17195470931801143*NC*NH)/738427259115 - 
         (1773472*lm*NC*NH)/27)*Log[x]^2 + 
       (4*CF*NC*(-419013570497854309*CA + 4*(209505381025437983*CF + 
            90090*(64698072271977*NM + 110842*NL)))*Log[x]^3)/3648645 + 
       (131141819952550521893868107767*CF^2*NC*PolyGamma[2, 1])/
        50031545098999707 + (388552908081550*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (1372883266259337586258*CF*NC*NH*PolyGamma[2, 1])/50031545098999707 + 
       CA*CF*NC*(23026403744965382927590593392782681561039961686770187473607/
          45767668209926694734295003209820342260940000000 + (11242*lm^2)/9 - 
         (15223110138493753786968917*Pi^2)/161786173348800 + 
         (295676378373515589631925*Pi^3)/(12719130576279036624*Sqrt[3]) + 
         (243091*Pi^4)/810 + lm*(34391971271839/9960800850 - (704*Pi^2)/81) - 
         (591843206651785148874408093853*Im[PolyLog[2, (-1)^(1/3)]])/
          (2228073698699680240609200*Sqrt[3]) + 
         (253912*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (59135275674703117926385*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (68699007742247883*Sqrt[3]) + (59135275674703117926385*Pi*Log[3]^2)/
          (3297552371627898384*Sqrt[3]) - (131141819952550521893868107767*
           PolyGamma[2, 1])/100063090197999414 - 
         (1197701413201619029315371168099707*Zeta[3])/
          500815766440987067070) + (1197701428025267991657495767459372*CF^2*
         NC*Zeta[3])/250407883220493533535 + 
       (144016481195732*CF*NM*NC*Zeta[3])/9 - (623968*CF*NC*NL*Zeta[3])/9 + 
       (30759190582215659377660*CF*NC*NH*Zeta[3])/50031545098999707 + 
       CF*Log[x]*((6507894074464032386653915333538987*NM*NC)/
          201570236011589445000 - (15716248552*lm*NM*NC)/1216215 - 
         (5440*lm^2*NM*NC)/3 - (103178658069713*NC*NL)/894439260 - 
         (15716248552*lm*NC*NL)/1216215 - (5440*lm^2*NC*NL)/3 - 
         (16602526165145910640385156873811893305174417*NC*NH)/
          9202077714749897128060238122202409000 - (15716248552*lm*NC*NH)/
          1216215 - (5440*lm^2*NC*NH)/3 + (57509397659872*NM*NC*Pi^2)/9 - 
         (935696*NC*NL*Pi^2)/81 + (629921525158153250432*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(-1418519444336492759694717373269200451831849960923/
            2279452708537764003060698603521800000 - (16083815752*lm)/135135 - 
           16320*lm^2 + (1676053175135858471*Pi^2)/7297290 + 
           (118270551349406235852770*Im[PolyLog[2, (-1)^(1/3)]])/
            (206097023226743649*Sqrt[3]) - 43520*Zeta[3]) + 
         CA*NC*(709259965649326863400825893245269789257332341249/
            2279452708537764003060698603521800000 + (9261562676*lm)/110565 + 
           (29920*lm^2)/3 - (1676053105080703301*Pi^2)/14594580 - 
           (59135275674703117926385*Im[PolyLog[2, (-1)^(1/3)]])/
            (206097023226743649*Sqrt[3]) + 21760*Zeta[3])), 
      (-691246655507399264911905530796842994541342064341380123051024305003*
         CF^2*NC)/16328816054446111566624487618330453246567360512000000 - 
       (1984549508742707*CF^2*lm*NC)/747989738496 - (26829*CF^2*lm^2*NC)/16 + 
       (1878005565075843002221618652157559324266148608422777*CF*NM*NC)/
        314890983640084664985724075620096000000 - 
       (1775509751512403*CF*lm*NM*NC)/6731907646464 - 
       (2981*CF*lm^2*NM*NC)/16 + (20527884987428216737741*CF*NC*NL)/
        379048474918713600 - (1775509751512403*CF*lm*NC*NL)/6731907646464 - 
       (2981*CF*lm^2*NC*NL)/16 + 
       (134650973380564917621753899665324947045749518100725753748401*CF*NC*
         NH)/85044013824825893300928341020573869347637803673600000 - 
       (1775509751512403*CF*lm*NC*NH)/6731907646464 - 
       (2981*CF*lm^2*NC*NH)/16 + (132423148141009569890556594719*CF^2*NC*
         Pi^2)/8363100653107200 + (1895*CF^2*lm*NC*Pi^2)/216 - 
       (271843159945343444*CF*NM*NC*Pi^2)/104247 + (1895*CF*lm*NM*NC*Pi^2)/
        1944 - (195758167277*CF*NC*NL*Pi^2)/140107968 + 
       (1895*CF*lm*NC*NL*Pi^2)/1944 + (1895*CF*lm*NC*NH*Pi^2)/1944 - 
       (8253686052905466163161365*CF^2*NC*Pi^3)/(203506089220464585984*
         Sqrt[3]) - (4445621841982299176975*CF*NC*NH*Pi^3)/
        (22236242266222092*Sqrt[3]) - (17621657*CF^2*NC*Pi^4)/38880 + 
       (35160994089091206038030293330259*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (71298358358389767699494400*Sqrt[3]) + 
       (13667503868775580228440611*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (44516957016976628184*Sqrt[3]) - 
       (265897*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (1650737210581093232632273*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1099184123875966128*
         Sqrt[3]) - (508071067655119905940*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (1650737210581093232632273*CF^2*NC*Pi*Log[3]^2)/(52760837946046374144*
         Sqrt[3]) - (127017766913779976485*CF*NC*NH*Pi*Log[3]^2)/
        (823564528378596*Sqrt[3]) + 
       CF*((114824111061224281575339483565217*CF*NC)/604303714692437760 - 
         (4257170*CF*lm*NC)/9 + CA*(-5467814808037652865521341580891/
            57552734732613120 + (23414435*lm)/81)*NC - 
         (11806938345782940614449129609*NM*NC)/377312509173600 - 
         (4257170*lm*NM*NC)/81 - (11083087*NC*NL)/162 - 
         (4257170*lm*NC*NL)/81 - (43496372564024570969*NC*NH)/
          2339337556876320 - (4257170*lm*NC*NH)/81)*Log[x]^2 + 
       (CF*NC*(-1642827348366337937969*CA + 4*(821413606685495258837*CF - 
            120120*(1063517441228267*NM - 4257170*NL)))*Log[x]^3)/
        58378320 + (39021268048221040142983880518919*CF^2*NC*PolyGamma[2, 1])/
        1601009443167990624 + (5203476120973537*CF*NM*NC*PolyGamma[2, 1])/
        648 + (3157912101651265517567*CF*NC*NH*PolyGamma[2, 1])/
        800504721583995312 + CA*CF*NC*
        (4838726584705570873997477221523814065001875928216298965602817132521/
          228603424762245561932742826656626345451943047168000000 + 
         (32791*lm^2)/32 - (132423148136484961462156879679*Pi^2)/
          16726201306214400 + (8253686052905466163161365*Pi^3)/
          (407012178440929171968*Sqrt[3]) + (5894099*Pi^4)/25920 + 
         lm*(3371813352180179/1223983208448 - (20845*Pi^2)/3888) - 
         (35160994089091206038030293330259*Im[PolyLog[2, (-1)^(1/3)]])/
          (142596716716779535398988800*Sqrt[3]) + 
         (265897*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (1650737210581093232632273*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2198368247751932256*Sqrt[3]) + (1650737210581093232632273*Pi*
           Log[3]^2)/(105521675892092748288*Sqrt[3]) - 
         (39021268048221040142983880518919*PolyGamma[2, 1])/
          3202018886335981248 - (165107171275567179531681531345896263*
           Zeta[3])/16026104526111586146240) + 
       (165107171507391384850509809817771823*CF^2*NC*Zeta[3])/
        8013052263055793073120 + (6621499507998703*CF*NM*NC*Zeta[3])/324 - 
       (3003985*CF*NC*NL*Zeta[3])/54 + (245192993601802667674727*CF*NC*NH*
         Zeta[3])/400252360791997656 + CF*Log[x]*
        ((-13553763675118510734094637817424108451749*NM*NC)/
          878794627030111013302080000 - (236804594699*lm*NM*NC)/23351328 - 
         1530*lm^2*NM*NC - (38665989880646501*NC*NL)/420744227904 - 
         (236804594699*lm*NC*NL)/23351328 - 1530*lm^2*NC*NL - 
         (77888717057648260922376201506135905424113339*NC*NH)/
          53539361249453946926895930892814016000 - (236804594699*lm*NC*NH)/
          23351328 - 1530*lm^2*NC*NH - (1063517435421997*NM*NC*Pi^2)/486 - 
         (2252515*NC*NL*Pi^2)/243 + (508071067655119905940*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(70664537720649658772266705713967576956313394539896689/
            943763558341050843851838781815056640000 - (242759183339*lm)/
            2594592 - 13770*lm^2 + (1095218222407174378523*Pi^2)/77837760 + 
           (1650737210581093232632273*Im[PolyLog[2, (-1)^(1/3)]])/
            (3297552371627898384*Sqrt[3]) - 36720*Zeta[3]) + 
         CA*NC*(-1837277977302688383921967191758466394415577116122672939/
            49075705033734643880295616654382945280000 + (282275998859*lm)/
            4245696 + 8415*lm^2 - (1095218222053809366523*Pi^2)/155675520 - 
           (1650737210581093232632273*Im[PolyLog[2, (-1)^(1/3)]])/
            (6595104743255796768*Sqrt[3]) + 18360*Zeta[3])), 
      (-9326194590821818956890157847633890478680043609689263894001752452393*
         CF^2*NC)/1714525685716841714495571199924697590889572853760000000 - 
       (6329113282776541*CF^2*lm*NC)/1558311955200 - (9809*CF^2*lm^2*NC)/4 - 
       (2293399492926649529128298660977108868105137891944539*CF*NM*NC)/
        12634514775682409397575348713152000000 - 
       (5692218200753341*CF*lm*NM*NC)/14024807596800 - 
       (9809*CF*lm^2*NM*NC)/36 + (33158175923826843794623*CF*NC*NL)/
        360998547541632000 - (5692218200753341*CF*lm*NC*NL)/14024807596800 - 
       (9809*CF*lm^2*NC*NL)/36 + 
       (81539115128970989436346461831672027243139520740705322671817*CF*NC*
         NH)/31891505184309709987848127882715201005364176377600000 - 
       (5692218200753341*CF*lm*NC*NH)/14024807596800 - 
       (9809*CF*lm^2*NC*NH)/36 + (32721763539309665720517720769*CF^2*NC*
         Pi^2)/72480205660262400 + (289*CF^2*lm*NC*Pi^2)/18 + 
       (1935360347584524811609*CF*NM*NC*Pi^2)/29189160 + 
       (289*CF*lm*NM*NC*Pi^2)/162 - (133171976849*CF*NC*NL*Pi^2)/58378320 + 
       (289*CF*lm*NC*NL*Pi^2)/162 + (289*CF*lm*NC*NH*Pi^2)/162 - 
       (76243602501296304315863605*CF^2*NC*Pi^3)/(1221036535322787515904*
         Sqrt[3]) - (5630652094230359539070*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) - (19864177*CF^2*NC*Pi^4)/25920 + 
       (60657626708790951932843114666147*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (85558030030067721239393280*Sqrt[3]) + 
       (80723817099838686133029863*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (83469294406831177845*Sqrt[3]) - 
       (2578985*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (15248720500259260863172721*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6595104743255796768*
         Sqrt[3]) - (2574012385933878646432*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (15248720500259260863172721*CF^2*NC*Pi*Log[3]^2)/
        (316565027676278244864*Sqrt[3]) - (160875774120867415402*CF*NC*NH*Pi*
         Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((54563517875613020092403279909911*CF*NC)/10071728578207296000 - 
         (2408968*CF*lm*NC)/3 + CA*(-54563516847026590491793069541791/
            20143457156414592000 + (13249324*lm)/27)*NC + 
         (8339119371078810933732480979*NM*NC)/10480903032600 - 
         (2408968*lm*NM*NC)/27 - (9210532*NC*NL)/81 - (2408968*lm*NC*NL)/
          27 - (211041387649064743*NC*NH)/6498159880212 - 
         (2408968*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-6752092927421042029*CA + 8*(1688019196100870419*CF + 
            45045*(2407683165307905*NM + 602242*NL)))*Log[x]^3)/3648645 + 
       (164527608422743811499676307373707*CF^2*NC*PolyGamma[2, 1])/
        7204542494255957808 + (262805251721869*CF*NM*NC*PolyGamma[2, 1])/2 - 
       (33618565325553659015287*CF*NC*NH*PolyGamma[2, 1])/
        900567811781994726 + CA*CF*NC*
        (717399572601820218513419637471574175444750003189511008384842322761/
          263773182417975648383934030757645783213780439040000000 + 
         (107899*lm^2)/72 - (1924809612972950170410723937*Pi^2)/
          8527083018854400 + (76243602501296304315863605*Pi^3)/
          (2442073070645575031808*Sqrt[3]) + (19938161*Pi^4)/51840 + 
         lm*(10555780645294141/2549965017600 - (3179*Pi^2)/324) - 
         (60657626708790951932843114666147*Im[PolyLog[2, (-1)^(1/3)]])/
          (171116060060135442478786560*Sqrt[3]) + 
         (2578985*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 + 
         (15248720500259260863172721*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (13190209486511593536*Sqrt[3]) + (15248720500259260863172721*Pi*
           Log[3]^2)/(633130055352556489728*Sqrt[3]) - 
         (164527608422743811499676307373707*PolyGamma[2, 1])/
          14409084988511915616 - (1264153564979393598586714673095219457*
           Zeta[3])/57693976294001710126464) + 
       (1264153567274474399056176202353488993*CF^2*NC*Zeta[3])/
        28846988147000855063232 + (3885497593645513*CF*NM*NC*Zeta[3])/27 - 
       (844798*CF*NC*NL*Zeta[3])/9 + (371593544831440302161129*CF*NC*NH*
         Zeta[3])/450283905890997363 + CF*Log[x]*
        ((2446884733101469942443134941061715305833*NM*NC)/
          8136987287315842715760000 - (160657835249*lm*NM*NC)/9729720 - 
         2312*lm^2*NM*NC - (273577471125809453*NC*NL)/1753100949600 - 
         (160657835249*lm*NC*NL)/9729720 - 2312*lm^2*NC*NL - 
         (49325465831068969098949720846150229628233603*NC*NH)/
          20077260468545230097585974084805256000 - (160657835249*lm*NC*NH)/
          9729720 - 2312*lm^2*NC*NH + (535040703525358*NM*NC*Pi^2)/9 - 
         (1266908*NC*NL*Pi^2)/81 + (2574012385933878646432*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(-7777675448037144148769737460720071430030990612884151411/
            736135575506019658204434249815744179200000 - (164407020689*lm)/
            1081080 - 20808*lm^2 + (86426770210050916213*Pi^2)/93405312 + 
           (15248720500259260863172721*Im[PolyLog[2, (-1)^(1/3)]])/
            (19785314229767390304*Sqrt[3]) - 55488*Zeta[3]) + 
         CA*NC*(7777675653980217518452082502634506832614971983652562611/
            1472271151012039316408868499631488358400000 + (189287978609*lm)/
            1769040 + 12716*lm^2 - (86426769001011356485*Pi^2)/186810624 - 
           (15248720500259260863172721*Im[PolyLog[2, (-1)^(1/3)]])/
            (39570628459534780608*Sqrt[3]) + 27744*Zeta[3])), 
      (-805989907097946424481686755489977851769922234102297550922473484456797\
3801*CF^2*NC)/20038070537405476979564735711267615095690419301573632000000 - 
       (1900433576766934057*CF^2*lm*NC)/600469540070400 - 
       (32025*CF^2*lm^2*NC)/16 + 
       (105931321753513946010305701109203566163384223591793382163*CF*NM*NC)/
        1626025664227772124128882362378368522240000 - 
       (1700120691134074057*CF*lm*NM*NC)/5404225860633600 - 
       (10675*CF*lm^2*NM*NC)/48 + (827623124863797271007*CF*NC*NL)/
        11239881516864000 - (1700120691134074057*CF*lm*NC*NL)/
        5404225860633600 - (10675*CF*lm^2*NC*NL)/48 + 
       (25124656146202458239669672103083893792808787975477175333999*CF*NC*
         NH)/11775324991129739072436231833617920371211388200960000 - 
       (1700120691134074057*CF*lm*NC*NH)/5404225860633600 - 
       (10675*CF*lm^2*NC*NH)/48 + (14222687228881362544219293749149*CF^2*NC*
         Pi^2)/94781807401881600 + (79*CF^2*lm*NC*Pi^2)/8 - 
       (679295428394715990937*CF*NM*NC*Pi^2)/24810786 + 
       (79*CF*lm*NM*NC*Pi^2)/72 - (2342380261099*CF*NC*NL*Pi^2)/
        1323241920 + (79*CF*lm*NC*NL*Pi^2)/72 + (79*CF*lm*NC*NH*Pi^2)/72 - 
       (259021733942062214988104095*CF^2*NC*Pi^3)/(4790220253958627947008*
         Sqrt[3]) - (54158064388605540152125*CF*NC*NH*Pi^3)/
        (200126180395998828*Sqrt[3]) - (14985581*CF^2*NC*Pi^4)/25920 + 
       (18627401265512753231990903480031797*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(28530312321564890120982297600*
         Sqrt[3]) + (183931440546488650323170329*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(400652613152789653656*Sqrt[3]) - 
       (670423*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (51804346788412442997620819*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(25873103223541971936*
         Sqrt[3]) - (6189493072983490303100*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(617673396283947*Sqrt[3]) - 
       (51804346788412442997620819*CF^2*NC*Pi*Log[3]^2)/
        (1241908954730014652928*Sqrt[3]) - (1547373268245872575775*CF*NC*NH*
         Pi*Log[3]^2)/(7412080755407364*Sqrt[3]) + 
       CF*((8020431915820730641402982041437061*CF*NC)/4454098708292513280 - 
         637398*CF*lm*NC + CA*(-5734608819149164845454397939370762331/
            6369361152858293990400 + 389521*lm)*NC - 
         (51239047680474929130728334607*NM*NC)/155955837125088 - 
         70822*lm*NM*NC - (14908337*NC*NL)/162 - 70822*lm*NC*NL - 
         (6678721489571958023*NC*NH)/259926395208480 - 70822*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-88299489318892636889349*CA + 
          884*(199772597805831645961*CF - 9240*(3775063992335219*NM - 
              1912194*NL)))*Log[x]^3)/330810480 + 
       (9726616942844108556604320985622023*CF^2*NC*PolyGamma[2, 1])/
        43227254965535746848 + (5040613022753489*CF*NM*NC*PolyGamma[2, 1])/
        72 + (101647031311154377808917*CF*NC*NH*PolyGamma[2, 1])/
        21613627482767873424 + CA*CF*NC*(104778687911153194829532112300961256\
822163249128105315477151852824906289513/
          520989833972542401468683128492957992487950901840914432000000 + 
         (117425*lm^2)/96 - (748562485727103763314932731711*Pi^2)/
          9977032358092800 + (259021733942062214988104095*Pi^3)/
          (9580440507917255894016*Sqrt[3]) + (3006217*Pi^4)/10368 + 
         lm*(3229782726875914057/982586520115200 - (869*Pi^2)/144) - 
         (18627401265512753231990903480031797*Im[PolyLog[2, (-1)^(1/3)]])/
          (57060624643129780241964595200*Sqrt[3]) + 
         (670423*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (51804346788412442997620819*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (51746206447083943872*Sqrt[3]) + (51804346788412442997620819*Pi*
           Log[3]^2)/(2483817909460029305856*Sqrt[3]) - 
         (9726616942844108556604320985622023*PolyGamma[2, 1])/
          86454509931071493696 - (103608305667477121907330706737149551071*
           Zeta[3])/1131689534997725852480640) + 
       (103608305689223433989628349781281368191*CF^2*NC*Zeta[3])/
        565844767498862926240320 + (20155257784343681*CF*NM*NC*Zeta[3])/
        108 - (448267*CF*NC*NL*Zeta[3])/6 + (8804380141033050491947357*CF*NC*
         NH*Zeta[3])/10806813741383936712 + 
       CF*Log[x]*((-1735393988957721552564435647435971477536013*NM*NC)/
          11260288487679155783777318400 - (2838953508269*lm*NM*NC)/
          220540320 - 1938*lm^2*NM*NC - (3697219386251681*NC*NL)/
          29967537600 - (2838953508269*lm*NC*NL)/220540320 - 
         1938*lm^2*NC*NL - (2086923432280672369737129017163804985925862251*
           NC*NH)/1060079352739188149152539431677717516800 - 
         (2838953508269*lm*NC*NH)/220540320 - 1938*lm^2*NC*NH - 
         (3775063989604781*NM*NC*Pi^2)/162 - (37349*NC*NL*Pi^2)/3 + 
         (6189493072983490303100*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1853020188851841*Sqrt[3]) + 
         CF*NC*(392232443883718793671531109359041417829688060083211924302181/
            555057549094238914896269646426452891796480000 - 
           (2910188031629*lm)/24504480 - 17442*lm^2 + 
           (27169073601888877373783*Pi^2)/203575680 + 
           (51804346788412442997620819*Im[PolyLog[2, (-1)^(1/3)]])/
            (77619309670625915808*Sqrt[3]) - 46512*Zeta[3]) + 
         CA*NC*(-509902176918453515955684402316499399979999885709980734581406\
3/14431496276450211787303010807087775186708480000 + (3382926232109*lm)/
            40098240 + 10659*lm^2 - (27169073600653029425063*Pi^2)/
            407151360 - (51804346788412442997620819*Im[PolyLog[2, (-1)^
                (1/3)]])/(155238619341251831616*Sqrt[3]) + 23256*Zeta[3])), 
      (-794468114960835500374434293826717992442820190801654273967874205627868\
007*CF^2*NC)/46516949461834142988275279329728392186424187664367360000000 - 
       (6695687342468381*CF^2*lm*NC)/1389975787200 - (5823*CF^2*lm^2*NC)/2 - 
       (63600747510235883602186975906162391621417379684682127351*CF*NM*NC)/
        37639482968235465836316721351351123200000 - 
       (6021201591729581*CF*lm*NM*NC)/12509782084800 - 
       (647*CF*lm^2*NM*NC)/2 + (955678109372701508481943*CF*NC*NL)/
        7728042980706048000 - (6021201591729581*CF*lm*NC*NL)/
        12509782084800 - (647*CF*lm^2*NC*NL)/2 + 
       (19429854213140532000222052755972483881789637492814543494137*CF*NC*
         NH)/5694911640055305354972879979056285893815031496000000 - 
       (6021201591729581*CF*lm*NC*NH)/12509782084800 - 
       (647*CF*lm^2*NC*NH)/2 - (355615744596836312916892686521*CF^2*NC*Pi^2)/
        51340145676019200 + 18*CF^2*lm*NC*Pi^2 + 
       (1260116487498011557789*CF*NM*NC*Pi^2)/2042040 + 
       2*CF*lm*NM*NC*Pi^2 - (2197228753*CF*NC*NL*Pi^2)/765765 + 
       2*CF*lm*NC*NL*Pi^2 + 2*CF*lm*NC*NH*Pi^2 - 
       (58347432847267839408778835*CF^2*NC*Pi^3)/(707646173880251855808*
         Sqrt[3]) - (30150252797235754174495*CF*NC*NH*Pi^3)/
        (66708726798666276*Sqrt[3]) - (209179*CF^2*NC*Pi^4)/216 + 
       (3926364521145951093617279878191379*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4214705229322086040599657600*Sqrt[3]) + 
       (224482039510386599592236939*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (166938588813662355690*Sqrt[3]) - 89738*CF^2*NC*
        Im[PolyLog[2, (-1)^(1/3)]]^2 - (11669486569453567881755767*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3822162976205064036*
         Sqrt[3]) - (3445743176826943334228*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (11669486569453567881755767*CF^2*NC*Pi*Log[3]^2)/
        (183463822857843073728*Sqrt[3]) - (861435794206735833557*CF*NC*NH*Pi*
         Log[3]^2)/(2470693585135788*Sqrt[3]) + 
       CF*((-55148002635250466553771994208108149*CF*NC)/
          663475120089405624000 - 1071612*CF*lm*NC + 
         CA*(265134628497968954566156097398813/6379568462398131000 + 
           654874*lm)*NC + (13366434877554218072826235601*NM*NC)/
          1805044411170 - 119068*lm*NM*NC - (454580*NC*NL)/3 - 
         119068*lm*NC*NL - (800989658154369833*NC*NH)/18050444111700 - 
         119068*lm*NC*NH)*Log[x]^2 + (CF*NC*(96718187827726336929*CA - 
          680*(284465763275718359*CF - 108108*(829888117755084*NM + 
              29767*NL)))*Log[x]^3)/27567540 + 
       (2147788089668470140646159521615253*CF^2*NC*PolyGamma[2, 1])/
        10806813741383936712 + (2399177079126203*CF*NM*NC*PolyGamma[2, 1])/
        2 - (67375690666806988965811*CF*NC*NH*PolyGamma[2, 1])/
        1350851717672992089 + CA*CF*NC*(1112255353548771002541685468947961391\
9262596993399028955017316693035630473/
          1302474584931356003671707821232394981219877254602286080000000 + 
         (7117*lm^2)/4 + (118538581567946909971992060137*Pi^2)/
          34226763784012800 + (58347432847267839408778835*Pi^3)/
          (1415292347760503711616*Sqrt[3]) + (1049351*Pi^4)/2160 + 
         lm*(11171820051916781/2274505833600 - 11*Pi^2) - 
         (3926364521145951093617279878191379*Im[PolyLog[2, (-1)^(1/3)]])/
          (8429410458644172081199315200*Sqrt[3]) + 
         44869*Im[PolyLog[2, (-1)^(1/3)]]^2 + (11669486569453567881755767*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7644325952410128072*
           Sqrt[3]) + (11669486569453567881755767*Pi*Log[3]^2)/
          (366927645715686147456*Sqrt[3]) - 
         (2147788089668470140646159521615253*PolyGamma[2, 1])/
          21613627482767873424 - (368715073032442794817635478943129986297*
           Zeta[3])/1838995494371304510281040) + 
       (368715073129187026608991373741427881947*CF^2*NC*Zeta[3])/
        919497747185652255140520 + 1292659589657657*CF*NM*NC*Zeta[3] - 
       124906*CF*NC*NL*Zeta[3] + (1472007486870973296397990*CF*NC*NH*
         Zeta[3])/1350851717672992089 + CF*Log[x]*
        ((1459055425148398402622527670472773197109333*NM*NC)/
          521309652207368323323024000 - (5309801936*lm*NM*NC)/255255 - 
         2907*lm^2*NM*NC - (916187696824783973*NC*NL)/4415217206400 - 
         (5309801936*lm*NC*NL)/255255 - 2907*lm^2*NC*NL - 
         (7261403571007208088635208934723751368899500063*NC*NH)/
          2208498651539975310734457149328578160000 - (5309801936*lm*NC*NH)/
          255255 - 2907*lm^2*NC*NH + (1659776235568529*NM*NC*Pi^2)/3 - 
         (62441*NC*NL*Pi^2)/3 + (3445743176826943334228*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(-628911269383554351232029295644398298825020891041748458202333/
            4509842586390691183532190877214929745846400000 - 
           (32600837901*lm)/170170 - 26163*lm^2 - (193436406021113154313*
             Pi^2)/110270160 + (11669486569453567881755767*
             Im[PolyLog[2, (-1)^(1/3)]])/(11466488928615192108*Sqrt[3]) - 
           69768*Zeta[3]) + CA*NC*
          (314455635505814294695535954213635430696901032874007062809929/
            4509842586390691183532190877214929745846400000 + 
           (3127099513*lm)/23205 + (31977*lm^2)/2 + 
           (64478802637926259721*Pi^2)/73513440 - (11669486569453567881755767*
             Im[PolyLog[2, (-1)^(1/3)]])/(22932977857230384216*Sqrt[3]) + 
           34884*Zeta[3])), (-26825363036636089979617369840477238262259649082\
216761699020098051079490669201*CF^2*NC)/
        7033362758629322419827222234654932898587337174852344832000000 - 
       (448943711034099889*CF^2*lm*NC)/120093908014080 - 
       (37851*CF^2*lm^2*NC)/16 + 
       (620244800348817013646700489779715291881255015213509497553*CF*NM*NC)/
        903347591237651180071601312432426956800000 - 
       (401592934864923409*CF*lm*NM*NC)/1080845172126720 - 
       (12617*CF*lm^2*NM*NC)/48 + (19152310659939317634705583*CF*NC*NL)/
        194746683113792409600 - (401592934864923409*CF*lm*NC*NL)/
        1080845172126720 - (12617*CF*lm^2*NC*NL)/48 + 
       (17192986496535334238710027779809933367235100694005095101776371*CF*NC*
         NH)/6078145693950791785919290255293955956316466556672000000 - 
       (401592934864923409*CF*lm*NC*NH)/1080845172126720 - 
       (12617*CF*lm^2*NC*NH)/48 + (1748777180442355154420207455363261*CF^2*
         NC*Pi^2)/1232163496224460800 + (265*CF^2*lm*NC*Pi^2)/24 - 
       (9288037064694465938741*CF*NM*NC*Pi^2)/33081048 + 
       (265*CF*lm*NM*NC*Pi^2)/216 - (585711265627*CF*NC*NL*Pi^2)/
        264648384 + (265*CF*lm*NC*NL*Pi^2)/216 + (265*CF*lm*NC*NH*Pi^2)/
        216 - (119282328715855309802316172205*CF^2*NC*Pi^3)/
        (1681367309139478409399808*Sqrt[3]) - 
       (1946585487673742177194625*CF*NC*NH*Pi^3)/(5403406870691968356*
         Sqrt[3]) - (18849233*CF^2*NC*Pi^4)/25920 + 
       (8529785367572970799319172580537767031*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10014139624869276432464786457600*
         Sqrt[3]) + (7188692387087675252953567643*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10817620555125320648712*Sqrt[3]) - 
       (834499*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 - 
       (23856465743171061960463234441*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9081459231463232149536*
         Sqrt[3]) - (222466912876999105965100*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (23856465743171061960463234441*CF^2*NC*Pi*Log[3]^2)/
        (435910043110235143177728*Sqrt[3]) - (55616728219249776491275*CF*NC*
         NH*Pi*Log[3]^2)/(200126180395998828*Sqrt[3]) + 
       CF*((54239198633523067742866276837278002071*CF*NC)/
          3184680576429146995200 - 844560*CF*lm*NC + 
         CA*(-54239198632637614318231694709154317931/6369361152858293990400 + 
           516120*lm)*NC - (8845881467992083055693096549*NM*NC)/
          2625519143520 - 93840*lm*NM*NC - (2191453*NC*NL)/18 - 
         93840*lm*NC*NL - (135769754480403800507*NC*NH)/3898895928127200 - 
         93840*lm*NC*NH)*Log[x]^2 + (CF*NC*(-835881860015125351160251*CA + 
          8*(208970464623958771681499*CF - 413513100*(96536311609933*NM - 
              6256*NL)))*Log[x]^3)/330810480 + 
       (807656323863458115489298294454816489*CF^2*NC*PolyGamma[2, 1])/
        389045294689821721632 + (263398495725542615*CF*NM*NC*
         PolyGamma[2, 1])/432 + (67139821688280880225397*CF*NC*NH*
         PolyGamma[2, 1])/12157665459056928801 + 
       CA*CF*NC*(268253630362286736442532558666275972319553483922165573012451\
91279517731675701/
          14066725517258644839654444469309865797174674349704689664000000 + 
         (138787*lm^2)/96 - (1748777180441256433655720862195341*Pi^2)/
          2464326992448921600 + (119282328715855309802316172205*Pi^3)/
          (3362734618278956818799616*Sqrt[3]) + (18900113*Pi^4)/51840 + 
         lm*(763180680156816529/196517304023040 - (2915*Pi^2)/432) - 
         (8529785367572970799319172580537767031*Im[PolyLog[2, (-1)^(1/3)]])/
          (20028279249738552864929572915200*Sqrt[3]) + 
         (834499*Im[PolyLog[2, (-1)^(1/3)]]^2)/24 + 
         (23856465743171061960463234441*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(18162918462926464299072*Sqrt[3]) + 
         (23856465743171061960463234441*Pi*Log[3]^2)/
          (871820086220470286355456*Sqrt[3]) - 
         (807656323863458115489298294454816489*PolyGamma[2, 1])/
          778090589379643443264 - (107595909354771439343237295044404856329111*
           Zeta[3])/132407675594733924740234880) + 
       (107595909358101604767502842609119614069111*CF^2*NC*Zeta[3])/
        66203837797366962370117440 + (367657712423060675*CF*NM*NC*Zeta[3])/
        216 - (1776595*CF*NC*NL*Zeta[3])/18 + 
       (12970712818324874291379859*CF*NC*NH*Zeta[3])/12157665459056928801 + 
       CF*Log[x]*((-9530559025727587964570290022577880020772187*NM*NC)/
          6255715826488419879876288000 - (26336776447*lm*NM*NC)/1633632 - 
         (4845*lm^2*NM*NC)/2 - (2589773826247476007*NC*NL)/15894781943040 - 
         (26336776447*lm*NC*NL)/1633632 - (4845*lm^2*NC*NL)/2 - 
         (1874755306299858208028549170291378504355506032403*NC*NH)/
          715553563098952000677964116382459323840000 - 
         (26336776447*lm*NC*NH)/1633632 - (4845*lm^2*NC*NH)/2 - 
         (1448044674009595*NM*NC*Pi^2)/6 - (32895*NC*NL*Pi^2)/2 + 
         (222466912876999105965100*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CF*NC*
          (1296823413911062468171858660978230667737278008519402217994764911/
            194825199732077859128590645895684965020564480000 - 
           (80989066101*lm)/544544 - (43605*lm^2)/2 + 
           (3343527439462563924449807*Pi^2)/2646483840 + 
           (23856465743171061960463234441*Im[PolyLog[2, (-1)^(1/3)]])/
            (27244377694389696448608*Sqrt[3]) - 58140*Zeta[3]) + 
         CA*NC*
          (-1296823413866233507809344930154166677524772381572490811581117361/
            389650399464155718257181291791369930041128960000 + 
           (31373560927*lm)/297024 + (53295*lm^2)/4 - 
           (3343527439441417433564287*Pi^2)/5292967680 - 
           (23856465743171061960463234441*Im[PolyLog[2, (-1)^(1/3)]])/
            (54488755388779392897216*Sqrt[3]) + 29070*Zeta[3])), 
      (2709206301816717722709972686840696691445982574063389482580901597208578\
0458311*CF^2*NC)/
        211000882758879672594816667039647986957620115245570344960000000 - 
       (2549349474803708261*CF^2*lm*NC)/450352155052800 - 
       (13699*CF^2*lm^2*NC)/4 - 
       (2491299172751967605462873887041550662340922993562166601*CF*NM*NC)/
        158370896079532114318303175391379200000 - 
       (2292292217634195461*CF*lm*NM*NC)/4053169395475200 - 
       (13699*CF*lm^2*NM*NC)/36 + (677601567223400307749446127*CF*NC*NL)/
        4138367016168088704000 - (2292292217634195461*CF*lm*NC*NL)/
        4053169395475200 - (13699*CF*lm^2*NC*NL)/36 + 
       (17599876651882340310250321907305468380765720309801850598066815204481*
         CF*NC*NH)/
        3925423001405040568235165068592910575955049251312611904000000 - 
       (2292292217634195461*CF*lm*NC*NH)/4053169395475200 - 
       (13699*CF*lm^2*NC*NH)/36 - (2718570339136082448157111696780343*CF^2*
         NC*Pi^2)/17003856247897559040 + (361*CF^2*lm*NC*Pi^2)/18 + 
       (21586269908383341285583*CF*NM*NC*Pi^2)/3759210 + 
       (361*CF*lm*NM*NC*Pi^2)/162 - (1179127394659*CF*NC*NL*Pi^2)/
        330810480 + (361*CF*lm*NC*NL*Pi^2)/162 + (361*CF*lm*NC*NH*Pi^2)/
        162 - (31821486363145796045169033655*CF^2*NC*Pi^3)/
        (296711878083437366364672*Sqrt[3]) - (9656922473518103867043905*CF*NC*
         NH*Pi^3)/(16210220612075905068*Sqrt[3]) - (31311449*CF^2*NC*Pi^4)/
        25920 + (125491969800296144413813833264254437*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(103953006486532281305862835200*
         Sqrt[3]) + (1264822148507572847052829140407*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(689623310389239191355390*Sqrt[3]) - 
       (3998417*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 - 
       (6364297272629159209033806731*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1602610452611158614624*
         Sqrt[3]) - (1103648282687783299090732*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (6364297272629159209033806731*CF^2*NC*Pi*Log[3]^2)/
        (76925301725335613501952*Sqrt[3]) - (275912070671945824772683*CF*NC*
         NH*Pi*Log[3]^2)/(600378541187996484*Sqrt[3]) + 
       CF*((-4364276321294109522750410264835539971*CF*NC)/
          2274771840306533568000 - 1407748*CF*lm*NC + 
         CA*(2777266750183988434739938882488647807/2895164160390133632000 + 
           (7742614*lm)/9)*NC + (261668763828352542828845776*NM*NC)/
          3797428635 - (1407748*lm*NM*NC)/9 - (5367538*NC*NL)/27 - 
         (1407748*lm*NC*NL)/9 - (238595656173614503957*NC*NH)/
          4007198592797400 - (1407748*lm*NC*NH)/9)*Log[x]^2 - 
       (CF*NC*(-8695049292559717052608*CA + 17390099296879174532593*CF - 
          12252240*(69507191360425618*NM + 351937*NL))*Log[x]^3)/41351310 + 
       (1008184380197844464690801150588874001*CF^2*NC*PolyGamma[2, 1])/
        583567942034732582448 + (886867462222821962*CF*NM*NC*
         PolyGamma[2, 1])/81 - (2391873498110533352352394*CF*NC*NH*
         PolyGamma[2, 1])/36472996377170786403 + 
       CA*CF*NC*(-38702947213516259836299226615382508618556318882582423528276\
52399177304008473/
          60285966502537049312804762011327996273605747213020098560000000 + 
         (150689*lm^2)/72 + (6220984757850168909167331540667*Pi^2)/
          77820852393123840 + (31821486363145796045169033655*Pi^3)/
          (593423756166874732729344*Sqrt[3]) + (2093591*Pi^4)/3456 + 
         lm*(4255274908746838661/736939890086400 - (3971*Pi^2)/324) - 
         (125491969800296144413813833264254437*Im[PolyLog[2, (-1)^(1/3)]])/
          (207906012973064562611725670400*Sqrt[3]) + 
         (3998417*Im[PolyLog[2, (-1)^(1/3)]]^2)/72 + 
         (6364297272629159209033806731*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3205220905222317229248*Sqrt[3]) + (6364297272629159209033806731*Pi*
           Log[3]^2)/(153850603450671227003904*Sqrt[3]) - 
         (1008184380197844464690801150588874001*PolyGamma[2, 1])/
          1167135884069465164896 - 
         (104001930293942227862220992929343824490539*Zeta[3])/
          56746146683457396317243520) + 
       (104001930297833188453034827823502026764699*CF^2*NC*Zeta[3])/
        28373073341728698158621760 + (939648628213592200*CF*NM*NC*Zeta[3])/
        81 - (4418906*CF*NC*NL*Zeta[3])/27 + 
       (51715357726243916383291864*CF*NC*NH*Zeta[3])/36472996377170786403 + 
       CF*Log[x]*((57097391160923747601798544932383766382693*NM*NC)/
          2193448747015574992944000 - (1426754013899*lm*NM*NC)/55135080 - 
         3610*lm^2*NM*NC - (137665941806743497659*NC*NL)/506646174434400 - 
         (1426754013899*lm*NC*NL)/55135080 - 3610*lm^2*NC*NL - 
         (1591601801177604777646707762718294491457393595290151*NC*NH)/
          367347310455924483348049828247845055376360000 - 
         (1426754013899*lm*NC*NH)/55135080 - 3610*lm^2*NC*NH + 
         (139014382721577359*NM*NC*Pi^2)/27 - (736364*NC*NL*Pi^2)/27 + 
         (1103648282687783299090732*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*
          (-4827122322359144832145272083975179423371517875488442995804958313/
            2922377995981167886928859688435274475308467200000 - 
           (1459926953699*lm)/6126120 - 32490*lm^2 - 
           (4416532989203002928011*Pi^2)/42007680 + 
           (6364297272629159209033806731*Im[PolyLog[2, (-1)^(1/3)]])/
            (4807831357833475843872*Sqrt[3]) - 86640*Zeta[3]) + 
         CA*NC*
          (4827122323702704915477356563879037099078017774032731102632100113/
            5844755991962335773857719376870548950616934400000 + 
           (1680074645099*lm)/10024560 + 19855*lm^2 + 
           (39748796911304184733219*Pi^2)/756138240 - 
           (6364297272629159209033806731*Im[PolyLog[2, (-1)^(1/3)]])/
            (9615662715666951687744*Sqrt[3]) + 43320*Zeta[3])), 
      (-111303618807674532907354444263344028260547026188171404464183352199199\
58391004681*CF^2*NC)/
        308385905570670290715501282596408596322675553051218196480000000 - 
       (776245525795639298501*CF^2*lm*NC)/177356866880793600 - 
       (44343*CF^2*lm^2*NC)/16 + 
       (29693594915357840455056764449577246531640973934965473825149*CF*NM*
         NC)/4205238786795962389988488868219918592000000 - 
       (694323280502982729701*CF*lm*NM*NC)/1596211801927142400 - 
       (4927*CF*lm^2*NM*NC)/16 + (772568707375171769069674438819*CF*NC*NL)/
        5975801971346720088576000 - (694323280502982729701*CF*lm*NC*NL)/
        1596211801927142400 - (4927*CF*lm^2*NC*NL)/16 + 
       (2522800588005104991828031009086657001172952652633353874349899526833*
         CF*NC*NH)/
        682682261113920098823506968450940969731312913271758592000000 - 
       (694323280502982729701*CF*lm*NC*NH)/1596211801927142400 - 
       (4927*CF*lm^2*NC*NH)/16 + (832426033541132805730797450074400947*CF^2*
         NC*Pi^2)/62129474751933388800 + (2651*CF^2*lm*NC*Pi^2)/216 - 
       (2052522142587043496336257*CF*NM*NC*Pi^2)/725238360 + 
       (2651*CF*lm*NM*NC*Pi^2)/1944 - (18749159109311*CF*NC*NL*Pi^2)/
        6856799040 + (2651*CF*lm*NC*NL*Pi^2)/1944 + (2651*CF*lm*NC*NH*Pi^2)/
        1944 - (338202387424656252819714761695*CF^2*NC*Pi^3)/
        (3686074485421164205222656*Sqrt[3]) - 
       (7658734597225420523654315*CF*NC*NH*Pi^3)/(16210220612075905068*
         Sqrt[3]) - (35121697*CF^2*NC*Pi^4)/38880 + 
       (91484346506890272852946662956366017027*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(83425486259487895202764336412160*
         Sqrt[3]) + (2583161354455955773449439331999*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2758493241556956765421560*Sqrt[3]) - 
       (1540435*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/18 - 
       (67640477484931250563942952339*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19909352930515547404752*
         Sqrt[3]) - (875283953968619488417636*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (67640477484931250563942952339*CF^2*NC*Pi*Log[3]^2)/
        (955648940664746275428096*Sqrt[3]) - (218820988492154872104409*CF*NC*
         NH*Pi*Log[3]^2)/(600378541187996484*Sqrt[3]) + 
       CF*((510239321005311268559848212203342243143*CF*NC)/
          3173545329658415712000 - (3307064*CF*lm*NC)/3 + 
         CA*(-6633111173053961400416100945107291326969/
            82512178571118808512000 + (18188852*lm)/27)*NC - 
         (1245261452057655541295386514051*NM*NC)/36666732866400 - 
         (3307064*lm*NM*NC)/27 - (8569285*NC*NL)/54 - (3307064*lm*NC*NL)/
          27 - (872794624608598040017*NC*NH)/18816410783570400 - 
         (3307064*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-150054016981713690150009275*CA + 
          82992*(3616107984917412492219*CF + 1870*(-396987747335674327*NM + 
              3307064*NL)))*Log[x]^3)/6285399120 + 
       (7447110075670799741553925467389421635*CF^2*NC*PolyGamma[2, 1])/
        389045294689821721632 + (20622914943668288935*CF*NM*NC*
         PolyGamma[2, 1])/3888 + (155457042421915767557899*CF*NC*NH*
         PolyGamma[2, 1])/24315330918113857602 + 
       CA*CF*NC*(144694704449678033576624167127343921022766616173156445499280\
995471114326583761353/
          8018033544837427558603033347506623504389564379331673108480000000 + 
         (54197*lm^2)/32 - (36192436240915795992797012430997429*Pi^2)/
          5402563021907251200 + (338202387424656252819714761695*Pi^3)/
          (7372148970842328410445312*Sqrt[3]) + (35206529*Pi^4)/77760 + 
         lm*(1319911335465087436901/290220327623116800 - (29161*Pi^2)/3888) - 
         (91484346506890272852946662956366017027*Im[PolyLog[2, (-1)^(1/3)]])/
          (166850972518975790405528672824320*Sqrt[3]) + 
         (1540435*Im[PolyLog[2, (-1)^(1/3)]]^2)/36 + 
         (67640477484931250563942952339*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(39818705861031094809504*Sqrt[3]) + 
         (67640477484931250563942952339*Pi*Log[3]^2)/
          (1911297881329492550856192*Sqrt[3]) - 
         (7447110075670799741553925467389421635*PolyGamma[2, 1])/
          778090589379643443264 - (139436170371205337506155862190997811532623*
           Zeta[3])/19351891048461112077418944) + 
       (139436170371833915268373775700154109498215*CF^2*NC*Zeta[3])/
        9675945524230556038709472 + (30150620881597683499*CF*NM*NC*Zeta[3])/
        1944 - (20814605*CF*NC*NL*Zeta[3])/162 + 
       (16751584020079676414572426*CF*NC*NH*Zeta[3])/12157665459056928801 + 
       CF*Log[x]*((-434748505762290205617302945834566426616146471*NM*NC)/
          29121435743997816682182720000 - (22797717127361*lm*NM*NC)/
          1142799840 - (5985*lm^2*NM*NC)/2 - (48987418252888291680857*NC*
           NL)/231030655542086400 - (22797717127361*lm*NC*NL)/1142799840 - 
         (5985*lm^2*NC*NL)/2 - 
         (438934493341383073585732412261446720666938652395461*NC*NH)/
          127772977549886776816712983738380888826560000 - 
         (22797717127361*lm*NC*NH)/1142799840 - (5985*lm^2*NC*NH)/2 - 
         (132329249110196465*NM*NC*Pi^2)/54 - (3468659*NC*NL*Pi^2)/162 + 
         (875283953968619488417636*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*
          (66830311849767186738222428077324817878728620756592991704397856987/
            1067791960070042112531698732312888750593478400000 - 
           (23367688547561*lm)/126977760 - (53865*lm^2)/2 + 
           (4617046676246305291692101*Pi^2)/386793792 + 
           (67640477484931250563942952339*Im[PolyLog[2, (-1)^(1/3)]])/
            (59728058791546642214256*Sqrt[3]) - 71820*Zeta[3]) + 
         CA*NC*
          (
           -17375881080859111490635915656309644374592661077072341569215710017\
37/55525181923642189851648334080270215030860876800000 + (298652487697771*lm)/
            2285599680 + (65835*lm^2)/4 - (1539015558747431563510871*Pi^2)/
            257862528 - (67640477484931250563942952339*
             Im[PolyLog[2, (-1)^(1/3)]])/(119456117583093284428512*Sqrt[3]) + 
           35910*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["a", 2, 1, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-1371442*NM + 19968*lm*NM + 248832*lm^2*NM + 1156608*NL + 
         19968*lm*NL + 248832*lm^2*NL - 1371442*NH + 19968*lm*NH + 
         248832*lm^2*NH + 108*CF*(1449734 + 5120*lm + 20736*lm^2 - 
           1191661*Zeta[3]) + 1416555*NM*Zeta[3] + 1416555*NH*Zeta[3] - 
         6*CA*(-4532938 + 308608*lm + 228096*lm^2 + 4204971*Zeta[3])))/
       44789760, -(CF*NC*(241558*NM + 258816*lm*NM + 124416*lm^2*NM + 
          588288*NL + 258816*lm*NL + 124416*lm^2*NL - 1593032*NH + 
          258816*lm*NH + 124416*lm^2*NH + 54*CF*(1454854 + 46592*lm + 
            20736*lm^2 - 1191661*Zeta[3]) + 165375*NM*Zeta[3] + 
          1251180*NH*Zeta[3] - 3*CA*(-4224330 + 764800*lm + 228096*lm^2 + 
            4204971*Zeta[3])))/22394880, 
      (CF*NC*(319379650*NM + 423874560*lm*NM + 149299200*lm^2*NM + 
         972988416*NL + 423874560*lm*NL + 149299200*lm^2*NL - 
         4083636350*NH + 423874560*lm*NH + 149299200*lm^2*NH + 
         40*CF*(81850674014 + 100970496*lm + 33592320*lm^2 - 
           68038331805*Zeta[3]) + 696016125*NM*Zeta[3] + 
         3301948125*NH*Zeta[3] - 4*CA*(-81162017578 + 844101120*lm + 
           205286400*lm^2 + 68495547375*Zeta[3])))/35831808000, 
      -(CF*NC*(-1087209910*NM + 535511040*lm*NM + 199065600*lm^2*NM + 
          1625513984*NL + 535511040*lm*NL + 199065600*lm^2*NL - 
          10412936250*NH + 535511040*lm*NH + 199065600*lm^2*NH + 
          160*CF*(80256281102 + 31988736*lm + 11197440*lm^2 - 
            66751337925*Zeta[3]) + 2840504625*NM*Zeta[3] + 
          8618376375*NH*Zeta[3] - 16*CA*(-78831967418 + 271173120*lm + 
            68428800*lm^2 + 65972564775*Zeta[3])))/71663616000, 
      (CF*NC*(-8307987154250*NM + 572457123840*lm*NM + 
         338146099200*lm^2*NM + 2986761453568*NL + 572457123840*lm*NL + 
         338146099200*lm^2*NL - 32009550166650*NH + 572457123840*lm*NH + 
         338146099200*lm^2*NH + 210*CF*(611269031470946 + 26949206016*lm + 
           14491975680*lm^2 - 508526846848755*Zeta[3]) + 
         10937619543375*NM*Zeta[3] + 26738228388375*NH*Zeta[3] - 
         CA*(-8557533182720206 + 5515536875520*lm + 1859803545600*lm^2 + 
           7128770749283925*Zeta[3])))/196644962304000, 
      (CF*NC*(3*CA*(-5688957499985486 + 325387632640*lm + 357654528000*lm^2 + 
           4733516017394325*Zeta[3]) - 
         2*(35*CF*(4248081954168050 - 4923113472*lm + 25082265600*lm^2 - 
             3534116655782475*Zeta[3]) + 35*NM*(-186868877306 - 
             1011499008*lm + 2786918400*lm^2 + 189549285975*Zeta[3]) + 
           4*(4096*(46077638 - 2160795*lm + 5953500*lm^2)*NL + 
             105*NH*(-38903227846 - 84291584*lm + 232243200*lm^2 + 
               32583825225*Zeta[3])))))/196644962304000, 
      (CF*NC*(CA*(188097736554612836902 + 10094340088627200*lm - 
           3341208600576000*lm^2 - 156462874909282769625*Zeta[3]) + 
         2*(9*CF*(219815755124223306122 - 1253629027123200*lm + 
             303746236416000*lm^2 - 182869621997232531375*Zeta[3]) + 
           10*(63*NM*(-81935754600938 - 2070243491840*lm + 482136883200*
                lm^2 + 72614527437375*Zeta[3]) + 2*(20480*(2436159475 - 
                 3184212402*lm + 741567960*lm^2)*NL + 63*NH*
                (-73562892248734 - 1035121745920*lm + 241068441600*lm^2 + 
                 61622162650125*Zeta[3]))))))/1168071076085760000, 
      (CF*NC*(-72*CF*(112073536413782430302 - 437269561344000*lm + 
           33359413248000*lm^2 - 93235603500274654125*Zeta[3]) + 
         4*CA*(-81726329276711606962 - 4404092313600000*lm + 
           366953545728000*lm^2 + 67979647681514800875*Zeta[3]) - 
         5*(131072*(-4159090903 - 5405633100*lm + 407219400*lm^2)*NL + 
           63*NM*(-408523047127938 - 11246462566400*lm + 847223193600*lm^2 + 
             337842755971875*Zeta[3]) + 63*NH*(-533809145522366 - 
             11246462566400*lm + 847223193600*lm^2 + 446808841912125*
              Zeta[3]))))/1168071076085760000, 
      -(CF*NC*(198128072852276291010*NM + 4603936757482782720*lm*NM - 
          85658545579622400*lm^2*NM + 6834699485453484032*NL + 
          4603936757482782720*lm*NL - 85658545579622400*lm^2*NL + 
          184282704300078364266*NH + 4603936757482782720*lm*NH - 
          85658545579622400*lm^2*NH - 704*CF*(27581604375466929087458 - 
            58674634941726720*lm + 1095066633830400*lm^2 - 
            22945423790004201191475*Zeta[3]) - 159119560356513631875*NM*
           Zeta[3] - 154075451744965125375*NH*Zeta[3] + 
          352*CA*(-1929068278899659107358 - 70233074849710080*lm + 
            1338414774681600*lm^2 + 1604644674223216920525*Zeta[3])))/
       1469900642146320384000, (CF*NC*(121693848834385152402*NM + 
         2083672198580797440*lm*NM + 24473870165606400*lm^2*NM + 
         4150377340741025792*NL + 2083672198580797440*lm*NL + 
         24473870165606400*lm^2*NL + 77632869040685546940*NH + 
         2083672198580797440*lm*NH + 24473870165606400*lm^2*NH - 
         44*CA*(12210262064096750303266 + 264352595076218880*lm + 
           3059233770700800*lm^2 - 10157143404408352211475*Zeta[3]) - 
         97132624882348930875*NM*Zeta[3] - 64827779612662316250*NH*
          Zeta[3] + 440*CF*(-39977036177518684157126 + 42704001346535424*lm + 
           500601889751040*lm^2 + 33257236740005615645385*Zeta[3])))/
       734950321073160192000, 
      -(CF*NC*(7*(83886080*(4356584037711959 + 1787562135499140*lm + 
              57677021241840*lm^2)*NL + 429*NM*(349537483224829132800*lm + 
              11278086755372236800*lm^2 + 1859*(16462261912975832962 - 
                13207272238835395875*Zeta[3])) + 1287*NH*
             (4279176735758054063362 + 116512494408276377600*lm + 
              3759362251790745600*lm^2 - 3568924004083903339875*Zeta[3])) - 
          440*CA*(1129727231090784887808934282 + 13659573871289932185600*lm + 
            423351181579785338880*lm^2 - 939791228373116525126255535*
             Zeta[3]) + 208*CF*(-88704248009194201176434444354 + 
            45662267792822265446400*lm + 1465446397776180019200*lm^2 + 
            73793748786129665774063057475*Zeta[3])))/
       445156469672728835653632000, 
      (CF*NC*(35*(134217728*(5027004449550409 + 1743043459837680*lm + 
             85463671293000*lm^2)*NL + 1287*NH*(6860218348787742995342 + 
             181777259506350161920*lm + 8912773727649792000*lm^2 - 
             5714705677228834411125*Zeta[3]) + 15015*NM*
            (2220445072530968208866 + 15580907957687156736*lm + 
             763952033798553600*lm^2 - 1797272803945469725875*Zeta[3])) - 
         352*CA*(20934190471185857740927899502 + 135923843316714150297600*
            lm + 6273060821281013760000*lm^2 - 17414906764007958785980525125*
            Zeta[3]) + 832*CF*(-369559570960639462799102607326 + 
           89297624674296712396800*lm + 4342888260886855680000*lm^2 + 
           307439350319751894877626118125*Zeta[3])))/
       4451564696727288356536320000, 
      -(CF*NC*(-(CA*(2895504131065691325769935515776694 + 
             9799275210024543455910297600*lm + 590643097734267807989760000*
              lm^2 - 2408759885282952622323912128744625*Zeta[3])) + 
          2*(35*(805306368*(98594913369952771 + 29181594298676820*lm + 
                1905036365232000*lm^2)*NL + 143*NH*(
                6607367028196453906628098 + 164336529490328231608320*lm + 
                10728237176174149632000*lm^2 - 5497888409811416419675875*
                 Zeta[3]) + 1001*NM*(5849731901525686972300126 + 
                23476647070046890229760*lm + 1532605310882021376000*lm^2 - 
                4775714286237980566606125*Zeta[3])) + 
            33*CF*(-2042869161859086336930546399545354 + 
              226760036711877655186636800*lm + 14644043745477714247680000*lm^
                2 + 1699477830809305266376326386091375*Zeta[3]))))/
       1210825597509822432977879040000, 
      (CF*NC*(-9*CA*(64918454376048790422809984339078 + 
           111449329224063033697894400*lm + 8426255119103148687360000*lm^2 - 
           54005751343801840792748461547625*Zeta[3]) + 
         2*(10*(1207959552*(27113636399919189 + 6822361494128180*lm + 
               570731753592000*lm^2)*NL + 286*NM*
              (13396534564176388276827646 + 28815163405696248053760*lm + 
               2410562494339743744000*lm^2 - 11010943491896729131876125*
                Zeta[3]) + 143*NH*(2561327575584613838130986 + 
               57630326811392496107520*lm + 4821124988679487488000*lm^2 - 
               2129063546525668763385375*Zeta[3])) + 
           21*CF*(-718280967440919016050964325366434 + 
             35811600912539948836454400*lm + 2954660885919285903360000*lm^2 + 
             597543191096525559073919601745875*Zeta[3]))))/
       172975085358546061853982720000, 
      -(CF*NC*(-25*CA*(3731890821361563658875092158473085450 + 
            3156329771590671014041026035712*lm + 
            298487359635216712312710758400*lm^2 - 
            3104575297564990232210662021193862255*Zeta[3]) + 
          2*(1365*(4*(503316480*(10919677057909487677 + 2296155612761166156*
                   lm + 246853605297499200*lm^2)*NL + 17017*NH*
                 (3484028538783574394596346 + 67914024830886362480640*lm + 
                  7301256842783490048000*lm^2 - 2893440277136717801868375*
                   Zeta[3])) + 1309*NM*(3263921772618949588340165846 + 
                3531529291206090848993280*lm + 379665355824741482496000*
                 lm^2 - 2695365500610181938240326625*Zeta[3])) + 
            17*CF*(-156222104620034155117372998421655585446 + 
              3400489566205884788427561369600*lm + 
              359142545015635081659678720000*lm^2 + 
              129962313032274191382485540918734409625*Zeta[3]))))/
       19945930067779304938444601425920000, 
      (CF*NC*(105*(8589934592*(12812979749959804931 + 2174245021349065665*
              lm + 310764097243700100*lm^2)*NL + 2431*NM*
            (7682691287688242559713280*lm + 1098084438035915813683200*lm^2 + 
             19*(796861844290432773523469066 - 660058456661626860313851375*
                Zeta[3])) + 12155*NH*(96404410110123952699075642 + 
             1536538257537648511942656*lm + 219616887607183162736640*lm^2 - 
             80001555783592310223931575*Zeta[3])) - 
         5*CA*(6347447063926258279941919005692451706 + 
           2549558061625949357467961917440*lm + 
           308320697553943460123875737600*lm^2 - 
           5280476906702863930917640156555361175*Zeta[3]) + 
         34*CF*(-58301407325154447561228115729720740542 + 
           531466046958707286110266982400*lm + 74194820266991741741039616000*
            lm^2 + 48501368554989377414535972646513816125*Zeta[3])))/
       4986482516944826234611150356480000, 
      -(CF*NC*(35*(137438953472*(1460276901733613573227 + 
              186890627261089451700*lm + 38259639185500933200*lm^2)*NL + 
            230945*NM*(513461701814440956604470950534 + 
              111221512587368282267320320*lm + 22768905020119815259422720*lm^
                2 - 426103295969503375277477848425*Zeta[3]) + 
            46189*NH*(46662100394640775394604788638 + 
              556107562936841411336601600*lm + 113844525100599076297113600*lm^
                2 - 38698773572839201326726346125*Zeta[3])) - 
          256*CA*(134621510061864141499782971874038119502 + 
            24347126647784434219257692160000*lm + 
            3954043821094833462907502592000*lm^2 - 
            111992502859300010072508547023205471125*Zeta[3]) + 
          165376*CF*(-14215128916571788055877145872632562022 + 
            50594829970083533083901952000*lm + 10015872330383760530866176000*
             lm^2 + 11825670218145409201008729003752669625*Zeta[3])))/
       4042375160403272467524772555653120000, 
      (CF*NC*(385*(17179869184*(388613919268719565697 + 32330316168526619880*
              lm + 11136727736471937600*lm^2)*NL + 16796*NM*
            (423053970789231043505245237142 + 33069219007659408642539520*lm + 
             11391255397142909838950400*lm^2 - 351460242037276200455892890625*
              Zeta[3]) + 4199*NH*(17608010800139026569712480694 + 
             132276876030637634570158080*lm + 45565021588571639355801600*
              lm^2 - 14596133610683315685474104625*Zeta[3])) - 
         2304*CA*(9877619792492640354231798452935630754 + 
           734267353438082514391819878400*lm + 175840293213866351633891328000*
            lm^2 - 8217260049191676564733267804643329875*Zeta[3]) + 
         6449664*CF*(-261807689189045209136277724046253526 + 
           315529411076536149422899200*lm + 102788281122656725499904000*
            lm^2 + 217799742968684238062808208154678625*Zeta[3])))/
       2021187580201636233762386277826560000, 
      -(CF*NC*(-14*CA*(489084158378736088383579025205627038365298762 + 
            12241495483660157657828613872733388800*lm + 
            5314220214929974808588048507338752000*lm^2 - 
            406872601248174390123927314305544395486887375*Zeta[3]) + 
          5*(231*(8658654068736*(42414140577202901854393 + 
                1394281422644800884480*lm + 1352609769951190951200*lm^2)*
               NL + 20995*NM*(33985102447685222023043481664963658 + 
                575022648875752494618686521344*lm + 
                557836631959987829565932175360*lm^2 - 
                28251293068620900767146949808692175*Zeta[3]) + 
              4199*NH*(1022878846645638819621422472520738 + 
                2875113244378762473093432606720*lm + 
                2789183159799939147829660876800*lm^2 - 
                847632130065670053126698674873875*Zeta[3])) + 
            4*CF*(-27528502180111599047265563107581855636592593202 + 
              7289267066830848869574364021370388480*lm + 
              6087197700737971144382673744769843200*lm^2 + 
              22901163668213340027785361887839864717223599275*Zeta[3]))))/
       466360737505404738033397960200589148160000, 
      (CF*NC*(-40*CA*(441261950257104735353013739763841318699557638 + 
           1604270656830132742917064750132101120*lm + 
           2957158712561532919227705176830771200*lm^2 - 
           367089019563579265170095070558728716764035625*Zeta[3]) + 
         16*CF*(-95806747132381641173258099577164812059353813218 - 
           6817606776830773268869599446276505600*lm + 
           12097467460478998305931521177944064000*lm^2 + 
           79702338750656431157705607760890307954060909875*Zeta[3]) + 
         1155*(98956046499840*(5186404439898831964681 - 137405222636150120652*
              lm + 188168800131277645680*lm^2)*NL + 
           4199*NM*(436914951578834028609234522537610946 - 
             3238170421648901901547544248320*lm + 
             4434494054682021862895832268800*lm^2 - 
             363325821067135300594692796873423875*Zeta[3]) + 
           4199*NH*(-3238170421648901901547544248320*lm + 
             4434494054682021862895832268800*lm^2 - 
             4199*(-369285941548447320118529076034 + 
               305955332531337557341486087875*Zeta[3])))))/
       932721475010809476066795920401178296320000, 
      -(CF*NC*(-13*CA*(7327609229378583812768019804841162142486381979706 - 
            33615517657021361748022481749927998259200*lm + 
            30681246402932598358880108060982273638400*lm^2 - 
            6095891771557506502785726371003185547756167905975*Zeta[3]) + 
          46*CF*(-193656487288027906215943383795225453980135504322082 - 
            31238923995386649778501892862725691801600*lm + 
            14188560589498474339877362225829747097600*lm^2 + 
            161104258877769157070942448361426095558625356160275*Zeta[3]) + 
          1155*(18141941858304*(81541368836955737678566601 - 
              8196651313060312736164440*lm + 3460890879175126378101120*lm^2)*
             NL + 96577*NM*(100976552945340384541189929256999635062 - 
              1539736909971642644790814577786880*lm + 
              650126646177969460415853483786240*lm^2 - 
              83984966543206781973970580695103564625*Zeta[3]) + 
            96577*NH*(-1539736909971642644790814577786880*lm + 
              650126646177969460415853483786240*lm^2 - 
              7429*(-29286502114971341762550554681294 + 
                24261863233077058933514436391125*Zeta[3])))))/
       3947277282245745702714680335137786550026240000, 
      (CF*NC*(CA*(-3645556528747831418162580009179551853548634042086 + 
           25131769937601603769944888482704077619200*lm - 
           9677644849034986175767128866401183334400*lm^2 + 
           3032765283499412031396437200255135955474098335225*Zeta[3]) + 
         2*(595*(2*(687194767360*(20902971828358058110558595 - 
                 4163112012449713579408152*lm + 1075846199032836042267456*
                  lm^2)*NL + 6084351*NH*(39046482177493044651788344994122 - 
                 470201142387906671870182686720*lm + 
                 121511049980435057258696540160*lm^2 - 
                 32347485021508215031480784151375*Zeta[3])) + 
             5681*NM*(61215585335855659897750182722588338078 - 
               1007170846994896091145931314954240*lm + 
               260276669058091892648127989022720*lm^2 - 
               50919837387936396924603880711731466125*Zeta[3])) + 
           23*CF*(-7957727358003097991310443102744318508455134281206 - 
             1274792430755260423812807966460162867200*lm + 
             344264046013102275027289169160516403200*lm^2 + 
             6620092042306748872770672353054560253923207873425*Zeta[3]))))/
       119614463098355930385293343489023834849280000}, 0, 22, 1]
 
CbarSeries["a", 2, 2, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(CF*(-2332800*lm^2 + 128176*Pi^2 + 3600*Pi^4 + 
            64800*lm*(-79 + 4*Pi^2) + 15*(-210425 + 296976*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 103680*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 49496*PolyGamma[2, 1] - 404368*Zeta[3])) + 
          60*(-2*NH*(22531 + 1080*lm^2 - 60*lm*(-53 + 2*Pi^2) + 
              82512*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 13752*PolyGamma[2, 
                1] - 167664*Zeta[3]) + NL*(-5915 - 2160*lm^2 + 28*Pi^2 + 
              120*lm*(-53 + 2*Pi^2) - 2880*Zeta[3]) + 
            NM*(-5915 - 2160*lm^2 + 28*Pi^2 + 120*lm*(-53 + 2*Pi^2) + 
              240*PolyGamma[2, 1] - 2400*Zeta[3])) + 
          CA*(712800*lm^2 - 306794*Pi^2 + 9720*Pi^4 - 
            3600*lm*(-835 + 22*Pi^2) + 30*(87287 - 74244*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 25920*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 12374*PolyGamma[2, 1] + 128956*Zeta[3]))))/11664000, 
      -(CF*NC*(-(CA*(-18915345 + 7128000*lm^2 - 5310852*Pi^2 + 191160*Pi^4 - 
             3600*lm*(-4203 + 220*Pi^2) - 51581280*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 15292800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             9140480*PolyGamma[2, 1] + 78517600*Zeta[3])) + 
          2*(-100*(NH*(1678131 - 5508*lm - 6480*lm^2 + 720*lm*Pi^2 - 
                499632*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 83272*
                 PolyGamma[2, 1] - 495856*Zeta[3]) + 3*NL*(8121 - 1836*lm - 
                2160*lm^2 + 124*Pi^2 + 240*lm*Pi^2 - 2880*Zeta[3]) + 
              3*NM*(8121 - 2160*lm^2 + 124*Pi^2 + 12*lm*(-153 + 20*Pi^2) + 
                240*PolyGamma[2, 1] - 2400*Zeta[3])) + 
            CF*(20675325 + 11664000*lm^2 - 362844*Pi^2 + 75960*Pi^4 - 
              129600*lm*(-9 + 10*Pi^2) - 51581280*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 15292800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              9140480*PolyGamma[2, 1] + 66343840*Zeta[3]))))/46656000, 
      -(CF*NC*(-40*(NH*(29389977 - 155520*lm^2 + 540*lm*(-217 + 4*Pi^2) - 
              6986256*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 999352*PolyGamma[
                2, 1] - 12153616*Zeta[3]) + 9*NM*(84865 - 17280*lm^2 - 
              12132*Pi^2 + 60*lm*(-217 + 4*Pi^2) - 1200*PolyGamma[2, 1] - 
              5280*Zeta[3]) + 9*NL*(47245 - 17280*lm^2 - 4692*Pi^2 + 
              60*lm*(-217 + 4*Pi^2) - 2880*Zeta[3])) + 
          5*CA*(9983835 - 6842880*lm^2 + 374208*Pi^2 + 119664*Pi^4 + 
            2160*lm*(-6419 + 44*Pi^2) + 41017872*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 15863040*Im[PolyLog[2, (-1)^(1/3)]]^
              2 - 7180856*PolyGamma[2, 1] - 59404624*Zeta[3]) + 
          CF*(111974400*lm^2 + 9601068*Pi^2 - 1334880*Pi^4 - 
            388800*lm*(-1 + 4*Pi^2) + 5*(43553979 - 82035744*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 31726080*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 14361712*PolyGamma[2, 1] + 106546496*Zeta[3]))))/
       69984000, -(CF*NC*(195955200*(-10*CA*(76 + 33*lm) + 
            9*CF*(251 + 120*lm) + 20*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 
              3*lm*NH))*Log[x]^2 + 3919104000*(11*CA + 36*CF - 
            2*(NM + NL))*Log[x]^3 - 7*CA*(6735960000*lm^2 - 
            2002262652*Pi^2 + 198800000*Sqrt[3]*Pi^3 + 70810200*Pi^4 - 
            1458000*lm*(-15637 + 132*Pi^2) + 153360000*Sqrt[3]*Pi*Log[3]^2 - 
            135*(-91052203 + 221061408*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              126748800*Im[PolyLog[2, (-1)^(1/3)]]^2 - 54528000*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 41182912*PolyGamma[2, 
                1] - 356030048*Zeta[3])) + 
          10*(CF*(15431472000*lm^2 - 1563464268*Pi^2 + 278320000*Sqrt[3]*Pi^
                3 + 59943240*Pi^4 - 146966400*lm*(-143 + 3*Pi^2) + 
              214704000*Sqrt[3]*Pi*Log[3]^2 - 189*(-148956601 + 221061408*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 126748800*
                 Im[PolyLog[2, (-1)^(1/3)]]^2 - 54528000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 41182912*
                 PolyGamma[2, 1] - 293315744*Zeta[3])) - 
            140*(-(NH*(6123600*lm^2 + 32603200*Sqrt[3]*Pi^3 - 14580*lm*
                  (-887 + 12*Pi^2) + 25151040*Sqrt[3]*Pi*Log[3]^2 + 
                 3*(-346434795 + 24641328*Sqrt[3]*Im[PolyLog[2, (-1)^
                       (1/3)]] + 402416640*Sqrt[3]*Im[PolyLog[3, 
                      -((-1)^(5/6)/Sqrt[3])]] + 982600*PolyGamma[2, 1] - 
                   84037360*Zeta[3]))) + 729*NL*(-5455 - 8400*lm^2 - 
                4388*Pi^2 + 20*lm*(-887 + 12*Pi^2) - 25920*Zeta[3]) + 
              729*NM*(42833 - 8400*lm^2 - 3108*Pi^2 + 20*lm*(-887 + 
                  12*Pi^2) - 1520*PolyGamma[2, 1] + 5600*Zeta[3]))) + 
          151200*Log[x]*(CA*(-1327104*lm - 213840*lm^2 + 3636*Pi^2 + 
              5*(-507399 + 22720*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
                46656*Zeta[3])) + 16*(22599*NL + 11988*lm*NL + 
              2430*lm^2*NL + 408765*NH + 11988*lm*NH + 2430*lm^2*NH + 
              1620*NL*Pi^2 + 81*NM*(99 + 148*lm + 30*lm^2 + 20*Pi^2) - 
              232880*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
              CF*(234474 + 182979*lm + 43740*lm^2 - 3789*Pi^2 - 14200*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 29160*Zeta[3])))))/8817984000, 
      (-2*CF*NC*(-10*CA*(76 + 33*lm) + 6*CF*(359 + 180*lm) + 85*NM + 
          60*lm*NM + 100*NL + 60*lm*NL + 60*lm*NH)*Log[x]^2)/45 - 
       (8*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/9 + 
       (CF*NC*Log[x]*(CA*(2720001 + 1285524*lm + 213840*lm^2 - 12726*Pi^2 - 
            197336*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 233280*Zeta[3]) - 
          2*(171981*NL + 92124*lm*NL + 19440*lm^2*NL + 2686983*NH + 
            92124*lm*NH + 19440*lm^2*NH + 12960*NL*Pi^2 + 
            36*NM*(716 + 2559*lm + 540*lm^2 + 405*Pi^2) - 
            1530400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            CF*(2019126 + 1395792*lm + 349920*lm^2 - 27882*Pi^2 - 
              197336*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 233280*Zeta[3]))))/
        29160 - (CF*NC*(-7*CA*(3021559200*lm^2 - 364574844*Pi^2 + 
            172669000*Sqrt[3]*Pi^3 + 9227520*Pi^4 - 583200*lm*
             (-16813 + 77*Pi^2) + 133201800*Sqrt[3]*Pi*Log[3]^2 + 
            5*(190458927 - 2935851936*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1657221120*Im[PolyLog[2, (-1)^(1/3)]]^2 + 1278737280*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 561090988*PolyGamma[2, 
                1] + 4744437176*Zeta[3])) + 
          4*(CF*(17305293600*lm^2 - 459256176*Pi^2 + 604341500*Sqrt[3]*Pi^3 + 
              9434880*Pi^4 - 64297800*lm*(-329 + 4*Pi^2) + 466206300*Sqrt[
                3]*Pi*Log[3]^2 - 35*(-495251163 + 1467925968*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 828610560*Im[PolyLog[2, 
                    (-1)^(1/3)]]^2 - 639368640*Sqrt[3]*Im[PolyLog[3, 
                   -((-1)^(5/6)/Sqrt[3])]] - 280545494*PolyGamma[2, 1] - 
                2042450092*Zeta[3])) - 35*(-(NH*(-4750205643 + 27468720*
                  lm^2 + 133910000*Sqrt[3]*Pi^3 - 58320*lm*(-929 + 7*Pi^2) + 
                 836026224*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 4958496000*
                  Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                 103302000*Sqrt[3]*Pi*Log[3]^2 - 76713352*PolyGamma[2, 1] - 
                 1589031824*Zeta[3])) + 243*NL*(-30655 - 113040*lm^2 - 
                67924*Pi^2 + 240*lm*(-929 + 7*Pi^2) - 365760*Zeta[3]) + 
              486*NM*(360445 - 56520*lm^2 - 23132*Pi^2 + 120*lm*
                 (-929 + 7*Pi^2) - 16956*PolyGamma[2, 1] + 64008*Zeta[3])))))/
        2204496000, -(CF*NC*(-3*CA*(2301 + 1100*lm) + 3*CF*(6943 + 3600*lm) + 
           4*(400*NM + 150*lm*NM + 225*NL + 150*lm*NL + 4*NH + 
             150*lm*NH))*Log[x]^2)/30 - 
       (20*CF*NC*(13*CA + 46*CF - 2*(2*NM + NL))*Log[x]^3)/3 + 
       (CF*NC*Log[x]*(-4*(30375*NL*(531 + 254*lm + 48*lm^2 + 40*Pi^2) + 
            405*NM*(26043 + 19050*lm + 3600*lm^2 + 520*Pi^2) + 
            NH*(271656969 + 7715250*lm + 1458000*lm^2 - 154331200*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) + 5*CF*(-131414475 - 95353200*lm - 
            20995200*lm^2 + 2600208*Pi^2 + 12775328*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 13996800*Zeta[3]) - 
          20*CA*(-22461522 - 10527975*lm - 1603800*lm^2 + 102681*Pi^2 + 
            1596916*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 1749600*Zeta[3])))/
        874800 - (CF*NC*(CF*(1481421312000*lm^2 - 247136468472*Pi^2 + 
            78248884000*Sqrt[3]*Pi^3 + 11650353120*Pi^4 - 1763596800*lm*
             (-1249 + 15*Pi^2) + 60363424800*Sqrt[3]*Pi*Log[3]^2 - 
            35*(-29810721069 + 124774459296*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 80974287360*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              82784125440*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              25927664704*PolyGamma[2, 1] - 172997820032*Zeta[3])) - 
          4*CA*(113164128000*lm^2 - 34528567653*Pi^2 + 9781110500*Sqrt[3]*
             Pi^3 + 1750226940*Pi^4 - 12247200*lm*(-32429 + 165*Pi^2) + 
            7545428100*Sqrt[3]*Pi*Log[3]^2 - 140*(-255850398 + 
              3899201853*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              2530446480*Im[PolyLog[2, (-1)^(1/3)]]^2 - 2587003920*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 810239522*PolyGamma[2, 
                1] - 6522374188*Zeta[3])) - 
          224*(-(NH*(-85974989481 + 367416000*lm^2 + 3375995000*Sqrt[3]*
                Pi^3 - 437400*lm*(-1879 + 15*Pi^2) - 125449800*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 125008272000*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 2604339000*Sqrt[3]*Pi*
                Log[3]^2 + 1498444075*PolyGamma[2, 1] - 30175527850*
                Zeta[3])) + 54675*NL*(-891 - 6720*lm^2 - 5348*Pi^2 + 
              8*lm*(-1879 + 15*Pi^2) - 37440*Zeta[3]) + 
            18225*NM*(193395 - 20160*lm^2 - 5474*Pi^2 + 24*lm*(-1879 + 
                15*Pi^2) - 4593*PolyGamma[2, 1] + 178014*Zeta[3]))))/
        13226976000, (CF*NC*(-97977600*(15*CF*(28345 + 15984*lm) - 
           4*CA*(36902 + 18315*lm) + 4*((9307 + 3330*lm)*NM + 
             9*(185*(3 + 2*lm)*NL + 2*(6 + 185*lm)*NH)))*Log[x]^2 - 
         11757312000*(515*CA + 1646*CF - 160*NM - 74*NL)*Log[x]^3 - 
         3*CF*(2158642483200*lm^2 - 234723182832*Pi^2 + 165587464000*Sqrt[3]*
            Pi^3 + 13192683840*Pi^4 - 195955200*lm*(-15149 + 126*Pi^2) + 
           127738900800*Sqrt[3]*Pi*Log[3]^2 - 35*(26813642805 + 
             205760144256*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             125467315200*Im[PolyLog[2, (-1)^(1/3)]]^2 - 175184778240*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 42331736096*
              PolyGamma[2, 1] - 306716918848*Zeta[3])) + 
         48*CA*(41224075200*lm^2 - 8254700523*Pi^2 + 5174608250*Sqrt[3]*
            Pi^3 + 480855690*Pi^4 - 340200*lm*(-411745 + 1386*Pi^2) + 
           3991840650*Sqrt[3]*Pi*Log[3]^2 - 35*(2023194708 + 
             6430004508*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             3920853600*Im[PolyLog[2, (-1)^(1/3)]]^2 - 5474524320*Sqrt[3]*
              Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 1322866753*
              PolyGamma[2, 1] - 11044140098*Zeta[3])) + 
         15120*Log[x]*(-8*(405*NM*(46713 + 43954*lm + 8640*lm^2 + 240*
                Pi^2) + 135*NL*(278771 + 131862*lm + 25920*lm^2 + 21960*
                Pi^2) + NH*(575223267 + 17801370*lm + 3499200*lm^2 - 
               326540000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
           15*CF*(-226418097 - 145698912*lm - 33592320*lm^2 + 4377384*Pi^2 + 
             27034688*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
             22394880*Zeta[3]) - 120*CA*(-18934959 - 8160129*lm - 
             1283040*lm^2 + 151047*Pi^2 + 1689668*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 1399680*Zeta[3])) + 
         448*(-(NH*(-199554833448 + 803066400*lm^2 + 7143062500*Sqrt[3]*Pi^
                3 - 72900*lm*(-23411 + 126*Pi^2) + 20599684440*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 264497400000*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 5510362500*Sqrt[3]*Pi*
               Log[3]^2 - 729614335*PolyGamma[2, 1] - 87420575870*Zeta[3])) + 
           1215*NL*(365185 - 660960*lm^2 - 564588*Pi^2 + 
             60*lm*(-23411 + 126*Pi^2) - 4043520*Zeta[3]) + 
           1215*NM*(7857110 - 660960*lm^2 - 114798*Pi^2 + 
             60*lm*(-23411 + 126*Pi^2) - 164907*PolyGamma[2, 1] + 
             7355466*Zeta[3]))))/39680928000, (4836323065*CF^2*NC)/15116544 - 
       (17335*CF^2*lm*NC)/27 - 420*CF^2*lm^2*NC + (13460809*CF*NM*NC)/
        29160 - (12920*CF*lm*NM*NC)/243 - (70*CF*lm^2*NM*NC)/3 + 
       (1063571*CF*NC*NL)/29160 - (12920*CF*lm*NC*NL)/243 - 
       (70*CF*lm^2*NC*NL)/3 + (156077989829269*CF*NC*NH)/20253807000 - 
       (12920*CF*lm*NC*NH)/243 - (70*CF*lm^2*NC*NH)/3 + 
       (1138553*CF^2*NC*Pi^2)/10080 + (50*CF^2*lm*NC*Pi^2)/9 + 
       (150313*CF*NM*NC*Pi^2)/4860 + (25*CF*lm*NM*NC*Pi^2)/81 - 
       (11905*CF*NC*NL*Pi^2)/486 + (25*CF*lm*NC*NL*Pi^2)/81 + 
       (25*CF*lm*NC*NH*Pi^2)/81 - (176174915*CF^2*NC*Pi^3)/
        (1417176*Sqrt[3]) - (172055485*CF*NC*NH*Pi^3)/(177147*Sqrt[3]) - 
       (1117*CF^2*NC*Pi^4)/216 + (10138817581*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2361960*Sqrt[3]) + 
       (242685743*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(295245*Sqrt[3]) - 
       (8630*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (10067138*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2187*Sqrt[3]) - (78653936*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2187*Sqrt[3]) - 
       (5033569*CF^2*NC*Pi*Log[3]^2)/(52488*Sqrt[3]) - 
       (4915871*CF*NC*NH*Pi*Log[3]^2)/(6561*Sqrt[3]) - 
       (CF*NC*(105*CF*(244921 + 133200*lm) - 7*CA*(1183249 + 610500*lm) + 
          4*(21*(1917 + 9250*lm)*NM + 175*(1577 + 1110*lm)*NL + 
            3*(3861 + 64750*lm)*NH))*Log[x]^2)/5670 - 
       (10*CF*NC*(5441*CA + 21640*CF - 4280*NM - 740*NL)*Log[x]^3)/81 - 
       (16822174853*CF^2*NC*PolyGamma[2, 1])/53144100 + 
       (28021*CF*NM*NC*PolyGamma[2, 1])/648 - 
       (3746527373*CF*NC*NH*PolyGamma[2, 1])/21257640 + 
       (CF*NC*Log[x]*(4*(-59535*NM*(579569 + 298870*lm + 54000*lm^2 - 
              151880*Pi^2) - 19845*NL*(2094269 + 896610*lm + 162000*lm^2 + 
              165000*Pi^2) - NH*(679844939097 + 17793225450*lm + 
              3214890000*lm^2 - 385404286400*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]])) - 490*CA*(-982587510*lm - 144342000*lm^2 + 
            20258586*Pi^2 + 5*(-453316827 + 40268552*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 31492800*Zeta[3])) + 
          245*CF*(-6661597929 - 4520441520*lm - 944784000*lm^2 + 
            161653968*Pi^2 + 805371040*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            629856000*Zeta[3])))/385786800 - (54958862153*CF^2*NC*Zeta[3])/
        26572050 + (160405*CF*NM*NC*Zeta[3])/324 - (5600*CF*NC*NL*Zeta[3])/
        27 + (30712894387*CF*NC*NH*Zeta[3])/10628820 + 
       (CA*CF*NC*(763857864000*lm^2 - 323232522327*Pi^2 + 
          123322440500*Sqrt[3]*Pi^3 + 16859801700*Pi^4 - 
          306180000*lm*(-8860 + 33*Pi^2) + 95134454100*Sqrt[3]*Pi*Log[3]^2 + 
          7*(-239195452185 - 608329054860*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 407674296000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
            652350542400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
            134577398824*PolyGamma[2, 1] + 1062847190768*Zeta[3])))/
        5952139200, (1639089003353*CF^2*NC)/1417176000 - 
       (167669*CF^2*lm*NC)/216 - 543*CF^2*lm^2*NC + (1061473777*CF*NM*NC)/
        1458000 - (255635*CF*lm*NM*NC)/3888 - (181*CF*lm^2*NM*NC)/6 + 
       (1989437*CF*NC*NL)/25920 - (255635*CF*lm*NC*NL)/3888 - 
       (181*CF*lm^2*NC*NL)/6 + (645713006222287*CF*NC*NH)/60761421000 - 
       (255635*CF*lm*NC*NH)/3888 - (181*CF*lm^2*NC*NH)/6 + 
       (52938877*CF^2*NC*Pi^2)/340200 + 5*CF^2*lm*NC*Pi^2 + 
       (36403*CF*NM*NC*Pi^2)/1080 + (5*CF*lm*NM*NC*Pi^2)/18 - 
       (64309*CF*NC*NL*Pi^2)/1944 + (5*CF*lm*NC*NL*Pi^2)/18 + 
       (5*CF*lm*NC*NH*Pi^2)/18 - (222779165*CF^2*NC*Pi^3)/
        (1062882*Sqrt[3]) - (657374935*CF*NC*NH*Pi^3)/(531441*Sqrt[3]) - 
       (6473*CF^2*NC*Pi^4)/1080 + (11212118071*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1771470*Sqrt[3]) - 
       (1633269049*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) - 
       1302*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (50920952*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (6561*Sqrt[3]) - (300514256*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6561*Sqrt[3]) - 
       (6365119*CF^2*NC*Pi*Log[3]^2)/(39366*Sqrt[3]) - 
       (18782141*CF*NC*NH*Pi*Log[3]^2)/(19683*Sqrt[3]) - 
       (CF*NC*(63*CF*(494069 + 317880*lm) - 14*CA*(727052 + 437085*lm) + 
          1445990*NM + 1112580*lm*NM + 1586935*NL + 1112580*lm*NL + 
          76032*NH + 1112580*lm*NH)*Log[x]^2)/5670 - 
       (2*CF*NC*(132935*CA + 433565*CF - 94404*NM - 15894*NL)*Log[x]^3)/
        243 - (10320124541*CF^2*NC*PolyGamma[2, 1])/25509168 + 
       (573347*CF*NM*NC*PolyGamma[2, 1])/8100 - 
       (4795550669*CF*NC*NH*PolyGamma[2, 1])/159432300 + 
       (CF*NC*Log[x]*(2*(-23814*NM*(14408521 + 6024750*lm + 1134000*lm^2 - 
              3530100*Pi^2) - 893025*NL*(382617 + 160660*lm + 30240*lm^2 + 
              31272*Pi^2) - 4*NH*(1299670100133 + 35868349125*lm + 
              6751269000*lm^2 - 736259927200*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]])) + 49*CF*(-147236132199 - 90528678000*lm - 
            19840464000*lm^2 + 4496335920*Pi^2 + 20368380800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 13226976000*Zeta[3]) - 
          98*CA*(-49055915631 - 19962024750*lm - 3031182000*lm^2 + 
            812487510*Pi^2 + 5092095200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            3306744000*Zeta[3])))/1157360400 - (212137690129*CF^2*NC*Zeta[3])/
        63772920 + (3137147*CF*NM*NC*Zeta[3])/4050 - 
       (2636*CF*NC*NL*Zeta[3])/9 + (382683987331*CF*NC*NH*Zeta[3])/
        79716150 + (CA*CF*NC*(-38628820467729 + 8464792248000*lm^2 - 
          3868719894000*Pi^2 + 1782233320000*Sqrt[3]*Pi^3 + 
          164227078800*Pi^4 - 6561000*lm*(-4454017 + 11880*Pi^2) - 
          53818166740800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          33212936736000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 65993553792000*
           Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          1374865704000*Sqrt[3]*Pi*Log[3]^2 + 10320124541000*
           PolyGamma[2, 1] + 97527558322000*Zeta[3]))/51018336000, 
      (122483174509367*CF^2*NC)/45349632000 - (29275*CF^2*lm*NC)/16 - 
       (2365*CF^2*lm^2*NC)/2 + (493381099*CF*NM*NC)/324000 - 
       (43465*CF*lm*NM*NC)/288 - (2365*CF*lm^2*NM*NC)/36 + 
       (14554639*CF*NC*NL)/51840 - (43465*CF*lm*NC*NL)/288 - 
       (2365*CF*lm^2*NC*NL)/36 + (1733506968231763*CF*NC*NH)/58330964160 - 
       (43465*CF*lm*NC*NH)/288 - (2365*CF*lm^2*NC*NH)/36 + 
       (176023067*CF^2*NC*Pi^2)/272160 + (25*CF^2*lm*NC*Pi^2)/2 + 
       (177881*CF*NM*NC*Pi^2)/240 + (25*CF*lm*NM*NC*Pi^2)/36 - 
       (1365*CF*NC*NL*Pi^2)/16 + (25*CF*lm*NC*NL*Pi^2)/36 + 
       (25*CF*lm*NC*NH*Pi^2)/36 - (18676617925*CF^2*NC*Pi^3)/
        (34012224*Sqrt[3]) - (49127427895*CF*NC*NH*Pi^3)/
        (12754584*Sqrt[3]) - (51779*CF^2*NC*Pi^4)/2592 + 
       (80169175507*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(5668704*Sqrt[3]) + 
       (53315453821*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (10628820*Sqrt[3]) - (18845*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (533617655*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (26244*Sqrt[3]) - (2807281594*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (533617655*CF^2*NC*Pi*Log[3]^2)/(1259712*Sqrt[3]) - 
       (1403640797*CF*NC*NH*Pi*Log[3]^2)/(472392*Sqrt[3]) - 
       (CF*NC*(-7*CA*(34188697 + 21918600*lm) + 
          20*(56*CF*(720902 + 448335*lm) + 3*(-5158482*NM + 464940*lm*NM + 
              640731*NL + 464940*lm*NL + 43004*NH + 464940*lm*NH)))*
         Log[x]^2)/45360 - (CF*NC*(289771*CA + 1147515*CF - 475992*NM - 
          33210*NL)*Log[x]^3)/81 - (434961522967*CF^2*NC*PolyGamma[2, 1])/
        478296900 + (1039037*CF*NM*NC*PolyGamma[2, 1])/1080 - 
       (11981168573*CF*NC*NH*PolyGamma[2, 1])/15943230 + 
       (CF*NC*Log[x]*(2*(8*(-1928934*NM*(398049 + 1198450*lm + 210000*lm^2 - 
                2425300*Pi^2) - 5*(321489*NL*(3740801 + 1438140*lm + 
                  252000*lm^2 + 305400*Pi^2) + 2*NH*(9719382490089 + 
                  231173095230*lm + 40507614000*lm^2 - 5502271924240*Sqrt[3]*
                   Im[PolyLog[2, (-1)^(1/3)]]))) + 147*CF*(-2956174615059 - 
              1966945809600*lm - 396809280000*lm^2 + 122879102760*Pi^2 + 
              426894124000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              264539520000*Zeta[3])) - 147*CA*(-4038485531829 - 
            1692522799200*lm - 242494560000*lm^2 + 86363667720*Pi^2 + 
            426894124000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            264539520000*Zeta[3])))/55553299200 - 
       (6824616007093*CF^2*NC*Zeta[3])/956593800 + 
       (1353677*CF*NM*NC*Zeta[3])/540 - (2570*CF*NC*NL*Zeta[3])/3 + 
       (89257751437*CF*NC*NH*Zeta[3])/7971615 + 
       (CA*CF*NC*(6193796051520000*lm^2 - 5214900477183840*Pi^2 + 
          1568835905700000*Sqrt[3]*Pi^3 + 180743320296000*Pi^4 - 
          1636838280000*lm*(-13509 + 40*Pi^2) + 1210244841540000*Sqrt[3]*Pi*
           Log[3]^2 + 7*(-4363483835510019 - 5772180636504000*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 3845762167680000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 8298821770560000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 1113501498795520*
             PolyGamma[2, 1] + 10552155792477440*Zeta[3])))/17142160896000, 
      (16544099757056882389*CF^2*NC)/3499857849600000 - 
       (18503377*CF^2*lm*NC)/9000 - (7064*CF^2*lm^2*NC)/5 + 
       (1912126519897*CF*NM*NC)/833490000 - (28039777*CF*lm*NM*NC)/162000 - 
       (3532*CF*lm^2*NM*NC)/45 + (4219455961*CF*NC*NL)/9720000 - 
       (28039777*CF*lm*NC*NL)/162000 - (3532*CF*lm^2*NC*NL)/45 + 
       (82490454248782963*CF*NC*NH)/2187411156000 - (28039777*CF*lm*NC*NH)/
        162000 - (3532*CF*lm^2*NC*NH)/45 + (5166847451*CF^2*NC*Pi^2)/
        3888000 + (163*CF^2*lm*NC*Pi^2)/15 + (3634961*CF*NM*NC*Pi^2)/5400 + 
       (163*CF*lm*NM*NC*Pi^2)/270 - (188573*CF*NC*NL*Pi^2)/1800 + 
       (163*CF*lm*NC*NL*Pi^2)/270 + (163*CF*lm*NC*NH*Pi^2)/270 - 
       (154494416461*CF^2*NC*Pi^3)/(191318760*Sqrt[3]) - 
       (87217836433*CF*NC*NH*Pi^3)/(19131876*Sqrt[3]) - 
       (43313*CF^2*NC*Pi^4)/1944 + (7687894102801*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(398580750*Sqrt[3]) - 
       (48731149373*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (15943230*Sqrt[3]) - (175574*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        45 - (44141261846*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1476225*Sqrt[3]) - (49838763676*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(295245*Sqrt[3]) - 
       (22070630923*CF^2*NC*Pi*Log[3]^2)/(35429400*Sqrt[3]) - 
       (12459690919*CF*NC*NH*Pi*Log[3]^2)/(3542940*Sqrt[3]) - 
       (CF*NC*(-5*CA*(1992668759 + 2987606160*lm) + 
          CF*(46155317843 + 48888100800*lm) + 360*(-48501246*NM + 
            7544460*lm*NM + 10461647*NL + 7544460*lm*NL + 768820*NH + 
            7544460*lm*NH))*Log[x]^2)/3402000 - 
       (CF*NC*(36239375*CA + 95232907*CF - 180*(243020*NM + 17963*NL))*
         Log[x]^3)/6075 - (2278423701077*CF^2*NC*PolyGamma[2, 1])/
        5739562800 + (3516887*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (17682415993*CF*NC*NH*PolyGamma[2, 1])/71744535 - 
       (29716448898011*CF^2*NC*Zeta[3])/2869781400 + 
       (5098487*CF*NM*NC*Zeta[3])/1350 - (16564*CF*NC*NL*Zeta[3])/15 + 
       (1206002690746*CF*NC*NH*Zeta[3])/71744535 + 
       (CA*CF*NC*(-18364495945749811623 + 2719529543453184000*lm^2 - 
          4079753945662636080*Pi^2 + 847865357537968000*Sqrt[3]*Pi^3 + 
          73222794497865600*Pi^4 - 19443654720*lm*(-486450347 + 
            1075800*Pi^2) - 20251758161362506240*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 12289680841713408000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 31395242953405900800*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 654067561529289600*Sqrt[3]*
           Pi*Log[3]^2 + 1250398927151057600*PolyGamma[2, 1] + 
          37527682682092220800*Zeta[3]))/6299744129280000 - 
       (CF*NC*Log[x]*(-80*(-13122*NM*(6739138649 + 1621379130*lm + 
              296352000*lm^2 - 3318539700*Pi^2) - 964467*NL*
             (58673801 + 22059580*lm + 4032000*lm^2 + 4936600*Pi^2) - 
            10*NH*(86324147109093 + 2127573694386*lm + 388873094400*lm^2 - 
              48841988402480*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          5*CA*(-5321579614515051 - 2307802716787680*lm - 342208323072000*
             lm^2 + 257050833616080*Pi^2 + 692134985745280*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 373318170624000*Zeta[3]) + 
          CF*(38563311751257381 + 26437231779638400*lm + 5599772559360000*
             lm^2 - 2960172765018000*Pi^2 - 6921349857452800*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 3733181706240000*Zeta[3])))/
        2083248720000, (65041512646823028307*CF^2*NC)/10499573548800000 - 
       (1728367*CF^2*lm*NC)/400 - (5551*CF^2*lm^2*NC)/2 - 
       (251829812777*CF*NM*NC)/27783000 - (2561017*CF*lm*NM*NC)/7200 - 
       (5551*CF*lm^2*NM*NC)/36 + (1593653879*CF*NC*NL)/1296000 - 
       (2561017*CF*lm*NC*NL)/7200 - (5551*CF*lm^2*NC*NL)/36 + 
       (1614391552789202811667*CF*NC*NH)/17468665491816000 - 
       (2561017*CF*lm*NC*NH)/7200 - (5551*CF*lm^2*NC*NH)/36 + 
       (673596130829*CF^2*NC*Pi^2)/149688000 + (49*CF^2*lm*NC*Pi^2)/2 + 
       (12715943*CF*NM*NC*Pi^2)/1296 + (49*CF*lm*NM*NC*Pi^2)/36 - 
       (102935*CF*NC*NL*Pi^2)/432 + (49*CF*lm*NC*NL*Pi^2)/36 + 
       (49*CF*lm*NC*NH*Pi^2)/36 - (8439471849557*CF^2*NC*Pi^3)/
        (4591650240*Sqrt[3]) - (1394260080815*CF*NC*NH*Pi^3)/
        (114791256*Sqrt[3]) - (3872141*CF^2*NC*Pi^4)/64800 + 
       (743314525734139*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (19131876000*Sqrt[3]) + (1882808872853*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(95659380*Sqrt[3]) - 
       (252343*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
       (1205638835651*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (17714700*Sqrt[3]) - (79672004618*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(177147*Sqrt[3]) - 
       (1205638835651*CF^2*NC*Pi*Log[3]^2)/(850305600*Sqrt[3]) - 
       (39836002309*CF*NC*NH*Pi*Log[3]^2)/(4251528*Sqrt[3]) - 
       (CF*NC*(-55*CA*(81212867 + 263159820*lm) + 
          11*CF*(3625231403 + 4306251600*lm) + 
          90*(22*(-69549833 + 1329090*lm)*NM + 77*(513619 + 379740*lm)*NL + 
            12*(299328 + 2436665*lm)*NH))*Log[x]^2)/1247400 - 
       (CF*NC*(6939341*CA + 9*(2267897*CF - 2319840*NM - 63290*NL))*
         Log[x]^3)/405 + (76921338557*CF^2*NC*PolyGamma[2, 1])/2152336050 + 
       (13145659*CF*NM*NC*PolyGamma[2, 1])/1080 - 
       (1052698673297*CF*NC*NH*PolyGamma[2, 1])/430467210 - 
       (171285310523963*CF^2*NC*Zeta[3])/8609344200 + 
       (6354619*CF*NM*NC*Zeta[3])/540 - (8338*CF*NC*NL*Zeta[3])/3 + 
       (7396176916753*CF*NC*NH*Zeta[3])/215233605 + 
       (CA*CF*NC*(-834804233308519589853 + 160278615115819200000*lm^2 - 
          411607513892690337600*Pi^2 + 57894776887961020000*Sqrt[3]*Pi^3 + 
          5852434588893144000*Pi^4 - 13124466936000*lm*(-43713987 + 
            107800*Pi^2) - 1223793035168686449600*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 794848166407451520000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 2143760881337070912000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 44661685027855644000*
           Sqrt[3]*Pi*Log[3]^2 - 3377154448006528000*PolyGamma[2, 1] + 
          2281601187976964896000*Zeta[3]))/188992323878400000 + 
       CF*Log[x]*((165722311*NM*NC)/5880 - (114359*lm*NM*NC)/60 - 
         (980*lm^2*NM*NC)/3 - (59244877*NC*NL)/10800 - 
         (114359*lm*NC*NL)/60 - (980*lm^2*NC*NL)/3 - 
         (55674969559275461*NC*NH)/630182737800 - (114359*lm*NC*NH)/60 - 
         (980*lm^2*NC*NH)/3 + (680935*NM*NC*Pi^2)/54 - 
         (921*NC*NL*Pi^2)/2 + (79672004618*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(531441*Sqrt[3]) + 
         CF*NC*(-76658513833564343/2083248720000 - (298977*lm)/10 - 
           5880*lm^2 + (16081607*Pi^2)/3600 + 
           (1205638835651*Im[PolyLog[2, (-1)^(1/3)]])/(53144100*Sqrt[3]) - 
           3920*Zeta[3]) + CA*NC*(111995148308213753/4166497440000 + 
           (510783*lm)/40 + (5390*lm^2)/3 - (125628611*Pi^2)/64800 - 
           (1205638835651*Im[PolyLog[2, (-1)^(1/3)]])/(106288200*Sqrt[3]) + 
           1960*Zeta[3])), (-176501094072904099*CF^2*NC)/3149872064640000 - 
       (124339919*CF^2*lm*NC)/27000 - (15673*CF^2*lm^2*NC)/5 - 
       (990794161980929*CF*NM*NC)/135025380000 - (187815569*CF*lm*NM*NC)/
        486000 - (15673*CF*lm^2*NM*NC)/90 + (16040085179*CF*NC*NL)/
        9720000 - (187815569*CF*lm*NC*NL)/486000 - (15673*CF*lm^2*NC*NL)/
        90 + (1443176438573827336537*CF*NC*NH)/13101499118862000 - 
       (187815569*CF*lm*NC*NH)/486000 - (15673*CF*lm^2*NC*NH)/90 + 
       (526393324823*CF^2*NC*Pi^2)/40824000 + (931*CF^2*lm*NC*Pi^2)/45 + 
       (177396103*CF*NM*NC*Pi^2)/24300 + (931*CF*lm*NM*NC*Pi^2)/810 - 
       (13293329*CF*NC*NL*Pi^2)/48600 + (931*CF*lm*NC*NL*Pi^2)/810 + 
       (931*CF*lm*NC*NH*Pi^2)/810 - (1060466575763*CF^2*NC*Pi^3)/
        (430467210*Sqrt[3]) - (2342418790663*CF*NC*NH*Pi^3)/
        (172186884*Sqrt[3]) - (43204*CF^2*NC*Pi^4)/675 + 
       (89680917377011*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1793613375*Sqrt[3]) - (202568970323*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(143489070*Sqrt[3]) - 
       (146944*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (1211961800872*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (13286025*Sqrt[3]) - (1338525023236*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (151495225109*CF^2*NC*Pi*Log[3]^2)/(79716150*Sqrt[3]) - 
       (334631255809*CF*NC*NH*Pi*Log[3]^2)/(31886460*Sqrt[3]) - 
       (CF*NC*(-132*CA*(-6091457707 + 1986265050*lm) + 
          33*CF*(-34810782817 + 26002015200*lm) + 
          20*(44*(-1660995074 + 54170865*lm)*NM + 
            3*(231*(4686139 + 3439420*lm)*NL + 10*(10486711 + 79450602*lm)*
               NH)))*Log[x]^2)/18711000 - 
       (CF*NC*(209481223*CA + 197893846*CF - 310244100*NM - 10318260*NL)*
         Log[x]^3)/6075 + (487267082769557*CF^2*NC*PolyGamma[2, 1])/
        51656065200 + (9818879*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (628458065128*CF*NC*NH*PolyGamma[2, 1])/645700815 - 
       (119889868065359*CF^2*NC*Zeta[3])/5165606520 + 
       (13557358*CF*NM*NC*Zeta[3])/675 - (150548*CF*NC*NL*Zeta[3])/45 + 
       (30946820524036*CF*NC*NH*Zeta[3])/645700815 + 
       (CA*CF*NC*(-209692528278566341131 + 135761848390032480000*lm^2 - 
          905218883275913413200*Pi^2 + 58198405677873440000*Sqrt[3]*Pi^3 + 
          4666570462342656000*Pi^4 - 145827410400*lm*(-3250850059 + 
            6144600*Pi^2) - 1181205298956087283200*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 694282200999690240000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 2155003821672113664000*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 44895912951502368000*
           Sqrt[3]*Pi*Log[3]^2 - 668530437559832204000*PolyGamma[2, 1] + 
          1940185716070247912000*Zeta[3]))/141744242908800000 + 
       CF*Log[x]*((-1238602886429*NM*NC)/107163000 - (8872213*lm*NM*NC)/
          4050 - 392*lm^2*NM*NC - (522513967*NC*NL)/81000 - 
         (8872213*lm*NC*NL)/4050 - 392*lm^2*NC*NL - 
         (46787674400237951*NC*NH)/472637053350 - (8872213*lm*NC*NH)/4050 - 
         392*lm^2*NC*NH + (5077097*NM*NC*Pi^2)/405 - (224891*NC*NL*Pi^2)/
          405 + (1338525023236*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7971615*Sqrt[3]) + CF*NC*(-2624761966130111/3124873080000 - 
           (7681513*lm)/225 - 7056*lm^2 + (97523497*Pi^2)/8100 + 
           (1211961800872*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) - 
           4704*Zeta[3]) + CA*NC*(31562777045180701/3124873080000 + 
           (119820743*lm)/8100 + 2156*lm^2 - (1293617*Pi^2)/225 - 
           (605980900436*Im[PolyLog[2, (-1)^(1/3)]])/(39858075*Sqrt[3]) + 
           2352*Zeta[3])), (-6931486806772988413*CF^2*NC)/157493603232000 - 
       (24207749*CF^2*lm*NC)/2700 - 5740*CF^2*lm^2*NC - 
       (138703385313179*CF*NM*NC)/675126900 - (35831249*CF*lm*NM*NC)/
        48600 - (2870*CF*lm^2*NM*NC)/9 + (2943803159*CF*NC*NL)/729000 - 
       (35831249*CF*lm*NC*NL)/48600 - (2870*CF*lm^2*NC*NL)/9 + 
       (294931656533539524638597*CF*NC*NH)/1199333065172492250 - 
       (35831249*CF*lm*NC*NH)/48600 - (2870*CF*lm^2*NC*NH)/9 + 
       (1026101003681*CF^2*NC*Pi^2)/26943840 + (392*CF^2*lm*NC*Pi^2)/9 + 
       (131727274*CF*NM*NC*Pi^2)/1215 + (196*CF*lm*NM*NC*Pi^2)/81 - 
       (1387729*CF*NC*NL*Pi^2)/2430 + (196*CF*lm*NC*NL*Pi^2)/81 + 
       (196*CF*lm*NC*NH*Pi^2)/81 - (878188163657*CF^2*NC*Pi^3)/
        (172186884*Sqrt[3]) - (1402473038575*CF*NC*NH*Pi^3)/
        (43046721*Sqrt[3]) - (60893*CF^2*NC*Pi^4)/405 + 
       (268771291338773*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2869781400*Sqrt[3]) + (1456053885824*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) - 
       (175952*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (501821807804*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (2657205*Sqrt[3]) - (641130531920*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (125455451951*CF^2*NC*Pi*Log[3]^2)/(31886460*Sqrt[3]) - 
       (40070658245*CF*NC*NH*Pi*Log[3]^2)/(1594323*Sqrt[3]) - 
       (CF*NC*(-143*CA*(-121547935459 + 28094913000*lm) + 
          20*(143*CF*(-9158474593 + 4597349400*lm) + 
            5*(143*(-10888886149 + 51081660*lm)*NM + 3003*(3249677 + 
                2432460*lm)*NL + (1096802503 + 7304677380*lm)*NH)))*
         Log[x]^2)/121621500 - (2*CF*NC*(96656317*CA + 84329235*CF - 
          450995300*NM - 4054100*NL)*Log[x]^3)/2025 + 
       (184950301367591*CF^2*NC*PolyGamma[2, 1])/6457008150 + 
       (23327909*CF*NM*NC*PolyGamma[2, 1])/180 - 
       (5726639599549*CF*NC*NH*PolyGamma[2, 1])/860934420 - 
       (131883585512464*CF^2*NC*Zeta[3])/3228504075 + 
       (2288423*CF*NM*NC*Zeta[3])/30 - (68428*CF*NC*NL*Zeta[3])/9 + 
       (38629892146691*CF*NC*NH*Zeta[3])/430467210 + 
       CA*CF*NC*(14541084400680558439/787468016160000 + (15785*lm^2)/9 - 
         (3625993000313*Pi^2)/192456000 + (878188163657*Pi^3)/
          (344373768*Sqrt[3]) + (62461*Pi^4)/810 + 
         lm*(611115739/97200 - (1078*Pi^2)/81) - 
         (268771291338773*Im[PolyLog[2, (-1)^(1/3)]])/(5739562800*Sqrt[3]) + 
         (87976*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (250910903902*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2657205*Sqrt[3]) + (125455451951*Pi*Log[3]^2)/(63772920*Sqrt[3]) - 
         (184950301367591*PolyGamma[2, 1])/12914016300 + 
         (33258050173703*Zeta[3])/1291401630) + 
       CF*Log[x]*((1029248404777*NM*NC)/2143260 - (125587*lm*NM*NC)/27 - 
         784*lm^2*NM*NC - (119147057*NC*NL)/8100 - (125587*lm*NC*NL)/27 - 
         784*lm^2*NC*NL - (9469056382693081612*NC*NH)/39937831008075 - 
         (125587*lm*NC*NH)/27 - 784*lm^2*NC*NH + (8982068*NM*NC*Pi^2)/81 - 
         (102250*NC*NL*Pi^2)/81 + (641130531920*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1594323*Sqrt[3]) + 
         CF*NC*(4432974393483941/156243654000 - (219422*lm)/3 - 14112*lm^2 + 
           (43366703*Pi^2)/1215 + (501821807804*Im[PolyLog[2, (-1)^(1/3)]])/
            (7971615*Sqrt[3]) - 9408*Zeta[3]) + 
         CA*NC*(11233672664040443/1562436540000 + (1677809*lm)/54 + 
           4312*lm^2 - (207457189*Pi^2)/12150 - 
           (250910903902*Im[PolyLog[2, (-1)^(1/3)]])/(7971615*Sqrt[3]) + 
           4704*Zeta[3])), (-4411395924378516155818343*CF^2*NC)/
        22010518519688160000 - (3036572269*CF^2*lm*NC)/330750 - 
       (31072*CF^2*lm^2*NC)/5 - (15012691432199400257*CF*NM*NC)/
        89859390390000 - (4578131869*CF*lm*NM*NC)/5953500 - 
       (15536*CF*lm^2*NM*NC)/45 + (31647439177*CF*NC*NL)/6378750 - 
       (4578131869*CF*lm*NC*NL)/5953500 - (15536*CF*lm^2*NC*NL)/45 + 
       (24106251335618018213047859*CF*NC*NH)/86351980692419442000 - 
       (4578131869*CF*lm*NC*NH)/5953500 - (15536*CF*lm^2*NC*NH)/45 + 
       (7392865498351*CF^2*NC*Pi^2)/53581500 + (1616*CF^2*lm*NC*Pi^2)/45 + 
       (2569404514*CF*NM*NC*Pi^2)/42525 + (808*CF*lm*NM*NC*Pi^2)/405 - 
       (26504311*CF*NC*NL*Pi^2)/42525 + (808*CF*lm*NC*NL*Pi^2)/405 + 
       (808*CF*lm*NC*NH*Pi^2)/405 - (11002489858133*CF^2*NC*Pi^3)/
        (1721868840*Sqrt[3]) - (501552452114*CF*NC*NH*Pi^3)/
        (14348907*Sqrt[3]) - (629821*CF^2*NC*Pi^4)/4050 + 
       (121490961508211557*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1054644664500*Sqrt[3]) + (2445703784968*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(215233605*Sqrt[3]) - 
       (108392*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (22004979716266*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (93002175*Sqrt[3]) - (1146405604832*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(885735*Sqrt[3]) - 
       (11002489858133*CF^2*NC*Pi*Log[3]^2)/(2232052200*Sqrt[3]) - 
       (71650350302*CF*NC*NH*Pi*Log[3]^2)/(2657205*Sqrt[3]) - 
       (CF*NC*(-117*CA*(-5355052823403 + 274676340400*lm) + 
          4*(39*CF*(-7672182002651 + 674205562800*lm) + 
            70*(26*(-81868779647 + 802625670*lm)*NM + 33033*(850613 + 
                631740*lm)*NL + 10*(331107961 + 2086826742*lm)*NH)))*
         Log[x]^2)/851350500 + (2*CF*NC*(-5662887208*CA + 4736669609*CF + 
          6992920200*NM + 97287960*NL)*Log[x]^3)/42525 + 
       (5292021547954831*CF^2*NC*PolyGamma[2, 1])/38742048900 + 
       (20703781*CF*NM*NC*PolyGamma[2, 1])/150 - 
       (55996397687033*CF*NC*NH*PolyGamma[2, 1])/19371024450 - 
       (966332452366259*CF^2*NC*Zeta[3])/135597171150 + 
       (11894581*CF*NM*NC*Zeta[3])/75 - (390568*CF*NC*NL*Zeta[3])/45 + 
       (1146034117316647*CF*NC*NH*Zeta[3])/9685512225 + 
       CA*CF*NC*(2655272009917428994298861/27513148149610200000 + 
         (85448*lm^2)/45 - (64902949943947*Pi^2)/943034400 + 
         (11002489858133*Pi^3)/(3443737680*Sqrt[3]) + (642749*Pi^4)/8100 + 
         lm*(79135229759/11907000 - (4444*Pi^2)/405) - 
         (121490961508211557*Im[PolyLog[2, (-1)^(1/3)]])/
          (2109289329000*Sqrt[3]) + (54196*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (11002489858133*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (93002175*Sqrt[3]) + (11002489858133*Pi*Log[3]^2)/
          (4464104400*Sqrt[3]) - (5292021547954831*PolyGamma[2, 1])/
          77484097800 + (2307257699101361*Zeta[3])/271194342300) + 
       CF*Log[x]*((-70696523676461*NM*NC)/3241680750 - (72126658*lm*NM*NC)/
          14175 - 896*lm^2*NM*NC - (111072821*NC*NL)/6750 - 
         (72126658*lm*NC*NL)/14175 - 896*lm^2*NC*NL - 
         (483907801940311709*NC*NH)/1901801476575 - (72126658*lm*NC*NH)/
          14175 - 896*lm^2*NC*NH + (33201992*NM*NC*Pi^2)/405 - 
         (584236*NC*NL*Pi^2)/405 + (1146405604832*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) + 
         CF*NC*(109654320422190212407/165422968672500 - (125202116*lm)/1575 - 
           16128*lm^2 + (2020238783*Pi^2)/17010 + 
           (22004979716266*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) - 
           10752*Zeta[3]) + CA*NC*(-5829967919180777209/18905482134000 + 
           (485602219*lm)/14175 + 4928*lm^2 - (9985847131*Pi^2)/170100 - 
           (11002489858133*Im[PolyLog[2, (-1)^(1/3)]])/(279006525*Sqrt[3]) + 
           5376*Zeta[3])), (-23619906904906057276113619*CF^2*NC)/
        30014343435938400000 - (248720621*CF^2*lm*NC)/14700 - 
       10812*CF^2*lm^2*NC - (708190244819753083*CF*NM*NC)/285267906000 - 
       (367922921*CF*lm*NM*NC)/264600 - (1802*CF*lm^2*NM*NC)/3 + 
       (21861454693*CF*NC*NL)/1984500 - (367922921*CF*lm*NC*NL)/264600 - 
       (1802*CF*lm^2*NC*NL)/3 + (912903233544423312320117*CF*NC*NH)/
        1570036012589444400 - (367922921*CF*lm*NC*NH)/264600 - 
       (1802*CF*lm^2*NC*NH)/3 + (1027354362305729*CF^2*NC*Pi^2)/2918916000 + 
       72*CF^2*lm*NC*Pi^2 + (215994910*CF*NM*NC*Pi^2)/189 + 
       4*CF*lm*NM*NC*Pi^2 - (154073*CF*NC*NL*Pi^2)/126 + 
       4*CF*lm*NC*NL*Pi^2 + 4*CF*lm*NC*NH*Pi^2 - 
       (15952358184659*CF^2*NC*Pi^3)/(1291401630*Sqrt[3]) - 
       (10000387103945*CF*NC*NH*Pi^3)/(129140163*Sqrt[3]) - 
       (225326*CF^2*NC*Pi^4)/675 + (1293574527534380923*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(6327867987000*Sqrt[3]) + 
       (34587220739488*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (215233605*Sqrt[3]) - (204448*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (127618865477272*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (279006525*Sqrt[3]) - (4571605533232*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (15952358184659*CF^2*NC*Pi*Log[3]^2)/(1674039150*Sqrt[3]) - 
       (285725345827*CF*NC*NH*Pi*Log[3]^2)/(4782969*Sqrt[3]) + 
       CF*((10803128279233*CF*NC)/2976750 - 268344*CF*lm*NC + 
         CA*(-1132274467897/595350 + 81994*lm)*NC + (20290953787*NM*NC)/
          1485 - 14908*lm*NM*NC - (98729*NC*NL)/5 - 14908*lm*NC*NL - 
         (31964687*NC*NH)/12285 - 14908*lm*NC*NH)*Log[x]^2 + 
       (2*CF*NC*(-4942903270*CA + 4473900393*CF + 
          18900*(1558327*NM + 3727*NL))*Log[x]^3)/14175 + 
       (61206585901080773*CF^2*NC*PolyGamma[2, 1])/174339220050 + 
       (78560737*CF*NM*NC*PolyGamma[2, 1])/60 - 
       (221637863079343*CF*NC*NH*PolyGamma[2, 1])/13947137604 + 
       (4181470564740002*CF^2*NC*Zeta[3])/610187270175 + 
       (6437019*CF*NM*NC*Zeta[3])/10 - 18316*CF*NC*NL*Zeta[3] + 
       (1450332595432529*CF*NC*NH*Zeta[3])/6973568802 + 
       CA*CF*NC*(11554723220794360037455097/30014343435938400000 + 
         (9911*lm^2)/3 - (973037024791*Pi^2)/5544000 + (15952358184659*Pi^3)/
          (2582803260*Sqrt[3]) + (114823*Pi^4)/675 + 
         lm*(6272261731/529200 - 22*Pi^2) - (1293574527534380923*
           Im[PolyLog[2, (-1)^(1/3)]])/(12655735974000*Sqrt[3]) + 
         (102224*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (63809432738636*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (279006525*Sqrt[3]) + (15952358184659*Pi*Log[3]^2)/
          (3348078300*Sqrt[3]) - (61206585901080773*PolyGamma[2, 1])/
          348678440100 + (10533822818441977*Zeta[3])/1220374540350) + 
       CF*Log[x]*((172659326088671*NM*NC)/28814940 - (1060277*lm*NM*NC)/
          105 - 1680*lm^2*NM*NC - (219580637*NC*NL)/6300 - 
         (1060277*lm*NC*NL)/105 - 1680*lm^2*NC*NL - 
         (12279256101997479983*NC*NH)/21784271458950 - (1060277*lm*NC*NH)/
          105 - 1680*lm^2*NC*NH + (3115180*NM*NC*Pi^2)/3 - 
         (9134*NC*NL*Pi^2)/3 + (4571605533232*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4782969*Sqrt[3]) + 
         CF*NC*(238371913050647971139/180461420370000 - (5567862*lm)/35 - 
           30240*lm^2 + (1503469888*Pi^2)/4725 + 
           (127618865477272*Im[PolyLog[2, (-1)^(1/3)]])/(837019575*Sqrt[3]) - 
           20160*Zeta[3]) + CA*NC*(-221092422634284322787/360922840740000 + 
           (14132647*lm)/210 + 9240*lm^2 - (2229697091*Pi^2)/14175 - 
           (63809432738636*Im[PolyLog[2, (-1)^(1/3)]])/(837019575*Sqrt[3]) + 
           10080*Zeta[3])), (-1915258771838565422093790013777*CF^2*NC)/
        669559973368913827200000 - (29618611097*CF^2*lm*NC)/1764000 - 
       (56631*CF^2*lm^2*NC)/5 - (3357776608001382628922009*CF*NM*NC)/
        2105824860659520000 - (44603173697*CF*lm*NM*NC)/31752000 - 
       (18877*CF*lm^2*NM*NC)/30 + (24228720870031*CF*NC*NL)/1905120000 - 
       (44603173697*CF*lm*NC*NL)/31752000 - (18877*CF*lm^2*NC*NL)/30 + 
       (225539509365964884944366803*CF*NC*NH)/355276720563097132800 - 
       (44603173697*CF*lm*NC*NH)/31752000 - (18877*CF*lm^2*NC*NH)/30 + 
       (34436391985708831*CF^2*NC*Pi^2)/22289904000 + (291*CF^2*lm*NC*Pi^2)/
        5 + (15780460067*CF*NM*NC*Pi^2)/37800 + (97*CF*lm*NM*NC*Pi^2)/30 - 
       (2020747*CF*NC*NL*Pi^2)/1575 + (97*CF*lm*NC*NL*Pi^2)/30 + 
       (97*CF*lm*NC*NH*Pi^2)/30 - (182245755530005*CF^2*NC*Pi^3)/
        (12397455648*Sqrt[3]) - (31095888117497*CF*NC*NH*Pi^3)/
        (387420489*Sqrt[3]) - (5431873*CF^2*NC*Pi^4)/16200 + 
       (3681835595666506861*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (15186883168800*Sqrt[3]) + (20798308745963*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(387420489*Sqrt[3]) - 
       (130862*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (36449151106001*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (66961566*Sqrt[3]) - (71076315697136*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23914845*Sqrt[3]) - 
       (36449151106001*CF^2*NC*Pi*Log[3]^2)/(3214155168*Sqrt[3]) - 
       (4442269731071*CF*NC*NH*Pi*Log[3]^2)/(71744535*Sqrt[3]) - 
       (CF*NC*(CA*(184964155523021849 - 1832904502228800*lm) + 
          8*(104*CF*(-440775772260067 + 7209851625900*lm) + 
            315*((-40154435156023 + 132244192080*lm)*NM + 
              14*(2574*(4899871 + 3669780*lm)*NL + 5*(344415199 + 
                  1889202744*lm)*NH))))*Log[x]^2)/20432412000 + 
       (CF*NC*(-224717835199*CA + 42*(9034169941*CF + 
            360*(11484085*NM + 61163*NL)))*Log[x]^3)/85050 + 
       (2118029379494137961*CF^2*NC*PolyGamma[2, 1])/1394713760400 + 
       (275953303*CF*NM*NC*PolyGamma[2, 1])/225 - 
       (631142108829452*CF*NC*NH*PolyGamma[2, 1])/87169610025 + 
       CA*CF*NC*(761657938150693207678048693819/535647978695131061760000 + 
         (207647*lm^2)/60 - (882558851769887*Pi^2)/1143072000 + 
         (182245755530005*Pi^3)/(24794911296*Sqrt[3]) + 
         (5515681*Pi^4)/32400 + lm*(770346745867/63504000 - (1067*Pi^2)/60) - 
         (3681835595666506861*Im[PolyLog[2, (-1)^(1/3)]])/
          (30373766337600*Sqrt[3]) + (65431*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (36449151106001*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (133923132*Sqrt[3]) + (36449151106001*Pi*Log[3]^2)/
          (6428310336*Sqrt[3]) - (2118029379494137961*PolyGamma[2, 1])/
          2789427520800 - (1711642677985687661*Zeta[3])/9762996322800) + 
       (363221277337931353*CF^2*NC*Zeta[3])/976299632280 + 
       (38702484*CF*NM*NC*Zeta[3])/25 - (300674*CF*NC*NL*Zeta[3])/15 + 
       (22866310327719776*CF*NC*NH*Zeta[3])/87169610025 + 
       CF*Log[x]*((-794707742777617717*NM*NC)/2921834916000 - 
         (22317709*lm*NM*NC)/2100 - 1848*lm^2*NM*NC - (42497288147*NC*NL)/
          1134000 - (22317709*lm*NC*NL)/2100 - 1848*lm^2*NC*NL - 
         (480107484422627649773*NC*NH)/821578237880400 - 
         (22317709*lm*NC*NH)/2100 - 1848*lm^2*NC*NH + 
         (22975832*NM*NC*Pi^2)/45 - (150046*NC*NL*Pi^2)/45 + 
         (71076315697136*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (71744535*Sqrt[3]) + CF*NC*(5861958930487957419711419/
            619343594709840000 - (58221327*lm)/350 - 33264*lm^2 + 
           (145859635267*Pi^2)/113400 + (36449151106001*
             Im[PolyLog[2, (-1)^(1/3)]])/(200884698*Sqrt[3]) - 
           22176*Zeta[3]) + CA*NC*(-5800805862420748732613033/
            1238687189419680000 + (299825999*lm)/4200 + 10164*lm^2 - 
           (87308164999*Pi^2)/136080 - (36449151106001*
             Im[PolyLog[2, (-1)^(1/3)]])/(401769396*Sqrt[3]) + 
           11088*Zeta[3])), (-5142817657768262759881607087401*CF^2*NC)/
        596864890546003183104000 - (279321989*CF^2*lm*NC)/9408 - 
       (37905*CF^2*lm^2*NC)/2 - (1075464836348130421321547*CF*NM*NC)/
        40110949726848000 - (413050829*CF*lm*NM*NC)/169344 - 
       (12635*CF*lm^2*NM*NC)/12 + (1872689077037*CF*NC*NL)/71124480 - 
       (413050829*CF*lm*NC*NL)/169344 - (12635*CF*lm^2*NC*NL)/12 + 
       (183744246418691547376937066108363*CF*NC*NH)/
        146619860362625681929497600 - (413050829*CF*lm*NC*NH)/169344 - 
       (12635*CF*lm^2*NC*NH)/12 + (3337981459557713*CF^2*NC*Pi^2)/
        1005903360 + (225*CF^2*lm*NC*Pi^2)/2 + (15593093693*CF*NM*NC*Pi^2)/
        1296 + (25*CF*lm*NM*NC*Pi^2)/4 - (605015*CF*NC*NL*Pi^2)/252 + 
       (25*CF*lm*NC*NL*Pi^2)/4 + (25*CF*lm*NC*NH*Pi^2)/4 - 
       (4013547186078385*CF^2*NC*Pi^3)/(148769467776*Sqrt[3]) - 
       (778864521558935*CF*NC*NH*Pi^3)/(4649045868*Sqrt[3]) - 
       (582385*CF^2*NC*Pi^4)/864 + (3007530002499114013*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7289703921024*Sqrt[3]) + 
       (61427901386573761*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (162716605380*Sqrt[3]) - (157615*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/2 - (802709437215677*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(803538792*Sqrt[3]) - 
       (89013088178164*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (14348907*Sqrt[3]) - (802709437215677*CF^2*NC*Pi*Log[3]^2)/
        (38569862016*Sqrt[3]) - (22253272044541*CF*NC*NH*Pi*Log[3]^2)/
        (172186884*Sqrt[3]) + CF*((34963374625348381*CF*NC)/908107200 - 
         599580*CF*lm*NC + CA*(-436012587521157/22422400 + 183205*lm)*NC + 
         (155970330357031*NM*NC)/1081080 - 33310*lm*NM*NC - 
         (87687*NC*NL)/2 - 33310*lm*NC*NL - (17166776299*NC*NH)/2625480 - 
         33310*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-34423310429*CA + 9*(6457427863*CF + 
            840*(31237467*NM + 16655*NL)))*Log[x]^3)/5670 + 
       (1840636432031907091*CF^2*NC*PolyGamma[2, 1])/523017660150 + 
       (588969248*CF*NM*NC*PolyGamma[2, 1])/45 - 
       (14389124516131351*CF*NC*NH*PolyGamma[2, 1])/418414128120 + 
       CA*CF*NC*(179219338134213310021655265431309/
          41780542338220222817280000 + (138985*lm^2)/24 - 
         (72280223369365027*Pi^2)/43589145600 + (4013547186078385*Pi^3)/
          (297538935552*Sqrt[3]) + (591025*Pi^4)/1728 + 
         lm*(7039830799/338688 - (275*Pi^2)/8) - 
         (3007530002499114013*Im[PolyLog[2, (-1)^(1/3)]])/
          (14579407842048*Sqrt[3]) + (157615*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          4 + (802709437215677*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1607077584*Sqrt[3]) + (802709437215677*Pi*Log[3]^2)/
          (77139724032*Sqrt[3]) - (1840636432031907091*PolyGamma[2, 1])/
          1046035320300 - (27395546415980431777*Zeta[3])/58577977936800) + 
       (28867803766470722617*CF^2*NC*Zeta[3])/29288988968400 + 
       (251452501*CF*NM*NC*Zeta[3])/45 - 39985*CF*NC*NL*Zeta[3] + 
       (91946502532909409*CF*NC*NH*Zeta[3])/209207064060 + 
       CF*Log[x]*((26392561539358129103*NM*NC)/389577988800 - 
         (1122417*lm*NM*NC)/56 - 3300*lm^2*NM*NC - (15886222049*NC*NL)/
          211680 - (1122417*lm*NC*NL)/56 - 3300*lm^2*NC*NL - 
         (24324063652232528615574653*NC*NH)/19944633302784590400 - 
         (1122417*lm*NC*NH)/56 - 3300*lm^2*NC*NH + (93713818*NM*NC*Pi^2)/
          9 - (19955*NC*NL*Pi^2)/3 + (89013088178164*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(43046721*Sqrt[3]) + 
         CF*NC*(286604576847767404503839011/19323520154947008000 - 
           (8854353*lm)/28 - 59400*lm^2 + (89703463691*Pi^2)/30240 + 
           (802709437215677*Im[PolyLog[2, (-1)^(1/3)]])/(2410616376*
             Sqrt[3]) - 39600*Zeta[3]) + CA*NC*(-282819026944378795581156181/
            38647040309894016000 + (14933787*lm)/112 + 18150*lm^2 - 
           (268414921753*Pi^2)/181440 - (802709437215677*
             Im[PolyLog[2, (-1)^(1/3)]])/(4821232752*Sqrt[3]) + 
           19800*Zeta[3])), (-1290733877404396058134070651666153*CF^2*NC)/
        37602488104398200535552000 - (7818684347*CF^2*lm*NC)/272160 - 
       19336*CF^2*lm^2*NC - (2168729149132425667079351*CF*NM*NC)/
        180499273770816000 - (11765548667*CF*lm*NM*NC)/4898880 - 
       (9668*CF*lm^2*NM*NC)/9 + (2088505156945757*CF*NC*NL)/72013536000 - 
       (11765548667*CF*lm*NC*NL)/4898880 - (9668*CF*lm^2*NC*NL)/9 + 
       (10191408923143173221915242079251*CF*NC*NH)/
        7689852816221626674624000 - (11765548667*CF*lm*NC*NH)/4898880 - 
       (9668*CF*lm^2*NC*NH)/9 + (430204503623983213*CF^2*NC*Pi^2)/
        24518894400 + (805*CF^2*lm*NC*Pi^2)/9 + (460051385147*CF*NM*NC*Pi^2)/
        204120 + (805*CF*lm*NM*NC*Pi^2)/162 - (1779320*CF*NC*NL*Pi^2)/729 + 
       (805*CF*lm*NC*NL*Pi^2)/162 + (805*CF*lm*NC*NH*Pi^2)/162 - 
       (10319396679500381*CF^2*NC*Pi^3)/(334731302496*Sqrt[3]) - 
       (1177191614138785*CF*NC*NH*Pi^3)/(6973568802*Sqrt[3]) - 
       (2140543*CF^2*NC*Pi^4)/3240 + (194669693020588906553*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(410045845557600*Sqrt[3]) + 
       (39360325265235287*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (244074908070*Sqrt[3]) - (244442*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/3 - (10319396679500381*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9039811410*Sqrt[3]) - 
       (269072368946008*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) - (10319396679500381*CF^2*NC*Pi*Log[3]^2)/
        (433910947680*Sqrt[3]) - (33634046118251*CF*NC*NH*Pi*Log[3]^2)/
        (258280326*Sqrt[3]) - 
       (CF*NC*(-34*CA*(-214149801668636969 + 395386696504800*lm) + 
          15*(85*CF*(-11402914693564201 + 34506475331328*lm) + 
            56*(51*(-43665951427201 + 57054357360*lm)*NM + 
              143*(64260*(420167 + 316652*lm)*NL + (4137362059 + 20348057520*
                   lm)*NH))))*Log[x]^2)/69470200800 + 
       (CF*NC*(-494667330760*CA + 955949927137*CF + 
          5040*(39004883*NM + 79163*NL))*Log[x]^3)/17010 + 
       (24336791357472326533*CF^2*NC*PolyGamma[2, 1])/1506290861232 + 
       (21296122676*CF*NM*NC*PolyGamma[2, 1])/2025 - 
       (50559560270481769*CF*NC*NH*PolyGamma[2, 1])/3138105960900 + 
       CA*CF*NC*(644718941632092045391716965488351/
          37602488104398200535552000 + (53174*lm^2)/9 - 
         (860334756167725361*Pi^2)/98075577600 + (10319396679500381*Pi^3)/
          (669462604992*Sqrt[3]) + (722101*Pi^4)/2160 + 
         lm*(203095835977/9797760 - (8855*Pi^2)/324) - 
         (194669693020588906553*Im[PolyLog[2, (-1)^(1/3)]])/
          (820091691115200*Sqrt[3]) + (122221*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          3 + (10319396679500381*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (18079622820*Sqrt[3]) + (10319396679500381*Pi*Log[3]^2)/
          (867821895360*Sqrt[3]) - (24336791357472326533*PolyGamma[2, 1])/
          3012581722464 - (83179006520394886313*Zeta[3])/52720180143120) + 
       (84312244902929429507*CF^2*NC*Zeta[3])/26360090071560 + 
       (31411936402*CF*NM*NC*Zeta[3])/2025 - (1141646*CF*NC*NL*Zeta[3])/
        27 + (839040403037675231*CF*NC*NH*Zeta[3])/1569052980450 + 
       CF*Log[x]*((-4853782890147889703*NM*NC)/584366983200 - 
         (19876225*lm*NM*NC)/972 - 3520*lm^2*NM*NC - (1116392841959*NC*NL)/
          14288400 - (19876225*lm*NC*NL)/972 - 3520*lm^2*NC*NL - 
         (257130708609312885031697*NC*NH)/209209440238999200 - 
         (19876225*lm*NC*NH)/972 - 3520*lm^2*NC*NH + (26018596*NM*NC*Pi^2)/
          9 - (190006*NC*NL*Pi^2)/27 + (269072368946008*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(129140163*Sqrt[3]) + 
         CF*NC*(9783969081965452878206509561/86955840697261536000 - 
           (17310145*lm)/54 - 63360*lm^2 + (492076096123*Pi^2)/34020 + 
           (10319396679500381*Im[PolyLog[2, (-1)^(1/3)]])/
            (27119434230*Sqrt[3]) - 42240*Zeta[3]) + 
         CA*NC*(-4883522716264730275473665807/86955840697261536000 + 
           (266538635*lm)/1944 + 19360*lm^2 - (983722978181*Pi^2)/136080 - 
           (10319396679500381*Im[PolyLog[2, (-1)^(1/3)]])/
            (54238868460*Sqrt[3]) + 21120*Zeta[3])), 
      (-1920601838951909235564258278865353*CF^2*NC)/
        22561492862638920321331200 - (37478622829*CF^2*lm*NC)/762048 - 
       (62755*CF^2*lm^2*NC)/2 - (102957375218964344246379487*CF*NM*NC)/
        360998547541632000 - (55411993669*CF*lm*NM*NC)/13716864 - 
       (62755*CF*lm^2*NM*NC)/36 + (1640215588057273*CF*NC*NL)/28805414400 - 
       (55411993669*CF*lm*NC*NL)/13716864 - (62755*CF*lm^2*NC*NL)/36 + 
       (340343163553414158762468269502934651771*CF*NC*NH)/
        135764859000678689567847245184000 - (55411993669*CF*lm*NC*NH)/
        13716864 - (62755*CF*lm^2*NC*NH)/36 + 
       (1219641493886530889*CF^2*NC*Pi^2)/39230231040 + 
       (3025*CF^2*lm*NC*Pi^2)/18 + (52063833143519*CF*NM*NC*Pi^2)/408240 + 
       (3025*CF*lm*NM*NC*Pi^2)/324 - (89821105*CF*NC*NL*Pi^2)/20412 + 
       (3025*CF*lm*NC*NL*Pi^2)/324 + (3025*CF*lm*NC*NH*Pi^2)/324 - 
       (218154913722371005*CF^2*NC*Pi^3)/(4016775629952*Sqrt[3]) - 
       (42191237834110505*CF*NC*NH*Pi^3)/(125524238436*Sqrt[3]) - 
       (3274645*CF^2*NC*Pi^4)/2592 + (768895960570998471101*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(984110029338240*Sqrt[3]) + 
       (3560523280195787083*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (4393348345260*Sqrt[3]) - (2561185*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/18 - (43630982744474201*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(21695547384*Sqrt[3]) - 
       (4821855752469772*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (387420489*Sqrt[3]) - (43630982744474201*CF^2*NC*Pi*Log[3]^2)/
        (1041386274432*Sqrt[3]) - (1205463938117443*CF*NC*NH*Pi*Log[3]^2)/
        (4649045868*Sqrt[3]) - 
       (CF*NC*(-969*CA*(-1011194833872410749 + 2052210272112000*lm) + 
          646*CF*(-3027049070144036479 + 10074486790368000*lm) + 
          1680*(323*(-14888184048742051 + 666302036400*lm)*NM + 
            640179540*(440399 + 336180*lm)*NL + (46436467375763 + 
              215215557757200*lm)*NH))*Log[x]^2)/5279735260800 + 
       (CF*NC*(-2854794898669*CA + 5491449975503*CF + 
          7560*(2929948921*NM + 308165*NL))*Log[x]^3)/51030 + 
       (945850861838798855099*CF^2*NC*PolyGamma[2, 1])/28242953648100 + 
       (53076804836*CF*NM*NC*PolyGamma[2, 1])/405 - 
       (777492925319367259*CF*NC*NH*PolyGamma[2, 1])/11297181459240 + 
       CA*CF*NC*(47972238143150333486922436022581727/
          1128074643131946016066560000 + (690305*lm^2)/72 - 
         (554315752276141727*Pi^2)/35663846400 + (218154913722371005*Pi^3)/
          (8033551259904*Sqrt[3]) + (1104455*Pi^4)/1728 + 
         lm*(944288186039/27433728 - (33275*Pi^2)/648) - 
         (768895960570998471101*Im[PolyLog[2, (-1)^(1/3)]])/
          (1968220058676480*Sqrt[3]) + (2561185*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          36 + (43630982744474201*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (43391094768*Sqrt[3]) + (43630982744474201*Pi*Log[3]^2)/
          (2082772548864*Sqrt[3]) - (945850861838798855099*PolyGamma[2, 1])/
          56485907296200 - (8695442705243736758749*Zeta[3])/
          1581605404293600) + (8772902043728635288069*CF^2*NC*Zeta[3])/
        790802702146800 + (18456350137*CF*NM*NC*Zeta[3])/405 - 
       (2178715*CF*NC*NL*Zeta[3])/27 + (4873691832423600701*CF*NC*NH*
         Zeta[3])/5648590729620 + CF*Log[x]*((2588069136308834809619*NM*NC)/
          3506201899200 - (504326779*lm*NM*NC)/13608 - 6050*lm^2*NM*NC - 
         (855659888983*NC*NL)/5715360 - (504326779*lm*NC*NL)/13608 - 
         6050*lm^2*NC*NL - (475662094279405401315293232059*NC*NH)/
          194400340802241402628800 - (504326779*lm*NC*NH)/13608 - 
         6050*lm^2*NC*NH + (325557442*NM*NC*Pi^2)/3 - (362615*NC*NL*Pi^2)/
          27 + (4821855752469772*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(73221772971703954654414098067/
            521735044183569216000 - (442580479*lm)/756 - 108900*lm^2 + 
           (22720983950647*Pi^2)/816480 + (43630982744474201*
             Im[PolyLog[2, (-1)^(1/3)]])/(65086642152*Sqrt[3]) - 
           72600*Zeta[3]) + CA*NC*(-73027117987013941085041475953/
            1043470088367138432000 + (6700192169*lm)/27216 + 33275*lm^2 - 
           (22708589068063*Pi^2)/1632960 - (43630982744474201*
             Im[PolyLog[2, (-1)^(1/3)]])/(130173284304*Sqrt[3]) + 
           36300*Zeta[3])), (-8299550340441234198638902136207612210557*CF^2*
         NC)/20783365206402190413506284800000 - (63426368987*CF^2*lm*NC)/
        1360800 - (156629*CF^2*lm^2*NC)/5 - (48353191215345424420430826593*CF*
         NM*NC)/646619846276263860000 - (95397480467*CF*lm*NM*NC)/
        24494400 - (156629*CF*lm^2*NM*NC)/90 + (806030605811069*CF*NC*NL)/
        13335840000 - (95397480467*CF*lm*NC*NL)/24494400 - 
       (156629*CF*lm^2*NC*NL)/90 + (2628738168540035944173211899827758154761*
         CF*NC*NH)/1018236442505090171758854338880000 - 
       (95397480467*CF*lm*NC*NH)/24494400 - (156629*CF*lm^2*NC*NH)/90 + 
       (2712769218324839269*CF^2*NC*Pi^2)/13621608000 + 
       (5929*CF^2*lm*NC*Pi^2)/45 + (2086954915273*CF*NM*NC*Pi^2)/510300 + 
       (5929*CF*lm*NM*NC*Pi^2)/810 - (317781607*CF*NC*NL*Pi^2)/72900 + 
       (5929*CF*lm*NC*NL*Pi^2)/810 + (5929*CF*lm*NC*NH*Pi^2)/810 - 
       (226164450292534169*CF^2*NC*Pi^3)/(3765727153080*Sqrt[3]) - 
       (31141801863135572*CF*NC*NH*Pi^3)/(94143178827*Sqrt[3]) - 
       (18194*CF^2*NC*Pi^4)/15 + (505413360911552981287*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(576626970315375*Sqrt[3]) + 
       (2617448928712103543*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (6590022517890*Sqrt[3]) - (2150368*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/15 - (452328900585068338*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(203395756725*Sqrt[3]) - 
       (71181261401452736*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5811307335*Sqrt[3]) - (226164450292534169*CF^2*NC*Pi*Log[3]^2)/
        (4881498161400*Sqrt[3]) - (4448828837590796*CF*NC*NH*Pi*Log[3]^2)/
        (17433922005*Sqrt[3]) - 
       (CF*NC*(-57*CA*(-17280481085942481581 + 5593266498619800*lm) + 
          5*(3040*CF*(-129567013672454054 + 68644634301243*lm) + 
            21*(38*(-10099883976952001 + 14527964931480*lm)*NM + 
              128035908*(5694071 + 4311780*lm)*NL + (122619335456447 + 
                552062667396240*lm)*NH)))*Log[x]^2)/824958634500 + 
       (CF*NC*(-27933509137105*CA + 55501809554572*CF + 3744003468240*NM + 
          3984084720*NL)*Log[x]^3)/85050 + (58060070715445909022597*CF^2*NC*
         PolyGamma[2, 1])/338915443777200 + 
       (707961322627*CF*NM*NC*PolyGamma[2, 1])/8100 - 
       (2779938531179723317*CF*NC*NH*PolyGamma[2, 1])/84728860944300 + 
       CA*CF*NC*(8298156144730475759368482042669874361263/
          41566730412804380827012569600000 + (1722919*lm^2)/180 - 
         (246611873194428247*Pi^2)/2476656000 + (226164450292534169*Pi^3)/
          (7531454306160*Sqrt[3]) + (1239953*Pi^4)/2025 + 
         lm*(1646166366097/48988800 - (65219*Pi^2)/1620) - 
         (505413360911552981287*Im[PolyLog[2, (-1)^(1/3)]])/
          (1153253940630750*Sqrt[3]) + (1075184*Im[PolyLog[2, (-1)^(1/3)]]^2)/
          15 + (226164450292534169*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (203395756725*Sqrt[3]) + (226164450292534169*Pi*Log[3]^2)/
          (9762996322800*Sqrt[3]) - (58060070715445909022597*PolyGamma[2, 1])/
          677830887554400 - (16677882218617846401923*Zeta[3])/
          2372408106440400) + (3354846790924111284547*CF^2*NC*Zeta[3])/
        237240810644040 + (620945638147*CF*NM*NC*Zeta[3])/4050 - 
       (11196614*CF*NC*NL*Zeta[3])/135 + (43167873798601452563*CF*NC*NH*
         Zeta[3])/42364430472150 + CF*Log[x]*
        ((-404188853233795165864343*NM*NC)/2533230872172000 - 
         (895642253*lm*NM*NC)/24300 - 6292*lm^2*NM*NC - 
         (401534270807*NC*NL)/2646000 - (895642253*lm*NC*NL)/24300 - 
         6292*lm^2*NC*NL - (3511305733255075928481344358539*NC*NH)/
          1458002556016810519716000 - (895642253*lm*NC*NH)/24300 - 
         6292*lm^2*NC*NH + (495493523*NM*NC*Pi^2)/45 - 
         (1864126*NC*NL*Pi^2)/135 + (71181261401452736*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(17433922005*Sqrt[3]) + 
         CF*NC*(723084595733120624678798538352361/565430354133943137840000 - 
           (780970553*lm)/1350 - 113256*lm^2 + (5581477232957*Pi^2)/34020 + 
           (452328900585068338*Im[PolyLog[2, (-1)^(1/3)]])/
            (610187270175*Sqrt[3]) - 75504*Zeta[3]) + 
         CA*NC*(-361440750527622567008324882666113/565430354133943137840000 + 
           (11992603183*lm)/48600 + 34606*lm^2 - (27905314392271*Pi^2)/
            340200 - (226164450292534169*Im[PolyLog[2, (-1)^(1/3)]])/
            (610187270175*Sqrt[3]) + 37752*Zeta[3])), 
      (-151811434322095326815061181521498766886789*CF^2*NC)/
        187050286857619713721556563200000 - (8228513669*CF^2*lm*NC)/105840 - 
       49588*CF^2*lm^2*NC - (149937314249699750255735261807*CF*NM*NC)/
        49266274002001056000 - (12164809109*CF*lm*NM*NC)/1905120 - 
       (24794*CF*lm^2*NM*NC)/9 + (1366120599251291*CF*NC*NL)/12002256000 - 
       (12164809109*CF*lm*NC*NL)/1905120 - (24794*CF*lm^2*NC*NL)/9 + 
       (4321913515427801544339529821535304076769*CF*NC*NH)/
        916412798254581154582968904992000 - (12164809109*CF*lm*NC*NH)/
        1905120 - (24794*CF*lm^2*NC*NH)/9 + 
       (70257767143182187969*CF^2*NC*Pi^2)/245188944000 + 
       242*CF^2*lm*NC*Pi^2 + (2197611125773*CF*NM*NC*Pi^2)/1620 + 
       (121*CF*lm*NM*NC*Pi^2)/9 - (86481263*CF*NC*NL*Pi^2)/11340 + 
       (121*CF*lm*NC*NL*Pi^2)/9 + (121*CF*lm*NC*NH*Pi^2)/9 - 
       (13877150872245013447*CF^2*NC*Pi^3)/(135566177510880*Sqrt[3]) - 
       (537111683695798295*CF*NC*NH*Pi^3)/(847288609443*Sqrt[3]) - 
       (36122449*CF^2*NC*Pi^4)/16200 + (233068916894441963480503*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(166068567450828000*Sqrt[3]) + 
       (47996490795534588253*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (29655101330505*Sqrt[3]) - (3653254*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (13877150872245013447*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3661123621050*Sqrt[3]) - 
       (245536769689507792*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) - (13877150872245013447*CF^2*NC*Pi*Log[3]^2)/
        (175733933810400*Sqrt[3]) - (15346048105594237*CF*NC*NH*Pi*Log[3]^2)/
        (31381059609*Sqrt[3]) - 
       (CF*NC*(-95*CA*(-119312149372084414013 + 50278455753926400*lm) + 
          2*(19*CF*(-596294150499618857053 + 411369183441216000*lm) + 
            12600*(57*(-74791692078885107 + 604599035040*lm)*NM + 
              64017954*(702617 + 538320*lm)*NL + (8038752383663 + 
                34462144997280*lm)*NH)))*Log[x]^2)/6599669076000 + 
       (4*CF*NC*(-5496739474112*CA + 10898282638843*CF + 
          9450*(5169172909*NM + 98692*NL))*Log[x]^3)/42525 + 
       (26422654013234622359867*CF^2*NC*PolyGamma[2, 1])/84728860944300 + 
       (284593060687*CF*NM*NC*PolyGamma[2, 1])/216 - 
       (2628277892441878897*CF*NC*NH*PolyGamma[2, 1])/20334926626632 + 
       CA*CF*NC*(3457186329440676221015710932961958977/
          8520876770117516113409100000 + (136367*lm^2)/9 - 
         (6386920708389149231*Pi^2)/44579808000 + (13877150872245013447*Pi^3)/
          (271132355021760*Sqrt[3]) + (36470929*Pi^4)/32400 + 
         lm*(207290415079/3810240 - (1331*Pi^2)/18) - 
         (233068916894441963480503*Im[PolyLog[2, (-1)^(1/3)]])/
          (332137134901656000*Sqrt[3]) + (1826627*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/15 + (13877150872245013447*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(7322247242100*Sqrt[3]) + 
         (13877150872245013447*Pi*Log[3]^2)/(351467867620800*Sqrt[3]) - 
         (26422654013234622359867*PolyGamma[2, 1])/169457721888600 - 
         (63237663672896368483741*Zeta[3])/1186204053220200) + 
       (63344678718184588630189*CF^2*NC*Zeta[3])/593102026610100 + 
       (36577649839*CF*NM*NC*Zeta[3])/108 - 152724*CF*NC*NL*Zeta[3] + 
       (16215541284839339663*CF*NC*NH*Zeta[3])/10167463313316 + 
       CF*Log[x]*((18554769098604754933651*NM*NC)/2345584140900 - 
         (61139782*lm*NM*NC)/945 - (31460*lm^2*NM*NC)/3 - 
         (1336374611393*NC*NL)/4762800 - (61139782*lm*NC*NL)/945 - 
         (31460*lm^2*NC*NL)/3 - (6054910451613081847712262376319*NC*NH)/
          1312202300415129467744400 - (61139782*lm*NC*NH)/945 - 
         (31460*lm^2*NC*NH)/3 + (10338422114*NM*NC*Pi^2)/9 - 
         (228844*NC*NL*Pi^2)/9 + (245536769689507792*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CF*NC*(909125587541494230294879920047759/726981883886498320080000 - 
           (107414714*lm)/105 - 188760*lm^2 + (87853099279601*Pi^2)/340200 + 
           (13877150872245013447*Im[PolyLog[2, (-1)^(1/3)]])/
            (10983370863150*Sqrt[3]) - 125840*Zeta[3]) + 
         CA*NC*(-6360467814080101470975016253207431/
            10177746374410976481120000 + (405638101*lm)/945 + 
           (173030*lm^2)/3 - (87843468661877*Pi^2)/680400 - 
           (13877150872245013447*Im[PolyLog[2, (-1)^(1/3)]])/
            (21966741726300*Sqrt[3]) + 62920*Zeta[3])), 
      (-5897720391402631677240309493791786555566886533*CF^2*NC)/
        1282977917556413616416156466988800000 - (278190182531*CF^2*lm*NC)/
        3841992 - (243088*CF^2*lm^2*NC)/5 - (33693653813681024949501275520677*
         CF*NM*NC)/113722192964330610660000 - (2091407526127*CF*lm*NM*NC)/
        345779280 - (121544*CF*lm^2*NM*NC)/45 + 
       (425673528320344001*CF*NC*NL)/3630682440000 - 
       (2091407526127*CF*lm*NC*NL)/345779280 - (121544*CF*lm^2*NC*NL)/45 + 
       (106670211557403614556671936301850149217*CF*NC*NH)/
        22461097996435812612327669240000 - (2091407526127*CF*lm*NC*NH)/
        345779280 - (121544*CF*lm^2*NC*NH)/45 + 
       (9080551390746272997541*CF^2*NC*Pi^2)/4045617576000 + 
       (2812*CF^2*lm*NC*Pi^2)/15 - (127547032765913*CF*NM*NC*Pi^2)/935550 + 
       (1406*CF*lm*NM*NC*Pi^2)/135 - (6916418851*CF*NC*NL*Pi^2)/935550 + 
       (1406*CF*lm*NC*NL*Pi^2)/135 + (1406*CF*lm*NC*NH*Pi^2)/135 - 
       (82144535354989458001*CF^2*NC*Pi^3)/(745613976309840*Sqrt[3]) - 
       (57573140811443593*CF*NC*NH*Pi^3)/(94143178827*Sqrt[3]) - 
       (51113339*CF^2*NC*Pi^4)/24300 + (2211167226276148552617047*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1435306904396442000*Sqrt[3]) + 
       (1222211908184758738*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1412147682405*Sqrt[3]) - (10804612*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - (11734933622141351143*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2876597130825*Sqrt[3]) - 
       (131595750426156784*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5811307335*Sqrt[3]) - (11734933622141351143*CF^2*NC*Pi*Log[3]^2)/
        (138076662279600*Sqrt[3]) - (8224734401634799*CF*NC*NH*Pi*Log[3]^2)/
        (17433922005*Sqrt[3]) - 
       (CF*NC*(CA*(1466320245819172446999997 - 78923916636393628800*lm) + 
          2*(CF*(-1466251434528977804347639 + 129148227223189574400*lm) + 
            166320*(13*(41207948301016279 + 3318395267880*lm)*NM + 
              51*(1882881*(591033 + 449240*lm)*NL + (202141959247 + 
                  845865460440*lm)*NH))))*Log[x]^2)/108894539754000 + 
       (2*CF*NC*(-2602374175727291*CA + 121*(42963674883733*CF - 
            249480*(4697291*NM - 2042*NL)))*Log[x]^3)/1403325 + 
       (2777427381968092164091639*CF^2*NC*PolyGamma[2, 1])/1525119496997400 + 
       (628961112139*CF*NM*NC*PolyGamma[2, 1])/900 - 
       (47522844096214028059*CF*NC*NH*PolyGamma[2, 1])/762559748498700 - 
       (3915210541170703699365487*CF^2*NC*Zeta[3])/58717100634399900 + 
       (674881833659*CF*NM*NC*Zeta[3])/450 - (6896552*CF*NC*NL*Zeta[3])/
        45 + (700328335652362187621*CF*NC*NH*Zeta[3])/381279874249350 + 
       CA*CF*NC*(1621829501606685950045144196365767002551227687/
          705637854656027489028886056843840000 + (668492*lm^2)/45 - 
         (1816106250626598357839*Pi^2)/1618247030400 + 
         (82144535354989458001*Pi^3)/(1491227952619680*Sqrt[3]) + 
         (51518267*Pi^4)/48600 + lm*(3280061173231/62868960 - 
           (7733*Pi^2)/135) - (2211167226276148552617047*
           Im[PolyLog[2, (-1)^(1/3)]])/(2870613808792884000*Sqrt[3]) + 
         (5402306*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (11734933622141351143*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (5753194261650*Sqrt[3]) + (11734933622141351143*Pi*Log[3]^2)/
          (276153324559200*Sqrt[3]) - (2777427381968092164091639*
           PolyGamma[2, 1])/3050238993994800 + (3923769459931907346677347*
           Zeta[3])/117434201268799800) + CF*Log[x]*
        ((-508494639245833706557199*NM*NC)/209362716312750 - 
         (9820698922*lm*NM*NC)/155925 - (32032*lm^2*NM*NC)/3 - 
         (4046668460489*NC*NL)/14553000 - (9820698922*lm*NC*NL)/155925 - 
         (32032*lm^2*NC*NL)/3 - (8677512325647626442278478667*NC*NH)/
          1949201278097340267000 - (9820698922*lm*NC*NH)/155925 - 
         (32032*lm^2*NC*NH)/3 - (2272846928*NM*NC*Pi^2)/45 - 
         (1148488*NC*NL*Pi^2)/45 + (131595750426156784*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(17433922005*Sqrt[3]) + 
         CF*NC*(28809354658890848484221457986112651593/
            2020791542639299380326376000 - (17144103044*lm)/17325 - 
           192192*lm^2 + (10407868379876147*Pi^2)/5613300 + 
           (11734933622141351143*Im[PolyLog[2, (-1)^(1/3)]])/
            (8629791392475*Sqrt[3]) - 128128*Zeta[3]) + 
         CA*NC*(-2939600533083178795459224633034258537/
            412406437273326404148240000 + (5969807861*lm)/14175 + 
           (176176*lm^2)/3 - (10407743623098617*Pi^2)/11226600 - 
           (11734933622141351143*Im[PolyLog[2, (-1)^(1/3)]])/
            (17259582784950*Sqrt[3]) + 64064*Zeta[3])), 
      (-64048912624347970328101873923308098583080004837*CF^2*NC)/
        8467654255872329868346632682126080000 - (1514021501501*CF^2*lm*NC)/
        12806640 - 75400*CF^2*lm^2*NC - (15398727942715783981492447762902929*
         CF*NM*NC)/473084322731615340345600 - (2238236993501*CF*lm*NM*NC)/
        230519520 - (37700*CF*lm^2*NM*NC)/9 + (310023192715165669*CF*NC*NL)/
        1452272976000 - (2238236993501*CF*lm*NC*NL)/230519520 - 
       (37700*CF*lm^2*NC*NL)/9 + 
       (40273855484547877595924954727178436493266113*CF*NC*NH)/
        4778569078441495246204706857301856000 - (2238236993501*CF*lm*NC*NH)/
        230519520 - (37700*CF*lm^2*NC*NH)/9 + 
       (86154519366979479271*CF^2*NC*Pi^2)/33345696384 + 
       338*CF^2*lm*NC*Pi^2 + (5396579702859479*CF*NM*NC*Pi^2)/374220 + 
       (169*CF*lm*NM*NC*Pi^2)/9 - (1573827229*CF*NC*NL*Pi^2)/124740 + 
       (169*CF*lm*NC*NL*Pi^2)/9 + (169*CF*lm*NC*NH*Pi^2)/9 - 
       (163483315577241613225*CF^2*NC*Pi^3)/(894736771571808*Sqrt[3]) - 
       (2885911126506394735*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) - 
       (12134759*CF^2*NC*Pi^4)/3240 + (29067134295242339371880099*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(12056577996930112800*Sqrt[3]) + 
       (270954882850337851643*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (88965303991515*Sqrt[3]) - (1196234*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - (32696663115448322645*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4832683179786*Sqrt[3]) - 
       (1319273657831494736*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31381059609*Sqrt[3]) - (32696663115448322645*CF^2*NC*Pi*Log[3]^2)/
        (231968792629728*Sqrt[3]) - (82454603614468421*CF*NC*NH*Pi*Log[3]^2)/
        (94143178827*Sqrt[3]) + CF*((32144399003935430288137*CF*NC)/
          1037090854800 - 4303728*CF*lm*NC + 
         CA*(-1125155123651800305438767/72596359836000 + 1315028*lm)*NC + 
         (15106765622759183323*NM*NC)/87297210 - 239096*lm*NM*NC - 
         (4667377*NC*NL)/15 - 239096*lm*NC*NL - (5693370888053*NC*NH)/
          95611230 - 239096*lm*NC*NH)*Log[x]^2 + 
       (2*CF*NC*(-1100199175081193*CA + 50*(43925555370617*CF + 
            12474*(18308867619*NM + 59774*NL)))*Log[x]^3)/467775 + 
       (1307396969110643196845257*CF^2*NC*PolyGamma[2, 1])/457535849099220 + 
       (14356214616749*CF*NM*NC*PolyGamma[2, 1])/1080 - 
       (210714258523115242843*CF*NC*NH*PolyGamma[2, 1])/915071698198440 + 
       CA*CF*NC*(80058359202081775455754890186437461041642572587/
          21169135639680824670866581705315200000 + (207350*lm^2)/9 - 
         (48729718301418630787*Pi^2)/37721376000 + 
         (163483315577241613225*Pi^3)/(1789473543143616*Sqrt[3]) + 
         (12232103*Pi^4)/6480 + lm*(3467208737501/41912640 - 
           (1859*Pi^2)/18) - (29067134295242339371880099*
           Im[PolyLog[2, (-1)^(1/3)]])/(24113155993860225600*Sqrt[3]) + 
         (598117*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (32696663115448322645*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9665366359572*Sqrt[3]) + (32696663115448322645*Pi*Log[3]^2)/
          (463937585259456*Sqrt[3]) - (1307396969110643196845257*
           PolyGamma[2, 1])/915071698198440 - (35616308828974472355058879*
           Zeta[3])/70460520761279880) + (35627473626782930921267431*CF^2*NC*
         Zeta[3])/35230260380639940 + (1174796054669*CF*NM*NC*Zeta[3])/540 - 
       (822068*CF*NC*NL*Zeta[3])/3 + (1282727489775317427557*CF*NC*NH*
         Zeta[3])/457535849099220 + CF*Log[x]*
        ((426484688345820179324047087*NM*NC)/5080535249189400 - 
         (1119467336*lm*NM*NC)/10395 - (52052*lm^2*NM*NC)/3 - 
         (1046181779645*NC*NL)/2095632 - (1119467336*lm*NC*NL)/10395 - 
         (52052*lm^2*NC*NL)/3 - (2458288379983157370812690230609993*NC*NH)/
          297495007251258637901480400 - (1119467336*lm*NC*NH)/10395 - 
         (52052*lm^2*NC*NH)/3 + (329560187998*NM*NC*Pi^2)/27 - 
         (410696*NC*NL*Pi^2)/9 + (1319273657831494736*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(129519479361859625806102095110234581639/
            12124749255835796281958256000 - (1968394402*lm)/1155 - 
           312312*lm^2 + (1759937667233261*Pi^2)/748440 + 
           (32696663115448322645*Im[PolyLog[2, (-1)^(1/3)]])/
            (14498049539358*Sqrt[3]) - 208208*Zeta[3]) + 
         CA*NC*(-1681890448369027277880024001009504613/
            314928552099631072258656000 + (674508328*lm)/945 + 
           (286286*lm^2)/3 - (1759900099700489*Pi^2)/1496880 - 
           (32696663115448322645*Im[PolyLog[2, (-1)^(1/3)]])/
            (28996099078716*Sqrt[3]) + 104104*Zeta[3])), 
      (-82143726626188755272036210987655572965386443027*CF^2*NC)/
        1568084121457838864508635681875200000 - (41681341557551*CF^2*lm*NC)/
        384199200 - (363987*CF^2*lm^2*NC)/5 + 
       (9347433577916577952592820973890407*CF*NM*NC)/
        6451149855431118277440000 - (62657868689111*CF*lm*NM*NC)/
        6915585600 - (40443*CF*lm^2*NM*NC)/10 + 
       (4672211706718586071*CF*NC*NL)/21784094640000 - 
       (62657868689111*CF*lm*NC*NL)/6915585600 - (40443*CF*lm^2*NC*NL)/10 + 
       (2088669700570657606519694019504497165318203597*CF*NC*NH)/
        250874876618178500425747110008347440000 - 
       (62657868689111*CF*lm*NC*NH)/6915585600 - (40443*CF*lm^2*NC*NH)/10 + 
       (382908635534638496989193*CF^2*NC*Pi^2)/15283444176000 + 
       (3887*CF^2*lm*NC*Pi^2)/15 - (11529092199101447*CF*NM*NC*Pi^2)/
        3742200 + (3887*CF*lm*NM*NC*Pi^2)/270 - (5617154218*CF*NC*NL*Pi^2)/
        467775 + (3887*CF*lm*NC*NL*Pi^2)/270 + (3887*CF*lm*NC*NH*Pi^2)/
        270 - (95550260154917220821*CF^2*NC*Pi^3)/(497075984206560*Sqrt[3]) - 
       (8210643739142481658*CF*NC*NH*Pi^3)/(7625597484987*Sqrt[3]) - 
       (6264011*CF^2*NC*Pi^4)/1800 + (828326366494162058845859*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(318957089865876000*Sqrt[3]) + 
       (92291965975568949439*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (53379182394909*Sqrt[3]) - (1929382*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (13650037164988174403*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1917731420550*Sqrt[3]) - 
       (18767185689468529504*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (470715894135*Sqrt[3]) - (13650037164988174403*CF^2*NC*Pi*Log[3]^2)/
        (92051108186400*Sqrt[3]) - (1172949105591783094*CF*NC*NH*Pi*
         Log[3]^2)/(1412147682405*Sqrt[3]) - 
       (CF*NC*(-23*CA*(-10912672689970587900535453 + 93646753636331095200*
             lm) + 46*CF*(-10912591078379094588115381 + 153240142313996337600*
             lm) + 9240*(207*(32274378636737656547 + 204746061560040*lm)*
             NM + 57424104738*(968077 + 738060*lm)*NL + 
            4*(2693374196835991 + 10595608685732070*lm)*NH))*Log[x]^2)/
        1669716276228000 + (CF*NC*(-12959654429286199*CA + 
          8*(3239257324924448*CF - 3465*(91200739374*NM - 1759043*NL)))*
         Log[x]^3)/311850 + (59134894808684013075051427*CF^2*NC*
         PolyGamma[2, 1])/3050238993994800 + 
       (42771353459137*CF*NM*NC*PolyGamma[2, 1])/8100 - 
       (767785512856847541943*CF*NC*NH*PolyGamma[2, 1])/6863037736488300 - 
       (326871123687109523033320111*CF^2*NC*Zeta[3])/117434201268799800 + 
       (59194811013217*CF*NM*NC*Zeta[3])/4050 - (12123592*CF*NC*NL*Zeta[3])/
        45 + (10844839213648126591577*CF*NC*NH*Zeta[3])/3431518868244150 + 
       CA*CF*NC*(16428677188036272399013290256685698666721928763/
          627233648583135545803454272750080000 + (444873*lm^2)/20 - 
         (1732617686166028051757*Pi^2)/138311712000 + 
         (95550260154917220821*Pi^3)/(994151968413120*Sqrt[3]) + 
         (18916417*Pi^4)/10800 + lm*(98254399579031/1257379200 - 
           (42757*Pi^2)/540) - (828326366494162058845859*
           Im[PolyLog[2, (-1)^(1/3)]])/(637914179731752000*Sqrt[3]) + 
         (964691*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (13650037164988174403*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (3835462841100*Sqrt[3]) + (13650037164988174403*Pi*Log[3]^2)/
          (184102216372800*Sqrt[3]) - (59134894808684013075051427*
           PolyGamma[2, 1])/6100477987989600 + (326900523157156684353520051*
           Zeta[3])/234868402537599600) + CF*Log[x]*
        ((-118728150771329755640614081*NM*NC)/3628953749421000 - 
         (64213059313*lm*NM*NC)/623700 - (52052*lm^2*NM*NC)/3 - 
         (762737295433387*NC*NL)/1571724000 - (64213059313*lm*NC*NL)/
          623700 - (52052*lm^2*NC*NL)/3 - 
         (15300225882844012687258533134466977*NC*NH)/
          1952310985086384811228465125 - (64213059313*lm*NC*NH)/623700 - 
         (52052*lm^2*NC*NH)/3 - (91199344123*NM*NC*Pi^2)/45 - 
         (224367*NC*NL*Pi^2)/5 + (18767185689468529504*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1412147682405*Sqrt[3]) + 
         CF*NC*(528109683676455654347650456577694674497/
            3367985904398832300543960000 - (56096851213*lm)/34650 - 
           312312*lm^2 + (77755983856998407*Pi^2)/3742200 + 
           (13650037164988174403*Im[PolyLog[2, (-1)^(1/3)]])/
            (5753194261650*Sqrt[3]) - 208208*Zeta[3]) + 
         CA*NC*(-1056212291186651726298929823938672600921/
            13471943617595329202175840000 + (77986018513*lm)/113400 + 
           (286286*lm^2)/3 - (77755839124992527*Pi^2)/7484400 - 
           (13650037164988174403*Im[PolyLog[2, (-1)^(1/3)]])/
            (11506388523300*Sqrt[3]) + 104104*Zeta[3])), 
      (-87509414769580011642830772361865231425807718329*CF^2*NC)/
        1269619130409845378011156920268800000 - (1637076187541*CF^2*lm*NC)/
        9408960 - (221949*CF^2*lm^2*NC)/2 - 
       (5921468634359325856664093749360463689*CF*NM*NC)/
        17031035618338152252441600 - (2420192161181*CF*lm*NM*NC)/169361280 - 
       (24661*CF*lm^2*NM*NC)/4 + (13651344043737669191*CF*NC*NL)/
        35943756156000 - (2420192161181*CF*lm*NC*NL)/169361280 - 
       (24661*CF*lm^2*NC*NL)/4 + 
       (2170286438210589125267664927449151307245373825303*CF*NC*NH)/
        150524925970907100255448266005008464000000 - 
       (2420192161181*CF*lm*NC*NH)/169361280 - (24661*CF*lm^2*NC*NH)/4 + 
       (84838828886497024051783*CF^2*NC*Pi^2)/3742884288000 + 
       (8281*CF^2*lm*NC*Pi^2)/18 + (76242462341866873*CF*NM*NC*Pi^2)/
        498960 + (8281*CF*lm*NM*NC*Pi^2)/324 - (6438119597*CF*NC*NL*Pi^2)/
        320760 + (8281*CF*lm*NC*NL*Pi^2)/324 + (8281*CF*lm*NC*NH*Pi^2)/
        324 - (50178418821424366331971*CF^2*NC*Pi^3)/(161052618882925440*
         Sqrt[3]) - (356182666726142304265*CF*NC*NH*Pi^3)/
        (183014339639688*Sqrt[3]) - (14483833*CF^2*NC*Pi^4)/2400 + 
       (1235772717889097776803507737*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (310026291349631472000*Sqrt[3]) + (38417130688438858700977*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7046052076127988*Sqrt[3]) - 
       (56584619*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
       (7168345545917766618853*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (621344980258200*Sqrt[3]) - (20353295241493845958*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(282429536481*Sqrt[3]) - 
       (7168345545917766618853*CF^2*NC*Pi*Log[3]^2)/(29824559052393600*
         Sqrt[3]) - (10176647620746922979*CF*NC*NH*Pi*Log[3]^2)/
        (6778308875544*Sqrt[3]) - 
       (CF*NC*(-115*CA*(-225661878950655959296297 + 3782428507652034240*lm) + 
          6*(575*CF*(-15043858243449350784947 + 412628564471131008*lm) + 
            88*(115*(-5762554201372315985501 + 1302489155527560*lm)*NM + 
              2900207310*(67053829 + 51646740*lm)*NL + (39447736271494381 + 
                149786252885669400*lm)*NH)))*Log[x]^2)/190824717283200 + 
       (CF*NC*(-16753335068112289*CA + 33493487461988651*CF + 
          9900*(20978246591056*NM + 11190127*NL))*Log[x]^3)/400950 + 
       (530261345048940197473756999*CF^2*NC*PolyGamma[2, 1])/
        20589113209464900 + (435560059378661*CF*NM*NC*PolyGamma[2, 1])/
        3240 - (1615858183872207450889*CF*NC*NH*PolyGamma[2, 1])/
        4117822641892980 + CA*CF*NC*
        (30015531049352843965878826543862084538760171913521/
          870958723461153929315653647304396800000 + (271271*lm^2)/8 - 
         (45682409381217250406713*Pi^2)/4030798464000 + 
         (50178418821424366331971*Pi^3)/(322105237765850880*Sqrt[3]) + 
         (393713411*Pi^4)/129600 + lm*(3749116237661/30792960 - 
           (91091*Pi^2)/648) - (1235772717889097776803507737*
           Im[PolyLog[2, (-1)^(1/3)]])/(620052582699262944000*Sqrt[3]) + 
         (56584619*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 + 
         (7168345545917766618853*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1242689960516400*Sqrt[3]) + (7168345545917766618853*Pi*Log[3]^2)/
          (59649118104787200*Sqrt[3]) - (530261345048940197473756999*
           PolyGamma[2, 1])/41178226418929800 - (1761986280193590872218125809*
           Zeta[3])/362368392486582240) + (8810415454375808855541867277*CF^2*
         NC*Zeta[3])/905920981216455600 + (16000208495741*CF*NM*NC*Zeta[3])/
        1620 - (12688988*CF*NC*NL*Zeta[3])/27 + 
       (9724377234958897992131*CF*NC*NH*Zeta[3])/2058911320946490 + 
       CF*Log[x]*((53897916602858746418911408787*NM*NC)/60966422990272800 - 
         (18413353777*lm*NM*NC)/106920 - (82810*lm^2*NM*NC)/3 - 
         (17634347079171103*NC*NL)/20746756800 - (18413353777*lm*NC*NL)/
          106920 - (82810*lm^2*NC*NL)/3 - 
         (13272078792393444406358679596523997213*NC*NH)/
          937109272841464709389663260000 - (18413353777*lm*NC*NH)/106920 - 
         (82810*lm^2*NC*NH)/3 + (20978253941555*NM*NC*Pi^2)/162 - 
         (12680707*NC*NL*Pi^2)/162 + (20353295241493845958*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(847288609443*Sqrt[3]) + 
         CF*NC*(6780593535673610569777235461798071038479/
            77944816644658690384017360000 - (16199842477*lm)/5940 - 
           496860*lm^2 + (134020992392877283*Pi^2)/6415200 + 
           (7168345545917766618853*Im[PolyLog[2, (-1)^(1/3)]])/
            (1864034940774600*Sqrt[3]) - 331240*Zeta[3]) + 
         CA*NC*(-847555813077430299893361455583579404057/
            19486204161164672596004340000 + (22169615377*lm)/19440 + 
           (455455*lm^2)/3 - (134020445403325867*Pi^2)/12830400 - 
           (7168345545917766618853*Im[PolyLog[2, (-1)^(1/3)]])/
            (3728069881549200*Sqrt[3]) + 165620*Zeta[3])), 
      (-121964152200530816562051367013982455033607476798946173003*CF^2*NC)/
        206640618372861267230679379571675619379200000 - 
       (69632616936517*CF^2*lm*NC)/441698400 - (528696*CF^2*lm^2*NC)/5 + 
       (149402811724919722005608843625788441210573*CF*NM*NC)/
        2590207629604003730693211840000 - (104661243529477*CF*lm*NM*NC)/
        7950571200 - (29372*CF*lm^2*NM*NC)/5 + 
       (2521806575186789470081*CF*NC*NL)/6749438655960000 - 
       (104661243529477*CF*lm*NC*NL)/7950571200 - (29372*CF*lm^2*NC*NL)/5 + 
       (3162835243164833369603014677198777409715985886109*CF*NC*NH)/
        225787388956360650383172399007512696000000 - 
       (104661243529477*CF*lm*NC*NH)/7950571200 - (29372*CF*lm^2*NC*NH)/5 + 
       (3142035613306358912401399*CF^2*NC*Pi^2)/11353415673600 + 
       (5243*CF^2*lm*NC*Pi^2)/15 - (6932462717459885107*CF*NM*NC*Pi^2)/
        145945800 + (5243*CF*lm*NM*NC*Pi^2)/270 - 
       (65342366957*CF*NC*NL*Pi^2)/3474900 + (5243*CF*lm*NC*NL*Pi^2)/270 + 
       (5243*CF*lm*NC*NH*Pi^2)/270 - (100964175994530585277331*CF^2*NC*Pi^3)/
        (314052606821704608*Sqrt[3]) - (499233998483282412287*CF*NC*NH*Pi^3)/
        (274521509459532*Sqrt[3]) - (3320569*CF^2*NC*Pi^4)/600 + 
       (33192194018833839283290811291*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (7859166485713157815200*Sqrt[3]) + (34156373184472701048575*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(10569078114191982*Sqrt[3]) - 
       598766*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (14423453713504369325333*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1211622711503490*Sqrt[3]) - 
       (285276570561875664164*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4236443047215*Sqrt[3]) - 
       (14423453713504369325333*CF^2*NC*Pi*Log[3]^2)/(58157890152167520*
         Sqrt[3]) - (71319142640468916041*CF*NC*NH*Pi*Log[3]^2)/
        (50837316566580*Sqrt[3]) - 
       (CF*NC*(CA*(1029798929664635713929961973 - 1362286613234320693920*
             lm) + 88*(CF*(-23404494156441966090245161 + 50663551731854901840*
               lm) + 39*((103002736238366999856901 + 72170301612328920*lm)*
               NM + 33*(17577014*(162794117 + 124422660*lm)*NL + 
                (586110130806709 + 2186978836737240*lm)*NH))))*Log[x]^2)/
        620180331170400 + (CF*NC*(-801001706413288921*CA + 
          520*(3080672877125402*CF - 467360440976352*NM + 889622019*NL))*
         Log[x]^3)/1737450 + (50960060925612342269493041647*CF^2*NC*
         PolyGamma[2, 1])/247069358513578800 + 
       (293831473372079*CF*NM*NC*PolyGamma[2, 1])/8100 - 
       (5918019259356648530287*CF*NC*NH*PolyGamma[2, 1])/30883669814197350 - 
       (856867159844054051963717329063*CF^2*NC*Zeta[3])/
        17665459133720884200 + (577092841709399*CF*NM*NC*Zeta[3])/4050 - 
       (6809576*CF*NC*NL*Zeta[3])/15 + (80705469184111716393773*CF*NC*NH*
         Zeta[3])/15441834907098675 + CA*CF*NC*
        (60982038207698985626125579745299180543263329166041267029/
          206640618372861267230679379571675619379200000 + (161546*lm^2)/5 - 
         (24244100791644043415071*Pi^2)/175207032000 + 
         (100964175994530585277331*Pi^3)/(628105213643409216*Sqrt[3]) + 
         (30052897*Pi^4)/10800 + lm*(164103761384197/1445558400 - 
           (57673*Pi^2)/540) - (33192194018833839283290811291*
           Im[PolyLog[2, (-1)^(1/3)]])/(15718332971426315630400*Sqrt[3]) + 
         299383*Im[PolyLog[2, (-1)^(1/3)]]^2 + (14423453713504369325333*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2423245423006980*
           Sqrt[3]) + (14423453713504369325333*Pi*Log[3]^2)/
          (116315780304335040*Sqrt[3]) - (50960060925612342269493041647*
           PolyGamma[2, 1])/494138717027157600 + 
         (856874473266492448135751783581*Zeta[3])/35330918267441768400) + 
       CF*Log[x]*((-99117367422735321389141708786771*NM*NC)/
          241884283213907334000 - (62584458181*lm*NM*NC)/386100 - 
         (81536*lm^2*NM*NC)/3 - (182637107338645969*NC*NL)/224756532000 - 
         (62584458181*lm*NC*NL)/386100 - (81536*lm^2*NC*NL)/3 - 
         (18603072279031792719968694236011202549*NC*NH)/
          1405663909262197064084494890000 - (62584458181*lm*NC*NH)/386100 - 
         (81536*lm^2*NC*NH)/3 - (14162412830893*NM*NC*Pi^2)/405 - 
         (10209121*NC*NL*Pi^2)/135 + (285276570561875664164*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) + 
         CF*NC*(10966314118513544497057685546322002254128280909/
            6432318048783813765250648616640000 - (54714195781*lm)/21450 - 
           489216*lm^2 + (400499310693523819*Pi^2)/1737450 + 
           (14423453713504369325333*Im[PolyLog[2, (-1)^(1/3)]])/
            (3634868134510470*Sqrt[3]) - 326144*Zeta[3]) + 
         CA*NC*(-5483151619675815528979686570772897033418672723/
            6432318048783813765250648616640000 + (75940054981*lm)/70200 + 
           (448448*lm^2)/3 - (1601996793600204253*Pi^2)/13899600 - 
           (14423453713504369325333*Im[PolyLog[2, (-1)^(1/3)]])/
            (7269736269020940*Sqrt[3]) + 163072*Zeta[3])), 
      (-202362033889353104100308401171245241861276632259373503*CF^2*NC)/
        330624989396578027569087007314680991006720 - 
       (8799248701753*CF^2*lm*NC)/35335872 - (317695*CF^2*lm^2*NC)/2 - 
       (425950898786627937589431433624694861864999*CF*NM*NC)/
        115120339093511276919698304000 - (13009009897393*CF*lm*NM*NC)/
        636045696 - (317695*CF*lm^2*NM*NC)/36 + 
       (87247215703511760451*CF*NC*NL)/134988773119200 - 
       (13009009897393*CF*lm*NC*NL)/636045696 - (317695*CF*lm^2*NC*NL)/36 + 
       (32183840673303269185317792846861957453941293200611*CF*NC*NH)/
        1354724333738163902299034394045076176000000 - 
       (13009009897393*CF*lm*NC*NH)/636045696 - (317695*CF*lm^2*NC*NH)/36 + 
       (49708914489882125487536957*CF^2*NC*Pi^2)/258857877358080 + 
       (1225*CF^2*lm*NC*Pi^2)/2 + (10453245728012341109*CF*NM*NC*Pi^2)/
        6486480 + (1225*CF*lm*NM*NC*Pi^2)/36 - (2861346145*CF*NC*NL*Pi^2)/
        92664 + (1225*CF*lm*NC*NL*Pi^2)/36 + (1225*CF*lm*NC*NH*Pi^2)/36 - 
       (641882841941323608522295*CF^2*NC*Pi^3)/(1256210427286818432*
         Sqrt[3]) - (5291888177121944522705*CF*NC*NH*Pi^3)/
        (1647129056757192*Sqrt[3]) - (24330173*CF^2*NC*Pi^4)/2592 + 
       (40082600452944919498577659933*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6287333188570526252160*Sqrt[3]) + (2966089217160842711867149*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(317072343425759460*Sqrt[3]) - 
       (5759075*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/6 - 
       (18339509769752103100637*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(969298169202792*Sqrt[3]) - 
       (302393610121253972726*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (18339509769752103100637*CF^2*NC*Pi*Log[3]^2)/(46526312121734016*
         Sqrt[3]) - (151196805060626986363*CF*NC*NH*Pi*Log[3]^2)/
        (61004779879896*Sqrt[3]) + CF*((43972758123329816266853981*CF*NC)/
          19082471728320 - 12421890*CF*lm*NC + 
         CA*(-2858239243069372477339672129/2480721324681600 + (7591155*lm)/2)*
          NC + (5752381864445565605181*NM*NC)/297457160 - 690105*lm*NM*NC - 
         (32192173*NC*NL)/36 - 690105*lm*NC*NL - (22977829838729291*NC*NH)/
          120470149800 - 690105*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-125036983605000314*CA + 250053587748120547*CF + 
          77220*(24631377077924*NM + 2070315*NL))*Log[x]^3)/347490 + 
       (10552653253705698454470778724*CF^2*NC*PolyGamma[2, 1])/
        46325504721296025 + (1470201281968817*CF*NM*NC*PolyGamma[2, 1])/
        1080 - (530160710014750777091*CF*NC*NH*PolyGamma[2, 1])/
        823564528378596 + CA*CF*NC*
        (25295222900642496898037698450817513935673406590359227749/
          82656247349144506892271751828670247751680000 + (3494645*lm^2)/72 - 
         (13081291338296105917372591*Pi^2)/136240988083200 + 
         (641882841941323608522295*Pi^3)/(2512420854573636864*Sqrt[3]) + 
         (24471293*Pi^4)/5184 + lm*(20152847077873/115644672 - 
           (13475*Pi^2)/72) - (40082600452944919498577659933*
           Im[PolyLog[2, (-1)^(1/3)]])/(12574666377141052504320*Sqrt[3]) + 
         (5759075*Im[PolyLog[2, (-1)^(1/3)]]^2)/12 + 
         (18339509769752103100637*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1938596338405584*Sqrt[3]) + (18339509769752103100637*Pi*Log[3]^2)/
          (93052624243468032*Sqrt[3]) - (5276326626852849227235389362*
           PolyGamma[2, 1])/46325504721296025 - 
         (10149687986920886983685490302879*Zeta[3])/211985509604650610400) + 
       (10149780149539656467460449726999*CF^2*NC*Zeta[3])/
        105992754802325305200 - (7678496060503*CF*NM*NC*Zeta[3])/540 - 
       (2326340*CF*NC*NL*Zeta[3])/3 + (3158989243781194477441*CF*NC*NH*
         Zeta[3])/411782264189298 + CF*Log[x]*
        ((19884213587927232322662291003047*NM*NC)/2150082517456954080 - 
         (8220386489*lm*NM*NC)/30888 - (127400*lm^2*NM*NC)/3 - 
         (8352618097475087*NC*NL)/5993507520 - (8220386489*lm*NC*NL)/
          30888 - (127400*lm^2*NC*NL)/3 - 
         (197155442903973997376406342059102436731*NC*NH)/
          8433983455573182384506969340000 - (8220386489*lm*NC*NH)/30888 - 
         (127400*lm^2*NC*NH)/3 + (24631378668955*NM*NC*Pi^2)/18 - 
         (2325115*NC*NL*Pi^2)/18 + (302393610121253972726*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(38715964154587343690098611486775390793001013/
            58475618625307397865914987424000 - (7236603689*lm)/1716 - 
           764400*lm^2 + (1000287629121466759*Pi^2)/5559840 + 
           (18339509769752103100637*Im[PolyLog[2, (-1)^(1/3)]])/
            (2907894507608376*Sqrt[3]) - 509600*Zeta[3]) + 
         CA*NC*(-425873679617095724060251754899780316685371693/
            1286463609756762753050129723328000 + (9889836089*lm)/5616 + 
           (700700*lm^2)/3 - (1000286853043996591*Pi^2)/11119680 - 
           (18339509769752103100637*Im[PolyLog[2, (-1)^(1/3)]])/
            (5815789015216752*Sqrt[3]) + 254800*Zeta[3])), 
      (-213902300932908835001260249236989246047107732137609881481249*CF^2*NC)/
        32545897393725649588832002282538910052224000000 - 
       (2897707355912641*CF^2*lm*NC)/12985932960 - 149629*CF^2*lm^2*NC + 
       (10787027828957843486539969954766920996172357*CF*NM*NC)/
        10792531790016682211221716000000 - (4355011478066521*CF*lm*NM*NC)/
        233746793280 - (149629*CF*lm^2*NM*NC)/18 + 
       (79027516715996231029*CF*NC*NL)/126551974799250 - 
       (4355011478066521*CF*lm*NC*NL)/233746793280 - (149629*CF*lm^2*NC*NL)/
        18 + (6603750597121338325068241402557609272025338148977*CF*NC*NH)/
        290298071515320836206935941581087752000000 - 
       (4355011478066521*CF*lm*NC*NH)/233746793280 - (149629*CF*lm^2*NC*NH)/
        18 + (4111594285078942863698665331*CF^2*NC*Pi^2)/1359003856129920 + 
       (1385*CF^2*lm*NC*Pi^2)/3 - (3097670165628996943*CF*NM*NC*Pi^2)/
        4864860 + (1385*CF*lm*NM*NC*Pi^2)/54 - (27763850717*CF*NC*NL*Pi^2)/
        972972 + (1385*CF*lm*NC*NL*Pi^2)/54 + (1385*CF*lm*NC*NH*Pi^2)/54 - 
       (45798960100252610450029*CF^2*NC*Pi^3)/(88327295668604421*Sqrt[3]) - 
       (7321774865852841504425*CF*NC*NH*Pi^3)/(2470693585135788*Sqrt[3]) - 
       (10339052*CF^2*NC*Pi^4)/1215 + (20600109273012872597868190543*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3094546803749555889735*Sqrt[3]) + 
       (2723883368214410377919917*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (475608515138639190*Sqrt[3]) - 
       (8113024*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (732783361604041767200464*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(38166115412359935*Sqrt[3]) - 
       (836774270383181886220*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (45798960100252610450029*CF^2*NC*Pi*Log[3]^2)/(114498346237079805*
         Sqrt[3]) - (209193567595795471555*CF*NC*NH*Pi*Log[3]^2)/
        (91507169819844*Sqrt[3]) - 
       (CF*NC*(-7*CA*(-8443448570552942355703106671 + 1675148884981910137800*
             lm) + CF*(-118208259563122882312379883557 + 
            38376138092312850429600*lm) + 
          54054*(24*(19177164208004917381129 + 1643424223766325*lm)*NM + 
            11*(1318276050*(3551417 + 2719956*lm)*NL + (1006038067156063 + 
                3585652851853800*lm)*NH)))*Log[x]^2)/3255946738644600 + 
       (CF*NC*(-36936291285878452481*CA + 56*(1319146223488579157*CF - 
            19305*(13289389348181*NM - 2946619*NL)))*Log[x]^3)/7297290 + 
       (194730478573442632024706669677*CF^2*NC*PolyGamma[2, 1])/
        88944969064888368 + (275294402810821*CF*NM*NC*PolyGamma[2, 1])/
        1350 - (87682688960115247127431*CF*NC*NH*PolyGamma[2, 1])/
        277953028327776150 - (152019105044044616858303080981547*CF^2*NC*
         Zeta[3])/222584785084883140920 + (939767351018221*CF*NM*NC*Zeta[3])/
        675 - (2212856*CF*NC*NL*Zeta[3])/3 + 
       (1160849062870421932859069*CF*NC*NH*Zeta[3])/138976514163888075 + 
       CA*CF*NC*(106951140741419681521518156173645629955629853577075350517637/
          32545897393725649588832002282538910052224000000 + 
         (1645919*lm^2)/36 - (13524981109356539435426831*Pi^2)/
          8940814842960 + (45798960100252610450029*Pi^3)/(176654591337208842*
           Sqrt[3]) + (5194456*Pi^4)/1215 + 
         lm*(6828012412630681/42499416960 - (15235*Pi^2)/108) - 
         (20600109273012872597868190543*Im[PolyLog[2, (-1)^(1/3)]])/
          (6189093607499111779470*Sqrt[3]) + 
         (4056512*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (366391680802020883600232*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (38166115412359935*Sqrt[3]) + (45798960100252610450029*Pi*Log[3]^2)/
          (228996692474159610*Sqrt[3]) - (194730478573442632024706669677*
           PolyGamma[2, 1])/177889938129776736 + 
         (152019252485912740437213063803267*Zeta[3])/445169570169766281840) + 
       CF*Log[x]*((-3944675927570646286718324643046289*NM*NC)/
          806280944046357780000 - (80148274411*lm*NM*NC)/324324 - 
         (123760*lm^2*NM*NC)/3 - (59024196917592559*NC*NL)/44951306400 - 
         (80148274411*lm*NC*NL)/324324 - (123760*lm^2*NC*NL)/3 - 
         (272786272736482334633600892971356163369*NC*NH)/
          12650975183359773576760454010000 - (80148274411*lm*NC*NH)/324324 - 
         (123760*lm^2*NC*NH)/3 - (13289386312993*NM*NC*Pi^2)/27 - 
         (3317899*NC*NL*Pi^2)/27 + (836774270383181886220*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(3717219609719485097492489129119421335105370729549/
            202618018536690133605395431424160000 - (70113689851*lm)/18018 - 
           742560*lm^2 + (18468134984975500603*Pi^2)/7297290 + 
           (732783361604041767200464*Im[PolyLog[2, (-1)^(1/3)]])/
            (114498346237079805*Sqrt[3]) - 495040*Zeta[3]) + 
         CA*NC*(-142969964448285759990661887162584056124048411989/
            15586001425899241046568879340320000 + (97176660331*lm)/58968 + 
           (680680*lm^2)/3 - (7387253689563251215*Pi^2)/5837832 - 
           (366391680802020883600232*Im[PolyLog[2, (-1)^(1/3)]])/
            (114498346237079805*Sqrt[3]) + 247520*Zeta[3])), 
      (-5588618871435222417186365692021877839570049108499504283237*CF^2*NC)/
        1061279262838879877896695726604529675616000000 - 
       (37647852928867*CF^2*lm*NC)/108216108 - 221960*CF^2*lm^2*NC - 
       (17617029716095482096526005291531706593376253*CF*NM*NC)/
        449688824584028425467571500000 - (55662588427627*CF*lm*NM*NC)/
        1947889944 - (110980*CF*lm^2*NM*NC)/9 + 
       (45047913875385363583*CF*NC*NL)/42541916376960 - 
       (55662588427627*CF*lm*NC*NL)/1947889944 - (110980*CF*lm^2*NC*NL)/9 + 
       (6548618819566981420161630648534389650033324851001*CF*NC*NH)/
        172845469646512854405103666895656978440000 - 
       (55662588427627*CF*lm*NC*NH)/1947889944 - (110980*CF*lm^2*NC*NH)/9 + 
       (175714283930824315925817521*CF^2*NC*Pi^2)/113250321344160 + 
       800*CF^2*lm*NC*Pi^2 + (20561593578474947293*CF*NM*NC*Pi^2)/1216215 + 
       (400*CF*lm*NM*NC*Pi^2)/9 - (3741771785*CF*NC*NL*Pi^2)/81081 + 
       (400*CF*lm*NC*NL*Pi^2)/9 + (400*CF*lm*NC*NH*Pi^2)/9 - 
       (1717671953059486441998545*CF^2*NC*Pi^3)/(2119855096046506104*
         Sqrt[3]) - (9511379560880559726560*CF*NC*NH*Pi^3)/
        (1853020188851841*Sqrt[3]) - (1147129*CF^2*NC*Pi^4)/81 + 
       (367783833152761535352177380641*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (37134561644994670676820*Sqrt[3]) + (143493450856326917854327676*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(9274366045203464205*Sqrt[3]) - 
       (4274800*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (687068781223794576799418*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22899669247415961*Sqrt[3]) - 
       (4348059227831113017856*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (343534390611897288399709*CF^2*NC*Pi*Log[3]^2)/(549592061937983064*
         Sqrt[3]) - (271753701739444563616*CF*NC*NH*Pi*Log[3]^2)/
        (68630377364883*Sqrt[3]) + CF*((15688739036841614201888876*CF*NC)/
          842636319525 - 19978320*CF*lm*NC + 
         CA*(-439284997749934198495518497/47187633893400 + (18313460*lm)/3)*
          NC + (1018347177072788326441318*NM*NC)/5019589575 - 
         (3329720*lm*NM*NC)/3 - (12922670*NC*NL)/9 - (3329720*lm*NC*NL)/
          3 - (529445381420*NC*NH)/1654653 - (3329720*lm*NC*NH)/3)*
        Log[x]^2 + (2*CF*NC*(-1808624111943411173*CA + 3617187045727985326*
           CF + 1081080*(32372801371277*NM + 416215*NL))*Log[x]^3)/
        1216215 + (821243063339838350244927801601*CF^2*NC*PolyGamma[2, 1])/
        416929542491664225 + (3723221834589187*CF*NM*NC*PolyGamma[2, 1])/
        270 - (170413970731244728679273*CF*NC*NH*PolyGamma[2, 1])/
        166771816996665690 + CA*CF*NC*
        (1397154393936119217489732313087161184416869145604712341753/
          530639631419439938948347863302264837808000000 + (610390*lm^2)/9 - 
         (25840335151949541526812973*Pi^2)/33308918042400 + 
         (1717671953059486441998545*Pi^3)/(4239710192093012208*Sqrt[3]) + 
         (1152889*Pi^4)/162 + lm*(86233048667947/354161808 - (2200*Pi^2)/9) - 
         (367783833152761535352177380641*Im[PolyLog[2, (-1)^(1/3)]])/
          (74269123289989341353640*Sqrt[3]) + 
         (2137400*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (343534390611897288399709*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (22899669247415961*Sqrt[3]) + (343534390611897288399709*Pi*
           Log[3]^2)/(1099184123875966128*Sqrt[3]) - 
         (821243063339838350244927801601*PolyGamma[2, 1])/
          833859084983328450 - (57551886536818802417928081819841*Zeta[3])/
          119241849152615968350) + (57551968323694187000101444579186*CF^2*NC*
         Zeta[3])/59620924576307984175 - (161513176311293*CF*NM*NC*Zeta[3])/
        135 - (3712120*CF*NC*NL*Zeta[3])/3 + 
       (1006616744663459050862167*CF*NC*NH*Zeta[3])/83385908498332845 + 
       CF*Log[x]*((6460016233753309109442802721620637*NM*NC)/
          67190078670529815000 - (10791852574*lm*NM*NC)/27027 - 
         (190400*lm^2*NM*NC)/3 - (261064494737749*NC*NL)/118053936 - 
         (10791852574*lm*NC*NL)/27027 - (190400*lm^2*NC*NL)/3 - 
         (4689604636359253034022521520808887799*NC*NH)/
          125588866368745657029969016200 - (10791852574*lm*NC*NH)/27027 - 
         (190400*lm^2*NC*NH)/3 + (388473620789792*NM*NC*Pi^2)/27 - 
         206140*NC*NL*Pi^2 + (4348059227831113017856*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(2698773242628871515469430074732204875991120637/
            600646300009950988948800686040000 - (19010734748*lm)/3003 - 
           1142400*lm^2 + (516748915498323229*Pi^2)/347490 + 
           (687068781223794576799418*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) - 761600*Zeta[3]) + 
         CA*NC*(-1855404699770291613424853172018705745105636567/
            825888662513682609804600943305000 + (6487489487*lm)/2457 + 
           (1047200*lm^2)/3 - (516748838602900339*Pi^2)/694980 - 
           (343534390611897288399709*Im[PolyLog[2, (-1)^(1/3)]])/
            (68699007742247883*Sqrt[3]) + 380800*Zeta[3])), 
      (-91661013021492754128614737654285768716419534676570742822163*CF^2*NC)/
        1266925071555064214098131576742431619680000000 - 
       (18792926590031719*CF^2*lm*NC)/60871560750 - (1034944*CF^2*lm^2*NC)/
        5 + (440612299153988570395202535663422516423263579*CF*NM*NC)/
        31221252678262544968177107000000 - (28242725075358919*CF*lm*NM*NC)/
        1095688093500 - (517472*CF*lm^2*NM*NC)/45 + 
       (795372898215858671071117*CF*NC*NL)/789684322747320000 - 
       (28242725075358919*CF*lm*NC*NL)/1095688093500 - 
       (517472*CF*lm^2*NC*NL)/45 + 
       (1997011363737665907318086995173515455079539187896014023*CF*NC*NH)/
        55755627371223884009726315348866549820283000000 - 
       (28242725075358919*CF*lm*NC*NH)/1095688093500 - 
       (517472*CF*lm^2*NC*NH)/45 + (15453101129682108297724671823*CF^2*NC*
         Pi^2)/471876338934000 + (26944*CF^2*lm*NC*Pi^2)/45 - 
       (16062900228711633058*CF*NM*NC*Pi^2)/2027025 + 
       (13472*CF*lm*NM*NC*Pi^2)/405 - (768704812586*CF*NC*NL*Pi^2)/
        18243225 + (13472*CF*lm*NC*NL*Pi^2)/405 + (13472*CF*lm*NC*NH*Pi^2)/
        405 - (5153739374461966972752283*CF^2*NC*Pi^3)/(6359565288139518312*
         Sqrt[3]) - (26020712558926020546800*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (571909*CF^2*NC*Pi^4)/45 + 
       (56862529732645498513502246191363*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (5570184246749200601523000*Sqrt[3]) + 
       (1351138266187506566723394568*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (139115490678051963075*Sqrt[3]) - 
       (19828528*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (10307478748923933945504566*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(343495038711239415*
         Sqrt[3]) - (11895182884080466535680*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (5153739374461966972752283*CF^2*NC*Pi*Log[3]^2)/(8243880929069745960*
         Sqrt[3]) - (743448930255029158480*CF*NC*NH*Pi*Log[3]^2)/
        (205891132094649*Sqrt[3]) - 
       (CF*NC*(-493*CA*(-62721406142629443009081697513 + 
            1823996382432193569600*lm) + 
          4*(4437*CF*(-3484522475249487874444795249 + 165817852948381233600*
               lm) + 140140*(5365*(4975976539283932138261 + 54364621866984*
                 lm)*NM + 27*(61616126*(228511331 + 175318580*lm)*NL + 
                (3155122153917343 + 10802451715421080*lm)*NH))))*Log[x]^2)/
        157370759034489000 + (2*CF*NC*(-167275039347165323967*CA + 
          14*(23896414378493889371*CF - 17160*(318812440894183*NM - 
              8765929*NL)))*Log[x]^3)/6081075 + 
       (57931834807735352857115371830061*CF^2*NC*PolyGamma[2, 1])/
        2501577254949985350 + (353470520771209*CF*NM*NC*PolyGamma[2, 1])/
        675 - (627820034001338320272359*CF*NC*NH*PolyGamma[2, 1])/
        1250788627474992675 - (2178225517377479730432370333108781*CF^2*NC*
         Zeta[3])/250407883220493533535 + (9208611700084178*CF*NM*NC*
         Zeta[3])/675 - (52253104*CF*NC*NL*Zeta[3])/45 + 
       (16207676601701251117584242*CF*NC*NH*Zeta[3])/1250788627474992675 + 
       CA*CF*NC*(5728813239083936983064419926658938435860838199774323941693/
          158365633944383026762266447092803952460000000 + (2846096*lm^2)/45 - 
         (6181240446086382673964518339*Pi^2)/377501071147200 + 
         (5153739374461966972752283*Pi^3)/(12719130576279036624*Sqrt[3]) + 
         (25843681*Pi^4)/4050 + lm*(44278746747429319/199216017000 - 
           (74096*Pi^2)/405) - (56862529732645498513502246191363*
           Im[PolyLog[2, (-1)^(1/3)]])/(11140368493498401203046000*Sqrt[3]) + 
         (9914264*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (5153739374461966972752283*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (343495038711239415*Sqrt[3]) + (5153739374461966972752283*Pi*
           Log[3]^2)/(16487761858139491920*Sqrt[3]) - 
         (57931834807735352857115371830061*PolyGamma[2, 1])/
          5003154509899970700 + (5445564437995619039485367149483586*Zeta[3])/
          1252039416102467667675) + CF*Log[x]*
        ((-10975060517549727250705792682993809*NM*NC)/
          194371299011175536250 - (2228099961508*lm*NM*NC)/6081075 - 
         60928*lm^2*NM*NC - (4507778685078678227*NC*NL)/2191376187000 - 
         (2228099961508*lm*NC*NL)/6081075 - 60928*lm^2*NC*NL - 
         (407582232319428773043154900700028112883377*NC*NH)/
          11969403895356265775312484550211250 - (2228099961508*lm*NC*NH)/
          6081075 - 60928*lm^2*NC*NH - (510099889598336*NM*NC*Pi^2)/81 - 
         (78352712*NC*NL*Pi^2)/405 + (11895182884080466535680*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(1542556359056079898566633409826129555078716916453/
            7887379614317522501940133576200000 - (3900438316616*lm)/675675 - 
           1096704*lm^2 + (334550050434197305243*Pi^2)/12162150 + 
           (10307478748923933945504566*Im[PolyLog[2, (-1)^(1/3)]])/
            (1030485116133718245*Sqrt[3]) - 731136*Zeta[3]) + 
         CA*NC*(-385639081889970818003499551061802715412480848297/
            3943689807158761250970066788100000 + (1349827631954*lm)/552825 + 
           335104*lm^2 - (66910009689763049717*Pi^2)/4864860 - 
           (5153739374461966972752283*Im[PolyLog[2, (-1)^(1/3)]])/
            (1030485116133718245*Sqrt[3]) + 365568*Zeta[3])), 
      (-2273981315268476051793390379734222414511623566595120285571339*CF^2*
         NC)/52305906525630508267765717954080391155360000000 - 
       (11587419092483491*CF^2*lm*NC)/24348624300 - 303688*CF^2*lm^2*NC - 
       (18027897589882803824324481852664675231630327049*CF*NM*NC)/
        43709753749567562955447949800000 - (17133207854797291*CF*lm*NM*NC)/
        438275237400 - (151844*CF*lm^2*NM*NC)/9 + 
       (106055714939922746305691*CF*NC*NL)/63174745819785600 - 
       (17133207854797291*CF*lm*NC*NL)/438275237400 - 
       (151844*CF*lm^2*NC*NL)/9 + 
       (601142780696077980316633390891860088038089274209635757*CF*NC*NH)/
        10238017104389365930311616497522703314201496875 - 
       (17133207854797291*CF*lm*NC*NH)/438275237400 - 
       (151844*CF*lm^2*NC*NH)/9 + (3672892871193805644262480019*CF^2*NC*
         Pi^2)/314584225956000 + (9248*CF^2*lm*NC*Pi^2)/9 + 
       (643554946342041281267*CF*NM*NC*Pi^2)/3648645 + 
       (4624*CF*lm*NM*NC*Pi^2)/81 - (49071346889*CF*NC*NL*Pi^2)/729729 + 
       (4624*CF*lm*NC*NL*Pi^2)/81 + (4624*CF*lm*NC*NH*Pi^2)/81 - 
       (7935457787738069355668303*CF^2*NC*Pi^3)/(6359565288139518312*
         Sqrt[3]) - (4921936043642237446400*CF*NC*NH*Pi^3)/
        (617673396283947*Sqrt[3]) - (42136693*CF^2*NC*Pi^4)/2025 + 
       (20883121986241663047383277795341*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1392546061687300150380750*Sqrt[3]) + 
       (229861231255109850481269196*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (9274366045203464205*Sqrt[3]) - 
       (92888272*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (15870915575476138711336606*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(343495038711239415*
         Sqrt[3]) - (2250027905665022832640*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (7935457787738069355668303*CF^2*NC*Pi*Log[3]^2)/(8243880929069745960*
         Sqrt[3]) - (140626744104063927040*CF*NC*NH*Pi*Log[3]^2)/
        (22876792454961*Sqrt[3]) + CF*((190072115021937216906003367073*CF*NC)/
          1356644474435250 - (93519856*CF*lm*NC)/3 + 
         CA*(-18102108795292945400966717093/258408471321000 + 
           (257179604*lm)/27)*NC + (11474327248171582139427760*NM*NC)/
          5421156741 - (46759928*lm*NM*NC)/27 - (906123902*NC*NL)/405 - 
         (46759928*lm*NC*NL)/27 - (1803887832131545994*NC*NH)/
          3481157078685 - (46759928*lm*NC*NH)/27)*Log[x]^2 + 
       (2*CF*NC*(-211460416835964773965*CA + 422919312316644513014*CF + 
          1801800*(3046828843755841*NM + 5844991*NL))*Log[x]^3)/18243225 + 
       (6901899132897984701370339472849*CF^2*NC*PolyGamma[2, 1])/
        416929542491664225 + (37699711792747381*CF*NM*NC*PolyGamma[2, 1])/
        270 - (788487852517111579533517*CF*NC*NH*PolyGamma[2, 1])/
        500315450989997070 + CA*CF*NC*
        (361769738823134897704995375598822901592004565147823115349867/
          16642788439973343539743637530843760822160000000 + (835142*lm^2)/9 - 
         (162039390493256906733314303*Pi^2)/27757431702000 + 
         (7935457787738069355668303*Pi^3)/(12719130576279036624*Sqrt[3]) + 
         (42321653*Pi^4)/4050 + lm*(26544243330238891/79686406800 - 
           (25432*Pi^2)/81) - (20883121986241663047383277795341*
           Im[PolyLog[2, (-1)^(1/3)]])/(2785092123374600300761500*Sqrt[3]) + 
         (46444136*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (7935457787738069355668303*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (343495038711239415*Sqrt[3]) + (7935457787738069355668303*Pi*
           Log[3]^2)/(16487761858139491920*Sqrt[3]) - 
         (6901899132897984701370339472849*PolyGamma[2, 1])/
          833859084983328450 - (4142530221149195688608385633038251*Zeta[3])/
          834692944068311778450) + (4142531099981655425790868163363578*CF^2*
         NC*Zeta[3])/417346472034155889225 - 
       (974890326124313*CF*NM*NC*Zeta[3])/45 - (17257448*CF*NC*NL*Zeta[3])/
        9 + (4621813241554819679301683*CF*NC*NH*Zeta[3])/
        250157725494998535 + CF*Log[x]*
        ((1081676589320967748282069361624561471*NM*NC)/
          1088479274462583003000 - (710081453726*lm*NM*NC)/1216215 - 
         92480*lm^2*NM*NC - (2989045367172952541*NC*NL)/876550474800 - 
         (710081453726*lm*NC*NL)/1216215 - 92480*lm^2*NC*NL - 
         (59261109721873346171389316144289529170908789*NC*NH)/
          1022453079416655236451137569133601000 - (710081453726*lm*NC*NH)/
          1216215 - 92480*lm^2*NC*NH + (12187315397393120*NM*NC*Pi^2)/81 - 
         (25876924*NC*NL*Pi^2)/81 + (2250027905665022832640*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(53664266107892274855229089800919343202020693392283/
            2279452708537764003060698603521800000 - (1251449562652*lm)/
            135135 - 1664640*lm^2 + (422920697225923255057*Pi^2)/36486450 + 
           (15870915575476138711336606*Im[PolyLog[2, (-1)^(1/3)]])/
            (1030485116133718245*Sqrt[3]) - 1109760*Zeta[3]) + 
         CA*NC*(-13416062584132969283224570660932671720777276450977/
            1139726354268882001530349301760900000 + (426616085263*lm)/
            110565 + 508640*lm^2 - (84584136956456945147*Pi^2)/14594580 - 
           (7935457787738069355668303*Im[PolyLog[2, (-1)^(1/3)]])/
            (1030485116133718245*Sqrt[3]) + 554880*Zeta[3])), 
      (-129880498525667011219070116547835458241109288706411218987186068482609*
         CF^2*NC)/164858239011234780239958769223528614508612774400000000 - 
       (33289602809941571*CF^2*lm*NC)/79505712000 - (1403503*CF^2*lm^2*NC)/
        5 + (12344852575074214109483015714908432685531907507785509*CF*NM*NC)/
        68226379788685010746906883051020800000 - 
       (50027578606311971*CF*lm*NM*NC)/1431102816000 - 
       (1403503*CF*lm^2*NM*NC)/90 + (621900495796049418331699*CF*NC*NL)/
        394842161373660000 - (50027578606311971*CF*lm*NC*NL)/1431102816000 - 
       (1403503*CF*lm^2*NC*NL)/90 + 
       (31822824286001145594302184911119909132847415913416126432739*CF*NC*
         NH)/579845548805631090688147779685730927370257752320000 - 
       (50027578606311971*CF*lm*NC*NH)/1431102816000 - 
       (1403503*CF*lm^2*NC*NH)/90 + (1767677487006014959158691731667*CF^2*NC*
         Pi^2)/5033347615296000 + (34391*CF^2*lm*NC*Pi^2)/45 - 
       (1716740630232773093218*CF*NM*NC*Pi^2)/18243225 + 
       (34391*CF*lm*NM*NC*Pi^2)/810 - (2533231911127*CF*NC*NL*Pi^2)/
        41698800 + (34391*CF*lm*NC*NL*Pi^2)/810 + (34391*CF*lm*NC*NH*Pi^2)/
        810 - (188065653351534816956093741*CF^2*NC*Pi^3)/
        (152629566915348439488*Sqrt[3]) - (119963564590443541382590*CF*NC*NH*
         Pi^3)/(16677181699666569*Sqrt[3]) - (299793181*CF^2*NC*Pi^4)/16200 + 
       (4084926119770243254551098270229947*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(267368843843961628873104000*Sqrt[3]) + 
       (6622972874453220852840337511*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (417346472034155889225*Sqrt[3]) - 
       (9470938*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (188065653351534816956093741*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4121940464534872980*
         Sqrt[3]) - (54840486669917047489184*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (188065653351534816956093741*CF^2*NC*Pi*Log[3]^2)/
        (197853142297673903040*Sqrt[3]) - (3427530416869815468074*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) - 
       (CF*NC*(-403*CA*(-2040647663360849558629931712031529 + 
            8531438093759011983552000*lm) + 
          22*(31*CF*(-2411674502467629546689107044571007 + 
              16498814164790155406208000*lm) + 
            18200*(31*(35506206667099526565590630677 + 50362680600702550080*
                 lm)*NM + 2*(8182867997304*(124155227 + 95397060*lm)*NL + 
                (236244583056421302037 + 780621549310889526240*lm)*NH))))*
         Log[x]^2)/390279482405532720000 + 
       (CF*NC*(-14406757441926650535475*CA + 12*(2401125937847096489583*CF - 
            40040*(15420903808557103*NM - 54058334*NL)))*Log[x]^3)/
        24324300 + (1627189586549531872954077048327761*CF^2*NC*
         PolyGamma[2, 1])/6670872679866627600 - 
       (12312069991332301*CF*NM*NC*PolyGamma[2, 1])/1350 - 
       (5819045955005445981406987*CF*NC*NH*PolyGamma[2, 1])/
        7504731764849956050 - (174332811108571928240470587926966029*CF^2*NC*
         Zeta[3])/1669385888136623556900 + (90493964043923689*CF*NM*NC*
         Zeta[3])/675 - (80007746*CF*NC*NL*Zeta[3])/45 + 
       (73481174129278023415261133*CF*NC*NH*Zeta[3])/3752365882424978025 + 
       CA*CF*NC*
        (16884464777232761479456063233693563887603537911869769144574965307216\
67/4286314214292104286238927999811743977223932134400000000 + 
         (15438533*lm^2)/180 - (34660342878059570486800614253*Pi^2)/
          197386180992000 + (188065653351534816956093741*Pi^3)/
          (305259133830696878976*Sqrt[3]) + (300893693*Pi^4)/32400 + 
         lm*(78431416321364771/260200512000 - (378301*Pi^2)/1620) - 
         (4084926119770243254551098270229947*Im[PolyLog[2, (-1)^(1/3)]])/
          (534737687687923257746208000*Sqrt[3]) + 
         (4735469*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (188065653351534816956093741*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (8243880929069745960*Sqrt[3]) + (188065653351534816956093741*Pi*
           Log[3]^2)/(395706284595347806080*Sqrt[3]) - 
         (1627189586549531872954077048327761*PolyGamma[2, 1])/
          13341745359733255200 + (174332813712487359595405304634922297*
           Zeta[3])/3338771776273247113800) + 
       CF*Log[x]*((-715762074262828320087850191845646995897*NM*NC)/
          1126659778243732068336000 - (3684405137473*lm*NM*NC)/6949800 - 
         87856*lm^2*NM*NC - (13744822936534986521*NC*NL)/4382752374000 - 
         (3684405137473*lm*NC*NL)/6949800 - 87856*lm^2*NC*NL - 
         (2311014593459439898986047067316174200042782257*NC*NH)/
          44169973030799506214689142986571563200 - (3684405137473*lm*NC*NH)/
          6949800 - 87856*lm^2*NC*NH - (6168361497102122*NM*NC*Pi^2)/81 - 
         (119977228*NC*NL*Pi^2)/405 + (54840486669917047489184*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(475520675792393700818116933177710351653523748734834359579/
            230042367345631143188885703067420056000000 - (3226468915873*lm)/
            386100 - 1581408*lm^2 + (28813514534535035274637*Pi^2)/97297200 + 
           (188065653351534816956093741*Im[PolyLog[2, (-1)^(1/3)]])/
            (12365821393604618940*Sqrt[3]) - 1054272*Zeta[3]) + 
         CA*NC*(-951041348869533633924233689096033041154956595031952206233/
            920169469382524572755542812269680224000000 + (4461509028673*lm)/
            1263600 + 483208*lm^2 - (28813514510333268281233*Pi^2)/
            194594400 - (188065653351534816956093741*Im[PolyLog[2, (-1)^
                (1/3)]])/(24731642787209237880*Sqrt[3]) + 527136*Zeta[3])), 
      (-435175569069191595942576538979510072989583815794859981548795325359101*
         CF^2*NC)/1285894264287631285871678399943523193167179640320000000 - 
       (12293676371981261*CF^2*lm*NC)/19238419200 - (815745*CF^2*lm^2*NC)/2 - 
       (327250063977611557437659503873144907364228125104780277*CF*NM*NC)/
        75807088654094456385452092278912000000 - 
       (18178792973345261*CF*lm*NM*NC)/346291545600 - 
       (271915*CF*lm^2*NM*NC)/12 + (12102144418318225430363*CF*NC*NL)/
        4679610801465600 - (18178792973345261*CF*lm*NC*NL)/346291545600 - 
       (271915*CF*lm^2*NC*NL)/12 + 
       (608494079837723506817661125354199890984849784866168635880821*CF*NC*
         NH)/6858388211679507524268414598433376560293371264000000 - 
       (18178792973345261*CF*lm*NC*NH)/346291545600 - 
       (271915*CF*lm^2*NC*NH)/12 + (72031365487311785758496518261*CF^2*NC*
         Pi^2)/929233405900800 + (2601*CF^2*lm*NC*Pi^2)/2 + 
       (38047991605106973767*CF*NM*NC*Pi^2)/20790 + (289*CF*lm*NM*NC*Pi^2)/
        4 - (46043202509*CF*NC*NL*Pi^2)/480480 + (289*CF*lm*NC*NL*Pi^2)/4 + 
       (289*CF*lm*NC*NH*Pi^2)/4 - (3429871115857868927817354505*CF^2*NC*
         Pi^3)/(1831554802984181273856*Sqrt[3]) - 
       (134090738356361792976215*CF*NC*NH*Pi^3)/(11118121133111046*
         Sqrt[3]) - (129037837*CF^2*NC*Pi^4)/4320 + 
       (14241372629011826700931977646915291*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(641685225225507909295449600*Sqrt[3]) + 
       (4295929215819396558281314151*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (111292392542441570460*Sqrt[3]) - 
       (5852471*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/2 - 
       (685974223171573785563470901*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(9892657114883695152*
         Sqrt[3]) - (30649311624311266965992*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (685974223171573785563470901*CF^2*NC*Pi*Log[3]^2)/
        (474847541514417367296*Sqrt[3]) - (3831163953038908370749*CF*NC*NH*
         Pi*Log[3]^2)/(411782264189298*Sqrt[3]) + 
       CF*((4684379263303060046117885530565113*CF*NC)/5035864289103648000 - 
         47362680*CF*lm*NC + CA*(-669197059625437073550788009423443/
            1438818368315328000 + 14471930*lm)*NC + 
         (153449662524123211028531205673*NM*NC)/6987268688400 - 
         2631260*lm*NM*NC - (16976251*NC*NL)/5 - 2631260*lm*NC*NL - 
         (5685934753178598767*NC*NH)/6987268688400 - 2631260*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-2663681385203865378579*CA + 
          80*(66591980242085805763*CF + 270270*(4694416100460617*NM + 
              1315630*NL)))*Log[x]^3)/16216200 + 
       (4522773778666253687761858867853866*CF^2*NC*PolyGamma[2, 1])/
        33771292941824802225 + (28247247903031747*CF*NM*NC*PolyGamma[2, 1])/
        20 - (128044104470037352006768579*CF*NC*NH*PolyGamma[2, 1])/
        54034068706919683560 + CA*CF*NC*
        (43517556533382445025211723464179070239262338691935114297023406651690\
1/2571788528575262571743356799887046386334359280640000000 + 
         (2991065*lm^2)/24 - (7061898568862489900067546179*Pi^2)/
          182202628608000 + (3429871115857868927817354505*Pi^3)/
          (3663109605968362547712*Sqrt[3]) + (129537229*Pi^4)/8640 + 
         lm*(28165657508993261/62962099200 - (3179*Pi^2)/8) - 
         (14241372629011826700931977646915291*Im[PolyLog[2, (-1)^(1/3)]])/
          (1283370450451015818590899200*Sqrt[3]) + 
         (5852471*Im[PolyLog[2, (-1)^(1/3)]]^2)/4 + 
         (685974223171573785563470901*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (19785314229767390304*Sqrt[3]) + (685974223171573785563470901*Pi*
           Log[3]^2)/(949695083028834734592*Sqrt[3]) - 
         (2261386889333126843880929433926933*PolyGamma[2, 1])/
          33771292941824802225 - (22411237385410086885762596327985428557*
           Zeta[3])/432704822205012825948480) + 
       (112056190339836939734039958381582607409*CF^2*NC*Zeta[3])/
        1081762055512532064871200 - (9146577684660829*CF*NM*NC*Zeta[3])/30 - 
       2895695*CF*NC*NL*Zeta[3] + (745420680740043175476828101*CF*NC*NH*
         Zeta[3])/27017034353459841780 + CF*Log[x]*
        ((23749250795839162629659250707210516808739*NM*NC)/
          2324853510661669347360000 - (40097592317*lm*NM*NC)/48048 - 
         131784*lm^2*NM*NC - (332894302570078517*NC*NL)/64929664800 - 
         (40097592317*lm*NC*NL)/48048 - 131784*lm^2*NC*NL - 
         (320439010495370929404622242964838544690422593*NC*NH)/
          3653430358213358661264610668864480000 - (40097592317*lm*NC*NH)/
          48048 - 131784*lm^2*NC*NH + 1564805367274933*NM*NC*Pi^2 - 
         (1447414*NC*NL*Pi^2)/3 + (30649311624311266965992*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(2015427228435462269272117686926892404009536361559846067/
            84938720250694575946665490363355097600000 - (106045872279*lm)/
            8008 - 2372112*lm^2 + (2130944960448768945947*Pi^2)/25945920 + 
           (685974223171573785563470901*Im[PolyLog[2, (-1)^(1/3)]])/
            (29677971344651085456*Sqrt[3]) - 1581408*Zeta[3]) + 
         CA*NC*(-2381867524723934904383068471326995956909523359900904531/
            200764247865278088601209340858839321600000 + (48156447485*lm)/
            8736 + 724812*lm^2 - (1183858303970836687007*Pi^2)/28828800 - 
           (685974223171573785563470901*Im[PolyLog[2, (-1)^(1/3)]])/
            (59355942689302170912*Sqrt[3]) + 790704*Zeta[3])), 
      (-165924657234048100796764074066431875212442369246411566621422804693148\
27992327*CF^2*NC)/
        1953711877397034005507561731848592471829815881903429120000000 - 
       (3323638516125410849*CF^2*lm*NC)/5957039088000 - 
       (1870152*CF^2*lm^2*NC)/5 + 
       (1484350147056556715708571163074909093604809709746695387063*CF*NM*NC)/
        677510693428238385053700984324320217600000 - 
       (4994723800800617249*CF*lm*NM*NC)/107226703584000 - 
       (311692*CF*lm^2*NM*NC)/15 + (34735256625964155015513131*CF*NC*NL)/
        14490080588823840000 - (4994723800800617249*CF*lm*NC*NL)/
        107226703584000 - (311692*CF*lm^2*NC*NL)/15 + 
       (47123331133100544641900955774140359165205783659607857516163573*CF*NC*
         NH)/574047093317574779781266301888873618096555174796800000 - 
       (4994723800800617249*CF*lm*NC*NH)/107226703584000 - 
       (311692*CF*lm^2*NC*NH)/15 + (2875425467221357027152026194599637*CF^2*
         NC*Pi^2)/770102185140288000 + (4809*CF^2*lm*NC*Pi^2)/5 - 
       (5323869525613309310122*CF*NM*NC*Pi^2)/4922775 + 
       (1603*CF*lm*NM*NC*Pi^2)/30 - (2251514894347*CF*NC*NL*Pi^2)/
        26254800 + (1603*CF*lm*NC*NL*Pi^2)/30 + (1603*CF*lm*NC*NH*Pi^2)/
        30 - (42699174564294574133167713475*CF^2*NC*Pi^3)/
        (23352323738048311241664*Sqrt[3]) - (1619367213040923006524185*CF*NC*
         NH*Pi^3)/(150094635296999121*Sqrt[3]) - (426892139*CF^2*NC*Pi^4)/
        16200 + (15560107014596955287138097281930339533*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(695426362838144196698943504000*
         Sqrt[3]) + (188658710350437331805292693133*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7512236496614806006050*Sqrt[3]) - 
       (39888866*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (8539834912858914826633542695*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(126131378214767113188*
         Sqrt[3]) - (740282154532993374411056*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (8539834912858914826633542695*CF^2*NC*Pi*Log[3]^2)/
        (6054306154308821433024*Sqrt[3]) - (46267634658312085900691*CF*NC*NH*
         Pi*Log[3]^2)/(5559060566555523*Sqrt[3]) - 
       (CF*NC*(CA*(89182758453995957770023782515669002769 - 
            52714598275654774955034739200*lm) + 
          88*(CF*(-2026880872911715371636564765151254941 + 
              1960460266449970969402118400*lm) + 139230*
             ((4216567530454036897639412971679 + 782262868973788762560*lm)*
               NM + 49097207983824*(20709263 + 15932940*lm)*NL + 
              (244355807377655265763 + 782262868973788762560*lm)*NH)))*
         Log[x]^2)/3980850720536433744000 + 
       (CF*NC*(-2613334317149792133335463*CA + 
          34*(153725545182996867820697*CF - 2162160*(19948798091706797*NM - 
              9028666*NL)))*Log[x]^3)/413513100 + 
       (1381802395215754843775847932007197419*CF^2*NC*PolyGamma[2, 1])/
        540340687069196835600 - (2261888586001907*CF*NM*NC*PolyGamma[2, 1])/
        10 - (52553174481211698673300789*CF*NC*NH*PolyGamma[2, 1])/
        45028390589099736300 - (2770618068227668721958133473920772557959*CF^2*
         NC*Zeta[3])/2298744367964130637851300 + 
       (59438195964419723*CF*NM*NC*Zeta[3])/45 - 
       (39845242*CF*NC*NL*Zeta[3])/15 + (651004159368253582320194531*CF*NC*
         NH*Zeta[3])/22514195294549868150 + 
       CA*CF*NC*(319085879214442160805927329857190603857413061201155345133610\
852588170579151/75142764515270538673367758917253556608839072380901120000000 + 
         (1714306*lm^2)/15 - (191695031144820646178197553442977*Pi^2)/
          102680291352038400 + (42699174564294574133167713475*Pi^3)/
          (46704647476096622483328*Sqrt[3]) + (428277131*Pi^4)/32400 + 
         lm*(7830504889946422049/19495764288000 - (17633*Pi^2)/60) - 
         (15560107014596955287138097281930339533*Im[PolyLog[2, (-1)^(1/3)]])/
          (1390852725676288393397887008000*Sqrt[3]) + 
         (19944433*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (8539834912858914826633542695*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (252262756429534226376*Sqrt[3]) + (8539834912858914826633542695*Pi*
           Log[3]^2)/(12108612308617642866048*Sqrt[3]) - 
         (1381802395215754843775847932007197419*PolyGamma[2, 1])/
          1080681374138393671200 + (69265451838420617464323689789198539867*
           Zeta[3])/114937218398206531892565) + 
       CF*Log[x]*((-361265648132666928377274815241295665017227*NM*NC)/
          51558097471058405603376000 - (3285020524933*lm*NM*NC)/4375800 - 
         124032*lm^2*NM*NC - (38640048437583649333*NC*NL)/8278532262000 - 
         (3285020524933*lm*NC*NL)/4375800 - 124032*lm^2*NC*NL - 
         (23992766747919845930585203721977090665326763649*NC*NH)/
          305792120982458119947847912983956976000 - (3285020524933*lm*NC*NH)/
          4375800 - 124032*lm^2*NC*NH - (7979519231999246*NM*NC*Pi^2)/9 - 
         (19917812*NC*NL*Pi^2)/45 + (740282154532993374411056*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CF*NC*(9165530035388098093477455640509836759949442043801568506281649/
            422797742474127298456142894738899663673100000 - 
           (2877966105733*lm)/243100 - 2232576*lm^2 + 
           (5226668625357280459315883*Pi^2)/1654052400 + 
           (8539834912858914826633542695*Im[PolyLog[2, (-1)^(1/3)]])/
            (378394134644301339564*Sqrt[3]) - 1488384*Zeta[3]) + 
         CA*NC*
          (-73324240254242781334919394838103728957640789955196473886891747/
            6764763879586036775298286315822394618769600000 + 
           (3975779539333*lm)/795600 + 682176*lm^2 - 
           (69688914996601560507847*Pi^2)/44108064 - 
           (8539834912858914826633542695*Im[PolyLog[2, (-1)^(1/3)]])/
            (756788269288602679128*Sqrt[3]) + 744192*Zeta[3])), 
      (-140343633945014466444159933204450943599958589652736915104897883692228\
21685703*CF^2*NC)/
        5861135632191102016522685195545777415489447645710287360000000 - 
       (4692690042311928341*CF^2*lm*NC)/5559903148800 - 
       (1077699*CF^2*lm^2*NC)/2 - 
       (20289961393134216558667800698814954719537679565929201556739*CF*NM*
         NC)/451673795618825590035800656216213478400000 - 
       (6939653316146407541*CF*lm*NM*NC)/100078256678400 - 
       (359233*CF*lm^2*NM*NC)/12 + (214418107449807804918523*CF*NC*NL)/
        55200307005043200 - (6939653316146407541*CF*lm*NC*NL)/
        100078256678400 - (359233*CF*lm^2*NC*NL)/12 + 
       (205204456792335511543633853299841066693286645252987124266780061*CF*NC*
         NH)/1565582981775203944857999005151473503899695931264000000 - 
       (6939653316146407541*CF*lm*NC*NH)/100078256678400 - 
       (359233*CF*lm^2*NC*NH)/12 + (8994452529655269633512318484462821*CF^2*
         NC*Pi^2)/23616467010968832000 + (3249*CF^2*lm*NC*Pi^2)/2 + 
       (86782104648014586960817*CF*NM*NC*Pi^2)/4594590 + 
       (361*CF*lm*NM*NC*Pi^2)/4 - (656131839091*CF*NC*NL*Pi^2)/4900896 + 
       (361*CF*lm*NC*NL*Pi^2)/4 + (361*CF*lm*NC*NH*Pi^2)/4 - 
       (769761262416612140697314411575*CF^2*NC*Pi^3)/
        (280227884856579734899968*Sqrt[3]) - (16071490742427859998669305*CF*
         NC*NH*Pi^3)/(900567811781994726*Sqrt[3]) - (907260887*CF^2*NC*Pi^4)/
        21600 + (268541594061903703698954906869145160009*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8345116354057730360387322048000*
         Sqrt[3]) + (40659791550918161641423867627*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(693437215072135939020*Sqrt[3]) - 
       (40692661*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 - 
       (153952252483322428139462882315*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1513576538577205358256*
         Sqrt[3]) - (3673483598269225142552984*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (153952252483322428139462882315*CF^2*NC*Pi*Log[3]^2)/
        (72651673851705857196288*Sqrt[3]) - (459185449783653142819123*CF*NC*
         NH*Pi*Log[3]^2)/(33354363399333138*Sqrt[3]) + 
       CF*((4043006278614178529316442518190066243*CF*NC)/
          884633493452540832000 - 70279632*CF*lm*NC + 
         CA*(-4043006318764348072786622209116944543/1769266986905081664000 + 
           21474332*lm)*NC + (1402703093910031169660478678121*NM*NC)/
          6188723695440 - 3904424*lm*NM*NC - (25164607*NC*NL)/5 - 
         3904424*lm*NC*NL - (15847460307155093261*NC*NH)/12741489961200 - 
         3904424*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-264317643322837503359655*CA + 8*(66079396348118311533653*CF + 
            781080300*(2856446346039599*NM + 114836*NL)))*Log[x]^3)/
        275675400 + (415450940220847898885681972632735507*CF^2*NC*
         PolyGamma[2, 1])/405255515301897626700 + 
       (855893190213478303*CF*NM*NC*PolyGamma[2, 1])/60 - 
       (112941041062668028105013971*CF*NC*NH*PolyGamma[2, 1])/
        32420441224151810136 + CA*CF*NC*(140343633691828683723348833310498819\
17818379502746625038097775097969130868103/
          11722271264382204033045370391091554830978895291420574720000000 + 
         (3951563*lm^2)/24 - (2286919025329241155893474599897*Pi^2)/
          12009390801408000 + (769761262416612140697314411575*Pi^3)/
          (560455769713159469799936*Sqrt[3]) + (910379927*Pi^4)/43200 + 
         lm*(10752681902047341941/18196046668800 - (3971*Pi^2)/8) - 
         (268541594061903703698954906869145160009*Im[PolyLog[2, (-1)^(1/3)]])/
          (16690232708115460720774644096000*Sqrt[3]) + 
         (40692661*Im[PolyLog[2, (-1)^(1/3)]]^2)/20 + 
         (153952252483322428139462882315*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(3027153077154410716512*Sqrt[3]) + 
         (153952252483322428139462882315*Pi*Log[3]^2)/
          (145303347703411714392576*Sqrt[3]) - 
         (415450940220847898885681972632735507*PolyGamma[2, 1])/
          810511030603795253400 - (2408751125772873078306768011894961536317*
           Zeta[3])/4413589186491130824674496) + 
       (60218778399479493920467987751109457710277*CF^2*NC*Zeta[3])/
        55169864831139135308431200 - (115298566522090607*CF*NM*NC*Zeta[3])/
        30 - 4273727*CF*NC*NL*Zeta[3] + (653470678740730501674011189*CF*NC*
         NH*Zeta[3])/16210220612075905068 + 
       CF*Log[x]*((326777861332635824729707465347196884775075501*NM*NC)/
          3127857913244209939938144000 - (4774648774537*lm*NM*NC)/4084080 - 
         184110*lm^2*NM*NC - (519968053694379847*NC*NL)/68987768850 - 
         (4774648774537*lm*NC*NL)/4084080 - 184110*lm^2*NC*NL - 
         (2210745671500232626402360846151672343680292652537*NC*NH)/
          17036989597594095254237240866249031520000 - 
         (4774648774537*lm*NC*NH)/4084080 - 184110*lm^2*NC*NH + 
         (145678763654517017*NM*NC*Pi^2)/9 - (2136322*NC*NL*Pi^2)/3 + 
         (3673483598269225142552984*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (16677181699666569*Sqrt[3]) + 
         CF*NC*
          (-297048925451819376578477632969483677098942933106220504067257967/
            162354333110064882607158871579737470850470400000 - 
           (12632126393811*lm)/680680 - 3313980*lm^2 + 
           (1057270554629673231851489*Pi^2)/2205403200 + 
           (153952252483322428139462882315*Im[PolyLog[2, (-1)^(1/3)]])/
            (4540729615731616074768*Sqrt[3]) - 2209320*Zeta[3]) + 
         CA*NC*
          (297048927815598713843008783148847305292188127363130564961890277/
            324708666220129765214317743159474941700940800000 + 
           (5731637825737*lm)/742560 + 1012605*lm^2 - 
           (7831633725685945562791*Pi^2)/32672640 - 
           (153952252483322428139462882315*Im[PolyLog[2, (-1)^(1/3)]])/
            (9081459231463232149536*Sqrt[3]) + 1104660*Zeta[3])), 
      (-125912493675724728718631551934993731979095088674815333432883174909533\
9395124907*CF^2*NC)/
        13881637023610504775974780726292630720896060213524364800000000 - 
       (824013466833261030289*CF^2*lm*NC)/1125880387632000 - 
       (2453261*CF^2*lm^2*NC)/5 + 
       (64858664855614696601524845872555761524277314529986581284361*CF*NM*
         NC)/2540665100355893943951378691216200816000000 - 
       (1238325233679631223089*CF*lm*NM*NC)/20265846977376000 - 
       (2453261*CF*lm^2*NM*NC)/90 + (127513402529394814455034739*CF*NC*NL)/
        35799022631211840000 - (1238325233679631223089*CF*lm*NC*NL)/
        20265846977376000 - (2453261*CF*lm^2*NC*NL)/90 + 
       (20027593147183713377950608102160065772219266621081760496120159*CF*NC*
         NH)/166658833543812032839722474741931050415128921715200000 - 
       (1238325233679631223089*CF*lm*NC*NH)/20265846977376000 - 
       (2453261*CF*lm^2*NC*NH)/90 + (18356394717758354496434175643875217*
         CF^2*NC*Pi^2)/466114480479648000 + (53789*CF^2*lm*NC*Pi^2)/45 - 
       (385792335747117557456059*CF*NM*NC*Pi^2)/31808700 + 
       (53789*CF*lm*NM*NC*Pi^2)/810 - (65499367151503*CF*NC*NL*Pi^2)/
        551350800 + (53789*CF*lm*NC*NL*Pi^2)/810 + (53789*CF*lm*NC*NH*Pi^2)/
        810 - (12310423052752368895939164199*CF^2*NC*Pi^3)/
        (4636123095053708849448*Sqrt[3]) - (42781041610644955752238895*CF*NC*
         NH*Pi^3)/(2701703435345984178*Sqrt[3]) - (74494516*CF^2*NC*Pi^4)/
        2025 + (7922662426741025406105031342079261*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(246540333464153010909551925*Sqrt[3]) + 
       (201020393768235915425654200501*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (5200779113041019542650*Sqrt[3]) - 
       (10997504*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (3517263729357819684554046914*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(35772554745784790505*
         Sqrt[3]) - (9778523796718847029083176*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (1758631864678909842277023457*CF^2*NC*Pi*Log[3]^2)/
        (858541313898834972120*Sqrt[3]) - (1222315474589855878635397*CF*NC*
         NH*Pi*Log[3]^2)/(100063090197999414*Sqrt[3]) - 
       (CF*NC*(-361*CA*(-6514104808443211010979624920692829909 + 
            536521553682661689734592000*lm) + 
          52*(19*CF*(-4760307359675000256113727751501325851 + 
              641574725033112929682624000*lm) + 196350*
             (2*(70931734102642132979221985681177 + 1724516845716145440960*
                 lm)*NM + 31*(993030625995408*(145463 + 112040*lm)*NL + 
                (35755488026739683711 + 111259151336525512320*lm)*NH))))*
         Log[x]^2)/9952126801341084360000 + 
       (CF*NC*(-27656317006701445359557117*CA + 
          320*(172851980816969886118595*CF - 306306*(169452781388863096*NM - 
              9951953*NL)))*Log[x]^3)/413513100 + 
       (389233918600639065624893924449994992693*CF^2*NC*PolyGamma[2, 1])/
        14589198550868314561200 - (1140931307157109363*CF*NM*NC*
         PolyGamma[2, 1])/324 - (2087297226769475534209729721*CF*NC*NH*
         PolyGamma[2, 1])/1215766545905692880100 - 
       (1678536036563832949414658224616511307978469*CF^2*NC*Zeta[3])/
        124132195870063054443970200 + (10562810500726784497*CF*NM*NC*
         Zeta[3])/810 - (524197042*CF*NC*NL*Zeta[3])/135 + 
       (25421861166961553196681671839*CF*NC*NH*Zeta[3])/
        607883272952846440050 + CA*CF*NC*(96855764362529278417800310389596796\
854859298896448224398795951615969793638839/
          2135636465170846888611504727121943187830163109772979200000000 + 
         (26985871*lm^2)/180 - (798104118161604439462946796801239*Pi^2)/
          40531693954752000 + (12310423052752368895939164199*Pi^3)/
          (9272246190107417698896*Sqrt[3]) + (12451612*Pi^4)/675 + 
         lm*(1941399747115895792689/3684699450432000 - (591679*Pi^2)/1620) - 
         (7922662426741025406105031342079261*Im[PolyLog[2, (-1)^(1/3)]])/
          (493080666928306021819103850*Sqrt[3]) + 
         (5498752*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (1758631864678909842277023457*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (35772554745784790505*Sqrt[3]) + (1758631864678909842277023457*Pi*
           Log[3]^2)/(1717082627797669944240*Sqrt[3]) - 
         (389233918600639065624893924449994992693*PolyGamma[2, 1])/
          29178397101736629122400 + 
         (1678536036979716961103186415457403635970993*Zeta[3])/
          248264391740126108887940400) + CF*Log[x]*
        ((-764579106166428254036630843007968854356526993*NM*NC)/
          10053829006856389092658320000 - (287504503302871*lm*NM*NC)/
          275675400 - 171836*lm^2*NM*NC - (29799118781560449329*NC*NL)/
          4382752374000 - (287504503302871*lm*NC*NL)/275675400 - 
         171836*lm^2*NC*NL - 
         (132881598840147111450218573195921898137361252541*NC*NH)/
          1154118650159600001093490510294289232000 - 
         (287504503302871*lm*NC*NH)/275675400 - 171836*lm^2*NC*NH - 
         (90374816733461401*NM*NC*Pi^2)/9 - (87348244*NC*NL*Pi^2)/135 + 
         (9778523796718847029083176*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CF*NC*
          (21699580396744729315456626795388921190546321085556341275284646303/
            96130855130959469964765121330107713003568000000 - 
           (251976284777071*lm)/15315300 - 3093048*lm^2 + 
           (27656317000120642020511901*Pi^2)/827026200 + 
           (3517263729357819684554046914*Im[PolyLog[2, (-1)^(1/3)]])/
            (107317664237354371515*Sqrt[3]) - 2062032*Zeta[3]) + 
         CA*NC*
          (-10849790197790809240161341115049842882896901326487667970934554089/
            96130855130959469964765121330107713003568000000 + 
           (347794813528471*lm)/50122800 + 945098*lm^2 - 
           (27656316999674808309421133*Pi^2)/1654052400 - 
           (1758631864678909842277023457*Im[PolyLog[2, (-1)^(1/3)]])/
            (107317664237354371515*Sqrt[3]) + 1031016*Zeta[3])), 
      (-424587994634905305716648309999424996331539687549004680298674882768253\
5626743*CF^2*NC)/
        304328196286845681627139423614876904265798243142649536000000 - 
       (4947117661027718861*CF^2*lm*NC)/4503521550528 - 701480*CF^2*lm^2*NC - 
       (67486362050309781128702080209978044810270193455426701514761*CF*NM*
         NC)/145180862877479653940078782355211475200000 - 
       (7316465383976004941*CF*lm*NM*NC)/81063387909504 - 
       (350740*CF*lm^2*NM*NC)/9 + (944296202913435122436064097*CF*NC*NL)/
        165534680646723548160 - (7316465383976004941*CF*lm*NC*NL)/
        81063387909504 - (350740*CF*lm^2*NC*NL)/9 + 
       (223467000192453963193020298103192041020708592191447072194259256961189*
         CF*NC*NH)/
        1177626900421512170470549520577873172786514775393783571200000 - 
       (7316465383976004941*CF*lm*NC*NH)/81063387909504 - 
       (350740*CF*lm^2*NC*NH)/9 - (2252260156066186285170238048993*CF^2*NC*
         Pi^2)/23356945395463680 + (18050*CF^2*lm*NC*Pi^2)/9 + 
       (1782152426185732878711449*CF*NM*NC*Pi^2)/9189180 + 
       (9025*CF*lm*NM*NC*Pi^2)/81 - (2026344081785*CF*NC*NL*Pi^2)/
        11027016 + (9025*CF*lm*NC*NL*Pi^2)/81 + (9025*CF*lm*NC*NH*Pi^2)/
        81 - (574436403427268108131174570385*CF^2*NC*Pi^3)/
        (145502940213993323890368*Sqrt[3]) - (314602166937321402085149665*CF*
         NC*NH*Pi^3)/(12157665459056928801*Sqrt[3]) - 
       (37576357*CF^2*NC*Pi^4)/648 + (7938998677477609397436925803854713487*
         CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/(173321647353506707484967457920*
         Sqrt[3]) + (12871900842974524238782338325801*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(147776423654836969576155*Sqrt[3]) - 
       (50059490*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (114887280685453621626234914077*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(785895510415087397556*
         Sqrt[3]) - (143818133457061212381782704*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) - (114887280685453621626234914077*CF^2*NC*Pi*Log[3]^2)/
        (37722984499924195082688*Sqrt[3]) - (8988633341066325773861419*CF*NC*
         NH*Pi*Log[3]^2)/(450283905890997363*Sqrt[3]) + 
       CF*((-3937076623225581359213148362806417*CF*NC)/3402436513279003200 - 
         102108280*CF*lm*NC + CA*(153545979557986911876136323736591819/
            265390048035762249600 + (280797770*lm)/9)*NC + 
         (226845926547953697341805495054437*NM*NC)/97472398203180 - 
         (51054140*lm*NM*NC)/9 - (197254732*NC*NL)/27 - 
         (51054140*lm*NC*NL)/9 - (956169775568844450967*NC*NH)/
          515211247645380 - (51054140*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-114674021766906875658497*CA + 
          208*(1102634696890780361482*CF + 58905*(2248643367417664856*NM + 
              12763535*NL)))*Log[x]^3)/41351310 + 
       (78422042250592990700871275639947934627*CF^2*NC*PolyGamma[2, 1])/
        10941898913151235920900 + (465945645293670344227*CF*NM*NC*
         PolyGamma[2, 1])/3240 - (21966412587443412518951235991*CF*NC*NH*
         PolyGamma[2, 1])/4376759565260494368360 + 
       CA*CF*NC*(551964392776517363289937386218061257388096456010457001121033\
66337317777757659/
          7912533103457987722305625013986799510910754321708887936000000 + 
         (1929070*lm^2)/9 + (592700042160619079036916029207*Pi^2)/
          12293129155507200 + (574436403427268108131174570385*Pi^3)/
          (291005880427986647780736*Sqrt[3]) + (12563959*Pi^4)/432 + 
         lm*(11337176671403399501/14738797801728 - (99275*Pi^2)/162) - 
         (7938998677477609397436925803854713487*Im[PolyLog[2, (-1)^(1/3)]])/
          (346643294707013414969934915840*Sqrt[3]) + 
         (25029745*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 + 
         (114887280685453621626234914077*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1571791020830174795112*Sqrt[3]) + 
         (114887280685453621626234914077*Pi*Log[3]^2)/
          (75445968999848390165376*Sqrt[3]) - 
         (78422042250592990700871275639947934627*PolyGamma[2, 1])/
          21883797826302471841800 - 
         (331178018821435419810977745496440718019567*Zeta[3])/
          57291782709259871281832400) + 
       (331178019011898389576561974105487580565247*CF^2*NC*Zeta[3])/
        28645891354629935640916200 - (73728762814233494333*CF*NM*NC*Zeta[3])/
        1620 - (166844320*CF*NC*NL*Zeta[3])/27 + 
       (126394373094102006531321361769*CF*NC*NH*Zeta[3])/
        2188379782630247184180 + CF*Log[x]*
        ((3741699946714067798927833930127626392010524169*NM*NC)/
          3518840152399736182430412000 - (8868965073037*lm*NM*NC)/5513508 - 
         252700*lm^2*NM*NC - (2200733096194895680129*NC*NL)/
          202658469773760 - (8868965073037*lm*NC*NL)/5513508 - 
         252700*lm^2*NC*NL - 
         (41464515896592354015032851339490593939013544620085463*NC*NH)/
          220408386273554690008829896948707033225816000 - 
         (8868965073037*lm*NC*NH)/5513508 - 252700*lm^2*NC*NH + 
         (4497286734865333334*NM*NC*Pi^2)/27 - (27801370*NC*NL*Pi^2)/27 + 
         (143818133457061212381782704*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CF*NC*
          (-644518187873918413690269752490175488467954272811834232881740049/
            16859873053737507039974190510203506588318080000 - 
           (7824017469337*lm)/306306 - 4548600*lm^2 + 
           (35284314076544963960923*Pi^2)/25446960 + 
           (114887280685453621626234914077*Im[PolyLog[2, (-1)^(1/3)]])/
            (2357686531245262192668*Sqrt[3]) - 3032400*Zeta[3]) + 
         CA*NC*
          (8378736446858415701130331576060705849605648889049392980125838827/
            438356699397175183039328953265291171296270080000 + 
           (10642209491437*lm)/1002456 + 1389850*lm^2 - 
           (35284314048909805513411*Pi^2)/50893920 - 
           (114887280685453621626234914077*Im[PolyLog[2, (-1)^(1/3)]])/
            (4715373062490524385336*Sqrt[3]) + 1516200*Zeta[3])), 
      (-108299648685318367209708279852034898669960597318804653655270669351446\
1337463132133*CF^2*NC)/
        1127535967242763250428551564493118930304782490843516530880000000 - 
       (3847655615583506515121*CF^2*lm*NC)/4064428199351520 - 
       634672*CF^2*lm^2*NC + 
       (3499603430323896935868006715113603384378966003515642914543*CF*NM*NC)/
        12098405239789971161673231862934289600000 - 
       (5782339696187627441201*CF*lm*NM*NC)/73159707588327360 - 
       (317336*CF*lm^2*NM*NC)/9 + (4422683705526176266039459697*CF*NC*NL)/
        853685995906674298368 - (5782339696187627441201*CF*lm*NC*NL)/
        73159707588327360 - (317336*CF*lm^2*NC*NL)/9 + 
       (20052492664926319087783206780409107390105748269347779035199712793761*
         CF*NC*NH)/
        116213180962649227349067386899132220998669221255965484000000 - 
       (5782339696187627441201*CF*lm*NC*NH)/73159707588327360 - 
       (317336*CF*lm^2*NC*NH)/9 + (2775224900831686907032424624598178303*
         CF^2*NC*Pi^2)/6730693098126117120 + (13220*CF^2*lm*NC*Pi^2)/9 - 
       (1164879368252499803074781*CF*NM*NC*Pi^2)/8729721 + 
       (6610*CF*lm*NM*NC*Pi^2)/81 - (50854861190729*CF*NC*NL*Pi^2)/
        314269956 + (6610*CF*lm*NC*NL*Pi^2)/81 + (6610*CF*lm*NC*NH*Pi^2)/
        81 - (203891730733489357924134813892891*CF^2*NC*Pi^3)/
        (53908839349284526501381344*Sqrt[3]) - 
       (831302942548510605067210085*CF*NC*NH*Pi^3)/(36472996377170786403*
         Sqrt[3]) - (27246301*CF^2*NC*Pi^4)/540 + 
       (39520878354518477259118400678112924861401*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(871498383246436048100306014305600*
         Sqrt[3]) + (180144116694871574808461383236688*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3103304896751576361099255*Sqrt[3]) - 
       (14914004*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 - 
       (29127390104784193989162116270413*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(207981633291992771996070*
         Sqrt[3]) - (380024202307890562316438896*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) - (29127390104784193989162116270413*CF^2*NC*Pi*Log[3]^2)/
        (9983118398015653055811360*Sqrt[3]) - 
       (23751512644243160144777431*CF*NC*NH*Pi*Log[3]^2)/
        (1350851717672992089*Sqrt[3]) + 
       CF*((31186589821955423615480952949382765182681*CF*NC)/
          6303013640849353428000 - 91740208*CF*lm*NC + 
         CA*(-1155058882306033141960041012206074004563/
            466889899322174328000 + (252285572*lm)/9)*NC - 
         (765091398627518945099681411713*NM*NC)/477805873545 - 
         (45870104*lm*NM*NC)/9 - (178484480*NC*NL)/27 - 
         (45870104*lm*NC*NL)/9 - (688704229951159906511*NC*NH)/
          409827128808825 - (45870104*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-91979303621799252235284145*CA + 
          912*(201708999090690536526633*CF - 85085*(751579967238132392*NM - 
              5733763*NL)))*Log[x]^3)/130945815 + 
       (727341073544910170661589992884014742233*CF^2*NC*PolyGamma[2, 1])/
        2626055739156296621016 - (379664547194551508567*CF*NM*NC*
         PolyGamma[2, 1])/8100 - (81222258799196177564132921689*CF*NC*NH*
         PolyGamma[2, 1])/32825696739453707762700 - 
       (6061044496942200364274086613490845283200926*CF^2*NC*Zeta[3])/
        40820395180347658288305585 + (522231413658946324633*CF*NM*NC*
         Zeta[3])/4050 - (150277072*CF*NC*NL*Zeta[3])/27 + 
       (974426374090861863395240958311*CF*NC*NH*Zeta[3])/
        16412848369726853881350 + CA*CF*NC*(108299648684799647263655883688296\
9760700643050771675256158142289896580362576367883/
          2255071934485526500857103128986237860609564981687033061760000000 + 
         (1745348*lm^2)/9 - (13876124504154330093597898165339860179*Pi^2)/
          67306930981261171200 + (203891730733489357924134813892891*Pi^3)/
          (107817678698569053002762688*Sqrt[3]) + (81950423*Pi^4)/3240 + 
         lm*(9065439954182499315761/13301765016059520 - (36355*Pi^2)/81) - 
         (39520878354518477259118400678112924861401*
           Im[PolyLog[2, (-1)^(1/3)]])/(1742996766492872096200612028611200*
           Sqrt[3]) + (7457002*Im[PolyLog[2, (-1)^(1/3)]]^2)/3 + 
         (29127390104784193989162116270413*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(415963266583985543992140*Sqrt[3]) + 
         (29127390104784193989162116270413*Pi*Log[3]^2)/
          (19966236796031306111622720*Sqrt[3]) - 
         (727341073544910170661589992884014742233*PolyGamma[2, 1])/
          5252111478312593242032 + 
         (6061044497136951954236062288871986040982877*Zeta[3])/
          81640790360695316576611170) + CF*Log[x]*
        ((-477638608973373047504436317680349021220804899*NM*NC)/
          586473358733289363738402000 - (74596212362267*lm*NM*NC)/52378326 - 
         234080*lm^2*NM*NC - (18704909581423318020461*NC*NL)/
          1925255462850720 - (74596212362267*lm*NC*NL)/52378326 - 
         234080*lm^2*NC*NL - 
         (273909479836820581340526533536737139463233415134068037*NC*NH)/
          1653062897051660175066224227115302749193620000 - 
         (74596212362267*lm*NC*NH)/52378326 - 234080*lm^2*NC*NH - 
         (3006319868919631904*NM*NC*Pi^2)/27 - (25041772*NC*NL*Pi^2)/27 + 
         (380024202307890562316438896*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1350851717672992089*Sqrt[3]) + CF*NC*(7293295623836925899824529126\
6040285288968804412217671747229060388503/
            31232914832048731791552187920151995954859243200000 - 
           (65400673449707*lm)/2909907 - 4213440*lm^2 + 
           (28301324190398162453162009*Pi^2)/80582040 + 
           (29127390104784193989162116270413*Im[PolyLog[2, (-1)^(1/3)]])/
            (623944899875978315988210*Sqrt[3]) - 2808960*Zeta[3]) + 
         CA*NC*
          (
           -56102274029109790567194913607084011408165507583997535121792879931\
31/4805063820315189506392644295407999377670652800000 + (90200763244187*lm)/
            9523332 + 1287440*lm^2 - (28301324190336085734532853*Pi^2)/
            161164080 - (29127390104784193989162116270413*
             Im[PolyLog[2, (-1)^(1/3)]])/(1247889799751956631976420*
             Sqrt[3]) + 1404480*Zeta[3]))}, 0, 39, 1]
 
CbarSeries["a", 2, 2, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(20*CF*(76466554762 + 80953344*lm + 179159040*lm^2 - 
           63547331247*Zeta[3]) - 2*CA*(-90048545102 + 1354659840*lm + 
           547430400*lm^2 + 75644617365*Zeta[3]) + 
         3*(6144*(40863 + 12980*lm + 10800*lm^2)*NL + 
           5*NM*(-116358970 + 15949824*lm + 13271040*lm^2 + 
             92510775*Zeta[3]) + 5*NH*(-116358970 + 15949824*lm + 
             13271040*lm^2 + 92510775*Zeta[3]))))/250822656000, 
      -(CF*NC*(80*CF*(76507031434 + 260112384*lm + 179159040*lm^2 - 
            63547331247*Zeta[3]) - 8*CA*(-89371215182 + 1902090240*lm + 
            547430400*lm^2 + 75644617365*Zeta[3]) + 
          3*(24576*(47353 + 23780*lm + 10800*lm^2)*NL + 
            5*NM*(-64032154 + 116883456*lm + 53084160*lm^2 + 
              119499975*Zeta[3]) + 5*NH*(-803040310 + 116883456*lm + 
              53084160*lm^2 + 620586225*Zeta[3]))))/501645312000, 
      (CF*NC*(3555777926050*NM + 3684987371520*lm*NM + 
         1300561920000*lm^2*NM + 6981021827072*NL + 3684987371520*lm*NL + 
         1300561920000*lm^2*NL - 32655621717950*NH + 3684987371520*lm*NH + 
         1300561920000*lm^2*NH + 140*CF*(1050875684405390 + 
           348372762624*lm + 167215104000*lm^2 - 874075229359605*Zeta[3]) + 
         1233811774125*NM*Zeta[3] + 25787038024125*NH*Zeta[3] - 
         2*CA*(-4798853896359062 + 14685681991680*lm + 3576545280000*lm^2 + 
           4004603033393025*Zeta[3])))/655483207680000, 
      -(CF*NC*(70*CF*(9029151162882622 + 1210523222016*lm + 
            501645312000*lm^2 - 7510812009253245*Zeta[3]) - 
          CA*(-39702677612669318 + 47594873733120*lm + 10729635840000*lm^2 + 
            33076158299829225*Zeta[3]) + 
          3*(16384*(254201777 + 125543670*lm + 39690000*lm^2)*NL + 
            70*NM*(31474029026 + 29384392704*lm + 9289728000*lm^2 + 
              22687829325*Zeta[3]) + 105*NH*(-245888858950 + 
              19589595136*lm + 6193152000*lm^2 + 198200140425*Zeta[3]))))/
       983224811520000, (CF*NC*(296766659797650*NM + 4343592588410880*lm*
          NM + 1348422598656000*lm^2*NM + 9834411213979648*NL + 
         4343592588410880*lm*NL + 1348422598656000*lm^2*NL - 
         82163129255026470*NH + 4343592588410880*lm*NH + 
         1348422598656000*lm^2*NH + 18*CF*(103636873284294415238 + 
           3332275639418880*lm + 1348422598656000*lm^2 - 86214629169620757225*
            Zeta[3]) + 9389419597837125*NM*Zeta[3] + 67154464259969625*NH*
          Zeta[3] - CA*(-89709101280954175562 + 33328717426851840*lm + 
           7416324292608000*lm^2 + 74666786943288999375*Zeta[3])))/
       778714050723840000, 
      -(CF*NC*(-5*CA*(-10733132790920604346 + 1256235916787712*lm + 
            293562836582400*lm^2 + 8930479677115526775*Zeta[3]) + 
          2*(9*CF*(71500464120378462958 + 602216691793920*lm + 
              266875305984000*lm^2 - 59481526369218689925*Zeta[3]) + 
            315*NM*(-3791649660090 + 1273608208384*lm + 423611596800*lm^2 + 
              6848260147575*Zeta[3]) + 4*(4096*(64126230779 + 24486485940*
                 lm + 8144388000*lm^2)*NL + 315*NH*(-9719383157414 + 
                318402052096*lm + 105902899200*lm^2 + 8012477590425*
                 Zeta[3])))))/194678512680960000, 
      (CF*NC*(-4851*CA*(-9087544342282204837706 + 312580616473804800*lm + 
           83398612746240000*lm^2 + 7560377100220528695375*Zeta[3]) + 
         5*(22*CF*(11216319897510523432566862 + 20766957994565959680*lm + 
             12036694326902784000*lm^2 - 9330937917629098267883925*Zeta[3]) + 
           21*(262144*(21285602075053 + 6614952816780*lm + 2672379864000*
                lm^2)*NL + 495*NH*(-194802690410812286 + 3503172103438336*
                lm + 1415249185996800*lm^2 + 161422788570968925*Zeta[3]) + 
             495*NM*(3503172103438336*lm + 1415249185996800*lm^2 + 55*
                (-775304097374546 + 897641948438235*Zeta[3]))))))/
       73495032107316019200000, 
      -(CF*NC*(22*CF*(25919638287098530267012598 + 6128615696750346240*lm + 
            8120875100405760000*lm^2 - 21562748457783416408257425*Zeta[3]) - 
          99*CA*(-179242212948806719037498 + 1531507676841246720*lm + 
            551417445089280000*lm^2 + 149114552050568294241975*Zeta[3]) + 
          3*(262144*(91755487452689 + 18990409602780*lm + 12620943720000*lm^
                2)*NL + 693*NH*(-998456702387231142 + 7183581435658240*lm + 
              4774177013760000*lm^2 + 829891025780441625*Zeta[3]) + 
            231*NM*(-1141352574802778786 + 21550744306974720*lm + 
              14322531041280000*lm^2 + 1095451577050705875*Zeta[3]))))/
       14699006421463203840000, 
      (CF*NC*(104*CF*(2974138437801346213702319813482 - 
           258852230036941543833600*lm + 266660762959069839360000*lm^2 - 
           2474208645748450340989729845375*Zeta[3]) - 
         132*CA*(-64134796557423757629102712798 + 67534944091966852300800*
            lm + 64196109601257553920000*lm^2 + 53354173081290605930455174125*
            Zeta[3]) + 105*(268435456*(280839916227557 - 12064997980035*lm + 
             54662661553500*lm^2)*NL + 1287*NH*(-3770944343520756199226 - 
             2516451619588014080*lm + 11401240466423808000*lm^2 + 
             3139778131795002072375*Zeta[3]) + 143*NM*
            (-21216965535102158118154 - 22648064576292126720*lm + 
             102611164197814272000*lm^2 + 18603535338557709915375*Zeta[3]))))/
       3709637247272740297113600000, 
      -(CF*NC*(416*CF*(9025565838092172747634380617498 - 
            945918913558367069798400*lm + 214694578640765583360000*lm^2 - 
            7508436442100310796022987418375*Zeta[3]) - 
          4752*CA*(-19187797604483118928589145598 - 13686120046203712307200*
             lm + 5742859099444346880000*lm^2 + 15962421181620074116170340125*
             Zeta[3]) + 105*(134217728*(-113531489790161 - 1287166874813820*
               lm + 352081107378000*lm^2)*NL + 3003*NM*
             (-9285748294865762811974 - 57529341822967480320*lm + 
              15736105995337728000*lm^2 + 7811735582708223791625*Zeta[3]) + 
            1287*NH*(-21084897298044494369026 - 134235130920257454080*lm + 
              36717580655788032000*lm^2 + 17572197365890592299875*Zeta[3]))))/
       22257823483636441782681600000, 
      (CF*NC*(-11*CA*(-3874937931388767062594870262094918 - 
           3290910164763412920061132800*lm + 272427128737445330288640000*
            lm^2 + 3223580485813328542212126638447625*Zeta[3]) + 
         15*(54*CF*(2423708168164269541377576384242054 - 
             170753597684063437250887680*lm + 12107872388330903568384000*
              lm^2 - 2016300922348467475856259656757225*Zeta[3]) + 
           7*(4831838208*(-19364949472726497 - 14339945624344340*lm + 
               1073936655792000*lm^2)*NL + 143*NH*
              (-46417096084687530568678598 - 484533546631813964759040*lm + 
               36287329835157553152000*lm^2 + 38700483113809288746599625*
                Zeta[3]) + 143*NM*(-80374910971219508709916838 - 
               484533546631813964759040*lm + 36287329835157553152000*lm^2 + 
               66551399605495382170217625*Zeta[3])))))/
       6054127987549112164889395200000, 
      (CF*NC*(275*CA*(-36667007981770955403496634248246 - 
           22937390811489070328315904*lm + 80942245885024351027200*lm^2 + 
           30503494454331066175297817191665*Zeta[3]) + 
         2*(-11*CF*(23455728049900744119348980113272506 - 
             945045609535493425122508800*lm + 3311273695296450723840000*
              lm^2 - 19512994113795330710548354497504375*Zeta[3]) - 
           15*(1001*NM*(-8711684763157004627739658 - 38362318040863699107840*
                lm + 134768974167539712000*lm^2 + 7186151899560964526571375*
                Zeta[3]) + 2*(134217728*(-275157501497250847 - 
                 143053681995364140*lm + 502555605552000*lm^2)*NL + 143*NH*
                (-10127165492198667620022458 - 134268113143022946877440*lm + 
                 471691409586388992000*lm^2 + 8444394086077199523648375*
                  Zeta[3]))))))/864875426792730309269913600000, 
      -(CF*NC*(-128*CA*(8323763553223167094462166556516925822 + 
            3298942803622929852852810547200*lm + 
            110658712030399988917862400000*lm^2 - 
            6924591608224498607462284026268588125*Zeta[3]) + 
          30464*CF*(-1977033321657551897722941905512269838 + 
            42285704628735670206490214400*lm + 1521662961456989916364800000*
             lm^2 + 1644708632481918194156389951044643125*Zeta[3]) + 
          45*(12884901888*(294812836188232579337 + 126759389548870298220*lm + 
              4441598129208240000*lm^2)*NL + 2431*NH*
             (671856148794720844838338560*lm + 23541569774073434603520000*lm^
                2 - 46189*(-964075465466073439773878 + 
                803792093610734836232625*Zeta[3])) + 2431*NM*
             (671856148794720844838338560*lm + 23541569774073434603520000*lm^
                2 - 323*(-743702495784332341941828514 + 
                614043299144441152905793875*Zeta[3])))))/
       56988371622226585538413146931200000, 
      (CF*NC*(-56*CA*(14831802261394811553753133785585238858 + 
           3460511401211922009987376742400*lm + 
           196769342587027378447319040000*lm^2 - 
           12338676345812231946519925166630775375*Zeta[3]) + 
         5*(272*CF*(-37936378562765094392644269625166763794 + 
             412700627140203466248463319040*lm + 
             26516510337930962229264384000*lm^2 + 
             31559553277687568510564140637320311675*Zeta[3]) + 
           9*(4294967296*(452161523514763139029 + 169109694940074328440*lm + 
               10365980728927824000*lm^2)*NL + 2431*NM*
              (183800087327071508306268611878 + 298774417607633040090071040*
                lm + 18314088120819105398784000*lm^2 - 
               152077814254310769836516129625*Zeta[3]) + 
             2431*NH*(298774417607633040090071040*lm + 
               18314088120819105398784000*lm^2 - 2431*
                (-7626633492850109097178358 + 6357146969989237529732625*
                  Zeta[3]))))))/28494185811113292769206573465600000, 
      -(CF*NC*(-2*CA*(8512663244294295001212656674517056678887562 + 
            1119331260846884507955533613681868800*lm + 
            83689911655982423957768849326080000*lm^2 - 
            7081744204924808534587909696013565382947375*Zeta[3]) + 
          5*(21*(34359738368*(307604878849511558002253 + 
                102084326375398777289880*lm + 8435314284934144608000*lm^2)*
               NL + 37791*NM*(92815504901490400871831306240*lm + 
                7669423722108179535888384000*lm^2 + 323*
                 (324104217347268035716278991706 - 
                  268685448712859062301704662375*Zeta[3])) + 
              4199*NH*(50700914238790470437866205864222 + 
                835339544113413607846481756160*lm + 
                69024813498973615822995456000*lm^2 - 
                42248432669656257167250468466125*Zeta[3])) + 
            76*CF*(-3043945476044676051505760317932109846289482 + 
              16364487170897100633328336785899520*lm + 
              1441548717519314479655348600832000*lm^2 + 
              2532280689537078304331886076864020917837775*Zeta[3]))))/
       384025640238310884414853392787046400000, 
      (CF*NC*(-2*CA*(12664587353188892142196967072169127952271194 + 
           911201576708088693466482212654284800*lm + 
           82770508174361339219290903019520000*lm^2 - 
           10535760963653277903733129311413441591574375*Zeta[3]) + 
         3*(76*CF*(-8220437496861856419245956827227462950048214 + 
             21352519017597483681171157234483200*lm + 
             2376186837541473853185384775680000*lm^2 + 
             6838642561302599701914744409733230973174625*Zeta[3]) + 
           455*(34359738368*(21065834490023726955371 + 6248027717506416801960*
                lm + 641741947845302304000*lm^2)*NL + 2261*NM*
              (206213944150528232562484204478506 + 
               94949401897183854346087956480*lm + 
               9752359764588805176164352000*lm^2 - 
               171191943766785422087210286057375*Zeta[3]) + 
             4199*NH*(51126601021560536955585822720*lm + 
               5251270642470895094857728000*lm^2 - 71383*
                (-44013131796189198150851458 + 36663064510702409265283875*
                  Zeta[3]))))))/384025640238310884414853392787046400000, 
      -(CF*NC*(-10*CA*(3738871863619026348463178027079216558998753054 + 
            143959591618418316930853632250824622080*lm + 
            15425708063947325059221686807691264000*lm^2 - 
            3110394636346754623637693303206074811136299725*Zeta[3]) + 
          3*(4*CF*(-250147043670017656721264487671471240041861670606 + 
              307520703317299215786373741311059558400*lm + 
              42070112901674522888786418566430720000*lm^2 + 
              208099169771341517575311345440369537166549175125*Zeta[3]) + 
            385*(68719476736*(10746250092099344151353527 + 
                2848003314912458175793320*lm + 353362606980080954256000*lm^2)*
               NL + 4199*NM*(202959891824818492536107450031996086 + 
                46609501677346404260062408212480*lm + 
                5783018206653961503070224384000*lm^2 - 
                168641667502260857233590802404488625*Zeta[3]) + 
              4199*NH*(46609501677346404260062408212480*lm + 
                5783018206653961503070224384000*lm^2 - 4199*
                 (-712162565745517311555874820794 + 
                  593029781866783022548732320375*Zeta[3]))))))/
       388633947921170615027831633500490956800000, 
      (CF*NC*(385*(18141941858304*(134264179910338100974537 + 
             31606637619219330245760*lm + 4715706631613517540000*lm^2)*NL + 
           20995*NM*(247126833706891315295587139955759130 + 
             27311539986871209835890519048192*lm + 
             4074878567828103584355975168000*lm^2 - 
             205450687537097593101897758162365575*Zeta[3]) + 
           62985*NH*(628644968615898715908109889980930 + 
             9103846662290403278630173016064*lm + 
             1358292855942701194785325056000*lm^2 - 
             523314217873557631285903286223075*Zeta[3])) - 
         432*CA*(165345969884510191363251805650064655766324762 + 
           3344327747671561488667017089751449600*lm + 
           419343796152915083543171196518400000*lm^2 - 
           137552520884629154294387330721000534468522375*Zeta[3]) + 
         544*CF*(-11398135798056191832396535447527839522667088162 + 
           6487215361863208781001357135760588800*lm + 
           1089845373958912997871557227315200000*lm^2 + 
           9482193199172178371342965026552212342467177875*Zeta[3])))/
       518178597228227486703775511333987942400000, 
      -(CF*NC*(-34*CA*(225630191263792133192016668899832967880005904199726 + 
            2356317232282435566387327244665092466278400*lm + 
            347209996399906210962145794623249842176000*lm^2 - 
            187703411841419666252632835121159379146267435361125*Zeta[3]) + 
          5*(1564*CF*(-91783600551366887911443178437970857440308144084582 + 
              23535264709576701735849903248083129466880*lm + 
              4940537498180483634243971781200393011200*lm^2 + 
              76355453947830229935638491541722861469353924800825*Zeta[3]) + 
            693*(3298534883328*(5011938381342713587684541627 + 
                1035446532972206603342454360*lm + 187795044337095882461174400*
                 lm^2)*NL + 260015*NM*(
                255644686714127550065628513895663188526 + 
                13135613363959231634416913898012672*lm + 
                2382356805038321457440605738106880*lm^2 - 
                212597083119999507054253322140273652325*Zeta[3]) + 
              408595*NH*(8359026686155874676447127026008064*lm + 
                1516045239569840927462203651522560*lm^2 - 7429*
                 (-86444669219297150576269805402414 + 
                  71940097996075690383981283229925*Zeta[3]))))))/
       39472772822457457027146803351377865500262400000, 
      (CF*NC*(-(CA*(484440988193011555528945373248326104444322482587534 + 
            2565688352791491752638162433425600728268800*lm + 
            450233686825822271590976082932486111232000*lm^2 - 
            403010020775949380441805587321297702431225392427125*Zeta[3])) + 
         5*(1071*(549755813888*(692600838557840772669410263 + 
               123067110880966890494296440*lm + 27806478412887000844617600*
                lm^2)*NL + 61180*NM*
              (48040065514349496156948476151077352074 + 
               1105865637548393160707298300002304*lm + 
               249865530749195744640537628508160*lm^2 - 
               39957399846056197549585133193451625775*Zeta[3]) + 
             37145*NH*(161982091906236414099214128681403214 + 
               1821425755962059323517903082356736*lm + 
               411543227116322402937356094013440*lm^2 - 
               134771030314205782223925542903483925*Zeta[3])) + 
           46*CF*(-211779026797120794779410815369550232811918135329606 + 
             23549241989146499982046010823126716252160*lm + 
             6406487243371384101689778255165810278400*lm^2 + 
             176180533695781773935508859947522879872585238374025*Zeta[3]))))/
       1794216946475338955779400152335357522739200000}, 0, 20, 1]
 
CbarSeries["a", 2, 3, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(7*CA*(96552063 + 24057000*lm^2 - 8795304*Pi^2 + 218700*Pi^4 - 
            10800*lm*(-9721 + 165*Pi^2) - 2579424*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 17496000*Im[PolyLog[2, (-1)^(1/3)]]^
              2 + 429904*PolyGamma[2, 1] + 10832528*Zeta[3]) + 
          CF*(-826686000*lm^2 + 57854196*Pi^2 + 567000*Pi^4 + 
            1020600*lm*(-1649 + 60*Pi^2) + 7*(-135929601 + 5158848*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 34992000*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 859808*PolyGamma[2, 1] + 18964544*Zeta[3])) + 
          70*(45*NL*(-31739 - 9720*lm^2 - 540*Pi^2 + 48*lm*(-626 + 
                15*Pi^2) - 8640*Zeta[3]) + 45*NM*(-31739 - 9720*lm^2 - 
              540*Pi^2 + 48*lm*(-626 + 15*Pi^2) + 720*PolyGamma[2, 1] - 
              7200*Zeta[3]) + NH*(-9179019 - 437400*lm^2 + 2160*lm*(-626 + 
                15*Pi^2) - 67222128*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              11203688*PolyGamma[2, 1] + 128731216*Zeta[3]))))/4408992000, 
      -(CF*NC*(2*(CF*(2976069600*lm^2 - 191983338*Pi^2 + 11430720*Pi^4 - 
              73483200*lm*(-20 + 3*Pi^2) - 35*(-103642947 + 218734296*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 55987200*Im[PolyLog[2, 
                    (-1)^(1/3)]]^2 - 38869516*PolyGamma[2, 1] - 293691512*
                 Zeta[3])) - 140*(NH*(255014199 - 787320*lm^2 + 
                4860*lm*(-251 + 12*Pi^2) - 12081552*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]] + 2013592*PolyGamma[2, 1] - 189906256*
                 Zeta[3]) + 27*NL*(60625 - 29160*lm^2 - 1068*Pi^2 + 
                180*lm*(-251 + 12*Pi^2) - 25920*Zeta[3]) + 27*NM*(60625 - 
                29160*lm^2 - 1068*Pi^2 + 180*lm*(-251 + 12*Pi^2) + 
                2160*PolyGamma[2, 1] - 21600*Zeta[3]))) - 
          7*CA*(173210400*lm^2 - 102625542*Pi^2 + 3499200*Pi^4 - 
            97200*lm*(-5029 + 132*Pi^2) - 5*(20672757 + 218734296*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 55987200*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 38869516*PolyGamma[2, 1] - 335619704*Zeta[3]))))/
       8817984000, 
      -(CF*NC*(-70*(NH*(4482794421 - 19683000*lm^2 + 3240*lm*(-8599 + 
                42*Pi^2) + 354155472*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              81433288*PolyGamma[2, 1] - 4396587536*Zeta[3]) + 
            27*NM*(1956395 - 729000*lm^2 - 416052*Pi^2 + 120*lm*(-8599 + 
                42*Pi^2) - 16560*PolyGamma[2, 1] - 93600*Zeta[3]) + 
            27*NL*(1058195 - 729000*lm^2 - 217332*Pi^2 + 120*lm*(-8599 + 
                42*Pi^2) - 60480*Zeta[3])) + 7*CA*(-202561209 - 
            1082565000*lm^2 + 12377043*Pi^2 + 17330760*Pi^4 + 
            16200*lm*(-179639 + 462*Pi^2) + 7089915492*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2246486400*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 1290332314*PolyGamma[2, 1] - 
            10364887748*Zeta[3]) + CF*(37200870000*lm^2 + 1207485306*Pi^2 - 
            257871600*Pi^4 - 3061800*lm*(-4373 + 84*Pi^2) + 
            7*(7012974303 - 14179830984*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              4492972800*Im[PolyLog[2, (-1)^(1/3)]]^2 + 2580664628*PolyGamma[
                2, 1] + 19318781416*Zeta[3]))))/13226976000, 
      -(CF*NC*(14914895525145*CF + 15755312462400*CF*lm + 
          10820989065600*CF*lm^2 - 875866672800*NM + 1006572873600*lm*NM + 
          400777372800*lm^2*NM + 703360778400*NL + 1006572873600*lm*NL + 
          400777372800*lm^2*NL - 61411968505440*NH + 1006572873600*lm*NH + 
          400777372800*lm^2*NH - 834987280464*CF*Pi^2 - 190468454400*CF*lm*
           Pi^2 + 149425637760*NM*Pi^2 - 7054387200*lm*NM*Pi^2 + 
          182933976960*NL*Pi^2 - 7054387200*lm*NL*Pi^2 - 
          7054387200*lm*NH*Pi^2 + 37355444000*Sqrt[3]*CF*Pi^3 + 
          2115220240000*Sqrt[3]*NH*Pi^3 + 17804979360*CF*Pi^4 - 
          14700762888000*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          4319996782080*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          8459973849600*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          1383218726400*Sqrt[3]*CF*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          78323583744000*Sqrt[3]*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          28817056800*Sqrt[3]*CF*Pi*Log[3]^2 + 1631741328000*Sqrt[3]*NH*Pi*
           Log[3]^2 + 26453952000*(-2*CA*(76 + 33*lm) + CF*(597 + 324*lm) + 
            4*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          105815808000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 + 
          2643488658160*CF*PolyGamma[2, 1] + 56435097600*NM*
           PolyGamma[2, 1] + 1797678512000*NH*PolyGamma[2, 1] + 
          21376751012960*CF*Zeta[3] + 38799129600*NM*Zeta[3] + 
          878271206400*NL*Zeta[3] - 4938100025600*NH*Zeta[3] + 
          75600*Log[x]*(4*(243*NM*(16193 + 15360*lm + 3240*lm^2 + 
                1800*Pi^2) + 243*NL*(29153 + 15360*lm + 3240*lm^2 + 
                1800*Pi^2) + NH*(151310001 + 3732480*lm + 787320*lm^2 - 
                86335520*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            4*CA*(-48357660 - 26039880*lm - 4330260*lm^2 + 245187*Pi^2 + 
              762356*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 3149280*Zeta[3]) + 
            CF*(330103203 + 313353360*lm + 85030560*lm^2 - 5942808*Pi^2 - 
              6098848*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 25194240*Zeta[
                3])) - 28*CA*(78724126800*lm^2 - 18544778766*Pi^2 + 
            667061500*Sqrt[3]*Pi^3 + 519499980*Pi^4 - 7873200*lm*
             (-37839 + 176*Pi^2) + 514590300*Sqrt[3]*Pi*Log[3]^2 + 
            5*(48140391753 - 52502724600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              30214192320*Im[PolyLog[2, (-1)^(1/3)]]^2 + 4940066880*Sqrt[
                3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 9441030922*
               PolyGamma[2, 1] + 90581649620*Zeta[3]))))/238085568000, 
      -(CF*NC*(-25*CA*(76 + 33*lm) + 2*(9*CF*(391 + 225*lm) + 
             5*(22*NM + 15*lm*NM + 25*NL + 15*lm*NL + 15*lm*NH)))*
          Log[x]^2)/45 - (10*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/
        9 + (CF*NC*Log[x]*(-4*(243*NL*(137707 + 73404*lm + 16200*lm^2 + 
              9000*Pi^2) + 243*NM*(55325 + 73404*lm + 16200*lm^2 + 
              10128*Pi^2) + NH*(598408179 + 17837172*lm + 3936600*lm^2 - 
              341538880*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
          27*CF*(-61892035 - 54727488*lm - 15746400*lm^2 + 1097640*Pi^2 + 
            3438688*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 4665600*Zeta[3]) - 
          108*CA*(-9331853 - 4654098*lm - 801900*lm^2 + 76077*Pi^2 + 
            429836*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 583200*Zeta[3])))/
        6298560 + (CF*NC*(9*CF*(-5416446672000*lm^2 + 235806791760*Pi^2 - 
            63185892000*Sqrt[3]*Pi^3 + 379118880*Pi^4 + 122472000*lm*
             (-58121 + 408*Pi^2) - 48743402400*Sqrt[3]*Pi*Log[3]^2 + 
            7*(-783165178305 + 1201125080640*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 674281843200*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
              334240473600*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
              221939753392*PolyGamma[2, 1] - 1746134780384*Zeta[3])) + 
          252*CA*(80503749315 + 39405366000*lm^2 - 4871982978*Pi^2 + 
            1128319500*Sqrt[3]*Pi^3 + 46106820*Pi^4 - 648000*lm*
             (-221501 + 561*Pi^2) - 150140635080*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 84285230400*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 41780059200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 870417900*Sqrt[3]*Pi*
             Log[3]^2 + 27742469174*PolyGamma[2, 1] + 250544226508*Zeta[3]) + 
          1120*(-(NH*(-245484313785 + 1612037700*lm^2 + 7471163000*Sqrt[3]*
                Pi^3 - 145800*lm*(-26201 + 102*Pi^2) + 5784765600*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] + 276646492800*Sqrt[3]*
                Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 5763468600*Sqrt[3]*Pi*
                Log[3]^2 + 2991931966*PolyGamma[2, 1] - 31121652868*
                Zeta[3])) + 2430*NL*(-922855 - 663390*lm^2 - 337806*Pi^2 + 
              60*lm*(-26201 + 102*Pi^2) - 1531440*Zeta[3]) + 
            243*NM*(21674345 - 6633900*lm^2 - 2884176*Pi^2 + 
              600*lm*(-26201 + 102*Pi^2) - 1353870*PolyGamma[2, 1] + 
              1301220*Zeta[3]))))/476171136000, 
      -(CF*NC*(-(CA*(20077 + 9900*lm)) + 2*(5*CF*(8263 + 4860*lm) + 
             2*(1035*NM + 450*lm*NM + 675*NL + 450*lm*NL + 8*NH + 450*lm*
                NH)))*Log[x]^2)/60 - 10*CF*NC*(13*CA + 46*CF - 
         2*(2*NM + NL))*Log[x]^3 + 
       (CF*NC*Log[x]*(2*(-16*(14580*NM*(49169 + 30501*lm + 6075*lm^2 + 
                1275*Pi^2) + 32805*NL*(27463 + 13556*lm + 2700*lm^2 + 
                1800*Pi^2) + 2*NH*(8679810099 + 222352290*lm + 
                44286750*lm^2 - 4943564600*Sqrt[3]*Im[PolyLog[2, 
                   (-1)^(1/3)]])) + 5*CF*(-33165220785 - 30344572512*lm - 
              7652750400*lm^2 + 684869256*Pi^2 + 1717519264*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 2267481600*Zeta[3])) - 
          5*CA*(-39603336171 - 19621694016*lm - 3117787200*lm^2 + 
            299140776*Pi^2 + 1717519264*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            2267481600*Zeta[3])))/188956800 - 
       (CF*NC*(-5*CA*(52640719084800*lm^2 - 13083144918192*Pi^2 + 
            2103961098400*Sqrt[3]*Pi^3 + 514820359872*Pi^4 - 
            352719360*lm*(-575759 + 1650*Pi^2) + 1623055704480*Sqrt[3]*Pi*
             Log[3]^2 + 7*(16191263883015 - 26204469398400*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 17435119518720*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 11129524830720*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 5101644473248*PolyGamma[2, 1] + 
              47644062698816*Zeta[3])) + 
          2*(-448*(-2*NH*(-5019704377587 + 26704910250*lm^2 + 216280951250*
                 Sqrt[3]*Pi^3 - 3936600*lm*(-17537 + 75*Pi^2) - 517795179000*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 8008574652000*Sqrt[3]*
                 Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 166845305250*Sqrt[3]*
                 Pi*Log[3]^2 + 192615748955*PolyGamma[2, 1] - 1410645422090*
                 Zeta[3]) + 54675*NL*(-1556653 - 976860*lm^2 - 619320*Pi^2 + 
                144*lm*(-17537 + 75*Pi^2) - 3628800*Zeta[3]) + 
              21870*NM*(11605940 - 2442150*lm^2 - 671250*Pi^2 + 
                360*lm*(-17537 + 75*Pi^2) - 404217*PolyGamma[2, 1] + 
                10369566*Zeta[3])) + CF*(646045188768000*lm^2 - 
              69586130217456*Pi^2 + 10519805492000*Sqrt[3]*Pi^3 + 
              2150838567360*Pi^4 - 11904278400*lm*(-83011 + 600*Pi^2) + 
              8115278522400*Sqrt[3]*Pi*Log[3]^2 + 35*(16672234094541 - 
                26204469398400*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                17435119518720*Im[PolyLog[2, (-1)^(1/3)]]^2 + 11129524830720*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                5101644473248*PolyGamma[2, 1] + 40093394320448*Zeta[3])))))/
        2857026816000, 
      -(CF*NC*(-21163161600*(CA*(802287 + 404250*lm) - 
            5*(20*CF*(31508 + 19845*lm) + 36521*NM + 14700*lm*NM + 
              21945*NL + 14700*lm*NL + 324*NH + 14700*lm*NH))*Log[x]^2 + 
          14814213120000*(475*CA + 1597*CF - 149*NM - 70*NL)*Log[x]^3 - 
          CA*(4213221732720000*lm^2 - 781893104016960*Pi^2 + 
            279728971480000*Sqrt[3]*Pi^3 + 30369599840160*Pi^4 - 
            19399564800*lm*(-814586 + 1575*Pi^2) + 215790920856000*Sqrt[3]*Pi*
             Log[3]^2 + 7*(571195555643565 - 2389479450640320*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 1509918264921600*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 1479709171584000*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 466800242096336*PolyGamma[2, 1] + 
              4251835703027872*Zeta[3])) + 
          56*(CF*(172073639615355 + 369340866180000*lm^2 - 30830880078072*Pi^
                2 + 9990320410000*Sqrt[3]*Pi^3 + 925904853720*Pi^4 - 
              1488034800*lm*(-353059 + 1800*Pi^2) - 597369862660080*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 377479566230400*
               Im[PolyLog[2, (-1)^(1/3)]]^2 + 369927292896000*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 7706818602000*Sqrt[3]*Pi*
               Log[3]^2 + 116700060524084*PolyGamma[2, 1] + 920610597406408*
               Zeta[3]) - 40*(-(NH*(-66964967066601 + 341982283500*lm^2 + 
                 2606099006000*Sqrt[3]*Pi^3 - 787320*lm*(-1076347 + 
                   3150*Pi^2) - 251158669440*Sqrt[3]*Im[PolyLog[2, 
                    (-1)^(1/3)]] + 96500123193600*Sqrt[3]*Im[PolyLog[3, 
                    -((-1)^(5/6)/Sqrt[3])]] + 2010419233200*Sqrt[3]*Pi*
                  Log[3]^2 + 1251147816790*PolyGamma[2, 1] - 22483462030420*
                  Zeta[3])) + 196830*NL*(-1912103 - 1737450*lm^2 - 
                1173110*Pi^2 + 4*lm*(-1076347 + 3150*Pi^2) - 7081200*
                 Zeta[3]) + 19683*NM*(109016365 - 17374500*lm^2 - 
                4534920*Pi^2 + 40*lm*(-1076347 + 3150*Pi^2) - 3474822*
                 PolyGamma[2, 1] + 95563956*Zeta[3]))) + 
          75600*Log[x]*(CA*(-716000345517 - 334211426352*lm - 
              54561276000*lm^2 + 6837926688*Pi^2 + 45670036160*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 39680928000*Zeta[3]) + 
            8*(12239974881*NL + 6017495508*lm*NL + 1240029000*lm^2*NL + 
              209247988659*NH + 6017495508*lm*NH + 1240029000*lm^2*NH + 
              841995000*NL*Pi^2 + 729*NM*(11859311 + 8254452*lm + 
                1701000*lm^2 + 288960*Pi^2) - 119135954560*Sqrt[3]*NH*Im[
                PolyLog[2, (-1)^(1/3)]] + CF*(148444991607 + 127131552216*
                 lm + 33480783000*lm^2 - 2997239760*Pi^2 - 11417509040*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 9920232000*Zeta[3])))))/
       25713241344000, (-1641059091703*CF^2*NC)/2267481600 - 
       (150547*CF^2*lm*NC)/40 - (9693*CF^2*lm^2*NC)/4 + 
       (54310847*CF*NM*NC)/58320 - (126431*CF*lm*NM*NC)/540 - 
       (359*CF*lm^2*NM*NC)/4 - (1348159*CF*NC*NL)/19440 - 
       (126431*CF*lm*NC*NL)/540 - (359*CF*lm^2*NC*NL)/4 + 
       (8110736745695047*CF*NC*NH)/364568526000 - (126431*CF*lm*NC*NH)/
        540 - (359*CF*lm^2*NC*NH)/4 + (3269077621*CF^2*NC*Pi^2)/8748000 + 
       20*CF^2*lm*NC*Pi^2 + (45229*CF*NM*NC*Pi^2)/540 + 
       (20*CF*lm*NM*NC*Pi^2)/27 - (69761*CF*NC*NL*Pi^2)/972 + 
       (20*CF*lm*NC*NL*Pi^2)/27 + (20*CF*lm*NC*NH*Pi^2)/27 - 
       (6137599405*CF^2*NC*Pi^3)/(25509168*Sqrt[3]) - 
       (19464578035*CF*NC*NH*Pi^3)/(6377292*Sqrt[3]) - 
       (137321*CF^2*NC*Pi^4)/10800 + (81645362713*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(7085880*Sqrt[3]) + 
       (20529530803*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2657205*Sqrt[3]) - 
       (120803*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (175359983*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (19683*Sqrt[3]) - (2224523204*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(19683*Sqrt[3]) - 
       (175359983*CF^2*NC*Pi*Log[3]^2)/(944784*Sqrt[3]) - 
       (556130801*CF*NC*NH*Pi*Log[3]^2)/(236196*Sqrt[3]) - 
       (CF*NC*(-455*CA*(72689 + 39600*lm) + 4*(7*CF*(5149193 + 3159000*lm) + 
            2184*(-418 + 375*lm)*NM + 1163750*NL + 819000*lm*NL + 
            34506*NH + 819000*lm*NH))*Log[x]^2)/11340 - 
       (10*CF*NC*(11451*CA + 45796*CF - 8912*NM - 1560*NL)*Log[x]^3)/81 - 
       (3019815883153*CF^2*NC*PolyGamma[2, 1])/3826375200 + 
       (75611*CF*NM*NC*PolyGamma[2, 1])/900 - 
       (108486641051*CF*NC*NH*PolyGamma[2, 1])/119574225 - 
       (CF*NC*Log[x]*(4*(178605*NM*(8302931 + 5346360*lm + 1020600*lm^2 - 
              1772040*Pi^2) + 178605*NL*(11682353 + 5346360*lm + 
              1020600*lm^2 + 808200*Pi^2) + NH*(38342981607981 + 
              954886627800*lm + 182284263000*lm^2 - 21800327399200*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]])) - 245*CF*(-380015231853 - 
            336111631920*lm - 80353879200*lm^2 + 9041285448*Pi^2 + 
            28057597280*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            23808556800*Zeta[3]) + 490*CA*(-113631921939 - 53288704440*lm - 
            8184191400*lm^2 + 1236726630*Pi^2 + 7014399320*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 5952139200*Zeta[3])))/6944162400 - 
       (11758462985197*CF^2*NC*Zeta[3])/1913187600 + 
       (1324133*CF*NM*NC*Zeta[3])/1350 - (4570*CF*NC*NL*Zeta[3])/9 + 
       (901373443598*CF*NC*NH*Zeta[3])/119574225 + 
       (CA*CF*NC*(26443122413400*lm^2 - 8787347027775*Pi^2 + 
          2148159791750*Sqrt[3]*Pi^3 + 372308787018*Pi^4 - 
          49601160*lm*(-2069251 + 4400*Pi^2) + 1657151839350*Sqrt[3]*Pi*
           Log[3]^2 + 7*(2383318991520 - 14696165288340*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] + 10271946739680*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 11363326898400*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3019815883153*
             PolyGamma[2, 1] + 28083190336706*Zeta[3])))/53569252800, 
      -(CF*NC*(-55553299200*(35*CA*(17894489 + 10655436*lm) - 
            2*(28*CF*(48131714 + 32692815*lm) + 84*(63718 + 403615*lm)*NM + 
              15*(7*(458089 + 322892*lm)*NL + 4*(27828 + 565061*lm)*NH)))*
           Log[x]^2 + 15554923776000*(1282475*CA + 4618485*CF - 931916*NM - 
            161446*NL)*Log[x]^3 - 49*CA*(117646114536720000*lm^2 - 
            38330884688427360*Pi^2 + 13314293147288000*Sqrt[3]*Pi^3 + 
            1464844075248960*Pi^4 - 10912255200*lm*(-40861149 + 63800*Pi^2) + 
            10271026142193600*Sqrt[3]*Pi*Log[3]^2 - 
            21*(4047249128240517 + 24732957014697920*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 16221341153203200*Im[PolyLog[2, (-1)^(1/3)]]^
                2 - 23476631182156800*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                   Sqrt[3])]] - 4785239013092192*PolyGamma[2, 1] - 
              46572251048469184*Zeta[3])) + 15120*Log[x]*
           (2*(4*(428652*NM*(269719001 + 129487395*lm + 25515000*lm^2 - 
                  47771850*Pi^2) + 5*(107163*NL*(103589916*lm + 20412000*
                     lm^2 + 341*(671549 + 48360*Pi^2)) + 2*NH*
                   (205990611076077 + 5550503084154*lm + 1093705578000*lm^2 - 
                    117060542665360*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]]))) - 
              49*CF*(-115282381231083 - 96892223917680*lm - 24106163760000*
                 lm^2 + 3012933497040*Pi^2 + 10868810732480*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 7142567040000*Zeta[3])) + 
            49*CA*(-138897144111963 - 62340744504240*lm - 9821029680000*lm^
                2 + 2011283997840*Pi^2 + 10868810732480*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 7142567040000*Zeta[3])) + 
          2*(49*CF*(-59258302627888287 + 288767735681040000*lm^2 - 
              43364029006004256*Pi^2 + 13314293147288000*Sqrt[3]*Pi^3 + 
              1363578346992960*Pi^4 - 26784626400*lm*(-15759699 + 
                63800*Pi^2) - 519392097308656320*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 340648164217267200*Im[PolyLog[2, (-1)^(1/3)]]^
                2 + 493009254825292800*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 10271026142193600*Sqrt[3]*Pi*
               Log[3]^2 + 100490019274936032*PolyGamma[2, 1] + 
              844062317500833984*Zeta[3]) - 
            8*(5*(-4*NH*(3275374779715500*lm^2 - 303807105*lm*(-27139749 + 
                    63800*Pi^2) + 2*(-426456234249638391 + 17924895595633250*
                     Sqrt[3]*Pi^3 - 11740717481749620*Sqrt[3]*Im[PolyLog[2, 
                       (-1)^(1/3)]] + 663733276912591200*Sqrt[3]*
                     Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                    13827776602345650*Sqrt[3]*Pi*Log[3]^2 + 9553121120357304*
                     PolyGamma[2, 1] - 166077604378542192*Zeta[3])) + 
                33756345*NL*(-52074599 - 388119600*lm^2 - 324386520*Pi^2 + 
                  36*lm*(-27139749 + 63800*Pi^2) - 2402231040*Zeta[3])) + 
              81015228*NM*(9985969883 - 808582500*lm^2 + 628107550*Pi^2 + 
                75*lm*(-27139749 + 63800*Pi^2) + 899877900*PolyGamma[2, 1] + 
                10761307800*Zeta[3])))))/7559692955136000, 
      (37285455520757227*CF^2*NC)/11019960576000 - (6922009*CF^2*lm*NC)/480 - 
       (73773*CF^2*lm^2*NC)/8 + (28253173199*CF*NM*NC)/5832000 - 
       (11594299*CF*lm*NM*NC)/12960 - (8197*CF*lm^2*NM*NC)/24 + 
       (10213159*CF*NC*NL)/51840 - (11594299*CF*lm*NC*NL)/12960 - 
       (8197*CF*lm^2*NC*NL)/24 + (104703000298256543*CF*NC*NH)/
        944961619392 - (11594299*CF*lm*NC*NH)/12960 - 
       (8197*CF*lm^2*NC*NH)/24 + (21061397737*CF^2*NC*Pi^2)/8316000 + 
       (245*CF^2*lm*NC*Pi^2)/4 + (16098863*CF*NM*NC*Pi^2)/6480 + 
       (245*CF*lm*NM*NC*Pi^2)/108 - (1278623*CF*NC*NL*Pi^2)/3888 + 
       (245*CF*lm*NC*NL*Pi^2)/108 + (245*CF*lm*NC*NH*Pi^2)/108 - 
       (12226990063351*CF^2*NC*Pi^3)/(8264970432*Sqrt[3]) - 
       (16014819450805*CF*NC*NH*Pi^3)/(1033121304*Sqrt[3]) - 
       (2158933*CF^2*NC*Pi^4)/32400 + (342514816691797*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(6887475360*Sqrt[3]) + 
       (35111680713697*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (860934420*Sqrt[3]) - (58597*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        5 - (1746712866193*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31886460*Sqrt[3]) - (915132540046*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (1746712866193*CF^2*NC*Pi*Log[3]^2)/(1530550080*Sqrt[3]) - 
       (457566270023*CF*NC*NH*Pi*Log[3]^2)/(38263752*Sqrt[3]) - 
       (CF*NC*(161*CF*(28811729 + 19799640*lm) - 
          7*CA*(129321557 + 92764980*lm) + 6*(882*(-311977 + 22310*lm)*NM + 
            5*(1127*(4817 + 3492*lm)*NL + 18*(14899 + 218638*lm)*NH)))*
         Log[x]^2)/68040 - (7*CF*NC*(349861*CA + 1397949*CF - 
          582*(970*NM + 69*NL))*Log[x]^3)/243 - 
       (1940818240681259*CF^2*NC*PolyGamma[2, 1])/619872782400 + 
       (4363697*CF*NM*NC*PolyGamma[2, 1])/1800 - 
       (88538440935443*CF*NC*NH*PolyGamma[2, 1])/19371024450 + 
       (CF*NC*Log[x]*(2*(8*(11573604*NM*(99420682 - 64350315*lm - 
                11907000*lm^2 + 89125050*Pi^2) - 5*(2893401*NL*(121587913 + 
                  51480252*lm + 9525600*lm^2 + 8797320*Pi^2) + 
                2*NH*(3159057525015165 + 74476506308526*lm + 13780690282800*
                   lm^2 - 1793659778490160*Sqrt[3]*Im[PolyLog[2, (-1)^
                      (1/3)]]))) + 49*CF*(-2919467806717569 - 
              2641822036359840*lm - 607475326752000*lm^2 + 107370816175800*Pi^
                2 + 279474058590880*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              179992689408000*Zeta[3])) - 49*CA*(-3523242012811539 - 
            1652524462617120*lm - 247489947936000*lm^2 + 74268919903320*
             Pi^2 + 279474058590880*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            179992689408000*Zeta[3])))/4499817235200 - 
       (8674640842724807*CF^2*NC*Zeta[3])/309936391200 + 
       (17604691*CF*NM*NC*Zeta[3])/2700 - (24682*CF*NC*NL*Zeta[3])/9 + 
       (381305757099307*CF*NC*NH*Zeta[3])/9685512225 + 
       (CA*CF*NC*(-424031525627366493 + 372613794471072000*lm^2 - 
          224967810853833120*Pi^2 + 48907960253404000*Sqrt[3]*Pi^3 + 
          6968695530545280*Pi^4 - 7652750400*lm*(-189506609 + 323400*Pi^2) - 
          1644071120120625600*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          1162325933769369600*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          1810991899668902400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          37728997909768800*Sqrt[3]*Pi*Log[3]^2 + 310530918509001440*
           PolyGamma[2, 1] + 3318525817503513280*Zeta[3]))/198359290368000, 
      (42705880967724735499*CF^2*NC)/3779846477568000 - 
       (92066989*CF^2*lm*NC)/4800 - (207207*CF^2*lm^2*NC)/16 + 
       (434284719181*CF*NM*NC)/62511750 - (157682539*CF*lm*NM*NC)/129600 - 
       (23023*CF*lm^2*NM*NC)/48 + (9172703909*CF*NC*NL)/13996800 - 
       (157682539*CF*lm*NC*NL)/129600 - (23023*CF*lm^2*NC*NL)/48 + 
       (19278021035942020319*CF*NC*NH)/118120202424000 - 
       (157682539*CF*lm*NC*NH)/129600 - (23023*CF*lm^2*NC*NH)/48 + 
       (2046168224659*CF^2*NC*Pi^2)/449064000 + (4655*CF^2*lm*NC*Pi^2)/72 + 
       (63088723*CF*NM*NC*Pi^2)/23328 + (4655*CF*lm*NM*NC*Pi^2)/1944 - 
       (11128013*CF*NC*NL*Pi^2)/23328 + (4655*CF*lm*NC*NL*Pi^2)/1944 + 
       (4655*CF*lm*NC*NH*Pi^2)/1944 - (55092828767347*CF^2*NC*Pi^3)/
        (20662426080*Sqrt[3]) - (43911124448947*CF*NC*NH*Pi^3)/
        (2066242608*Sqrt[3]) - (2148419*CF^2*NC*Pi^4)/24300 + 
       (543788554590337*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6887475360*Sqrt[3]) + (7598540010233*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(344373768*Sqrt[3]) - 
       (780052*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (7870404109621*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (79716150*Sqrt[3]) - (6273017778421*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) - 
       (7870404109621*CF^2*NC*Pi*Log[3]^2)/(3826375200*Sqrt[3]) - 
       (6273017778421*CF*NC*NH*Pi*Log[3]^2)/(382637520*Sqrt[3]) - 
       (CF*NC*(-3*CA*(1504057241 + 1667816150*lm) + 
          CF*(28583466722 + 24562383300*lm) + 15*(-525947516*NM + 
            60647860*lm*NM + 83706875*NL + 60647860*lm*NL + 4631604*NH + 
            60647860*lm*NH))*Log[x]^2)/340200 - 
       (CF*NC*(8728085*CA + 28182709*CF - 26*(435166*NM + 33323*NL))*
         Log[x]^3)/486 - (1116106011243751*CF^2*NC*PolyGamma[2, 1])/
        309936391200 + (362575811*CF*NM*NC*PolyGamma[2, 1])/97200 - 
       (154384242639689*CF*NC*NH*PolyGamma[2, 1])/38742048900 - 
       (6965748610007593*CF^2*NC*Zeta[3])/154968195600 + 
       (560008211*CF*NM*NC*Zeta[3])/48600 - (337997*CF*NC*NL*Zeta[3])/81 + 
       (1270936995906481*CF*NC*NH*Zeta[3])/19371024450 + 
       (CA*CF*NC*(-2226106281907141692903 + 897428868734558160000*lm^2 - 
          718713972880409580480*Pi^2 + 151174722137600168000*Sqrt[3]*Pi^3 + 
          15689995734355084800*Pi^4 - 235802922616800*lm*
           (-14497833 + 19000*Pi^2) - 4476467381387654184000*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 2948476804519873536000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 5597783996866566220800*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 116620499934720129600*
           Sqrt[3]*Pi*Log[3]^2 + 612518978970570548800*PolyGamma[2, 1] + 
          8872863689471923971200*Zeta[3]))/340186182981120000 + 
       (CF*NC*Log[x]*(10*(4*(-393660*NM*(11164820833 + 5500898907*lm + 
                1050197400*lm^2 - 7523828970*Pi^2) - 4822335*NL*(
                1076820205 + 449052972*lm + 85730400*lm^2 + 80560680*Pi^2) - 
              2*NH*(43330265120719497 + 1082741931864810*lm + 
                206710354242000*lm^2 - 24590229691410320*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]])) + CF*(-203324999612432469 - 
              186742296515622960*lm - 44649436516272000*lm^2 + 
              10194256366244496*Pi^2 + 24681587287771456*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 13229462671488000*Zeta[3])) + 
          CA*(1247859703384325391 + 592164248396036400*lm + 
            90952555866480000*lm^2 - 40801771265456880*Pi^2 - 
            123407936438857280*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            66147313357440000*Zeta[3])))/22499086176000, 
      (122204796550421967593*CF^2*NC)/6749725852800000 - 
       (22054031*CF^2*lm*NC)/500 - (281043*CF^2*lm^2*NC)/10 - 
       (339434950607*CF*NM*NC)/22325625 - (9221714*CF*lm*NM*NC)/3375 - 
       (10409*CF*lm^2*NM*NC)/10 + (6161940409*CF*NC*NL)/2430000 - 
       (9221714*CF*lm*NC*NL)/3375 - (10409*CF*lm^2*NC*NL)/10 + 
       (162032074869844322551*CF*NC*NH)/374328546253200 - 
       (9221714*CF*lm*NC*NH)/3375 - (10409*CF*lm^2*NC*NH)/10 + 
       (13687267570183*CF^2*NC*Pi^2)/673596000 + (784*CF^2*lm*NC*Pi^2)/5 + 
       (159769237*CF*NM*NC*Pi^2)/4050 + (784*CF*lm*NM*NC*Pi^2)/135 - 
       (14231959*CF*NC*NL*Pi^2)/12150 + (784*CF*lm*NC*NL*Pi^2)/135 + 
       (784*CF*lm*NC*NH*Pi^2)/135 - (332213799869*CF^2*NC*Pi^3)/
        (51018336*Sqrt[3]) - (7871479499779*CF*NC*NH*Pi^3)/
        (129140163*Sqrt[3]) - (1400497*CF^2*NC*Pi^4)/5400 + 
       (2969315286756661*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (17218688400*Sqrt[3]) + (11899895554018*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) - 
       (1813238*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (47459114267*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (196830*Sqrt[3]) - (17991953142352*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) - 
       (47459114267*CF^2*NC*Pi*Log[3]^2)/(9447840*Sqrt[3]) - 
       (1124497071397*CF*NC*NH*Pi*Log[3]^2)/(23914845*Sqrt[3]) - 
       (CF*NC*(-55*CA*(-60617191 + 1368164160*lm) + 
          8*(11*CF*(3664695781 + 4197776400*lm) + 20*(-4969016151*NM + 
              85510260*lm*NM + 115894207*NL + 85510260*lm*NL + 
              7983510*NH + 85510260*lm*NH)))*Log[x]^2)/1782000 - 
       (4*CF*NC*(95204025*CA + 280774978*CF - 60*(4619875*NM + 129561*NL))*
         Log[x]^3)/6075 - (1662716453399929*CF^2*NC*PolyGamma[2, 1])/
        464904586800 + (989635*CF*NM*NC*PolyGamma[2, 1])/27 - 
       (1033073117546407*CF*NC*NH*PolyGamma[2, 1])/58113073350 - 
       (24101406415363717*CF^2*NC*Zeta[3])/232452293400 + 
       30234*CF*NM*NC*Zeta[3] - (507392*CF*NC*NL*Zeta[3])/45 + 
       (4496904955161353*CF*NC*NH*Zeta[3])/29056536675 + 
       CF*Log[x]*((320146706023*NM*NC)/1701000 - (6588652*lm*NM*NC)/675 - 
         1764*lm^2*NM*NC - (6046552409*NC*NL)/243000 - 
         (6588652*lm*NC*NL)/675 - 1764*lm^2*NC*NL - 
         (71645169882525493*NC*NH)/162046989720 - (6588652*lm*NC*NH)/675 - 
         1764*lm^2*NC*NH + (17994788*NM*NC*Pi^2)/405 - 
         (252128*NC*NL*Pi^2)/135 + (17991953142352*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(23914845*Sqrt[3]) + 
         CF*NC*(-576278412686201/3306744000 - (5331802*lm)/25 - 47628*lm^2 + 
           (892254089*Pi^2)/48600 + (47459114267*Im[PolyLog[2, (-1)^(1/3)]])/
            (590490*Sqrt[3]) - 14112*Zeta[3]) + 
         CA*NC*(1856449669548767/16533720000 + (44572486*lm)/675 + 
           9702*lm^2 - (50408017*Pi^2)/6480 - 
           (47459114267*Im[PolyLog[2, (-1)^(1/3)]])/(1180980*Sqrt[3]) + 
           7056*Zeta[3])) + CA*CF*NC*((114499*lm^2)/20 - 
         (3706977284971*Pi^2)/384912000 + (332213799869*Pi^3)/
          (102036672*Sqrt[3]) + (1450673*Pi^4)/10800 - 
         (lm*(-150621379 + 215600*Pi^2))/6750 + (47459114267*Pi*Log[3]^2)/
          (18895680*Sqrt[3]) + (-528766690665805444719 - 
           1309468041459687501000*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           917914455440952480000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           1830909982390027560000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                Sqrt[3])]] + 81473106216596521000*PolyGamma[2, 1] + 
           2819199533729054462000*Zeta[3])/45560649506400000), 
      (26827220434679619610213*CF^2*NC)/850465457452800000 - 
       (2967233927*CF^2*lm*NC)/54000 - (147315*CF^2*lm^2*NC)/4 - 
       (15891097757417171*CF*NM*NC)/540101520000 - (5066472677*CF*lm*NM*NC)/
        1458000 - (49105*CF*lm^2*NM*NC)/36 + (201214339123*CF*NC*NL)/
        43740000 - (5066472677*CF*lm*NC*NL)/1458000 - 
       (49105*CF*lm^2*NC*NL)/36 + (1676184254333340225001453*CF*NC*NH)/
        2829923809674192000 - (5066472677*CF*lm*NC*NH)/1458000 - 
       (49105*CF*lm^2*NC*NH)/36 + (61300300337231*CF^2*NC*Pi^2)/1347192000 + 
       (7154*CF^2*lm*NC*Pi^2)/45 + (1251685457*CF*NM*NC*Pi^2)/36450 + 
       (7154*CF*lm*NM*NC*Pi^2)/1215 - (57295873*CF*NC*NL*Pi^2)/36450 + 
       (7154*CF*lm*NC*NL*Pi^2)/1215 + (7154*CF*lm*NC*NH*Pi^2)/1215 - 
       (143778544343413*CF^2*NC*Pi^3)/(13774950720*Sqrt[3]) - 
       (30351722171288*CF*NC*NH*Pi^3)/(387420489*Sqrt[3]) - 
       (31800811*CF^2*NC*Pi^4)/97200 + (394431116722787239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1549681956000*Sqrt[3]) + 
       (201484827690904*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1937102445*Sqrt[3]) - (827323*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        15 - (20539792049059*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (53144100*Sqrt[3]) - (69375364962944*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23914845*Sqrt[3]) - 
       (20539792049059*CF^2*NC*Pi*Log[3]^2)/(2550916800*Sqrt[3]) - 
       (4335960310184*CF*NC*NH*Pi*Log[3]^2)/(71744535*Sqrt[3]) - 
       (CF*NC*(-1089*CA*(-23324453053 + 12334464800*lm) + 
          8*(264*CF*(1018936789 + 31221614025*lm) + 
            5*(33*(-63187050037 + 1850169720*lm)*NM + 1386*(59805147 + 
                44051660*lm)*NL + 5*(1243078247 + 12211120152*lm)*NH)))*
         Log[x]^2)/224532000 - (4*CF*NC*(181351206*CA + 
          5*(61673998*CF - 63236010*NM - 2202583*NL))*Log[x]^3)/6075 + 
       (18841551540429847*CF^2*NC*PolyGamma[2, 1])/1549681956000 + 
       (784312273*CF*NM*NC*PolyGamma[2, 1])/16200 - 
       (1172165206680881*CF*NC*NH*PolyGamma[2, 1])/77484097800 - 
       (117211505780774813*CF^2*NC*Zeta[3])/774840978000 + 
       (510099073*CF*NM*NC*Zeta[3])/8100 - (6418282*CF*NC*NL*Zeta[3])/405 + 
       (9206251655882239*CF*NC*NH*Zeta[3])/38742048900 + 
       (CA*CF*NC*(-251657857004572627995 + 95704826910503580000*lm^2 - 
          282458182536975186945*Pi^2 + 22192218319405796550*Sqrt[3]*Pi^3 + 
          2146934621871917640*Pi^4 - 30623756184*lm*(-11939104921 + 
            13490400*Pi^2) - 541159492143664091908*Sqrt[3]*
           Im[PolyLog[2, (-1)^(1/3)]] + 351804816828111427200*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 821746141198568923680*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 17119711274970185910*
           Sqrt[3]*Pi*Log[3]^2 - 77551826140409250252*PolyGamma[2, 1] + 
          1121558412205702364376*Zeta[3]))/12756981861792000 + 
       CF*Log[x]*((2946481800797*NM*NC)/214326000 - (159635279*lm*NM*NC)/
          12150 - 2450*lm^2*NM*NC - (49657254391*NC*NL)/1458000 - 
         (159635279*lm*NC*NL)/12150 - 2450*lm^2*NC*NL - 
         (19346415958809669683*NC*NH)/34029867841200 - (159635279*lm*NC*NH)/
          12150 - 2450*lm^2*NC*NH + (20498092*NM*NC*Pi^2)/405 - 
         (3194833*NC*NL*Pi^2)/1215 + (69375364962944*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(71744535*Sqrt[3]) + 
         CF*NC*(-133395030713717543/1249949232000 - (128214029*lm)/450 - 
           66150*lm^2 + (1304111321*Pi^2)/32400 + 
           (20539792049059*Im[PolyLog[2, (-1)^(1/3)]])/(159432300*Sqrt[3]) - 
           19600*Zeta[3]) + CA*NC*(558517943058014309/6249746160000 + 
           (2172733069*lm)/24300 + 13475*lm^2 - (718473317*Pi^2)/38880 - 
           (20539792049059*Im[PolyLog[2, (-1)^(1/3)]])/(318864600*Sqrt[3]) + 
           9800*Zeta[3])), (-57765207140655744497941*CF^2*NC)/
        425232728726400000 - (345358751*CF^2*lm*NC)/3000 - 
       (731997*CF^2*lm^2*NC)/10 - (173608352940462877*CF*NM*NC)/
        270050760000 - (577157801*CF*lm*NM*NC)/81000 - 
       (27111*CF*lm^2*NM*NC)/10 + (23731155803*CF*NC*NL)/1822500 - 
       (577157801*CF*lm*NC*NL)/81000 - (27111*CF*lm^2*NC*NL)/10 + 
       (628193205715843640215416077*CF*NC*NH)/444095900703871416000 - 
       (577157801*CF*lm*NC*NH)/81000 - (27111*CF*lm^2*NC*NH)/10 + 
       (54418140529351*CF^2*NC*Pi^2)/265356000 + (1764*CF^2*lm*NC*Pi^2)/5 + 
       (6347417341*CF*NM*NC*Pi^2)/12150 + (196*CF*lm*NM*NC*Pi^2)/15 - 
       (4712191*CF*NC*NL*Pi^2)/1350 + (196*CF*lm*NC*NL*Pi^2)/15 + 
       (196*CF*lm*NC*NH*Pi^2)/15 - (472999373472073*CF^2*NC*Pi^3)/
        (20662426080*Sqrt[3]) - (954265249147*CF*NC*NH*Pi^3)/
        (4782969*Sqrt[3]) - (1481207*CF^2*NC*Pi^4)/1800 + 
       (395497503678972989*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (774840978000*Sqrt[3]) + (1085280518050906*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1937102445*Sqrt[3]) - 
       (584318*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (67571339067439*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (79716150*Sqrt[3]) - (2181177712336*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(295245*Sqrt[3]) - 
       (67571339067439*CF^2*NC*Pi*Log[3]^2)/(3826375200*Sqrt[3]) - 
       (136323607021*CF*NC*NH*Pi*Log[3]^2)/(885735*Sqrt[3]) - 
       (CF*NC*(-143*CA*(-2774350761733 + 512579944800*lm) + 
          20*(143*CF*(-164883203377 + 125815077360*lm) + 
            286*(-524640450329 + 2329908840*lm)*NM + 
            14*(858*(74344889 + 55474020*lm)*NL + 5*(1112850131 + 
                9519341832*lm)*NH)))*Log[x]^2)/486486000 - 
       (CF*NC*(1809803567*CA + 1491880518*CF - 240*(32986670*NM + 
            308189*NL))*Log[x]^3)/4050 + (126718113476786537*CF^2*NC*
         PolyGamma[2, 1])/1394713760400 + (1218963283*CF*NM*NC*
         PolyGamma[2, 1])/2700 - (4010362607562499*CF*NC*NH*PolyGamma[2, 1])/
        69735688020 - (242204675200451683*CF^2*NC*Zeta[3])/697356880200 + 
       (148094483*CF*NM*NC*Zeta[3])/1350 - (1716092*CF*NC*NL*Zeta[3])/45 + 
       (17479901507090093*CF*NC*NH*Zeta[3])/34867844010 + 
       CF*Log[x]*((87002184558571*NM*NC)/26790750 - (2236958*lm*NM*NC)/75 - 
         5292*lm^2*NM*NC - (1104710503*NC*NL)/13500 - (2236958*lm*NC*NL)/
          75 - 5292*lm^2*NC*NL - (918078319832822371*NC*NH)/633933825525 - 
         (2236958*lm*NC*NH)/75 - 5292*lm^2*NC*NH + (65619196*NM*NC*Pi^2)/
          135 - (854518*NC*NL*Pi^2)/135 + (2181177712336*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(885735*Sqrt[3]) + 
         CF*NC*(3760774945648256999/9374619240000 - (16362072*lm)/25 - 
           142884*lm^2 + (943033429*Pi^2)/5400 + 
           (67571339067439*Im[PolyLog[2, (-1)^(1/3)]])/(239148450*Sqrt[3]) - 
           42336*Zeta[3]) + CA*NC*(-283178609001324709/2343654810000 + 
           (15081569*lm)/75 + 29106*lm^2 - (2681925637*Pi^2)/32400 - 
           (67571339067439*Im[PolyLog[2, (-1)^(1/3)]])/(478296900*Sqrt[3]) + 
           21168*Zeta[3])) + (CA*CF*NC*(156931495371975721320000*lm^2 - 
          1061390527349078856979350*Pi^2 + 40154099312477957152500*Sqrt[3]*
           Pi^3 + 4440287860704276966000*Pi^4 - 64966111333200*lm*
           (-9423123211 + 11642400*Pi^2) + 30976019469625852660500*Sqrt[3]*Pi*
           Log[3]^2 + 11*(54765336543939730465641 - 81393386257132641136200*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 55906005956389333920000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 + 135168084958367357064000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 43464312922537782191000*
             PolyGamma[2, 1] + 196088218820287366622000*Zeta[3])))/
        10524510035978400000, (-8087416669218369432272709797*CF^2*NC)/
        23771360001263212800000 - (72173346787*CF^2*lm*NC)/529200 - 
       (363987*CF^2*lm^2*NC)/4 - (1756165424207581288691*CF*NM*NC)/
        2156625369360000 - (123004131337*CF*lm*NM*NC)/14288400 - 
       (13481*CF*lm^2*NM*NC)/4 + (8490163751203*CF*NC*NL)/428652000 - 
       (123004131337*CF*lm*NC*NL)/14288400 - (13481*CF*lm^2*NC*NL)/4 + 
       (4867644033865216896530990669*CF*NC*NH)/2664575404223228496000 - 
       (123004131337*CF*lm*NC*NH)/14288400 - (13481*CF*lm^2*NC*NH)/4 + 
       (5196979153380893*CF^2*NC*Pi^2)/9430344000 + 346*CF^2*lm*NC*Pi^2 + 
       (42183852194*CF*NM*NC*Pi^2)/127575 + (346*CF*lm*NM*NC*Pi^2)/27 - 
       (12514384*CF*NC*NL*Pi^2)/2835 + (346*CF*lm*NC*NL*Pi^2)/27 + 
       (346*CF*lm*NC*NH*Pi^2)/27 - (12541632970583167*CF^2*NC*Pi^3)/
        (371923669440*Sqrt[3]) - (283231524695350*CF*NC*NH*Pi^3)/
        (1162261467*Sqrt[3]) - (32179129*CF^2*NC*Pi^4)/32400 + 
       (162211361217998061533*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (227803247532000*Sqrt[3]) + (2210961753697754*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(5811307335*Sqrt[3]) - 
       (2261243*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (12541632970583167*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10044234900*Sqrt[3]) - (129477268432160*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(14348907*Sqrt[3]) - 
       (12541632970583167*CF^2*NC*Pi*Log[3]^2)/(482123275200*Sqrt[3]) - 
       (8092329277010*CF*NC*NH*Pi*Log[3]^2)/(43046721*Sqrt[3]) - 
       (CF*NC*(CA*(56871290566468339 - 4086925606764000*lm) + 
          8*(13*CF*(-937672319351143 + 192914320599000*lm) + 
            175*(65*(-859890965161 + 8165685528*lm)*NM + 
              7*(2574*(39567219 + 29457740*lm)*NL + (9488212337 + 
                  75824222760*lm)*NH))))*Log[x]^2)/20432412000 + 
       (CF*NC*(-87309329873*CA + 14*(2274057277*CF + 9905394840*NM + 
            147288700*NL))*Log[x]^3)/85050 + 
       (14442651793508199637*CF^2*NC*PolyGamma[2, 1])/41841412812000 + 
       (24373185677*CF*NM*NC*PolyGamma[2, 1])/48600 - 
       (100050440218130069*CF*NC*NH*PolyGamma[2, 1])/2092070640600 - 
       (69376764004076926241*CF^2*NC*Zeta[3])/146444944842000 + 
       (10640922077*CF*NM*NC*Zeta[3])/24300 - (4080890*CF*NC*NL*Zeta[3])/
        81 + (756089487652955131*CF*NC*NH*Zeta[3])/1046035320300 + 
       CF*Log[x]*((5050544108953327*NM*NC)/11114334000 - 
         (71531107*lm*NM*NC)/1890 - 6930*lm^2*NM*NC - (71875412621*NC*NL)/
          680400 - (71531107*lm*NC*NL)/1890 - 6930*lm^2*NC*NL - 
         (872297998809710142749*NC*NH)/492946942728240 - 
         (71531107*lm*NC*NH)/1890 - 6930*lm^2*NC*NH + 
         (164045156*NM*NC*Pi^2)/405 - (2034217*NC*NL*Pi^2)/243 + 
         (129477268432160*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (43046721*Sqrt[3]) + CF*NC*(422287700731076991337469/
            142925444933040000 - (57705757*lm)/70 - 187110*lm^2 + 
           (100973788487*Pi^2)/226800 + (12541632970583167*
             Im[PolyLog[2, (-1)^(1/3)]])/(30132704700*Sqrt[3]) - 
           55440*Zeta[3]) + CA*NC*(-27985580492689141530559/
            20417920704720000 + (970209977*lm)/3780 + 38115*lm^2 - 
           (98675613181*Pi^2)/453600 - (12541632970583167*
             Im[PolyLog[2, (-1)^(1/3)]])/(60265409400*Sqrt[3]) + 
           27720*Zeta[3])) + CA*CF*NC*((148291*lm^2)/8 - 
         (3441616942869607*Pi^2)/12573792000 + (12541632970583167*Pi^3)/
          (743847338880*Sqrt[3]) + (32843449*Pi^4)/64800 + 
         lm*(2027222166107/28576800 - (1903*Pi^2)/27) + 
         (12541632970583167*Pi*Log[3]^2)/(964246550400*Sqrt[3]) + 
         (1041812030762116130279036322 - 793444707545746168134054525*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 503932700656279041576660000*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 1391337645965096530142673000*
            Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
           1153870751467993808353741175*PolyGamma[2, 1] + 
           1824879056989536253526201150*Zeta[3])/6685695000355278600000), 
      (-75825637853335861465909569779*CF^2*NC)/21394224001136891520000 - 
       (784772797*CF^2*lm*NC)/2940 - (339039*CF^2*lm^2*NC)/2 - 
       (3228234758732881633*CF*NM*NC)/326761419600 - 
       (327712078*CF*lm*NM*NC)/19845 - (12557*CF*lm^2*NM*NC)/2 + 
       (688808948603*CF*NC*NL)/14288400 - (327712078*CF*lm*NC*NL)/19845 - 
       (12557*CF*lm^2*NC*NL)/2 + (845899991557179115136306323*CF*NC*NH)/
        209835313082579244060 - (327712078*CF*lm*NC*NH)/19845 - 
       (12557*CF*lm^2*NC*NH)/2 + (15745112278042951*CF^2*NC*Pi^2)/
        6810804000 + 720*CF^2*lm*NC*Pi^2 + (111674645849*CF*NM*NC*Pi^2)/
        17010 + (80*CF*lm*NM*NC*Pi^2)/3 - (3440119*CF*NC*NL*Pi^2)/378 + 
       (80*CF*lm*NC*NL*Pi^2)/3 + (80*CF*lm*NC*NH*Pi^2)/3 - 
       (114406557184768601*CF^2*NC*Pi^3)/(1673656512480*Sqrt[3]) - 
       (5946118998685915*CF*NC*NH*Pi^3)/(10460353203*Sqrt[3]) - 
       (12139561*CF^2*NC*Pi^4)/5400 + (1372798603907721128239*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1025114613894000*Sqrt[3]) + 
       (86009218736881802*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (52301766015*Sqrt[3]) - (1491094*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (114406557184768601*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(45199057050*Sqrt[3]) - 
       (2718225827970704*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (129140163*Sqrt[3]) - (114406557184768601*CF^2*NC*Pi*Log[3]^2)/
        (2169554738400*Sqrt[3]) - (169889114248169*CF*NC*NH*Pi*Log[3]^2)/
        (387420489*Sqrt[3]) - 
       (CF*NC*(-351*CA*(-122599251003841 + 4444425832000*lm) + 
          224*(468*CF*(-755389464559 + 73051642125*lm) + 
            25*(286*(-166862242073 + 177094890*lm)*NM + 3003*(22433231 + 
                16866180*lm)*NL + (7017192731 + 50649138540*lm)*NH)))*
         Log[x]^2)/3405402000 + (CF*NC*(-58415783459*CA + 
          48*(1160251812*CF + 175*(37268357*NM + 93701*NL)))*Log[x]^3)/
        14175 + (55597657856857989599*CF^2*NC*PolyGamma[2, 1])/
        37657271530800 + (7065173737*CF*NM*NC*PolyGamma[2, 1])/1350 - 
       (381094996797022121*CF*NC*NH*PolyGamma[2, 1])/2353579470675 - 
       (35340393199823211887*CF^2*NC*Zeta[3])/26360090071560 + 
       (895993*CF*NM*NC*Zeta[3])/75 - (1001968*CF*NC*NL*Zeta[3])/9 + 
       (3313644790542093758*CF*NC*NH*Zeta[3])/2353579470675 + 
       CF*Log[x]*((427192761232663*NM*NC)/9430344 - (8323562*lm*NM*NC)/
          105 - 13860*lm^2*NM*NC - (1763574781*NC*NL)/7560 - 
         (8323562*lm*NC*NL)/105 - 13860*lm^2*NC*NL - 
         (320516494721041288720151*NC*NH)/77639143479697800 - 
         (8323562*lm*NC*NH)/105 - 13860*lm^2*NC*NH + 
         (148970876*NM*NC*Pi^2)/27 - (499544*NC*NL*Pi^2)/27 + 
         (2718225827970704*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (387420489*Sqrt[3]) + CF*NC*(8259122158373755336651939/
            643164502198680000 - (61086708*lm)/35 - 374220*lm^2 + 
           (43248460393*Pi^2)/22680 + (114406557184768601*
             Im[PolyLog[2, (-1)^(1/3)]])/(135597171150*Sqrt[3]) - 
           110880*Zeta[3]) + CA*NC*(-797606365884229598903911/
            128632900439736000 + (55966691*lm)/105 + 76230*lm^2 - 
           (213328509083*Pi^2)/226800 - (114406557184768601*
             Im[PolyLog[2, (-1)^(1/3)]])/(271194342300*Sqrt[3]) + 
           55440*Zeta[3])) + CA*CF*NC*((138127*lm^2)/4 - 
         (8554050106305811*Pi^2)/7429968000 + (114406557184768601*Pi^3)/
          (3347313024960*Sqrt[3]) + (12369961*Pi^4)/10800 + 
         lm*(5349188513/39690 - (440*Pi^2)/3) + 
         (114406557184768601*Pi*Log[3]^2)/(4339109476800*Sqrt[3]) + 
         (16713665720823332276803877139 - 2148781251558183942302864184*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 1435535956923804545585529600*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 4061433475651153018893094080*
            Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
           7107006349622185598368074760*PolyGamma[2, 1] + 
           7281859775237060791951964560*Zeta[3])/9627400800511601184000), 
      (-53697681092132231965594605387227*CF^2*NC)/6836816018981491006464000 - 
       (14702531773*CF^2*lm*NC)/48384 - (3234465*CF^2*lm^2*NC)/16 - 
       (20622993082442233627618069*CF*NM*NC)/2165991285249792000 - 
       (25026944053*CF*lm*NM*NC)/1306368 - (119795*CF*lm^2*NM*NC)/16 + 
       (182341708088341*CF*NC*NL)/2743372800 - (25026944053*CF*lm*NC*NL)/
        1306368 - (119795*CF*lm^2*NC*NL)/16 + 
       (90790269775437194548480103267*CF*NC*NH)/18271374200387852544000 - 
       (25026944053*CF*lm*NC*NH)/1306368 - (119795*CF*lm^2*NC*NH)/16 + 
       (1018539611081476423*CF^2*NC*Pi^2)/140107968000 + 
       (5495*CF^2*lm*NC*Pi^2)/8 + (60665822557*CF*NM*NC*Pi^2)/23328 + 
       (5495*CF*lm*NM*NC*Pi^2)/216 - (889574*CF*NC*NL*Pi^2)/81 + 
       (5495*CF*lm*NC*NL*Pi^2)/216 + (5495*CF*lm*NC*NH*Pi^2)/216 - 
       (632177796637255921*CF^2*NC*Pi^3)/(6694626049920*Sqrt[3]) - 
       (18583470557726165*CF*NC*NH*Pi^3)/(27894275208*Sqrt[3]) - 
       (169381463*CF^2*NC*Pi^4)/64800 + (14644852384955924338033*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8200916911152000*Sqrt[3]) + 
       (163381147865205313*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (139471376040*Sqrt[3]) - (11010901*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/30 - (632177796637255921*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(180796228200*Sqrt[3]) - 
       (1061912603298638*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) - (632177796637255921*CF^2*NC*Pi*Log[3]^2)/
        (8678218953600*Sqrt[3]) - (530956301649319*CF*NC*NH*Pi*Log[3]^2)/
        (1033121304*Sqrt[3]) - 
       (CF*NC*(CA*(3443313905377338311 - 47200930600824000*lm) + 
          2*(11*CF*(-304460924410948789 + 10532439059688000*lm) + 
            4900*(5*(-51391112429407 + 175142599632*lm)*NM + 
              5148*(226820109 + 170107420*lm)*NL + 5*(25639008091 + 
                175142599632*lm)*NH)))*Log[x]^2)/81729648000 + 
       (CF*NC*(-3983623952639*CA + 6119556152756*CF + 
          19600*(205808565*NM + 1215053*NL))*Log[x]^3)/340200 + 
       (1820557727832420535399*CF^2*NC*PolyGamma[2, 1])/376572715308000 + 
       (28202314186*CF*NM*NC*PolyGamma[2, 1])/6075 - 
       (331052561381130289*CF*NC*NH*PolyGamma[2, 1])/2510484768720 - 
       (1542529045251482170201*CF^2*NC*Zeta[3])/659002251789000 + 
       (49954275919*CF*NM*NC*Zeta[3])/12150 - (22673497*CF*NC*NL*Zeta[3])/
        162 + (2423796518514152711*CF*NC*NH*Zeta[3])/1255242384360 + 
       CA*CF*NC*(53098631061854165684172464964437/
          13673632037962982012928000 + (1317745*lm^2)/32 - 
         (339067867144287101*Pi^2)/93405312000 + (632177796637255921*Pi^3)/
          (13389252099840*Sqrt[3]) + (172019063*Pi^4)/129600 + 
         lm*(412230694823/2612736 - (60445*Pi^2)/432) - 
         (14644852384955924338033*Im[PolyLog[2, (-1)^(1/3)]])/
          (16401833822304000*Sqrt[3]) + (11010901*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/60 + (632177796637255921*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(361592456400*Sqrt[3]) + 
         (632177796637255921*Pi*Log[3]^2)/(17356437907200*Sqrt[3]) - 
         (1820557727832420535399*PolyGamma[2, 1])/753145430616000 + 
         (416784380013588318439*Zeta[3])/329501125894500) + 
       CF*Log[x]*((5394080734469315983*NM*NC)/3005315913600 - 
         (207365237*lm*NM*NC)/2160 - 17325*lm^2*NM*NC - 
         (156423664039*NC*NL)/544320 - (207365237*lm*NC*NL)/2160 - 
         17325*lm^2*NC*NL - (8179872153581776541701*NC*NH)/
          1690103803639680 - (207365237*lm*NC*NH)/2160 - 17325*lm^2*NC*NH + 
         (239934331*NM*NC*Pi^2)/81 - (11312021*NC*NL*Pi^2)/486 + 
         (1061912603298638*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (129140163*Sqrt[3]) + CF*NC*(1079530013455703935683934163/
            19762691067559440000 - (167864237*lm)/80 - 467775*lm^2 + 
           (170921304541*Pi^2)/30240 + (632177796637255921*
             Im[PolyLog[2, (-1)^(1/3)]])/(542388684600*Sqrt[3]) - 
           138600*Zeta[3]) + CA*NC*(-854816687142378756540233719/
            31620305708095104000 + (2804925607*lm)/4320 + (190575*lm^2)/2 - 
           (31498342563*Pi^2)/11200 - (632177796637255921*
             Im[PolyLog[2, (-1)^(1/3)]])/(1084777369200*Sqrt[3]) + 
           69300*Zeta[3])), (-14133206585626755430611776153849593*CF^2*NC)/
        282018660782986504016640000 - (53118060797*CF^2*lm*NC)/94080 - 
       (2866347*CF^2*lm^2*NC)/8 - (328268139126379716296321671*CF*NM*NC)/
        2526989832791424000 - (88698981557*CF*lm*NM*NC)/2540160 - 
       (106161*CF*lm^2*NM*NC)/8 + (93978658241501*CF*NC*NL)/640120320 - 
       (88698981557*CF*lm*NC*NL)/2540160 - (106161*CF*lm^2*NC*NL)/8 + 
       (40810452613945886097011232091749913*CF*NC*NH)/
        3958736229790893412096435200 - (88698981557*CF*lm*NC*NH)/2540160 - 
       (106161*CF*lm^2*NC*NH)/8 + (28185388754883631*CF^2*NC*Pi^2)/
        1061424000 + (5445*CF^2*lm*NC*Pi^2)/4 + 
       (11110196524213*CF*NM*NC*Pi^2)/136080 + (605*CF*lm*NM*NC*Pi^2)/12 - 
       (32333851*CF*NC*NL*Pi^2)/1512 + (605*CF*lm*NC*NL*Pi^2)/12 + 
       (605*CF*lm*NC*NH*Pi^2)/12 - (226220347853482127*CF^2*NC*Pi^3)/
        (1255242384360*Sqrt[3]) - (182300225303402185*CF*NC*NH*Pi^3)/
        (125524238436*Sqrt[3]) - (9857507*CF^2*NC*Pi^4)/1800 + 
       (19645599034253405435189*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (6150687683364000*Sqrt[3]) + (3797260244644709851*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(878669669052*Sqrt[3]) - 
       (3442934*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (452440695706964254*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (67798585575*Sqrt[3]) - (20834311463245964*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (226220347853482127*CF^2*NC*Pi*Log[3]^2)/(1627166053800*Sqrt[3]) - 
       (5208577865811491*CF*NC*NH*Pi*Log[3]^2)/(4649045868*Sqrt[3]) - 
       (CF*NC*(CA*(36139149155768362793 - 284944250190600000*lm) + 
          34*CF*(-2088772619703420631 + 41141683182600000*lm) + 
          1400*(17*(-9524686711981589 + 2176808634000*lm)*NM + 
            11231220*(4359203 + 3294900*lm)*NL + 523*(11202723859 + 
              70756686000*lm)*NH))*Log[x]^2)/231567336000 + 
       (CF*NC*(-2518419289111*CA + 4306973170984*CF + 14947843621200*NM + 
          8456910000*NL)*Log[x]^3)/56700 + (901608804253912894643*CF^2*NC*
         PolyGamma[2, 1])/50209695374400 + 
       (40705569584*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (7699376881915883543*CF*NC*NH*PolyGamma[2, 1])/18828635765400 - 
       (1550200633143504375883*CF^2*NC*Zeta[3])/175733933810400 - 
       (2153462269*CF*NM*NC*Zeta[3])/225 - (2607055*CF*NC*NL*Zeta[3])/9 + 
       (33332933886043988257*CF*NC*NH*Zeta[3])/9414317882700 + 
       CA*CF*NC*(14074452418276643238946226710158361/
          564037321565973008033280000 + (1167771*lm^2)/16 - 
         (28161719338224961*Pi^2)/2122848000 + (226220347853482127*Pi^3)/
          (2510484768720*Sqrt[3]) + (10002707*Pi^4)/3600 + 
         lm*(1447604167207/5080320 - (6655*Pi^2)/24) - 
         (19645599034253405435189*Im[PolyLog[2, (-1)^(1/3)]])/
          (12301375366728000*Sqrt[3]) + (1721467*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/5 + (226220347853482127*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (67798585575*Sqrt[3]) + (226220347853482127*Pi*Log[3]^2)/
          (3254332107600*Sqrt[3]) - (901608804253912894643*PolyGamma[2, 1])/
          100419390748800 + (325080668266655035751*Zeta[3])/70293573524160) + 
       CF*Log[x]*((292958794763669439091*NM*NC)/500885985600 - 
         (31770541*lm*NM*NC)/168 - 32670*lm^2*NM*NC - (25182303793*NC*NL)/
          42336 - (31770541*lm*NC*NL)/168 - 32670*lm^2*NC*NL - 
         (227268626729146459864962487*NC*NH)/21540203967007357632 - 
         (31770541*lm*NC*NH)/168 - 32670*lm^2*NC*NH + 
         (1779486416*NM*NC*Pi^2)/27 - (1300805*NC*NL*Pi^2)/27 + 
         (20834311463245964*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(218927143389908230327159538797/
            1304337610458923040000 - (233793549*lm)/56 - 882090*lm^2 + 
           (164697280121*Pi^2)/7560 + (452440695706964254*
             Im[PolyLog[2, (-1)^(1/3)]])/(203395756725*Sqrt[3]) - 
           261360*Zeta[3]) + CA*NC*(-5437643728103663254054063711/
            65216880522946152000 + (426315791*lm)/336 + 179685*lm^2 - 
           (2463060323713*Pi^2)/226800 - (226220347853482127*
             Im[PolyLog[2, (-1)^(1/3)]])/(203395756725*Sqrt[3]) + 
           130680*Zeta[3])), (-527008003585709240510999414542818857*CF^2*NC)/
        4351145052080363204828160000 - (1896717623135*CF^2*lm*NC)/3048192 - 
       (6610065*CF^2*lm^2*NC)/16 - (1332502764072328631713541431*CF*NM*NC)/
        15161938996748544000 - (3225975254375*CF*lm*NM*NC)/82301184 - 
       (2203355*CF*lm^2*NM*NC)/144 + (54536448785646853*CF*NC*NL)/
        288054144000 - (3225975254375*CF*lm*NC*NL)/82301184 - 
       (2203355*CF*lm^2*NC*NL)/144 + (1188251550009291756702506736204974263*
         CF*NC*NH)/97168980185776474660548864000 - 
       (3225975254375*CF*lm*NC*NH)/82301184 - (2203355*CF*lm^2*NC*NH)/144 + 
       (934721934274439861*CF^2*NC*Pi^2)/9552816000 + (91355*CF^2*lm*NC*Pi^2)/
        72 + (36160748429293*CF*NM*NC*Pi^2)/2449440 + 
       (91355*CF*lm*NM*NC*Pi^2)/1944 - (3042682049*CF*NC*NL*Pi^2)/122472 + 
       (91355*CF*lm*NC*NL*Pi^2)/1944 + (91355*CF*lm*NC*NH*Pi^2)/1944 - 
       (64166588287242164423*CF^2*NC*Pi^3)/(271132355021760*Sqrt[3]) - 
       (11149848589306130935*CF*NC*NH*Pi^3)/(6778308875544*Sqrt[3]) - 
       (599786957*CF^2*NC*Pi^4)/97200 + (194729042512893256319837*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(47448162128808000*Sqrt[3]) + 
       (753101688871601626301*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (237240810644040*Sqrt[3]) - (36706439*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - (9166655469606023489*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1046035320300*Sqrt[3]) - 
       (637134205103207482*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (10460353203*Sqrt[3]) - (9166655469606023489*CF^2*NC*Pi*Log[3]^2)/
        (50209695374400*Sqrt[3]) - (318567102551603741*CF*NC*NH*Pi*Log[3]^2)/
        (251048476872*Sqrt[3]) - 
       (CF*NC*(-51*CA*(-23836412993197213403 + 60785451250524000*lm) + 
          14*(17*CF*(-10163330651964634693 + 63943137029772000*lm) + 
            150*(1071*(-163233506687679 + 250609982480*lm)*NM + 
              11*(612612*(52831671 + 39829940*lm)*NL + (4043620763591 + 
                  24400299203280*lm)*NH))))*Log[x]^2)/2084106024000 + 
       (CF*NC*(-154939718423387*CA + 168*(1750375277751*CF + 
            50*(9012344247*NM + 21906467*NL)))*Log[x]^3)/1020600 + 
       (3789146606592732595137623*CF^2*NC*PolyGamma[2, 1])/
        61004779879896000 + (95823626759*CF*NM*NC*PolyGamma[2, 1])/2430 - 
       (997018212741547782241*CF*NC*NH*PolyGamma[2, 1])/3050238993994800 - 
       (859706473786987835654197*CF^2*NC*Zeta[3])/30502389939948000 + 
       (106412491933*CF*NM*NC*Zeta[3])/2430 - (18881863*CF*NC*NL*Zeta[3])/
        54 + (7109736504753399804359*CF*NC*NH*Zeta[3])/1525119496997400 + 
       CA*CF*NC*(3681851951261400226066841028608590961/
          60916030729125084867594240000 + (24236905*lm^2)/288 - 
         (934509228290412311*Pi^2)/19105632000 + (64166588287242164423*Pi^3)/
          (542264710043520*Sqrt[3]) + (202365119*Pi^4)/64800 - 
         (55*lm*(-965743302619 + 773521056*Pi^2))/164602368 - 
         (194729042512893256319837*Im[PolyLog[2, (-1)^(1/3)]])/
          (94896324257616000*Sqrt[3]) + (36706439*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/90 + (9166655469606023489*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(2092070640600*Sqrt[3]) + 
         (9166655469606023489*Pi*Log[3]^2)/(100419390748800*Sqrt[3]) - 
         (3789146606592732595137623*PolyGamma[2, 1])/122009559759792000 + 
         (873489395620780864895257*Zeta[3])/61004779879896000) + 
       CF*Log[x]*((-393134597939789486873*NM*NC)/7012403798400 - 
         (90020645077*lm*NM*NC)/408240 - 39325*lm^2*NM*NC - 
         (40305762018511*NC*NL)/57153600 - (90020645077*lm*NC*NL)/408240 - 
         39325*lm^2*NC*NL - (31600027164354401626488182933*NC*NH)/
          2643570486859993891200 - (90020645077*lm*NC*NH)/408240 - 
         39325*lm^2*NC*NH + 18549781*NM*NC*Pi^2 - (28277117*NC*NL*Pi^2)/
          486 + (637134205103207482*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (31381059609*Sqrt[3]) + CF*NC*(1114523784815513331715343740513/
            1437433284995547840000 - (73074716077*lm)/15120 - 1061775*lm^2 + 
           (2197868653991*Pi^2)/29160 + (9166655469606023489*
             Im[PolyLog[2, (-1)^(1/3)]])/(3138105960900*Sqrt[3]) - 
           314600*Zeta[3]) + CA*NC*(-5451883314250302687406836976267/
            14086846192956368832000 + (1214983627847*lm)/816480 + 
           (432575*lm^2)/2 - (10979536531189*Pi^2)/291600 - 
           (9166655469606023489*Im[PolyLog[2, (-1)^(1/3)]])/
            (6276211921800*Sqrt[3]) + 157300*Zeta[3])), 
      (-9430908435302745492225712175063529257*CF^2*NC)/
        15229007682281271216898560000 - (14680011739*CF^2*lm*NC)/13230 - 
       (2815263*CF^2*lm^2*NC)/4 - (49829550469054682933699441*CF*NM*NC)/
        30083212295136000 - (98035194751*CF*lm*NM*NC)/1428840 - 
       (104269*CF*lm^2*NM*NC)/4 + (28083354193442999*CF*NC*NL)/
        72013536000 - (98035194751*CF*lm*NC*NL)/1428840 - 
       (104269*CF*lm^2*NC*NL)/4 + (22125826997219043730942788919913437762493*
         CF*NC*NH)/916412798254581154582968904992000 - 
       (98035194751*CF*lm*NC*NH)/1428840 - (104269*CF*lm^2*NC*NH)/4 + 
       (1259239432294568171*CF^2*NC*Pi^2)/4191264000 + 2420*CF^2*lm*NC*Pi^2 + 
       (17206382741173*CF*NM*NC*Pi^2)/17010 + (2420*CF*lm*NM*NC*Pi^2)/27 - 
       (314541007*CF*NC*NL*Pi^2)/6804 + (2420*CF*lm*NC*NL*Pi^2)/27 + 
       (2420*CF*lm*NC*NH*Pi^2)/27 - (116748698650659161887*CF^2*NC*Pi^3)/
        (271132355021760*Sqrt[3]) - (11515180488661469305*CF*NC*NH*Pi^3)/
        (3389154437772*Sqrt[3]) - (131578447*CF^2*NC*Pi^4)/10800 + 
       (2341618041099352336853281*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (332137134901656000*Sqrt[3]) + (307925418579943178852*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(29655101330505*Sqrt[3]) - 
       (66018821*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (116748698650659161887*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7322247242100*Sqrt[3]) - (1316020627275596492*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(10460353203*Sqrt[3]) - 
       (116748698650659161887*CF^2*NC*Pi*Log[3]^2)/(351467867620800*
         Sqrt[3]) - (329005156818899123*CF*NC*NH*Pi*Log[3]^2)/
        (125524238436*Sqrt[3]) + CF*((1491298741197747857*CF*NC)/416988000 - 
         14699388*CF*lm*NC + CA*(-24448328732809909189/13621608000 + 
           (26948878*lm)/9)*NC + (4920247513353217*NM*NC)/405405 - 
         (4899796*lm*NM*NC)/9 - (290585218*NC*NL)/405 - 
         (4899796*lm*NC*NL)/9 - (37724280908557*NC*NH)/392837445 - 
         (4899796*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-63544630314686*CA + 122691875253379*CF + 
          37800*(10899218344*NM + 1224949*NL))*Log[x]^3)/127575 + 
       (1241233203972455480926783*CF^2*NC*PolyGamma[2, 1])/6100477987989600 + 
       (473188580779*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (721352336540187717821*CF*NC*NH*PolyGamma[2, 1])/762559748498700 - 
       (78305289541447811560901*CF^2*NC*Zeta[3])/854066918318544 - 
       (140784789892*CF*NM*NC*Zeta[3])/675 - (2061202*CF*NC*NL*Zeta[3])/3 + 
       (3107904610619027249179*CF*NC*NH*Zeta[3])/381279874249350 + 
       CA*CF*NC*(168263635790060128899257861985173203/
          543893131510045400603520000 + (1146959*lm^2)/8 - 
         (13391531200475749577*Pi^2)/89159616000 + 
         (116748698650659161887*Pi^3)/(542264710043520*Sqrt[3]) + 
         (44375749*Pi^4)/7200 + lm*(1599830155121/2857680 - 
           (13310*Pi^2)/27) - (2341618041099352336853281*
           Im[PolyLog[2, (-1)^(1/3)]])/(664274269803312000*Sqrt[3]) + 
         (66018821*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 + 
         (116748698650659161887*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (14644494484200*Sqrt[3]) + (116748698650659161887*Pi*Log[3]^2)/
          (702935735241600*Sqrt[3]) - (1241233203972455480926783*
           PolyGamma[2, 1])/12200955975979200 + 
         (1978565223225662858795033*Zeta[3])/42703345915927200) + 
       CF*Log[x]*((852605389423499378743*NM*NC)/116873396640 - 
         (1173252146*lm*NM*NC)/2835 - 70785*lm^2*NM*NC - 
         (39624939857791*NC*NL)/28576800 - (1173252146*lm*NC*NL)/2835 - 
         70785*lm^2*NC*NL - (2591768331375810591522297266561*NC*NH)/
          104976184033210357419552 - (1173252146*lm*NC*NH)/2835 - 
         70785*lm^2*NC*NH + (21798927079*NM*NC*Pi^2)/27 - 
         (3086963*NC*NL*Pi^2)/27 + (1316020627275596492*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(31381059609*Sqrt[3]) + 
         CF*NC*(66664048292507707823443928809969/35217115482390922080000 - 
           (1922856067*lm)/210 - 1911195*lm^2 + (101243621152171*Pi^2)/
            408240 + (116748698650659161887*Im[PolyLog[2, (-1)^(1/3)]])/
            (21966741726300*Sqrt[3]) - 566280*Zeta[3]) + 
         CA*NC*(-2663076359375295711933071509357/2817369238591273766400 + 
           (7857615128*lm)/2835 + (778635*lm^2)/2 - (505908197676719*Pi^2)/
            4082400 - (116748698650659161887*Im[PolyLog[2, (-1)^(1/3)]])/
            (43933483452600*Sqrt[3]) + 283140*Zeta[3])), 
      (-435201380798697174484154769309810583514509*CF^2*NC)/
        249400382476826284962075417600000 - (3239873082707*CF^2*lm*NC)/
        2721600 - (6314121*CF^2*lm^2*NC)/8 - (36653424272743318013479377631*
         CF*NM*NC)/53745026184001152000 - (5507273933807*CF*lm*NM*NC)/
        73483200 - (701569*CF*lm^2*NM*NC)/24 + (24304056839813*CF*NC*NL)/
        50803200 - (5507273933807*CF*lm*NC*NL)/73483200 - 
       (701569*CF*lm^2*NC*NL)/24 + 
       (72618371585103868190585872345274281003567*CF*NC*NH)/
        2618322280727374727379911157120000 - (5507273933807*CF*lm*NC*NH)/
        73483200 - (701569*CF*lm^2*NC*NH)/24 + 
       (350154131660042965453*CF^2*NC*Pi^2)/267478848000 + 
       (39809*CF^2*lm*NC*Pi^2)/18 - (101603057999*CF*NM*NC*Pi^2)/21870 + 
       (39809*CF*lm*NM*NC*Pi^2)/486 - (569096891*CF*NC*NL*Pi^2)/10935 + 
       (39809*CF*lm*NC*NL*Pi^2)/486 + (39809*CF*lm*NC*NH*Pi^2)/486 - 
       (19618754022104884091*CF^2*NC*Pi^3)/(36150980669568*Sqrt[3]) - 
       (12673165356885178201*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) - 
       (2598517229*CF^2*NC*Pi^4)/194400 + (388859919443358789848701*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(44284951320220800*Sqrt[3]) + 
       (6597021712658161528*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (847288609443*Sqrt[3]) - (151528663*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - (19618754022104884091*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(976299632280*Sqrt[3]) - 
       (7241808775362958972*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (52301766015*Sqrt[3]) - (19618754022104884091*CF^2*NC*Pi*Log[3]^2)/
        (46862382349440*Sqrt[3]) - (1810452193840739743*CF*NC*NH*Pi*
         Log[3]^2)/(627621192180*Sqrt[3]) - 
       (CF*NC*(CA*(88764297349404842672911 - 39549184726667616000*lm) + 
          2*(19*CF*(-4667610277217017813343 + 5109224821148448000*lm) + 
            840*(5225*(74793337465547 + 819179865504*lm)*NM + 
              9*(10161580*(61838961 + 46801720*lm)*NL + (87183781844787 + 
                  475579421917600*lm)*NH))))*Log[x]^2)/11313718416000 + 
       (CF*NC*(-516258564751651*CA + 1022318137885333*CF + 
          323400*(184555407*NM + 334298*NL))*Log[x]^3)/255150 + 
       (144998792807073452311405171*CF^2*NC*PolyGamma[2, 1])/
        183014339639688000 + (28992571833407*CF*NM*NC*PolyGamma[2, 1])/
        97200 - (6805577842986064675481*CF*NC*NH*PolyGamma[2, 1])/
        9150716981984400 - (281771966830544244687751793*CF^2*NC*Zeta[3])/
        640550188738908000 + (23544061874207*CF*NM*NC*Zeta[3])/48600 - 
       (21646625*CF*NC*NL*Zeta[3])/27 + (47462677986177591863239*CF*NC*NH*
         Zeta[3])/4575358490992200 + CA*CF*NC*
        (27191096581977649386037904543273114644669/
          31175047809603285620259427200000 + (7717259*lm^2)/48 - 
         (26933950799312923861*Pi^2)/41150592000 + 
         (19618754022104884091*Pi^3)/(72301961339136*Sqrt[3]) + 
         (2623994989*Pi^4)/388800 + lm*(90652908770677/146966400 - 
           (437899*Pi^2)/972) - (388859919443358789848701*
           Im[PolyLog[2, (-1)^(1/3)]])/(88569902640441600*Sqrt[3]) + 
         (151528663*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 + 
         (19618754022104884091*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1952599264560*Sqrt[3]) + (19618754022104884091*Pi*Log[3]^2)/
          (93724764698880*Sqrt[3]) - (144998792807073452311405171*
           PolyGamma[2, 1])/366028679279376000 + 
         (282413129371780401012196853*Zeta[3])/1281100377477816000) + 
       CF*Log[x]*((-13233987759851319908687*NM*NC)/7895784536640 - 
         (3409225853*lm*NM*NC)/7290 - (165165*lm^2*NM*NC)/2 - 
         (481498153999*NC*NL)/302400 - (3409225853*lm*NC*NL)/7290 - 
         (165165*lm^2*NC*NL)/2 - (101895451423640938088499280246073*NC*NH)/
          3749149429757512764984000 - (3409225853*lm*NC*NH)/7290 - 
         (165165*lm^2*NC*NH)/2 + (4739900627*NM*NC*Pi^2)/81 - 
         (64860257*NC*NL*Pi^2)/486 + (7241808775362958972*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(156905298045*Sqrt[3]) + 
         CF*NC*(70099364352995453786999057344209097/
            6785164249607317654080000 - (5547507031*lm)/540 - 
           (4459455*lm^2)/2 + (4124867887187917*Pi^2)/4082400 + 
           (19618754022104884091*Im[PolyLog[2, (-1)^(1/3)]])/
            (2928898896840*Sqrt[3]) - 660660*Zeta[3]) + 
         CA*NC*(-70079823917776994047740747318422701/
            13570328499214635308160000 + (45929854333*lm)/14580 + 
           (1816815*lm^2)/4 - (4124248039092589*Pi^2)/8164800 - 
           (19618754022104884091*Im[PolyLog[2, (-1)^(1/3)]])/
            (5857797793680*Sqrt[3]) + 330330*Zeta[3])), 
      (-146536755805717490657840570757423423707585273*CF^2*NC)/
        20201430980622929081928108825600000 - (2173131482849*CF^2*lm*NC)/
        1058400 - (26039871*CF^2*lm^2*NC)/20 - 
       (216833280111530215334337313061263*CF*NM*NC)/
        10345917540420221760000 - (3627718676909*CF*lm*NM*NC)/28576800 - 
       (2893319*CF*lm^2*NM*NC)/60 + (168160004027792789*CF*NC*NL)/
        180033840000 - (3627718676909*CF*lm*NC*NL)/28576800 - 
       (2893319*CF*lm^2*NC*NL)/60 + 
       (13008989579569166453041779708408276467733103*CF*NC*NH)/
        247431455528736911737401604347840000 - (3627718676909*CF*lm*NC*NH)/
        28576800 - (2893319*CF*lm^2*NC*NH)/60 + 
       (51288430186099387663*CF^2*NC*Pi^2)/15466464000 + 
       (20449*CF^2*lm*NC*Pi^2)/5 + (1058817516250853*CF*NM*NC*Pi^2)/85050 + 
       (20449*CF*lm*NM*NC*Pi^2)/135 - (15874987843*CF*NC*NL*Pi^2)/170100 + 
       (20449*CF*lm*NC*NL*Pi^2)/135 + (20449*CF*lm*NC*NH*Pi^2)/135 - 
       (6953057325907136298899*CF^2*NC*Pi^3)/(7320573585587520*Sqrt[3]) - 
       (676339047335173767419*CF*NC*NH*Pi^3)/(91507169819844*Sqrt[3]) - 
       (163146841*CF^2*NC*Pi^4)/6480 + (130851458374770145960368347*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(8967702642344712000*Sqrt[3]) + 
       (18547168999501563412528*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (800687735923635*Sqrt[3]) - (43885127*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - (6953057325907136298899*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(197700675536700*Sqrt[3]) - 
       (386479455620099295668*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1412147682405*Sqrt[3]) - 
       (6953057325907136298899*CF^2*NC*Pi*Log[3]^2)/(9489632425761600*
         Sqrt[3]) - (96619863905024823917*CF*NC*NH*Pi*Log[3]^2)/
        (16945772188860*Sqrt[3]) - 
       (CF*NC*(-57*CA*(-920674463654463408871 + 311295919354580160*lm) + 
          38*CF*(-2759946887631687621379 + 2292269951610999360*lm) + 
          336*(57*(-20591306275066379299 + 168450172810920*lm)*NM + 
            1109644536*(11370653 + 8652915*lm)*NL + 
            (1852137232545617 + 9601659850222440*lm)*NH))*Log[x]^2)/
        2639867630400 + (CF*NC*(-470730257451125*CA + 934277309791212*CF + 
          3378887937059040*NM + 69292543320*NL)*Log[x]^3)/85050 + 
       (368335183589172068626969339*CF^2*NC*PolyGamma[2, 1])/
        164712905675719200 + (8873430200791*CF*NM*NC*PolyGamma[2, 1])/1080 - 
       (83823862150252239387619*CF*NC*NH*PolyGamma[2, 1])/
        41178226418929800 - (612830781012535716528805121*CF^2*NC*Zeta[3])/
        576495169865017200 - (1848134571713*CF*NM*NC*Zeta[3])/540 - 
       (7550972*CF*NC*NL*Zeta[3])/5 + (359357522386772043613661*CF*NC*NH*
         Zeta[3])/20589113209464900 + CA*CF*NC*
        (146511491110100065581599467875047791799366927/
          40402861961245858163856217651200000 + (31826509*lm^2)/120 - 
         (541490281525233851*Pi^2)/326592000 + (6953057325907136298899*Pi^3)/
          (14641147171175040*Sqrt[3]) + (823586621*Pi^4)/64800 + 
         lm*(59197325072479/57153600 - (224939*Pi^2)/270) - 
         (130851458374770145960368347*Im[PolyLog[2, (-1)^(1/3)]])/
          (17935405284689424000*Sqrt[3]) + 
         (43885127*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (6953057325907136298899*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (395401351073400*Sqrt[3]) + (6953057325907136298899*Pi*Log[3]^2)/
          (18979264851523200*Sqrt[3]) - (368335183589172068626969339*
           PolyGamma[2, 1])/329425811351438400 + 
         (122807952907726205888502361*Zeta[3])/230598067946006880) + 
       CF*Log[x]*((37639018736860123243636727*NM*NC)/422205145362000 - 
         (23926309121*lm*NM*NC)/28350 - 143143*lm^2*NM*NC - 
         (214510492164259*NC*NL)/71442000 - (23926309121*lm*NC*NL)/28350 - 
         143143*lm^2*NC*NL - (1189427536288103665011930159509747*NC*NH)/
          22143413819505309768186750 - (23926309121*lm*NC*NH)/28350 - 
         143143*lm^2*NC*NH + (1340839271309*NM*NC*Pi^2)/135 - 
         (33938476*NC*NL*Pi^2)/135 + (386479455620099295668*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) + 
         CF*NC*(2774696371667443426069351449749881981/
            137399576054548182495120000 - (9821377423*lm)/525 - 
           3864861*lm^2 + (1881298637932619*Pi^2)/680400 + 
           (6953057325907136298899*Im[PolyLog[2, (-1)^(1/3)]])/
            (593102026610100*Sqrt[3]) - 1145144*Zeta[3]) + 
         CA*NC*(-2773977398940550880774949818186882431/
            274799152109096364990240000 + (320002857031*lm)/56700 + 
           (1574573*lm^2)/2 - (1881075003616483*Pi^2)/1360800 - 
           (6953057325907136298899*Im[PolyLog[2, (-1)^(1/3)]])/
            (1186204053220200*Sqrt[3]) + 572572*Zeta[3])), 
      (-565696844470856209556600209355039216737015773761*CF^2*NC)/
        23093602516015445095490816405798400000 - 
       (4964020648345877*CF^2*lm*NC)/2305195200 - (11410425*CF^2*lm^2*NC)/8 - 
       (41662178902574266470789995939793997*CF*NM*NC)/
        10917330524575738623360000 - (8434589272368377*CF*lm*NM*NC)/
        62240270400 - (1267825*CF*lm^2*NM*NC)/24 + 
       (10665716724911813281*CF*NC*NL)/9681819840000 - 
       (8434589272368377*CF*lm*NC*NL)/62240270400 - (1267825*CF*lm^2*NC*NL)/
        24 + (29082863439360889293471688240991829097002239*CF*NC*NH)/
        494862911057473823474803208695680000 - 
       (8434589272368377*CF*lm*NC*NH)/62240270400 - (1267825*CF*lm^2*NC*NH)/
        24 + (729856411287342309913973*CF^2*NC*Pi^2)/42323383872000 + 
       (330733*CF^2*lm*NC*Pi^2)/90 - (8462572813651441*CF*NM*NC*Pi^2)/
        4209975 + (330733*CF*lm*NM*NC*Pi^2)/2430 - 
       (1723072029263*CF*NC*NL*Pi^2)/16839900 + (330733*CF*lm*NC*NL*Pi^2)/
        2430 + (330733*CF*lm*NC*NH*Pi^2)/2430 - 
       (12422485513389797769287*CF^2*NC*Pi^3)/(10736841258861696*Sqrt[3]) - 
       (363174592259219773543*CF*NC*NH*Pi^3)/(45753584909922*Sqrt[3]) - 
       (5248947509*CF^2*NC*Pi^4)/194400 + (1828792536737619309836456621*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(103342097116543824000*Sqrt[3]) + 
       (14107644660969632704912*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (800687735923635*Sqrt[3]) - (294199087*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - (1774640787627113967041*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(41422998683880*Sqrt[3]) - 
       (415056676867679741192*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1412147682405*Sqrt[3]) - 
       (1774640787627113967041*CF^2*NC*Pi*Log[3]^2)/(1988303936826240*
         Sqrt[3]) - (51882084608459967649*CF*NC*NH*Pi*Log[3]^2)/
        (8472886094430*Sqrt[3]) - 
       (CF*NC*(CA*(90120630937935464079712775 - 6638099831136428054400*lm) + 
          2*(CF*(-90107203602512536605919549 + 16293517767334868860800*lm) + 
            9240*(13*(87486623512723016761 + 5023839668767920*lm)*NM + 
              9*(184940756*(51691683 + 39237740*lm)*NL + (1446871840867077 + 
                  7256657299331440*lm)*NH))))*Log[x]^2)/871156318032000 + 
       (CF*NC*(-15034822640503108*CA + 30016380749478541*CF - 
          2205465000082344*NM + 518456106168*NL)*Log[x]^3)/561330 + 
       (1109952930249457693844063561*CF^2*NC*PolyGamma[2, 1])/
        109808603783812800 + (170667882193841*CF*NM*NC*PolyGamma[2, 1])/
        97200 - (129879387656321554090223*CF*NC*NH*PolyGamma[2, 1])/
        82356452837859600 - (27775711533046096921927182881*CF^2*NC*Zeta[3])/
        4227631245676792800 + (266667220547201*CF*NM*NC*Zeta[3])/48600 - 
       (231172591*CF*NC*NL*Zeta[3])/135 + (888721024398336954524017*CF*NC*
         NH*Zeta[3])/41178226418929800 + 
       CA*CF*NC*(12444672734960300166036361648553055197330421408611/
          1016118510704679584201595921855129600000 + (13946075*lm^2)/48 - 
         (42932492172492742821193*Pi^2)/4979221632000 + 
         (12422485513389797769287*Pi^3)/(21473682517723392*Sqrt[3]) + 
         (5291281333*Pi^4)/388800 + lm*(12619198330998377/11316412800 - 
           (3638063*Pi^2)/4860) - (1828792536737619309836456621*
           Im[PolyLog[2, (-1)^(1/3)]])/(206684194233087648000*Sqrt[3]) + 
         (294199087*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 + 
         (1774640787627113967041*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (82845997367760*Sqrt[3]) + (1774640787627113967041*Pi*Log[3]^2)/
          (3976607873652480*Sqrt[3]) - (1109952930249457693844063561*
           PolyGamma[2, 1])/219617207567625600 + 
         (27784507239684413218272857909*Zeta[3])/8455262491353585600) + 
       CF*Log[x]*((-1885679370634403603540745427*NM*NC)/60296462298072000 - 
         (1303478577193*lm*NM*NC)/1403325 - (325325*lm^2*NM*NC)/2 - 
         (3516229366173173*NC*NL)/1047816000 - (1303478577193*lm*NC*NL)/
          1403325 - (325325*lm^2*NC*NL)/2 - 
         (40884409435056930018332351477590651*NC*NH)/
          708589242224169912581976000 - (1303478577193*lm*NC*NH)/1403325 - 
         (325325*lm^2*NC*NH)/2 - (397761121082*NM*NC*Pi^2)/405 - 
         (692856307*NC*NL*Pi^2)/2430 + (415056676867679741192*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4236443047215*Sqrt[3]) + 
         CF*NC*(97225224171889980536383264666710977373883/
            727484955350147776917495360000 - (4250114596897*lm)/207900 - 
           (8783775*lm^2)/2 + (601266685329473411*Pi^2)/44906400 + 
           (1774640787627113967041*Im[PolyLog[2, (-1)^(1/3)]])/
            (124268996051640*Sqrt[3]) - 1301300*Zeta[3]) + 
         CA*NC*(-97220937110317989661033677806900151076351/
            1454969910700295553834990720000 + (797000967659*lm)/127575 + 
           (3578575*lm^2)/4 - (601252304266665299*Pi^2)/89812800 - 
           (1774640787627113967041*Im[PolyLog[2, (-1)^(1/3)]])/
            (248537992103280*Sqrt[3]) + 650650*Zeta[3])), 
      (-187355220724879348482765436391620469341261798103*CF^2*NC)/
        2283982666419109954499091732441600000 - (295098215851*CF^2*lm*NC)/
        81675 - (45815679*CF^2*lm^2*NC)/20 - 
       (190429258994407017806421001212194219*CF*NM*NC)/
        724108657242268378080000 - (3940739417123*CF*lm*NM*NC)/17641800 - 
       (1696877*CF*lm^2*NM*NC)/20 + (12828324763691987479*CF*NC*NL)/
        6224027040000 - (3940739417123*CF*lm*NC*NL)/17641800 - 
       (1696877*CF*lm^2*NC*NL)/20 + 
       (486280403854630671953522835901297256094540636929*CF*NC*NH)/
        4515747779127213007663447980150253920000 - 
       (3940739417123*CF*lm*NC*NH)/17641800 - (1696877*CF*lm^2*NC*NH)/20 + 
       (1025056568500085915777*CF^2*NC*Pi^2)/28791417600 + 
       (33124*CF^2*lm*NC*Pi^2)/5 + (20276411570696789*CF*NM*NC*Pi^2)/
        133650 + (33124*CF*lm*NM*NC*Pi^2)/135 - (47563769669*CF*NC*NL*Pi^2)/
        267300 + (33124*CF*lm*NC*NL*Pi^2)/135 + (33124*CF*lm*NC*NH*Pi^2)/
        135 - (94734795710665002586141*CF^2*NC*Pi^3)/(48315785664877632*
         Sqrt[3]) - (4152079439829572151397*CF*NC*NH*Pi^3)/
        (274521509459532*Sqrt[3]) - (528589243*CF^2*NC*Pi^4)/10800 + 
       (13299839723765310802994896579*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (465039437024447208000*Sqrt[3]) + (116600489571245881363436*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(2402063207770905*Sqrt[3]) - 
       (49680085*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/9 - 
       (13533542244380714655163*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(186403494077460*Sqrt[3]) - 
       (2372616822759755515084*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4236443047215*Sqrt[3]) - 
       (13533542244380714655163*CF^2*NC*Pi*Log[3]^2)/(8947367715718080*
         Sqrt[3]) - (593154205689938878771*CF*NC*NH*Pi*Log[3]^2)/
        (50837316566580*Sqrt[3]) - 
       (CF*NC*(-8073*CA*(-4207078480740909272769 + 277892731109593600*lm) + 
          10*(299*CF*(-22714879129104743974417 + 3683341835979886080*lm) + 
            704*(966*(-42570127057778779933 + 59979061282140*lm)*NM + 
              44663192574*(1700917 + 1297260*lm)*NL + (12052467930482627 + 
                57939773198547240*lm)*NH)))*Log[x]^2)/159020597736000 + 
       (CF*NC*(-12042239888195917*CA + 77*(312285100376359*CF + 
            1080*(1170979118603*NM + 4122404*NL)))*Log[x]^3)/200475 + 
       (11863064666333576065352804323*CF^2*NC*PolyGamma[2, 1])/
        494138717027157600 + (28994852355859*CF*NM*NC*PolyGamma[2, 1])/300 - 
       (12731821194879049491046*CF*NC*NH*PolyGamma[2, 1])/3088366981419735 - 
       (32760600565191503235317964373*CF^2*NC*Zeta[3])/2717762943649366800 - 
       (22297816103443*CF*NM*NC*Zeta[3])/450 - (46718126*CF*NC*NL*Zeta[3])/
        15 + (21726364331184024123248*CF*NC*NH*Zeta[3])/617673396283947 + 
       CA*CF*NC*(128802457287958705785043979684226620998533232951/
          3140476166326276187436251132107200000 + (18665647*lm^2)/40 - 
         (35876782957574031156199*Pi^2)/2015399232000 + 
         (94734795710665002586141*Pi^3)/(96631571329755264*Sqrt[3]) + 
         (11840647*Pi^4)/480 + lm*(5845755349943/3207600 - 
           (182182*Pi^2)/135) - (13299839723765310802994896579*
           Im[PolyLog[2, (-1)^(1/3)]])/(930078874048894416000*Sqrt[3]) + 
         (49680085*Im[PolyLog[2, (-1)^(1/3)]]^2)/18 + 
         (13533542244380714655163*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (372806988154920*Sqrt[3]) + (13533542244380714655163*Pi*Log[3]^2)/
          (17894735431436160*Sqrt[3]) - (11863064666333576065352804323*
           PolyGamma[2, 1])/988277434054315200 + 
         (32772103063938039886391326801*Zeta[3])/5435525887298733600) + 
       CF*Log[x]*((46699547709623229710510965057*NM*NC)/43547444993052000 - 
         (36148692359*lm*NM*NC)/22275 - 273273*lm^2*NM*NC - 
         (1372411380150229*NC*NL)/224532000 - (36148692359*lm*NC*NL)/
          22275 - 273273*lm^2*NC*NL - 
         (61808069362928008781380875883910265229*NC*NH)/
          562265563704878825633797956000 - (36148692359*lm*NC*NH)/22275 - 
         273273*lm^2*NC*NH + (5464579923173*NM*NC*Pi^2)/45 - 
         (70010941*NC*NL*Pi^2)/135 + (2372616822759755515084*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) + 
         CF*NC*(7466885018812130802883446324235547598137/
            35974530759073241715700320000 - (59446721893*lm)/1650 - 
           7378371*lm^2 + (96321696002119759*Pi^2)/3207600 + 
           (13533542244380714655163*Im[PolyLog[2, (-1)^(1/3)]])/
            (559210482232380*Sqrt[3]) - 2186184*Zeta[3]) + 
         CA*NC*(-1493301978208054052403325676669795836921/
            14389812303629296686280128000 + (43895981909*lm)/4050 + 
           (3006003*lm^2)/2 - (96319548280509439*Pi^2)/6415200 - 
           (13533542244380714655163*Im[PolyLog[2, (-1)^(1/3)]])/
            (1118420964464760*Sqrt[3]) + 1093092*Zeta[3])), 
      (-563980113484260001420187308247944708321392140975873*CF^2*NC)/
        1679706109532225435108760605515622400000 - 
       (233130710236217*CF^2*lm*NC)/62726400 - (39358683*CF^2*lm^2*NC)/16 + 
       (441717675958914583994532671762065567*CF*NM*NC)/
        150273843691218990462720000 - (396004812226817*CF*lm*NM*NC)/
        1693612800 - (1457729*CF*lm^2*NM*NC)/16 + 
       (184616805111740708033*CF*NC*NL)/78422740704000 - 
       (396004812226817*CF*lm*NC*NL)/1693612800 - (1457729*CF*lm^2*NC*NL)/
        16 + (588135039677527668732036499223485297398000806149*CF*NC*NH)/
        5002059078417835946950280839551050496000 - 
       (396004812226817*CF*lm*NC*NH)/1693612800 - (1457729*CF*lm^2*NC*NH)/
        16 + (29960564125774941084361*CF^2*NC*Pi^2)/134359948800 + 
       (140777*CF^2*lm*NC*Pi^2)/24 - (6016707742015560389*CF*NM*NC*Pi^2)/
        134719200 + (140777*CF*lm*NM*NC*Pi^2)/648 - 
       (122355822329*CF*NC*NL*Pi^2)/641520 + (140777*CF*lm*NC*NL*Pi^2)/
        648 + (140777*CF*lm*NC*NH*Pi^2)/648 - 
       (10092546429335332535365751*CF^2*NC*Pi^3)/(4348420709838986880*
         Sqrt[3]) - (157172794890353269051115*CF*NC*NH*Pi^3)/
        (9882774340543152*Sqrt[3]) - (1111668649*CF^2*NC*Pi^4)/21600 + 
       (56747788953298403504653114739*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1674141973288009948800*Sqrt[3]) + (6450837595906808441888309*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(172948550959505160*Sqrt[3]) - 
       (180836929*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
       (1441792347047904647909393*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16776314466971400*Sqrt[3]) - 
       (4490651282581521972889*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7625597484987*Sqrt[3]) - 
       (1441792347047904647909393*CF^2*NC*Pi*Log[3]^2)/(805263094414627200*
         Sqrt[3]) - (4490651282581521972889*CF*NC*NH*Pi*Log[3]^2)/
        (366028679279376*Sqrt[3]) - 
       (CF*NC*(-161*CA*(-7928618983619715288283723 + 92432895660679860000*
             lm) + 110*(69*CF*(-336357695952345883821857 + 
              9625243680368316000*lm) + 20*(391*(594461308596998949499 + 
                3145504470708600*lm)*NM + 143*(133855722*(84451841 + 
                  64253100*lm)*NL + 5*(368262313293181 + 1720129018247640*
                   lm)*NH))))*Log[x]^2)/954123586416000 + 
       (CF*NC*(-186456626408736125*CA + 372800915951853324*CF - 
          62795908835298320*NM + 1010701263000*NL)*Log[x]^3)/534600 + 
       (5708000551742279227887045388987*CF^2*NC*PolyGamma[2, 1])/
        44472484532444184000 + (231408794391143*CF*NM*NC*PolyGamma[2, 1])/
        97200 - (3504605527138303052881831*CF*NC*NH*PolyGamma[2, 1])/
        1111812113311104600 - (22523337080031391493240280590893*CF^2*NC*
         Zeta[3])/244598664928443012000 + (3086860318446863*CF*NM*NC*
         Zeta[3])/48600 - (31011682*CF*NC*NL*Zeta[3])/9 + 
       (23589517236557341608495269*CF*NC*NH*Zeta[3])/555906056655552300 + 
       CA*CF*NC*(789565774087477617361695034090214750484602971311421/
          4703177106690231218304529695443742720000 + (16035019*lm^2)/32 - 
         (29960539857946929848453*Pi^2)/268719897600 + 
         (10092546429335332535365751*Pi^3)/(8696841419677973760*Sqrt[3]) + 
         (3357530267*Pi^4)/129600 + lm*(592388896923617/307929600 - 
           (1548547*Pi^2)/1296) - (56747788953298403504653114739*
           Im[PolyLog[2, (-1)^(1/3)]])/(3348283946576019897600*Sqrt[3]) + 
         (180836929*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (1441792347047904647909393*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (33552628933942800*Sqrt[3]) + (1441792347047904647909393*Pi*
           Log[3]^2)/(1610526188829254400*Sqrt[3]) - 
         (5708000551742279227887045388987*PolyGamma[2, 1])/
          88944969064888368000 + (22524338992047600863027759476393*Zeta[3])/
          489197329856886024000) + CF*Log[x]*
        ((-39551777283724572489389494433*NM*NC)/80690853957714000 - 
         (373420872877*lm*NM*NC)/213840 - (910910*lm^2*NM*NC)/3 - 
         (15105907211801663*NC*NL)/2263282560 - (373420872877*lm*NC*NL)/
          213840 - (910910*lm^2*NC*NL)/3 - 
         (3600155795910670691394737689525320067*NC*NH)/
          31140861989808673419718040640 - (373420872877*lm*NC*NH)/213840 - 
         (910910*lm^2*NC*NH)/3 - (142716368688059*NM*NC*Pi^2)/4860 - 
         (185929315*NC*NL*Pi^2)/324 + (4490651282581521972889*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(22876792454961*Sqrt[3]) + 
         CF*NC*(14231704298685504058196445803007166389681653/
            8418040197623138561473874880000 - (304884004477*lm)/7920 - 
           8198190*lm^2 + (124300277898615299*Pi^2)/712800 + 
           (1441792347047904647909393*Im[PolyLog[2, (-1)^(1/3)]])/
            (50328943400914200*Sqrt[3]) - (7287280*Zeta[3])/3) + 
         CA*NC*(-3557902058201008806330905830056723883977929/
            4209020098811569280736937440000 + (456058628077*lm)/38880 + 
           (5010005*lm^2)/3 - (41433274419252209*Pi^2)/475200 - 
           (1441792347047904647909393*Im[PolyLog[2, (-1)^(1/3)]])/
            (100657886801828400*Sqrt[3]) + (3643640*Zeta[3])/3)), 
      (-130553707617825060875722901550494592944796007273403*CF^2*NC)/
        145159787243525654885942274550732800000 - (2547853421765*CF^2*lm*NC)/
        418176 - (30901689*CF^2*lm^2*NC)/8 - 
       (39680157856838282124953059844525511803*CF*NM*NC)/
        12165025441670108751744000 - (4252885014029*CF*lm*NM*NC)/11290752 - 
       (1144507*CF*lm^2*NM*NC)/8 + (45297944526257743219*CF*NC*NL)/
        10650001824000 - (4252885014029*CF*lm*NC*NL)/11290752 - 
       (1144507*CF*lm^2*NC*NL)/8 + 
       (1761312774367948553707520764786318589917310698357*CF*NC*NH)/
        8414436855516545977012635987857616000000 - 
       (4252885014029*CF*lm*NC*NH)/11290752 - (1144507*CF*lm^2*NC*NH)/8 + 
       (9239950554367565407027633*CF^2*NC*Pi^2)/24890180515200 + 
       (41405*CF^2*lm*NC*Pi^2)/4 + (1172430134659772411*CF*NM*NC*Pi^2)/
        641520 + (41405*CF*lm*NM*NC*Pi^2)/108 - (3455726729*CF*NC*NL*Pi^2)/
        10692 + (41405*CF*lm*NC*NL*Pi^2)/108 + (41405*CF*lm*NC*NH*Pi^2)/
        108 - (57795375267089321257193*CF^2*NC*Pi^3)/(15098683020274260*
         Sqrt[3]) - (48390154742099728107935*CF*NC*NH*Pi^3)/
        (1647129056757192*Sqrt[3]) - (975944333*CF^2*NC*Pi^4)/10800 + 
       (552862110430908255863875963*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (10334209711654382400*Sqrt[3]) + (4367707917975680755628851*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(45296049060822780*Sqrt[3]) - 
       (447111119*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (33025928724051040718396*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(233004367596825*Sqrt[3]) - 
       (2765151699548555891882*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (8256482181012760179599*CF^2*NC*Pi*Log[3]^2)/(2796052411161900*
         Sqrt[3]) - (1382575849774277945941*CF*NC*NH*Pi*Log[3]^2)/
        (61004779879896*Sqrt[3]) + CF*((9239394437221443393200329*CF*NC)/
          2074181709600 - 137334717*CF*lm*NC + 
         CA*(-46198268319924141760979957/20741817096000 + (55951181*lm)/2)*
          NC + (9846060934240600015867*NM*NC)/448957080 - 
         5086471*lm*NM*NC - (1198362191*NC*NL)/180 - 5086471*lm*NC*NL - 
         (281519230349059*NC*NH)/249420600 - 5086471*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-508445310885174283*CA + 40*(25414031787468653*CF + 
            495*(238049205898090*NM + 137334717*NL)))*Log[x]^3)/801900 + 
       (82915486849762500540974817073*CF^2*NC*PolyGamma[2, 1])/
        329425811351438400 + (6135239160563617*CF*NM*NC*PolyGamma[2, 1])/
        5400 - (1469082417728157917812933*CF*NC*NH*PolyGamma[2, 1])/
        185302018885184100 - (236730439577670923216130067261*CF^2*NC*Zeta[3])/
        1811841962432911200 - (199958401948687*CF*NM*NC*Zeta[3])/300 - 
       (54763124*CF*NC*NL*Zeta[3])/9 + (6238031305076214617072567*CF*NC*NH*
         Zeta[3])/92651009442592050 + CA*CF*NC*
        (130552906588624822368961548571608954852549880650749/
          290319574487051309771884549101465600000 + (12589577*lm^2)/16 - 
         (18704335278550852426373*Pi^2)/100769961600 + 
         (57795375267089321257193*Pi^3)/(30197366040548520*Sqrt[3]) + 
         (982569133*Pi^4)/21600 + lm*(6308712579821/2052864 - 
           (455455*Pi^2)/216) - (552862110430908255863875963*
           Im[PolyLog[2, (-1)^(1/3)]])/(20668419423308764800*Sqrt[3]) + 
         (447111119*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 + 
         (16512964362025520359198*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (233004367596825*Sqrt[3]) + (8256482181012760179599*Pi*Log[3]^2)/
          (5592104822323800*Sqrt[3]) - (82915486849762500540974817073*
           PolyGamma[2, 1])/658851622702876800 + 
         (236745161036976263540410589941*Zeta[3])/3623683924865822400) + 
       CF*Log[x]*((1483920728298306293353723988*NM*NC)/116644941945675 - 
         (105816268649*lm*NM*NC)/35640 - 496860*lm^2*NM*NC - 
         (81645670950102223*NC*NL)/6915585600 - (105816268649*lm*NC*NL)/
          35640 - 496860*lm^2*NC*NL - 
         (11185636933717969909463665448171113747*NC*NH)/
          52384990407286847108738940000 - (105816268649*lm*NC*NH)/35640 - 
         496860*lm^2*NC*NH + (238049302477469*NM*NC*Pi^2)/162 - 
         (6080191*NC*NL*Pi^2)/6 + (2765151699548555891882*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(385171961212365499495553417364659476638299/
            187067559947180856921641664000 - (87124395449*lm)/1320 - 
           13415220*lm^2 + (127107272950431479*Pi^2)/400950 + 
           (33025928724051040718396*Im[PolyLog[2, (-1)^(1/3)]])/
            (699013102790475*Sqrt[3]) - 3974880*Zeta[3]) + 
         CA*NC*(-1925841326615701438658353291704792156420463/
            1870675599471808569216416640000 + (128353838249*lm)/6480 + 
           2732730*lm^2 - (254213507414674339*Pi^2)/1603800 - 
           (16512964362025520359198*Im[PolyLog[2, (-1)^(1/3)]])/
            (699013102790475*Sqrt[3]) + 1987440*Zeta[3])), 
      (-25045981332336266873573976078315065374754893551610287146491*CF^2*NC)/
        5579296696067254215228343248435241723238400000 - 
       (39200822878922011*CF^2*lm*NC)/6360456960 - (65233035*CF^2*lm^2*NC)/
        16 + (3505277806918652723622777240418356128562977*CF*NM*NC)/
        6216498311049608953663708416000 - (66573483706233811*CF*lm*NM*NC)/
        171732337920 - (7248115*CF*lm^2*NM*NC)/48 + 
       (344754072034707186182159*CF*NC*NL)/72893937484368000 - 
       (66573483706233811*CF*lm*NC*NL)/171732337920 - 
       (7248115*CF*lm^2*NC*NL)/48 + 
       (57480913262686135622067706389650330583033612639997*CF*NC*NH)/
        256684610603020528856659148345382854400000 - 
       (66573483706233811*CF*lm*NC*NH)/171732337920 - 
       (7248115*CF*lm^2*NC*NH)/48 + (7132993520051579281722281*CF^2*NC*Pi^2)/
        2521342961280 + (651455*CF^2*lm*NC*Pi^2)/72 - 
       (261113155972114564997*CF*NM*NC*Pi^2)/350269920 + 
       (651455*CF*lm*NM*NC*Pi^2)/1944 - (1699967968445*CF*NC*NL*Pi^2)/
        5003856 + (651455*CF*lm*NC*NL*Pi^2)/1944 + 
       (651455*CF*lm*NC*NH*Pi^2)/1944 - (93727826294158958276460253*CF^2*NC*
         Pi^3)/(21198550960465061040*Sqrt[3]) - 
       (899181298862697350610845*CF*NC*NH*Pi^3)/(29648323021629456*
         Sqrt[3]) - (567453278*CF^2*NC*Pi^4)/6075 + 
       (13186866525872253767049673158041*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (212197495114255261010400*Sqrt[3]) + (425981428430851748666598109*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(5707302181663670280*Sqrt[3]) - 
       (478663696*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (13389689470594136896637179*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(81784533026485575*Sqrt[3]) - 
       (25690894253219924303167*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (13389689470594136896637179*CF^2*NC*Pi*Log[3]^2)/
        (3925657585271307600*Sqrt[3]) - (25690894253219924303167*CF*NC*NH*Pi*
         Log[3]^2)/(1098086037838128*Sqrt[3]) - 
       (CF*NC*(CA*(78952972954943165044000823949 - 140778211421188840999500*
             lm) + 5*(8*CF*(-3947634322311111494854001191 + 
              17277325947145903213575*lm) + 
            2145*(3*(1293209012262708569461651 + 795525670247588280*lm)*NM + 
              19*(91585494*(1799338763 + 1371497940*lm)*NL + 
                (28587634527801161 + 125609316354882360*lm)*NH))))*Log[x]^2)/
        4651352483778000 + (CF*NC*(-92940709103695196277*CA + 
          520*(357446678304729472*CF + 165*(-518358358911254*NM + 
              891473661*NL)))*Log[x]^3)/20849400 + 
       (1994233957256014496544236996533*CF^2*NC*PolyGamma[2, 1])/
        1235346792567894000 - (5168481833609837*CF*NM*NC*PolyGamma[2, 1])/
        32400 - (148025470831078467734353*CF*NC*NH*PolyGamma[2, 1])/
        24706935851357880 - (108562982726424628342508889423361*CF^2*NC*
         Zeta[3])/88327295668604421000 + (12110846317264363*CF*NM*NC*
         Zeta[3])/16200 - (533777458*CF*NC*NL*Zeta[3])/81 + 
       (982142473135280921364347*CF*NC*NH*Zeta[3])/12353467925678940 + 
       CA*CF*NC*(25045951341472784761428167367095986248478356623924130973303/
          11158593392134508430456686496870483446476800000 + 
         (79729265*lm^2)/96 - (13139723394391154979928117*Pi^2)/
          9289158278400 + (93727826294158958276460253*Pi^3)/
          (42397101920930122080*Sqrt[3]) + (190236851*Pi^4)/4050 + 
         lm*(99577840301844211/31224061440 - (7166005*Pi^2)/3888) - 
         (13186866525872253767049673158041*Im[PolyLog[2, (-1)^(1/3)]])/
          (424394990228510522020800*Sqrt[3]) + 
         (239331848*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (13389689470594136896637179*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (163569066052971150*Sqrt[3]) + (13389689470594136896637179*Pi*
           Log[3]^2)/(7851315170542615200*Sqrt[3]) - 
         (1994233957256014496544236996533*PolyGamma[2, 1])/
          2470693585135788000 + (13570457810471175346643752773017*Zeta[3])/
          22081823917151105250) + CF*Log[x]*
        ((-25376348941372642300151415235453*NM*NC)/3628264248208610010 - 
         (26130565867583*lm*NM*NC)/8339760 - 541450*lm^2*NM*NC - 
         (20445077379889330481*NC*NL)/1618247030400 - 
         (26130565867583*lm*NC*NL)/8339760 - 541450*lm^2*NC*NL - 
         (352307586039294852378983213283498392707*NC*NH)/
          1598017917898076662327636296000 - (26130565867583*lm*NC*NH)/
          8339760 - 541450*lm^2*NC*NH - (518357606557795*NM*NC*Pi^2)/972 - 
         (39514943*NC*NL*Pi^2)/36 + (25690894253219924303167*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(182077322331337602715535568867327306672708239731/
            8683629365858148583088375632464000 - (21364138201583*lm)/308880 - 
           14619150*lm^2 + (92940235672403314799*Pi^2)/41698800 + 
           (13389689470594136896637179*Im[PolyLog[2, (-1)^(1/3)]])/
            (245353599079456725*Sqrt[3]) - 4331600*Zeta[3]) + 
         CA*NC*(-3641542784810409021958168779726245548799311151303/
            347345174634325943323535025298560000 + (31877646115583*lm)/
            1516320 + 2977975*lm^2 - (92940185237634037907*Pi^2)/83397600 - 
           (13389689470594136896637179*Im[PolyLog[2, (-1)^(1/3)]])/
            (490707198158913450*Sqrt[3]) + 2165800*Zeta[3])), 
      (-4902486753269173453644059419961300953177733498460849570517*CF^2*NC)/
        512384390455155999357704992203236484787200000 - 
       (27344474212217*CF^2*lm*NC)/2760615 - 6279651*CF^2*lm^2*NC - 
       (2584825959766696328200396695048572719467931*CF*NM*NC)/
        64755190740100093267330296000 - (91286534664649*CF*lm*NM*NC)/
        149073210 - (697739*CF*lm^2*NM*NC)/3 + 
       (106694322742783539493*CF*NC*NL)/12856073630400 - 
       (91286534664649*CF*lm*NC*NL)/149073210 - (697739*CF*lm^2*NC*NL)/3 + 
       (190518429026580848506854089357060105096548837231369*CF*NC*NH)/
        489877995682103911099204401418085581500000 - 
       (91286534664649*CF*lm*NC*NH)/149073210 - (697739*CF*lm^2*NC*NH)/3 + 
       (606892417241580686367397423*CF^2*NC*Pi^2)/161786173348800 + 
       15680*CF^2*lm*NC*Pi^2 + (79362538528073478131*CF*NM*NC*Pi^2)/
        3648645 + (15680*CF*lm*NM*NC*Pi^2)/27 - (19566970001*CF*NC*NL*Pi^2)/
        34749 + (15680*CF*lm*NC*NL*Pi^2)/27 + (15680*CF*lm*NC*NH*Pi^2)/27 - 
       (2718486903710286174918956791*CF^2*NC*Pi^3)/(381573917288371098720*
         Sqrt[3]) - (909808881098152196086660*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) - (1293180091*CF^2*NC*Pi^4)/8100 + 
       (183529011147997110152446752342301*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (1909777456028297349093600*Sqrt[3]) + 
       (33550225223625803161281524*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (183448998696332259*Sqrt[3]) - 
       (85868076*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (388355271958612310702708113*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1472121594476740350*
         Sqrt[3]) - (415912631359155289639616*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (388355271958612310702708113*CF^2*NC*Pi*Log[3]^2)/
        (70661836534883536800*Sqrt[3]) - (25994539459947205602476*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) - 
       (CF*NC*(-7*CA*(-9970315865171052467109937207 + 23407135476521116320000*
             lm) + 320*(CF*(-436199027167207734786179627 + 
              2513607161967324423000*lm) + 
            429*(5*(-1179168462482129363818421 + 43401660398296200*lm)*NM + 
              42*(15536824875*(434671 + 332556*lm)*NL + 2*(606294629884277 + 
                  2583432166565250*lm)*NH))))*Log[x]^2)/3100901655852000 + 
       (CF*NC*(-11283064504197251859*CA + 40*(564117095565998119*CF + 
            85800*(35585913674525*NM + 3242421*NL)))*Log[x]^3)/1737450 + 
       (77200540748696125869130321666361*CF^2*NC*PolyGamma[2, 1])/
        30018927059399824200 + (8980299992607626*CF*NM*NC*PolyGamma[2, 1])/
        675 - (54715407246471685484631037*CF*NC*NH*PolyGamma[2, 1])/
        3752365882424978025 - (2898818880835856429082276818087003*CF^2*NC*
         Zeta[3])/2146353284747087430300 - (1921096832704516*CF*NM*NC*
         Zeta[3])/225 - (102121040*CF*NC*NL*Zeta[3])/9 + 
       (462609530454594138898976326*CF*NC*NH*Zeta[3])/3752365882424978025 + 
       CA*CF*NC*(7506924484658444964301526464960743423420132809108936066087/
          1569177195768915248032971538622411734660800000 + (7675129*lm^2)/6 - 
         (1213784630617859128162712017*Pi^2)/647144693395200 + 
         (2718486903710286174918956791*Pi^3)/(763147834576742197440*
           Sqrt[3]) + (1300706491*Pi^4)/16200 + 
         lm*(135413767834669/27104220 - (86240*Pi^2)/27) - 
         (183529011147997110152446752342301*Im[PolyLog[2, (-1)^(1/3)]])/
          (3819554912056594698187200*Sqrt[3]) + 
         (42934038*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (388355271958612310702708113*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (2944243188953480700*Sqrt[3]) + (388355271958612310702708113*Pi*
           Log[3]^2)/(141323673069767073600*Sqrt[3]) - 
         (77200540748696125869130321666361*PolyGamma[2, 1])/
          60037854118799648400 + (362356367338292592087957090723796*Zeta[3])/
          536588321186771857575) + CF*Log[x]*
        ((3603984885930884900608117841062717*NM*NC)/24188428321390733400 - 
         (60289217288*lm*NM*NC)/11583 - 866320*lm^2*NM*NC - 
         (874746759945701*NC*NL)/40135095 - (60289217288*lm*NC*NL)/11583 - 
         866320*lm^2*NC*NL - (879456269032834956195128504811023948647*NC*
           NH)/2218028116563077185535923755000 - (60289217288*lm*NC*NH)/
          11583 - 866320*lm^2*NC*NH + (1423436655137776*NM*NC*Pi^2)/81 - 
         (17009720*NC*NL*Pi^2)/9 + (415912631359155289639616*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(3069176267811667609548679649299074066256230777781/
            156305328585446674495590761384352000 - (49697155808*lm)/429 - 
           23390640*lm^2 + (2507332819521779819*Pi^2)/772200 + 
           (388355271958612310702708113*Im[PolyLog[2, (-1)^(1/3)]])/
            (4416364783430221050*Sqrt[3]) - 6930560*Zeta[3]) + 
         CA*NC*(-1918231665934674883792581821151620069346884223043/
            195381660731808343119488451730440000 + (36530253364*lm)/1053 + 
           4764760*lm^2 - (22565978731531849453*Pi^2)/13899600 - 
           (388355271958612310702708113*Im[PolyLog[2, (-1)^(1/3)]])/
            (8832729566860442100*Sqrt[3]) + 3465280*Zeta[3])), 
      (-102936154672952723068112325910904670669396029497842460842270037*CF^2*
         NC)/1757478459261185077796928123257101142820096000000 - 
       (192335912988140239*CF^2*lm*NC)/19478899440 - (13058595*CF^2*lm^2*NC)/
        2 + (2394931745953394241570198388477505775921521551*CF*NM*NC)/
        194265572220300279801990888000000 - (326585194038724939*CF*lm*NM*NC)/
        525930284880 - (1450955*CF*lm^2*NM*NC)/6 + 
       (23909739480288411812791*CF*NC*NL)/2650688635795200 - 
       (326585194038724939*CF*lm*NC*NL)/525930284880 - 
       (1450955*CF*lm^2*NC*NL)/6 + 
       (344971800008526136273891076249114672418457804281799*CF*NC*NH)/
        844097469483009816047859891674239771200000 - 
       (326585194038724939*CF*lm*NC*NH)/525930284880 - 
       (1450955*CF*lm^2*NC*NH)/6 + (239447930986552554244378549229*CF^2*NC*
         Pi^2)/6795019280649600 + (121960*CF^2*lm*NC*Pi^2)/9 - 
       (120406937174500944148*CF*NM*NC*Pi^2)/10945935 + 
       (121960*CF*lm*NM*NC*Pi^2)/243 - (1273847473154*CF*NC*NL*Pi^2)/
        2189187 + (121960*CF*lm*NC*NL*Pi^2)/243 + (121960*CF*lm*NC*NH*Pi^2)/
        243 - (6148453947083496040055474813*CF^2*NC*Pi^3)/
        (763147834576742197440*Sqrt[3]) - (924151935774006852462620*CF*NC*NH*
         Pi^3)/(16677181699666569*Sqrt[3]) - (7900492699*CF^2*NC*Pi^4)/
        48600 + (586420161792194559926241669422029*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(5347376876879232577462080*Sqrt[3]) + 
       (913816077134260272992168144*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (6420714954371629065*Sqrt[3]) - 
       (813129346*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (6148453947083496040055474813*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(20609702322674364900*
         Sqrt[3]) - (422469456353831703982912*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (6148453947083496040055474813*CF^2*NC*Pi*Log[3]^2)/
        (989265711488369515200*Sqrt[3]) - (26404341022114481498932*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((1376823955848392863398516046753*CF*NC)/3255946738644600 - 
         275373228*CF*lm*NC + CA*(-145695735572090897215400516363/
            689089256856000 + (504850918*lm)/9)*NC - 
         (1834878674375036371878161*NM*NC)/13900401900 - 
         (91791076*lm*NM*NC)/9 - (5411096977*NC*NL)/405 - 
         (91791076*lm*NC*NL)/9 - (37917824751177509*NC*NH)/15489019260 - 
         (91791076*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-4081085413090624662777*CA + 2800*(2915038328537414111*CF - 
            858*(996632915281258*NM - 206529921*NL)))*Log[x]^3)/72972900 + 
       (6020533655545583464704754989305939*CF^2*NC*PolyGamma[2, 1])/
        300189270593998242000 - (135452206037635*CF*NM*NC*PolyGamma[2, 1])/
        36 - (163661196046398055562479373*CF*NC*NH*PolyGamma[2, 1])/
        15009463529699912100 - (2376039806738743995738597028483672391*CF^2*NC*
         Zeta[3])/150244729932296120121000 + 
       (479543782847527*CF*NM*NC*Zeta[3])/54 - (976975924*CF*NC*NL*Zeta[3])/
        81 + (1072217549450912963786439427*CF*NC*NH*Zeta[3])/
        7504731764849956050 + CA*CF*NC*
        (3216754277009464136020412568864200432711897710276512092947931/
          109842403703824067362308007703568821426256000000 + 
         (15960505*lm^2)/12 - (478895854332065602492847754127*Pi^2)/
          27180077122598400 + (6148453947083496040055474813*Pi^3)/
          (1526295669153484394880*Sqrt[3]) + (2646506633*Pi^4)/32400 + 
         lm*(488455140568616539/95623688160 - (670780*Pi^2)/243) - 
         (586420161792194559926241669422029*Im[PolyLog[2, (-1)^(1/3)]])/
          (10694753753758465154924160*Sqrt[3]) + 
         (406564673*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (6148453947083496040055474813*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (41219404645348729800*Sqrt[3]) + (6148453947083496040055474813*Pi*
           Log[3]^2)/(1978531422976739030400*Sqrt[3]) - 
         (6020533655545583464704754989305939*PolyGamma[2, 1])/
          600378541187996484000 + (594010473088105736627979067097953379*
           Zeta[3])/75122364966148060060500) + 
       CF*Log[x]*((-681999858520469390160734751770573351*NM*NC)/
          7256528496417220020000 - (19703995342589*lm*NM*NC)/3648645 - 
         928200*lm^2*NM*NC - (842775307468992907*NC*NL)/36778341600 - 
         (19703995342589*lm*NC*NL)/3648645 - 928200*lm^2*NC*NL - 
         (55036337147693441589490432760020623278069*NC*NH)/
          136630531980285554629012903308000 - (19703995342589*lm*NC*NH)/
          3648645 - 928200*lm^2*NC*NH - (1993265428798192*NM*NC*Pi^2)/243 - 
         (54249338*NC*NL*Pi^2)/27 + (422469456353831703982912*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(2794693227074213093139562589773499686405347894505177/
            10941373000981267214691353296904640000 - (16129174593089*lm)/
            135135 - 25061400*lm^2 + (8162164647368989373693*Pi^2)/
            291891600 + (6148453947083496040055474813*
             Im[PolyLog[2, (-1)^(1/3)]])/(61829106968023094700*Sqrt[3]) - 
           7425600*Zeta[3]) + CA*NC*
          (-26872046325002869329105412302184071177961132798409/
            210411019249639754128679871094320000 + (24014305528589*lm)/
            663390 + 5105100*lm^2 - (8162164005755049252539*Pi^2)/583783200 - 
           (6148453947083496040055474813*Im[PolyLog[2, (-1)^(1/3)]])/
            (123658213936046189400*Sqrt[3]) + 3712800*Zeta[3])), 
      (-7885008637092324870232960212652743245526538108062693927430537*CF^2*
         NC)/79885384511872048990769460148050051946368000000 - 
       (3376274736081899*CF^2*lm*NC)/216432216 - 9890073*CF^2*lm^2*NC - 
       (15597620357508458059952417976478502355026763287*CF*NM*NC)/
        32377595370050046633665148000000 - (5635723508306543*CF*lm*NM*NC)/
        5843669832 - 366299*CF*lm^2*NM*NC + (12042151105827153215767*CF*NC*
         NL)/779935133577600 - (5635723508306543*CF*lm*NC*NL)/5843669832 - 
       366299*CF*lm^2*NC*NL + 
       (6196997161921218616309951925448048357777868062072259877*CF*NC*NH)/
        8920900379395821441556210455818647971245280000 - 
       (5635723508306543*CF*lm*NC*NH)/5843669832 - 366299*CF*lm^2*NC*NH + 
       (24365990928008967818520613*CF^2*NC*Pi^2)/665786721600 + 
       23120*CF^2*lm*NC*Pi^2 + (933326931718825022513*CF*NM*NC*Pi^2)/
        3648645 + (23120*CF*lm*NM*NC*Pi^2)/27 - 
       (230141970881*CF*NC*NL*Pi^2)/243243 + (23120*CF*lm*NC*NL*Pi^2)/27 + 
       (23120*CF*lm*NC*NH*Pi^2)/27 - (373453047962480821133547607*CF^2*NC*
         Pi^3)/(29351839791413161440*Sqrt[3]) - 
       (541480574447226818067580*CF*NC*NH*Pi^3)/(5559060566555523*Sqrt[3]) - 
       (733097477*CF^2*NC*Pi^4)/2700 + (6852811633785030740007298013131*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(41133668283686404442016*Sqrt[3]) + 
       (9268652260501607743044467372*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (27823098135610392615*Sqrt[3]) - 
       (1289482844*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (373453047962480821133547607*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(792680858564398650*
         Sqrt[3]) - (247533976890160831116608*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (373453047962480821133547607*CF^2*NC*Pi*Log[3]^2)/
        (38048681211091135200*Sqrt[3]) - (15470873555635051944788*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((238317169922786422203535484273*CF*NC)/542657789774100 - 
         469696536*CF*lm*NC + CA*(-4766348054865786824038977542723/
            21706311590964000 + 95678924*lm)*NC + 
         (277347426297146995631283763*NM*NC)/90352612350 - 
         17396168*lm*NM*NC - (1022054926*NC*NL)/45 - 17396168*lm*NC*NL - 
         (57618298672644691*NC*NH)/13437055170 - 17396168*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-2347566818257752253709*CA + 
          220*(21341249884809487939*CF + 32760*(4205156564652206*NM + 
              58712067*NL)))*Log[x]^3)/36486450 + 
       (2299066976601562567222673703701467*CF^2*NC*PolyGamma[2, 1])/
        90056781178199472600 + (69685997914892629*CF*NM*NC*PolyGamma[2, 1])/
        450 - (580794895617536573671791673*CF*NC*NH*PolyGamma[2, 1])/
        22514195294549868150 - (598692933037707130204876990605099919*CF^2*NC*
         Zeta[3])/45073418979688836036300 - (71285682180752113*CF*NM*NC*
         Zeta[3])/675 - (182876072*CF*NC*NL*Zeta[3])/9 + 
       (2445045142549174861418654327*CF*NC*NH*Zeta[3])/
        11257097647274934075 + CA*CF*NC*
        (2710471179677054009895195321494161558033792370834754754873681/
          54921201851912033681154003851784410713128000000 + 
         (4029289*lm^2)/2 - (696580661536688229774955109*Pi^2)/
          38067334905600 + (373453047962480821133547607*Pi^3)/
          (58703679582826322880*Sqrt[3]) + (736796677*Pi^4)/5400 + 
         lm*(8360034946586975/1062485424 - (127160*Pi^2)/27) - 
         (6852811633785030740007298013131*Im[PolyLog[2, (-1)^(1/3)]])/
          (82267336567372808884032*Sqrt[3]) + 
         (644741422*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (373453047962480821133547607*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1585361717128797300*Sqrt[3]) + (373453047962480821133547607*Pi*
           Log[3]^2)/(76097362422182270400*Sqrt[3]) - 
         (2299066976601562567222673703701467*PolyGamma[2, 1])/
          180113562356398945200 + (149673531097276525696128903817454701*
           Zeta[3])/22536709489844418018150) + 
       CF*Log[x]*((2085502352261460013514006045163442337*NM*NC)/
          1209421416069536670000 - (3564801710692*lm*NM*NC)/405405 - 
         1456560*lm^2*NM*NC - (11302367067690017959*NC*NL)/292183491600 - 
         (3564801710692*lm*NC*NL)/405405 - 1456560*lm^2*NC*NL - 
         (387355791187160473961079879639828400820827*NC*NH)/
          547172749502000721157142150866800 - (3564801710692*lm*NC*NH)/
          405405 - 1456560*lm^2*NC*NH + (16820626481933200*NM*NC*Pi^2)/81 - 
         (10154644*NC*NL*Pi^2)/3 + (247533976890160831116608*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(976033146480357379787819405809496553104903451632447/
            5470686500490633607345676648452320000 - (2941499631292*lm)/
            15015 - 39327120*lm^2 + (4695128527549998786491*Pi^2)/145945800 + 
           (373453047962480821133547607*Im[PolyLog[2, (-1)^(1/3)]])/
            (2378042575693195950*Sqrt[3]) - 11652480*Zeta[3]) + 
         CA*NC*(-24400820098809367876874923337088247008918409647089/
            273534325024531680367283832422616000 + (2158171486946*lm)/36855 + 
           8011080*lm^2 - (4695127905972392538893*Pi^2)/291891600 - 
           (373453047962480821133547607*Im[PolyLog[2, (-1)^(1/3)]])/
            (4756085151386391900*Sqrt[3]) + 5826240*Zeta[3])), 
      (-3474579309094129975552807418712878308144766058426565620172280929*CF^2*
         NC)/4652148862750195794168339149798208907464960000000 - 
       (19417281624196999*CF^2*lm*NC)/1264863600 - (20296419*CF^2*lm^2*NC)/
        2 + (51041823175486909166450249836401846534341332673*CF*NM*NC)/
        249770021426100359745416856000000 - (32966499137128099*CF*lm*NM*NC)/
        34151317200 - (6765473*CF*lm^2*NM*NC)/18 + 
       (404996802754443893484497*CF*NC*NL)/24613537332384000 - 
       (32966499137128099*CF*lm*NC*NL)/34151317200 - 
       (6765473*CF*lm^2*NC*NL)/18 + 
       (10749549878033763441904902301256778514048018484003117471*CF*NC*NH)/
        14960516164204172603852029956962950013889600000 - 
       (32966499137128099*CF*lm*NC*NH)/34151317200 - 
       (6765473*CF*lm^2*NC*NH)/18 + (14657666364200017405494010783937*CF^2*
         NC*Pi^2)/33975096403248000 + (178024*CF^2*lm*NC*Pi^2)/9 - 
       (236302210039287293312*CF*NM*NC*Pi^2)/1563705 + 
       (178024*CF*lm*NM*NC*Pi^2)/243 - (136915811879*CF*NC*NL*Pi^2)/
        142155 + (178024*CF*lm*NC*NL*Pi^2)/243 + (178024*CF*lm*NC*NH*Pi^2)/
        243 - (19402433441406516570890853313*CF^2*NC*Pi^3)/
        (1373666102238135955392*Sqrt[3]) - (14639202231825510068348920*CF*NC*
         NH*Pi^3)/(150094635296999121*Sqrt[3]) - (13258440539*CF^2*NC*Pi^4)/
        48600 + (225150595981596192474839860899961261*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(1203159797297827329928968000*Sqrt[3]) + 
       (139657976689886378097681197744*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (536588321186771857575*Sqrt[3]) - 
       (445387862*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (19402433441406516570890853313*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(37097464180813856820*
         Sqrt[3]) - (6692206734548804602673792*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (19402433441406516570890853313*CF^2*NC*Pi*Log[3]^2)/
        (1780678280679065127360*Sqrt[3]) - (418262920909300287667112*CF*NC*
         NH*Pi*Log[3]^2)/(5559060566555523*Sqrt[3]) + 
       CF*((708248461675785103582659229151*CF*NC)/136804484817000 - 
         490396620*CF*lm*NC + CA*(-404713438611846672940198805551/
            156347982648000 + (899060470*lm)/9)*NC - 
         (140439133753697086134369233*NM*NC)/77445096300 - 
         (163465540*lm*NM*NC)/9 - (1069395421*NC*NL)/45 - 
         (163465540*lm*NC*NL)/9 - (1338249060553676617*NC*NH)/
          292944494700 - (163465540*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-50305074605795680060053*CA + 8*(12576253583229668201959*CF - 
            31531500*(133775172649570*NM - 3502833*NL)))*Log[x]^3)/
        72972900 + (664132077220381859981901463277691227*CF^2*NC*
         PolyGamma[2, 1])/2701703435345984178000 - 
       (1524730099109684663*CF*NM*NC*PolyGamma[2, 1])/24300 - 
       (2581209395367337018613436523*CF*NC*NH*PolyGamma[2, 1])/
        135085171767299208900 - (38195284584915521608321690826166067289*CF^2*
         NC*Zeta[3])/193171795627237868727000 + 
       (1284550337958138937*CF*NM*NC*Zeta[3])/12150 - 
       (1720973716*CF*NC*NL*Zeta[3])/81 + (16721488139932982359493292197*CF*
         NC*NH*Zeta[3])/67542585883649604450 + 
       CA*CF*NC*(835235390364130739620186569956883537735227826064564117714421\
9/22366100301683633625809322835568312055120000000 + (74420203*lm^2)/36 - 
         (1724431333216959601328187172187*Pi^2)/7994140330176000 + 
         (19402433441406516570890853313*Pi^3)/(2747332204476271910784*
           Sqrt[3]) + (13315408219*Pi^4)/97200 + 
         lm*(49303354702958899/6209330400 - (979132*Pi^2)/243) - 
         (225150595981596192474839860899961261*Im[PolyLog[2, (-1)^(1/3)]])/
          (2406319594595654659857936000*Sqrt[3]) + 
         (222693931*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (19402433441406516570890853313*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(74194928361627713640*Sqrt[3]) + 
         (19402433441406516570890853313*Pi*Log[3]^2)/(3561356561358130254720*
           Sqrt[3]) - (664132077220381859981901463277691227*PolyGamma[2, 1])/
          5403406870691968356000 + (9548822312832100238992322091571272641*
           Zeta[3])/96585897813618934363500) + 
       CF*Log[x]*((-3764226596948825317584671111909644291*NM*NC)/
          3109940784178808580000 - (425890874647*lm*NM*NC)/47385 - 
         1537480*lm^2*NM*NC - (2734818346275288853*NC*NL)/68302634400 - 
         (425890874647*lm*NC*NL)/47385 - 1537480*lm^2*NC*NL - 
         (4553779373591313540119919693082367035988453*NC*NH)/
          6423332276762617161409929597132000 - (425890874647*lm*NC*NH)/
          47385 - 1537480*lm^2*NC*NH - (9364261818736160*NM*NC*Pi^2)/81 - 
         (95570090*NC*NL*Pi^2)/27 + (6692206734548804602673792*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CF*NC*(88654302406609107704926871118673868477348857794618469/
            28962457943773942627124170491806400000 - (348989968747*lm)/1755 - 
           41511960*lm^2 + (4790958959748609897833*Pi^2)/13899600 + 
           (19402433441406516570890853313*Im[PolyLog[2, (-1)^(1/3)]])/
            (111292392542441570460*Sqrt[3]) - 12299840*Zeta[3]) + 
         CA*NC*(-11081787568939107785162388585421372278383699858917823/
            7240614485943485656781042622951600000 + (5704748478317*lm)/
            94770 + 8456140*lm^2 - (1596986302082997583333*Pi^2)/9266400 - 
           (19402433441406516570890853313*Im[PolyLog[2, (-1)^(1/3)]])/
            (222584785084883140920*Sqrt[3]) + 6149920*Zeta[3])), 
      (-2997218279192567504744889897631348427060848386328779367141348111*CF^2*
         NC)/3041789641028974173110067905637290439496320000000 - 
       (8977887245772073*CF^2*lm*NC)/375750375 - (75744639*CF^2*lm^2*NC)/5 - 
       (17906384177167107518305485589522469037987135647*CF*NM*NC)/
        3122125267826254496817710700000 - (29972673461795321*CF*lm*NM*NC)/
        20290520250 - (2805357*CF*lm^2*NM*NC)/5 + 
       (7256795803574596978710239*CF*NC*NL)/263228107582440000 - 
       (29972673461795321*CF*lm*NC*NL)/20290520250 - 
       (2805357*CF*lm^2*NC*NL)/5 + 
       (10749813446079409395835643425276739459171088380152655296555709*CF*NC*
         NH)/8969485833087105934082285967013650282758674606200000 - 
       (29972673461795321*CF*lm*NC*NH)/20290520250 - 
       (2805357*CF*lm^2*NC*NH)/5 + (129268895010847318955284236847*CF^2*NC*
         Pi^2)/377501071147200 + (166464*CF^2*lm*NC*Pi^2)/5 + 
       (1644065579429454238511*CF*NM*NC*Pi^2)/552825 + 
       (18496*CF*lm*NM*NC*Pi^2)/15 - (1040580565313*CF*NC*NL*Pi^2)/675675 + 
       (18496*CF*lm*NC*NL*Pi^2)/15 + (18496*CF*lm*NC*NH*Pi^2)/15 - 
       (6842277689356664243608922909*CF^2*NC*Pi^3)/(312196841417758171680*
         Sqrt[3]) - (25217434152293936236827220*CF*NC*NH*Pi^3)/
        (150094635296999121*Sqrt[3]) - (401982323*CF^2*NC*Pi^4)/900 + 
       (3061266462007796435897762399782721*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(10937816339071157544808800*Sqrt[3]) + 
       (169185434279474847128438982572*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (288932172946723307925*Sqrt[3]) - 
       (231773036*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (6842277689356664243608922909*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(8431241859275876550*
         Sqrt[3]) - (11527969898191513708263872*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1853020188851841*Sqrt[3]) - 
       (6842277689356664243608922909*CF^2*NC*Pi*Log[3]^2)/
        (404699609245242074400*Sqrt[3]) - (720498118636969606766492*CF*NC*NH*
         Pi*Log[3]^2)/(5559060566555523*Sqrt[3]) - 
       (CF*NC*(-899*CA*(-44597759634766956343387711118479 + 
            3624335812924578476524800*lm) + 
          560*(899*CF*(-159277683912777019582400053507 + 
              31771774983429746385120*lm) + 
            572*(7192*(-302290638192090639069914471 + 257153060925195435*lm)*
               NM + 2045716999326*(1179245789 + 904057020*lm)*NL + 
              (476093397273920517671 + 1849444814174005568520*lm)*NH)))*
         Log[x]^2)/19513974120276636000 + 
       (CF*NC*(-2486813585856490011283*CA + 8*(621701884664563149791*CF + 
            120120*(40930293691128449*NM + 85383163*NL)))*Log[x]^3)/
        4054050 + (22066723479999946609456947640381307*CF^2*NC*
         PolyGamma[2, 1])/90056781178199472600 + 
       (26842444388458309*CF*NM*NC*PolyGamma[2, 1])/15 - 
       (496493408913982663079317558*CF*NC*NH*PolyGamma[2, 1])/
        11257097647274934075 - (794272004818786063107932015291978417*CF^2*NC*
         Zeta[3])/6439059854241262290900 - (171720666602526086*CF*NM*NC*
         Zeta[3])/135 - (1580286544*CF*NC*NL*Zeta[3])/45 + 
       (4164008625425639866181899924*CF*NC*NH*Zeta[3])/
        11257097647274934075 + CA*CF*NC*
        (1217619882903856812583667210889147577305306312095563108324960049/
          2471454083336041515651930173330298482090760000000 + 
         (30858927*lm^2)/10 - (76040526089510233460699058137*Pi^2)/
          444118907232000 + (6842277689356664243608922909*Pi^3)/
          (624393682835516343360*Sqrt[3]) + (403757939*Pi^4)/1800 + 
         lm*(44461948775208221/3689185500 - (101728*Pi^2)/15) - 
         (3061266462007796435897762399782721*Im[PolyLog[2, (-1)^(1/3)]])/
          (21875632678142315089617600*Sqrt[3]) + 
         (115886518*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (6842277689356664243608922909*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (16862483718551753100*Sqrt[3]) + (6842277689356664243608922909*Pi*
           Log[3]^2)/(809399218490484148800*Sqrt[3]) - 
         (22066723479999946609456947640381307*PolyGamma[2, 1])/
          180113562356398945200 + (99284037006026327556950969488540132*
           Zeta[3])/1609764963560315572725) + 
       CF*Log[x]*((1652559814189464681406119531508260499*NM*NC)/
          83729174958660231000 - (3239014725524*lm*NM*NC)/225225 - 
         2372112*lm^2*NM*NC - (24222263877697291727*NC*NL)/365229364500 - 
         (3239014725524*lm*NC*NL)/225225 - 2372112*lm^2*NC*NL - 
         (303365457055322594369148195913921614270341451229*NC*NH)/
          248456098298247222457626429299465043000 - (3239014725524*lm*NC*NH)/
          225225 - 2372112*lm^2*NC*NH + (65488470050111120*NM*NC*Pi^2)/27 - 
         (789810344*NC*NL*Pi^2)/135 + (11527969898191513708263872*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(5559060566555523*Sqrt[3]) + 
         CF*NC*(373521275998733692522885320722722148300432926872792163/
            246180892522078512330555449180354400000 - (8025224246772*lm)/
            25025 - 64047024*lm^2 + (710518025238713473553*Pi^2)/2316600 + 
           (6842277689356664243608922909*Im[PolyLog[2, (-1)^(1/3)]])/
            (25293725577827629650*Sqrt[3]) - 18976896*Zeta[3]) + 
         CA*NC*(-46690156244016397781225787897169511376413162677879421/
            61545223130519628082638862295088600000 + (1959490315162*lm)/
            20475 + 13046616*lm^2 - (236839336095765282613*Pi^2)/1544400 - 
           (6842277689356664243608922909*Im[PolyLog[2, (-1)^(1/3)]])/
            (50587451155655259300*Sqrt[3]) + 9488448*Zeta[3])), 
      (-324607258979721881159365766837409344773923581165616513361505607804432\
7*CF^2*NC)/348061605371088167604364078180201766571567421440000000 - 
       (80495274144974519927*CF^2*lm*NC)/3462915456000 - 
       (245810565*CF^2*lm^2*NC)/16 + 
       (2455764038372421157347236396943775344244548913520651657*CF*NM*NC)/
        818716557464220128962882596612249600000 - 
       (136652228627423339927*CF*lm*NM*NC)/93498717312000 - 
       (9104095*CF*lm^2*NM*NC)/16 + (1094639362762972923331940689*CF*NC*NL)/
        37904847491871360000 - (136652228627423339927*CF*lm*NC*NL)/
        93498717312000 - (9104095*CF*lm^2*NC*NL)/16 + 
       (8420048477116705237486803396769194322874286497471638681299302893*CF*
         NC*NH)/6888565119810897357375195622666483417158662097561600000 - 
       (136652228627423339927*CF*lm*NC*NH)/93498717312000 - 
       (9104095*CF*lm^2*NC*NH)/16 + (134555100752144191160607501470911*CF^2*
         NC*Pi^2)/25885787735808000 + (1129123*CF^2*lm*NC*Pi^2)/40 - 
       (4583176439156438836363*CF*NM*NC*Pi^2)/2316600 + 
       (1129123*CF*lm*NM*NC*Pi^2)/1080 - (602076218196077*CF*NC*NL*Pi^2)/
        389188800 + (1129123*CF*lm*NC*NL*Pi^2)/1080 + 
       (1129123*CF*lm*NC*NH*Pi^2)/1080 - (1972882181679689621757914505133*
         CF^2*NC*Pi^3)/(82419966134288157323520*Sqrt[3]) - 
       (299159783235262841164436555*CF*NC*NH*Pi^3)/(1801135623563989452*
         Sqrt[3]) - (28737149707*CF^2*NC*Pi^4)/64800 + 
       (1278585782657356840144213154077997881*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4125119305021122274042176000*Sqrt[3]) + 
       (41362288147400148719329093115111*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(90146837959377672072600*Sqrt[3]) - 
       (1421529137*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 - 
       (281840311668527088822559215019*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(317978264406975915600*
         Sqrt[3]) - (34189689512601467561649892*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(5559060566555523*Sqrt[3]) - 
       (281840311668527088822559215019*CF^2*NC*Pi*Log[3]^2)/
        (15262956691534843948800*Sqrt[3]) - (8547422378150366890412473*CF*NC*
         NH*Pi*Log[3]^2)/(66708726798666276*Sqrt[3]) - 
       (CF*NC*(-6479*CA*(-4508883422900905385961833684294549 + 
            24833342447520852647001600*lm) + 
          14*(589*CF*(-7085388156019548859149929733517591 + 
              95785749440437574495577600*lm) + 
            5720*(31*(8957730168097372344094712840489 + 
                11784053608963441565760*lm)*NM + 11*(4463382543984*
                 (9725243673 + 7440456940*lm)*NL + (8706340156357958699603 + 
                  33209605625260608048960*lm)*NH))))*Log[x]^2)/
        936670757773278528000 + (CF*NC*(-813279468618868518316629*CA + 
          56*(29045690067298155564231*CF - 2860*(3744196839254437911*NM - 
              12648776798*NL)))*Log[x]^3)/97297200 + 
       (24086244844623058094585890941602350777*CF^2*NC*PolyGamma[2, 1])/
        8105110306037952534000 - (44390127129256555103*CF*NM*NC*
         PolyGamma[2, 1])/48600 - (52503374593062665384713148297*CF*NC*NH*
         PolyGamma[2, 1])/1621022061207590506800 - 
       (508971046142013036223581863860819423271*CF^2*NC*Zeta[3])/
        210732867956986765884000 + (30493815938735718187*CF*NM*NC*Zeta[3])/
        24300 - (29310654703*CF*NC*NL*Zeta[3])/810 + 
       (336720892297482158928011013823*CF*NC*NH*Zeta[3])/
        810511030603795253400 + CA*CF*NC*(22722508050898294785573413694288270\
978357565605372650212871687525976889/
          4872862475195234346461097094522824732001943900160000000 + 
         (100145045*lm^2)/32 - (376905044013769998385708520291*Pi^2)/
          145018418688000 + (1972882181679689621757914505133*Pi^3)/
          (164839932268576314647040*Sqrt[3]) + (5769109103*Pi^4)/25920 + 
         lm*(204363006280902299927/16999766784000 - (12420353*Pi^2)/2160) - 
         (1278585782657356840144213154077997881*Im[PolyLog[2, (-1)^(1/3)]])/
          (8250238610042244548084352000*Sqrt[3]) + 
         (1421529137*Im[PolyLog[2, (-1)^(1/3)]]^2)/60 + 
         (281840311668527088822559215019*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(635956528813951831200*Sqrt[3]) + 
         (281840311668527088822559215019*Pi*Log[3]^2)/
          (30525913383069687897600*Sqrt[3]) - 
         (24086244844623058094585890941602350777*PolyGamma[2, 1])/
          16210220612075905068000 + (508971054723806474326343463233872706411*
           Zeta[3])/421465735913973531768000) + 
       CF*Log[x]*((-2652919863406607353301582915697664636534873*NM*NC)/
          175758925406022202660416000 - (940929304694003*lm*NM*NC)/
          64864800 - 2470950*lm^2*NM*NC - (3560540845744628819317*NC*NL)/
          52593028488000 - (940929304694003*lm*NC*NL)/64864800 - 
         2470950*lm^2*NC*NL - 
         (57588871185058932078160899552398298217261858783157*NC*NH)/
          47703570873263466711864274425497288256000 - 
         (940929304694003*lm*NC*NH)/64864800 - 2470950*lm^2*NC*NH - 
         (249613121612219191*NM*NC*Pi^2)/162 - (7325123149*NC*NL*Pi^2)/
          1215 + (34189689512601467561649892*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(16677181699666569*Sqrt[3]) + 
         CF*NC*(168778669393838830657886517697672252102657786474540957883/
            4670033021302286365488657129940106400000 - (771747311714003*lm)/
            2402400 - 66715650*lm^2 + (21124141711513735153891*Pi^2)/
            5054400 + (281840311668527088822559215019*
             Im[PolyLog[2, (-1)^(1/3)]])/(953934793220927746800*Sqrt[3]) - 
           19767600*Zeta[3]) + CA*NC*
          (-1718473719682398263858599682328080837846630136879911055601/
            95098854251973831442678108827871257600000 + (1144919076134003*lm)/
            11793600 + 13590225*lm^2 - (21124141678547923156643*Pi^2)/
            10108800 - (281840311668527088822559215019*
             Im[PolyLog[2, (-1)^(1/3)]])/(1907869586441855493600*Sqrt[3]) + 
           9883800*Zeta[3])), (-987295946265103699310588030072153995621793129\
6842427753363170915765490317*CF^2*NC)/
        1041574354072981341556059503954253786465415508659200000000 - 
       (6869326538854756661*CF^2*lm*NC)/192384192000 - 
       (905614803*CF^2*lm^2*NC)/40 - 
       (9197163237613625819879497741015232586704173778770342567*CF*NM*NC)/
        136452759577370021493813766102041600000 - 
       (11466956359173491861*CF*lm*NM*NC)/5194373184000 - 
       (33541289*CF*lm^2*NM*NC)/40 + (200015796032385900905391419*CF*NC*NL)/
        4211649721319040000 - (11466956359173491861*CF*lm*NC*NL)/
        5194373184000 - (33541289*CF*lm^2*NC*NL)/40 + 
       (62154879233489752532106213893711508412226054383789695202158278111*CF*
         NC*NH)/30998543039149038108188380301999175377213979439027200000 - 
       (11466956359173491861*CF*lm*NC*NH)/5194373184000 - 
       (33541289*CF*lm^2*NC*NH)/40 + (50198716143037670191802321085277*CF^2*
         NC*Pi^2)/16538142164544000 + (938961*CF^2*lm*NC*Pi^2)/20 + 
       (1663813813719091700791403*CF*NM*NC*Pi^2)/48648600 + 
       (104329*CF*lm*NM*NC*Pi^2)/60 - (52700327147371*CF*NC*NL*Pi^2)/
        21621600 + (104329*CF*lm*NC*NL*Pi^2)/60 + (104329*CF*lm*NC*NH*Pi^2)/
        60 - (847704139445220712847004732347*CF^2*NC*Pi^3)/
        (23180615475268544247240*Sqrt[3]) - (2277951296019363127464851515*CF*
         NC*NH*Pi^3)/(8105110306037952534*Sqrt[3]) - 
       (963215393*CF^2*NC*Pi^4)/1350 + 
       (14852247256855372679840839758554512901*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(32485314527041337908082136000*
         Sqrt[3]) + (404520999865046959793489153387023*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(405660770817199524326700*Sqrt[3]) - 
       (364791032*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (1695408278890441425694009464694*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1252039416102467667675*
         Sqrt[3]) - (520674581947283000563394632*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(50031545098999707*Sqrt[3]) - 
       (847704139445220712847004732347*CF^2*NC*Pi*Log[3]^2)/
        (30048945986459224024200*Sqrt[3]) - (65084322743410375070424329*CF*NC*
         NH*Pi*Log[3]^2)/(300189270593998242*Sqrt[3]) - 
       (CF*NC*(-186*CA*(-19106885587973522478522739769256521 + 
            295905766550733036609912000*lm) + 
          279*CF*(-25475846563296124841372747335575533 + 
            968418872347853574359712000*lm) + 
          100100*(31*(-25808667243465944833300067501839 + 
              3224838069756422159040*lm)*NM + 
            13*(23919152607504*(419042219 + 321499620*lm)*NL + 
              (2057665945365007011469 + 7689998474034545148480*lm)*NH)))*
         Log[x]^2)/195139741202766360000 + 
       (CF*NC*(-90397031131786341339133*CA + 80*(2259924695966810482901*CF + 
            6006*(3782288223965180347*NM + 1153826414*NL)))*Log[x]^3)/
        16216200 + (131653822660860524779100849801116953349*CF^2*NC*
         PolyGamma[2, 1])/58356794203473258244800 + 
       (55393679351410666339*CF*NM*NC*PolyGamma[2, 1])/2700 - 
       (106729387130065557151411612717*CF*NC*NH*PolyGamma[2, 1])/
        1458919855086831456120 - (31031835915433972162274370258099795745567*
         CF^2*NC*Zeta[3])/29207575498838365751522400 - 
       (20252084558386746991*CF*NM*NC*Zeta[3])/1350 - 
       (2646617749*CF*NC*NL*Zeta[3])/45 + (89185964728557201867339481135*CF*
         NC*NH*Zeta[3])/145891985508683145612 + 
       CA*CF*NC*(759458415428510910398960896648932784336701679011706123261917\
566115895909/160242208318920206393239923685269813302371616716800000000 + 
         (368954179*lm^2)/80 - (2895912702948787835568979769*Pi^2)/
          1908137088000 + (847704139445220712847004732347*Pi^3)/
          (46361230950537088494480*Sqrt[3]) + (966971237*Pi^4)/2700 + 
         lm*(17010510018122397461/944431488000 - (1147619*Pi^2)/120) - 
         (14852247256855372679840839758554512901*Im[PolyLog[2, (-1)^(1/3)]])/
          (64970629054082675816164272000*Sqrt[3]) + 
         (182395516*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (847704139445220712847004732347*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(1252039416102467667675*Sqrt[3]) + 
         (847704139445220712847004732347*Pi*Log[3]^2)/
          (60097891972918448048400*Sqrt[3]) - 
         (131653822660860524779100849801116953349*PolyGamma[2, 1])/
          116713588406946516489600 + 
         (31031838109336299988901493495767914087927*Zeta[3])/
          58415150997676731503044800) + CF*Log[x]*
        ((503827040223760241693902825041640918063811*NM*NC)/
          2253319556487464136672000 - (82366669290809*lm*NM*NC)/3603600 - 
         3755844*lm^2*NM*NC - (80552321278625578159*NC*NL)/730458729000 - 
         (82366669290809*lm*NC*NL)/3603600 - 3755844*lm^2*NC*NL - 
         (438430441250338054012648225954443567195719213859319*NC*NH)/
          214666068929685600203389234914737797152000 - 
         (82366669290809*lm*NC*NH)/3603600 - 3755844*lm^2*NC*NH + 
         (756457645058809901*NM*NC*Pi^2)/27 - (1322839394*NC*NL*Pi^2)/135 + 
         (520674581947283000563394632*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (150094635296999121*Sqrt[3]) + 
         CF*NC*(2597633191081328123162964941439932555058532134990560323832333/
            223601181059953471179596903381532294432000000 - 
           (204240569650827*lm)/400400 - 101407788*lm^2 + 
           (30132342585924185258221*Pi^2)/10810800 + 
           (1695408278890441425694009464694*Im[PolyLog[2, (-1)^(1/3)]])/
            (3756118248307403003025*Sqrt[3]) - 30046752*Zeta[3]) + 
         CA*NC*(-162352072016404165873336361515568641228664308977774198294863/
            27950147632494183897449612922691536804000000 + 
           (99592472212409*lm)/655200 + 20657142*lm^2 - 
           (90397027362305762913523*Pi^2)/64864800 - 
           (847704139445220712847004732347*Im[PolyLog[2, (-1)^(1/3)]])/
            (3756118248307403003025*Sqrt[3]) + 15023376*Zeta[3])), 
      (-120542324505662459756057544182120986444256725849556641162971024585188\
774144431979*CF^2*NC)/
        1055004413794398362974083335198239934788100576227851724800000000 - 
       (983157440369820592273*CF^2*lm*NC)/28593787622400 - 
       (363543093*CF^2*lm^2*NC)/16 + 
       (142876478786740390462874188245167320507098001707331494684677*CF*NM*
         NC)/3484340709059511694561890776525075404800000 - 
       (1668943571841403333873*CF*lm*NM*NC)/772032265804800 - 
       (13464559*CF*lm^2*NM*NC)/16 + (294924371475628918593153377*CF*NC*NL)/
        6018956552280672000 - (1668943571841403333873*CF*lm*NC*NL)/
        772032265804800 - (13464559*CF*lm^2*NC*NL)/16 + 
       (29807465358002672790064230087926359347964545070175206306672857841*CF*
         NC*NH)/14761210971023351480089704905713893036768561637632000000 - 
       (1668943571841403333873*CF*lm*NC*NH)/772032265804800 - 
       (13464559*CF*lm^2*NC*NH)/16 + (14195779640583804380755117160202083*
         CF^2*NC*Pi^2)/230030522834112000 + (315875*CF^2*lm*NC*Pi^2)/8 - 
       (123066254521803710148359*CF*NM*NC*Pi^2)/4922775 + 
       (315875*CF*lm*NM*NC*Pi^2)/216 - (457355498864291*CF*NC*NL*Pi^2)/
        189034560 + (315875*CF*lm*NC*NL*Pi^2)/216 + 
       (315875*CF*lm*NC*NH*Pi^2)/216 - (248214468622837624579616106349541*
         CF^2*NC*Pi^3)/(6305127409273044035249280*Sqrt[3]) - 
       (1484206503862670282678171545*CF*NC*NH*Pi^3)/(5403406870691968356*
         Sqrt[3]) - (22710131843*CF^2*NC*Pi^4)/32400 + 
       (18772489356676487294846402753826349084303*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(37553023593259786621742949216000*
         Sqrt[3]) + (6050812305540637862772446231903*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7726871825089514749080*Sqrt[3]) - 
       (1105161961*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (248214468622837624579616106349541*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(170277360589935602803800*
         Sqrt[3]) - (169623600441448032306076748*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (248214468622837624579616106349541*CF^2*NC*Pi*Log[3]^2)/
        (8173313308316908934582400*Sqrt[3]) - 
       (42405900110362008076519187*CF*NC*NH*Pi*Log[3]^2)/
        (200126180395998828*Sqrt[3]) - 
       (CF*NC*(CA*(7370058391508116681144945155365918485391 - 
            5699661586623102370590798480000*lm) + 
          13*(CF*(-1133855135354886173938789161913732915519 + 
              2152319759983549146936385440000*lm) + 
            916300*(11*(45570355385116212189478720370911 + 
                7908837584560175390400*lm)*NM + 666319251209040*(170511063 + 
                130563860*lm)*NL + (23668033086034991007163 + 
                86997213430161929294400*lm)*NH)))*Log[x]^2)/
        19904253602682168720000 + (CF*NC*(-33022251046945289658754749*CA + 
          136*(485621325982306425776673*CF - 140140*(1370117818234395729*
               NM - 602458954*NL)))*Log[x]^3)/330810480 + 
       (2068453767605226006793973813347746316697*CF^2*NC*PolyGamma[2, 1])/
        58356794203473258244800 - (599456866828867220189*CF*NM*NC*
         PolyGamma[2, 1])/48600 - (259223682716790946434167116037*CF*NC*NH*
         PolyGamma[2, 1])/4863066183622771520400 - 
       (14365749520054586456724838171581503638253323*CF^2*NC*Zeta[3])/
        496528783480252217775880800 + (359625616486960527541*CF*NM*NC*
         Zeta[3])/24300 - (9689952671*CF*NC*NL*Zeta[3])/162 + 
       (1647505141853253747798815950963*CF*NC*NH*Zeta[3])/
        2431533091811385760200 + CA*CF*NC*(1205423244489641627092789550416844\
13098723840798436779929382678749789940864467979/
          2110008827588796725948166670396479869576201152455703449600000000 + 
         (148110149*lm^2)/32 - (10828207200637477440383674671557*Pi^2)/
          350923757184000 + (248214468622837624579616106349541*Pi^3)/
          (12610254818546088070498560*Sqrt[3]) + (22785941843*Pi^4)/64800 + 
         lm*(2495824457634890658673/140369502873600 - (3474625*Pi^2)/432) - 
         (18772489356676487294846402753826349084303*
           Im[PolyLog[2, (-1)^(1/3)]])/(75106047186519573243485898432000*
           Sqrt[3]) + (1105161961*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (248214468622837624579616106349541*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(340554721179871205607600*Sqrt[3]) + 
         (248214468622837624579616106349541*Pi*Log[3]^2)/
          (16346626616633817869164800*Sqrt[3]) - 
         (2068453767605226006793973813347746316697*PolyGamma[2, 1])/
          116713588406946516489600 + 
         (14365749553189405042148631493807663756117087*Zeta[3])/
          993057566960504435551761600) + CF*Log[x]*
        ((-885432934717085596324504338107300064592507247*NM*NC)/
          4825837923291066764475993600 - (717814680585029*lm*NM*NC)/
          31505760 - 3866310*lm^2*NM*NC - (218462605392700469761*NC*NL)/
          1965014251200 - (717814680585029*lm*NC*NL)/31505760 - 
         3866310*lm^2*NC*NL - 
         (29152135818038531045380234415610674001144783925727*NC*NH)/
          14603133940794938789346206456784884160000 - 
         (717814680585029*lm*NC*NH)/31505760 - 3866310*lm^2*NC*NH - 
         (15984707870366974151*NM*NC*Pi^2)/810 - (2421777449*NC*NL*Pi^2)/
          243 + (169623600441448032306076748*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(50031545098999707*Sqrt[3]) + 
         CF*NC*
          (307549993164389614500973460221940315587288241428854035896263204594\
1/7305944989952919717322149221088186188271168000000 - (589236365920229*lm)/
            1166880 - 104390370*lm^2 + (41277813718223620822676993*Pi^2)/
            827026200 + (248214468622837624579616106349541*
             Im[PolyLog[2, (-1)^(1/3)]])/(510832081769806808411400*Sqrt[3]) - 
           30930480*Zeta[3]) + CA*NC*(-15377499651950332071742585223809713145\
84199072005276174335090786983/
            7305944989952919717322149221088186188271168000000 + 
           (872846906879429*lm)/5728320 + 21264705*lm^2 - 
           (41277813709346140401906031*Pi^2)/1654052400 - 
           (248214468622837624579616106349541*Im[PolyLog[2, (-1)^(1/3)]])/
            (1021664163539613616822800*Sqrt[3]) + 15465240*Zeta[3])), 
      (-172458134779910651629432500178798347675785787944878552967473654314395\
57012042773*CF^2*NC)/
        197813327586449693057640625349669987772768858042722198400000000 - 
       (1451227391781275245*CF^2*lm*NC)/27799515744 - 
       (132414021*CF^2*lm^2*NC)/4 - 
       (159052007388913305011245796746099723213908787993022863698959*CF*NM*
         NC)/203253208028471515516110295297296065280000 - 
       (2422614441347956993*CF*lm*NM*NC)/750586925088 - 
       (4904223*CF*lm^2*NM*NC)/4 + (1543725462238596092551591967*CF*NC*NL)/
        19474668311379240960 - (2422614441347956993*CF*lm*NC*NL)/
        750586925088 - (4904223*CF*lm^2*NC*NL)/4 + 
       (15175242470904038261885532346628674347459783843945046268092192603*CF*
         NC*NH)/4649781455872355716228257045299876306582096915854080000 - 
       (2422614441347956993*CF*lm*NC*NH)/750586925088 - 
       (4904223*CF*lm^2*NC*NH)/4 + (11746382252165161502017843279232279*CF^2*
         NC*Pi^2)/472329340219376640 + 64980*CF^2*lm*NC*Pi^2 + 
       (64393830895108135524008447*CF*NM*NC*Pi^2)/165405240 + 
       (7220*CF*lm*NM*NC*Pi^2)/3 - (6914471494213*CF*NC*NL*Pi^2)/1837836 + 
       (7220*CF*lm*NC*NL*Pi^2)/3 + (7220*CF*lm*NC*NH*Pi^2)/3 - 
       (1122018587885047285040608807013167*CF^2*NC*Pi^3)/
        (18915382227819132105747840*Sqrt[3]) - 
       (22246552486669785819260249555*CF*NC*NH*Pi^3)/(48630661836227715204*
         Sqrt[3]) - (3997626923*CF^2*NC*Pi^4)/3600 + 
       (82052819851704853333539103597754166152921*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(112659070779779359865228847648000*
         Sqrt[3]) + (200901353791930319198194040517151*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(121698231245159857298010*Sqrt[3]) - 
       (560282963*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (1122018587885047285040608807013167*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(510832081769806808411400*
         Sqrt[3]) - (2542463141333689807915457092*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) - (1122018587885047285040608807013167*CF^2*NC*Pi*Log[3]^2)/
        (24519939924950726803747200*Sqrt[3]) - 
       (635615785333422451978864273*CF*NC*NH*Pi*Log[3]^2)/
        (1801135623563989452*Sqrt[3]) + 
       CF*((94285691864548737863579761885856178931*CF*NC)/
          315940533375907440000 - 2272068564*CF*lm*NC + 
         CA*(-50769219050941409942226643923188338829/340243651327900320000 + 
           (4165459034*lm)/9)*NC + (227681582271251589124544598237283*NM*NC)/
          48736199101590 - (757356188*lm*NM*NC)/9 - (44392817672*NC*NL)/
          405 - (757356188*lm*NC*NL)/9 - (1136141741061699055543*NC*NH)/
          48736199101590 - (757356188*lm*NC*NH)/9)*Log[x]^2 + 
       (8*CF*NC*(-204262121531952228693323*CA + 408524203199338581990231*CF + 
          1276275*(4323391606559903182*NM + 189339047*NL))*Log[x]^3)/
        34459425 + (573206862410596673647207386377788263389*CF^2*NC*
         PolyGamma[2, 1])/29178397101736629122400 + 
       (157479812741496133522*CF*NM*NC*PolyGamma[2, 1])/675 - 
       (47863523212674567449592420403*CF*NC*NH*PolyGamma[2, 1])/
        405255515301897626700 - (2883799840087303389988486726833504612679*
         CF^2*NC*Zeta[3])/354663416771608726982772 - 
       (117379534702659954806*CF*NM*NC*Zeta[3])/675 - 
       (862006478*CF*NC*NL*Zeta[3])/9 + (199299137731564461313419818597*CF*
         NC*NH*Zeta[3])/202627757650948813350 + 
       CA*CF*NC*(492737527383258097894558409626081284674801384591303078223866\
4690162288967755203/
          113036187192256967461508928771239993013010776024412684800000000 + 
         (53946453*lm^2)/8 - (15455766118597246015293652907163557*Pi^2)/
          1242971947945728000 + (1122018587885047285040608807013167*Pi^3)/
          (37830764455638264211495680*Sqrt[3]) + (4011489323*Pi^4)/7200 + 
         lm*(3593856242739362737/136470350016 - (39710*Pi^2)/3) - 
         (82052819851704853333539103597754166152921*
           Im[PolyLog[2, (-1)^(1/3)]])/(225318141559558719730457695296000*
           Sqrt[3]) + (560282963*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (1122018587885047285040608807013167*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1021664163539613616822800*
           Sqrt[3]) + (1122018587885047285040608807013167*Pi*Log[3]^2)/
          (49039879849901453607494400*Sqrt[3]) - 
         (573206862410596673647207386377788263389*PolyGamma[2, 1])/
          58356794203473258244800 + 
         (36047498539522439302818753584590246618133*Zeta[3])/
          8866585419290218174569300) + CF*Log[x]*
        ((7062794561961744220876260222556043393766300389*NM*NC)/
          2815072121919788945944329600 - (27118767906437*lm*NM*NC)/765765 - 
         5799465*lm^2*NM*NC - (7089998837121041731051*NC*NL)/
          39736954857600 - (27118767906437*lm*NC*NL)/765765 - 
         5799465*lm^2*NC*NL - 
         (214070161810427525619063688881029556550045821040633*NC*NH)/
          64399820678905680061016770474421339145600 - 
         (27118767906437*lm*NC*NH)/765765 - 5799465*lm^2*NC*NH + 
         (8646783213588789767*NM*NC*Pi^2)/27 - (430873279*NC*NL*Pi^2)/27 + 
         (2542463141333689807915457092*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CF*NC*
          (787048649873902076076280210214518088520097648093363724346894144361/
            10958917484929379575983223831632279282406752000000 - 
           (134586101105697*lm)/170170 - 156585555*lm^2 + 
           (3735078766751949394478113*Pi^2)/157528800 + 
           (1122018587885047285040608807013167*Im[PolyLog[2, (-1)^(1/3)]])/
            (1532496245309420425234200*Sqrt[3]) - 46395720*Zeta[3]) + 
         CA*NC*
          (-60542203602531961462026736229208224219774137634979192699188799097/
            1685987305373750703997419051020350658831808000000 + 
           (32770984490087*lm)/139230 + (63794115*lm^2)/2 - 
           (1245026254545767914208507*Pi^2)/105019200 - 
           (1122018587885047285040608807013167*Im[PolyLog[2, (-1)^(1/3)]])/
            (3064992490618840850468400*Sqrt[3]) + 23197860*Zeta[3])), 
      (-226114790902207820326991826901693661250248558767576880461761990016880\
8519347146677*CF^2*NC)/
        1643372259948966680786552887520335283035310512970307494400000000 - 
       (4486295056416031116473*CF^2*lm*NC)/90070431010560 - 
       (263288415*CF^2*lm^2*NC)/8 + 
       (6515902777068687340201110117228912818491308677138346634435993*CF*NM*
         NC)/12195192481708290930966617717837763916800000 - 
       (7615291718663299328873*CF*lm*NM*NC)/2431901637285120 - 
       (87762805*CF*lm^2*NM*NC)/72 + (141427353112634273445824047123*CF*NC*
         NL)/1752720148024131686400 - (7615291718663299328873*CF*lm*NC*NL)/
        2431901637285120 - (87762805*CF*lm^2*NC*NL)/72 + 
       (40796852818662711454975207414224188227099512066168939624620942623597*
         CF*NC*NH)/
        12554409930855360433816294022309666027771661672806016000000 - 
       (7615291718663299328873*CF*lm*NC*NH)/2431901637285120 - 
       (87762805*CF*lm^2*NC*NH)/72 + (2363606891727634136109122722530674701*
         CF^2*NC*Pi^2)/3269972355364915200 + (976505*CF^2*lm*NC*Pi^2)/18 - 
       (25413178587428995842481817*CF*NM*NC*Pi^2)/82702620 + 
       (976505*CF*lm*NM*NC*Pi^2)/486 - (733375877128553*CF*NC*NL*Pi^2)/
        198486288 + (976505*CF*lm*NC*NL*Pi^2)/486 + 
       (976505*CF*lm*NC*NH*Pi^2)/486 - (4952792087593321732356370066710299*
         CF^2*NC*Pi^3)/(78571587715556394900798720*Sqrt[3]) - 
       (580997860799586386952858565265*CF*NC*NH*Pi^3)/
        (1313027869578148310508*Sqrt[3]) - (210047799403*CF^2*NC*Pi^4)/
        194400 + (52624135150145275910849013658503128003851*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(66852635407781158601344590912000*
         Sqrt[3]) + (387868672042583577467356117068083*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(298713840329028740640570*Sqrt[3]) - 
       (10073653681*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
       (707541726799045961765195723815757*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(303131125445819424771600*
         Sqrt[3]) - (66399755519952729937469550316*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) - (707541726799045961765195723815757*CF^2*NC*Pi*Log[3]^2)/
        (14550294021399332389036800*Sqrt[3]) - 
       (16599938879988182484367387579*CF*NC*NH*Pi*Log[3]^2)/
        (48630661836227715204*Sqrt[3]) + 
       CF*((79683097299002897091725326577532576846329*CF*NC)/
          9186578585853308640000 - (6838718146*CF*lm*NC)/3 + 
         CA*(-1035880265115122256601945369428667394546537/
            238851043232186024640000 + (37612949803*lm)/81)*NC - 
         (862608750914318152855304115327025*NM*NC)/233933755687632 - 
         (6838718146*lm*NM*NC)/81 - (14874330557*NC*NL)/135 - 
         (6838718146*lm*NC*NL)/81 - (46294028165746332423979*NC*NH)/
          1949447964063600 - (6838718146*lm*NC*NH)/81)*Log[x]^2 + 
       (CF*NC*(-486108219082507626803530947*CA + 
          1768*(549896173303330452831513*CF - 3850*(59577892749463662117*
               NM - 3419359073*NL)))*Log[x]^3)/413513100 + 
       (9864098261373412256738894025568864429261499*CF^2*NC*PolyGamma[2, 1])/
        23634501652406669589144000 - (5139885956444738684641*CF*NM*NC*
         PolyGamma[2, 1])/32400 - (20194397974798501872959358347861*CF*NC*NH*
         PolyGamma[2, 1])/236345016524066695891440 - 
       (1318082385957683497136690562002084320964537281*CF^2*NC*Zeta[3])/
        3867195332875041311523687000 + (2803833088298727078559*CF*NM*NC*
         Zeta[3])/16200 - (7797582881*CF*NC*NL*Zeta[3])/81 + 
       (127299604006228753033738371405739*CF*NC*NH*Zeta[3])/
        118172508262033347945720 + CA*CF*NC*(14697461407703435055137985455925\
489608098730872625979250824924814994708541704558213/
          21363839379336566850225187537764358679459036668613997427200000000 + 
         (965390855*lm^2)/144 - (622001813609390060693120731079115323*Pi^2)/
          1721038081771008000 + (4952792087593321732356370066710299*Pi^3)/
          (157143175431112789801597440*Sqrt[3]) + (70224254201*Pi^4)/129600 + 
         lm*(11388053244435125116073/442163934051840 - (10741555*Pi^2)/972) - 
         (52624135150145275910849013658503128003851*
           Im[PolyLog[2, (-1)^(1/3)]])/(133705270815562317202689181824000*
           Sqrt[3]) + (10073653681*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 + 
         (707541726799045961765195723815757*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(606262250891638849543200*Sqrt[3]) + 
         (707541726799045961765195723815757*Pi*Log[3]^2)/
          (29100588042798664778073600*Sqrt[3]) - 
         (9864098261373412256738894025568864429261499*PolyGamma[2, 1])/
          47269003304813339178288000 + 
         (659041193184974955177383366936028258476220383*Zeta[3])/
          3867195332875041311523687000) + CF*Log[x]*
        ((-342180867672377476920460307158790928320598553*NM*NC)/
          156683049457502167677792000 - (5777083206463861*lm*NM*NC)/
          165405240 - (11813725*lm^2*NM*NC)/2 - 
         (127225208471185407026159*NC*NL)/715265187436800 - 
         (5777083206463861*lm*NC*NL)/165405240 - (11813725*lm^2*NC*NL)/2 - 
         (25414847120266962499936858326610491575674224974909533*NC*NH)/
          7903614356047515280215694558224437076960000 - 
         (5777083206463861*lm*NC*NH)/165405240 - (11813725*lm^2*NC*NH)/2 - 
         (6619765860530754803*NM*NC*Pi^2)/27 - (7795629871*NC*NL*Pi^2)/
          486 + (66399755519952729937469550316*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12157665459056928801*Sqrt[3]) + 
         CF*NC*(2204580368225193574398945033960201151072183958576244182387038\
58791457/45521657245091269007930314377549467788458816000000 - 
           (4745777974256611*lm)/6126120 - (318970575*lm^2)/2 + 
           (299143519344869893126129523*Pi^2)/508939200 + 
           (707541726799045961765195723815757*Im[PolyLog[2, (-1)^(1/3)]])/
            (909393376337458274314800*Sqrt[3]) - 47254900*Zeta[3]) + 
         CA*NC*(-286595447853281116856882944789932343072588244315304129359243\
6066145341/1183563088372372994206188173816286162499929216000000 + 
           (7020570854866861*lm)/30073680 + (129950975*lm^2)/4 - 
           (299143519336110508555157411*Pi^2)/1017878400 - 
           (707541726799045961765195723815757*Im[PolyLog[2, (-1)^(1/3)]])/
            (1818786752674916548629600*Sqrt[3]) + 23627450*Zeta[3])), 
      (-288149728435682089517472643773742370754184553925197064456338712909744\
598540442119*CF^2*NC)/
        381497131773867265182592634602934976418911369082392811200000000 - 
       (7642534528393082717*CF^2*lm*NC)/102120670080 - 
       (189845397*CF^2*lm^2*NC)/4 - 
       (4347070581464022719988231691130599944663976142250007662000161*CF*NM*
         NC)/483936209591598846466929274517371584000000 - 
       (12758585138276816237*CF*lm*NM*NC)/2757258092160 - 
       (7031311*CF*lm^2*NM*NC)/4 + (1690169019490515167784775451*CF*NC*NL)/
        13137673067200281600 - (12758585138276816237*CF*lm*NC*NL)/
        2757258092160 - (7031311*CF*lm^2*NC*NL)/4 + 
       (881214314059203275690441758290176523619831481168499379553827208630383\
9*CF*NC*NH)/1700316915047103133834483265005485329691759301370703552000000 - 
       (12758585138276816237*CF*lm*NC*NH)/2757258092160 - 
       (7031311*CF*lm^2*NC*NH)/4 + (107912991016085235847235098877512433*
         CF^2*NC*Pi^2)/607280580282055680 + 88445*CF^2*lm*NC*Pi^2 + 
       (103716717976105166790468557*CF*NM*NC*Pi^2)/23629320 + 
       (88445*CF*lm*NM*NC*Pi^2)/27 - (26836449140419*CF*NC*NL*Pi^2)/
        4725864 + (88445*CF*lm*NC*NL*Pi^2)/27 + (88445*CF*lm*NC*NH*Pi^2)/
        27 - (4355637628717698377009737714194619*CF^2*NC*Pi^3)/
        (46428665468283324259562880*Sqrt[3]) - 
       (953926939236602967668767604905*CF*NC*NH*Pi^3)/
        (1313027869578148310508*Sqrt[3]) - (18235466809*CF^2*NC*Pi^4)/10800 + 
       (44806651678828446484717810636107330103511*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(39503830013688866446249076448000*
         Sqrt[3]) + (8754100979892982498555825021089341*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3285852243619316147046270*Sqrt[3]) - 
       (7576802387*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (622233946959671196715676816313517*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(179122937763438751001400*
         Sqrt[3]) - (109020221627040339162144869132*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) - (622233946959671196715676816313517*CF^2*NC*Pi*Log[3]^2)/
        (8597901012645060048067200*Sqrt[3]) - 
       (27255055406760084790536217283*CF*NC*NH*Pi*Log[3]^2)/
        (48630661836227715204*Sqrt[3]) + 
       CF*((6063361162705947554928421651006936004959*CF*NC)/
          2843464800383166960000 - 3632986770*CF*lm*NC + 
         CA*(-6063361172195956182957902999366436375979/
            5686929600766333920000 + (6660475745*lm)/9)*NC + 
         (2444787658438155210165481237523779*NM*NC)/46415427715800 - 
         (1210995590*lm*NM*NC)/9 - (14188967611*NC*NL)/81 - 
         (1210995590*lm*NC*NL)/9 - (154125748740374257579981*NC*NH)/
          4007198592797400 - (1210995590*lm*NC*NH)/9)*Log[x]^2 + 
       (CF*NC*(-10723389703390205499615537*CA + 
          8*(2680847368299213140169323*CF + 3828825*(13981690632448319596*
               NM + 86499685*NL)))*Log[x]^3)/29536650 + 
       (371680873895546152197167126413486009384111*CF^2*NC*PolyGamma[2, 1])/
        2363450165240666958914400 + (1578922307813484824201*CF*NM*NC*
         PolyGamma[2, 1])/600 - (109961027830939962831153722725459*CF*NC*NH*
         PolyGamma[2, 1])/590862541310166739728600 - 
       (69707436071115844588334167136098437015586009*CF^2*NC*Zeta[3])/
        1436386837925015344280226600 - (596007345786739038799*CF*NM*NC*
         Zeta[3])/300 - (1368958360*CF*NC*NL*Zeta[3])/9 + 
       (456409345844781681159376866708941*CF*NC*NH*Zeta[3])/
        295431270655083369864300 + CA*CF*NC*(67799936088159630081929825072791\
374082850963293620000624433503023723340138471653/
          179528062011231654203573004519028224197134761921126028800000000 + 
         (77344421*lm^2)/8 - (141990777647538881797083590908999859*Pi^2)/
          1598106790215936000 + (4355637628717698377009737714194619*Pi^3)/
          (92857330936566648519125760*Sqrt[3]) + (2032452401*Pi^4)/2400 + 
         lm*(18927220323399786797/501319653120 - (972895*Pi^2)/54) - 
         (44806651678828446484717810636107330103511*
           Im[PolyLog[2, (-1)^(1/3)]])/(79007660027377732892498152896000*
           Sqrt[3]) + (7576802387*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 + 
         (622233946959671196715676816313517*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(358245875526877502002800*Sqrt[3]) + 
         (622233946959671196715676816313517*Pi*Log[3]^2)/
          (17195802025290120096134400*Sqrt[3]) - 
         (371680873895546152197167126413486009384111*PolyGamma[2, 1])/
          4726900330481333917828800 + 
         (69707436346466669117478542438080953984480331*Zeta[3])/
          2872773675850030688560453200) + CF*Log[x]*
        ((276665168949135026772300153594709719519528863*NM*NC)/
          9915018744434308769880000 - (14081206301945*lm*NM*NC)/262548 - 
         8756055*lm^2*NM*NC - (543685366735613086037*NC*NL)/1930080664512 - 
         (14081206301945*lm*NC*NL)/262548 - 8756055*lm^2*NC*NL - 
         (157067558476405786319552783072416025161364771957144167453*NC*NH)/
          29755132146929883151192036088075449485485160000 - 
         (14081206301945*lm*NC*NH)/262548 - 8756055*lm^2*NC*NH + 
         (97871834427936122393*NM*NC*Pi^2)/27 - (684302290*NC*NL*Pi^2)/27 + 
         (109020221627040339162144869132*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (12157665459056928801*Sqrt[3]) + 
         CF*NC*
          (799440205419213843776764063126519136530603278244506693501064735474\
1/42270110299013321221649577636295934374997472000000 - (11654605755575*lm)/
            9724 - 236413485*lm^2 + (85787117497387175013351359*Pi^2)/
            472586400 + (622233946959671196715676816313517*
             Im[PolyLog[2, (-1)^(1/3)]])/(537368813290316253004200*Sqrt[3]) - 
           70048440*Zeta[3]) + CA*NC*(-79944020358804901351787754001164363222\
98257325547528437940002081141/
            84540220598026642443299155272591868749994944000000 + 
           (17007059592305*lm)/47736 + (96316605*lm^2)/2 - 
           (85787117482603208850987103*Pi^2)/945172800 - 
           (622233946959671196715676816313517*Im[PolyLog[2, (-1)^(1/3)]])/
            (1074737626580632506008400*Sqrt[3]) + 35024220*Zeta[3])), 
      (-945974299610326165906557927493185964157748306658891862347247557812619\
101216416808427*CF^2*NC)/
        57987564029627824307754080459646116415674528100523707302400000000 - 
       (2764137453127190773561*CF^2*lm*NC)/39034124363520 - 
       (374289615*CF^2*lm^2*NC)/8 + 
       (136594704952375775869701773688778176419049184384755567269137987*CF*
         NM*NC)/20325320802847151551611029529729606528000000 - 
       (4691854676861887968361*CF*lm*NM*NC)/1053921357815040 - 
       (41587735*CF*lm^2*NM*NC)/24 + (1391734018927371591697178476411817*CF*
         NC*NL)/10756443548424096159436800 - 
       (4691854676861887968361*CF*lm*NC*NL)/1053921357815040 - 
       (41587735*CF*lm^2*NC*NL)/24 + (14435148928120102363010811906971178778\
797951762587256177499526530344301*CF*NC*NH)/
        2826304561011629209129318849386895614687635460945080570880000 - 
       (4691854676861887968361*CF*lm*NC*NH)/1053921357815040 - 
       (41587735*CF*lm^2*NC*NH)/24 + 
       (321599353295382059747201351675506610183*CF^2*NC*Pi^2)/
        38461103417863526400 + (1320305*CF^2*lm*NC*Pi^2)/18 - 
       (34819961472076882596029063429*CF*NM*NC*Pi^2)/9428098680 + 
       (1320305*CF*lm*NM*NC*Pi^2)/486 - (175036465908001*CF*NC*NL*Pi^2)/
        31691088 + (1320305*CF*lm*NC*NL*Pi^2)/486 + 
       (1320305*CF*lm*NC*NH*Pi^2)/486 - 
       (173855355595951860680755335138361303*CF^2*NC*Pi^3)/
        (1764289287794766321863389440*Sqrt[3]) - 
       (152348435982776300632731480485*CF*NC*NH*Pi^3)/(218837978263024718418*
         Sqrt[3]) - (316621952003*CF^2*NC*Pi^4)/194400 + 
       (4942377206158477808621915696111595507519419*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4074537895697623082027404742208000*
         Sqrt[3]) + (6510755115806125932140655995140153*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(3103304896751576361099255*Sqrt[3]) - 
       (14987237881*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 - 
       (24836479370850265811536476448337329*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(6806671635010672538053200*
         Sqrt[3]) - (34822499653206011573195766968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1350851717672992089*
         Sqrt[3]) - (24836479370850265811536476448337329*CF^2*NC*Pi*Log[3]^2)/
        (326720238480512281826553600*Sqrt[3]) - 
       (4352812456650751446649470871*CF*NC*NH*Pi*Log[3]^2)/
        (8105110306037952534*Sqrt[3]) + 
       CF*((32525754591771219283079472616321377249991129*CF*NC)/
          324154987243681033440000 - (10818404680*CF*lm*NC)/3 + 
         CA*(-32525754592752075446105113451284884982551949/
            648309974487362066880000 + (59501225740*lm)/81)*NC - 
         (5082157717863348167447320231433299*NM*NC)/114673409650800 - 
         (10818404680*lm*NM*NC)/81 - (23515557328*NC*NL)/135 - 
         (10818404680*lm*NC*NL)/81 - (62057087458273413481499*NC*NH)/
          1602879437118960 - (10818404680*lm*NC*NH)/81)*Log[x]^2 + 
       (CF*NC*(-15340105994583585095226353299*CA + 
          304*(100921749908413834374770662*CF - 
            60775*(722398433039252968611*NM - 5409202340*NL)))*Log[x]^3)/
        1122392700 + (344244879538194060647299667871266957044690477*CF^2*NC*
         PolyGamma[2, 1])/70903504957220008767432000 - 
       (12766984221699520433987*CF*NM*NC*PolyGamma[2, 1])/6480 - 
       (474193644416024748256256804800469*CF*NC*NH*PolyGamma[2, 1])/
        3545175247861000438371600 - 
       (15576102100174243198598212769506545744777768412*CF^2*NC*Zeta[3])/
        3936252392390667049229467125 + (6496973996334118440973*CF*NM*NC*
         Zeta[3])/3240 - (12251969015*CF*NC*NL*Zeta[3])/81 + 
       (2967010524974541771252224214117931*CF*NC*NH*Zeta[3])/
        1772587623930500219185800 + CA*CF*NC*(1299415246706294547290570180088\
998969476092737121627413989653521348947307539694759/
          159306494586889627219104616647379440702402549726713481600000000 + 
         (457465085*lm^2)/48 - (535998922158618501862069779346073485633*Pi^2)/
          128203678059545088000 + (173855355595951860680755335138361303*Pi^3)/
          (3528578575589532643726778880*Sqrt[3]) + (317466947203*Pi^4)/
          388800 + lm*(7016183578207073102761/191622065057280 - 
           (14523355*Pi^2)/972) - 
         (4942377206158477808621915696111595507519419*
           Im[PolyLog[2, (-1)^(1/3)]])/(8149075791395246164054809484416000*
           Sqrt[3]) + (14987237881*Im[PolyLog[2, (-1)^(1/3)]]^2)/180 + 
         (24836479370850265811536476448337329*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(13613343270021345076106400*
           Sqrt[3]) + (24836479370850265811536476448337329*Pi*Log[3]^2)/
          (653440476961024563653107200*Sqrt[3]) - 
         (344244879538194060647299667871266957044690477*PolyGamma[2, 1])/
          141807009914440017534864000 + 
         (124608816806635013753684839598469732540312940331*Zeta[3])/
          62980038278250672787671474000) + CF*Log[x]*
        ((-3594633055826001694746308826821155087043530308623*NM*NC)/
          140753606095989447297216480000 - (1383551662378229*lm*NM*NC)/
          26409240 - (17665725*lm^2*NM*NC)/2 - (64221596584681274981231863*
           NC*NL)/231030655542086400 - (1383551662378229*lm*NC*NL)/
          26409240 - (17665725*lm^2*NC*NL)/2 - 
         (8027835994226104160207058488144505082267503613256936431*NC*NH)/
          1586940381169593768063575258030690639225875200 - 
         (1383551662378229*lm*NC*NH)/26409240 - (17665725*lm^2*NC*NH)/2 - 
         (240799477677139002442*NM*NC*Pi^2)/81 - (12249328405*NC*NL*Pi^2)/
          486 + (34822499653206011573195766968*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(4052555153018976267*Sqrt[3]) + 
         CF*NC*(8848768753482642967881218320503997788207688018816282263099879\
6427255457/1606264191362506206422683950179245506249903936000000 - 
           (1137323077525979*lm)/978120 - (476974575*lm^2)/2 + 
           (9440065227046472881482386351*Pi^2)/1381406400 + 
           (24836479370850265811536476448337329*Im[PolyLog[2, (-1)^(1/3)]])/
            (20420014905032017614159600*Sqrt[3]) - 70662900*Zeta[3]) + 
         CA*NC*(-884876875341578319935759921362492005904408914678951443034461\
91624828257/3212528382725012412845367900358491012499807872000000 + 
           (1680439716841229*lm)/4801680 + (194322975*lm^2)/4 - 
           (116544015148262189096237327*Pi^2)/34108800 - 
           (24836479370850265811536476448337329*Im[PolyLog[2, (-1)^(1/3)]])/
            (40840029810064035228319200*Sqrt[3]) + 35331450*Zeta[3]))}, 0, 
     39, 1]
 
CbarSeries["a", 2, 3, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-(CA*(-5812371437295686 + 17179996323840*lm + 
            5722472448000*lm^2 + 4844322911356425*Zeta[3])) + 
         2*(2083529293824*NL + 899713597440*lm*NL + 520224768000*lm^2*NL - 
           6556055583770*NH + 899713597440*lm*NH + 520224768000*lm^2*NH + 
           35*CF*(1113566829377534 + 270453178368*lm + 401316249600*lm^2 - 
             926273866011165*Zeta[3]) + 5106884682375*NH*Zeta[3] + 
           35*NM*(-187315873822 + 25706102784*lm + 14863564800*lm^2 + 
             145910990925*Zeta[3]))))/7865798492160000, 
      -(CF*NC*(-3*CA*(-1935548257284802 + 6998325985280*lm + 
            1907490816000*lm^2 + 1614774303785475*Zeta[3]) + 
          2*(2383433826304*NL + 1246530109440*lm*NL + 520224768000*lm^2*
             NL - 9792292768930*NH + 1246530109440*lm*NH + 
            520224768000*lm^2*NH + 35*CF*(1113656980436990 + 
              537997344768*lm + 401316249600*lm^2 - 926273866011165*Zeta[
                3]) + 7633484593875*NH*Zeta[3] + 35*NM*(-77714552390 + 
              35615145984*lm + 14863564800*lm^2 + 73722422025*Zeta[3]))))/
       2621932830720000, 
      (CF*NC*(-(CA*(-36959155694285626786 + 27002236690759680*lm + 
            6489283756032000*lm^2 + 30767638162334958675*Zeta[3])) + 
         2*(9*CF*(44156521893225532142 + 3243640569200640*lm + 
             1769804660736000*lm^2 - 36732834420196097925*Zeta[3]) + 
           2*(131072*(11954755327 + 6499948770*lm + 2250423000*lm^2)*NL + 
             315*NH*(-25789809214778 + 2704639000576*lm + 936404582400*
                lm^2 + 20397340229175*Zeta[3]) + 315*NM*(2704639000576*lm + 
               936404582400*lm^2 + 35*(-9416824222 + 63023453325*
                  Zeta[3]))))))/1699012474306560000, 
      -(CF*NC*(1808766432783450*NM + 2540524756008960*lm*NM + 
          786579849216000*lm^2*NM + 4787772324315136*NL + 
          2540524756008960*lm*NL + 786579849216000*lm^2*NL - 
          30872834605614330*NH + 2540524756008960*lm*NH + 
          786579849216000*lm^2*NH + 36*CF*(40882165382240240102 + 
            1282684519710720*lm + 589934886912000*lm^2 - 34009589254123272825*
             Zeta[3]) + 1306457161529625*NM*Zeta[3] + 24767070240252375*NH*
           Zeta[3] - 10*CA*(-6514340536137501026 + 1947894510256128*lm + 
            432618917068800*lm^2 + 5421066008269900275*Zeta[3])))/
       849506237153280000, 
      (CF*NC*(-1936*CA*(-15364617248898583306646 + 1636477964668108800*lm + 
           347640201216000000*lm^2 + 12783560040335574036225*Zeta[3]) + 
         5*(167099849080542593024*NL + 84059486683681259520*lm*NL + 
           24473870165606400000*lm^2*NL - 1343798468810263973430*NH + 
           84059486683681259520*lm*NH + 24473870165606400000*lm^2*NH + 
           352*CF*(467655061994567101304758 + 4466195570282987520*lm + 
             1877257086566400000*lm^2 - 389043499071590554989105*Zeta[3]) + 
           1090203181118995568625*NH*Zeta[3] + 693*NM*(91418019896767762 + 
             121297960582512640*lm + 35315829964800000*lm^2 + 
             102681791133646725*Zeta[3]))))/117592051371705630720000, 
      -(CF*NC*(176*CF*(14840294511839503971358994 + 45863918038752952320*lm + 
            18697480582201344000*lm^2 - 12345727572968459103524475*Zeta[3]) - 
          6776*CA*(-12237324604968787544486 + 472999687885946880*lm + 
            98928468688896000*lm^2 + 10180828235509117299225*Zeta[3]) + 
          7*(4194304*(31021072079501 + 14564506550220*lm + 4151203749000*lm^
                2)*NL + 33*NM*(-178940110183648394 + 1851150547927695360*
               lm + 527618499674112000*lm^2 + 3557416769799267375*Zeta[3]) + 
            99*NH*(-13330163087572985214 + 617050182642565120*lm + 
              175872833224704000*lm^2 + 10903896340832620125*Zeta[3]))))/
       117592051371705630720000, 
      (CF*NC*(1872*CF*(430631842597838500754744297294 + 
           412748376446109273292800*lm + 172527731936770129920000*lm^2 - 
           358245612241335055852304815125*Zeta[3]) - 
         88*CA*(-254789098374626315992979075662 + 3529247505840654306508800*
            lm + 747620171726003896320000*lm^2 + 
           211964936600193972288391423125*Zeta[3]) + 
         35*(134217728*(20276930764870433 + 8779699201733460*lm + 
             2546379129294000*lm^2)*NL + 1287*NH*(915610939689260810240*
              lm + 265554950552027136000*lm^2 + 11583*(-2382247289218997994 + 
               1960110600214141375*Zeta[3])) + 2145*NM*
            (549366563813556486144*lm + 159332970331216281600*lm^2 + 
             143*(-9895551681792796678 + 16829084319317094825*Zeta[3])))))/
       12718756276363681018675200000, 
      -(CF*NC*(832*CF*(5011034782554786769042199023418 + 
            1421537816215047005798400*lm + 651719583413965946880000*lm^2 - 
            4168716248363447948268214488375*Zeta[3]) - 
          352*CA*(-291746774383443059423255171306 + 1415038122397573683609600*
             lm + 313790910532650270720000*lm^2 + 
            242707946150711670417771357375*Zeta[3]) + 
          5*(1073741824*(30778903617048161 + 12107704551562620*lm + 
              3740679151209000*lm^2)*NL + 429*NM*
             (-273195649012983785832782 + 30304309486358856990720*lm + 
              9362526001906581504000*lm^2 + 309347928986285567503125*Zeta[
                3]) + 1287*NH*(-444475578294039366873942 + 
              10101436495452952330240*lm + 3120842000635527168000*lm^2 + 
              367227416537217177566625*Zeta[3]))))/
       25437512552727362037350400000, 
      (CF*NC*(-143*CA*(-2916150516295248351593082468021598 + 
           4727072472775531854770995200*lm + 1150017004057317353717760000*
            lm^2 + 2425972557569528272768313675950125*Zeta[3]) + 
         2*(CF*(9485536758016749168766354239923925118 + 
             719377178128461285456818995200*lm + 
             403655968424118391154933760000*lm^2 - 
             7891087852239313939819940060065468125*Zeta[3]) + 
           455*(60129542144*(4461366854087279 + 1550658961231380*lm + 
               546447345444000*lm^2)*NL + 429*NM*
              (-5917721656216550566526986 + 217343620886558335303680*lm + 
               76591209061426397184000*lm^2 + 5652740052000243014187375*
                Zeta[3]) + 429*NH*(-15075934278756660605243354 + 
               217343620886558335303680*lm + 76591209061426397184000*lm^2 + 
               12491822479126047528846375*Zeta[3])))))/
       48433023900392897319115161600000, 
      -(CF*NC*(6*CF*(1010526876700177523977323418227661354 + 
            15616617552662641042784256000*lm + 13993596649052814547353600000*
             lm^2 - 840664767371317401796857244329033375*Zeta[3]) - 
          715*CA*(-167480974172478503643122586208838 + 
            82389176643706729109913600*lm + 23920678032568913756160000*lm^2 + 
            139328741276904260332079944540425*Zeta[3]) + 
          260*(66*NM*(-35790133883857250923091074 + 393520282799455390924800*
               lm + 181217257822491770880000*lm^2 + 
              31559986013875007529715875*Zeta[3]) + 
            5*(4294967296*(4226013284046787 + 1209431265702660*lm + 
                556946686296000*lm^2)*NL + 3003*NH*(
                -221076335034159564040334 + 1729759484832770949120*lm + 
                796559375043919872000*lm^2 + 183550273554722040091125*
                 Zeta[3])))))/6919003414341842474159308800000, 
      (CF*NC*(306*CF*(3221789070225154891703038147331524270114 + 
           66875699421596796373381939200*lm + 
           14147466917291340198838272000000*lm^2 - 
           2680230108696457617291841299946719097875*Zeta[3]) - 
         99*CA*(-177782198816097298011696758919956460026 + 
           20781668880483600440495387443200*lm + 
           8907664355331584569638912000000*lm^2 + 
           147898331856203479618212236242492716375*Zeta[3]) + 
         35*(4294967296*(6521687903590898988661 + 1130915295763372779660*lm + 
             1066616858728020600000*lm^2)*NL + 328185*NM*
            (-7320134188562285709084665386 + 14800323627983769652166656*lm + 
             13958847983908772904960000*lm^2 + 6221551855261346381277474975*
              Zeta[3]) + 51051*NH*(-36509107987258390052294313302 + 
             95144937608467090621071360*lm + 89735451325127825817600000*
              lm^2 + 30353754787135033415254718625*Zeta[3]))))/
       531891468474114798358522704691200000, 
      -(CF*NC*(3264*CF*(1217418650975976397644788081600139970262 - 
            3219469604929489907605517107200*lm + 
            1591098621702779902875402240000*lm^2 - 
            1012779558267841206344865790106341286625*Zeta[3]) - 
          1056*CA*(-61050563964410939239640125137164758942 + 
            305406885164987480328162508800*lm + 
            1001802835886935494403031040000*lm^2 + 
            50788410495234950203959877851664522125*Zeta[3]) + 
          35*(68719476736*(220069811015053340611 - 77402078623524695040*lm + 
              79971565403597868000*lm^2)*NL + 7293*NH*
             (-484520230213383459064200831886 - 729333654365466636928942080*
               lm + 753545060783497345499136000*lm^2 + 
              403205276153873458881678187125*Zeta[3]) + 
            2431*NM*(-3458336050728261002305318708502 - 
              2188000963096399910786826240*lm + 2260635182350492036497408000*
               lm^2 + 2894044365395922503676184898625*Zeta[3]))))/
       1063782936948229596717045409382400000, 
      (CF*NC*(65664*CF*(337671585211144154519695574204014295205818 - 
           754882108715612281359181440614400*lm + 
           112374993506027115459505029120000*lm^2 - 
           280911482330044688539543379788710200400375*Zeta[3]) - 
         704*CA*(-466610454883515080907413914826873617808018 - 
           9371585479135565142239575906713600*lm + 
           2135124876614515193730595553280000*lm^2 + 
           388176643616856605592483994072010818162875*Zeta[3]) + 
         35*(3023656976384*(-15865573504254464460217 - 
             14621785152801871000320*lm + 2582454541836605436000*lm^2)*NL + 
           29393*NH*(-1504142574233911771328057180160*lm + 
             265657016691688443601747968000*lm^2 + 
             29393*(-10852096435751690334248057554 + 
               9036294954099833268436462875*Zeta[3])) + 
           4199*NM*(-10528998019637382399296400261120*lm + 
             1859599116841819105212235776000*lm^2 + 
             323*(-31096902134759535079400673892634 + 
               25877110264647234201378829434375*Zeta[3])))))/
       3072205121906487075318827142296371200000, 
      CA*CF*NC*((-514289237422963*lm)/142518910886352000 + (87*lm^2)/671840 + 
         (-99586304493423675003537021435603643037534 + 
           82846575323988796577495967858977120398125*Zeta[3])/
          545490966247600688089280387481600000) - 
       (CF*NC*(19456*CF*(2121704391836888819794502307030739305209842 - 
            3030974062313738198235640705843200*lm + 
            100380908339361346711757783040000*lm^2 - 
            1765061529460035364109285477523754320220875*Zeta[3]) + 
          35*(4199*NM*(-17374102766966523692750716435675106 - 
              14341817287120487578043091517440*lm + 
              492183438145543436677152768000*lm^2 + 
              14436271005702532955870053090813875*Zeta[3]) + 
            7*(1099511627776*(-14516009750047753040188 - 
                7824420700882251671205*lm + 268518989257782763500*lm^2)*NL + 
              12597*NH*(-95081754911942452532801968746818 - 
                682943680339070837049671024640*lm + 
                23437306578359211270340608000*lm^2 + 
                79201767848667646168928090023875*Zeta[3])))))/
        3072205121906487075318827142296371200000, 
      -(CF*NC*(-784*CA*(3602233610446879995478277038730258562523022698 + 
            50934139274975388991168370278662144000*lm + 
            1287497861768400598971440116531200000*lm^2 - 
            2996724562996427120951903305583598590998293375*Zeta[3]) + 
          32*CF*(-7054979459580387260050408329257928301933142718134 + 
            5765451198921382101596896706420539392000*lm + 
            154850879192690362949019570379161600000*lm^2 + 
            5869089431277173289586095683308741608811132136625*Zeta[3]) + 
          1155*(12597*NM*(917847762556580902464649533226148162 + 
              482960469696437504999727248179200*lm + 
              12613940440851028379864924160000*lm^2 - 
              762623993336733487182509469572263875*Zeta[3]) + 
            5*(274877906944*(10037961273039279053009257 + 
                4426585682643070504477920*lm + 115613371405488872916000*lm^2)*
               NL + 4199*NH*(289776281817862502999836348907520*lm + 
                7568364264510617027918954496000*lm^2 - 4199*
                 (-7643791459017135085448736105874 + 
                  6368458914568574702773550530875*Zeta[3]))))))/
       9327214750108094760667959204011782963200000, 
      (CF*NC*(-64*CA*(142629173630510801060487064855934923174079173874 + 
           1277977113756928730688363810858310041600*lm + 
           73029237752311794677161390485012480000*lm^2 - 
           118654257756202968957358134921146830887337996875*Zeta[3]) + 
         128*CF*(-6169796093794557412100593681873467731180802468622 + 
           2719499875042018404918900415739933491200*lm + 
           179253583573856223298487049372303360000*lm^2 + 
           5132698859860087359822849649217623236270079987125*Zeta[3]) + 
         1155*(1099511627776*(27972537341645144022486427 + 
             10858381995779871519526560*lm + 669163495923739885068000*lm^2)*
            NL + 4199*NM*(9440688384096859580687685811403037842 + 
             2843276318931540389857297107517440*lm + 
             175221015635005949462427205632000*lm^2 - 
             7846753272889816095255247595320402875*Zeta[3]) + 
           62985*NH*(189551754595436025990486473834496*lm + 
             11681401042333729964161813708800*lm^2 - 
             4199*(-4362925037439207127256672296334 + 
               3635290168293425449881524375925*Zeta[3])))))/
       18654429500216189521335918408023565926400000, 
      -(CF*NC*(-(CA*(121990171473194210177609559875056468892656135953209522 + 
             650213648762051638809795729777046596668620800*lm + 
             50987362211327055774659871546069447868416000*lm^2 - 
             101484521333719261841082560062982390900221381286992875*
              Zeta[3])) + 
          2*(23*CF*(-247502747756359661402393229311504038775629154179999202 + 
              56721413120085044074140147527731159184179200*lm + 
              5441339050220673936426152299382905503744000*lm^2 + 
              205899360627087400288003272644283900172592046950173875*Zeta[
                3]) + 2310*(2199023255552*(29839523396860136648596007483 + 
                10475128355380340447607051240*lm + 
                912489881711514589431748800*lm^2)*NL + 37145*NH*(
                620138668956078714935387338963943424*lm + 
                54020365334217638932210227483770880*lm^2 - 
                7429*(-7445204592168968894489109770624738 + 
                  6203512807765514045975635905114675*Zeta[3])) + 
              66861*NM*(344521482753377063852992966091079680*lm + 
                30011314074565354962339015268761600*lm^2 - 
                529*(-4042298099858638483671951559069517882 + 
                  3360920884385750075865689188928328375*Zeta[3]))))))/
       157891091289829828108587213405511462001049600000, 
      (CF*NC*(-(CA*(17145768910443780234808433521657998663972315659320498 + 
            52315757684338676238308885964532615426867200*lm + 
            4983244444348552070434865575023341469696000*lm^2 - 
            14263691427168246156956486346657629367488976766480875*Zeta[3])) + 
         10*(253*CF*(-680255808795890574291778186710988492874989589225518 + 
             78998245836615575644804688115098462453760*lm + 
             9669249011671642536955901582869581004800*lm^2 + 
             565909822612054808231341256542186517520669787949925*Zeta[3]) + 
           21*(17592186044416*(7044065947286068390334163773 + 
               2262586909128909801736137840*lm + 245250780290821853493145200*
                lm^2)*NL + 7429*NM*
              (65187272216322967038364645417237524254314 + 
               5357901446635609014030814047224463360*lm + 
               580764215158746910339655879412940800*lm^2 - 
               54211964159550122058125108383856162949375*Zeta[3]) + 
             111435*NH*(357193429775707267602054269814964224*lm + 
               38717614343916460689310391960862720*lm^2 - 705755*
                (-43320370358144182028796119914118 + 
                 36093507948208843130007976431465*Zeta[3]))))))/
       14353735571802711646235201218682860181913600000}, 0, 18, 1]
 
CbarSeries["a", 2, 4, "x0"] = SeriesData[x, 0, 
     {-(CF*NC*(3*CF*(-8230118400*lm^2 + 571362336*Pi^2 + 3175200*Pi^4 + 
            30481920*lm*(-544 + 15*Pi^2) + 35*(-231398195 + 60351360*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] - 39191040*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 10058560*PolyGamma[2, 1] - 
              120574976*Zeta[3])) + 12*CA*(314344800*lm^2 - 104019648*Pi^2 + 
            2143260*Pi^4 - 26460*lm*(-53411 + 660*Pi^2) - 
            35*(-35894897 + 7543920*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              4898880*Im[PolyLog[2, (-1)^(1/3)]]^2 - 1257320*PolyGamma[2, 
                1] - 20995024*Zeta[3])) + 
          560*(9*NL*(-503321 - 136080*lm^2 - 13578*Pi^2 + 126*lm*(-3481 + 
                60*Pi^2) - 90720*Zeta[3]) + 9*NM*(-503321 - 136080*lm^2 - 
              13578*Pi^2 + 126*lm*(-3481 + 60*Pi^2) + 7560*PolyGamma[2, 1] - 
              75600*Zeta[3]) + NH*(-15068961 - 1224720*lm^2 + 
              1134*lm*(-3481 + 60*Pi^2) - 329721384*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 54953564*PolyGamma[2, 1] + 605782648*Zeta[
                3]))))/144027072000, 
      -(CF*NC*(CF*(1036994918400*lm^2 - 72311938704*Pi^2 + 2789095680*Pi^4 - 
            342921600*lm*(-2329 + 168*Pi^2) - 35*(-30040388397 + 
              55155145728*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              12227604480*Im[PolyLog[2, (-1)^(1/3)]]^2 - 9800529728*PolyGamma[
                2, 1] - 77107316608*Zeta[3])) - 8*CA*(19803722400*lm^2 - 
            10242608436*Pi^2 + 334348560*Pi^4 - 595350*lm*
             (-108149 + 1848*Pi^2) - 35*(-447418557 + 3447196608*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 764225280*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 612533108*PolyGamma[2, 1] - 
              5358212392*Zeta[3])) - 3920*(NH*(2863018539 - 7348320*lm^2 + 
              2430*lm*(-5983 + 168*Pi^2) + 718018656*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] - 119669776*PolyGamma[2, 1] - 3665289632*Zeta[
                3]) + 81*NL*(85969 - 90720*lm^2 - 8112*Pi^2 + 
              30*lm*(-5983 + 168*Pi^2) - 60480*Zeta[3]) + 
            81*NM*(85969 - 90720*lm^2 - 8112*Pi^2 + 30*lm*(-5983 + 
                168*Pi^2) + 5040*PolyGamma[2, 1] - 50400*Zeta[3]))))/
       1296243648000, (CF*NC*(CF*(-1777705574400*lm^2 - 22772216016*Pi^2 + 
           8560339200*Pi^4 + 121927680*lm*(-9079 + 60*Pi^2) + 
           35*(-55890408915 + 91118022144*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 30412247040*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
             16799588224*PolyGamma[2, 1] - 118719046400*Zeta[3])) - 
         448*CA*(-606236400*lm^2 - 1330992*Pi^2 + 9191070*Pi^4 + 
           1890*lm*(-995563 + 1320*Pi^2) + 5*(-177231537 + 711859548*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 237595680*Im[PolyLog[2, 
                 (-1)^(1/3)]]^2 - 131246783*PolyGamma[2, 1] - 
             991900186*Zeta[3])) + 3360*(NH*(3931911327 - 14696640*lm^2 + 
             504*lm*(-53393 + 120*Pi^2) + 1638312512*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] - 291369940*PolyGamma[2, 1] - 
             6238345640*Zeta[3]) + 3*NM*(6663125 - 4898880*lm^2 - 
             2487888*Pi^2 + 168*lm*(-53393 + 120*Pi^2) - 
             47880*PolyGamma[2, 1] - 337680*Zeta[3]) + 
           3*NL*(2651537 - 4898880*lm^2 - 1520208*Pi^2 + 
             168*lm*(-53393 + 120*Pi^2) - 241920*Zeta[3]))))/432081216000, 
      -(CF*NC*(555532992000*(-14*CA*(76 + 33*lm) + 9*CF*(577 + 336*lm) + 
            28*(5*NM + 3*lm*NM + 5*NL + 3*lm*NL + 3*lm*NH))*Log[x]^2 + 
          15554923776000*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3 - 
          40*CA*(11977291307520*lm^2 - 2525870766429*Pi^2 - 
            31363577000*Sqrt[3]*Pi^3 + 56427106302*Pi^4 - 
            22504230*lm*(-2146811 + 6600*Pi^2) - 24194759400*Sqrt[3]*Pi*
             Log[3]^2 - 7*(-6525116328069 + 4689538496724*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 2748499477920*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 165906921600*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 825307762778*PolyGamma[2, 1] - 
              8686266609076*Zeta[3])) + 211680*Log[x]*
           (4*(6561*NM*(49423 + 39000*lm + 8400*lm^2 + 4200*Pi^2) + 
              6561*NL*(74623 + 39000*lm + 8400*lm^2 + 4200*Pi^2) + 
              NH*(12563210811 + 255879000*lm + 55112400*lm^2 - 7170144800*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            5*CF*(5134428975 + 5451403680*lm + 1587237120*lm^2 - 
              93463632*Pi^2 + 29260480*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              264539520*Zeta[3]) + 4*CA*(-1793121300*lm - 303118200*lm^2 + 
              24942735*Pi^2 - 2*(1635374049 + 9143900*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] + 82668600*Zeta[3]))) + 
          7*(-560*(2187*NL*(-25053647 - 10160640*lm^2 - 4314720*Pi^2 + 
                1050*lm*(-26717 + 120*Pi^2) - 17841600*Zeta[3]) + 
              10935*NM*(1080689 - 2032128*lm^2 - 752064*Pi^2 + 
                210*lm*(-26717 + 120*Pi^2) - 240912*PolyGamma[2, 1] - 
                784224*Zeta[3]) - NH*(-3271429318293 + 22221319680*lm^2 + 
                125477534000*Sqrt[3]*Pi^3 - 2296350*lm*(-26717 + 120*Pi^2) - 
                796979297760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                4646253830400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                96796954800*Sqrt[3]*Pi*Log[3]^2 + 199515242128*PolyGamma[2, 
                  1] + 371694733856*Zeta[3])) + CF*(447981804748800*lm^2 - 
              28552369367088*Pi^2 - 358440880000*Sqrt[3]*Pi^3 + 
              397977662880*Pi^4 - 9258883200*lm*(-75121 + 600*Pi^2) - 
              276511536000*Sqrt[3]*Pi*Log[3]^2 + 5*(107700283796481 - 
                75032615947584*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
                43975991646720*Im[PolyLog[2, (-1)^(1/3)]]^2 - 2654510745600*
                 Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
                13204924204448*PolyGamma[2, 1] + 119096953901248*Zeta[3])))))/
       34998578496000, (-2*CF*NC*(-35*CA*(76 + 33*lm) + 
          3*CF*(4061 + 2520*lm) + 35*(9*NM + 6*lm*NM + 10*NL + 6*lm*NL + 
            6*lm*NH))*Log[x]^2)/105 - 
       (4*CF*NC*(11*CA + 36*CF - 2*(NM + NL))*Log[x]^3)/3 + 
       (CF*NC*Log[x]*(CA*(120797760099 + 62244338220*lm + 10912255200*lm^2 - 
            1272571560*Pi^2 - 3085742960*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
            5952139200*Zeta[3]) - 4*(4146805692*NL + 2198000610*lm*NL + 
            496011600*lm^2*NL + 86824203789*NH + 2198000610*lm*NH + 
            496011600*lm^2*NH + 248005800*NL*Pi^2 + 
            3645*NM*(615995 + 603018*lm + 136080*lm^2 + 76020*Pi^2) - 
            49581232400*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
            CF*(56429866887 + 57551517360*lm + 17856417600*lm^2 - 
              1071608130*Pi^2 - 1542871480*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 2976069600*Zeta[3]))))/496011600 + 
       (CF*NC*(CF*(-25522963358054400*lm^2 + 1111762204357536*Pi^2 - 
            105840983528000*Sqrt[3]*Pi^3 + 5698379665440*Pi^4 + 
            55553299200*lm*(-647447 + 3000*Pi^2) - 81648758721600*Sqrt[3]*Pi*
             Log[3]^2 + 35*(-710038756879875 + 697294892757504*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] - 407326313157120*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 - 111975440532480*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] - 125791201158464*PolyGamma[2, 1] - 
              1059621497800960*Zeta[3])) + 
          560*(6561*NL*(-404822299 - 192961440*lm^2 - 89572320*Pi^2 + 
              840*lm*(-601297 + 1500*Pi^2) - 358041600*Zeta[3]) + 
            19683*NM*(95713891 - 64320480*lm^2 - 27782920*Pi^2 + 
              280*lm*(-601297 + 1500*Pi^2) - 10398348*PolyGamma[2, 1] - 
              12430296*Zeta[3]) - NH*(-182879005534605 + 1266020007840*lm^
                2 + 6073700969000*Sqrt[3]*Pi^3 - 5511240*lm*(-601297 + 
                1500*Pi^2) - 25830482621280*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]] + 224900470166400*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 4685426461800*Sqrt[3]*Pi*Log[3]^
                2 + 7707458421076*PolyGamma[2, 1] + 15830243888552*Zeta[
                3])) + 80*CA*(48741770301840*lm^2 - 6243885336798*Pi^2 + 
            661506147050*Sqrt[3]*Pi^3 + 10679543091*Pi^4 - 
            19289340*lm*(-9830291 + 16500*Pi^2) + 510304742010*Sqrt[3]*Pi*
             Log[3]^2 + 14*(10535074648776 - 10895232699336*Sqrt[3]*Im[
                PolyLog[2, (-1)^(1/3)]] + 6364473643080*Im[PolyLog[2, 
                  (-1)^(1/3)]]^2 + 1749616258320*Sqrt[3]*Im[PolyLog[3, 
                 -((-1)^(5/6)/Sqrt[3])]] + 1965487518101*PolyGamma[2, 1] + 
              18912033861322*Zeta[3]))))/104995735488000, 
      -(CF*NC*(125458110862435197*CF + 214174051096118400*CF*lm + 
          134562534601420800*CF*lm^2 - 8332953909441840*NM + 
          10465845752023200*lm*NM + 3737848183372800*lm^2*NM + 
          8997218596301040*NL + 10465845752023200*lm*NL + 
          3737848183372800*lm^2*NL - 623520393823171152*NH + 
          10465845752023200*lm*NH + 3737848183372800*lm^2*NH - 
          10939167086285376*CF*Pi^2 - 1049957354880000*CF*lm*Pi^2 + 
          1051596177206400*NM*Pi^2 - 29165482080000*lm*NM*Pi^2 + 
          2076665654044800*NL*Pi^2 - 29165482080000*lm*NL*Pi^2 - 
          29165482080000*lm*NH*Pi^2 + 715581306468000*Sqrt[3]*CF*Pi^3 + 
          29712264169840000*Sqrt[3]*NH*Pi^3 + 242263771313760*CF*Pi^4 - 
          113906723456574720*Sqrt[3]*CF*Im[PolyLog[2, (-1)^(1/3)]] - 
          139226917189785600*Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
          78713802956275200*CF*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          26496953519500800*Sqrt[3]*CF*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]] + 1100202696117504000*Sqrt[3]*NH*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 552019864989600*Sqrt[3]*CF*
           Pi*Log[3]^2 + 22920889502448000*Sqrt[3]*NH*Pi*Log[3]^2 + 
          499979692800*(-10*CA*(9575 + 4851*lm) + 5*CF*(100867 + 63504*lm) + 
            14*(7*(179 + 90*lm)*NM + 945*NL + 630*lm*NL + 8*NH + 
              630*lm*NH))*Log[x]^2 + 1469940296832000*(13*CA + 46*CF - 
            2*(2*NM + NL))*Log[x]^3 + 21248287241367200*CF*
           PolyGamma[2, 1] + 507223843015680*NM*PolyGamma[2, 1] + 
          38695922302947840*NH*PolyGamma[2, 1] + 105840*Log[x]*
           (4*(67825131381*NL + 33869325420*lm*NL + 6944162400*lm^2*NL + 
              1519434627351*NH + 33869325420*lm*NH + 6944162400*lm^2*NH + 
              4050761400*NL*Pi^2 + 6561*NM*(8863123 + 5162220*lm + 
                1058400*lm^2 + 256200*Pi^2) - 866246768800*Sqrt[3]*NH*Im[
                PolyLog[2, (-1)^(1/3)]] - 45*CF*(-19597517097 - 20382770016*
                 lm - 5555329920*lm^2 + 396434574*Pi^2 + 463609528*Sqrt[3]*
                 Im[PolyLog[2, (-1)^(1/3)]] - 925888320*Zeta[3])) + 
            45*CA*(-40760744997 - 20879149032*lm - 3394923840*lm^2 + 
              396713052*Pi^2 + 927219056*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              1851776640*Zeta[3])) + 191260725656835520*CF*Zeta[3] - 
          8785154292848640*NM*Zeta[3] + 10639567862784000*NL*Zeta[3] - 
          125506581128248320*NH*Zeta[3] - 5*CA*(4111633001710080*lm^2 - 
            926946865126512*Pi^2 + 71558130646800*Sqrt[3]*Pi^3 + 
            28892854264176*Pi^4 - 2083248720*lm*(-8038127 + 15400*Pi^2) + 
            55201986498960*Sqrt[3]*Pi*Log[3]^2 + 7*(1848435655455927 - 
              1627238906522496*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              1124482899375360*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
              378527907421440*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
              303546960590960*PolyGamma[2, 1] + 3209328326961760*Zeta[3]))))/
       104995735488000, -(CF*NC*(-21*CA*(291677 + 148720*lm) + 
           CF*(30628622 + 20442240*lm) + 112*(11243*NM + 5070*lm*NM + 
             7545*NL + 5070*lm*NL + 81*NH + 5070*lm*NH))*Log[x]^2)/5670 - 
       (16*CF*NC*(2255*CA + 7838*CF - 712*NM - 338*NL)*Log[x]^3)/81 + 
       (CF*NC*Log[x]*(-16*(78732*NM*(1731373 + 1072905*lm + 226800*lm^2 + 
              52150*Pi^2) + 98415*NL*(1717591 + 858324*lm + 181440*lm^2 + 
              107800*Pi^2) + 4*NH*(824534854944 + 21117989115*lm + 
              4464104400*lm^2 - 470061419800*Sqrt[3]*Im[PolyLog[2, 
                 (-1)^(1/3)]])) + CF*(-36210702016623 - 36227780271360*lm - 
            10285296537600*lm^2 + 724024983240*Pi^2 + 1698309877760*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 1714216089600*Zeta[3]) + 
          CA*(19340900228589 + 9433450939680*lm + 1571364748800*lm^2 - 
            213851858400*Pi^2 - 849154938880*Sqrt[3]*Im[PolyLog[2, (-1)^
                (1/3)]] + 857108044800*Zeta[3])))/4464104400 - 
       (CF*NC*(CF*(2541352780289433600*lm^2 - 170964789410463984*Pi^2 + 
            29126014403584000*Sqrt[3]*Pi^3 + 3268350585843840*Pi^4 - 
            7999675084800*lm*(-472459 + 1650*Pi^2) + 22468639682764800*
             Sqrt[3]*Pi*Log[3]^2 - 35*(-50060730158501265 + 70020622580827776*
               Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 46430914159687680*
               Im[PolyLog[2, (-1)^(1/3)]]^2 - 30814134422077440*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 13192169187358336*
               PolyGamma[2, 1] - 113803390660647680*Zeta[3])) - 
          224*(-(NH*(-54174520782859131 + 315147914222400*lm^2 + 
               2303300957020000*Sqrt[3]*Pi^3 - 248005800*lm*(-3425299 + 
                 6600*Pi^2) - 6348953727307200*Sqrt[3]*Im[PolyLog[2, 
                  (-1)^(1/3)]] + 85287944008512000*Sqrt[3]*Im[PolyLog[3, 
                  -((-1)^(5/6)/Sqrt[3])]] + 1776832166844000*Sqrt[3]*Pi*
                Log[3]^2 + 2232378209533160*PolyGamma[2, 1] - 
               12894300429381680*Zeta[3])) + 4428675*NL*(-141935507 - 
              71160768*lm^2 - 41799920*Pi^2 + 56*lm*(-3425299 + 6600*Pi^2) - 
              221760000*Zeta[3]) + 295245*NM*(3603542551 - 1067411520*lm^2 - 
              313141200*Pi^2 + 840*lm*(-3425299 + 6600*Pi^2) - 
              179522388*PolyGamma[2, 1] + 3359265624*Zeta[3])) - 
          10*CA*(38826223032199680*lm^2 - 6963189755963256*Pi^2 + 
            1456300720179200*Sqrt[3]*Pi^3 + 192749671269792*Pi^4 - 
            2777664960*lm*(-55468481 + 72600*Pi^2) + 1123431984138240*Sqrt[3]*
             Pi*Log[3]^2 + 7*(12661962268603905 - 17505155645206944*Sqrt[
                3]*Im[PolyLog[2, (-1)^(1/3)]] + 11607728539921920*
               Im[PolyLog[2, (-1)^(1/3)]]^2 + 7703533605519360*Sqrt[3]*Im[
                PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 3298042296839584*
               PolyGamma[2, 1] + 32810649226701248*Zeta[3]))))/
        944961619392000, (-35791254272863931*CF^2*NC)/6428310336000 - 
       (2680369*CF^2*lm*NC)/180 - (46508*CF^2*lm^2*NC)/5 + 
       (1306253239*CF*NM*NC)/816480 - (4703467*CF*lm*NM*NC)/6480 - 
       (11627*CF*lm^2*NM*NC)/45 - (2024525387*CF*NC*NL)/4082400 - 
       (4703467*CF*lm*NC*NL)/6480 - (11627*CF*lm^2*NC*NL)/45 + 
       (1066941281865315587*CF*NC*NH)/19686700404000 - 
       (4703467*CF*lm*NC*NH)/6480 - (11627*CF*lm^2*NC*NH)/45 + 
       (168991005143*CF^2*NC*Pi^2)/168399000 + (490*CF^2*lm*NC*Pi^2)/9 + 
       (6087043*CF*NM*NC*Pi^2)/34020 + (245*CF*lm*NM*NC*Pi^2)/162 - 
       (283913*CF*NC*NL*Pi^2)/1620 + (245*CF*lm*NC*NL*Pi^2)/162 + 
       (245*CF*lm*NC*NH*Pi^2)/162 - (257725722415*CF^2*NC*Pi^3)/
        (688747536*Sqrt[3]) - (1400624918105*CF*NC*NH*Pi^3)/
        (172186884*Sqrt[3]) - (431039*CF^2*NC*Pi^4)/16200 + 
       (73944492523013*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (2869781400*Sqrt[3]) + (16966389590554*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(502211745*Sqrt[3]) - 
       (283598*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (7363592069*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (531441*Sqrt[3]) - (160071419212*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(531441*Sqrt[3]) - 
       (7363592069*CF^2*NC*Pi*Log[3]^2)/(25509168*Sqrt[3]) - 
       (40017854803*CF*NC*NH*Pi*Log[3]^2)/(6377292*Sqrt[3]) - 
       (CF*NC*(7*CF*(24117929 + 15770160*lm) - CA*(29483837 + 16865310*lm) - 
          6982410*NM + 3066420*lm*NM + 4357570*NL + 3066420*lm*NL + 
          96228*NH + 3066420*lm*NH)*Log[x]^2)/5670 - 
       (14*CF*NC*(15289*CA + 61422*CF - 11832*NM - 2086*NL)*Log[x]^3)/81 - 
       (424577510109737*CF^2*NC*PolyGamma[2, 1])/253114719480 + 
       (2039486*CF*NM*NC*PolyGamma[2, 1])/14175 - 
       (73549712170414*CF*NC*NH*PolyGamma[2, 1])/22599528525 - 
       (CF*NC*Log[x]*(4*(131710704085611*NL + 62215470738540*lm*NL + 
            12249502473600*lm^2*NL + 2755050052934325*NH + 
            62215470738540*lm*NH + 12249502473600*lm^2*NH + 
            8308111631400*NL*Pi^2 + 413343*NM*(190760007 + 150517780*lm + 
              29635200*lm^2 - 35830200*Pi^2) - 1568699908277600*Sqrt[3]*NH*
             Im[PolyLog[2, (-1)^(1/3)]] - 14*CF*(-119366446382544 - 
              121921684927560*lm - 31498720646400*lm^2 + 2686426873875*Pi^2 + 
              5154514448300*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
              5249786774400*Zeta[3])) + 35*CA*(-99500865905067 - 
            48906469300248*lm - 7699687269120*lm^2 + 1239958377396*Pi^2 + 
            4123611558640*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            4199829419520*Zeta[3])))/187492384800 - 
       (9554148534583993*CF^2*NC*Zeta[3])/632786798700 + 
       (24150772*CF*NM*NC*Zeta[3])/14175 - (29204*CF*NC*NL*Zeta[3])/27 + 
       (368121836906872*CF*NC*NH*Zeta[3])/22599528525 + 
       (CA*CF*NC*(1175814974994664221 + 575513124930374400*lm^2 - 
          167709573841486680*Pi^2 + 25257120796670000*Sqrt[3]*Pi^3 + 
          5877748769064480*Pi^4 - 343736038800*lm*(-6834379 + 9800*Pi^2) - 
          1739174464141265760*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
          1276139168268249600*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
          935235101499552000*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
          19484064614574000*Sqrt[3]*Pi*Log[3]^2 + 339662008087789600*
           PolyGamma[2, 1] + 3615108311929304000*Zeta[3]))/404983551168000, 
      (CF*NC*(-916629436800*(-(CA*(342796493 + 203531790*lm)) + 
           CF*(1903472099 + 1332208080*lm) - 31068744*NM + 37005780*lm*NM + 
           52323915*NL + 37005780*lm*NL + 1378296*NH + 37005780*lm*NH)*
          Log[x]^2 - 898296848064000*(193245*CA + 741841*CF - 142652*NM - 
           25174*NL)*Log[x]^3 + 166320*Log[x]*
          (2*(-498074871806883*NL - 233777109284460*lm*NL - 
             47248080969600*lm^2*NL - 9385322956507506*NH - 
             233777109284460*lm*NH - 47248080969600*lm^2*NH - 
             32745004903800*NL*Pi^2 - 183708*NM*(2348954033 + 1272547245*
                lm + 257191200*lm^2 - 329218050*Pi^2) + 5342491161610400*
              Sqrt[3]*NH*Im[PolyLog[2, (-1)^(1/3)]] + 
             14*CF*(-459525916269264 - 454334600861640*lm - 121495065350400*
                lm^2 + 10689186875265*Pi^2 + 28414609762460*Sqrt[3]*
                Im[PolyLog[2, (-1)^(1/3)]] - 20249177558400*Zeta[3])) - 
           7*CA*(-978719856924579 - 461860190814780*lm - 74246984380800*
              lm^2 + 13847383175850*Pi^2 + 56829219524920*Sqrt[3]*
              Im[PolyLog[2, (-1)^(1/3)]] - 40498355116800*Zeta[3])) + 
         77*CA*(1146864337750221237 + 1031958835908739200*lm^2 - 
           280651551147790740*Pi^2 + 69615793918027000*Sqrt[3]*Pi^3 + 
           9262361299474080*Pi^4 - 744017400*lm*(-5542157193 + 
             5929000*Pi^2) - 3530316882825228720*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 2454551305822425600*
            Im[PolyLog[2, (-1)^(1/3)]]^2 + 2577773397650371200*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 53703612451049400*Sqrt[3]*
            Pi*Log[3]^2 + 674148984471020320*PolyGamma[2, 1] + 
           7030538649010855040*Zeta[3]) + 
         44*(-4*NH*(-17920980553768937586 + 82087634674558800*lm^2 + 
             818068959121592500*Sqrt[3]*Pi^3 - 651015225*lm*(-343352091 + 
               539000*Pi^2) - 2086149056655127800*Sqrt[3]*Im[PolyLog[2, 
                (-1)^(1/3)]] + 30291924886330968000*Sqrt[3]*Im[PolyLog[3, 
                -((-1)^(5/6)/Sqrt[3])]] + 631081768465228500*Sqrt[3]*Pi*
              Log[3]^2 + 741143349982942480*PolyGamma[2, 1] - 
             6004476508954971040*Zeta[3]) + 14467005*NL*(-32530195339 - 
             22696511040*lm^2 - 16059739080*Pi^2 + 180*lm*(-343352091 + 
               539000*Pi^2) - 103833273600*Zeta[3]) + 4960116*NM*
            (474441038631 - 66198157200*lm^2 + 37517925550*Pi^2 + 
             525*lm*(-343352091 + 539000*Pi^2) + 41956696020*
              PolyGamma[2, 1] + 536090096040*Zeta[3])) - 
         7*CF*(74301036185429222400*lm^2 - 7503891976824828696*Pi^2 + 
           1531547466196594000*Sqrt[3]*Pi^3 + 189655855261709760*Pi^4 - 
           589261780800*lm*(-190991253 + 539000*Pi^2) + 1181479473923086800*
            Sqrt[3]*Pi*Log[3]^2 + 11*(2258837857746536661 - 
             7060633765650457440*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
             4909102611644851200*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
             5155546795300742400*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                  Sqrt[3])]] + 1348297968942040640*PolyGamma[2, 1] + 
             12121191324240918400*Zeta[3]))))/31183733439936000, 
      (-183748007369537687*CF^2*NC)/19284931008000 - (13285817*CF^2*lm*NC)/
        180 - (230048*CF^2*lm^2*NC)/5 + (569366215937*CF*NM*NC)/40824000 - 
       (4658581*CF*lm*NM*NC)/1296 - (57512*CF*lm^2*NM*NC)/45 - 
       (412872163*CF*NC*NL)/291600 - (4658581*CF*lm*NC*NL)/1296 - 
       (57512*CF*lm^2*NC*NL)/45 + (8017812608552377247*CF*NC*NH)/
        23624040484800 - (4658581*CF*lm*NC*NH)/1296 - 
       (57512*CF*lm^2*NC*NH)/45 + (257519988901*CF^2*NC*Pi^2)/32076000 + 
       (1960*CF^2*lm*NC*Pi^2)/9 + (23199397*CF*NM*NC*Pi^2)/3402 + 
       (490*CF*lm*NM*NC*Pi^2)/81 - (827897*CF*NC*NL*Pi^2)/810 + 
       (490*CF*lm*NC*NL*Pi^2)/81 + (490*CF*lm*NC*NH*Pi^2)/81 - 
       (6608880152399*CF^2*NC*Pi^3)/(2066242608*Sqrt[3]) - 
       (13285519156595*CF*NC*NH*Pi^3)/(258280326*Sqrt[3]) - 
       (1474711*CF^2*NC*Pi^4)/8100 + (4267444979999809*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(30132704700*Sqrt[3]) + 
       (302812306265668*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1506635235*Sqrt[3]) - (1592444*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/
        45 - (944125736057*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (7971615*Sqrt[3]) - (3036690092936*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1594323*Sqrt[3]) - 
       (944125736057*CF^2*NC*Pi*Log[3]^2)/(382637520*Sqrt[3]) - 
       (379586261617*CF*NC*NH*Pi*Log[3]^2)/(9565938*Sqrt[3]) - 
       (CF*NC*(-(CA*(327135133 + 261242520*lm)) + 
          2*CF*(1184514833 + 854975520*lm) - 789658134*NM + 
          47498640*lm*NM + 65568860*NL + 47498640*lm*NL + 2488410*NH + 
          47498640*lm*NH)*Log[x]^2)/11340 - 
       (14*CF*NC*(421509*CA + 1697254*CF - 673560*NM - 48468*NL)*Log[x]^3)/
        243 - (2751667909376063*CF^2*NC*PolyGamma[2, 1])/316393399350 + 
       (151865449*CF*NM*NC*PolyGamma[2, 1])/28350 - 
       (177235162093693*CF*NC*NH*PolyGamma[2, 1])/9039811410 + 
       (CA*CF*NC*(46971018222794265600*lm^2 - 23086790673487487640*Pi^2 + 
          3562186402143061000*Sqrt[3]*Pi^3 + 640632267548048160*Pi^4 - 
          515604058200*lm*(-372166147 + 431200*Pi^2) + 2747972367367504200*
           Sqrt[3]*Pi*Log[3]^2 - 33*(-963976298681793957 + 
            4779538377599786080*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            3582853478645414400*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
            3997050716170915200*Sqrt[3]*Im[PolyLog[3, -((-1)^(5/6)/
                 Sqrt[3])]] - 880533731000340160*PolyGamma[2, 1] - 
            10520014868872675520*Zeta[3])))/6682228594272000 - 
       (CF*NC*Log[x]*(4*(8680203*NM*(-357328851 + 133126720*lm + 
              25401600*lm^2 - 139604400*Pi^2) + 2480058*NL*
             (1046748053 + 465943520*lm + 88905600*lm^2 + 69217400*Pi^2) + 
            NH*(52325447498032119 + 1155566954324160*lm + 220491044524800*lm^
                2 - 29759562910772800*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) - 
          7*CF*(-17190179064002361 - 18290885667909120*lm - 
            4535815773081600*lm^2 + 556017597695160*Pi^2 + 1057420824383840*
             Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 755969295513600*Zeta[3]) + 
          7*CA*(-8987779862498877 - 4513746034546560*lm - 692971854220800*
             lm^2 + 191124964724940*Pi^2 + 528710412191920*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 377984647756800*Zeta[3])))/
        562477154400 - (13867607283206144*CF^2*NC*Zeta[3])/158196699675 + 
       (205686349*CF*NM*NC*Zeta[3])/14175 - (199724*CF*NC*NL*Zeta[3])/27 + 
       (513480533763347*CF*NC*NH*Zeta[3])/4519905705, 
      (89449812393247680623*CF^2*NC)/17718030363600000 - 
       (2672768986*CF^2*lm*NC)/23625 - (370176*CF^2*lm^2*NC)/5 + 
       (22918023713951*CF*NM*NC)/1250235000 - (2393121293*CF*lm*NM*NC)/
        425250 - (30848*CF*lm^2*NM*NC)/15 - (500312176*CF*NC*NL)/455625 - 
       (2393121293*CF*lm*NC*NL)/425250 - (30848*CF*lm^2*NC*NL)/15 + 
       (25173392235820282873*CF*NC*NH)/44295075909000 - 
       (2393121293*CF*lm*NC*NH)/425250 - (30848*CF*lm^2*NC*NH)/15 + 
       (8162514726229*CF^2*NC*Pi^2)/589396500 + (1344*CF^2*lm*NC*Pi^2)/5 + 
       (121964684*CF*NM*NC*Pi^2)/14175 + (112*CF*lm*NM*NC*Pi^2)/15 - 
       (10331324*CF*NC*NL*Pi^2)/6075 + (112*CF*lm*NC*NL*Pi^2)/15 + 
       (112*CF*lm*NC*NH*Pi^2)/15 - (9008247909521*CF^2*NC*Pi^3)/
        (1291401630*Sqrt[3]) - (10308251173948*CF*NC*NH*Pi^3)/
        (129140163*Sqrt[3]) - (561353*CF^2*NC*Pi^4)/2025 + 
       (28990829210657947*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (112997642625*Sqrt[3]) + (917392708194944*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4519905705*Sqrt[3]) - 
       (905392*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (10295140468024*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (39858075*Sqrt[3]) - (23561716969024*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(7971615*Sqrt[3]) - 
       (1286892558503*CF^2*NC*Pi*Log[3]^2)/(239148450*Sqrt[3]) - 
       (1472607310564*CF*NC*NH*Pi*Log[3]^2)/(23914845*Sqrt[3]) - 
       (CF*NC*(-25*CA*(1472356531 + 1391898816*lm) + 
          22*CF*(12948784577 + 10352966400*lm) + 
          240*(-282933547*NM + 26361720*lm*NM + 36288994*NL + 
            26361720*lm*NL + 1568085*NH + 26361720*lm*NH))*Log[x]^2)/
        850500 - (4*CF*NC*(70492920*CA + 259907551*CF - 
          240*(400720*NM + 31383*NL))*Log[x]^3)/6075 - 
       (39839817666107771*CF^2*NC*PolyGamma[2, 1])/2847540594150 + 
       (182634518*CF*NM*NC*PolyGamma[2, 1])/19845 - 
       (66673234972792471*CF*NC*NH*PolyGamma[2, 1])/2847540594150 + 
       (CA*CF*NC*(396806771276497612800*lm^2 - 213423996608910319176*Pi^2 + 
          40785743235147279600*Sqrt[3]*Pi^3 + 5072077554746479200*Pi^4 - 
          41248324656*lm*(-38567905423 + 34927200*Pi^2) + 
          31463287638542187120*Sqrt[3]*Pi*Log[3]^2 - 
          11*(10390072880865615669 + 136372860606934982688*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 96250577681763187200*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 137294346059093180160*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 22310297893020351760*
             PolyGamma[2, 1] - 288022694129342503520*Zeta[3])))/
        35081700119928000 - (8842659177308153*CF^2*NC*Zeta[3])/56950811883 + 
       (585322156*CF*NM*NC*Zeta[3])/19845 - (193568*CF*NC*NL*Zeta[3])/15 + 
       (297107289699375209*CF*NC*NH*Zeta[3])/1423770297075 - 
       (CF*NC*Log[x]*(5*CA*(-270546626339914857 - 132747730533815040*lm - 
            20789155626624000*lm^2 + 6904204052712120*Pi^2 + 
            20178475317327040*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] - 
            11339539432704000*Zeta[3]) + 
          2*(-40*(-177147*NM*(5315489287 + 6818220640*lm + 1333584000*lm^2 - 
                6949689600*Pi^2) - 1240029*NL*(2210612219 + 974031520*lm + 
                190512000*lm^2 + 151376400*Pi^2) - 5*NH*(10153315521499719 + 
                241565466342816*lm + 47248080969600*lm^2 - 5772620657410880*
                 Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]])) + 
            CF*(1266512694815048439 + 1328213053232755200*lm + 
              340186182981120000*lm^2 - 45971882762393700*Pi^2 - 
              100892376586635200*Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
              56697697163520000*Zeta[3]))))/7030964430000, 
      (3128290395825163004999*CF^2*NC)/141744242908800000 - 
       (425589991*CF^2*lm*NC)/1500 - (883512*CF^2*lm^2*NC)/5 + 
       (9321279106673*CF*NM*NC)/370440000 - (745863091*CF*lm*NM*NC)/54000 - 
       (24542*CF*lm^2*NM*NC)/5 + (17875699*CF*NC*NL)/270000 - 
       (745863091*CF*lm*NC*NL)/54000 - (24542*CF*lm^2*NC*NL)/5 + 
       (12201311917708652040707*CF*NC*NH)/7486570925064000 - 
       (745863091*CF*lm*NC*NH)/54000 - (24542*CF*lm^2*NC*NH)/5 + 
       (1916480836243*CF^2*NC*Pi^2)/26061750 + (3528*CF^2*lm*NC*Pi^2)/5 + 
       (1228864307*CF*NM*NC*Pi^2)/9450 + (98*CF*lm*NM*NC*Pi^2)/5 - 
       (6102929*CF*NC*NL*Pi^2)/1350 + (98*CF*lm*NC*NL*Pi^2)/5 + 
       (98*CF*lm*NC*NH*Pi^2)/5 - (377858722033499*CF^2*NC*Pi^3)/
        (20662426080*Sqrt[3]) - (21228277365659*CF*NC*NH*Pi^3)/
        (86093442*Sqrt[3]) - (966931*CF^2*NC*Pi^4)/1080 + 
       (156862085854150019*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (258280326000*Sqrt[3]) + (468150496718344*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(502211745*Sqrt[3]) - 
       (759962*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (53979817433357*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (79716150*Sqrt[3]) - (24260888417896*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2657205*Sqrt[3]) - 
       (53979817433357*CF^2*NC*Pi*Log[3]^2)/(3826375200*Sqrt[3]) - 
       (3032611052237*CF*NC*NH*Pi*Log[3]^2)/(15943230*Sqrt[3]) - 
       (CF*NC*(-55*CA*(-10101723517 + 28968619680*lm) + 
          8*(143*CF*(8234641601 + 9115999200*lm) + 
            135*(33*(-517659437 + 8128120*lm)*NM + 7*(242*(214943 + 
                  158340*lm)*NL + 15*(187855 + 2554552*lm)*NH))))*Log[x]^2)/
        12474000 - (2*CF*NC*(64169015*CA + 190035406*CF - 183195000*NM - 
          5225220*NL)*Log[x]^3)/675 - (7732569818855939*CF^2*NC*
         PolyGamma[2, 1])/421857865800 + (919159277*CF*NM*NC*
         PolyGamma[2, 1])/9450 - (36942613175033971*CF*NC*NH*
         PolyGamma[2, 1])/406791513450 + 
       (CA*CF*NC*(15784543212960004560000*lm^2 - 19976845735532947037175*
           Pi^2 + 1782076197790489658750*Sqrt[3]*Pi^3 + 270908630121017889000*
           Pi^4 - 5413842611100*lm*(-11915244401 + 11642400*Pi^2) + 
          1374744495438377736750*Sqrt[3]*Pi*Log[3]^2 - 
          22*(392010445319612445309 + 2690184772398672825850*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 2019754468677327480000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 2999442535501915062000*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 243575949293962078500*
             PolyGamma[2, 1] - 6390150197663115954000*Zeta[3])))/
        584695001998800000 - (85762770279947321*CF^2*NC*Zeta[3])/
        210928932900 + (322240577*CF*NM*NC*Zeta[3])/4725 - 
       (187852*CF*NC*NL*Zeta[3])/5 + (114516606578356109*CF*NC*NH*Zeta[3])/
        203395756725 + CF*Log[x]*((121668603949*NM*NC)/147000 - 
         (8527096*lm*NM*NC)/225 - 7056*lm^2*NM*NC - (711975007*NC*NL)/
          7875 - (8527096*lm*NC*NL)/225 - 7056*lm^2*NC*NL - 
         (482198305076911421*NC*NH)/270078316200 - (8527096*lm*NC*NH)/225 - 
         7056*lm^2*NC*NH + (1973606*NM*NC*Pi^2)/15 - (93338*NC*NL*Pi^2)/
          15 + (24260888417896*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (7971615*Sqrt[3]) + CF*NC*(-6679346154223908521/9374619240000 - 
           (26434984*lm)/25 - 254016*lm^2 + (7015764379*Pi^2)/113400 + 
           (53979817433357*Im[PolyLog[2, (-1)^(1/3)]])/(239148450*Sqrt[3]) - 
           42336*Zeta[3]) + CA*NC*(3566027318198219479/9374619240000 + 
           (58012228*lm)/225 + 38808*lm^2 - (5833919821*Pi^2)/226800 - 
           (53979817433357*Im[PolyLog[2, (-1)^(1/3)]])/(478296900*Sqrt[3]) + 
           21168*Zeta[3])), (138330793120598590867301*CF^2*NC)/
        1275698186179200000 - (19051858187*CF^2*lm*NC)/47250 - 
       (1312776*CF^2*lm^2*NC)/5 - (21668882375317099*CF*NM*NC)/
        270050760000 - (34042119137*CF*lm*NM*NC)/1701000 - 
       (36466*CF*lm^2*NM*NC)/5 + (31634646461*CF*NC*NL)/6378750 - 
       (34042119137*CF*lm*NC*NL)/1701000 - (36466*CF*lm^2*NC*NL)/5 + 
       (10661933425773500089945283*CF*NC*NH)/4244885714511288000 - 
       (34042119137*CF*lm*NC*NH)/1701000 - (36466*CF*lm^2*NC*NH)/5 + 
       (2106186300297587*CF^2*NC*Pi^2)/15324309000 + (4144*CF^2*lm*NC*Pi^2)/
        5 + (1571652167*CF*NM*NC*Pi^2)/12150 + (1036*CF*lm*NM*NC*Pi^2)/45 - 
       (83826523*CF*NC*NL*Pi^2)/12150 + (1036*CF*lm*NC*NL*Pi^2)/45 + 
       (1036*CF*lm*NC*NH*Pi^2)/45 - (6408073269196609*CF^2*NC*Pi^3)/
        (185961834720*Sqrt[3]) - (413858144816102*CF*NC*NH*Pi^3)/
        (1162261467*Sqrt[3]) - (20853559*CF^2*NC*Pi^4)/16200 + 
       (16454306228558876423*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (16271660538000*Sqrt[3]) + (7497019060901318*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(8135830269*Sqrt[3]) - 
       (3560362*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (6408073269196609*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5022117450*Sqrt[3]) - (945961473865376*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(71744535*Sqrt[3]) - 
       (6408073269196609*CF^2*NC*Pi*Log[3]^2)/(241061637600*Sqrt[3]) - 
       (59122592116586*CF*NC*NH*Pi*Log[3]^2)/(215233605*Sqrt[3]) - 
       (CF*NC*(CA*(8270781757601 - 7728069333600*lm) + 
          8*(44*CF*(87903606731 + 143703768600*lm) + 
            5*(11*(-120349782473 + 3193417080*lm)*NM + 1386*(34351781 + 
                25344580*lm)*NL + 5*(569597449 + 7025517576*lm)*NH)))*
         Log[x]^2)/37422000 - (4*CF*NC*(177872611*CA + 426503513*CF - 
          353307900*NM - 12672290*NL)*Log[x]^3)/2025 - 
       (290234301626549771*CF^2*NC*PolyGamma[2, 1])/51255730694700 + 
       (18549559759*CF*NM*NC*PolyGamma[2, 1])/132300 - 
       (1051448002155942029*CF*NC*NH*PolyGamma[2, 1])/10251146138940 + 
       (CA*CF*NC*(25329927676151230070400*lm^2 - 41133335697133361286255*
           Pi^2 + 3626649066701820863550*Sqrt[3]*Pi^3 + 418062675929994988200*
           Pi^4 - 185617460952*lm*(-548143575307 + 430768800*Pi^2) + 
          2797700708598547523310*Sqrt[3]*Pi*Log[3]^2 - 
          11*(3564158449918508033841 + 9675132062392619336724*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 6812921018312023305600*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 12208148546611843738080*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 162531208910867871760*
             PolyGamma[2, 1] - 21940694932513209646640*Zeta[3])))/
        631470602158704000 - (1685369056168658411*CF^2*NC*Zeta[3])/
        2562786534735 + (11369158559*CF*NM*NC*Zeta[3])/66150 - 
       (8099972*CF*NC*NL*Zeta[3])/135 + (4845777587087043619*CF*NC*NH*
         Zeta[3])/5125573069470 + CF*Log[x]*((3532193474441*NM*NC)/
          13395375 - (823910279*lm*NM*NC)/14175 - 11088*lm^2*NM*NC - 
         (39794054831*NC*NL)/283500 - (823910279*lm*NC*NL)/14175 - 
         11088*lm^2*NC*NL - (32914166315004015247*NC*NH)/12761200440450 - 
         (823910279*lm*NC*NH)/14175 - 11088*lm^2*NC*NH + 
         (22728592*NM*NC*Pi^2)/135 - (4031338*NC*NL*Pi^2)/405 + 
         (945961473865376*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (215233605*Sqrt[3]) + CF*NC*(-76844402430509862439/84371573160000 - 
           (2535974516*lm)/1575 - 399168*lm^2 + (1148807029*Pi^2)/9720 + 
           (6408073269196609*Im[PolyLog[2, (-1)^(1/3)]])/(15066352350*
             Sqrt[3]) - 66528*Zeta[3]) + CA*NC*(42894890722883078567/
            84371573160000 + (11263426669*lm)/28350 + 60984*lm^2 - 
           (7050914953*Pi^2)/136080 - (6408073269196609*
             Im[PolyLog[2, (-1)^(1/3)]])/(30132704700*Sqrt[3]) + 
           33264*Zeta[3])), (-133209323025049991967743*CF^2*NC)/
        765418911707520000 - (491014031*CF^2*lm*NC)/540 - 
       (2830296*CF^2*lm^2*NC)/5 - (19964582008229653*CF*NM*NC)/18003384000 - 
       (860367659*CF*lm*NM*NC)/19440 - (235858*CF*lm^2*NM*NC)/15 + 
       (8580876707*CF*NC*NL)/378000 - (860367659*CF*lm*NC*NL)/19440 - 
       (235858*CF*lm^2*NC*NL)/15 + (5135114398523516501054678317*CF*NC*NH)/
        799372621266968548800 - (860367659*CF*lm*NC*NH)/19440 - 
       (235858*CF*lm^2*NC*NH)/15 + (2531005746193427*CF^2*NC*Pi^2)/
        2918916000 + 1960*CF^2*lm*NC*Pi^2 + (17379030647*CF*NM*NC*Pi^2)/
        8505 + (490*CF*lm*NM*NC*Pi^2)/9 - (6637883*CF*NC*NL*Pi^2)/405 + 
       (490*CF*lm*NC*NL*Pi^2)/9 + (490*CF*lm*NC*NH*Pi^2)/9 - 
       (44828801682372001*CF^2*NC*Pi^3)/(557885504160*Sqrt[3]) - 
       (6742120077553315*CF*NC*NH*Pi^3)/(6973568802*Sqrt[3]) - 
       (6299041*CF^2*NC*Pi^4)/1800 + (106073536333098251957*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(48814981614000*Sqrt[3]) + 
       (438375934867307818*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (122037454035*Sqrt[3]) - (2691122*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/5 - (6404114526053143*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2152336050*Sqrt[3]) - 
       (1541056017726472*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (43046721*Sqrt[3]) - (6404114526053143*CF^2*NC*Pi*Log[3]^2)/
        (103312130400*Sqrt[3]) - (192632002215809*CF*NC*NH*Pi*Log[3]^2)/
        (258280326*Sqrt[3]) - 
       (CF*NC*(-429*CA*(-1342342245267 + 210984004000*lm) + 
          8*(41184*CF*(-1667803427 + 1798159125*lm) + 
            25*(143*(-136853646619 + 575410920*lm)*NM + 2002*(55219669 + 
                41100780*lm)*NL + 7*(1103359973 + 11754823080*lm)*NH)))*
         Log[x]^2)/162162000 - (CF*NC*(3411850581*CA + 
          4*(677461639*CF - 50*(71532168*NM + 685013*NL)))*Log[x]^3)/2025 + 
       (81372964216352595893*CF^2*NC*PolyGamma[2, 1])/307534384168200 + 
       (7979146327*CF*NM*NC*PolyGamma[2, 1])/5670 - 
       (3807900600074496293*CF*NC*NH*PolyGamma[2, 1])/10983370863150 + 
       (CA*CF*NC*(21298047239604507948576000*lm^2 - 
          104375149941900107312838810*Pi^2 + 3298211840577996415573500*
           Sqrt[3]*Pi^3 + 441639662068675393923600*Pi^4 - 
          6334195854987000*lm*(-13743451801 + 11642400*Pi^2) + 
          2544334848445882949156700*Sqrt[3]*Pi*Log[3]^2 - 
          143*(-102484205699507686086723 + 623712393638617721507160*Sqrt[3]*
             Im[PolyLog[2, (-1)^(1/3)]] - 463463026315237043424000*
             Im[PolyLog[2, (-1)^(1/3)]]^2 - 854042466611205465451200*Sqrt[3]*
             Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 227844299805787268500400*
             PolyGamma[2, 1] - 1740373496159364170350400*Zeta[3])))/
        246273534841894560000 - (53489760643569442637*CF^2*NC*Zeta[3])/
        30753438416820 - (90144413*CF*NM*NC*Zeta[3])/2835 - 
       (4154780*CF*NC*NL*Zeta[3])/27 + (12232878092219714107*CF*NC*NH*
         Zeta[3])/5491685431575 + CF*Log[x]*((28297952515789*NM*NC)/
          1786050 - (3826093*lm*NM*NC)/27 - 25872*lm^2*NM*NC - 
         (2711606911*NC*NL)/7560 - (3826093*lm*NC*NL)/27 - 
         25872*lm^2*NC*NL - (6475295030679501849541*NC*NH)/
          924275517615450 - (3826093*lm*NC*NH)/27 - 25872*lm^2*NC*NH + 
         (15794234*NM*NC*Pi^2)/9 - (2068570*NC*NL*Pi^2)/81 + 
         (1541056017726472*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (129140163*Sqrt[3]) + CF*NC*(577293555963223855697/
            253114719480000 - (11928076*lm)/3 - 931392*lm^2 + 
           (3106513483*Pi^2)/4536 + (6404114526053143*
             Im[PolyLog[2, (-1)^(1/3)]])/(6457008150*Sqrt[3]) - 
           155232*Zeta[3]) + CA*NC*(-10555190302690007587/10124588779200 + 
           (51866639*lm)/54 + 142296*lm^2 - (73011227269*Pi^2)/226800 - 
           (6404114526053143*Im[PolyLog[2, (-1)^(1/3)]])/(12914016300*
             Sqrt[3]) + 77616*Zeta[3])), 
      (174573643608273371232189557*CF^2*NC)/1247996400066318672000 - 
       (169278640894*CF^2*lm*NC)/138915 - (27686016*CF^2*lm^2*NC)/35 - 
       (574837081058610452807*CF*NM*NC)/188704719819000 - 
       (151028656439*CF*lm*NM*NC)/2500470 - (769056*CF*lm^2*NM*NC)/35 + 
       (63532599252611*CF*NC*NL)/1312746750 - (151028656439*CF*lm*NC*NL)/
        2500470 - (769056*CF*lm^2*NC*NL)/35 + 
       (661780011516175729209252637*CF*NC*NH)/71372555470265049000 - 
       (151028656439*CF*lm*NC*NH)/2500470 - (769056*CF*lm^2*NC*NH)/35 + 
       (383115818916275699*CF^2*NC*Pi^2)/214540326000 + 
       (46400*CF^2*lm*NC*Pi^2)/21 + (258858523496*CF*NM*NC*Pi^2)/178605 + 
       (11600*CF*lm*NM*NC*Pi^2)/189 - (464360936*CF*NC*NL*Pi^2)/19845 + 
       (11600*CF*lm*NC*NL*Pi^2)/189 + (11600*CF*lm*NC*NH*Pi^2)/189 - 
       (33349680441044029*CF^2*NC*Pi^3)/(244074908070*Sqrt[3]) - 
       (4596645918468680*CF*NC*NH*Pi^3)/(3486784401*Sqrt[3]) - 
       (67763602*CF^2*NC*Pi^4)/14175 + (2026480527655557125009*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(597983524771500*Sqrt[3]) + 
       (2985098688621576112*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (854262178245*Sqrt[3]) - (82458464*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^
          2)/105 - (266797443528352232*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(52732233225*Sqrt[3]) - 
       (14709266939099776*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (301327047*Sqrt[3]) - (33349680441044029*CF^2*NC*Pi*Log[3]^2)/
        (316393399350*Sqrt[3]) - (919329183693736*CF*NC*NH*Pi*Log[3]^2)/
        (903981141*Sqrt[3]) - 
       (CF*NC*(-819*CA*(-182316175139821 + 18309951352000*lm) + 
          8*(117*CF*(-219618914492827 + 104866085016000*lm) + 
            350*(13*(-8251851745369 + 74904346440*lm)*NM + 2574*(507819023 + 
                378304780*lm)*NL + 7*(14110656751 + 139108071960*lm)*NH)))*
         Log[x]^2)/17878360500 - (2*CF*NC*(486782882362*CA + 90191765717*CF - 
          5600*(174108774*NM + 2702177*NL))*Log[x]^3)/297675 + 
       (19471861278459789949*CF^2*NC*PolyGamma[2, 1])/25627865347350 + 
       (970122326209*CF*NM*NC*PolyGamma[2, 1])/595350 - 
       (32638837741927166*CF*NC*NH*PolyGamma[2, 1])/87169610025 - 
       (34121018450182576949*CF^2*NC*Zeta[3])/12813932673675 + 
       (307550637409*CF*NM*NC*Zeta[3])/297675 - 
       (129997408*CF*NC*NL*Zeta[3])/567 + (2130157936110442076*CF*NC*NH*
         Zeta[3])/610187270175 + (CA*CF*NC*(-43702355597341140836284641 + 
          46170132568265731044096000*lm^2 - 336325065362532132212844540*
           Pi^2 + 8700131234737802109404000*Sqrt[3]*Pi^3 + 
          931928974629296055350400*Pi^4 - 76393580868000*lm*
           (-2430515803357 + 1688148000*Pi^2) - 215779646584763722670958320*
           Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 150011466803204279632128000*
           Im[PolyLog[2, (-1)^(1/3)]]^2 + 322153430863434043822502400*Sqrt[3]*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 6711529809654875912968800*
           Sqrt[3]*Pi*Log[3]^2 - 145135465225127890363866400*
           PolyGamma[2, 1] + 581132309802034844736097600*Zeta[3]))/
        382039714306015920000 + CF*Log[x]*((28621066206508456*NM*NC)/
          6807529575 - (1344475912*lm*NM*NC)/6615 - 38016*lm^2*NM*NC - 
         (217248815216*NC*NL)/416745 - (1344475912*lm*NC*NL)/6615 - 
         38016*lm^2*NC*NL - (883240777400235276226*NC*NH)/92427551761545 - 
         (1344475912*lm*NC*NH)/6615 - 38016*lm^2*NC*NH + 
         (920235536*NM*NC*Pi^2)/567 - (64789904*NC*NL*Pi^2)/1701 + 
         (14709266939099776*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (903981141*Sqrt[3]) + CF*NC*(3233908658781153495132149/
            375179292949230000 - (4162437088*lm)/735 - 1368576*lm^2 + 
           (18316744321*Pi^2)/13230 + (266797443528352232*
             Im[PolyLog[2, (-1)^(1/3)]])/(158196699675*Sqrt[3]) - 
           228096*Zeta[3]) + CA*NC*(-11033669308065597094529/
            2679852092494500 + (9154948396*lm)/6615 + 209088*lm^2 - 
           (132021860557*Pi^2)/198450 - (133398721764176116*
             Im[PolyLog[2, (-1)^(1/3)]])/(158196699675*Sqrt[3]) + 
           114048*Zeta[3])), (-305559839058298503133602555563*CF^2*NC)/
        32091336001705337280000 - (13442554039*CF^2*lm*NC)/5292 - 
       (7905216*CF^2*lm^2*NC)/5 - (592253117346540001001*CF*NM*NC)/
        23962504104000 - (117762673907*CF*lm*NM*NC)/952560 - 
       (658768*CF*lm^2*NM*NC)/15 + (23311656937669*CF*NC*NL)/166698000 - 
       (117762673907*CF*lm*NC*NL)/952560 - (658768*CF*lm^2*NC*NL)/15 + 
       (5472796413873373098592311890249*CF*NC*NH)/251802375699095092872000 - 
       (117762673907*CF*lm*NC*NH)/952560 - (658768*CF*lm^2*NC*NH)/15 + 
       (835093173367114693*CF^2*NC*Pi^2)/71513442000 + 4840*CF^2*lm*NC*Pi^2 + 
       (257134071428*CF*NM*NC*Pi^2)/8505 + (1210*CF*lm*NM*NC*Pi^2)/9 - 
       (144902362*CF*NC*NL*Pi^2)/2835 + (1210*CF*lm*NC*NL*Pi^2)/9 + 
       (1210*CF*lm*NC*NH*Pi^2)/9 - (5133600463725056063*CF^2*NC*Pi^3)/
        (17573393381040*Sqrt[3]) - (204066173139204985*CF*NC*NH*Pi^3)/
        (62762119218*Sqrt[3]) - (72715907*CF^2*NC*Pi^4)/6300 + 
       (72840822650634646841857*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (10763703445887000*Sqrt[3]) + (2632909372963433870*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(219667417263*Sqrt[3]) - 
       (57619628*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
       (5133600463725056063*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (474590099025*Sqrt[3]) - (46643696717532568*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(387420489*Sqrt[3]) - 
       (5133600463725056063*CF^2*NC*Pi*Log[3]^2)/(22780324753200*Sqrt[3]) - 
       (5830462089691571*CF*NC*NH*Pi*Log[3]^2)/(2324522934*Sqrt[3]) - 
       (CF*NC*(CA*(9113622667090474 - 289443288634500*lm) + 
          13*CF*(-1253059030596169 + 145733683788000*lm) + 
          175*(13*(-22537654590263 + 23132330760*lm)*NM + 
            1430*(280647461 + 210293916*lm)*NL + 
            (33980656169 + 300720299880*lm)*NH))*Log[x]^2)/141891750 + 
       (CF*NC*(-270687684929*CA + 4*(66703728689*CF + 
            350*(963172932*NM + 2503499*NL)))*Log[x]^3)/14175 + 
       (114129427827973713739*CF^2*NC*PolyGamma[2, 1])/19770067553670 + 
       (541140038393*CF*NM*NC*PolyGamma[2, 1])/28350 - 
       (112738244231534592851*CF*NC*NH*PolyGamma[2, 1])/98850337768350 - 
       (3180824709078320629036*CF^2*NC*Zeta[3])/345976182189225 - 
       (95487315907*CF*NM*NC*Zeta[3])/14175 - (14448404*CF*NC*NL*Zeta[3])/
        27 + (369556771354656506749*CF*NC*NH*Zeta[3])/49425168884175 + 
       CF*Log[x]*((54552005990439829*NM*NC)/216112050 - 
         (427628311*lm*NM*NC)/945 - 81312*lm^2*NM*NC - 
         (38524641677*NC*NL)/31752 - (427628311*lm*NC*NL)/945 - 
         81312*lm^2*NC*NL - (686363964055917878368481*NC*NH)/
          29114678804886675 - (427628311*lm*NC*NH)/945 - 81312*lm^2*NC*NH + 
         23761222*NM*NC*Pi^2 - (7202422*NC*NL*Pi^2)/81 + 
         (46643696717532568*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1162261467*Sqrt[3]) + CF*NC*(551659838286742623250121467/
            6753227273086140000 - (1339120684*lm)/105 - 2927232*lm^2 + 
           (101378466641*Pi^2)/11340 + (5133600463725056063*
             Im[PolyLog[2, (-1)^(1/3)]])/(1423770297075*Sqrt[3]) - 
           487872*Zeta[3]) + CA*NC*(-54705938353846631239899727/
            1350645454617228000 + (5779669181*lm)/1890 + 447216*lm^2 - 
           (3493340255983*Pi^2)/793800 - (5133600463725056063*
             Im[PolyLog[2, (-1)^(1/3)]])/(2847540594150*Sqrt[3]) + 
           243936*Zeta[3])) + CA*CF*NC*((3623224*lm^2)/15 + 
         lm*(376214211197/381024 - (6655*Pi^2)/9) + 
         (334365020201477632511541436839 - 419348587242093909516040111110*
            Pi^2 + 3515487030758686529414368500*Sqrt[3]*Pi^3 + 
           424471568349155039310351600*Pi^4 - 81438953356315560555069800280*
            Sqrt[3]*Im[PolyLog[2, (-1)^(1/3)]] + 
           59435062792755071775689952000*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
           130173462624664506917743473600*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] + 
           2711947138013843894119655700*Sqrt[3]*Pi*Log[3]^2 - 
           208415400298353293817627548000*PolyGamma[2, 1] + 
           365329496469169736688466805600*Zeta[3])/72205506003837008880000), 
      (-105876468538029555305392910159009521*CF^2*NC)/
        11844783752885433168698880000 - (4812901615241*CF^2*lm*NC)/1481760 - 
       (73645506*CF^2*lm^2*NC)/35 - (787833078445667430085445849*CF*NM*NC)/
        17688928829539968000 - (8580311120177*CF*lm*NM*NC)/53343360 - 
       (4091417*CF*lm^2*NM*NC)/70 + (5280199873094479*CF*NC*NL)/
        22404211200 - (8580311120177*CF*lm*NC*NL)/53343360 - 
       (4091417*CF*lm^2*NC*NL)/70 + (359560656601879748128159475546639*CF*NC*
         NH)/12086514033556564457856000 - (8580311120177*CF*lm*NC*NH)/
        53343360 - (4091417*CF*lm^2*NC*NH)/70 + 
       (92157420651824504029*CF^2*NC*Pi^2)/3432645216000 + 
       (36905*CF^2*lm*NC*Pi^2)/7 + (12390817990211*CF*NM*NC*Pi^2)/952560 + 
       (36905*CF*lm*NM*NC*Pi^2)/252 - (6590799809*CF*NC*NL*Pi^2)/95256 + 
       (36905*CF*lm*NC*NL*Pi^2)/252 + (36905*CF*lm*NC*NH*Pi^2)/252 - 
       (96976454644180913951*CF^2*NC*Pi^3)/(210880720572480*Sqrt[3]) - 
       (1593033089611587935*CF*NC*NH*Pi^3)/(376572715308*Sqrt[3]) - 
       (3423220097*CF^2*NC*Pi^4)/226800 + (2586976572108806431365353*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(258328882701288000*Sqrt[3]) + 
       (1061555292240557548363*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (92260315250460*Sqrt[3]) - (238936819*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - 
       (96976454644180913951*CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (5695081188300*Sqrt[3]) - (1274426471689270348*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(8135830269*Sqrt[3]) - 
       (96976454644180913951*CF^2*NC*Pi*Log[3]^2)/(273363897038400*Sqrt[3]) - 
       (318606617922317587*CF*NC*NH*Pi*Log[3]^2)/(97629963228*Sqrt[3]) - 
       (CF*NC*(CA*(43809448714578041219 - 827005827479832000*lm) + 
          2*(CF*(-41221146031003428071 + 2706564526297632000*lm) + 
            10500*((-2097956796413447 + 7160223614544*lm)*NM + 
              1716*(5565658369 + 4172624484*lm)*NL + 7*(123153544861 + 
                1022889087792*lm)*NH)))*Log[x]^2)/286053768000 + 
       (CF*NC*(-49293484366591*CA + 65659830625244*CF + 
          8400*(7862237397*NM + 49674101*NL))*Log[x]^3)/1190700 + 
       (116747098425825945910901*CF^2*NC*PolyGamma[2, 1])/8303428372541400 + 
       (1617611245561*CF*NM*NC*PolyGamma[2, 1])/99225 - 
       (9856100292785413678031*CF*NC*NH*PolyGamma[2, 1])/8303428372541400 - 
       (18695205795201834638861*CF^2*NC*Zeta[3])/1186204053220200 + 
       (861493954397*CF*NM*NC*Zeta[3])/99225 - (142491115*CF*NC*NL*Zeta[3])/
        189 + (46042389586714325532169*CF*NC*NH*Zeta[3])/4151714186270700 + 
       CA*CF*NC*(101489710154399363503204224686206747/
          23689567505770866337397760000 + (45005587*lm^2)/140 - 
         (103139554485651839*Pi^2)/7705152000 + (96976454644180913951*Pi^3)/
          (421761441144960*Sqrt[3]) + (3476363297*Pi^4)/453600 + 
         lm*(138033408310171/106686720 - (405955*Pi^2)/504) - 
         (2586976572108806431365353*Im[PolyLog[2, (-1)^(1/3)]])/
          (516657765402576000*Sqrt[3]) + 
         (238936819*Im[PolyLog[2, (-1)^(1/3)]]^2)/210 + 
         (96976454644180913951*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (11390162376600*Sqrt[3]) + (96976454644180913951*Pi*Log[3]^2)/
          (546727794076800*Sqrt[3]) - (116747098425825945910901*
           PolyGamma[2, 1])/16606856745082800 + 
         (140677485379178019709169*Zeta[3])/16606856745082800) + 
       CF*Log[x]*((633737113072432252811*NM*NC)/24543413294400 - 
         (97673223373*lm*NM*NC)/158760 - 113256*lm^2*NM*NC - 
         (7433503460921*NC*NL)/4445280 - (97673223373*lm*NC*NL)/158760 - 
         113256*lm^2*NC*NL - (171511025404368440514442757*NC*NH)/
          5590018330538241600 - (97673223373*lm*NC*NH)/158760 - 
         113256*lm^2*NC*NH + (2616618892*NM*NC*Pi^2)/189 - 
         (71079485*NC*NL*Pi^2)/567 + (1274426471689270348*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(24407490807*Sqrt[3]) + 
         CF*NC*(1555476608069649245015189034263/6847772454909345960000 - 
           (75946758613*lm)/4410 - 4077216*lm^2 + (3770767610003*Pi^2)/
            190512 + (96976454644180913951*Im[PolyLog[2, (-1)^(1/3)]])/
            (17085243564900*Sqrt[3]) - 679536*Zeta[3]) + 
         CA*NC*(-1237679550192778640032385059237/10956435927854953536000 + 
           (1326132772943*lm)/317520 + 622908*lm^2 - (93444402274691*Pi^2)/
            9525600 - (96976454644180913951*Im[PolyLog[2, (-1)^(1/3)]])/
            (34170487129800*Sqrt[3]) + 339768*Zeta[3])), 
      (-314433514676798868772143652106858059*CF^2*NC)/
        1692111964697919024099840000 - (14986266209*CF^2*lm*NC)/2352 - 
       (19828116*CF^2*lm^2*NC)/5 - (19243456756231524350979713*CF*NM*NC)/
        46796108014656000 - (131282836717*CF*lm*NM*NC)/423360 - 
       (550781*CF*lm^2*NM*NC)/5 + (85474884768697*CF*NC*NL)/148176000 - 
       (131282836717*CF*lm*NC*NL)/423360 - (550781*CF*lm^2*NC*NL)/5 + 
       (386600203127272645970087381132540861*CF*NC*NH)/
        5938104344686340118144652800 - (131282836717*CF*lm*NC*NH)/423360 - 
       (550781*CF*lm^2*NC*NH)/5 + (1637689247778735839*CF^2*NC*Pi^2)/
        10216206000 + 10890*CF^2*lm*NC*Pi^2 + (236927888519*CF*NM*NC*Pi^2)/
        540 + (605*CF*lm*NM*NC*Pi^2)/2 - (1070429393*CF*NC*NL*Pi^2)/7560 + 
       (605*CF*lm*NC*NL*Pi^2)/2 + (605*CF*lm*NC*NH*Pi^2)/2 - 
       (6923576675525472317*CF^2*NC*Pi^3)/(7531454306160*Sqrt[3]) - 
       (1823172211510812365*CF*NC*NH*Pi^3)/(188286357654*Sqrt[3]) - 
       (90155263*CF^2*NC*Pi^4)/2700 + (87082272060250758354853*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(4613015762523000*Sqrt[3]) + 
       (117404666218000101497*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (3295011258945*Sqrt[3]) - (22436084*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - (6923576675525472317*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(203395756725*Sqrt[3]) - 
       (416725076916757112*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (1162261467*Sqrt[3]) - (6923576675525472317*CF^2*NC*Pi*Log[3]^2)/
        (9762996322800*Sqrt[3]) - (52090634614594639*CF*NC*NH*Pi*Log[3]^2)/
        (6973568802*Sqrt[3]) + CF*((784857379551879631*CF*NC)/425675250 - 
         42447024*CF*lm*NC + CA*(-11248107430183243721/11918907000 + 
           6484962*lm)*NC + (189565562219435*NM*NC)/36036 - 
         1179084*lm*NM*NC - (98686585*NC*NL)/63 - 1179084*lm*NC*NL - 
         (7500312283*NC*NH)/48620 - 1179084*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-16471039487477*CA + 56*(507328564633*CF + 
            9450*(166737071*NM + 98257*NL)))*Log[x]^3)/66150 + 
       (196518120875503013089*CF^2*NC*PolyGamma[2, 1])/2278032475320 + 
       (1219864372429*CF*NM*NC*PolyGamma[2, 1])/4725 - 
       (494154253091422447903*CF*NC*NH*PolyGamma[2, 1])/148275506652525 - 
       (459000346541004941503*CF^2*NC*Zeta[3])/5695081188300 - 
       (670067871292*CF*NM*NC*Zeta[3])/4725 - 1635738*CF*NC*NL*Zeta[3] + 
       (3278117345353839008494*CF*NC*NH*Zeta[3])/148275506652525 + 
       CA*CF*NC*(218959565615348248918689211459256083/
          2368956750577086633739776000 + (6058591*lm^2)/10 - 
         (1388042874018664349*Pi^2)/17336592000 + (6923576675525472317*Pi^3)/
          (15062908612320*Sqrt[3]) + (91462063*Pi^4)/5400 + 
         lm*(419402281507/169344 - (6655*Pi^2)/4) - 
         (87082272060250758354853*Im[PolyLog[2, (-1)^(1/3)]])/
          (9226031525046000*Sqrt[3]) + (11218042*Im[PolyLog[2, (-1)^(1/3)]]^
            2)/5 + (6923576675525472317*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(406791513450*Sqrt[3]) + 
         (6923576675525472317*Pi*Log[3]^2)/(19525992645600*Sqrt[3]) - 
         (196518120875503013089*PolyGamma[2, 1])/4556064950640 + 
         (474419078224041841447*Zeta[3])/11390162376600) + 
       CF*Log[x]*((48538312012403156887*NM*NC)/12985932960 - 
         (1609427809*lm*NM*NC)/1260 - 226512*lm^2*NM*NC - 
         (782091895*NC*NL)/216 - (1609427809*lm*NC*NL)/1260 - 
         226512*lm^2*NC*NL - (56735079617701506088523035319*NC*NH)/
          807757648762775911200 - (1609427809*lm*NC*NH)/1260 - 
         226512*lm^2*NC*NH + 333463376*NM*NC*Pi^2 - 272018*NC*NL*Pi^2 + 
         (416725076916757112*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (3486784401*Sqrt[3]) + CF*NC*(154490350110670952806532363113/
            122281650980524035000 - (1264563289*lm)/35 - 8154432*lm^2 + 
           (347256378097*Pi^2)/2835 + (6923576675525472317*
             Im[PolyLog[2, (-1)^(1/3)]])/(610187270175*Sqrt[3]) - 
           1359072*Zeta[3]) + CA*NC*(-123386863890742255980145770341/
            195650641568838456000 + (21699377579*lm)/2520 + 1245816*lm^2 - 
           (12113010457487*Pi^2)/198450 - (6923576675525472317*
             Im[PolyLog[2, (-1)^(1/3)]])/(1220374540350*Sqrt[3]) + 
           679536*Zeta[3])), (-22950819252575300277543803757168642743*CF^2*
         NC)/106603053775968898518289920000 - (2178234677033*CF^2*lm*NC)/
        277830 - (177512016*CF^2*lm^2*NC)/35 - 
       (7012178762552066753187431*CF*NM*NC)/13648864837608000 - 
       (3880885556501*CF*lm*NM*NC)/10001880 - (14792668*CF*lm^2*NM*NC)/
        105 + (2190536601455473*CF*NC*NL)/2520473760 - 
       (3880885556501*CF*lm*NC*NL)/10001880 - (14792668*CF*lm^2*NC*NL)/
        105 + (219126478306911510294066007477562861*CF*NC*NH)/
        2569372072220051012658744000 - (3880885556501*CF*lm*NC*NH)/
        10001880 - (14792668*CF*lm^2*NC*NH)/105 + 
       (360372385579386435841*CF^2*NC*Pi^2)/858161304000 + 
       (242000*CF^2*lm*NC*Pi^2)/21 + (1570954275713*CF*NM*NC*Pi^2)/19845 + 
       (60500*CF*lm*NM*NC*Pi^2)/189 - (3641856284*CF*NC*NL*Pi^2)/19845 + 
       (60500*CF*lm*NC*NL*Pi^2)/189 + (60500*CF*lm*NC*NH*Pi^2)/189 - 
       (323175490086253551113*CF^2*NC*Pi^3)/(237240810644040*Sqrt[3]) - 
       (10265379338563650880*CF*NC*NH*Pi^3)/(847288609443*Sqrt[3]) - 
       (1192840429*CF^2*NC*Pi^4)/28350 + (7775429030622352353465779*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(290619993038949000*Sqrt[3]) + 
       (7019774680825841236172*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (207585709313535*Sqrt[3]) - (623115064*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - (646350980172507102226*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(12813932673675*Sqrt[3]) - 
       (32849213883403682816*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (73222472421*Sqrt[3]) - (323175490086253551113*CF^2*NC*Pi*Log[3]^2)/
        (307534384168200*Sqrt[3]) - (2053075867712730176*CF*NC*NH*Pi*
         Log[3]^2)/(219667417263*Sqrt[3]) - 
       (CF*NC*(-17*CA*(-89250057364131918733 + 313261958305296000*lm) + 
          28*(17*CF*(-6304462836583101643 + 73230068175264000*lm) + 
            300*(765*(-89263757382857 + 150679152624*lm)*NM + 
              13*(3366*(3498425503 + 2634250920*lm)*NL + 7*(174758678263 + 
                  1266698370960*lm)*NH))))*Log[x]^2)/607864257000 + 
       (2*CF*NC*(-91820383521607*CA + 18*(9433408732141*CF + 
            2800*(1139355336*NM + 3136013*NL)))*Log[x]^3)/297675 + 
       (8168624806141777981140947*CF^2*NC*PolyGamma[2, 1])/
        37365427676436300 + (28166553730457*CF*NM*NC*PolyGamma[2, 1])/
        198450 - (125625629937586676546333*CF*NC*NH*PolyGamma[2, 1])/
        37365427676436300 - (1735559058614250554859851*CF^2*NC*Zeta[3])/
        9341356919109075 + (10216487865257*CF*NM*NC*Zeta[3])/99225 - 
       (46216144*CF*NC*NL*Zeta[3])/21 + (585564487390031843676067*CF*NC*NH*
         Zeta[3])/18682713838218150 + CA*CF*NC*
        (5703873610283444709353480468753918777/
          53301526887984449259144960000 + (81359674*lm^2)/105 - 
         (8186299554189540179*Pi^2)/39007332000 + 
         (323175490086253551113*Pi^3)/(474481621288080*Sqrt[3]) + 
         (1207360429*Pi^4)/56700 + lm*(62417006483623/20003760 - 
           (332750*Pi^2)/189) - (7775429030622352353465779*
           Im[PolyLog[2, (-1)^(1/3)]])/(581239986077898000*Sqrt[3]) + 
         (311557532*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 + 
         (323175490086253551113*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (12813932673675*Sqrt[3]) + (323175490086253551113*Pi*Log[3]^2)/
          (615068768336400*Sqrt[3]) - (8168624806141777981140947*
           PolyGamma[2, 1])/74730855352872600 + 
         (3532910587665913956828139*Zeta[3])/37365427676436300) + 
       CF*Log[x]*((-5848917131725387133*NM*NC)/20452844412 - 
         (10996203922*lm*NM*NC)/6615 - 302016*lm^2*NM*NC - 
         (59724724010401*NC*NL)/12502350 - (10996203922*lm*NC*NL)/6615 - 
         302016*lm^2*NC*NL - (6144940954970398839826122283*NC*NH)/
          69902104219855607700 - (10996203922*lm*NC*NH)/6615 - 
         302016*lm^2*NC*NH + (6077058976*NM*NC*Pi^2)/63 - 
         (69203216*NC*NL*Pi^2)/189 + (32849213883403682816*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(219667417263*Sqrt[3]) + 
         CF*NC*(476291709718354608873862061012789/123259904188368227280000 - 
           (34328609128*lm)/735 - 10872576*lm^2 + (18194948922461*Pi^2)/
            59535 + (646350980172507102226*Im[PolyLog[2, (-1)^(1/3)]])/
            (38441798021025*Sqrt[3]) - 1812096*Zeta[3]) + 
         CA*NC*(-47586151116898556560234863406643/24651980837673645456000 + 
           (74463972451*lm)/6615 + 1661088*lm^2 - (12975306628973*Pi^2)/
            85050 - (323175490086253551113*Im[PolyLog[2, (-1)^(1/3)]])/
            (38441798021025*Sqrt[3]) + 906048*Zeta[3])), 
      (-943078808873623531386983704247242913611*CF^2*NC)/
        319809161327906695554869760000 - (13957756087909*CF^2*lm*NC)/952560 - 
       (45598696*CF^2*lm^2*NC)/5 - (2713079371480624830152069899*CF*NM*NC)/
        421164972131904000 - (24454667104501*CF*lm*NM*NC)/34292160 - 
       (11399674*CF*lm^2*NM*NC)/45 + (8668143264345689*CF*NC*NL)/
        4500846000 - (24454667104501*CF*lm*NC*NL)/34292160 - 
       (11399674*CF*lm^2*NC*NL)/45 + 
       (138689486204255971376958929207993248234961*CF*NC*NH)/
        785496684218212418213973347136000 - (24454667104501*CF*lm*NC*NH)/
        34292160 - (11399674*CF*lm^2*NC*NH)/45 + 
       (125516628618671360836289*CF^2*NC*Pi^2)/58354968672000 + 
       (204490*CF^2*lm*NC*Pi^2)/9 + (641374196938847*CF*NM*NC*Pi^2)/102060 + 
       (102245*CF*lm*NM*NC*Pi^2)/162 - (72755420023*CF*NC*NL*Pi^2)/204120 + 
       (102245*CF*lm*NC*NL*Pi^2)/162 + (102245*CF*lm*NC*NH*Pi^2)/162 - 
       (14695320070009744910351*CF^2*NC*Pi^3)/(5693779455456960*Sqrt[3]) - 
       (66397076993166238340*CF*NC*NH*Pi^3)/(2541865828329*Sqrt[3]) - 
       (19733353211*CF^2*NC*Pi^4)/226800 + (335756387827376333947527353*CF^2*
         NC*Im[PolyLog[2, (-1)^(1/3)]])/(6974879832934776000*Sqrt[3]) + 
       (8570266559552553863023*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (88965303991515*Sqrt[3]) - (3509551331*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/315 - (14695320070009744910351*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(153767192084100*Sqrt[3]) - 
       (30352949482590280384*CF*NC*NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (31381059609*Sqrt[3]) - (14695320070009744910351*CF^2*NC*Pi*Log[3]^2)/
        (7380825220036800*Sqrt[3]) - (1897059342661892524*CF*NC*NH*Pi*
         Log[3]^2)/(94143178827*Sqrt[3]) - 
       (CF*NC*(-6783*CA*(-175105819344451718917 + 251088496731072000*lm) + 
          10982*CF*(-215258325427350078079 + 1015095740795136000*lm) + 
          58800*(1615*(-73360564485026015 + 3260889567936*lm)*NM + 
            7205484*(967951879 + 730878960*lm)*NL + 
            163*(4762062059917 + 32308813817280*lm)*NH))*Log[x]^2)/
        92395367064000 + (CF*NC*(-5948267038342237*CA + 11513374514621978*
           CF + 57506400*(589264059*NM + 69394*NL))*Log[x]^3)/1786050 + 
       (528602354145718677857641459*CF^2*NC*PolyGamma[2, 1])/
        448385132117235600 + (49986272526944*CF*NM*NC*PolyGamma[2, 1])/
        14175 - (7079161899680006384531*CF*NC*NH*PolyGamma[2, 1])/
        800687735923635 - (11008801407140484639747379*CF^2*NC*Zeta[3])/
        11209628302930890 - (34131747987362*CF*NM*NC*Zeta[3])/14175 - 
       (40537718*CF*NC*NL*Zeta[3])/9 + (47287685837752113777458*CF*NC*NH*
         Zeta[3])/800687735923635 + CF*Log[x]*
        ((93428795246487147996833*NM*NC)/1753100949600 - 
         (111068965579*lm*NM*NC)/34020 - 572572*lm^2*NM*NC - 
         (139511163056651*NC*NL)/14288400 - (111068965579*lm*NC*NL)/34020 - 
         572572*lm^2*NC*NL - (298459446378979005543380262671777*NC*NH)/
          1574642760498155361293280 - (111068965579*lm*NC*NH)/34020 - 
         572572*lm^2*NC*NH + (14229951542*NM*NC*Pi^2)/3 - 
         (60704332*NC*NL*Pi^2)/81 + (30352949482590280384*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(94143178827*Sqrt[3]) + 
         CF*NC*(12444704388458493094178097450227327/
            739559425130209363680000 - (87531962089*lm)/945 - 20612592*lm^2 + 
           (4741836625288909*Pi^2)/2857680 + (14695320070009744910351*
             Im[PolyLog[2, (-1)^(1/3)]])/(461301576252300*Sqrt[3]) - 
           3435432*Zeta[3]) + CA*NC*(-2488074626741003898737213030848429/
            295823770052083745472000 + (1494463213529*lm)/68040 + 
           3149146*lm^2 - (23693247643405169*Pi^2)/28576800 - 
           (14695320070009744910351*Im[PolyLog[2, (-1)^(1/3)]])/
            (922603152504600*Sqrt[3]) + 1717716*Zeta[3])) + 
       CA*CF*NC*((62698207*lm^2)/45 - (1911889993212279137*Pi^2)/1778112000 + 
         (14695320070009744910351*Pi^3)/(11387558910913920*Sqrt[3]) + 
         (6654127337*Pi^4)/151200 + lm*(390620720962439/68584320 - 
           (1124695*Pi^2)/324) + (14695320070009744910351*Pi*Log[3]^2)/
          (14761650440073600*Sqrt[3]) + 
         (605638555399324898463845970266920328799 - 
           3298919163387216322342022317602478560*Sqrt[3]*
            Im[PolyLog[2, (-1)^(1/3)]] + 
           2290585036335405450670214183142144000*Im[PolyLog[2, (-1)^(1/3)]]^
             2 + 6549369383867792331650462241086707200*Sqrt[3]*
            Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]] - 
           242372456020032285802499032758408438400*PolyGamma[2, 1] + 
           203389541812491813796898344819337382400*Zeta[3])/
          411183207421594322856261120000), 
      (-1187772215294741605840411612793196136073*CF^2*NC)/
        282766873556492386578316800000 - (873185260161743*CF^2*lm*NC)/
        50009400 - (78985764*CF^2*lm^2*NC)/7 - 
       (371685960657120502559746475720387*CF*NM*NC)/
        72421422782941552320000 - (1555035791824043*CF*lm*NM*NC)/
        1800338400 - (2194049*CF*lm^2*NM*NC)/7 + 
       (3402184716357882461*CF*NC*NL)/1260236880000 - 
       (1555035791824043*CF*lm*NC*NL)/1800338400 - (2194049*CF*lm^2*NC*NL)/
        7 + (2042720262969878157405494023735556272672583*CF*NC*NH)/
        9164127982545811545829689049920000 - (1555035791824043*CF*lm*NC*NH)/
        1800338400 - (2194049*CF*lm^2*NC*NH)/7 + 
       (1144278993545911125020137*CF^2*NC*Pi^2)/175064906016000 + 
       (22166716*CF^2*lm*NC*Pi^2)/945 - (1089270716878997*CF*NM*NC*Pi^2)/
        5358150 + (5541679*CF*lm*NM*NC*Pi^2)/8505 - 
       (4774386062303*CF*NC*NL*Pi^2)/10716300 + (5541679*CF*lm*NC*NL*Pi^2)/
        8505 + (5541679*CF*lm*NC*NH*Pi^2)/8505 - 
       (109717259149285400437*CF^2*NC*Pi^3)/(30125817224640*Sqrt[3]) - 
       (107168617383958559479*CF*NC*NH*Pi^3)/(3389154437772*Sqrt[3]) - 
       (72275188271*CF^2*NC*Pi^4)/680400 + (161875902513392948432309*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2460275073345600*Sqrt[3]) + 
       (18788841021573662132552*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (207585709313535*Sqrt[3]) - (639091739*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - (109717259149285400437*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(813583026900*Sqrt[3]) - 
       (428674469535834237916*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(366112362105*Sqrt[3]) - 
       (109717259149285400437*CF^2*NC*Pi*Log[3]^2)/(39051985291200*Sqrt[3]) - 
       (107168617383958559479*CF*NC*NH*Pi*Log[3]^2)/(4393348345260*
         Sqrt[3]) - (CF*NC*(-19*CA*(-571214003909773774170037 + 
            349068920842254412800*lm) + 
          14*(133*CF*(-11634828954956790160283 + 23314436271467827200*lm) + 
            120*(19*(21331343174449841521 + 37778021736174720*lm)*NM + 
              21616452*(43962681353 + 33205375840*lm)*NL + 
              21*(5270981197343639 + 34180114904158080*lm)*NH)))*Log[x]^2)/
        277186101192000 + (CF*NC*(-8529585707893073*CA + 16809921995957991*
           CF + 858225640713840*NM + 2590019315520*NL)*Log[x]^3)/893025 + 
       (745283154005500568209185881*CF^2*NC*PolyGamma[2, 1])/
        224192566058617800 + (90906097838747*CF*NM*NC*PolyGamma[2, 1])/
        95256 - (1947038771168147131623563*CF*NC*NH*PolyGamma[2, 1])/
        224192566058617800 - (653872416800355396589951679*CF^2*NC*Zeta[3])/
        224192566058617800 + (348147942954367*CF*NM*NC*Zeta[3])/238140 - 
       (5509880636*CF*NC*NL*Zeta[3])/945 + (9037450569301679716602997*CF*NC*
         NH*Zeta[3])/112096283029308900 + 
       CA*CF*NC*(14537116538287576711005348598308015219209/
          6927788402134063471168761600000 + (24134539*lm^2)/14 - 
         (470666877474281060611*Pi^2)/144027072000 + 
         (109717259149285400437*Pi^3)/(60251634449280*Sqrt[3]) + 
         (72984523183*Pi^4)/1360800 + lm*(25005455042427673/3600676800 - 
           (60958469*Pi^2)/17010) - (161875902513392948432309*
           Im[PolyLog[2, (-1)^(1/3)]])/(4920550146691200*Sqrt[3]) + 
         (639091739*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 + 
         (109717259149285400437*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1627166053800*Sqrt[3]) + (109717259149285400437*Pi*Log[3]^2)/
          (78103970582400*Sqrt[3]) - (745283154005500568209185881*
           PolyGamma[2, 1])/448385132117235600 + 
         (26230935628338877175784185*Zeta[3])/17935405284689424) + 
       CF*Log[x]*((-343789687363393380287928773*NM*NC)/26598924157806000 - 
         (3658604371708*lm*NM*NC)/893025 - 736164*lm^2*NM*NC - 
         (6210708180965761*NC*NL)/500094000 - (3658604371708*lm*NC*NL)/
          893025 - 736164*lm^2*NC*NL - (13444574774148294626470454946773*NC*
           NH)/58580459839961136952875 - (3658604371708*lm*NC*NH)/893025 - 
         736164*lm^2*NC*NH + (681685257023*NM*NC*Pi^2)/2835 - 
         (8253737596*NC*NL*Pi^2)/8505 + (428674469535834237916*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(1098337086315*Sqrt[3]) + 
         CF*NC*(475921878750312374913632370770284693/
            7916024957875203929760000 - (11456922015682*lm)/99225 - 
           26501904*lm^2 + (68123063424829523*Pi^2)/14288400 + 
           (109717259149285400437*Im[PolyLog[2, (-1)^(1/3)]])/
            (2440749080700*Sqrt[3]) - 4416984*Zeta[3]) + 
         CA*NC*(-475849745113058582872823412915744217/
            15832049915750407859520000 + (24724214037094*lm)/893025 + 
           4048902*lm^2 - (68104583811999947*Pi^2)/28576800 - 
           (109717259149285400437*Im[PolyLog[2, (-1)^(1/3)]])/
            (4881498161400*Sqrt[3]) + 2208492*Zeta[3])), 
      (-10929488647971633286664319245256456124514057*CF^2*NC)/
        254639886310373055654555993600000 - (3048900305921*CF^2*lm*NC)/
        97200 - 19523504*CF^2*lm^2*NC - (1019468455529471045707983428503357*
         CF*NM*NC)/10345917540420221760000 - (5341935850721*CF*lm*NM*NC)/
        3499200 - (4880876*CF*lm^2*NM*NC)/9 + (40978311778559983*CF*NC*NL)/
        7348320000 - (5341935850721*CF*lm*NC*NL)/3499200 - 
       (4880876*CF*lm^2*NC*NL)/9 + 
       (327204912798494188149616751915803108111754371*CF*NC*NH)/
        742294366586210735212204813043520000 - (5341935850721*CF*lm*NC*NH)/
        3499200 - (4880876*CF*lm^2*NC*NH)/9 + 
       (11085882053222439187273*CF^2*NC*Pi^2)/396972576000 + 
       (2004002*CF^2*lm*NC*Pi^2)/45 + (45217180710677197*CF*NM*NC*Pi^2)/
        510300 + (1002001*CF*lm*NM*NC*Pi^2)/810 - 
       (120878228471*CF*NC*NL*Pi^2)/145800 + (1002001*CF*lm*NC*NL*Pi^2)/
        810 + (1002001*CF*lm*NC*NH*Pi^2)/810 - 
       (145036958952235406383313*CF^2*NC*Pi^3)/(21961720756762560*Sqrt[3]) - 
       (17819177406142878487673*CF*NC*NH*Pi^3)/(274521509459532*Sqrt[3]) - 
       (6744108371*CF^2*NC*Pi^4)/32400 + (437795175546877852787301809*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(3843301132433448000*Sqrt[3]) + 
       (577814397642877224476533*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (2402063207770905*Sqrt[3]) - (1152450299*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - (20719565564605058054759*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(84728860944300*Sqrt[3]) - 
       (10182387089224501992956*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4236443047215*Sqrt[3]) - 
       (20719565564605058054759*CF^2*NC*Pi*Log[3]^2)/(4066985325326400*
         Sqrt[3]) - (2545596772306125498239*CF*NC*NH*Pi*Log[3]^2)/
        (50837316566580*Sqrt[3]) - 
       (CF*NC*(-969*CA*(-2280630100763715431287 + 651023329790433600*lm) + 
          10*(323*CF*(-1367051373581258721347 + 1278373083952124160*lm) + 
            168*(19*(-439678171123097899303 + 3593310586505640*lm)*NM + 
              100876776*(894318967 + 676795035*lm)*NL + (11111039482163843 + 
                68272901143607160*lm)*NH)))*Log[x]^2)/13199338152000 + 
       (CF*NC*(-11142488583323089*CA + 22129898759742926*CF + 
          2520*(27168841854114*NM + 586555697*NL))*Log[x]^3)/255150 + 
       (37436391343807178343898914541*CF^2*NC*PolyGamma[2, 1])/
        2421279713433072240 + (1371261400860577*CF*NM*NC*PolyGamma[2, 1])/
        28350 - (4678807748149427352386839*CF*NC*NH*PolyGamma[2, 1])/
        216185688699381450 - (38642694309764964291522349541*CF^2*NC*Zeta[3])/
        3026599641791340300 - (529584590528243*CF*NM*NC*Zeta[3])/14175 - 
       (511945252*CF*NC*NL*Zeta[3])/45 + (15688547680208457731229641*CF*NC*
         NH*Zeta[3])/108092844349690725 + 
       CA*CF*NC*(9561405475099699883538446478161984447762113/
          445619801043152847395472988800000 + (26844818*lm^2)/9 - 
         (36176354486155094363*Pi^2)/2590963200 + 
         (145036958952235406383313*Pi^3)/(43923441513525120*Sqrt[3]) + 
         (50431381*Pi^4)/480 - (121*lm*(-705197343811 + 393513120*Pi^2))/
          6998400 - (437795175546877852787301809*Im[PolyLog[2, (-1)^(1/3)]])/
          (7686602264866896000*Sqrt[3]) + 
         (1152450299*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 + 
         (20719565564605058054759*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (169457721888600*Sqrt[3]) + (20719565564605058054759*Pi*Log[3]^2)/
          (8133970650652800*Sqrt[3]) - (37436391343807178343898914541*
           PolyGamma[2, 1])/4842559426866144480 + 
         (1934814977886044648022262093*Zeta[3])/302659964179134030) + 
       CF*Log[x]*((234370658056634814655123031*NM*NC)/316653859021500 - 
         (186873505247*lm*NM*NC)/24300 - (4008004*lm^2*NM*NC)/3 - 
         (494249108381591*NC*NL)/20412000 - (186873505247*lm*NC*NL)/24300 - 
         (4008004*lm^2*NC*NL)/3 - (125184859369947562950956719086446471*NC*
           NH)/265720965834063717218241000 - (186873505247*lm*NC*NH)/
          24300 - (4008004*lm^2*NC*NH)/3 + (3018786307417*NM*NC*Pi^2)/45 - 
         (766915877*NC*NL*Pi^2)/405 + (10182387089224501992956*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12709329141645*Sqrt[3]) + 
         CF*NC*(10237072062825810340785179417662583101/
            48493968019252299704160000 - (147645166097*lm)/675 - 
           48096048*lm^2 + (44538222307479773*Pi^2)/2041200 + 
           (20719565564605058054759*Im[PolyLog[2, (-1)^(1/3)]])/
            (254186582832900*Sqrt[3]) - 8016008*Zeta[3]) + 
         CA*NC*(-10236343715910166530141302412181104223/
            96987936038504599408320000 + (2510116211317*lm)/48600 + 
           (22044022*lm^2)/3 - (8906512040581681*Pi^2)/816480 - 
           (20719565564605058054759*Im[PolyLog[2, (-1)^(1/3)]])/
            (508373165665800*Sqrt[3]) + 4008004*Zeta[3])), 
      (-2520119576472705016216720078548203733958582965151*CF^2*NC)/
        32817224628021948293592212787187200000 - (53475389532889*CF^2*lm*NC)/
        1470150 - 23489232*CF^2*lm^2*NC - 
       (34094906690033389551011830134744203*CF*NM*NC)/
        806393731928889784680000 - (95202395296189*CF*lm*NM*NC)/52925400 - 
       (1957436*CF*lm^2*NM*NC)/3 + (320512676989950607*CF*NC*NL)/
        43222410000 - (95202395296189*CF*lm*NC*NL)/52925400 - 
       (1957436*CF*lm^2*NC*NL)/3 + 
       (13645874273337960854936491600381290381745573*CF*NC*NH)/
        25305489769984456882234254990120000 - (95202395296189*CF*lm*NC*NH)/
        52925400 - (1957436*CF*lm^2*NC*NH)/3 + 
       (571308367339192312323127*CF^2*NC*Pi^2)/5731291566000 + 
       (2025296*CF^2*lm*NC*Pi^2)/45 - (3746212502000993*CF*NM*NC*Pi^2)/
        200475 + (506324*CF*lm*NM*NC*Pi^2)/405 - 
       (201471186566*CF*NC*NL*Pi^2)/200475 + (506324*CF*lm*NC*NL*Pi^2)/
        405 + (506324*CF*lm*NC*NH*Pi^2)/405 - 
       (1621487173522163174074201*CF^2*NC*Pi^3)/(181184196243291120*
         Sqrt[3]) - (15726222163170507335858*CF*NC*NH*Pi^3)/
        (205891132094649*Sqrt[3]) - (2003185379*CF^2*NC*Pi^4)/8100 + 
       (10529900357276297032902466729*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (69755915553667081200*Sqrt[3]) + (1614143982197438722601404*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(7206189623312715*Sqrt[3]) - 
       (474640868*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (1621487173522163174074201*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4893091719533325*Sqrt[3]) - 
       (35945650658675445339104*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(12709329141645*Sqrt[3]) - 
       (1621487173522163174074201*CF^2*NC*Pi*Log[3]^2)/(234868402537599600*
         Sqrt[3]) - (2246603166167215333694*CF*NC*NH*Pi*Log[3]^2)/
        (38127987424935*Sqrt[3]) - 
       (CF*NC*(-57*CA*(-380772169278574597326643 + 38193497453397686400*lm) + 
          10*(19*CF*(-228390204535008856794059 + 74998140453944547840*lm) + 
            3696*(7*(31466537898788626219 + 1529930113877880*lm)*NM + 
              3*(1200914*(3926795801 + 2972599980*lm)*NL + 
                3*(201391767509197 + 1189945644127240*lm)*NH))))*Log[x]^2)/
        36298179918000 + (2*CF*NC*(-34281527760517524*CA + 
          68384643242981153*CF - 9019576613789280*NM + 1700327188560*NL)*
         Log[x]^3)/467775 + (455308597832530806075454056017*CF^2*NC*
         PolyGamma[2, 1])/9079798925374020900 + 
       (190614290603563*CF*NM*NC*PolyGamma[2, 1])/132300 - 
       (18862348309121588809412921*CF*NC*NH*PolyGamma[2, 1])/
        907979892537402090 - (2312744070568783764429950896811*CF^2*NC*
         Zeta[3])/49938894089557114950 + (490616913629561*CF*NM*NC*Zeta[3])/
        22050 - (213766592*CF*NC*NL*Zeta[3])/15 + 
       (87107248377694377489222247*CF*NC*NH*Zeta[3])/453989946268701045 + 
       CA*CF*NC*(866177170369486785904050031200121394868424359949/
          22561841931765089451844646291191200000 + (10765898*lm^2)/3 - 
         (2790240889265081890901*Pi^2)/55983312000 + 
         (1621487173522163174074201*Pi^3)/(362368392486582240*Sqrt[3]) + 
         (673129249*Pi^4)/5400 + lm*(139153097291389/9622800 - 
           (2784782*Pi^2)/405) - (10529900357276297032902466729*
           Im[PolyLog[2, (-1)^(1/3)]])/(139511831107334162400*Sqrt[3]) + 
         (237320434*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (1621487173522163174074201*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (9786183439066650*Sqrt[3]) + (1621487173522163174074201*Pi*
           Log[3]^2)/(469736805075199200*Sqrt[3]) - 
         (455308597832530806075454056017*PolyGamma[2, 1])/
          18159597850748041800 + (1156876141300315896068990641819*Zeta[3])/
          49938894089557114950) + CF*Log[x]*
        ((-16423363772144550725611257401*NM*NC)/57156021553380750 - 
         (4377082325278*lm*NM*NC)/467775 - 1665664*lm^2*NM*NC - 
         (93100057740689*NC*NL)/3118500 - (4377082325278*lm*NC*NL)/467775 - 
         1665664*lm^2*NC*NL - (55253502191622342011370616952213218*NC*NH)/
          99645362187773893956840375 - (4377082325278*lm*NC*NH)/467775 - 
         1665664*lm^2*NC*NH - (3904226828936*NM*NC*Pi^2)/405 - 
         (960937016*NC*NL*Pi^2)/405 + (35945650658675445339104*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(38127987424935*Sqrt[3]) + 
         CF*NC*(9291770953344751165362463255407091190069/
            10337944102344205250932828800 - (13742408742712*lm)/51975 - 
           59963904*lm^2 + (137088111927088349*Pi^2)/1871100 + 
           (1621487173522163174074201*Im[PolyLog[2, (-1)^(1/3)]])/
            (14679275158599975*Sqrt[3]) - 9993984*Zeta[3]) + 
         CA*NC*(-14518035478285731341375433785627404974191/
            32306075319825641409165090000 + (2684367693839*lm)/42525 + 
           9161152*lm^2 - (45694090590498733*Pi^2)/1247400 - 
           (1621487173522163174074201*Im[PolyLog[2, (-1)^(1/3)]])/
            (29358550317199950*Sqrt[3]) + 4996992*Zeta[3])), 
      (-192892281067227366809378000123040814482649193235259*CF^2*NC)/
        326609521297932723493370117739148800000 - (3305067327785*CF^2*lm*NC)/
        52272 - (196786044*CF^2*lm^2*NC)/5 - 
       (18573250681349542377987152105477897*CF*NM*NC)/
        12615581939509742409216 - (28954736750053*CF*lm*NM*NC)/9408960 - 
       (5466279*CF*lm^2*NM*NC)/5 + (286838416652282881*CF*NC*NL)/
        19758816000 - (28954736750053*CF*lm*NC*NL)/9408960 - 
       (5466279*CF*lm^2*NC*NL)/5 + 
       (5560408964945521959573767471818993713340210328689*CF*NC*NH)/
        5418897334952655609196137576180304704000 - 
       (28954736750053*CF*lm*NC*NH)/9408960 - (5466279*CF*lm^2*NC*NH)/5 + 
       (581447187744266790357923*CF^2*NC*Pi^2)/1659345367680 + 
       82810*CF^2*lm*NC*Pi^2 + (30611084113412779*CF*NM*NC*Pi^2)/24948 + 
       (41405*CF*lm*NM*NC*Pi^2)/18 - (64310856701*CF*NC*NL*Pi^2)/35640 + 
       (41405*CF*lm*NC*NL*Pi^2)/18 + (41405*CF*lm*NC*NH*Pi^2)/18 - 
       (1889766290443303649250727*CF^2*NC*Pi^3)/(120789464162194080*
         Sqrt[3]) - (123934598854247318084465*CF*NC*NH*Pi^3)/
        (823564528378596*Sqrt[3]) - (834731989*CF^2*NC*Pi^4)/1800 + 
       (11766270528416321404805931223*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (46503943702444720800*Sqrt[3]) + (809121482036280280577327*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1441237924662543*Sqrt[3]) - 
       (275846298*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (269966612920471949892961*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(466008735193650*Sqrt[3]) - 
       (14163954154771122066796*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(2541865828329*Sqrt[3]) - 
       (269966612920471949892961*CF^2*NC*Pi*Log[3]^2)/(22368419289295200*
         Sqrt[3]) - (3540988538692780516699*CF*NC*NH*Pi*Log[3]^2)/
        (30502389939948*Sqrt[3]) + CF*((1130216724969020682198077*CF*NC)/
          268875406800 - 751079784*CF*lm*NC + 
         CA*(-16956406924067366308467659/8066262204000 + (344244901*lm)/3)*
          NC + (2570705263427444734823*NM*NC)/174594420 - 
         (62589982*lm*NM*NC)/3 - (137619872*NC*NL)/5 - 
         (62589982*lm*NC*NL)/3 - (14827673653990291*NC*NH)/4015671660 - 
         (62589982*lm*NC*NH)/3)*Log[x]^2 + 
       (CF*NC*(-173067840087514781*CA + 120*(2880349004627698*CF + 
            1155*(8412586954620*NM + 31294991*NL)))*Log[x]^3)/311850 + 
       (3565386895472163946995523082453*CF^2*NC*PolyGamma[2, 1])/
        18159597850748041800 + (1248918480115949*CF*NM*NC*PolyGamma[2, 1])/
        1890 - (10699737633813742204126811*CF*NC*NH*PolyGamma[2, 1])/
        216185688699381450 - (4053518196929650477405581942599*CF^2*NC*
         Zeta[3])/24969447044778557475 - (517565777581231*CF*NM*NC*Zeta[3])/
        945 - (80162264*CF*NC*NL*Zeta[3])/3 + 
       (35951290980495980401302889*CF*NC*NH*Zeta[3])/108092844349690725 + 
       CA*CF*NC*(84387282238558833228013258737080669792634235384639/
          285783331135691133056698853021755200000 + (60129069*lm^2)/10 - 
         (82390765327131189934553*Pi^2)/470259820800 + 
         (1889766290443303649250727*Pi^3)/(241578928324388160*Sqrt[3]) + 
         (280452263*Pi^4)/1200 + lm*(8409303737057/342144 - 
           (455455*Pi^2)/36) - (11766270528416321404805931223*
           Im[PolyLog[2, (-1)^(1/3)]])/(93007887404889441600*Sqrt[3]) + 
         (137923149*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (269966612920471949892961*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (932017470387300*Sqrt[3]) + (269966612920471949892961*Pi*Log[3]^2)/
          (44736838578590400*Sqrt[3]) - (3565386895472163946995523082453*
           PolyGamma[2, 1])/36319195701496083600 + 
         (4054534534280409962401453778189*Zeta[3])/49938894089557114950) + 
       CF*Log[x]*((580401546552535933530194117*NM*NC)/57733355104425 - 
         (20096298469*lm*NM*NC)/1188 - 2914912*lm^2*NM*NC - 
         (279219759475847*NC*NL)/4989600 - (20096298469*lm*NC*NL)/1188 - 
         2914912*lm^2*NC*NL - (92134178704529207690788981926874524403*NC*
           NH)/84339834555731823845069693400 - (20096298469*lm*NC*NH)/
          1188 - 2914912*lm^2*NC*NH + (8412605330939*NM*NC*Pi^2)/9 - 
         (40039727*NC*NL*Pi^2)/9 + (14163954154771122066796*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(7625597484987*Sqrt[3]) + 
         CF*NC*(33311541632389007244175274368201358903429/
            13094729196302659984514916480 - (15911942293*lm)/33 - 
           104936832*lm^2 + (346088356513221869*Pi^2)/1247400 + 
           (269966612920471949892961*Im[PolyLog[2, (-1)^(1/3)]])/
            (1398026205580950*Sqrt[3]) - 17489472*Zeta[3]) + 
         CA*NC*(-4163884006705964603562726562746722280667807/
            3273682299075664996128729120000 + (24503645413*lm)/216 + 
           16032016*lm^2 - (115360110306047419*Pi^2)/831600 - 
           (269966612920471949892961*Im[PolyLog[2, (-1)^(1/3)]])/
            (2796052411161900*Sqrt[3]) + 8744736*Zeta[3])), 
      (-82078113528592020411953253359156277505953708233869987*CF^2*NC)/
        61729199525309284740246952252699123200000 - 
       (2358782491698869*CF^2*lm*NC)/32931360 - (231146682*CF^2*lm^2*NC)/5 - 
       (17186751738246565431517212029606460949*CF*NM*NC)/
        85155178091690761262208000 - (4198343019487853*CF*lm*NM*NC)/
        1185528960 - (38524447*CF*lm^2*NM*NC)/30 + 
       (96847720029153209947*CF*NC*NL)/5228182713600 - 
       (4198343019487853*CF*lm*NC*NL)/1185528960 - (38524447*CF*lm^2*NC*NL)/
        30 + (140681015579761126534284403946108080747839495079*CF*NC*NH)/
        115159565559796695354817563602414976000 - 
       (4198343019487853*CF*lm*NC*NH)/1185528960 - (38524447*CF*lm^2*NC*NH)/
        30 + (1594037801747965782178913*CF^2*NC*Pi^2)/1075501627200 + 
       (739375*CF^2*lm*NC*Pi^2)/9 - (1990088408832015307*CF*NM*NC*Pi^2)/
        4490640 + (739375*CF*lm*NM*NC*Pi^2)/324 - 
       (341680718821*CF*NC*NL*Pi^2)/160380 + (739375*CF*lm*NC*NL*Pi^2)/
        324 + (739375*CF*lm*NC*NH*Pi^2)/324 - 
       (66825306610245350978996623*CF^2*NC*Pi^3)/(3261315532379240160*
         Sqrt[3]) - (2561388634843551710344175*CF*NC*NH*Pi^3)/
        (14824161510814728*Sqrt[3]) - (4358862391*CF^2*NC*Pi^4)/8100 + 
       (2869181605498733971156487610283*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (8789245359762052231200*Sqrt[3]) + (26905723105618592903281339*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(51884565287851548*Sqrt[3]) - 
       (331820476*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (66825306610245350978996623*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(88075650951599850*Sqrt[3]) - 
       (146365064848202954876810*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(22876792454961*Sqrt[3]) - 
       (66825306610245350978996623*CF^2*NC*Pi*Log[3]^2)/
        (4227631245676792800*Sqrt[3]) - (73182532424101477438405*CF*NC*NH*Pi*
         Log[3]^2)/(549043018919064*Sqrt[3]) - 
       (CF*NC*(-23*CA*(-322779477179341864055080841 + 5077514637667122651000*
             lm) + 330*(92*CF*(-489035156452224816672709 + 
              25177758533886558600*lm) + 385*(69*(506456385339568157519 + 
                2422102793062680*lm)*NM + 6169531914*(35724657 + 
                27088780*lm)*NL + (30612262168481209 + 167125092721324920*
                 lm)*NH)))*Log[x]^2)/834858138114000 + 
       (CF*NC*(-4115127952032651707*CA + 40*(205666267311896768*CF + 
            1155*(-46171892394070*NM + 686700573*NL)))*Log[x]^3)/1871100 + 
       (121873406473607518457508452868977*CF^2*NC*PolyGamma[2, 1])/
        163436380656732376200 - (90193430173707397*CF*NM*NC*PolyGamma[2, 1])/
        793800 - (3804638701791337392834979021*CF*NC*NH*PolyGamma[2, 1])/
        81718190328366188100 - (6364043639137162996242069606173*CF^2*NC*
         Zeta[3])/8989000936120280691 + (136130784724997603*CF*NM*NC*
         Zeta[3])/396900 - (878574892*CF*NC*NL*Zeta[3])/27 + 
       (17475002269207815343630664879*CF*NC*NH*Zeta[3])/
        40859095164183094050 + CA*CF*NC*
        (82076586245138765880598575899121810045476156976062371/
          123458399050618569480493904505398246400000 + (423768917*lm^2)/60 - 
         (522740281277907991527847*Pi^2)/705389731200 + 
         (66825306610245350978996623*Pi^3)/(6522631064758480320*Sqrt[3]) + 
         (4388437391*Pi^4)/16200 + lm*(6135936553459949/215550720 - 
           (8133125*Pi^2)/648) - (2869181605498733971156487610283*
           Im[PolyLog[2, (-1)^(1/3)]])/(17578490719524104462400*Sqrt[3]) + 
         (165910238*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 + 
         (66825306610245350978996623*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (176151301903199700*Sqrt[3]) + (66825306610245350978996623*Pi*
           Log[3]^2)/(8455262491353585600*Sqrt[3]) - 
         (121873406473607518457508452868977*PolyGamma[2, 1])/
          326872761313464752400 + (25457797284588141798009033345335*Zeta[3])/
          71912007488962245528) + CF*Log[x]*
        ((-236243547565990264671521149661*NM*NC)/45724817242704600 - 
         (2143310196079*lm*NM*NC)/106920 - 3539536*lm^2*NM*NC - 
         (126687934926564791*NC*NL)/1886068800 - (2143310196079*lm*NC*NL)/
          106920 - 3539536*lm^2*NC*NL - 
         (13851399043786376277933792318073588045*NC*NH)/
          11040851069113984212445487136 - (2143310196079*lm*NC*NH)/106920 - 
         3539536*lm^2*NC*NH - (46171438343291*NM*NC*Pi^2)/162 - 
         (292611839*NC*NL*Pi^2)/54 + (146365064848202954876810*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(68630377364883*Sqrt[3]) + 
         CF*NC*(230404172268056043072736945819616893329679987/
            17677884415008590979095137248000 - (1686019842559*lm)/2970 - 
           127423296*lm^2 + (2057474053562937047*Pi^2)/1871100 + 
           (66825306610245350978996623*Im[PolyLog[2, (-1)^(1/3)]])/
            (264226952854799550*Sqrt[3]) - 21237216*Zeta[3]) + 
         CA*NC*(-576008212863873312453305603770165528460556193/
            88389422075042954895475686240000 + (2624970254959*lm)/19440 + 
           19467448*lm^2 - (228606761969926079*Pi^2)/415800 - 
           (66825306610245350978996623*Im[PolyLog[2, (-1)^(1/3)]])/
            (528453905709599100*Sqrt[3]) + 10618608*Zeta[3])), 
      (-29336292537208274358957457222249907627769456083740009*CF^2*NC)/
        3779338746447507228994711362410150400000 - 
       (71205937057711*CF^2*lm*NC)/588060 - (376891424*CF^2*lm^2*NC)/5 - 
       (144011472193030340284784359782885173*CF*NM*NC)/
        6719947766074081539000 - (124767673333759*CF*lm*NM*NC)/21170160 - 
       (94222856*CF*lm^2*NM*NC)/45 + (713506222479497116721*CF*NC*NL)/
        20539289232000 - (124767673333759*CF*lm*NC*NL)/21170160 - 
       (94222856*CF*lm^2*NC*NL)/45 + 
       (642848253214691452283383979160034957059721754652793*CF*NC*NH)/
        285762164147893948141202567493883255875000 - 
       (124767673333759*CF*lm*NC*NH)/21170160 - (94222856*CF*lm^2*NC*NH)/
        45 + (601310026980292796088037*CF^2*NC*Pi^2)/141421480200 + 
       (1324960*CF^2*lm*NC*Pi^2)/9 + (9358386804322427633*CF*NM*NC*Pi^2)/
        561330 + (331240*CF*lm*NM*NC*Pi^2)/81 - 
       (148795486021*CF*NC*NL*Pi^2)/40095 + (331240*CF*lm*NC*NL*Pi^2)/81 + 
       (331240*CF*lm*NC*NH*Pi^2)/81 - (169884328012711707257124227*CF^2*NC*
         Pi^3)/(4891973298568860240*Sqrt[3]) - 
       (1827570670951427948214340*CF*NC*NH*Pi^3)/(5559060566555523*
         Sqrt[3]) - (3939441233*CF^2*NC*Pi^4)/4050 + 
       (143205211045299601406129796173*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (269058531421287313200*Sqrt[3]) + (377942369214690054589386586*CF*NC*
         NH*Im[PolyLog[2, (-1)^(1/3)]])/(305748331160553765*Sqrt[3]) - 
       (5059922504*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (24269189716101672465303461*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(18873353775342825*Sqrt[3]) - 
       (835460878149224204897984*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (24269189716101672465303461*CF^2*NC*Pi*Log[3]^2)/
        (905920981216455600*Sqrt[3]) - (52216304884326512806124*CF*NC*NH*Pi*
         Log[3]^2)/(205891132094649*Sqrt[3]) + 
       CF*((37038425260315034453530951*CF*NC)/725963598360 - 
         1689306528*CF*lm*NC + CA*(-77166057313454248646784023/
            3024848326500 + (774265492*lm)/3)*NC + 
         (15718333067235834318445*NM*NC)/78567489 - (140775544*lm*NM*NC)/
          3 - (1669453994*NC*NL)/27 - (140775544*lm*NC*NL)/3 - 
         (403212507832074067*NC*NH)/45176306175 - (140775544*lm*NC*NH)/3)*
        Log[x]^2 + (CF*NC*(-9575074296135998689*CA + 
          80*(239309471922901222*CF + 10395*(86338046515363*NM + 
              52790829*NL)))*Log[x]^3)/1403325 + 
       (29630240990204129444691836403092*CF^2*NC*PolyGamma[2, 1])/
        12257728549254928215 + (4692890448074093*CF*NM*NC*PolyGamma[2, 1])/
        525 - (934825513120472212081072399*CF*NC*NH*PolyGamma[2, 1])/
        8755520392324948725 - (1340711166525710718356679063833669*CF^2*NC*
         Zeta[3])/674175070209021051825 - (36399417876794326*CF*NM*NC*
         Zeta[3])/4725 - (1592655064*CF*NC*NL*Zeta[3])/27 + 
       (6287326897115143060386490402*CF*NC*NH*Zeta[3])/8755520392324948725 + 
       CA*CF*NC*(359367229732820627439789307502016207670575078831370717/
          92593799287963927110370428379048684800000 + (518225708*lm^2)/45 - 
         (2590255703031442308554753*Pi^2)/1218400444800 + 
         (169884328012711707257124227*Pi^3)/(9783946597137720480*Sqrt[3]) + 
         (3965940433*Pi^4)/8100 + lm*(181183796809471/3849120 - 
           (1821820*Pi^2)/81) - (143205211045299601406129796173*
           Im[PolyLog[2, (-1)^(1/3)]])/(538117062842574626400*Sqrt[3]) + 
         (2529961252*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (24269189716101672465303461*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (37746707550685650*Sqrt[3]) + (24269189716101672465303461*Pi*
           Log[3]^2)/(1811841962432911200*Sqrt[3]) - 
         (14815120495102064722345918201546*PolyGamma[2, 1])/
          12257728549254928215 + (2681541354779561507087158674433663*Zeta[3])/
          2696700280836084207300) + CF*Log[x]*
        ((489476795800258339504237905607*NM*NC)/3657985379416368 - 
         (469186413488*lm*NM*NC)/13365 - (18019456*lm^2*NM*NC)/3 - 
         (90231348077527147*NC*NL)/740955600 - (469186413488*lm*NC*NL)/
          13365 - (18019456*lm^2*NC*NL)/3 - 
         (24705579982152493550587997622109463050397*NC*NH)/
          10350797877294360199167644190000 - (469186413488*lm*NC*NH)/13365 - 
         (18019456*lm^2*NC*NH)/3 + (345352345049008*NM*NC*Pi^2)/27 - 
         (29469076*NC*NL*Pi^2)/3 + (835460878149224204897984*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(784479511555509803148787167409907220081000803/
            26516826622512886468642705872000 - (1488741717632*lm)/1485 - 
           216233472*lm^2 + (19149663396947917681*Pi^2)/5613300 + 
           (24269189716101672465303461*Im[PolyLog[2, (-1)^(1/3)]])/
            (56620061326028475*Sqrt[3]) - 36038912*Zeta[3]) + 
         CA*NC*(-1961193442297067694830675823078716091624813977/
            132584133112564432343213529360000 + (285678364504*lm)/1215 + 
           (99107008*lm^2)/3 - (19149584494847447323*Pi^2)/11226600 - 
           (24269189716101672465303461*Im[PolyLog[2, (-1)^(1/3)]])/
            (113240122652056950*Sqrt[3]) + 18019456*Zeta[3])), 
      (-160048260302899686184259418062924050578925504895706606669799*CF^2*NC)/
        7322826913588271157487200513571254761750400000 - 
       (2003772909030154*CF^2*lm*NC)/14907321 - (433590912*CF^2*lm^2*NC)/5 + 
       (17965190327437165414859140366283563556237*CF*NM*NC)/
        8830253282740921809181404000 - (8914571612744881*CF*lm*NM*NC)/
        1341658890 - (12044192*CF*lm^2*NM*NC)/5 + 
       (78111907620225892243423*CF*NC*NL)/1822348437109200 - 
       (8914571612744881*CF*lm*NC*NL)/1341658890 - (12044192*CF*lm^2*NC*NL)/
        5 + (1544225021008692274272761698419805304592823801031*CF*NC*NH)/
        590417694520442041614054891516287718750 - 
       (8914571612744881*CF*lm*NC*NH)/1341658890 - (12044192*CF*lm^2*NC*NH)/
        5 + (1139552768889863418113540681*CF^2*NC*Pi^2)/53086088130075 + 
       (3879680*CF^2*lm*NC*Pi^2)/27 - (89203793049261928616*CF*NM*NC*Pi^2)/
        10945935 + (969920*CF*lm*NM*NC*Pi^2)/243 - 
       (1339314544000*CF*NC*NL*Pi^2)/312741 + (969920*CF*lm*NC*NL*Pi^2)/
        243 + (969920*CF*lm*NC*NH*Pi^2)/243 - 
       (702327204558857398325133529*CF^2*NC*Pi^3)/(15898913220348795780*
         Sqrt[3]) - (2053767246583058084724800*CF*NC*NH*Pi^3)/
        (5559060566555523*Sqrt[3]) - (6717105802*CF^2*NC*Pi^4)/6075 + 
       (373659530218227953084625207061459*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]])/
        (557018424674920060152300*Sqrt[3]) + (2425945018486861287973159472*CF*
         NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/(2140238318123876355*Sqrt[3]) - 
       (1982269088*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (2809308818235429593300534116*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(1717475193556197075*
         Sqrt[3]) - (938865027009397981588480*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(68630377364883*Sqrt[3]) - 
       (702327204558857398325133529*CF^2*NC*Pi*Log[3]^2)/
        (20609702322674364900*Sqrt[3]) - (58679064188087373849280*CF*NC*NH*
         Pi*Log[3]^2)/(205891132094649*Sqrt[3]) - 
       (CF*NC*(CA*(2096764233806206574393208343791 - 
            4994803646078721707232000*lm) + 
          80*(5*CF*(-10483740784796323969836636817 + 81733150572197264300160*
               lm) + 6006*(105*(31556969197811112389731 + 18000771400600560*
                 lm)*NM + 2*(12429459900*(100145231 + 76032306*lm)*NL + 
                (185314631875013191 + 945040498531529400*lm)*NH))))*
         Log[x]^2)/16279733693223000 + 
       (4*CF*NC*(-146688164361841901693*CA + 520*(564145336601581337*CF - 
            60060*(3293352939152*NM - 5430879*NL)))*Log[x]^3)/18243225 + 
       (666340076195579017806928447167997*CF^2*NC*PolyGamma[2, 1])/
        61288642746274641075 - (301156108880907496*CF*NM*NC*PolyGamma[2, 1])/
        99225 - (6047146206663810206085012847*CF*NC*NH*PolyGamma[2, 1])/
        61288642746274641075 - (18262219942706452793526088790457454*CF^2*NC*
         Zeta[3])/1752855182543454734745 + (516595231867385008*CF*NM*NC*
         Zeta[3])/99225 - (5677200320*CF*NC*NL*Zeta[3])/81 + 
       (55247999651719104689856982306*CF*NC*NH*Zeta[3])/
        61288642746274641075 + CA*CF*NC*
        (80023923568997843783299274597907718378157519881788009893351/
          7322826913588271157487200513571254761750400000 + 
         (66243056*lm^2)/5 - (18232840113193685220156680243*Pi^2)/
          1698754820162400 + (702327204558857398325133529*Pi^3)/
          (31797826440697591560*Sqrt[3]) + (1125983767*Pi^4)/2025 + 
         lm*(2605564365368381/48787596 - (5334560*Pi^2)/243) - 
         (373659530218227953084625207061459*Im[PolyLog[2, (-1)^(1/3)]])/
          (1114036849349840120304600*Sqrt[3]) + 
         (991134544*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (1404654409117714796650267058*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (1717475193556197075*Sqrt[3]) + (702327204558857398325133529*Pi*
           Log[3]^2)/(41219404645348729800*Sqrt[3]) - 
         (666340076195579017806928447167997*PolyGamma[2, 1])/
          122577285492549282150 + (1826238740292168270254761099264354*
           Zeta[3])/350571036508690946949) + 
       CF*Log[x]*((-1510545652748081691136946676977779*NM*NC)/
          18141321241043050050 - (148347182264704*lm*NM*NC)/3648645 - 
         7128576*lm^2*NM*NC - (722132313061199837*NC*NL)/5057021970 - 
         (148347182264704*lm*NC*NL)/3648645 - 7128576*lm^2*NC*NL - 
         (38182118730883452815910769277701476548947*NC*NH)/
          14232347081279745273855510761250 - (148347182264704*lm*NC*NH)/
          3648645 - 7128576*lm^2*NC*NH - (1370032961757824*NM*NC*Pi^2)/
          243 - (315184480*NC*NL*Pi^2)/27 + (938865027009397981588480*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(205891132094649*Sqrt[3]) + 
         CF*NC*(68435311292953550948842248269551590061800809839/
            372155544251063510703787527105600 - (467675453691136*lm)/405405 - 
           256628736*lm^2 + (32597153715096213158*Pi^2)/2027025 + 
           (2809308818235429593300534116*Im[PolyLog[2, (-1)^(1/3)]])/
            (5152425580668591225*Sqrt[3]) - 42771456*Zeta[3]) + 
         CA*NC*(-2619787722990932399193732335764421057515228817627/
            28493158856722050038258732544022500 + (90725182246592*lm)/
            331695 + 39207168*lm^2 - (97791369574163172367*Pi^2)/12162150 - 
           (1404654409117714796650267058*Im[PolyLog[2, (-1)^(1/3)]])/
            (5152425580668591225*Sqrt[3]) + 21385728*Zeta[3])), 
      (-2459520648450957738064351154838629839765309789643343258043543*CF^2*
         NC)/25106835132302643968527544617958587754572800000 - 
       (22049366032556119*CF^2*lm*NC)/99382140 - (690639824*CF^2*lm^2*NC)/5 - 
       (546494921417541369363142324072551848917147*CF*NM*NC)/
        1798755298336113701870286000 - (38636704754822431*CF*lm*NM*NC)/
        3577757040 - (172659956*CF*lm^2*NM*NC)/45 + 
       (1593471404521500916259*CF*NC*NL)/20539289232000 - 
       (38636704754822431*CF*lm*NC*NL)/3577757040 - 
       (172659956*CF*lm^2*NC*NL)/45 + 
       (16055571352210925586808942314093750917089880951369947*CF*NC*NH)/
        3429145969774727377694430809926599070500000 - 
       (38636704754822431*CF*lm*NC*NH)/3577757040 - 
       (172659956*CF*lm^2*NC*NH)/45 + (2692072297805004969028910129*CF^2*NC*
         Pi^2)/53928724449600 + (2265760*CF^2*lm*NC*Pi^2)/9 + 
       (1622429194789789701383*CF*NM*NC*Pi^2)/7297290 + 
       (566440*CF*lm*NM*NC*Pi^2)/81 - (3788365239547*CF*NC*NL*Pi^2)/
        521235 + (566440*CF*lm*NC*NL*Pi^2)/81 + (566440*CF*lm*NC*NH*Pi^2)/
        81 - (2139768011934744506086421377*CF^2*NC*Pi^3)/
        (29351839791413161440*Sqrt[3]) - (11376609754787725418637100*CF*NC*
         NH*Pi^3)/(16677181699666569*Sqrt[3]) - (15692548921*CF^2*NC*Pi^4)/
        8100 + (22412315004918394643000173965481*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(20986565450860410429600*Sqrt[3]) + 
       (2373039052538536505613142954*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (917244993481661295*Sqrt[3]) - (9831017924*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - (305681144562106358012345911*CF^2*
         NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(113240122652056950*
         Sqrt[3]) - (5200735887902960191376960*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*Sqrt[3]) - 
       (305681144562106358012345911*CF^2*NC*Pi*Log[3]^2)/
        (5435525887298733600*Sqrt[3]) - (325045992993935011961060*CF*NC*NH*
         Pi*Log[3]^2)/(617673396283947*Sqrt[3]) - 
       (CF*NC*(-39*CA*(-166700599370086962583902843797 + 
            305439476005287095472000*lm) + 
          20*(CF*(-650128248383493311190456092147 + 3898518402831118927660800*
               lm) + 24024*(5*(-24106049782302744674436901 + 
                901533282187978440*lm)*NM + 14051504416950*(422321 + 
                320796*lm)*NL + (912790155286440709 + 4507666410939892200*
                 lm)*NH)))*Log[x]^2)/21706311590964000 + 
       (CF*NC*(-2961721017691382235509*CA + 40*(148078055838852846703*CF + 
            540540*(1159612064984053*NM + 112251867*NL)))*Log[x]^3)/
        36486450 + (4244675781485694314738852720904889*CF^2*NC*
         PolyGamma[2, 1])/147092742591059138580 + 
       (563840613153583411*CF*NM*NC*PolyGamma[2, 1])/4725 - 
       (5751549337982571043633036559*CF*NC*NH*PolyGamma[2, 1])/
        26266561176974846175 - (616804292717046517971909940952959636*CF^2*NC*
         Zeta[3])/26292827738151821021175 - (495771740041820378*CF*NM*NC*
         Zeta[3])/4725 - (3332535976*CF*NC*NL*Zeta[3])/27 + 
       (38684391134977570662822240482*CF*NC*NH*Zeta[3])/
        26266561176974846175 + CA*CF*NC*
        (165544469753755864730964943499083285826639476700959803193127/
          3379766267809971303455631006263656043884800000 + 
         (949629758*lm^2)/45 - (1330200182139722177609540837*Pi^2)/
          53294268867840 + (2139768011934744506086421377*Pi^3)/
          (58703679582826322880*Sqrt[3]) + (15783179321*Pi^4)/16200 + 
         lm*(56108008236582559/650501280 - (3115420*Pi^2)/81) - 
         (22412315004918394643000173965481*Im[PolyLog[2, (-1)^(1/3)]])/
          (41973130901720820859200*Sqrt[3]) + 
         (4915508962*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (305681144562106358012345911*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
          (226480245304113900*Sqrt[3]) + (305681144562106358012345911*Pi*
           Log[3]^2)/(10871051774597467200*Sqrt[3]) - 
         (4244675781485694314738852720904889*PolyGamma[2, 1])/
          294185485182118277160 + (2467236313773106779508694591949244639*
           Zeta[3])/210342621905214568169400) + 
       CF*Log[x]*((16912341854913864034194199174081661*NM*NC)/
          9675371328556293360 - (12039060363392*lm*NM*NC)/173745 - 
         11781952*lm^2*NM*NC - (186405264592245073*NC*NL)/740955600 - 
         (12039060363392*lm*NC*NL)/173745 - 11781952*lm^2*NC*NL - 
         (130142871983141150932051649333390902545259*NC*NH)/
          26275102303901068197887096790000 - (12039060363392*lm*NC*NH)/
          173745 - 11781952*lm^2*NC*NH + (4638448664513840*NM*NC*Pi^2)/27 - 
         (185015012*NC*NL*Pi^2)/9 + (5200735887902960191376960*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(363477052209984399821440157260812996331017960406489/
            1094137300098126721469135329690464000 - (38262141077408*lm)/
            19305 - 424150272*lm^2 + (5923414931214094081541*Pi^2)/
            145945800 + (305681144562106358012345911*Im[PolyLog[2, (-1)^
                (1/3)]])/(339720367956170850*Sqrt[3]) - 70691712*Zeta[3]) + 
         CA*NC*(-227173040511682582478649904454616919941055790782291/
            1367671625122658401836419162113080000 + (7322201704576*lm)/
            15795 + 64800736*lm^2 - (5923410675735116067563*Pi^2)/291891600 - 
           (305681144562106358012345911*Im[PolyLog[2, (-1)^(1/3)]])/
            (679440735912341700*Sqrt[3]) + 35345856*Zeta[3])), 
      (-371991315805126405306679716377331443060517687897799233707985427*CF^2*
         NC)/1085501401308379018639279134952915411741824000000 - 
       (41653674447242801*CF^2*lm*NC)/172161990 - (5461479024*CF^2*lm^2*NC)/
        35 + (1763326474971274844068175619586769936100156227*CF*NM*NC)/
        20603924326395484221423276000000 - (74115000419073557*CF*lm*NM*NC)/
        6197831640 - (455123252*CF*lm^2*NM*NC)/105 + 
       (479700014131021844488957*CF*NC*NL)/5154116791824000 - 
       (74115000419073557*CF*lm*NC*NL)/6197831640 - 
       (455123252*CF*lm^2*NC*NL)/105 + 
       (3071339917382841004393561506182344380013960740954068617*CF*NC*NH)/
        576096522922154199452664376067668643844000000 - 
       (74115000419073557*CF*lm*NC*NH)/6197831640 - 
       (455123252*CF*lm^2*NC*NH)/105 + (2402718774519897116520241161649*CF^2*
         NC*Pi^2)/7927522494091200 + (5086400*CF^2*lm*NC*Pi^2)/21 - 
       (1132428554783477721188*CF*NM*NC*Pi^2)/8513505 + 
       (1271600*CF*lm*NM*NC*Pi^2)/189 - (6362624976769*CF*NC*NL*Pi^2)/
        773955 + (1271600*CF*lm*NC*NL*Pi^2)/189 + 
       (1271600*CF*lm*NC*NH*Pi^2)/189 - (724549333493459457122269225331*CF^2*
         NC*Pi^3)/(8013052263055793073120*Sqrt[3]) - 
       (37633497638080078349430860*CF*NC*NH*Pi^3)/(50031545098999707*
         Sqrt[3]) - (122618063437*CF^2*NC*Pi^4)/56700 + 
       (370139705916518759982995672455460459*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(280737286036159710316759200*Sqrt[3]) + 
       (317757465103365970221908909312*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (134835014041804210365*Sqrt[3]) - 
       (26415813596*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - 
       (724549333493459457122269225331*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(216401874388080831450*
         Sqrt[3]) - (120427192441856250718178752*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4323713773987629*Sqrt[3]) - 
       (724549333493459457122269225331*CF^2*NC*Pi*Log[3]^2)/
        (10387289970627879909600*Sqrt[3]) - (7526699527616015669886172*CF*NC*
         NH*Pi*Log[3]^2)/(12971141321962887*Sqrt[3]) - 
       (CF*NC*(-221*CA*(-1250282402908561566240845386561 + 
            438773205829919936976000*lm) + 
          80*(5440*CF*(-1269816625675418115919200652 + 1458422303468767972335*
               lm) + 3003*(7*(144219666822700879956640739 + 
                10483983385490300400*lm)*NM + 126780490980*(761701981 + 
                578857860*lm)*NL + 3*(5090836857102544159 + 
                24462627899477367600*lm)*NH)))*Log[x]^2)/
        151944181136748000 + (CF*NC*(-1858512483634713226451*CA + 
          160*(23231149102383505763*CF + 715*(-13558204213358212*NM + 
              2741305437*NL)))*Log[x]^3)/4054050 + 
       (171035645960786006693763123269901221*CF^2*NC*PolyGamma[2, 1])/
        1103195569432943539350 - (3782987301066864589*CF*NM*NC*
         PolyGamma[2, 1])/66150 - (219731241166653952588054108229*CF*NC*NH*
         PolyGamma[2, 1])/1103195569432943539350 - 
       (936196842840286523413426203243087169*CF^2*NC*Zeta[3])/
        6310278657156437045082 + (848068926495805537*CF*NM*NC*Zeta[3])/
        11025 - (9042131768*CF*NC*NL*Zeta[3])/63 + 
       (998423926942021620200111821771*CF*NC*NH*Zeta[3])/
        551597784716471769675 + CA*CF*NC*
        (23249449019762227952866742601330227496972721432223322570263927/
          135687675163547377329909891869114426467728000000 + 
         (2503177886*lm^2)/105 - (282672788128922570234997190477*Pi^2)/
          1865299410374400 + (724549333493459457122269225331*Pi^3)/
          (16026104526111586146240*Sqrt[3]) + (123228431437*Pi^4)/113400 + 
         lm*(108306240314168021/1126878480 - (6993800*Pi^2)/189) - 
         (370139705916518759982995672455460459*Im[PolyLog[2, (-1)^(1/3)]])/
          (561474572072319420633518400*Sqrt[3]) + 
         (13207906798*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 + 
         (724549333493459457122269225331*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(432803748776161662900*Sqrt[3]) + 
         (724549333493459457122269225331*Pi*Log[3]^2)/
          (20774579941255759819200*Sqrt[3]) - 
         (171035645960786006693763123269901221*PolyGamma[2, 1])/
          2206391138865887078700 + (9361980597055213704296608592285103397*
           Zeta[3])/126205573143128740901640) + 
       CF*Log[x]*((-815105619897567395893625909052033469*NM*NC)/
          651226916345135130000 - (20292194000642*lm*NM*NC)/257985 - 
         13705536*lm^2*NM*NC - (4133604949367807611*NC*NL)/14302688400 - 
         (20292194000642*lm*NC*NL)/257985 - 13705536*lm^2*NC*NL - 
         (39183418441758127554034746739811320151681039*NC*NH)/
          7173102928964991618023177423670000 - (20292194000642*lm*NC*NH)/
          257985 - 13705536*lm^2*NC*NH - (18077602076667248*NM*NC*Pi^2)/
          189 - (167352692*NC*NL*Pi^2)/7 + (120427192441856250718178752*NC*
           NH*Im[PolyLog[2, (-1)^(1/3)]])/(12971141321962887*Sqrt[3]) + 
         CF*NC*(17097651087958279412263843961686131445259050106881427/
            6757906853547253279662306448088160000 - (64078966261928*lm)/
            28665 - 493399296*lm^2 + (78057448075188065384339*Pi^2)/
            340540200 + (724549333493459457122269225331*
             Im[PolyLog[2, (-1)^(1/3)]])/(649205623164242494350*Sqrt[3]) - 
           82233216*Zeta[3]) + CA*NC*
          (-4274412398454589574337329705992652453234740451058989/
            3378953426773626639831153224044080000 + (136357825938251*lm)/
            257985 + 75380448*lm^2 - (321224023255972655719*Pi^2)/2802800 - 
           (724549333493459457122269225331*Im[PolyLog[2, (-1)^(1/3)]])/
            (1298411246328484988700*Sqrt[3]) + 41116608*Zeta[3])), 
      (-4395585683183679988578820582486655623563643940924770598468539957*CF^2*
         NC)/3690704764448488663373549058839912399922201600000 - 
       (1567775104177833*CF^2*lm*NC)/4008004 - (1217764944*CF^2*lm^2*NC)/5 - 
       (419721541834208442629292073225714276785450167*CF*NM*NC)/
        99930849907561872326127000000 - (4578839010181687*CF*lm*NM*NC)/
        240480240 - (33826804*CF*lm^2*NM*NC)/5 + 
       (273246837958026355320077*CF*NC*NL)/1671289571952000 - 
       (4578839010181687*CF*lm*NC*NL)/240480240 - (33826804*CF*lm^2*NC*NL)/
        5 + (311502759300115480106544101406794008037041811970693708347*CF*NC*
         NH)/33453376422734330405835789209319929892169800000 - 
       (4578839010181687*CF*lm*NC*NH)/240480240 - (33826804*CF*lm^2*NC*NH)/
        5 + (1498108888838034194058482307551*CF^2*NC*Pi^2)/2642507498030400 + 
       416160*CF^2*lm*NC*Pi^2 + (157428920842993577917*CF*NM*NC*Pi^2)/
        54054 + 11560*CF*lm*NM*NC*Pi^2 - (1843262133236*CF*NC*NL*Pi^2)/
        135135 + 11560*CF*lm*NC*NL*Pi^2 + 11560*CF*lm*NC*NH*Pi^2 - 
       (1168387823783293622727213646153*CF^2*NC*Pi^3)/(8013052263055793073120*
         Sqrt[3]) - (22566350806560549640599640*CF*NC*NH*Pi^3)/
        (16677181699666569*Sqrt[3]) - (69725442557*CF^2*NC*Pi^4)/18900 + 
       (577105231322911230138223344352128181*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(280737286036159710316759200*Sqrt[3]) + 
       (6650136450328294031394213302*CF*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
        (1284142990874325813*Sqrt[3]) - (14248562716*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - (1168387823783293622727213646153*
         CF^2*NC*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/
        (216401874388080831450*Sqrt[3]) - (10316046082999108407131264*CF*NC*
         NH*Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(205891132094649*
         Sqrt[3]) - (1168387823783293622727213646153*CF^2*NC*Pi*Log[3]^2)/
        (10387289970627879909600*Sqrt[3]) - (644752880187444275445704*CF*NC*
         NH*Pi*Log[3]^2)/(617673396283947*Sqrt[3]) + 
       CF*((265049510629873748075914134293*CF*NC)/38960046445320 - 
         7274041056*CF*lm*NC + CA*(-172282375684517038454061290792251/
            50648060378916000 + 1111311828*lm)*NC + 
         (19492323827136105710238451*NM*NC)/557732175 - 
         202056696*lm*NM*NC - (9303790906*NC*NL)/35 - 202056696*lm*NC*NL - 
         (1258592272223802539*NC*NH)/29113619535 - 202056696*lm*NC*NH)*
        Log[x]^2 + (CF*NC*(-26518544578077884324851*CA + 
          160*(331478444485945310266*CF + 2837835*(566477328337895*NM + 
              8419029*NL)))*Log[x]^3)/28378350 + 
       (736706186420922152061508352936990807*CF^2*NC*PolyGamma[2, 1])/
        2206391138865887078700 + (7417301715159776387*CF*NM*NC*
         PolyGamma[2, 1])/4725 - (2256890996532011159549439587*CF*NC*NH*
         PolyGamma[2, 1])/5253312235394969235 - 
       (21034623685300307047585957196824152106*CF^2*NC*Zeta[3])/
        78878483214455463063525 - (6578231534717548826*CF*NM*NC*Zeta[3])/
        4725 - 246474840*CF*NC*NL*Zeta[3] + (15172094642710509518238517946*
         CF*NC*NH*Zeta[3])/5253312235394969235 + 
       CA*CF*NC*
        (49949827515592699827202607071269649954153528777563732327719281/
          83879653737465651440307933155452554543686400000 + 
         (186047422*lm^2)/5 - (176248099133072866856057899297*Pi^2)/
          621766470124800 + (1168387823783293622727213646153*Pi^3)/
          (16026104526111586146240*Sqrt[3]) + (70075016957*Pi^4)/37800 + 
         lm*(1329896861021579/8744736 - 63580*Pi^2) - 
         (577105231322911230138223344352128181*Im[PolyLog[2, (-1)^(1/3)]])/
          (561474572072319420633518400*Sqrt[3]) + 
         (7124281358*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
         (1168387823783293622727213646153*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(432803748776161662900*Sqrt[3]) + 
         (1168387823783293622727213646153*Pi*Log[3]^2)/
          (20774579941255759819200*Sqrt[3]) - 
         (736706186420922152061508352936990807*PolyGamma[2, 1])/
          4412782277731774157400 + (84138608028341445238555082597209287589*
           Zeta[3])/631027865715643704508200) + 
       CF*Log[x]*((111688077268073219182595220754349531*NM*NC)/
          4977042864483690000 - (5897634175766*lm*NM*NC)/45045 - 
         22139712*lm^2*NM*NC - (5374522022585893321*NC*NL)/10821610800 - 
         (5897634175766*lm*NC*NL)/45045 - 22139712*lm^2*NC*NL - 
         (564496661706452978632983590718908861455224059*NC*NH)/
          57453138697710075721499925841014000 - (5897634175766*lm*NC*NH)/
          45045 - 22139712*lm^2*NC*NH + (6797728044548096*NM*NC*Pi^2)/3 - 
         41056020*NC*NL*Pi^2 + (10316046082999108407131264*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(617673396283947*Sqrt[3]) + 
         CF*NC*(82628221167961131241709352154524966061065437453017453/
            22976883302060661150851841923499744000 - (18770333955704*lm)/
            5005 - 797029632*lm^2 + (53037046102603739813699*Pi^2)/
            113513400 + (1168387823783293622727213646153*
             Im[PolyLog[2, (-1)^(1/3)]])/(649205623164242494350*Sqrt[3]) - 
           132838272*Zeta[3]) + CA*NC*
          (-51642633238341626486097555240689263484713445362891453/
            28721104127575826438564802404374680000 + (3583451932363*lm)/
            4095 + 121768416*lm^2 - (841857770496891478819*Pi^2)/3603600 - 
           (1168387823783293622727213646153*Im[PolyLog[2, (-1)^(1/3)]])/
            (1298411246328484988700*Sqrt[3]) + 66419136*Zeta[3])), 
      (-10919212119197644021630600271964758116075342339441155384233555009*
         CF^2*NC)/2118389214288035584844511577140255841792080000000 - 
       (903652416693183614*CF^2*lm*NC)/2152024875 - (9476443008*CF^2*lm^2*NC)/
        35 + (348949732625080455442302937690724339654699865449*CF*NM*NC)/
        191230172654358087930084780375000 - (803857572222984007*CF*lm*NM*NC)/
        38736447750 - (263234528*CF*lm^2*NM*NC)/35 + 
       (264615824739728166025063907*CF*NC*NL)/1381947564807810000 - 
       (803857572222984007*CF*lm*NC*NL)/38736447750 - 
       (263234528*CF*lm^2*NC*NL)/35 + 
       (164523665903860778789385618323584348050180219860689243413251*CF*NC*
         NH)/15806720359741971116757410401403666874050230500000 - 
       (803857572222984007*CF*lm*NC*NH)/38736447750 - 
       (263234528*CF*lm^2*NC*NH)/35 + (33524042676221659547620907653*CF^2*NC*
         Pi^2)/8023808192400 + (13835008*CF^2*lm*NC*Pi^2)/35 - 
       (28637022282824357318452*CF*NM*NC*Pi^2)/14189175 + 
       (3458752*CF*lm*NM*NC*Pi^2)/315 - (58657637276248*CF*NC*NL*Pi^2)/
        3869775 + (3458752*CF*lm*NC*NL*Pi^2)/315 + 
       (3458752*CF*lm*NC*NH*Pi^2)/315 - (1594737653455597593835970289833*
         CF^2*NC*Pi^3)/(9014683795937767207260*Sqrt[3]) - 
       (660607039825317147802895680*CF*NC*NH*Pi^3)/(450283905890997363*
         Sqrt[3]) - (57439480558*CF^2*NC*Pi^4)/14175 + 
       (1967334758155626596225169819408891353*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(789573616976699185265885250*Sqrt[3]) + 
       (369841667932998219700978961569952*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(78878483214455463063525*Sqrt[3]) - 
       (48345430688*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - 
       (6378950613822390375343881159332*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(973808434746363741525*
         Sqrt[3]) - (2113942527441014872969266176*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(38913423965888661*Sqrt[3]) - 
       (1594737653455597593835970289833*CF^2*NC*Pi*Log[3]^2)/
        (11685701216956364898300*Sqrt[3]) - (132121407965063429560579136*CF*
         NC*NH*Pi*Log[3]^2)/(116740271897665983*Sqrt[3]) - 
       (CF*NC*(-1421*CA*(-19433679791134878793827398929813 + 
            982585564824513790483200*lm) + 
          4*(29*CF*(-476125076840902252752648752892467 + 
              78785497106838287564198400*lm) + 
            40040*(2030*(82058571839134325208456379 + 780821332505176248*lm)*
               NM + 113127207336*(18423357553 + 14011371290*lm)*NL + 
              (347608163573601848849 + 1585067304985507783440*lm)*NH)))*
         Log[x]^2)/1101595313241423000 + 
       (4*CF*NC*(-67858767015437737855594*CA + 
          7*(19388186487422580172273*CF - 68640*(131842910532039543*NM - 
              3402761599*NL)))*Log[x]^3)/42567525 + 
       (10730301395461281440689319387358847661*CF^2*NC*PolyGamma[2, 1])/
        4964380062448245927075 - (2065397809395467713*CF*NM*NC*
         PolyGamma[2, 1])/2205 - (1912764550064956680443210287496*CF*NC*NH*
         PolyGamma[2, 1])/4964380062448245927075 - 
       (1457905998855776337691271729335521892498*CF^2*NC*Zeta[3])/
        709906348930099167571725 + (7296167358495593338*CF*NM*NC*Zeta[3])/
        6615 - (265723035328*CF*NC*NL*Zeta[3])/945 + 
       (17293830926085819233175637874288*CF*NC*NH*Zeta[3])/
        4964380062448245927075 + CA*CF*NC*
        (267520684102665611931091445305671748799767162335359804007188385733/
          103801071500113743657381067279872536247811920000000 + 
         (1447789904*lm^2)/35 - (93670118847473965401529329289*Pi^2)/
          44838928134000 + (1594737653455597593835970289833*Pi^3)/
          (18029367591875534414520*Sqrt[3]) + (28844255351*Pi^4)/14175 + 
         lm*(1174649228218180807/7042990500 - (19023136*Pi^2)/315) - 
         (1967334758155626596225169819408891353*Im[PolyLog[2, (-1)^(1/3)]])/
          (1579147233953398370531770500*Sqrt[3]) + 
         (24172715344*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 + 
         (3189475306911195187671940579666*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(973808434746363741525*Sqrt[3]) + 
         (1594737653455597593835970289833*Pi*Log[3]^2)/
          (23371402433912729796600*Sqrt[3]) - 
         (10730301395461281440689319387358847661*PolyGamma[2, 1])/
          9928760124896491854150 + (728953131921468322273520796933034260872*
           Zeta[3])/709906348930099167571725) + 
       CF*Log[x]*((-170507641305632680022777955501184964707*NM*NC)/
          9524193651547601276250 - (188344412704624*lm*NM*NC)/1289925 - 
         25302528*lm^2*NM*NC - (2148591144458728446427*NC*NL)/
          3834908327250 - (188344412704624*lm*NC*NL)/1289925 - 
         25302528*lm^2*NC*NL - 
         (6573579249124096348500938823478423055243089093*NC*NH)/
          616968364424272972236561703633616250 - (188344412704624*lm*NC*NH)/
          1289925 - 25302528*lm^2*NC*NH - (281264867821575040*NM*NC*Pi^2)/
          189 - (132799260128*NC*NL*Pi^2)/2835 + 
         (2113942527441014872969266176*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (116740271897665983*Sqrt[3]) + 
         CF*NC*(3381876153675829446848417778609764202976342928808994429/
            99419206595454783825801239092066200000 - (595625560904896*lm)/
            143325 - 910891008*lm^2 + (135717514959581252762828*Pi^2)/
            42567525 + (6378950613822390375343881159332*
             Im[PolyLog[2, (-1)^(1/3)]])/(2921425304239091224575*Sqrt[3]) - 
           151815168*Zeta[3]) + CA*NC*
          (-392539191400494099840416203749137639239056842995031371/
            23079458673944860530989573360658225000 + (1264362813888232*lm)/
            1289925 + 139163904*lm^2 - (45239170807566235865429*Pi^2)/
            28378350 - (3189475306911195187671940579666*
             Im[PolyLog[2, (-1)^(1/3)]])/(2921425304239091224575*Sqrt[3]) + 
           75907584*Zeta[3])), 
      (-38258852230766679535345462981767918469525865549550315748968601201*
         CF^2*NC)/2737610676926076755799061115073561395546688000000 - 
       (9018106065885903671*CF^2*lm*NC)/13527013500 - 
       (2075706528*CF^2*lm^2*NC)/5 - 
       (7811791877281936735156640486274538311618014707*CF*NM*NC)/
        137711889570156152978727000000 - (15803649370573651271*CF*lm*NM*NC)/
        486972486000 - (172975544*CF*lm^2*NM*NC)/15 + 
       (517803646528773964210312631*CF*NC*NL)/1579368645494640000 - 
       (15803649370573651271*CF*lm*NC*NL)/486972486000 - 
       (172975544*CF*lm^2*NC*NL)/15 + 
       (78905596201559316663944286628184570187609697948052527721426869*CF*NC*
         NH)/4435460027350766670700031522149607282682861069000000 - 
       (15803649370573651271*CF*lm*NC*NH)/486972486000 - 
       (172975544*CF*lm^2*NC*NH)/15 + (27000002227460110183920327236707*CF^2*
         NC*Pi^2)/4341262318192800 + (3338528*CF^2*lm*NC*Pi^2)/5 + 
       (456248810491246690858223*CF*NM*NC*Pi^2)/12162150 + 
       (834632*CF*lm*NM*NC*Pi^2)/45 - (5553188390914*CF*NC*NL*Pi^2)/
        225225 + (834632*CF*lm*NC*NL*Pi^2)/45 + (834632*CF*lm*NC*NH*Pi^2)/
        45 - (4320038856974136010307663985041*CF^2*NC*Pi^3)/
        (15453743650179029498160*Sqrt[3]) - (3484340549155146199849764280*CF*
         NC*NH*Pi^3)/(1350851717672992089*Sqrt[3]) - 
       (3039251381*CF^2*NC*Pi^4)/450 + 
       (10325469932061093077260825960198746529*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(2707109543920111492340178000*Sqrt[3]) + 
       (336853579605246368326754708880986*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(33805064234766627027225*Sqrt[3]) - 
       731217736*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2 - 
       (4320038856974136010307663985041*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(417346472034155889225*
         Sqrt[3]) - (1592841393899495405645606528*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(16677181699666569*Sqrt[3]) - 
       (4320038856974136010307663985041*CF^2*NC*Pi*Log[3]^2)/
        (20032630657639482682800*Sqrt[3]) - (99552587118718462852850408*CF*NC*
         NH*Pi*Log[3]^2)/(50031545098999707*Sqrt[3]) - 
       (CF*NC*(-899*CA*(-1417499904972759771140971292850149 + 
            81900124405911049796157600*lm) + 
          77*(899*CF*(-36818172007101555287912347810841 + 
              6961994046311210844537600*lm) + 
            10920*(268801*(-68016168626828404771942631 + 59229398210348520*
                 lm)*NM + 1850886808914*(11310528121 + 8601780180*lm)*NL + 
              5*(715308700851580604191 + 3184184293667978504904*lm)*NH)))*
         Log[x]^2)/34149454710484113000 + 
       (CF*NC*(-29513716222166126144867*CA + 28*(2108118620987326330811*CF + 
            4004*(2974398293227667061*NM + 6615178567*NL)))*Log[x]^3)/
        2837835 + (55707388990238292887710198135545804248*CF^2*NC*
         PolyGamma[2, 1])/14893140187344737781225 + 
       (288339764732465979419*CF*NM*NC*PolyGamma[2, 1])/14175 - 
       (1724538840723458347716503614313*CF*NC*NH*PolyGamma[2, 1])/
        2127591455334962540175 - (6216939925007876158432545204680335402693*
         CF^2*NC*Zeta[3])/2129719046790297502715175 - 
       (256151945307583186922*CF*NM*NC*Zeta[3])/14175 - 
       (63768306008*CF*NC*NL*Zeta[3])/135 + 
       (11583464443420031770963374837614*CF*NC*NH*Zeta[3])/
        2127591455334962540175 + CA*CF*NC*
        (124341265619997127774384635850761183047916604221760132244124113197/
          17794469400019498912693897247978149071053472000000 + 
         (951365492*lm^2)/15 - (254408419206756884970663315139*Pi^2)/
          81811377648000 + (4320038856974136010307663985041*Pi^3)/
          (30907487300358058996320*Sqrt[3]) + (3052605493*Pi^4)/900 + 
         lm*(22950804700903065671/88540452000 - (4590476*Pi^2)/45) - 
         (10325469932061093077260825960198746529*Im[PolyLog[2, (-1)^(1/3)]])/
          (5414219087840222984680356000*Sqrt[3]) + 
         365608868*Im[PolyLog[2, (-1)^(1/3)]]^2 + 
         (4320038856974136010307663985041*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(834692944068311778450*Sqrt[3]) + 
         (4320038856974136010307663985041*Pi*Log[3]^2)/
          (40065261315278965365600*Sqrt[3]) - 
         (27853694495119146443855099067772902124*PolyGamma[2, 1])/
          14893140187344737781225 + 
         (12433882750969342977911273186505838419749*Zeta[3])/
          8518876187161190010860700) + CF*Log[x]*
        ((1944435296515039052097432582376778501*NM*NC)/6858722586405690000 - 
         (22981121889494*lm*NM*NC)/96525 - 40062336*lm^2*NM*NC - 
         (589803207778178209693*NC*NL)/626107482000 - 
         (22981121889494*lm*NC*NL)/96525 - 40062336*lm^2*NC*NL - 
         (59831248972725213665588367072367322240927212256779*NC*NH)/
          3194435549548892860169482662421693410000 - 
         (22981121889494*lm*NC*NH)/96525 - 40062336*lm^2*NC*NH + 
         29376773341896320*NM*NC*Pi^2 - (31869129628*NC*NL*Pi^2)/405 + 
         (1592841393899495405645606528*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (50031545098999707*Sqrt[3]) + 
         CF*NC*(169013737563756464293427186172206399598766923310338241/
            4521689862650421655051018454333040000 - (73233905476376*lm)/
            10725 - 1442244096*lm^2 + (104104804290424538357*Pi^2)/20020 + 
           (4320038856974136010307663985041*Im[PolyLog[2, (-1)^(1/3)]])/
            (1252039416102467667675*Sqrt[3]) - 240374016*Zeta[3]) + 
         CA*NC*(-28985855467493415383959335050010077686584983686757915129/
            1550939622889094627682499329836232720000 + (13951389933547*lm)/
            8775 + 220342848*lm^2 - (98379037971704639632991*Pi^2)/37837800 - 
           (4320038856974136010307663985041*Im[PolyLog[2, (-1)^(1/3)]])/
            (2504078832204935335350*Sqrt[3]) + 120187008*Zeta[3])), 
      (-363441070049539172483637415988409742958759791155869101458617276935240\
42237*CF^2*NC)/486068031900724626059494435178651767017193904040960000000 - 
       (6415071155474708614691*CF^2*lm*NC)/9090153072000 - 
       (15923656458*CF^2*lm^2*NC)/35 + 
       (41479651379033556629622988136122686860785159646112729179*CF*NM*NC)/
        1302503614147622932440949585519488000000 - 
       (11412339923814802460291*CF*lm*NM*NC)/327245510592000 - 
       (884647581*CF*lm^2*NM*NC)/70 + (99780392515183706823858845969*CF*NC*
         NL)/265333932443099520000 - (11412339923814802460291*CF*lm*NC*NL)/
        327245510592000 - (884647581*CF*lm^2*NC*NL)/70 + 
       (7073830743960256493292848767251833452811635779195208831947614343479*
         CF*NC*NH)/
        361649668790072111262197770189990379400829760121984000000 - 
       (11412339923814802460291*CF*lm*NC*NH)/327245510592000 - 
       (884647581*CF*lm^2*NC*NH)/70 + (6177964367957074453220571346486463*
         CF^2*NC*Pi^2)/109673995406976000 + (65831599*CF^2*lm*NC*Pi^2)/105 - 
       (762138633141043240093531*CF*NM*NC*Pi^2)/26195400 + 
       (65831599*CF*lm*NM*NC*Pi^2)/3780 - (36739733063228621*CF*NC*NL*Pi^2)/
        1362160800 + (65831599*CF*lm*NC*NL*Pi^2)/3780 + 
       (65831599*CF*lm*NC*NH*Pi^2)/3780 - (287849130193080907816080139046143*
         CF^2*NC*Pi^3)/(865409644410025651896960*Sqrt[3]) - 
       (7442458780792698226332369185*CF*NC*NH*Pi^3)/(2701703435345984178*
         Sqrt[3]) - (1658435748323*CF^2*NC*Pi^4)/226800 + 
       (1378780636212212769934960553768497775017*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(303196268919052487142099936000*
         Sqrt[3]) + (8492308230216195595029095801691659*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(946541798573465556762300*Sqrt[3]) - 
       (85453361593*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/105 - 
       (287849130193080907816080139046143*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(23371402433912729796600*
         Sqrt[3]) - (11907934049268317162131790696*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(116740271897665983*
         Sqrt[3]) - (287849130193080907816080139046143*CF^2*NC*Pi*Log[3]^2)/
        (1121827316827811030236800*Sqrt[3]) - 
       (1488491756158539645266473837*CF*NC*NH*Pi*Log[3]^2)/
        (700441631385995898*Sqrt[3]) - 
       (CF*NC*(-93*CA*(-11914204067977821946944165402117540587 + 
            85198936492483014503740838400*lm) + 
          10*(93*CF*(-2382840758186711111199787242680075513 + 
              55766576613261609493357639680*lm) + 
            8008*(217*(65866016450378113634979041614379 + 
                82903074029038832437440*lm)*NM + 133263850241808*(
                177399158327 + 134995102060*lm)*NL + 
              (4133288796801694525925701 + 17989967064301426638924480*lm)*
               NH)))*Log[x]^2)/3278347652206474848000 + 
       (CF*NC*(-29523600791697059815446761*CA + 
          104*(567761411158227479951581*CF - 20020*(14294154125895016311*
               NM - 47915843918*NL)))*Log[x]^3)/340540200 + 
       (1170896354090370025480889832357665174749*CF^2*NC*PolyGamma[2, 1])/
        39715040499585967416600 - (16869348324529860438197*CF*NM*NC*
         PolyGamma[2, 1])/1190700 - (5701206373555587663750936446413*CF*NC*
         NH*PolyGamma[2, 1])/7943008099917193483320 - 
       (28635291075044177686280122114689051830333*CF^2*NC*Zeta[3])/
        1032591052989235152831600 + (9146014422838372625593*CF*NM*NC*
         Zeta[3])/595350 - (1501952052019*CF*NC*NL*Zeta[3])/2835 + 
       (25647711331735586266656835653611*CF*NC*NH*Zeta[3])/
        3971504049958596741660 + CA*CF*NC*(3003645187680698424887520255792071\
03099490554066724604003506338048373997/
          8034182345466522744785031986423996149044527339520000000 + 
         (9731123391*lm^2)/140 - (110602942587092873560097466985807*Pi^2)/
          3926946127104000 + (287849130193080907816080139046143*Pi^3)/
          (1730819288820051303793920*Sqrt[3]) + (1664755581827*Pi^4)/453600 + 
         lm*(16675920820875214786691/59499183744000 - (724147589*Pi^2)/
            7560) - (1378780636212212769934960553768497775017*
           Im[PolyLog[2, (-1)^(1/3)]])/(606392537838104974284199872000*
           Sqrt[3]) + (85453361593*Im[PolyLog[2, (-1)^(1/3)]]^2)/210 + 
         (287849130193080907816080139046143*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(46742804867825459593200*Sqrt[3]) + 
         (287849130193080907816080139046143*Pi*Log[3]^2)/
          (2243654633655622060473600*Sqrt[3]) - 
         (1170896354090370025480889832357665174749*PolyGamma[2, 1])/
          79430080999171934833200 + 
         (28635291793880188326732542990859397615913*Zeta[3])/
          2065182105978470305663200) + CF*Log[x]*
        ((-758148407304652398791715813016472036242475081*NM*NC)/
          3075781194605388546557280000 - (59336004615832799*lm*NM*NC)/
          227026800 - 45070128*lm^2*NM*NC - (48117387602248849601089*NC*NL)/
          46018899927000 - (59336004615832799*lm*NC*NL)/227026800 - 
         45070128*lm^2*NC*NL - 
         (50104701736755696541463746269180510435527657055354991*NC*NH)/
          2504437470846332002372874407338607633440000 - 
         (59336004615832799*lm*NC*NH)/227026800 - 45070128*lm^2*NC*NH - 
         (12388266858559090231*NM*NC*Pi^2)/567 - (750679783814*NC*NL*Pi^2)/
          8505 + (11907934049268317162131790696*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(350220815692997949*Sqrt[3]) + 
         CF*NC*(91270579752939231478315834256586371888449636932765301268329/
            203803159820270090918903427561292455862500 - 
           (46972184568854399*lm)/6306300 - 1622524608*lm^2 + 
           (5367927310209497599302677*Pi^2)/123832800 + 
           (287849130193080907816080139046143*Im[PolyLog[2, (-1)^(1/3)]])/
            (70114207301738189389800*Sqrt[3]) - 270420768*Zeta[3]) + 
         CA*NC*(-359465667291723311840839453001735429051052138398539474773409\
1/16053418127381274853919777678674113446400000 + (72358711624562399*lm)/
            41277600 + 247885704*lm^2 - (5367927296378788436636437*Pi^2)/
            247665600 - (287849130193080907816080139046143*
             Im[PolyLog[2, (-1)^(1/3)]])/(140228414603476378779600*Sqrt[3]) + 
           135210384*Zeta[3])), 
      (-173201598159651192116010464404948264891502695280988815908151161275710\
1431221*CF^2*NC)/
        10936530717766304086338624791519664757886862840921600000000 - 
       (1909160822867025865*CF^2*lm*NC)/1731457728 - 
       (3433426692*CF^2*lm^2*NC)/5 - 
       (17055276388958265055449552444283270990324926629257743643*CF*NM*NC)/
        22742126596228336915635627683673600000 - 
       (16729144206091854221*CF*lm*NM*NC)/311662391040 - 
       (286118891*CF*lm^2*NM*NC)/15 + (6495017333680084582555621*CF*NC*NL)/
        10314244215475200 - (16729144206091854221*CF*lm*NC*NL)/
        311662391040 - (286118891*CF*lm^2*NC*NL)/15 + 
       (7624573170693000558979006798184571678201547911942500529601225791877*
         CF*NC*NH)/
        232489072793617785811412852264993815329104845792704000000 - 
       (16729144206091854221*CF*lm*NC*NH)/311662391040 - 
       (286118891*CF*lm^2*NC*NH)/15 + (483960088213820897262793258657159*
         CF^2*NC*Pi^2)/7366990600569600 + 1043290*CF^2*lm*NC*Pi^2 + 
       (4627945197232894593167407*CF*NM*NC*Pi^2)/9729720 + 
       (521645*CF*lm*NM*NC*Pi^2)/18 - (279634295663381*CF*NC*NL*Pi^2)/
        6486480 + (521645*CF*lm*NC*NL*Pi^2)/18 + (521645*CF*lm*NC*NH*Pi^2)/
        18 - (62828625369326794839570213311899*CF^2*NC*Pi^3)/
        (121698231245159857298010*Sqrt[3]) - (57699670100157306352264570990*
         CF*NC*NH*Pi^3)/(12157665459056928801*Sqrt[3]) - 
       (18808308088*CF^2*NC*Pi^4)/1575 + 
       (2336091479561127428787835647276278083613*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(341095802533934048034862428000*
         Sqrt[3]) + (225256167653898528747682356155279*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(12169823124515985729801*Sqrt[3]) - 
       (44491911488*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 - 
       (502629002954614358716561706495192*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(26292827738151821021175*
         Sqrt[3]) - (26376992045786197189606661024*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(150094635296999121*
         Sqrt[3]) - (62828625369326794839570213311899*CF^2*NC*Pi*Log[3]^2)/
        (157756966428910926127050*Sqrt[3]) - (1648562002861637324350416314*CF*
         NC*NH*Pi*Log[3]^2)/(450283905890997363*Sqrt[3]) + 
       CF*((310144939192697944384789686403937057*CF*NC)/393426897586222500 - 
         (79082813536*CF*lm*NC)/3 + 
         CA*(-17368117208813911809048435919268636377/44063812529656920000 + 
           (108738868612*lm)/27)*NC + (11964589689833776424160861469643*NM*
           NC)/2096180606520 - (19770703384*lm*NM*NC)/27 - 
         (2728570350998*NC*NL)/2835 - (19770703384*lm*NC*NL)/27 - 
         (55825295285945102079091*NC*NH)/324907994010600 - 
         (19770703384*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-6335802237020003771016633*CA + 
          16*(791975004724300264299961*CF + 350350*(15177982619964766161*
               NM + 4942675846*NL)))*Log[x]^3)/56756700 + 
       (43403537709723204877346363051229328260931*CF^2*NC*PolyGamma[2, 1])/
        1072306093488821120248200 + (1472487790929378710033*CF*NM*NC*
         PolyGamma[2, 1])/5670 - (56563798608620357522956270113511*CF*NC*NH*
         PolyGamma[2, 1])/38296646196029325723150 - 
       (18092488374454591200348676687819345131787*CF^2*NC*Zeta[3])/
        589768351418851616136510 - (652429758019194667357*CF*NM*NC*Zeta[3])/
        2835 - (23565983746*CF*NC*NL*Zeta[3])/27 + 
       (189759608152651772329708342840589*CF*NC*NH*Zeta[3])/
        19148323098014662861575 + CA*CF*NC*(173201597191568259450438215849312\
8452415436364600994072598276858886206165221/
          21873061435532608172677249583039329515773725681843200000000 + 
         (3147307801*lm^2)/30 - (7491642226073261313402591869309*Pi^2)/
          228080204352000 + (62828625369326794839570213311899*Pi^3)/
          (243396462490319714596020*Sqrt[3]) + (9440669194*Pi^4)/1575 + 
         lm*(4859059105061793769/11333177856 - (5738095*Pi^2)/36) - 
         (2336091479561127428787835647276278083613*
           Im[PolyLog[2, (-1)^(1/3)]])/(682191605067868096069724856000*
           Sqrt[3]) + (22245955744*Im[PolyLog[2, (-1)^(1/3)]]^2)/35 + 
         (251314501477307179358280853247596*Im[PolyLog[3, 
             -((-1)^(5/6)/Sqrt[3])]])/(26292827738151821021175*Sqrt[3]) + 
         (62828625369326794839570213311899*Pi*Log[3]^2)/
          (315513932857821852254100*Sqrt[3]) - 
         (43403537709723204877346363051229328260931*PolyGamma[2, 1])/
          2144612186977642240496400 + 
         (90462445550944872617036904732849549100463*Zeta[3])/
          5897683514188516161365100) + CF*Log[x]*
        ((17227457771539338287734991697000145706294507*NM*NC)/
          4882192372389505629456000 - (30161409542899*lm*NM*NC)/72072 - 
         70109088*lm^2*NM*NC - (3023094189524647588417*NC*NL)/
          1753100949600 - (30161409542899*lm*NC*NL)/72072 - 
         70109088*lm^2*NC*NL - 
         (55484568118186446924075088992236319447582012148216133*NC*NH)/
          1609995516972642001525419261860533478640000 - 
         (30161409542899*lm*NC*NH)/72072 - 70109088*lm^2*NC*NH + 
         (3372885028047586622*NM*NC*Pi^2)/9 - (11778297068*NC*NL*Pi^2)/81 + 
         (26376992045786197189606661024*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (450283905890997363*Sqrt[3]) + 
         CF*NC*
          (124142694285570167387824712841134656111959504091912626334657397/
            335401771589930206769395355072298441648000000 - 
           (24055819396243*lm)/2002 - 2523927168*lm^2 + 
           (487369390690097653516159*Pi^2)/8731800 + 
           (502629002954614358716561706495192*Im[PolyLog[2, (-1)^(1/3)]])/
            (78878483214455463063525*Sqrt[3]) - 420654528*Zeta[3]) + 
         CA*NC*
          (-217249714254915977509425987173268196665653338191736370939918501/
            1173906200564755723692883742753044545768000000 + 
           (36592375966963*lm)/13104 + 385599984*lm^2 - 
           (69624198417618247056589*Pi^2)/2494800 - 
           (251314501477307179358280853247596*Im[PolyLog[2, (-1)^(1/3)]])/
            (78878483214455463063525*Sqrt[3]) + 210327264*Zeta[3])), 
      (-873113027645344475936869693560100126786188966176451795045060172804704\
4191088838701*CF^2*NC)/
        8308159758630887108420906264686139486456292037794332332800000000 - 
       (2523391859727677707583*CF^2*lm*NC)/2189211864840 - 
       (26004550032*CF^2*lm^2*NC)/35 + 
       (4457477843956722281044727016082148108795961340625489179395107*CF*NM*
         NC)/8892327851245628803829825419256702856000000 - 
       (4488814019997337527311*CF*lm*NM*NC)/78811627134240 - 
       (722348612*CF*lm^2*NM*NC)/35 + (708109866795717010801115402*CF*NC*
         NL)/998457115573642725 - (4488814019997337527311*CF*lm*NC*NL)/
        78811627134240 - (722348612*CF*lm^2*NC*NL)/35 + 
       (1667865612336224864248898497422968557754403524419989490522954799327*
         CF*NC*NH)/
        46944908929480514442689133630431443479915401554296000000 - 
       (4488814019997337527311*CF*lm*NC*NH)/78811627134240 - 
       (722348612*CF*lm^2*NC*NH)/35 + (1153220495167957929247554213632426881*
         CF^2*NC*Pi^2)/1549830647594829600 + (6786800*CF^2*lm*NC*Pi^2)/7 - 
       (11677134518933123370072920*CF*NM*NC*Pi^2)/28945917 + 
       (1696700*CF*lm*NM*NC*Pi^2)/63 - (13459375351190987*CF*NC*NL*Pi^2)/
        289459170 + (1696700*CF*lm*NC*NL*Pi^2)/63 + 
       (1696700*CF*lm*NC*NH*Pi^2)/63 - (4282394612318818802626112348195857*
         CF^2*NC*Pi^3)/(7093268335432174539655440*Sqrt[3]) - 
       (182374049476956156600462631000*CF*NC*NH*Pi^3)/(36472996377170786403*
         Sqrt[3]) - (361828820033*CF^2*NC*Pi^4)/28350 + 
       (339872149391959434853552968533678093764811*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(42247151542417259949460817868000*
         Sqrt[3]) + (21187183873028091912859853540741332*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(1277831428074178501629105*Sqrt[3]) - 
       (20919384104*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (4282394612318818802626112348195857*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(191562030663677553154275*
         Sqrt[3]) - (583596958326259701121480419200*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(3151987341236981541*
         Sqrt[3]) - (4282394612318818802626112348195857*CF^2*NC*Pi*Log[3]^2)/
        (9194977471856522551405200*Sqrt[3]) - 
       (36474809895391231320092526200*CF*NC*NH*Pi*Log[3]^2)/
        (9455962023710944623*Sqrt[3]) - 
       (CF*NC*(CA*(155511783383191986280019200045923442396117 - 
            154841711679304129012874140800000*lm) + 
          2*(CF*(-155511782878296520514161761203949503479807 + 
              506754692768631694951224460800000*lm) + 
            20420400*(7*(589823241558042563089775321763949 + 
                98476588142761318776000*lm)*NM + 111053208534840*(
                8153281811 + 6207259800*lm)*NL + (165121119651174030510553 + 
                689336116999329231432000*lm)*NH)))*Log[x]^2)/
        34832443804693795260000 + (2*CF*NC*(-417609817928950180945810847*CA + 
          51*(16376855003611874805594069*CF - 4004000*
             (2177957110439729841*NM - 954735674*NL)))*Log[x]^3)/
        723647925 + (633612732134566890917182290290041681642109*CF^2*NC*
         PolyGamma[2, 1])/1608459140233231680372300 - 
       (40311730139931750231539*CF*NM*NC*PolyGamma[2, 1])/198450 - 
       (2079653040372189212683040463769379*CF*NC*NH*PolyGamma[2, 1])/
        1608459140233231680372300 - 
       (51157372109630472261327067648536249085960646*CF^2*NC*Zeta[3])/
        139648720353820936249466475 + (20671069644670022880061*CF*NM*NC*
         Zeta[3])/99225 - (182215117232*CF*NC*NL*Zeta[3])/189 + 
       (9312499990344299767622130664539421*CF*NC*NH*Zeta[3])/
        804229570116615840186150 + CA*CF*NC*(87311302689562627603064915261266\
59968681197237179226915495897781064436459241462701/
          16616319517261774216841812529372278972912584075588664665600000000 + 
         (3972917366*lm^2)/35 - (356824312349909873890124372909447*Pi^2)/
          959083293168000 + (4282394612318818802626112348195857*Pi^3)/
          (14186536670864349079310880*Sqrt[3]) + (363050444033*Pi^4)/56700 + 
         lm*(6558976546174784860943/14329386751680 - (9331850*Pi^2)/63) - 
         (339872149391959434853552968533678093764811*
           Im[PolyLog[2, (-1)^(1/3)]])/(84494303084834519898921635736000*
           Sqrt[3]) + (10459692052*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 + 
         (4282394612318818802626112348195857*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(383124061327355106308550*
           Sqrt[3]) + (4282394612318818802626112348195857*Pi*Log[3]^2)/
          (18389954943713045102810400*Sqrt[3]) - 
         (633612732134566890917182290290041681642109*PolyGamma[2, 1])/
          3216918280466463360744600 + 
         (716203211990161118402860863814159073792737087*Zeta[3])/
          3910164169906986214985061300) + CF*Log[x]*
        ((-202677572773335381026917198613304521466588792853*NM*NC)/
          61579702666995383192532210000 - (21852423001336717*lm*NM*NC)/
          48243195 - 77768064*lm^2*NM*NC - (24595899359099372818957*NC*NL)/
          13038688312650 - (21852423001336717*lm*NC*NL)/48243195 - 
         77768064*lm^2*NC*NL - 
         (153473823391481724910449101511712215762540246910565779*NC*NH)/
          4226238232053185254004225562383900381430000 - 
         (21852423001336717*lm*NC*NH)/48243195 - 77768064*lm^2*NC*NH - 
         (58078856244671947184*NM*NC*Pi^2)/189 - (91077018016*NC*NL*Pi^2)/
          567 + (583596958326259701121480419200*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(9455962023710944623*Sqrt[3]) + 
         CF*NC*(3327793563384804090073708877635244224593857613732330653155931\
98464179/57534316795879242773911925116069466232635448000000 - 
           (69276089269778548*lm)/5360355 - 2799650304*lm^2 + 
           (13257454500908376747322247*Pi^2)/22972950 + 
           (4282394612318818802626112348195857*Im[PolyLog[2, (-1)^(1/3)]])/
            (574686091991032659462825*Sqrt[3]) - 466608384*Zeta[3]) + 
         CA*NC*(-332779356252293248252024524977696427380134870784483012584967\
548463279/115068633591758485547823850232138932465270896000000 + 
           (26627415571204237*lm)/8771490 + 427724352*lm^2 - 
           (417609816632208306701011751*Pi^2)/1447295850 - 
           (4282394612318818802626112348195857*Im[PolyLog[2, (-1)^(1/3)]])/
            (1149372183982065318925650*Sqrt[3]) + 233304192*Zeta[3])), 
      (-587192254693246137862656712535807583489120410829678859381383188783349\
162246340223*CF^2*NC)/
        339108561576770902384526786313719979039032328073238054400000000 - 
       (3357577538553078831*CF^2*lm*NC)/1891123520 - 
       (5529010032*CF^2*lm^2*NC)/5 - 
       (6944868353777063705056284390156639864176426495648081264309*CF*NM*NC)/
        714221688201811495945288830196416000000 - 
       (1961484697576313573*CF*lm*NM*NC)/22693482240 - 
       (153583612*CF*lm^2*NM*NC)/5 + (45000265024438403334751627*CF*NC*NL)/
        38640214903530240 - (1961484697576313573*CF*lm*NC*NL)/22693482240 - 
       (153583612*CF*lm^2*NC*NL)/5 + 
       (8168335807012338208615484337147281315855517699298536149981487626437*
         CF*NC*NH)/
        139493443676170671486847711358996289197462907475622400000 - 
       (1961484697576313573*CF*lm*NC*NH)/22693482240 - 
       (153583612*CF*lm^2*NC*NH)/5 + (224000731257039020879761046469213029*
         CF^2*NC*Pi^2)/337378100156697600 + 1592010*CF^2*lm*NC*Pi^2 + 
       (109225815990515583620799113*CF*NM*NC*Pi^2)/18378360 + 
       (88445*CF*lm*NM*NC*Pi^2)/2 - (384211534853489*CF*NC*NL*Pi^2)/
        5250960 + (88445*CF*lm*NC*NL*Pi^2)/2 + (88445*CF*lm*NC*NH*Pi^2)/2 - 
       (52332486758230679632282734993561281*CF^2*NC*Pi^3)/
        (56746146683457396317243520*Sqrt[3]) - 
       (617132621790159430295427943765*CF*NC*NH*Pi^3)/(72945992754341572806*
         Sqrt[3]) - (221083026269*CF^2*NC*Pi^4)/10800 + 
       (576533215582620473104700310551504556273889*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(48282458905619725656526648992000*
         Sqrt[3]) + (6080701277966429477446377149595638*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(182547346867739785947015*Sqrt[3]) - 
       (10731962983*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/5 - 
       (7476069536890097090326104999080183*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(218928035044202917890600*
         Sqrt[3]) - (141058884980607869781812101432*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(450283905890997363*
         Sqrt[3]) - (7476069536890097090326104999080183*CF^2*NC*Pi*Log[3]^2)/
        (10508545682121740058748800*Sqrt[3]) - 
       (17632360622575983722726512679*CF*NC*NH*Pi*Log[3]^2)/
        (2701703435345984178*Sqrt[3]) + 
       CF*((52861371985466819123076713426519516937211*CF*NC)/
          6634751200894056240000 - 47604613392*CF*lm*NC + 
         CA*(-52861372320122737729817237624338961331691/
            13269502401788112480000 + 7272927046*lm)*NC + 
         (83053125957975180442523507187617*NM*NC)/1164544781400 - 
         1322350372*lm*NM*NC - (15638046938*NC*NL)/9 - 
         1322350372*lm*NC*NL - (776597323772794714111*NC*NH)/
          2406725881560 - 1322350372*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-158517838550109493906163371*CA + 
          32*(9907364272328752221388316*CF + 11486475*
             (7064330181329259516*NM + 330587593*NL)))*Log[x]^3)/
        137837700 + (180706028692458775757948421741186424535177*CF^2*NC*
         PolyGamma[2, 1])/428922437395528448099280 + 
       (30887471899701903871627*CF*NM*NC*PolyGamma[2, 1])/9450 - 
       (42817289329877365095409435271137*CF*NC*NH*PolyGamma[2, 1])/
        16412848369726853881350 - 
       (1602791092973169931919370596534003892781898143*CF^2*NC*Zeta[3])/
        5213552226542648286646748400 - (13617808188520700322623*CF*NM*NC*
         Zeta[3])/4725 - 1561045738*CF*NC*NL*Zeta[3] + 
       (143466157680780426912760500324263*CF*NC*NH*Zeta[3])/
        8206424184863426940675 + CA*CF*NC*(4110345778990063470012670569674821\
807337472148774952925683578995633255001915696811/
          4747519862074792633383375008392079706546452593025332761600000000 + 
         (844709866*lm^2)/5 - (412632925941043584241537291958085077*Pi^2)/
          1242971947945728000 + (52332486758230679632282734993561281*Pi^3)/
          (113492293366914792634487040*Sqrt[3]) + (221847191069*Pi^4)/21600 + 
         lm*(2848663926628653797/4126087680 - (972895*Pi^2)/4) - 
         (576533215582620473104700310551504556273889*
           Im[PolyLog[2, (-1)^(1/3)]])/(96564917811239451313053297984000*
           Sqrt[3]) + (10731962983*Im[PolyLog[2, (-1)^(1/3)]]^2)/10 + 
         (7476069536890097090326104999080183*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(437856070088405835781200*
           Sqrt[3]) + (7476069536890097090326104999080183*Pi*Log[3]^2)/
          (21017091364243480117497600*Sqrt[3]) - 
         (180706028692458775757948421741186424535177*PolyGamma[2, 1])/
          857844874791056896198560 + 
         (1602791104518681308762087047339918399525649371*Zeta[3])/
          10427104453085296573293496800) + CF*Log[x]*
        ((3642447133984443659495713620319171566639323537*NM*NC)/
          84082201968930374729520000 - (624558607325281*lm*NM*NC)/875160 - 
         119082348*lm^2*NM*NC - (38576828520918310717*NC*NL)/12614906304 - 
         (624558607325281*lm*NC*NL)/875160 - 119082348*lm^2*NC*NL - 
         (59343608160332352583026997728075343127945097042849743*NC*NH)/
          965997310183585200915251557116320087184000 - 
         (624558607325281*lm*NC*NH)/875160 - 119082348*lm^2*NC*NH + 
         4709553454520207716*NM*NC*Pi^2 - (780257534*NC*NL*Pi^2)/3 + 
         (141058884980607869781812101432*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (1350851717672992089*Sqrt[3]) + CF*NC*(1130652615241266098281780743\
23092067253561638834102045341973617746113/
            32876752454788138727949671494896837847220256000000 - 
           (498630810550501*lm)/24310 - 4286964528*lm^2 + 
           (634071351414053434753411471*Pi^2)/1102701600 + 
           (7476069536890097090326104999080183*Im[PolyLog[2, (-1)^(1/3)]])/
            (656784105132608753671800*Sqrt[3]) - 714494088*Zeta[3]) + 
         CA*NC*(-113065261448446098207672725144877556484577046409862096168262\
064435063/65753504909576277455899342989793675694440512000000 + 
           (757197289821601*lm)/159120 + 654952914*lm^2 - 
           (211357117005611700176219429*Pi^2)/735134400 - 
           (7476069536890097090326104999080183*Im[PolyLog[2, (-1)^(1/3)]])/
            (1313568210265217507343600*Sqrt[3]) + 357247044*Zeta[3])), 
      (-383667494546647179869548577583478481479369512510532087839132418306301\
94739420167293*CF^2*NC)/
        2670479922417070856278148442220544834932379583576749678400000000 - 
       (21863495928051764071*CF^2*lm*NC)/11914078176 - 
       (5913817716*CF^2*lm^2*NC)/5 + 
       (8341949219098949437029169034957103901592332786640893251634273*CF*NM*
         NC)/1129184489047063975089501640540533696000000 - 
       (194453850932929454291*CF*lm*NM*NC)/2144534071680 - 
       (492818143*CF*lm^2*NM*NC)/15 + (246396719826596303354861699*CF*NC*
         NL)/190928120699796480 - (194453850932929454291*CF*lm*NC*NL)/
        2144534071680 - (492818143*CF*lm^2*NC*NL)/15 + 
       (92996013061591192637435430837836411053864289364852799919227484603*CF*
         NC*NH)/1485728985900042654889502251160907222221498422817280000 - 
       (194453850932929454291*CF*lm*NC*NH)/2144534071680 - 
       (492818143*CF*lm^2*NC*NH)/15 + (3597048347930721542466808392396528913*
         CF^2*NC*Pi^2)/372891584383718400 + 1465660*CF^2*lm*NC*Pi^2 - 
       (179364140052508163507876263*CF*NM*NC*Pi^2)/33081048 + 
       (366415*CF*lm*NM*NC*Pi^2)/9 - (4546367998655*CF*NC*NL*Pi^2)/58344 + 
       (366415*CF*lm*NC*NL*Pi^2)/9 + (366415*CF*lm*NC*NH*Pi^2)/9 - 
       (49300915273163347177116792256653029*CF^2*NC*Pi^3)/
        (46428665468283324259562880*Sqrt[3]) - 
       (11560686427841156575886985180035*CF*NC*NH*Pi^3)/
        (1313027869578148310508*Sqrt[3]) - (700618293817*CF^2*NC*Pi^4)/
        32400 + (3826611748176737059320796270432479284963347*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(276526810095822065123743535136000*
         Sqrt[3]) + (1072371494581553241427397439152581*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(36108266413399078538970*Sqrt[3]) - 
       (34866686459*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/15 - 
       (7042987896166192453873827465236147*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(179122937763438751001400*
         Sqrt[3]) - (1321221306038989322958512592004*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) - (7042987896166192453873827465236147*CF^2*NC*Pi*Log[3]^2)/
        (8597901012645060048067200*Sqrt[3]) - 
       (330305326509747330739628148001*CF*NC*NH*Pi*Log[3]^2)/
        (48630661836227715204*Sqrt[3]) + 
       CF*((329149193477326012220416279080578285041889*CF*NC)/
          2843464800383166960000 - 51818135472*CF*lm*NC + 
         CA*(-2304044355371482244999354591579844864609563/
            39808507205364337440000 + 7916659586*lm)*NC - 
         (7046553415839126550676129753734507*NM*NC)/108302664670200 - 
         1439392652*lm*NM*NC - (357202032658*NC*NL)/189 - 
         1439392652*lm*NC*NL - (54225178019438457809*NC*NH)/151472258280 - 
         1439392652*lm*NC*NH)*Log[x]^2 + 
       (CF*NC*(-3116026490160851145714360869*CA + 
          4*(1558013236842197080572294097*CF - 137837700*
             (6267676024718017310*NM - 359848163*NL)))*Log[x]^3)/
        206756550 + (149483189722724596373529921084296378253730877*CF^2*NC*
         PolyGamma[2, 1])/28952264524198170246701400 - 
       (2222296885004372424553709*CF*NM*NC*PolyGamma[2, 1])/793800 - 
       (65430871577237306091753736868268107*CF*NC*NH*PolyGamma[2, 1])/
        28952264524198170246701400 - 
       (667907490573100235513526565674346711215451772353*CF^2*NC*Zeta[3])/
        140765910116651503739462206800 + (1094557272246986104867291*CF*NM*NC*
         Zeta[3])/396900 - (5102184760*CF*NC*NL*Zeta[3])/3 + 
       (291717795086909774464268784466929493*CF*NC*NH*Zeta[3])/
        14476132262099085123350700 + CA*CF*NC*(153466997801209716124676131780\
158125685410053920882588831478580459754099451375576547/
          21363839379336566850225187537764358679459036668613997427200000000 + 
         (5420999573*lm^2)/30 - (5995080579827751311360118519432536327*Pi^2)/
          1242971947945728000 + (49300915273163347177116792256653029*Pi^3)/
          (92857330936566648519125760*Sqrt[3]) + (702728844217*Pi^4)/64800 + 
         lm*(56825454045104594935/77983057152 - (4030565*Pi^2)/18) - 
         (3826611748176737059320796270432479284963347*
           Im[PolyLog[2, (-1)^(1/3)]])/(553053620191644130247487070272000*
           Sqrt[3]) + (34866686459*Im[PolyLog[2, (-1)^(1/3)]]^2)/30 + 
         (7042987896166192453873827465236147*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(358245875526877502002800*
           Sqrt[3]) + (7042987896166192453873827465236147*Pi*Log[3]^2)/
          (17195802025290120096134400*Sqrt[3]) - 
         (149483189722724596373529921084296378253730877*PolyGamma[2, 1])/
          57904529048396340493402800 + 
         (667907490882636578941725077763951780061846925029*Zeta[3])/
          281531820233303007478924413600) + CF*Log[x]*
        ((-167502464244065902590165984952789808921264171971*NM*NC)/
          3909822391555262424922680000 - (21025185979945799*lm*NM*NC)/
          27567540 - 130423524*lm^2*NM*NC - (17149458269304992999*NC*NL)/
          5194373184 - (21025185979945799*lm*NC*NL)/27567540 - 
         130423524*lm^2*NC*NL - 
         (4276282774674370042259699130875794498494263972887007*NC*NH)/
          66876736858863590832594338569591390651200 - 
         (21025185979945799*lm*NC*NH)/27567540 - 130423524*lm^2*NC*NH - 
         (12535352048412371069*NM*NC*Pi^2)/3 - (850119850*NC*NL*Pi^2)/3 + 
         (1321221306038989322958512592004*NC*NH*Im[PolyLog[2, (-1)^(1/3)]])/
          (12157665459056928801*Sqrt[3]) + 
         CF*NC*(2172097923355827972768672420350395060329974512267284415486964\
3518916377/295890772093093248551547043454071540624982304000000 - 
           (16680676991215889*lm)/765765 - 4695246864*lm^2 + 
           (24928211911879785879443331623*Pi^2)/3308104800 + 
           (7042987896166192453873827465236147*Im[PolyLog[2, (-1)^(1/3)]])/
            (537368813290316253004200*Sqrt[3]) - 782541144*Zeta[3]) + 
         CA*NC*(-217209792327731101317128365772699801526161121845741415422012\
36251417177/591781544186186497103094086908143081249964608000000 + 
           (25601220526068839*lm)/5012280 + 717329382*lm^2 - 
           (24928211910703836642572479751*Pi^2)/6616209600 - 
           (7042987896166192453873827465236147*Im[PolyLog[2, (-1)^(1/3)]])/
            (1074737626580632506008400*Sqrt[3]) + 391270572*Zeta[3])), 
      (-721891362808385750248080155313251638505461473143570691691373428782588\
241347838171*CF^2*NC)/
        39636065638843352226762871127577659887679103281287564800000000 - 
       (10599001410126970733*CF^2*lm*NC)/3797876160 - 
       (8691776632*CF^2*lm^2*NC)/5 - 
       (139864508159588363126342948084660870198272168699932710498987399*CF*
         NM*NC)/1129184489047063975089501640540533696000000 - 
       (18576488464317128237*CF*lm*NM*NC)/136723541760 - 
       (2172944158*CF*lm^2*NM*NC)/45 + (1477625742502910196220448241967*CF*
         NC*NL)/709434345628815206400 - (18576488464317128237*CF*lm*NC*NL)/
        136723541760 - (2172944158*CF*lm^2*NC*NL)/45 + 
       (323015447684794487125243958106875408899053056975788340853521187094294\
38119*CF*NC*NH)/
        317959263113808286027048370556025756652358989356321564224000000 - 
       (18576488464317128237*CF*lm*NC*NH)/136723541760 - 
       (2172944158*CF*lm^2*NC*NH)/45 + (15231708683233957380438913459751039*
         CF^2*NC*Pi^2)/2400318499138560 + (21403690*CF^2*lm*NC*Pi^2)/9 + 
       (2019436094845128663750712829*CF*NM*NC*Pi^2)/27567540 + 
       (10701845*CF*lm*NM*NC*Pi^2)/162 - (519486962165479*CF*NC*NL*Pi^2)/
        4296240 + (10701845*CF*lm*NC*NL*Pi^2)/162 + 
       (10701845*CF*lm*NC*NH*Pi^2)/162 - 
       (24746245964835992262644010666130763*CF^2*NC*Pi^3)/
        (15476221822761108086520960*Sqrt[3]) - 
       (19244867989766650630956752367655*CF*NC*NH*Pi^3)/
        (1313027869578148310508*Sqrt[3]) - (1105817180237*CF^2*NC*Pi^4)/
        32400 + (800837406038445188368593119021701342535681*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(39503830013688866446249076448000*
         Sqrt[3]) + (250324705400841481971680898493040561*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(4296883703194490346137430*Sqrt[3]) - 
       (158863920677*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (3535177994976570323234858666590109*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(59707645921146250333800*
         Sqrt[3]) - (2199413484544760072109343127732*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) - (3535177994976570323234858666590109*CF^2*NC*Pi*Log[3]^2)/
        (2865967004215020016022400*Sqrt[3]) - 
       (549853371136190018027335781933*CF*NC*NH*Pi*Log[3]^2)/
        (48630661836227715204*Sqrt[3]) + 
       CF*((10599145570457289447727749688586344173061*CF*NC)/
          139190584634141040000 - (250206757528*CF*lm*NC)/3 + 
         CA*(-137788892576170179386034537687120377287633/
            3618955200487667040000 + (344034291601*lm)/27)*NC + 
         (31734468900906905987431928341998647*NM*NC)/36100888223400 - 
         (62551689382*lm*NM*NC)/27 - (246521413465*NC*NL)/81 - 
         (62551689382*lm*NC*NL)/27 - (2347072645397165136730243*NC*NH)/
          4007198592797400 - (62551689382*lm*NC*NH)/27)*Log[x]^2 + 
       (CF*NC*(-423623818081157926945010583*CA + 847247625897954884688732536*
           CF + 1856400*(4727226712718237292018*NM + 31275844691*NL))*
         Log[x]^3)/37592100 + (48467247144088331379581801010803288258044019*
         CF^2*NC*PolyGamma[2, 1])/11580905809679268098680560 + 
       (191752981462243906982783*CF*NM*NC*PolyGamma[2, 1])/4725 - 
       (36766585813172519069037439876922*CF*NC*NH*PolyGamma[2, 1])/
        8206424184863426940675 - 
       (37095130329352592006637261887381464181399744441*CF^2*NC*Zeta[3])/
        12796900919695591249042018800 - (168003820130417775325034*CF*NM*NC*
         Zeta[3])/4725 - (73206446264*CF*NC*NL*Zeta[3])/27 + 
       (246058971464391252897215941282556*CF*NC*NH*Zeta[3])/
        8206424184863426940675 + CA*CF*NC*(3537267677198758091010298889421160\
3953730800682006282966449682234795578709577185129/
          3884334432606648518222761370502610668992552121566181350400000000 + 
         (11951192869*lm^2)/45 - (3226717234131792037209053601504308893*Pi^2)/
          1016977048319232000 + (24746245964835992262644010666130763*Pi^3)/
          (30952443645522216173041920*Sqrt[3]) + (369747256879*Pi^4)/21600 + 
         lm*(296770188631898511343/273447083520 - (117720295*Pi^2)/324) - 
         (800837406038445188368593119021701342535681*
           Im[PolyLog[2, (-1)^(1/3)]])/(79007660027377732892498152896000*
           Sqrt[3]) + (158863920677*Im[PolyLog[2, (-1)^(1/3)]]^2)/90 + 
         (3535177994976570323234858666590109*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(119415291842292500667600*
           Sqrt[3]) + (3535177994976570323234858666590109*Pi*Log[3]^2)/
          (5731934008430040032044800*Sqrt[3]) - 
         (48467247144088331379581801010803288258044019*PolyGamma[2, 1])/
          23161811619358536197361120 + 
         (37095130378256909777877800215862777448154978997*Zeta[3])/
          25593801839391182498084037600) + CF*Log[x]*
        ((256631815556548639831492548591864538165773029381*NM*NC)/
          488727798944407803115335000 - (848043297434927*lm*NM*NC)/716040 - 
         196913948*lm^2*NM*NC - (305164762580342310564361*NC*NL)/
          57902419935360 - (848043297434927*lm*NC*NL)/716040 - 
         196913948*lm^2*NC*NL - 
         (186279970337370766249736717809627280444307226129400367797*NC*NH)/
          1750301890995875479481884475769144087381480000 - 
         (848043297434927*lm*NC*NH)/716040 - 196913948*lm^2*NC*NH + 
         (1575742237587925925593*NM*NC*Pi^2)/27 - (36592521287*NC*NL*Pi^2)/
          81 + (2199413484544760072109343127732*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12157665459056928801*Sqrt[3]) + 
         CF*NC*(2603142481795663861164351857063810054810673371083067366612846\
96946719/8966387033124037834895364953153683049241888000000 - 
           (677670395916107*lm)/19890 - 7088902128*lm^2 + 
           (564831756995880076060264031*Pi^2)/100245600 + 
           (3535177994976570323234858666590109*Im[PolyLog[2, (-1)^(1/3)]])/
            (179122937763438751001400*Sqrt[3]) - 1181483688*Zeta[3]) + 
         CA*NC*(-260314248143232813543860433423896618360427382455195169089242\
961773069/17932774066248075669790729906307366098483776000000 + 
           (11302451958347077*lm)/1432080 + 1083026714*lm^2 - 
           (1694495270800231124981369261*Pi^2)/601473600 - 
           (3535177994976570323234858666590109*Im[PolyLog[2, (-1)^(1/3)]])/
            (358245875526877502002800*Sqrt[3]) + 590741844*Zeta[3])), 
      (-353643377878060451801201520346401049340773442484168767847601126037028\
9444476828228383*CF^2*NC)/
        18450588554881580461558116509887400677714622577439361414400000000 - 
       (10275488905173036700829*CF^2*lm*NC)/3598962396120 - 
       (9200250576*CF^2*lm^2*NC)/5 + 
       (4256365427620363265528722340003091912764231578910063816947427*CF*NM*
         NC)/40978469360578934579860946632519368000000 - 
       (18277399904166834490733*CF*lm*NM*NC)/129562646260320 - 
       (255562516*CF*lm^2*NM*NC)/5 + (1529330517880650613216887680370103*CF*
         NC*NL)/672277721776506009964800 - (18277399904166834490733*CF*lm*NC*
         NL)/129562646260320 - (255562516*CF*lm^2*NC*NL)/5 + 
       (426383632154619872498937111999809408531786814166332410319114861314888\
5631*CF*NC*NH)/
        39744907889226035753381046319503219581544873669540195528000000 - 
       (18277399904166834490733*CF*lm*NC*NH)/129562646260320 - 
       (255562516*CF*lm^2*NC*NH)/5 + 
       (1128186098841821995202219002633500233593*CF^2*NC*Pi^2)/
        9178217861081068800 + (58612400*CF^2*lm*NC*Pi^2)/27 - 
       (83688749985920411862121689857*CF*NM*NC*Pi^2)/1178512335 + 
       (14653100*CF*lm*NM*NC*Pi^2)/243 - (3896697413304509*CF*NC*NL*Pi^2)/
        30610710 + (14653100*CF*lm*NC*NL*Pi^2)/243 + 
       (14653100*CF*lm*NC*NH*Pi^2)/243 - 
       (30800064339480100902681447948965273*CF^2*NC*Pi^3)/
        (16964320074949676171763360*Sqrt[3]) - 
       (4951501269549407022672485059930*CF*NC*NH*Pi^3)/
        (328256967394537077627*Sqrt[3]) - (866847826889*CF^2*NC*Pi^4)/24300 + 
       (4049969453430866994197177031181811692619771*CF^2*NC*
         Im[PolyLog[2, (-1)^(1/3)]])/(174521290987048541100824154168000*
         Sqrt[3]) + (1444390837263175635392948146846158032*CF*NC*NH*
         Im[PolyLog[2, (-1)^(1/3)]])/(27929744070764187249893295*Sqrt[3]) - 
       (170031130412*CF^2*NC*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 - 
       (30800064339480100902681447948965273*CF^2*NC*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(458141360048795266984350*
         Sqrt[3]) - (2263543437508300353221707455968*CF*NC*NH*
         Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(4052555153018976267*
         Sqrt[3]) - (30800064339480100902681447948965273*CF^2*NC*Pi*Log[3]^2)/
        (21990785282342172815248800*Sqrt[3]) - 
       (141471464844268772076356715998*CF*NC*NH*Pi*Log[3]^2)/
        (12157665459056928801*Sqrt[3]) + 
       CF*((38033973853123539345629630350179105041453879*CF*NC)/
          25785055803474627660000 - (806818681280*CF*lm*NC)/9 + 
         CA*(-38033973855437688668521540527242088532698899/
            51570111606949255320000 + (1109375686760*lm)/81)*NC - 
         (478460539209535721308615910633899*NM*NC)/561476948175 - 
         (201704670320*lm*NM*NC)/81 - (1323827301584*NC*NL)/405 - 
         (201704670320*lm*NC*NL)/81 - (320966846774927331801247*NC*NH)/
          500899824099675 - (201704670320*lm*NC*NH)/81)*Log[x]^2 + 
       (2*CF*NC*(-17260612684828467797928977609*CA + 
          19*(1816906597038972288616968217*CF - 618800*
             (1678664235219872112732*NM - 12606541895*NL)))*Log[x]^3)/
        178562475 + (2886998468689142422256683672604919592539128183*CF^2*NC*
         PolyGamma[2, 1])/43428396786297255370052100 - 
       (14844419106123604368108817*CF*NM*NC*PolyGamma[2, 1])/396900 - 
       (83476901182014021063438306186142081*CF*NC*NH*PolyGamma[2, 1])/
        21714198393148627685026050 - 
       (11009577639988136814795006963789765415994379855259*CF^2*NC*Zeta[3])/
        182355838105662175298848767900 + (7090126905079121106059183*CF*NM*NC*
         Zeta[3])/198450 - (236301693088*CF*NC*NL*Zeta[3])/81 + 
       (370645945072481979974297660582217119*CF*NC*NH*Zeta[3])/
        10857099196574313842513025 + CA*CF*NC*(353643377872771270847050141729\
3447390449973903753911079955467536214585876393632492883/
          36901177109763160923116233019774801355429245154878722828800000000 + 
         (1405593838*lm^2)/5 - (5640930494202244937171130432937645012217*
           Pi^2)/91782178610810688000 + (30800064339480100902681447948965273*
           Pi^3)/(33928640149899352343526720*Sqrt[3]) + (869192322889*Pi^4)/
          48600 + lm*(293763195347970215860399/259125292520640 - 
           (80592050*Pi^2)/243) - 
         (4049969453430866994197177031181811692619771*
           Im[PolyLog[2, (-1)^(1/3)]])/(349042581974097082201648308336000*
           Sqrt[3]) + (85015565206*Im[PolyLog[2, (-1)^(1/3)]]^2)/45 + 
         (30800064339480100902681447948965273*
           Im[PolyLog[3, -((-1)^(5/6)/Sqrt[3])]])/(916282720097590533968700*
           Sqrt[3]) + (30800064339480100902681447948965273*Pi*Log[3]^2)/
          (43981570564684345630497600*Sqrt[3]) - 
         (2886998468689142422256683672604919592539128183*PolyGamma[2, 1])/
          86856793572594510740104200 + 
         (11009577640671535281365483011014559753128369340057*Zeta[3])/
          364711676211324350597697535800) + CF*Log[x]*
        ((-38711715540291083845298106674840000100866171527*NM*NC)/
          70944357911285003678032500 - (6383499172402451*lm*NM*NC)/5101785 - 
         213200064*lm^2*NM*NC - (81186020942786891063199893*NC*NL)/
          14439415971380400 - (6383499172402451*lm*NC*NL)/5101785 - 
         213200064*lm^2*NC*NL - 
         (203720411740512063712966019770325258892489052181996670613*NC*NH)/
          1859695759183117696949502255504715592842822500 - 
         (6383499172402451*lm*NC*NH)/5101785 - 213200064*lm^2*NC*NH - 
         (4476437960535493630856*NM*NC*Pi^2)/81 - (118121540344*NC*NL*Pi^2)/
          243 + (2263543437508300353221707455968*NC*NH*
           Im[PolyLog[2, (-1)^(1/3)]])/(12157665459056928801*Sqrt[3]) + 
         CF*NC*(1046035567464558800867544938799304236826986735813679356790834\
133931911/1140812635910870885243383487343214137961579500000 - 
           (20276775728457644*lm)/566865 - 7675202304*lm^2 + 
           (138084901471573437060643340563*Pi^2)/1428499800 + 
           (30800064339480100902681447948965273*Im[PolyLog[2, (-1)^(1/3)]])/
            (1374424080146385800953050*Sqrt[3]) - 1279200384*Zeta[3]) + 
         CA*NC*(-585779917777232037847277035133377687775351215654496829565547\
87659472791/127771015222017539147258950582439983451696904000000 + 
           (85446303335626321*lm)/10203570 + 1172600352*lm^2 - 
           (19726414495815061328877623893*Pi^2)/408142800 - 
           (30800064339480100902681447948965273*Im[PolyLog[2, (-1)^(1/3)]])/
            (2748848160292771601906100*Sqrt[3]) + 639600192*Zeta[3]))}, 0, 
     39, 1]
 
CbarSeries["a", 2, 4, "x1"] = SeriesData[x, 1, 
     {(CF*NC*(-(CA*(-28018615286684473814 + 16455916993904640*lm + 
            4944216195072000*lm^2 + 23318053271394422625*Zeta[3])) + 
         2*(1948903647739904*NL + 923934381834240*lm*NL + 
           449474199552000*lm^2*NL - 7540877721305880*NH + 
           923934381834240*lm*NH + 449474199552000*lm^2*NH + 
           63*CF*(4316784102648065878 + 217611270881280*lm + 
             256842399744000*lm^2 - 3591097962173265825*Zeta[3]) + 
           5911159464094500*NH*Zeta[3] + 1260*NM*(-5984823588338 + 
             733281255424*lm + 356725555200*lm^2 + 4691396400075*Zeta[3]))))/
       37378274434744320000, 
      -(CF*NC*(-17017271507173770*NM + 4594685926440960*lm*NM + 
          1797896798208000*lm^2*NM + 8719548972793856*NL + 
          4594685926440960*lm*NL + 1797896798208000*lm^2*NL - 
          41461881499604790*NH + 4594685926440960*lm*NH + 
          1797896798208000*lm^2*NH + 252*CF*(4316838505465786198 + 
            346032470753280*lm + 256842399744000*lm^2 - 3591097962173265825*
             Zeta[3]) + 14635352085267375*NM*Zeta[3] + 32653923627488625*NH*
           Zeta[3] - 2*CA*(-28014501307435997654 + 18928025091440640*lm + 
            4944216195072000*lm^2 + 23318053271394422625*Zeta[3])))/
       18689137217372160000, 
      (CF*NC*(154*CF*(3582500490112456007979338 + 55932363782435635200*lm + 
           32038520944066560000*lm^2 - 2980287487603690202775375*Zeta[3]) - 
         11*CA*(-1752002222459511258285818 + 289652345831581286400*lm + 
           68526836463697920000*lm^2 + 1457725306016139391452375*Zeta[3]) + 
         5*(16777216*(8894670632161 + 4826459220660*lm + 1633807098000*lm^2)*
            NL + 3465*NM*(-32355221474800862 + 23369278170333184*lm + 
             7910745912115200*lm^2 + 38266176891113325*Zeta[3]) + 
           3465*NH*(-247467789408193838 + 23369278170333184*lm + 
             7910745912115200*lm^2 + 196829606462660325*Zeta[3]))))/
       633187968924568780800000, 
      -(CF*NC*(154*CF*(3223509337999545718065338 + 21935211212596838400*lm + 
            10679506981355520000*lm^2 - 2681651781069361416768375*Zeta[3]) - 
          11*CA*(-1493168205294427949925098 + 103590057674067148800*lm + 
            22842278821232640000*lm^2 + 1242266493788454926397375*Zeta[3]) + 
          5*(8388608*(6610744372937 + 3553298303940*lm + 1089204732000*lm^2)*
             NL + 231*NM*(-17764524467965126 + 129035612895313920*lm + 
              39553729560576000*lm^2 + 119493364623719625*Zeta[3]) + 
            693*NH*(-550354631315036922 + 43011870965104640*lm + 
              13184576520192000*lm^2 + 442071751440540375*Zeta[3]))))/
       126637593784913756160000, 
      (CF*NC*(-22*CA*(-989040698864377430764220809498 + 
           26265643922615911317504000*lm + 5517719959313433231360000*lm^2 + 
           822814965153954523656645114375*Zeta[3]) + 
         7*(156*CF*(709215885242727030845681063362 + 
             1658353357752398512128000*lm + 727611423206167019520000*lm^2 - 
             590001145179281659414203487875*Zeta[3]) + 
           25*(134217728*(6284315927645653 + 3277078909043940*lm + 
               939662108985600*lm^2)*NL + 1287*NH*(341757642306601615360*
                lm + 97994804472211046400*lm^2 + 16731*(-322173936911743478 + 
                 260974339390004625*Zeta[3])) + 429*NM*
              (1025272926919804846080*lm + 293984413416633139200*lm^2 + 1859*
                (225088180345818254 + 423831294087460875*Zeta[3]))))))/
       44515646967272883565363200000, 
      -(CF*NC*(1456*CF*(3804969765721174697629817896258 + 
            3171060156437597100441600*lm + 1307257090573766492160000*lm^2 - 
            3165380828273403985028428519875*Zeta[3]) - 
          88*CA*(-1573745173580659525579488284894 + 
            16214289570907637258649600*lm + 3304455423394798632960000*lm^2 + 
            1309226666167291566455994358125*Zeta[3]) + 
          5*(536870912*(143167633042392583 + 71576947164783060*lm + 
              19696089168756000*lm^2)*NL + 3003*NM*
             (3825521358085659521818 + 12796397236940691210240*lm + 
              3521231220400717824000*lm^2 + 14609536049419499813625*Zeta[
                3]) + 9009*NH*(-84257254258080433635534 + 
              4265465745646897070080*lm + 1173743740133572608000*lm^2 + 
              68714424810626485015125*Zeta[3]))))/
       89031293934545767130726400000, 
      (CF*NC*(-22*CA*(-9678916067424015105037369410469954 + 
           38578419707254580198139494400*lm + 7753137729098565046763520000*
            lm^2 + 8052003225542249291585722796215875*Zeta[3]) + 
         5*(48282170952632615125381021696*NL + 22968631896176034292716011520*
            lm*NL + 6202510183278852037410816000*lm^2*NL - 
           577480639812644907264982482426*NH + 22968631896176034292716011520*
            lm*NH + 6202510183278852037410816000*lm^2*NH + 
           28*CF*(68337535406634259499990043474914254 + 
             19895055546060970389657354240*lm + 7974655949929952619528192000*
              lm^2 - 56850489478943623443429210195559125*Zeta[3]) + 
           473441344873801205778914412375*NH*Zeta[3] + 
           3003*NM*(-5681272339255776821232142 + 7648562069988689408163840*
              lm + 2065437956469814198272000*lm^2 + 
             17502173861295016739971125*Zeta[3]))))/
       48433023900392897319115161600000, 
      -(CF*NC*(42*CF*(46590383762807858693378332660225154 + 
            4671074531050066420118323200*lm + 1880656780137894688849920000*
             lm^2 - 38758881437959954954754218886899875*Zeta[3]) - 
          11*CA*(-3552873310405474611173335205526466 + 
            5446640489366404637864755200*lm + 1097049788413771901829120000*
             lm^2 + 2955667650034243507917344115199875*Zeta[3]) + 
          5*(429*NM*(-13665978329435421972578066 + 3776592358146865385963520*
               lm + 1022890245607246528512000*lm^2 + 
              18770443769078946880810875*Zeta[3]) + 
            8*(3758096384*(119762283878682437 + 53888922611950140*lm + 
                14595817620384000*lm^2)*NL + 429*NH*(
                -15396961091655047625611462 + 472074044768358173245440*lm + 
                127861280700905816064000*lm^2 + 12674282770374735596711625*
                 Zeta[3])))))/3459501707170921237079654400000, 
      (CF*NC*(612*CF*(18118927300854564984092018613145379981326 + 
           610559079106954822338371125248000*lm + 
           256006351973265580328264663040000*lm^2 - 
           15073268927663734649302867230354876451125*Zeta[3]) - 
         22*CA*(-9088287990341040072445919738443606657574 + 
           5294337004028717310236587720704000*lm + 
           1088026995886378716395124817920000*lm^2 + 
           7560619944861731381513205246737297105625*Zeta[3]) + 
         1225*(17179869184*(1757136602347931614967 + 743076694274092918740*
              lm + 206796755726540179200*lm^2)*NL + 36465*NH*
            (350088040622736272705716224*lm + 97428800522626166339665920*
              lm^2 + 26741*(-568145212218146333556518 + 
               469128124801282275099225*Zeta[3])) + 36465*NM*
            (350088040622736272705716224*lm + 97428800522626166339665920*
              lm^2 + 85*(-44649145348782168438221294 + 
               46514028786964913259650565*Zeta[3])))))/
       7446480558637607177019317865676800000, 
      -(CF*NC*(44064*CF*(123467193619324457843583435053242809482 + 
            1340778913697299495304927641600*lm + 
            614259920088122069052555264000*lm^2 - 
            102713268147591752692647698503559523375*Zeta[3]) - 
          176*CA*(-505948987845297876172196337693560847586 + 
            109578408876602721936040211251200*lm + 
            23495441943370669141260238848000*lm^2 + 
            420902821894362561460827975568812973875*Zeta[3]) + 
          35*(549755813888*(336483510289196332817 + 132505780502512847430*
               lm + 39074706218622274200*lm^2)*NL + 2431*NM*
             (-889883050524791651645278740518 + 29965373593181255478426992640*
               lm + 8836506342926031762594201600*lm^2 + 
              819509194295723934393175409625*Zeta[3]) + 
            21879*NH*(3329485954797917275380776960*lm + 
              981834038102892418066022400*lm^2 + 415701*(
                -479787421540850141422658 + 397102500547128997495875*
                 Zeta[3])))))/1489296111727521435403863573135360000, 
      (CF*NC*(456*CF*(795774029264983245172113485698351244418674074 + 
           2572307460815911445022178505077555200*lm + 
           1392102360141091024332179594280960000*lm^2 - 
           662010281343254894241478255948638530939442375*Zeta[3]) - 
         308*CA*(-17590272757696685165124028975122874419095182 + 
           1363068546870873449046050795107123200*lm + 
           314880295746199160265612051087360000*lm^2 + 
           14633479155423561446977745241120298347835125*Zeta[3]) + 
         35*(274877906944*(15529938559552624486402493 + 
             5601391934500170964635480*lm + 1832844548312709435504000*lm^2)*
            NL + 415701*NH*(3703861407426034908670323589120*lm + 
             1211949149013157669635096576000*lm^2 + 
             12597*(-25773756627606640139509153738 + 
               21370046921951939138664111375*Zeta[3])) + 
           46189*NM*(33334752666834314178032912302080*lm + 
             10907542341118419026715869184000*lm^2 + 
             3553*(-784730334319315674619865370178 + 
               682128454748037030477244375875*Zeta[3])))))/
       43010871706690819054463579992149196800000, 
      -(CF*NC*(152*CF*(5233075357615406560586558617770743569694333566 + 
            4212134258097859635781293018867302400*lm + 
            3182684515430630811535341288161280000*lm^2 - 
            4353433972229847478527397659942087894291484125*Zeta[3]) - 
          44*CA*(-247293927121760249012382348158482531174687666 + 
            6390632810727384720395232335206809600*lm + 
            1679750160921721817199207902085120000*lm^2 + 
            205725647789184231424244854213399418409376875*Zeta[3]) + 
          245*(46189*NM*(-790773511805227975437167597824438 + 
              3006471790609591541251713269760*lm + 
              1187490199970200037697257472000*lm^2 + 
              669514307171331372096793726904625*Zeta[3]) + 
            7*(274877906944*(226627227347062176144833 + 
                72170184875548679857080*lm + 28505634923111922576000*lm^2)*
               NL + 415701*NH*(47721774454120500654789099520*lm + 
                18849050793177778376146944000*lm^2 + 46189*
                 (-147280632897024216784543234 + 122280480256977128599387875*
                   Zeta[3]))))))/43010871706690819054463579992149196800000, 
      (CF*NC*(8*CF*(632138847221027550046842356097496628122785803691398 + 
           63979546337252413693984872331761785241600*lm + 
           130137116394668797456055970139346042880000*lm^2 - 
           525880967669637566520726479663829553604620430939625*Zeta[3]) - 
         4*CA*(-15908785192055546124856614246232594317855522527866 + 
           118206494758729976329778549463954594201600*lm + 
           39764118898371021444905990875911290880000*lm^2 + 
           13234635772791637025264365644693655022846103972375*Zeta[3]) + 
         1155*(2199023255552*(77176620566257564092685823 + 
             19356056277286296873385080*lm + 11386148904757878595344000*lm^2)*
            NL + 12597*NM*(-3636703849005766853474822399990557034 + 
             3378932911766757020121427114721280*lm + 
             1987648347443082430027350933504000*lm^2 + 
             3044478702976519490654063439234261375*Zeta[3]) + 
           4199*NH*(10136798735300271060364281344163840*lm + 
             5962945042329247290082052800512000*lm^2 + 
             4199*(-715768413853096681242292133151218 + 
               594869130610564706949944965948875*Zeta[3])))))/
       130581006501513326649351428856164961484800000, 
      -(CF*NC*(8*CF*(635695177862087998890813105346279222692514194906754 - 
            39200359445093766770157211882811817984000*lm + 
            41948294069504633967660642945529282560000*lm^2 - 
            528839505302777582779997434629903229675350817363875*Zeta[3]) - 
          4*CA*(-14769948195950949248598621203461186728584375050622 + 
            19823191807894422247102103231781666816000*lm + 
            12817534299015304823451863122245058560000*lm^2 + 
            12287228778443746222712110236373189144370447788125*Zeta[3]) + 
          5775*(549755813888*(12703848325070904788161343 + 
              804041441668807510208040*lm + 2936161708869819052022400*lm^2)*
             NL + 37791*NM*(-233306161919024317346358195987877994 + 
              11696606524418939687143179550720*lm + 
              42713131961750371294325715763200*lm^2 + 
              194448438428832941692003443721317375*Zeta[3]) + 
            4199*NH*(105269458719770457184288615956480*lm + 
              384418187655753341648931441868800*lm^2 + 
              4199*(-68646925086048341714039127572342 + 
                57094540450191545816913850076625*Zeta[3])))))/
       65290503250756663324675714428082480742400000, 
      (CF*NC*
        (368*CF*(453885148240180494030932054932290420286567526807849714 - 
           33006452615156525705844028203648977731584000*lm + 
           8536910549224485157101297187964917383168000*lm^2 - 
           377590401179228703826161755521539700518597731020972875*Zeta[3]) - 
         8*CA*(-224672785226595937479231056482673643032034488498275394 - 
           83109517193476337030270714254473509732352000*lm + 
           59995510248716520687406338570975669387264000*lm^2 + 
           186906945898123112831131266531382605807317128405111875*Zeta[3]) + 
         40425*(61572651155456*(-48715350023061223002142937 - 
             93188310033362829595441560*lm + 35059697661291049890823680*lm^2)*
            NL + 7429*NH*(-772358501204836423152382070583459840*lm + 
             290579961463781179699143357518315520*lm^2 + 
             7429*(-49472035594084806728845611632697502 + 
               41169038982717605303025452768122125*Zeta[3])) + 
           66861*NM*(-85817611244981824794709118953717760*lm + 
             32286662384864575522127039724257280*lm^2 + 
             69*(-8811085468802411954765873588557106606 + 
               7332261466370014625288015051325577125*Zeta[3])))))/
       1105237639028808796760110493838580234007347200000, 
      -(CF*NC*(184*CF*
           (77516416082770218685485959583962841125612105172416578 - 
            4026460828394097579400011518639593645670400*lm + 
            297536435297618335322254282123816992768000*lm^2 - 
            64486478040208861505980666432537361185872518927671875*Zeta[3]) - 
          20*CA*(-7130126965144428360229417303128126858001837109112938 - 
            4621824942650541731594238236338960560291840*lm + 
            418203989612763549091835185429587217612800*lm^2 + 
            5931605174769339031381712387852291859987606606232575*Zeta[3]) + 
          735*(4398046511104*(-10221454393560642468080169223 - 
              5797912931452467529202739240*lm + 470444419063833225288076800*
               lm^2)*NL + 74290*NM*
             (-2584648902159997240906056803393243964674 - 
              343242572888131510620836647585972224*lm + 
              27850806783309191309015234830663680*lm^2 + 
              2149925453689454119812044198953304914275*Zeta[3]) + 
            111435*NH*(-228828381925421007080557765057314816*lm + 
              18567204522206127539343489887109120*lm^2 + 
              7429*(-7506301368139106390487866711026834 + 
                6248950701181274134830566491782075*Zeta[3])))))/
       50238074501309490761823204265390010636697600000}, 0, 16, 1]

CbarTable["a", 2, -1] = {{0., 0.000038580246913580246*CF*NC*
       (-3.*CA*(5160.430157209292 + 198.04533104651125*lm + 7140.*lm^2 + 
          1320.*lm^3) + 2.*(CF*(-135.93938964079425 + 116.1865557539944*lm + 
            5670.*lm^2 - 3240.*lm^3) - 
          15.*((-288.8434648794611 - 83.04316479128514*lm - 84.*lm^2 - 
              24.*lm^3)*NM + (-288.8434648794611 - 83.04316479128514*lm - 
              84.*lm^2 - 24.*lm^3)*NL - 1.*(-114.9438057198067 + 
              83.04316479128514*lm + 84.*lm^2 + 24.*lm^3)*NH)))}, 
     {0.005, CF*NC*(CF*(-0.03677470535618152 - 0.004806524065402655*lm + 
          0.4381379293859821*lm^2 - 0.25250625*lm^3) + 
        CA*(-0.6281659519423299 - 0.04255425769679392*lm - 
          0.8369638869030109*lm^2 - 0.154309375*lm^3) + 
        0.3412698042883041*NM + 0.10007604008820126*lm*NM + 
        0.09861332034600198*lm^2*NM + 0.02805625*lm^3*NM + 
        0.34129322848438026*NL + 0.10007604008820126*lm*NL + 
        0.09861332034600198*lm^2*NL + 0.02805625*lm^3*NL - 
        0.13636653792220954*NH + 0.10007604008820126*lm*NH + 
        0.09861332034600198*lm^2*NH + 0.02805625*lm^3*NH)}, 
     {0.01, CF*NC*(CF*(-0.062268351212858515 - 0.01851513398317798*lm + 
          0.4388076359767084*lm^2 - 0.255025*lm^3) + 
        CA*(-0.6586066295608243 - 0.062120685795076014*lm - 
          0.8475741530142338*lm^2 - 0.15584861111111112*lm^3) + 
        0.34811731769024096*NM + 0.10403131900315318*lm*NM + 
        0.10000817933592128*lm^2*NM + 0.02833611111111111*lm^3*NM + 
        0.3482164250986726*NL + 0.10403131900315318*lm*NL + 
        0.10000817933592128*lm^2*NL + 0.02833611111111111*lm^3*NL - 
        0.13970746863646918*NH + 0.10403131900315318*lm*NH + 
        0.10000817933592128*lm^2*NH + 0.02833611111111111*lm^3*NH)}, 
     {0.015, CF*NC*(CF*(-0.08673027984685326 - 0.03208284462252465*lm + 
          0.4395162880703962*lm^2 - 0.25755625*lm^3) + 
        CA*(-0.6884066583685199 - 0.08155263983838029*lm - 
          0.858215306595869*lm^2 - 0.15739548611111112*lm^3) + 
        0.35481851706403156*NM + 0.10796915945812019*lm*NM + 
        0.10140600271440042*lm^2*NM + 0.02861736111111111*lm^3*NM + 
        0.3550513556933227*NL + 0.10796915945812019*lm*NL + 
        0.10140600271440042*lm^2*NL + 0.02861736111111111*lm^3*NL - 
        0.1430566040348293*NH + 0.10796915945812019*lm*NH + 
        0.10140600271440042*lm^2*NH + 0.02861736111111111*lm^3*NH)}, 
     {0.02, CF*NC*(CF*(-0.11007273757006425 - 0.04546044914999557*lm + 
          0.4402698653838051*lm^2 - 0.2601*lm^3) + 
        CA*(-0.7174667617788887 - 0.10080260814349593*lm - 
          0.8688836933765636*lm^2 - 0.15895*lm^3) + 0.3613551357887721*NM + 
        0.1118817685817572*lm*NM + 0.1028061260684661*lm^2*NM + 
        0.0289*lm^3*NM + 0.3617839431656498*NL + 0.1118817685817572*lm*
         NL + 0.1028061260684661*lm^2*NL + 0.0289*lm^3*NL - 
        0.14641142116738123*NH + 0.1118817685817572*lm*NH + 
        0.1028061260684661*lm^2*NH + 0.0289*lm^3*NH)}, 
     {0.025, CF*NC*(CF*(-0.13226665246688937 - 0.05861333899159588*lm + 
          0.4410736246691975*lm^2 - 0.26265625*lm^3) + 
        CA*(-0.7457268047447873 - 0.11983410883221617*lm - 
          0.8795761008966015*lm^2 - 0.16051215277777778*lm^3) + 
        0.36771577970576436*NM + 0.1157632566844072*lm*NM + 
        0.10420796531453361*lm^2*NM + 0.029184027777777777*lm^3*NM + 
        0.36840603714319986*NL + 0.1157632566844072*lm*NL + 
        0.10420796531453361*lm^2*NL + 0.029184027777777777*lm^3*NL - 
        0.1497696891296892*NH + 0.1157632566844072*lm*NH + 
        0.10420796531453361*lm^2*NH + 0.029184027777777777*lm^3*NH)}, 
     {0.03, CF*NC*(CF*(-0.15331295440280632 - 0.07151616830693336*lm + 
          0.44193230135374656*lm^2 - 0.265225*lm^3) + 
        CA*(-0.7731493172106829 - 0.13861784111726852*lm - 
          0.8902896352838215*lm^2 - 0.16208194444444443*lm^3) + 
        0.3738930677921966*NM + 0.11960896600657038*lm*NM + 
        0.10561099429402816*lm^2*NM + 0.029469444444444444*lm^3*NM + 
        0.37491284215062026*NL + 0.11960896600657038*lm*NL + 
        0.10561099429402816*lm^2*NL + 0.029469444444444444*lm^3*NL - 
        0.1531293890429781*NH + 0.11960896600657038*lm*NH + 
        0.10561099429402816*lm^2*NH + 0.029469444444444444*lm^3*NH)}, 
     {0.035, CF*NC*(CF*(-0.17322963296540478 - 0.08415007039316094*lm + 
          0.4428502250647379*lm^2 - 0.26780625*lm^3) + 
        CA*(-0.7997115067114711 - 0.15712964726732986*lm - 
          0.9010216506548824*lm^2 - 0.163659375*lm^3) + 
        0.37988223820013306*NM + 0.12341511650398596*lm*NM + 
        0.10701473193725135*lm^2*NM + 0.02975625*lm^3*NM + 
        0.3813016894330108*NL + 0.12341511650398596*lm*NL + 
        0.10701473193725135*lm^2*NL + 0.02975625*lm^3*NL - 
        0.15648866829082236*NH + 0.12341511650398596*lm*NH + 
        0.10701473193725135*lm^2*NH + 0.02975625*lm^3*NH)}, 
     {0.04, CF*NC*(CF*(-0.19204486621358377 - 0.09650097853669394*lm + 
          0.44383139487333956*lm^2 - 0.2704*lm^3) + 
        CA*(-0.8254007206514495 - 0.17534926699985884*lm - 
          0.9117697031329591*lm^2 - 0.16524444444444444*lm^3) + 
        0.38568035191827826*NM + 0.12717859001413478*lm*NM + 
        0.10841873390296228*lm^2*NM + 0.030044444444444443*lm^3*NM + 
        0.3875713486649027*NL + 0.12717859001413478*lm*NL + 
        0.10841873390296228*lm^2*NL + 0.030044444444444443*lm^3*NL - 
        0.15984581074205056*NH + 0.12717859001413478*lm*NH + 
        0.10841873390296228*lm^2*NH + 0.030044444444444443*lm^3*NH)}, 
     {0.045, CF*NC*(CF*(-0.2097930084503381 - 0.10855852037006504*lm + 
          0.44487953227359545*lm^2 - 0.27300625*lm^3) + 
        CA*(-0.8502116112891035 - 0.193259507288219*lm - 0.9225315184716917*
           lm^2 - 0.16683715277777778*lm^3) + 0.3912857925477928*NM + 
        0.13089678680405892*lm*NM + 0.10982258669182272*lm^2*NM + 
        0.03033402777777778*lm^3*NM + 0.393721603495856*NL + 
        0.13089678680405892*lm*NL + 0.10982258669182272*lm^2*NL + 
        0.03033402777777778*lm^3*NL - 0.16319921578942512*NH + 
        0.13089678680405892*lm*NH + 0.10982258669182272*lm^2*NH + 
        0.03033402777777778*lm^3*NH)}, 
     {0.05, CF*NC*(CF*(-0.22651209715741707 - 0.12031524525299357*lm + 
          0.44599812051894466*lm^2 - 0.275625*lm^3) + 
        CA*(-0.8741442470016932 - 0.21084565547415293*lm - 
          0.9333049680162004*lm^2 - 0.1684375*lm^3) + 0.396697931301326*NM + 
        0.13456752442627867*lm*NM + 0.11122590327567282*lm^2*NM + 
        0.030625*lm^3*NM + 0.399752972363189*NL + 0.13456752442627867*lm*
         NL + 0.11122590327567282*lm^2*NL + 0.030625*lm^3*NL - 
        0.166547382778335*NH + 0.13456752442627867*lm*NH + 
        0.11122590327567282*lm^2*NH + 0.030625*lm^3*NH)}, 
     {0.055, CF*NC*(CF*(-0.2422422362434798 - 0.1317660605169433*lm + 
          0.4471904349823092*lm^2 - 0.27825625*lm^3) + 
        CA*(-0.897202794094907 - 0.22809504620031035*lm - 
          0.9440880501496999*lm^2 - 0.17004548611111112*lm^3) + 
        0.4019168920260736*NM + 0.13818896327259814*lm*NM + 
        0.11262831972418787*lm^2*NM + 0.03091736111111111*lm^3*NM + 
        0.40566651610902194*NL + 0.13818896327259814*lm*NL + 
        0.11262831972418787*lm^2*NL + 0.03091736111111111*lm^3*NL - 
        0.1698888989748979*NH + 0.13818896327259814*lm*NH + 
        0.11262831972418787*lm^2*NH + 0.03091736111111111*lm^3*NH)}, 
     {0.06, CF*NC*(CF*(-0.2570245158647242 - 0.14290780634963204*lm + 
          0.4484595672910421*lm^2 - 0.2809*lm^3) + 
        CA*(-0.9193945638496851 - 0.24499673122385035*lm - 
          0.9548788755443631*lm^2 - 0.1716611111111111*lm^3) + 
        0.4069433805192855*NM + 0.14175954995323756*lm*NM + 
        0.11402949252321755*lm^2*NM + 0.03121111111111111*lm^3*NM + 
        0.41146370067928467*NL + 0.14175954995323756*lm*NL + 
        0.11402949252321755*lm^2*NL + 0.03121111111111111*lm^3*NL - 
        0.1732224299842636*NH + 0.14175954995323756*lm*NH + 
        0.11402949252321755*lm^2*NH + 0.03121111111111111*lm^3*NH)}, 
     {0.065, CF*NC*(CF*(-0.2709002759743214 - 0.15373892681698442*lm + 
          0.4498084449660058*lm^2 - 0.28355625*lm^3) + 
        CA*(-0.9407293043964735 - 0.26154122109365546*lm - 
          0.9656756551596631*lm^2 - 0.173284375*lm^3) + 
        0.41177855711562944*NM + 0.14527797310629753*lm*NM + 
        0.11542909639266602*lm^2*NM + 0.03150625*lm^3*NM + 
        0.4171462964252604*NL + 0.14527797310629753*lm*NL + 
        0.11542909639266602*lm^2*NL + 0.03150625*lm^3*NL - 
        0.17654671193577678*NH + 0.14527797310629753*lm*NH + 
        0.11542909639266602*lm^2*NH + 0.03150625*lm^3*NH)}, 
     {0.07, CF*NC*(CF*(-0.28391059794007634 - 0.16425920990809637*lm + 
          0.45123984770699826*lm^2 - 0.286225*lm^3) + 
        CA*(-0.9612186628148996 - 0.27772027878976296*lm - 
          0.9764766902901677*lm^2 - 0.17491527777777777*lm^3) + 
        0.4164239394814298*NM + 0.14874312818064517*lm*NM + 
        0.1168268224770002*lm^2*NM + 0.03180277777777778*lm^3*NM + 
        0.42271630263373505*NL + 0.14874312818064517*lm*NL + 
        0.1168268224770002*lm^2*NL + 0.03180277777777778*lm^3*NL - 
        0.17986054498446713*NH + 0.14874312818064517*lm*NH + 
        0.1168268224770002*lm^2*NH + 0.03180277777777778*lm^3*NH)}, 
     {0.075, CF*NC*(CF*(-0.2960959517557914 - 0.17446957856060577*lm + 
          0.452756421109619*lm^2 - 0.28890625*lm^3) + 
        CA*(-0.9808757691622804 - 0.2935267520091193*lm - 
          0.9872803641830106*lm^2 - 0.17655381944444445*lm^3) + 
        0.42088132713031845*NM + 0.15215408888217372*lm*NM + 
        0.11822237682115344*lm^2*NM + 0.032100694444444446*lm^3*NM + 
        0.42817588997018474*NL + 0.15215408888217372*lm*NL + 
        0.11822237682115344*lm^2*NL + 0.032100694444444446*lm^3*NL - 
        0.18316278781975673*NH + 0.15215408888217372*lm*NH + 
        0.11822237682115344*lm^2*NH + 0.032100694444444446*lm^3*NH)}, 
     {0.08, CF*NC*(CF*(-0.30749595178652617 - 0.18437192023770785*lm + 
          0.4543606883711391*lm^2 - 0.2916*lm^3) + 
        CA*(-0.9997149100176365 - 0.3089544348760812*lm - 
          0.998085134884304*lm^2 - 0.1782*lm^3) + 0.42515274194683383*NM + 
        0.15551008368563277*lm*NM + 0.11961547906987344*lm^2*NM + 
        0.0324*lm^3*NM + 0.4335273559569673*NL + 0.15551008368563277*lm*
         NL + 0.11961547906987344*lm^2*NL + 0.0324*lm^3*NL - 
        0.18645235296224494*NH + 0.15551008368563277*lm*NH + 
        0.11961547906987344*lm^2*NH + 0.0324*lm^3*NH)}, 
     {0.085, CF*NC*(CF*(-0.31814918957729976 - 0.19396894624373168*lm + 
          0.45605506039233157*lm^2 - 0.29430625*lm^3) + 
        CA*(-1.0177512691230735 - 0.323997952504928*lm - 1.0088895290657973*
           lm^2 - 0.17985381944444445*lm^3) + 0.42924038075337506*NM + 
        0.15881047627453604*lm*NM + 0.12100586134529649*lm^2*NM + 
        0.03270069444444444*lm^3*NM + 0.43877309013445004*NL + 
        0.15881047627453604*lm*NL + 0.12100586134529649*lm^2*NL + 
        0.03270069444444444*lm^3*NL - 0.18972820268889273*NH + 
        0.15881047627453604*lm*NH + 0.12100586134529649*lm^2*NH + 
        0.03270069444444444*lm^3*NH)}, 
     {0.09, CF*NC*(CF*(-0.3280931221544586 - 0.20326407437347452*lm + 
          0.45784184457928934*lm^2 - 0.297025*lm^3) + 
        CA*(-1.0350007192164443 - 0.33865266361359864*lm - 
          1.01969213664599*lm^2 - 0.1815152777777778*lm^3) + 
        0.43314657709833576*NM + 0.16205474907926934*lm*NM + 
        0.12239326726896785*lm^2*NM + 0.03300277777777778*lm^3*NM + 
        0.4439155465421023*NL + 0.16205474907926934*lm*NL + 
        0.12239326726896785*lm^2*NL + 0.03300277777777778*lm^3*NL - 
        0.19298934546750607*NH + 0.16205474907926934*lm*NH + 
        0.12239326726896785*lm^2*NH + 0.03300277777777778*lm^3*NH)}, 
     {0.095, CF*NC*(CF*(-0.3373640007229738 - 0.21226133014117476*lm + 
          0.45972325257695273*lm^2 - 0.29975625*lm^3) + 
        CA*(-1.0514796535193414 - 0.352914577607496*lm - 1.0304916060640845*
           lm^2 - 0.183184375*lm^3) + 0.43687377021195845*NM + 
        0.16524248929504906*lm*NM + 0.1237774511025608*lm^2*NM + 
        0.03330625*lm^3*NM + 0.44895722181696657*NL + 
        0.16524248929504906*lm*NL + 0.1237774511025608*lm^2*NL + 
        0.03330625*lm^3*NL - 0.196234832809877*NH + 0.16524248929504906*lm*
         NH + 0.1237774511025608*lm^2*NH + 0.03330625*lm^3*NH)}, 
     {0.1, CF*NC*(CF*(-0.34599682900481793 - 0.22096526299475502*lm + 
          0.461701407114072*lm^2 - 0.3025*lm^3) + 
        CA*(-1.0672048483530403 - 0.3667802834126067*lm - 
          1.041286640096956*lm^2 - 0.18486111111111111*lm^3) + 
        0.4404244796071003*NM + 0.16837337691046364*lm*NM + 
        0.12515817698732534*lm^2*NM + 0.03361111111111111*lm^3*NM + 
        0.45390063765924193*NL + 0.16837337691046364*lm*NL + 
        0.12515817698732534*lm^2*NL + 0.03361111111111111*lm^3*NL - 
        0.19946375647337672*NH + 0.16837337691046364*lm*NH + 
        0.12515817698732534*lm^2*NH + 0.03361111111111111*lm^3*NH)}, 
     {0.105, CF*NC*(CF*(-0.3540253434397525 - 0.2293808747535757*lm + 
          0.46377834810115015*lm^2 - 0.30525625*lm^3) + 
        CA*(-1.082193350472874 - 0.38024688795735045*lm - 
          1.0520759921326304*lm^2 - 0.1865454861111111*lm^3) + 
        0.4438012841766782*NM + 0.1714471743846909*lm*NM + 
        0.12653521826653888*lm^2*NM + 0.03391736111111111*lm^3*NM + 
        0.4587483267315014*NL + 0.1714471743846909*lm*NL + 
        0.12653521826653888*lm^2*NL + 0.03391736111111111*lm^3*NL - 
        0.20267524595577618*NH + 0.1714471743846909*lm*NH + 
        0.12653521826653888*lm^2*NH + 0.03391736111111111*lm^3*NH)}, 
     {0.11, CF*NC*(CF*(-0.3614820095491331 - 0.2375135581171595*lm + 
          0.4659560380943686*lm^2 - 0.308025*lm^3) + 
        CA*(-1.0964623842318766 - 0.3933119626581289*lm - 
          1.0628584628312192*lm^2 - 0.1882375*lm^3) + 0.4470068049092006*
         NM + 0.1744637176902739*lm*NM + 0.1279083568784035*lm^2*NM + 
        0.034225*lm^3*NM + 0.46350282128431436*NL + 0.1744637176902739*lm*
         NL + 0.1279083568784035*lm^2*NL + 0.034225*lm^3*NL - 
        0.20586846623925295*NH + 0.1744637176902739*lm*NH + 
        0.1279083568784035*lm^2*NH + 0.034225*lm^3*NH)}, 
     {0.115, CF*NC*(CF*(-0.3683980302404805 - 0.24536904354569952*lm + 
          0.4682363672168089*lm^2 - 0.31080625*lm^3) + 
        CA*(-1.1100292747950877 - 0.40597349660384985*lm - 
          1.0736328971175058*lm^2 - 0.18993715277777778*lm^3) + 
        0.450043690541301*NM + 0.17742290849714687*lm*NM + 
        0.12927738280924345*lm^2*NM + 0.034534027777777775*lm^3*NM + 
        0.4681666439654602*NL + 0.17742290849714687*lm*NL + 
        0.12927738280924345*lm^2*NL + 0.034534027777777775*lm^3*NL - 
        0.20904261574802868*NH + 0.17742290849714687*lm*NH + 
        0.12927738280924345*lm^2*NH + 0.034534027777777775*lm^3*NH)}, 
     {0.12, CF*NC*(CF*(-0.374803362895536 - 0.25295335315565565*lm + 
          0.47062115761156753*lm^2 - 0.3136*lm^3) + 
        CA*(-1.122911384449818 - 0.41822985539276286*lm - 
          1.0843981814595975*lm^2 - 0.19164444444444445*lm^3) + 
        0.4529146056131196*NM + 0.18032470731815667*lm*NM + 
        0.13064209359871473*lm^2*NM + 0.03484444444444444*lm^3*NM + 
        0.4727423003912641*NL + 0.18032470731815667*lm*NL + 
        0.13064209359871473*lm^2*NL + 0.03484444444444444*lm^3*NL - 
        0.2121969244906117*NH + 0.18032470731815667*lm*NH + 
        0.13064209359871473*lm^2*NH + 0.03484444444444444*lm^3*NH)}, 
     {0.125, CF*NC*(CF*(-0.38072674286240615 - 0.2602727605360149*lm + 
          0.47311216748830254*lm^2 - 0.31640625*lm^3) + 
        CA*(-1.1351260596769903 - 0.43007974477330196*lm - 
          1.0951532413960374*lm^2 - 0.193359375*lm^3) + 
        0.45562222050322027*NM + 0.18316912747054598*lm*NM + 
        0.1320022938901886*lm^2*NM + 0.03515625*lm^3*NM + 
        0.47723227314939165*NL + 0.18316912747054598*lm*NL + 
        0.1320022938901886*lm^2*NL + 0.03515625*lm^3*NL - 
        0.21533065236271362*NH + 0.18316912747054598*lm*NH + 
        0.1320022938901886*lm^2*NH + 0.03515625*lm^3*NH)}, 
     {0.13, CF*NC*(CF*(-0.3861957115472113 - 0.2673337555941121*lm + 
          0.4757110948144357*lm^2 - 0.319225*lm^3) + 
        CA*(-1.1466905871208741 - 0.4415221783949693*lm - 
          1.105897039280067*lm^2 - 0.19508194444444443*lm^3) + 
        0.45816920310440407*NM + 0.18595622973446574*lm*NM + 
        0.13335779502061826*lm^2*NM + 0.03546944444444444*lm^3*NM + 
        0.48163901697125316*NL + 0.18595622973446574*lm*NL + 
        0.13335779502061826*lm^2*NL + 0.03546944444444444*lm^3*NL - 
        0.2184430875909268*NH + 0.18595622973446574*lm*NH + 
        0.13335779502061826*lm^2*NH + 0.03546944444444444*lm^3*NH)}, 
     {0.135, CF*NC*(CF*(-0.39123664772978684 - 0.2741430136992909*lm + 
          0.4784195806939951*lm^2 - 0.32205625*lm^3) + 
        CA*(-1.157622156958389 - 0.4525564490967263*lm - 1.1166285722147808*
           lm^2 - 0.19681215277777778*lm^3) + 0.46055821186720036*NM + 
        0.18868611761049878*lm*NM + 0.13470841464511166*lm^2*NM + 
        0.035784027777777776*lm^3*NM + 0.4859649548649058*NL + 
        0.18868611761049878*lm*NL + 0.13470841464511166*lm^2*NL + 
        0.035784027777777776*lm^3*NL - 0.22153354530045624*NH + 
        0.18868611761049878*lm*NH + 0.13470841464511166*lm^2*NH + 
        0.035784027777777776*lm^3*NH)}, 
     {0.14, CF*NC*(CF*(-0.39587480105130135 - 0.2807073685189032*lm + 
          0.48123921247043805*lm^2 - 0.3249*lm^3) + 
        CA*(-1.167937832452474 - 0.463182103256871*lm - 1.1273468701569545*
           lm^2 - 0.19855*lm^3) + 0.4627918899888956*NM + 
        0.1913589330947841*lm*NM + 0.13605397639217356*lm^2*NM + 
        0.0361*lm^3*NM + 0.4902124750401823*NL + 0.1913589330947841*lm*
         NL + 0.13605397639217356*lm^2*NL + 0.0361*lm^3*NL - 
        0.2246013661927813*NH + 0.1913589330947841*lm*NH + 
        0.13605397639217356*lm^2*NH + 0.0361*lm^3*NH)}, 
     {0.145, CF*NC*(CF*(-0.4001343268672139 - 0.2870337880420358*lm + 
          0.4841715265843875*lm^2 - 0.32775625*lm^3) + 
        CA*(-1.1776545246967285 - 0.4733989178058058*lm - 
          1.138050994170652*lm^2 - 0.20029548611111112*lm^3) + 
        0.46487286056621213*NM + 0.1939748529036447*lm*NM + 
        0.13739430954617918*lm^2*NM + 0.03641736111111111*lm^3*NM + 
        0.49438392848969986*NL + 0.1939748529036447*lm*NL + 
        0.13739430954617918*lm^2*NL + 0.03641736111111111*lm^3*NL - 
        0.2276459153212208*NH + 0.1939748529036447*lm*NH + 
        0.13739430954617918*lm^2*NH + 0.03641736111111111*lm^3*NH)}, 
     {0.15, CF*NC*(CF*(-0.4040383218468389 - 0.2931293533676863*lm + 
          0.4872180112127798*lm^2 - 0.330625*lm^3) + 
        CA*(-1.1867889717351354 - 0.48320687956574293*lm - 
          1.1487400348144123*lm^2 - 0.2020486111111111*lm^3) + 
        0.4668037225617549*NM + 0.19653408509038278*lm*NM + 
        0.1387292487541356*lm^2*NM + 0.03673611111111111*lm^3*NM + 
        0.4984816271145752*NL + 0.19653408509038278*lm*NL + 
        0.1387292487541356*lm^2*NL + 0.03673611111111111*lm^3*NL - 
        0.2306665809540972*NH + 0.19653408509038278*lm*NH + 
        0.1387292487541356*lm^2*NH + 0.03673611111111111*lm^3*NH)}, 
     {0.155, CF*NC*(CF*(-0.40760885984536743 - 0.2990012399002059*lm + 
          0.4903801087122538*lm^2 - 0.33350625*lm^3) + 
        CA*(-1.1953577213818525 - 0.49260616663247814*lm - 
          1.1594131106480672*lm^2 - 0.203809375*lm^3) + 
        0.4685870474599893*NM + 0.19903686600567788*lm*NM + 
        0.14005863375419403*lm^2*NM + 0.03705625*lm^3*NM + 
        0.5025078423036765*NL + 0.19903686600567788*lm*NL + 
        0.14005863375419403*lm^2*NL + 0.03705625*lm^3*NL - 
        0.23366277351661408*NH + 0.19903686600567788*lm*NH + 
        0.14005863375419403*lm^2*NH + 0.03705625*lm^3*NH)}, 
     {0.16, CF*NC*(CF*(-0.41086702768609 - 0.3046567006489202*lm + 
          0.49365921788655825*lm^2 - 0.3364*lm^3) + 
        CA*(-1.2033771171797363 - 0.5015971315563321*lm - 
          1.1700693668471034*lm^2 - 0.20557777777777778*lm^3) + 
        0.47022537650921753*NM + 0.20148345756021938*lm*NM + 
        0.14138230912371574*lm^2*NM + 0.03737777777777778*lm^3*NM + 
        0.5064648038912597*NL + 0.20148345756021938*lm*NL + 
        0.14138230912371574*lm^2*NL + 0.03737777777777778*lm^3*NL - 
        0.23663392460374474*NH + 0.20148345756021938*lm*NH + 
        0.14138230912371574*lm^2*NH + 0.03737777777777778*lm^3*NH)}, 
     {0.165, CF*NC*(CF*(-0.41383296057755425 - 0.3101030513734249*lm + 
          0.49705669609519654*lm^2 - 0.33930625*lm^3) + 
        CA*(-1.2108632870284677 - 0.5101802861140617*lm - 
          1.1807079739140465*lm^2 - 0.20735381944444445*lm^3) + 
        0.47172121846285053*NM + 0.20387414475415552*lm*NM + 
        0.14270012404497817*lm^2*NM + 0.037700694444444446*lm^3*NM + 
        0.5103546994307449*NL + 0.20387414475415552*lm*NL + 
        0.14270012404497817*lm^2*NL + 0.037700694444444446*lm^3*NL - 
        0.23957948605741908*NH + 0.20387414475415552*lm*NH + 
        0.14270012404497817*lm^2*NH + 0.037700694444444446*lm^3*NH)}, 
     {0.17, CF*NC*(CF*(-0.41652587695827953 - 0.315347657353022*lm + 
          0.5005738612183697*lm^2 - 0.342225*lm^3) + 
        CA*(-1.2178321340883576 - 0.518356287492432*lm - 1.191328126477663*
           lm^2 - 0.2091375*lm^3) + 0.4730770477470361*NM + 
        0.20620923344288614*lm*NM + 0.14401193208684782*lm^2*NM + 
        0.038025*lm^3*NM + 0.514179673732859*NL + 0.20620923344288614*lm*
         NL + 0.14401193208684782*lm^2*NL + 0.038025*lm^3*NL - 
        0.2424989291021294*NH + 0.20620923344288614*lm*NH + 
        0.14401193208684782*lm^2*NH + 0.038025*lm^3*NH)}, 
     {0.175, CF*NC*(CF*(-0.4189641126147892 - 0.32039792158960395*lm + 
          0.5042119934914497*lm^2 - 0.34515625*lm^3) + 
        CA*(-1.2242993296276834 - 0.5261259257283197*lm - 
          1.2019290421718918*lm^2 - 0.21092881944444444*lm^3) + 
        0.4742953029930277*NM + 0.2084890483128657*lm*NM + 
        0.14531759100095004*lm^2*NM + 0.038350694444444444*lm^3*NM + 
        0.5179418286249083*NL + 0.2084890483128657*lm*NL + 
        0.14531759100095004*lm^2*NL + 0.038350694444444444*lm^3*NL - 
        0.2453917435337834*NH + 0.2084890483128657*lm*NH + 
        0.14531759100095004*lm^2*NH + 0.038350694444444444*lm^3*NH)}, 
     {0.18, CF*NC*(CF*(-0.4211651539604082 - 0.3252612742791607*lm + 
          0.5079723372206563*lm^2 - 0.3481*lm^3) + 
        CA*(-1.2302803075323618 - 0.5334901122705782*lm - 
          1.2125099605873768*lm^2 - 0.21272777777777777*lm^3) + 
        0.4753783858820472*NM + 0.21071393104456315*lm*NM + 
        0.1466169625310382*lm^2*NM + 0.038677777777777776*lm^3*NM + 
        0.5216432228949508*NL + 0.21071393104456315*lm*NL + 
        0.1466169625310382*lm^2*NL + 0.038677777777777776*lm^3*NL - 
        0.24825743695723512*NH + 0.21071393104456315*lm*NH + 
        0.1466169625310382*lm^2*NH + 0.038677777777777776*lm^3*NH)}, 
     {0.185, CF*NC*(CF*(-0.42314567039501955 - 0.32994516340889246*lm + 
          0.5118561023902731*lm^2 - 0.35105625*lm^3) + 
        CA*(-1.2357902602390693 - 0.5404498695461134*lm - 
          1.2230701422892776*lm^2 - 0.214534375*lm^3) + 
        0.47632866025818144*NM + 0.21288423864266828*lm*NM + 
        0.1479099122344141*lm^2*NM + 0.03900625*lm^3*NM + 
        0.5252858723904077*NL + 0.21288423864266828*lm*NL + 
        0.1479099122344141*lm^2*NL + 0.03900625*lm^3*NL - 
        0.25109553406843915*NH + 0.21288423864266828*lm*NH + 
        0.1479099122344141*lm^2*NH + 0.03900625*lm^3*NH)}, 
     {0.19, CF*NC*(CF*(-0.42492154569170926 - 0.33445704635538576*lm + 
          0.5158644661705905*lm^2 - 0.354025*lm^3) + 
        CA*(-1.2408441358881643 - 0.5470063214272702*lm - 
          1.2336088678957502*lm^2 - 0.21634861111111112*lm^3) + 
        0.47714845147135676*NM + 0.21500034191613335*lm*NM + 
        0.14919630931437883*lm^2*NM + 0.03933611111111111*lm^3*NM + 
        0.5288717502454342*NL + 0.21500034191613335*lm*NL + 
        0.14919630931437883*lm^2*NL + 0.03933611111111111*lm^3*NL - 
        0.25390557597762003*NH + 0.21500034191613335*lm*NH + 
        0.14919630931437883*lm^2*NH + 0.03933611111111111*lm^3*NH)}, 
     {0.195, CF*NC*(CF*(-0.42650790837644015 - 0.3388043823750318*lm + 
          0.5199985743347668*lm^2 - 0.35700625*lm^3) + 
        CA*(-1.2454566365222905 - 0.5531606845101316*lm - 
          1.244125437212087*lm^2 - 0.21817048611111112*lm^3) + 
        0.47784004591789686*NM + 0.21706262409277352*lm*NM + 
        0.15047602646280367*lm^2*NM + 0.03966736111111111*lm^3*NM + 
        0.5324027872153434*NL + 0.21706262409277352*lm*NL + 
        0.15047602646280367*lm^2*NL + 0.03966736111111111*lm^3*NL - 
        0.25668711957023016*NH + 0.21706262409277352*lm*NH + 
        0.15047602646280367*lm^2*NH + 0.03966736111111111*lm^3*NH)}, 
     {0.2, NC*(CF^2*(-0.4279191610827451 - 0.3429946258912999*lm + 
          0.5242595425919377*lm^2 - 0.36*lm^3) + 
        CA*CF*(-1.2496422171813673 - 0.5589142601240608*lm - 
          1.254619168416038*lm^2 - 0.22*lm^3) + 
        CF*((0.47840569075075845 + 0.21907147955497713*lm + 
            0.15174893971200692*lm^2 + 0.04*lm^3)*NM + 
          (0.5358808720996934 + 0.21907147955497713*lm + 0.15174893971200692*
             lm^2 + 0.04*lm^3)*NL + (-0.25943973690280514 + 
            0.21907147955497713*lm + 0.15174893971200692*lm^2 + 0.04*lm^3)*
           NH))}, {0.205, NC*(CF^2*(-0.4291690088758012 - 
          0.34703522049500807*lm + 0.5286484578431492*lm^2 - 
          0.36300625*lm^3) + CA*CF*(-1.2534150857656305 - 
          0.5642684270020626*lm - 1.2650893972902977*lm^2 - 
          0.22183715277777777*lm^3) + 
        CF*((0.47884759373545055 + 0.22102731268465048*lm + 
            0.15301492829520563*lm^2 + 0.04033402777777778*lm^3)*NM + 
          (0.5393078522384311 + 0.22102731268465048*lm + 0.15301492829520563*
             lm^2 + 0.04033402777777778*lm^3)*NL + 
          (-0.26216301463111463 + 0.22102731268465048*lm + 
            0.15301492829520563*lm^2 + 0.04033402777777778*lm^3)*NH))}, 
     {0.21, NC*(CF^2*(-0.4302704865499146 - 0.3509335935836581*lm + 
          0.5331663793660333*lm^2 - 0.366025*lm^3) + 
        CA*CF*(-1.256789203556133 - 0.5692246345495167*lm - 
          1.2755354764985352*lm^2 - 0.22368194444444445*lm^3) + 
        CF*((0.4791679232308978 + 0.22293053680688132*lm + 0.1542738745148852*
             lm^2 + 0.040669444444444446*lm^3)*NM + 
          (0.5426855340678197 + 0.22293053680688132*lm + 0.1542738745148852*
             lm^2 + 0.040669444444444446*lm^3)*NL + 
          (-0.26485655346826226 + 0.22293053680688132*lm + 0.1542738745148852*
             lm^2 + 0.040669444444444446*lm^3)*NH))}, 
     {0.215, NC*(CF^2*(-0.43123598491083387 - 0.35469715157448595*lm + 
          0.5378143399335665*lm^2 - 0.36905625*lm^3) + 
        CA*CF*(-1.2597782862972307 - 0.5737843966557746*lm - 
          1.2859567749017093*lm^2 - 0.225534375*lm^3) + 
        CF*((0.47936880827736444 + 0.22478157322298278*lm + 
            0.1555256636184926*lm^2 + 0.04100625*lm^3)*NM + 
          (0.546015683724853 + 0.22478157322298278*lm + 0.1555256636184926*
             lm^2 + 0.04100625*lm^3)*NL + (-0.2675199676706118 + 
            0.22478157322298278*lm + 0.1555256636184926*lm^2 + 
            0.04100625*lm^3)*NH))}, 
     {0.22, NC*(CF^2*(-0.4320772760600418 - 0.35833327563331846*lm + 
          0.5425933468717417*lm^2 - 0.3721*lm^3) + 
        CA*CF*(-1.262395805758443 - 0.5779492859991405*lm - 
          1.2963526769117135*lm^2 - 0.22739444444444445*lm^3) + 
        CF*((0.4794523387759479 + 0.2265808503246051*lm + 0.1567701836809176*
             lm^2 + 0.04134444444444445*lm^3)*NM + 
          (0.5493000276905259 + 0.2265808503246051*lm + 0.1567701836809176*
             lm^2 + 0.04134444444444445*lm^3)*NL + 
          (-0.27015288454961295 + 0.2265808503246051*lm + 0.1567701836809176*
             lm^2 + 0.04134444444444445*lm^3)*NH))}, 
     {0.225, NC*(CF^2*(-0.4328055377024462 - 0.3618493178678023*lm + 
          0.5475043830605343*lm^2 - 0.37515625*lm^3) + 
        CA*CF*(-1.2646549917041012 - 0.5817209288010253*lm - 
          1.3067225818796735*lm^2 - 0.22926215277777778*lm^3) + 
        CF*((0.47942056574617237 + 0.22832880278149625*lm + 
            0.15800732549327395*lm^2 + 0.04168402777777778*lm^3)*NM + 
          (0.5525402534637462 + 0.22832880278149625*lm + 0.15800732549327395*
             lm^2 + 0.04168402777777778*lm^3)*NL + 
          (-0.27275494400777517 + 0.22832880278149625*lm + 
            0.15800732549327395*lm^2 + 0.04168402777777778*lm^3)*NH))}, 
     {0.23, NC*(CF^2*(-0.43343137650205465 - 0.3652525979392205*lm + 
          0.5525484078821459*lm^2 - 0.378225*lm^3) + 
        CA*CF*(-1.2665688342086558 - 0.5851009999896811*lm - 
          1.3170659035164665*lm^2 - 0.2311375*lm^3) + 
        CF*((0.4792755016500098 + 0.23002587079627607*lm + 
            0.15923698245753934*lm^2 + 0.042025*lm^3)*NM + 
          (0.5557380102588784 + 0.23002587079627607*lm + 0.15923698245753934*
             lm^2 + 0.042025*lm^3)*NL + (-0.2753257980971929 + 
            0.23002587079627607*lm + 0.15923698245753934*lm^2 + 
            0.042025*lm^3)*NH))}, 
     {0.235, NC*(CF^2*(-0.4339648505125338 - 0.36855040005205747*lm + 
          0.5577263581201514*lm^2 - 0.38130625*lm^3) + 
        CA*CF*(-1.2681500862636337 - 0.5880912187379771*lm - 
          1.3273820693432408*lm^2 - 0.23302048611111112*lm^3) + 
        CF*((0.479019120772212 + 0.23167249942027476*lm + 0.16045905048664985*
             lm^2 + 0.04236736111111111*lm^3)*NM + 
          (0.5588949097209349 + 0.23167249942027476*lm + 0.16045905048664985*
             lm^2 + 0.04236736111111111*lm^3)*NL + 
          (-0.27786511059916263 + 0.23167249942027476*lm + 
            0.16045905048664985*lm^2 + 0.04236736111111111*lm^3)*NH))}, 
     {0.24, NC*(CF^2*(-0.43441549071104907 - 0.3717499702848106*lm + 
          0.563039148812862*lm^2 - 0.3844*lm^3) + 
        CA*CF*(-1.2694112666292754 - 0.5906933443432536*lm - 
          1.3376705201699177*lm^2 - 0.2349111111111111*lm^3) + 
        CF*((0.47865335964803446 + 0.2332691379250932*lm + 0.161673427909682*
             lm^2 + 0.04271111111111111*lm^3)*NM + 
          (0.5620125266533107 + 0.2332691379250932*lm + 0.161673427909682*
             lm^2 + 0.04271111111111111*lm^3)*NL + 
          (-0.28037255662355504 + 0.2332691379250932*lm + 0.161673427909682*
             lm^2 + 0.04271111111111111*lm^3)*NH))}, 
     {0.245, NC*(CF^2*(-0.43479232166486365 - 0.3748585142293662*lm + 
          0.5684876740639334*lm^2 - 0.38750625*lm^3) + 
        CA*CF*(-1.2703646628899194 - 0.5929091724204456*lm - 
          1.3479307095998185*lm^2 - 0.236809375*lm^3) + 
        CF*((0.4781801175307273 + 0.2348162392250749*lm + 0.16288001538178518*
             lm^2 + 0.04305625*lm^3)*NM + (0.5650923997537024 + 
            0.2348162392250749*lm + 0.16288001538178518*lm^2 + 
            0.04305625*lm^3)*NL + (-0.28284782222671645 + 0.2348162392250749*
             lm + 0.16288001538178518*lm^2 + 0.04305625*lm^3)*NH))}, 
     {0.25, NC*(CF^2*(-0.4351038813606563 - 0.3778831949096222*lm + 
          0.5740728078129939*lm^2 - 0.390625*lm^3) + 
        CA*CF*(-1.271022334677469 - 0.594740531382464*lm - 
          1.358162103558726*lm^2 - 0.2387152777777778*lm^3) + 
        CF*((0.47760125689202576 + 0.2363142593463531*lm + 
            0.16407871579855624*lm^2 + 0.043402777777777776*lm^3)*NM + 
          (0.568136032354506 + 0.2363142593463531*lm + 0.16407871579855624*
             lm^2 + 0.043402777777777776*lm^3)*NL + 
          (-0.285290604046771 + 0.2363142593463531*lm + 0.16407871579855624*
             lm^2 + 0.043402777777777776*lm^3)*NH))}, 
     {0.255, NC*(CF^2*(-0.43535824022674396 - 0.3808311309530178*lm + 
          0.5797954045688409*lm^2 - 0.39375625*lm^3) + 
        CA*CF*(-1.2713961170318315 - 0.5961892791843063*lm - 
          1.3683641798468194*lm^2 - 0.24062881944444445*lm^3) + 
        CF*((0.47691860394979574 + 0.2377636569385553*lm + 
            0.16526943421457324*lm^2 + 0.043750694444444446*lm^3)*NM + 
          (0.5711448931645319 + 0.2377636569385553*lm + 0.16526943421457324*
             lm^2 + 0.043750694444444446*lm^3)*NL + 
          (-0.28770060895528515 + 0.2377636569385553*lm + 0.16526943421457324*
             lm^2 + 0.043750694444444446*lm^3)*NH))}, 
     {0.26, NC*(CF^2*(-0.43556301937830216 - 0.38370939499126816*lm + 
          0.5856563001075518*lm^2 - 0.3969*lm^3) + 
        CA*CF*(-1.2714976238711817 - 0.5972573003095738*lm - 
          1.3785364277120518*lm^2 - 0.24255*lm^3) + 
        CF*((0.47613394921771784 + 0.23916489282561992*lm + 
            0.1664520777658276*lm^2 + 0.0441*lm^3)*NM + 
          (0.5741204170093579 + 0.23916489282561992*lm + 0.1664520777658276*
             lm^2 + 0.0441*lm^3)*NL + (-0.2900775537243357 + 
            0.23916489282561992*lm + 0.1664520777658276*lm^2 + 0.0441*lm^3)*
           NH))}, {0.265, NC*(CF^2*(-0.4357254081153823 - 
          0.3865250122689414*lm + 0.5916563121376641*lm^2 - 
          0.40005625*lm^3) + CA*CF*(-1.2713382515483442 - 
          0.5979465029800446*lm - 1.3886783474436497*lm^2 - 
          0.24447881944444444*lm^3) + 
        CF*((0.4752490480725435 + 0.24051842959251196*lm + 0.1676265555958151*
             lm^2 + 0.044450694444444445*lm^3)*NM + 
          (0.5770640055680505 + 0.24051842959251196*lm + 0.1676265555958151*
             lm^2 + 0.044450694444444445*lm^3)*NL + 
          (-0.2924211647080941 + 0.24051842959251196*lm + 0.1676265555958151*
             lm^2 + 0.044450694444444445*lm^3)*NH))}, 
     {0.27, NC*(CF^2*(-0.43585218070306386 - 0.3892849594406014*lm + 
          0.597796240934423*lm^2 - 0.403225*lm^3) + 
        CA*CF*(-1.2709291824726034 - 0.5982588165707104*lm - 
          1.3987894499845193*lm^2 - 0.24641527777777777*lm^3) + 
        CF*((0.4742656213350268 + 0.2418247312049211*lm + 0.1687927787850641*
             lm^2 + 0.044802777777777775*lm^3)*NM + 
          (0.5799770281043348 + 0.2418247312049211*lm + 0.1687927787850641*
             lm^2 + 0.044802777777777775*lm^3)*NL + 
          (-0.2947311775381066 + 0.2418247312049211*lm + 0.1687927787850641*
             lm^2 + 0.044802777777777775*lm^3)*NH))}, 
     {0.275, NC*(CF^2*(-0.4359497124625057 - 0.3919961635390946*lm + 
          0.6040768699449307*lm^2 - 0.40640625*lm^3) + 
        CA*CF*(-1.270281388778855 - 0.598196189214262*lm - 
          1.4088692565614314*lm^2 - 0.248359375*lm^3) + 
        CF*((0.47318535586113447 + 0.24308426265929045*lm + 
            0.1699506602838966*lm^2 + 0.04515625*lm^3)*NM + 
          (0.5828608221906044 + 0.24308426265929045*lm + 0.1699506602838966*
             lm^2 + 0.04515625*lm^3)*NL + (-0.297007336831509 + 
            0.24308426265929045*lm + 0.1699506602838966*lm^2 + 
            0.04515625*lm^3)*NH))}, 
     {0.28, NC*(CF^2*(-0.43602399520098845 - 0.39466550109921944*lm + 
          0.6104989663659074*lm^2 - 0.4096*lm^3) + 
        CA*CF*(-1.2694056360283148 - 0.5977605855804203*lm - 
          1.4189172983319456*lm^2 - 0.2503111111111111*lm^3) + 
        CF*((0.4720099051405668 + 0.244297489660762*lm + 0.1711001148482325*
             lm^2 + 0.04551111111111111*lm^3)*NM + 
          (0.5857166944234232 + 0.244297489660762*lm + 0.1711001148482325*
             lm^2 + 0.04551111111111111*lm^3)*NL + 
          (-0.29924939591146776 + 0.244297489660762*lm + 0.1711001148482325*
             lm^2 + 0.04551111111111111*lm^3)*NH))}, 
     {0.285, NC*(CF^2*(-0.43608065200830026 - 0.39729979742249955*lm + 
          0.6170632816956386*lm^2 - 0.41280625*lm^3) + 
        CA*CF*(-1.2683124869269904 - 0.5969539848167836*lm - 
          1.4289331160471097*lm^2 - 0.25227048611111114*lm^3) + 
        CF*((0.4707408899000098 + 0.24546487832683847*lm + 0.1722410589782624*
             lm^2 + 0.04586736111111111*lm^3)*NM + 
          (0.5885459211293983 + 0.24546487832683847*lm + 0.1722410589782624*
             lm^2 + 0.04586736111111111*lm^3)*NL + 
          (-0.30145711653919083 + 0.24546487832683847*lm + 0.1722410589782624*
             lm^2 + 0.04586736111111111*lm^3)*NH))}, 
     {0.29, NC*(CF^2*(-0.4361249514459979 - 0.3999058259701123*lm + 
          0.6237705522615766*lm^2 - 0.416025*lm^3) + 
        CA*CF*(-1.267012305049899 - 0.5957783786390021*lm - 
          1.4389162597290366*lm^2 - 0.2542375*lm^3) + 
        CF*((0.46937989870886926 + 0.24658689491475252*lm + 
            0.17337341085982483*lm^2 + 0.046225*lm^3)*NM + 
          (0.5913497490605045 + 0.24658689491475252*lm + 0.17337341085982483*
             lm^2 + 0.046225*lm^3)*NL + (-0.30363026865689413 + 
            0.24658689491475252*lm + 0.17337341085982483*lm^2 + 
            0.046225*lm^3)*NH))}, 
     {0.295, NC*(CF^2*(-0.43616182115515395 - 0.40249030787221757*lm + 
          0.6306214997249565*lm^2 - 0.41925625*lm^3) + 
        CA*CF*(-1.2655152585605987 - 0.594235769559127*lm - 
          1.4488662883625265*lm^2 - 0.25621215277777776*lm^3) + 
        CF*((0.46792848858553543 + 0.24766400557070836*lm + 
            0.17449709030833818*lm^2 + 0.04658402777777778*lm^3)*NM + 
          (0.594129396078108 + 0.24766400557070836*lm + 0.17449709030833818*
             lm^2 + 0.04658402777777778*lm^3)*NL + 
          (-0.3057686301411526 + 0.24766400557070836*lm + 0.17449709030833818*
             lm^2 + 0.04658402777777778*lm^3)*NH))}, 
     {0.3, NC*(CF^2*(-0.43619590433004235 - 0.40505991154300486*lm + 
          0.6376168315636933*lm^2 - 0.4225*lm^3) + 
        CA*CF*(-1.263831302205613 - 0.5923281692419106*lm - 
          1.4587827695999651*lm^2 - 0.25819444444444445*lm^3) + 
        CF*((0.4663881856024831 + 0.24869667609931556*lm + 
            0.17561201871514517*lm^2 + 0.04694444444444444*lm^3)*NM + 
          (0.5968860518250854 + 0.24869667609931556*lm + 0.17561201871514517*
             lm^2 + 0.04694444444444444*lm^3)*NL + 
          (-0.3078719865661016 + 0.24869667609931556*lm + 0.17561201871514517*
             lm^2 + 0.04694444444444444*lm^3)*NH))}, 
     {0.305, NC*(CF^2*(-0.43623139000940325 - 0.40762125239174285*lm + 
          0.6447572415347418*lm^2 - 0.42575625*lm^3) + 
        CA*CF*(-1.2619702721119885 - 0.590057596979677*lm - 
          1.468665279478769*lm^2 - 0.260184375*lm^3) + 
        CF*((0.4647604854887425 + 0.24968537175167718*lm + 0.1767181189961398*
             lm^2 + 0.04730625*lm^3)*NM + (0.5996208783855639 + 
            0.24968537175167718*lm + 0.1767181189961398*lm^2 + 
            0.04730625*lm^3)*NL + (-0.3099401309759901 + 0.24968537175167718*
             lm + 0.1767181189961398*lm^2 + 0.04730625*lm^3)*NH))}, 
     {0.31, NC*(CF^2*(-0.4362723121813003 - 0.4101808926209862*lm + 
          0.6520434101170167*lm^2 - 0.429025*lm^3) + 
        CA*CF*(-1.259941745894669 - 0.5874260782771524*lm - 
          1.478513402150712*lm^2 - 0.2621819444444444*lm^3) + 
        CF*((0.46304685422847625 + 0.25063055703072123*lm + 
            0.1778153155425537*lm^2 + 0.047669444444444445*lm^3)*NM + 
          (0.6023350109319155 + 0.25063055703072123*lm + 0.1778153155425537*
             lm^2 + 0.047669444444444445*lm^3)*NL + 
          (-0.31197286366661725 + 0.25063055703072123*lm + 0.1778153155425537*
             lm^2 + 0.047669444444444445*lm^3)*NH))}, 
     {0.315, NC*(CF^2*(-0.4363223597014351 - 0.41274534110388117*lm + 
          0.6594760049359035*lm^2 - 0.43230625*lm^3) + 
        CA*CF*(-1.2577551470789248 - 0.5844356435383299*lm - 
          1.4883267296225033*lm^2 - 0.26418715277777777*lm^3) + 
        CF*((0.4612487286545733 + 0.25153269551248086*lm + 0.1789035341737885*
             lm^2 + 0.04803402777777778*lm^3)*NM + 
          (0.6050295583587377 + 0.25153269551248086*lm + 0.1789035341737885*
             lm^2 + 0.04803402777777778*lm^3)*NL + 
          (-0.3139699919752154 + 0.25153269551248086*lm + 0.1789035341737885*
             lm^2 + 0.04803402777777778*lm^3)*NH))}, 
     {0.32, NC*(CF^2*(-0.43638494062682354 - 0.4153210533332218*lm + 
          0.6670556811703173*lm^2 - 0.4356*lm^3) + 
        CA*CF*(-1.2554197220424634 - 0.5810883268480814*lm - 
          1.4981048615070283*lm^2 - 0.2662*lm^3) + 
        CF*((0.45936751703632994 + 0.2523922496821328*lm + 
            0.17998270209218695*lm^2 + 0.0484*lm^3)*NM + 
          (0.6077056039036294 + 0.2523922496821328*lm + 0.17998270209218695*
             lm^2 + 0.0484*lm^3)*NL + (-0.315931330078368 + 
            0.2523922496821328*lm + 0.17998270209218695*lm^2 + 0.0484*lm^3)*
           NH))}, {0.325, NC*(CF^2*(-0.4364631928008355 - 
          0.41791443143555285*lm + 0.6747830819432095*lm^2 - 
          0.43890625*lm^3) + CA*CF*(-1.2529445435650872 - 
          0.5773861648417983*lm - 1.5078474047847052*lm^2 - 
          0.2682204861111111*lm^3) + 
        CF*((0.45740459966042263 + 0.253209680783701*lm + 0.1810527478396434*
             lm^2 + 0.04876736111111111*lm^3)*NM + 
          (0.6103642057546502 + 0.253209680783701*lm + 0.1810527478396434*
             lm^2 + 0.04876736111111111*lm^3)*NL + 
          (-0.31785669879757666 + 0.253209680783701*lm + 0.1810527478396434*
             lm^2 + 0.04876736111111111*lm^3)*NH))}, 
     {0.33, NC*(CF^2*(-0.4365599940093514 - 0.42053182424419744*lm + 
          0.6826588386963627*lm^2 - 0.442225*lm^3) + 
        CA*CF*(-1.250338514332125 - 0.573331195656867*lm - 
          1.517553973574445*lm^2 - 0.2702486111111111*lm^3) + 
        CF*((0.455361329404501 + 0.25398544868241685*lm + 0.18211360125595968*
             lm^2 + 0.04913611111111111*lm^3)*NM + 
          (0.6130063976444038 + 0.25398544868241685*lm + 0.18211360125595968*
             lm^2 + 0.04913611111111111*lm^3)*NL + 
          (-0.3197459254121149 + 0.25398544868241685*lm + 0.18211360125595968*
             lm^2 + 0.04913611111111111*lm^3)*NH))}, 
     {0.335, NC*(CF^2*(-0.43667797172639167 - 0.42317952742561626*lm + 
          0.6906835715502633*lm^2 - 0.44555625*lm^3) + 
        CA*CF*(-1.247610370388727 - 0.5689254579602621*lm - 
          1.527224188913728*lm^2 - 0.272284375*lm^3) + 
        CF*((0.453239032302835 + 0.2547200117388092*lm + 0.18316519343885962*
             lm^2 + 0.04950625*lm^3)*NM + (0.6156331894307435 + 
            0.2547200117388092*lm + 0.18316519343885962*lm^2 + 
            0.04950625*lm^3)*NL + (-0.3215988434788265 + 0.2547200117388092*
             lm + 0.18316519343885962*lm^2 + 0.04950625*lm^3)*NH))}, 
     {0.34, NC*(CF^2*(-0.43681951246680084 - 0.42586378365398686*lm + 
          0.6988578896497895*lm^2 - 0.4489*lm^3) + 
        CA*CF*(-1.2447686845425967 - 0.564170990046975*lm - 
          1.536857678547351*lm^2 - 0.2743277777777778*lm^3) + 
        CF*((0.4510390081035465 + 0.2554138266936673*lm + 0.18420745670557895*
             lm^2 + 0.04987777777777778*lm^3)*NM + 
          (0.6182455676641427 + 0.2554138266936673*lm + 0.18420745670557895*
             lm^2 + 0.04987777777777778*lm^3)*NL + 
          (-0.32341529265854824 + 0.2554138266936673*lm + 0.18420745670557895*
             lm^2 + 0.04987777777777778*lm^3)*NH))}, 
     {0.345, NC*(CF^2*(-0.4369867707628216 - 0.42859078282932644*lm + 
          0.7071823914964114*lm^2 - 0.45225625*lm^3) + 
        CA*CF*(-1.2418218697131902 - 0.559069829004395*lm - 
          1.5464540767244153*lm^2 - 0.2763788194444444*lm^3) + 
        CF*((0.4487625308170369 + 0.25606734856308805*lm + 0.1852403245559543*
             lm^2 + 0.050250694444444445*lm^3)*NM + 
          (0.6208444961418089 + 0.25606734856308805*lm + 0.1852403245559543*
             lm^2 + 0.050250694444444445*lm^3)*NL + 
          (-0.3251951185488521 + 0.25606734856308805*lm + 0.1852403245559543*
             lm^2 + 0.050250694444444445*lm^3)*NH))}, 
     {0.35, NC*(CF^2*(-0.4371816777806667 - 0.43136666233487975*lm + 
          0.7156576652675554*lm^2 - 0.455625*lm^3) + 
        CA*CF*(-1.2387781822257768 - 0.5536240099381223*lm - 
          1.5560130240031607*lm^2 - 0.2784375*lm^3) + 
        CF*((0.4464108492552976 + 0.2566810305428772*lm + 0.1862637316369383*
             lm^2 + 0.050625*lm^3)*NM + (0.6234309164486542 + 
            0.2566810305428772*lm + 0.1862637316369383*lm^2 + 0.050625*lm^3)*
           NL + (-0.32693817252282315 + 0.2566810305428772*lm + 
            0.1862637316369383*lm^2 + 0.050625*lm^3)*NH))}, 
     {0.355, NC*(CF^2*(-0.43740594959250234 - 0.4341975073298561*lm + 
          0.7242842891237468*lm^2 - 0.45900625*lm^3) + 
        CA*CF*(-1.2356457250491173 - 0.5478355652550309*lm - 
          1.5655341670632659*lm^2 - 0.28050381944444447*lm^3) + 
        CF*((0.4439851875618553 + 0.25725532392163164*lm + 
            0.18727761370847257*lm^2 + 0.051000694444444446*lm^3)*NM + 
          (0.6260057484852644 + 0.25725532392163164*lm + 0.18727761370847257*
             lm^2 + 0.051000694444444446*lm^3)*NL + 
          (-0.32864431157360136 + 0.25725532392163164*lm + 
            0.18727761370847257*lm^2 + 0.051000694444444446*lm^3)*NH))}, 
     {0.36, NC*(CF^2*(-0.4376610951185818 - 0.4370893510739278*lm + 
          0.733062831504109*lm^2 - 0.4624*lm^3) + 
        CA*CF*(-1.2324324509757976 - 0.5417065239996989*lm - 
          1.5750171585252668*lm^2 - 0.28257777777777776*lm^3) + 
        CF*((0.44148674573215774 + 0.2577906780018779*lm + 
            0.18828190761065455*lm^2 + 0.05137777777777778*lm^3)*NM + 
          (0.6285698909830268 + 0.2577906780018779*lm + 0.18828190761065455*
             lm^2 + 0.05137777777777778*lm^3)*NL + 
          (-0.3303133981644334 + 0.2577906780018779*lm + 0.18828190761065455*
             lm^2 + 0.05137777777777778*lm^3)*NH))}, 
     {0.365, NC*(CF^2*(-0.4379484237536217 - 0.44004817528020534*lm + 
          0.7419938514107648*lm^2 - 0.46580625*lm^3) + 
        CA*CF*(-1.2291461657445353 - 0.5352389112406141*lm - 
          1.5844616567767549*lm^2 - 0.284659375*lm^3) + 
        CF*((0.4389167001242613 + 0.25828754002869175*lm + 
            0.18927655123213724*lm^2 + 0.05175625*lm^3)*NM + 
          (0.6311242220066033 + 0.25828754002869175*lm + 0.18927655123213724*
             lm^2 + 0.05175625*lm^3)*NL + (-0.33194530008399226 + 
            0.25828754002869175*lm + 0.18927655123213724*lm^2 + 
            0.05175625*lm^3)*NH))}, 
     {0.37, NC*(CF^2*(-0.4382690526908943 - 0.44307991049367834*lm + 
          0.751077898682652*lm^2 - 0.469225*lm^3) + 
        CA*CF*(-1.2257945311039982 - 0.5284347475028125*lm - 
          1.593867325805046*lm^2 - 0.2867486111111111*lm^3) + 
        CF*((0.4362762039597209 + 0.2587463551252629*lm + 0.19026148347970534*
             lm^2 + 0.05213611111111111*lm^3)*NM + 
          (0.6336695994439445 + 0.2587463551252629*lm + 0.19026148347970534*
             lm^2 + 0.05213611111111111*lm^3)*NL + 
          (-0.33353989030673764 + 0.2587463551252629*lm + 0.19026148347970534*
             lm^2 + 0.05213611111111111*lm^3)*NH))}, 
     {0.375, NC*(CF^2*(-0.43862391395691114 - 0.4461904364923633*lm + 
          0.7603155142592396*lm^2 - 0.47265625*lm^3) + 
        CA*CF*(-1.2223850678178845 - 0.5212960482438526*lm - 
          1.6032338350360202*lm^2 - 0.2888454861111111*lm^3) + 
        CF*((0.433566387814624 + 0.25916756623491066*lm + 0.19123664424897338*
             lm^2 + 0.05251736111111111*lm^3)*NM + 
          (0.6362068614840586 + 0.25916756623491066*lm + 0.19123664424897338*
             lm^2 + 0.05251736111111111*lm^3)*NL + 
          (-0.33509704685809943 + 0.25916756623491066*lm + 
            0.19123664424897338*lm^2 + 0.05251736111111111*lm^3)*NH))}, 
     {0.38, NC*(CF^2*(-0.43901376116900515 - 0.4493855827086278*lm + 
          0.7697072304346019*lm^2 - 0.4761*lm^3) + 
        CA*CF*(-1.218925158611191 - 0.5138248233702426*lm - 
          1.6125608591788545*lm^2 - 0.29095*lm^3) + 
        CF*((0.4307883601007448 + 0.2595516140690916*lm + 0.19220197439615536*
             lm^2 + 0.0529*lm^3)*NM + (0.6387368270827576 + 
            0.2595516140690916*lm + 0.19220197439615536*lm^2 + 0.0529*lm^3)*
           NL + (-0.3366166526842805 + 0.2595516140690916*lm + 
            0.19220197439615536*lm^2 + 0.0529*lm^3)*NH))}, 
     {0.385, NC*(CF^2*(-0.43943917602756816 - 0.4526711286683737*lm + 
          0.7792535711022818*lm^2 - 0.47955625*lm^3) + 
        CA*CF*(-1.2154220510577582 - 0.5060230767916446*lm - 
          1.6218480780763833*lm^2 - 0.29306215277777775*lm^3) + 
        CF*((0.42794320753682197 + 0.25989893706097245*lm + 
            0.1931574157108576*lm^2 + 0.05328402777777778*lm^3)*NM + 
          (0.6412602964166112 + 0.25989893706097245*lm + 0.1931574157108576*
             lm^2 + 0.05328402777777778*lm^3)*NL + 
          (-0.3380985955264838 + 0.25989893706097245*lm + 0.1931574157108576*
             lm^2 + 0.05328402777777778*lm^3)*NH))}, 
     {0.39, NC*(CF^2*(-0.43990057455418174 - 0.4560528044459513*lm + 
          0.7889550519913542*lm^2 - 0.483025*lm^3) + 
        CA*CF*(-1.211882860409307 - 0.4978928060103597*lm - 
          1.631095176560839*lm^2 - 0.29518194444444446*lm^3) + 
        CF*((0.4250319956099923 + 0.2602099713241741*lm + 0.19410291088984954*
             lm^2 + 0.05366944444444444*lm^3)*NM + 
          (0.6437780513253459 + 0.2602099713241741*lm + 0.19410291088984954*
             lm^2 + 0.05366944444444444*lm^3)*NL + 
          (-0.3395427677993801 + 0.2602099713241741*lm + 0.19410291088984954*
             lm^2 + 0.05366944444444444*lm^3)*NH))}, 
     {0.395, NC*(CF^2*(-0.4403982130863747 - 0.4595362911328559*lm + 
          0.7988121808940749*lm^2 - 0.48650625*lm^3) + 
        CA*CF*(-1.208314572366316 - 0.4894360017437775*lm - 
          1.640301844314732*lm^2 - 0.297309375*lm^3) + 
        CF*((0.4220557690274325 + 0.26048515061631883*lm + 
            0.19503840351176946*lm^2 + 0.05405625*lm^3)*NM + 
          (0.6462908557429322 + 0.26048515061631883*lm + 0.19503840351176946*
             lm^2 + 0.05405625*lm^3)*NL + (-0.3409490664736404 + 
            0.26048515061631883*lm + 0.19503840351176946*lm^2 + 
            0.05405625*lm^3)*NH))}, 
     {0.4, NC*(CF^2*(-0.4409321940392652 - 0.46312722131841844*lm + 
          0.8088254578854825*lm^2 - 0.49*lm^3) + 
        CA*CF*(-1.204724045791182 - 0.4806546475776274*lm - 
          1.6494677757366496*lm^2 - 0.29944444444444446*lm^3) + 
        CF*((0.4190155521582833 + 0.26072490630703954*lm + 
            0.19596383801272416*lm^2 + 0.05444444444444444*lm^3)*NM + 
          (0.6487994561176036 + 0.26072490630703954*lm + 0.19596383801272416*
             lm^2 + 0.05444444444444444*lm^3)*NL + 
          (-0.3423173929623679 + 0.26072490630703954*lm + 0.19596383801272416*
             lm^2 + 0.05444444444444444*lm^3)*NH))}, 
     {0.405, NC*(CF^2*(-0.44150247144388655 - 0.4668311795808521*lm + 
          0.8189953755352989*lm^2 - 0.49350625*lm^3) + 
        CA*CF*(-1.2011180153642007 - 0.47155071964801687*lm - 
          1.6585926698117617*lm^2 - 0.30158715277777776*lm^3) + 
        CF*((0.4159123494659441 + 0.2609296673501347*lm + 0.19687915966274458*
             lm^2 + 0.05483402777777778*lm^3)*NM + 
          (0.6513045818210572 + 0.2609296673501347*lm + 0.19687915966274458*
             lm^2 + 0.05483402777777778*lm^3)*NL + 
          (-0.34364765301126976 + 0.2609296673501347*lm + 0.19687915966274458*
             lm^2 + 0.05483402777777778*lm^3)*NH))}, 
     {0.41, NC*(CF^2*(-0.4421088562715592 - 0.4706537029871502*lm + 
          0.8293224191124593*lm^2 - 0.497025*lm^3) + 
        CA*CF*(-1.1975030941829796 - 0.46212618635038094*lm - 
          1.6676762299868304*lm^2 - 0.3037375*lm^3) + 
        CF*((0.412747145930844 + 0.26109986025957316*lm + 0.19778431454306009*
             lm^2 + 0.055225*lm^3)*NM + (0.6538069455470827 + 
            0.26109986025957316*lm + 0.19778431454306009*lm^2 + 
            0.055225*lm^3)*NL + (-0.3449397565924203 + 0.26109986025957316*
             lm + 0.19778431454306009*lm^2 + 0.055225*lm^3)*NH))}, 
     {0.415, NC*(CF^2*(-0.4427510215532559 - 0.47460028160046125*lm + 
          0.8398070667825823*lm^2 - 0.50055625*lm^3) + 
        CA*CF*(-1.1938857763059667 - 0.45238300807358933*lm - 
          1.676718164049533*lm^2 - 0.3058954861111111*lm^3) + 
        CF*((0.40952090746380576 + 0.2612359090890754*lm + 
            0.19867924952415753*lm^2 + 0.05561736111111111*lm^3)*NM + 
          (0.6563072436998681 + 0.2612359090890754*lm + 0.19867924952415753*
             lm^2 + 0.05561736111111111*lm^3)*NL + 
          (-0.34619361780147073 + 0.2612359090890754*lm + 0.19867924952415753*
             lm^2 + 0.05561736111111111*lm^3)*NH))}, 
     {0.42, NC*(CF^2*(-0.443428507302506 - 0.47867635899367594*lm + 
          0.8504497897986769*lm^2 - 0.5041*lm^3) + 
        CA*CF*(-1.1902724392408301 - 0.442323136957577*lm - 
          1.6857181840119198*lm^2 - 0.3080611111111111*lm^3) + 
        CF*((0.40623458131012924 + 0.26133823541501455*lm + 
            0.19956391224459144*lm^2 + 0.05601111111111111*lm^3)*NM + 
          (0.6588061567722309 + 0.26133823541501455*lm + 0.19956391224459144*
             lm^2 + 0.05601111111111111*lm^3)*NL + 
          (-0.3474091547581704 + 0.26133823541501455*lm + 0.19956391224459144*
             lm^2 + 0.05601111111111111*lm^3)*NH))}, 
     {0.425, NC*(CF^2*(-0.4441407252500088 - 0.48288733276807255*lm + 
          0.861251052685367*lm^2 - 0.50765625*lm^3) + 
        CA*CF*(-1.1866693463784728 - 0.431948516672972*lm - 
          1.6946760059978312*lm^2 - 0.310234375*lm^3) + 
        CF*((0.402889096444531 + 0.26140725832240125*lm + 0.20043825109051477*
             lm^2 + 0.05640625*lm^3)*NM + (0.661304349714019 + 
            0.26140725832240125*lm + 0.20043825109051477*lm^2 + 
            0.05640625*lm^3)*NL + (-0.34858628951006926 + 
            0.26140725832240125*lm + 0.20043825109051477*lm^2 + 
            0.05640625*lm^3)*NH))}, 
     {0.43, NC*(CF^2*(-0.44488696339775824 - 0.4872385550759611*lm + 
          0.8722113134169015*lm^2 - 0.511225*lm^3) + 
        CA*CF*(-1.1830826493735092 - 0.42126108222129327*lm - 
          1.7035913501341158*lm^2 - 0.3124152777777778*lm^3) + 
        CF*((0.3994853639570849 + 0.2614433943937286*lm + 0.20130221517589983*
             lm^2 + 0.05680277777777778*lm^3)*NM + 
          (0.6638024722909268 + 0.2614433943937286*lm + 0.20130221517589983*
             lm^2 + 0.05680277777777778*lm^3)*NL + 
          (-0.3497249479392776 + 0.2614433943937286*lm + 0.20130221517589983*
             lm^2 + 0.05680277777777778*lm^3)*NH))}, 
     {0.435, NC*(CF^2*(-0.4456663904001414 - 0.4917353331463575*lm + 
          0.8833310235892032*lm^2 - 0.51480625*lm^3) + 
        CA*CF*(-1.1795183904720627 - 0.41026275975438686*lm - 
          1.7124639404454869*lm^2 - 0.31460381944444443*lm^3) + 
        CF*((0.39602427743031154 + 0.26144705770047294*lm + 
            0.20215575432342187*lm^2 + 0.05720069444444444*lm^3)*NM + 
          (0.6663011594339665 + 0.26144705770047294*lm + 0.20215575432342187*
             lm^2 + 0.05720069444444444*lm^3)*NL + 
          (-0.35082505967216576 + 0.26144705770047294*lm + 
            0.20215575432342187*lm^2 + 0.05720069444444444*lm^3)*NH))}, 
     {0.44, NC*(CF^2*(-0.4464780597791365 - 0.4963829298128018*lm + 
          0.894610628586198*lm^2 - 0.5184*lm^3) + 
        CA*CF*(-1.175982504787766 - 0.3989554664118546*lm - 
          1.721293504752879*lm^2 - 0.3168*lm^3) + 
        CF*((0.39250671330757286 + 0.2614186597970563*lm + 0.202998819045978*
             lm^2 + 0.0576*lm^3)*NM + (0.6688010315798331 + 
            0.2614186597970563*lm + 0.202998819045978*lm^2 + 0.0576*lm^3)*
           NL + (-0.3518865579918912 + 0.2614186597970563*lm + 
            0.202998819045978*lm^2 + 0.0576*lm^3)*NH))}, 
     {0.445, NC*(CF^2*(-0.447320913980428 - 0.5011865640425102*lm + 
          0.9060505677406546*lm^2 - 0.52200625*lm^3) + 
        CA*CF*(-1.1724808225268748 - 0.3873411101753085*lm - 
          1.7300797745751555*lm^2 - 0.31900381944444445*lm^3) + 
        CF*((0.38893353125292995 + 0.2613586097170927*lm + 
            0.20383136052881615*lm^2 + 0.058000694444444445*lm^3)*NM + 
          (0.6713026950023976 + 0.2613586097170927*lm + 0.20383136052881615*
             lm^2 + 0.058000694444444445*lm^3)*NL + 
          (-0.35290937975364467 + 0.2613586097170927*lm + 0.20383136052881615*
             lm^2 + 0.058000694444444445*lm^3)*NH))}, 
     {0.45, NC*(CF^2*(-0.4481937882769486 - 0.5061514114661205*lm + 
          0.9176512744897534*lm^2 - 0.525625*lm^3) + 
        CA*CF*(-1.169019071163417 - 0.3754215897383628*lm - 
          1.7388224850340397*lm^2 - 0.32121527777777775*lm^3) + 
        CF*((0.3853055745026259 + 0.2612673139717496*lm + 0.20465333061224963*
             lm^2 + 0.058402777777777776*lm^3)*NM + 
          (0.6738067421355599 + 0.2612673139717496*lm + 0.20465333061224963*
             lm^2 + 0.058402777777777776*lm^3)*NL + 
          (-0.3538934653025138 + 0.2612673139717496*lm + 0.20465333061224963*
             lm^2 + 0.058402777777777776*lm^3)*NH))}, 
     {0.455, NC*(CF^2*(-0.4490954145260816 - 0.5112826049073568*lm + 
          0.9294131765255919*lm^2 - 0.52925625*lm^3) + 
        CA*CF*(-1.1656028775653107 - 0.3631987943913416*lm - 
          1.7475213747621383*lm^2 - 0.323434375*lm^3) + 
        CF*((0.3816236702083576 + 0.26114517655006947*lm + 
            0.20546468177493424*lm^2 + 0.05880625*lm^3)*NM + 
          (0.6763137518876869 + 0.26114517655006947*lm + 0.20546468177493424*
             lm^2 + 0.05880625*lm^3)*NL + (-0.35483875839386647 + 
            0.26114517655006947*lm + 0.20546468177493424*lm^2 + 
            0.05880625*lm^3)*NH))}, 
     {0.46, NC*(CF^2*(-0.4500244247864697 - 0.5165852349119949*lm + 
          0.9413366959408273*lm^2 - 0.5329*lm^3) + 
        CA*CF*(-1.1622377700724018 - 0.3506746039197469*lm - 
          1.7561761858139389*lm^2 - 0.3256611111111111*lm^3) + 
        CF*((0.37788862977250204 + 0.2609925989211051*lm + 
            0.20626536711768587*lm^2 + 0.05921111111111111*lm^3)*NM + 
          (0.6788242899478594 + 0.2609925989211051*lm + 0.20626536711768587*
             lm^2 + 0.05921111111111111*lm^3)*NL + 
          (-0.3557452061161594 + 0.2609925989211051*lm + 0.20626536711768587*
             lm^2 + 0.05921111111111111*lm^3)*NH))}, 
     {0.465, NC*(CF^2*(-0.4509793548001321 - 0.5220643502755707*lm + 
          0.9534222493696429*lm^2 - 0.53655625*lm^3) + 
        CA*CF*(-1.1589291805273614 - 0.3378508885155934*lm - 
          1.7647866635796625*lm^2 - 0.32789548611111113*lm^3) + 
        CF*((0.3741012491754633 + 0.2608099800377337*lm + 0.20705534034781745*
             lm^2 + 0.059617361111111114*lm^3)*NM + 
          (0.6813389090841462 + 0.2608099800377337*lm + 0.20705534034781745*
             lm^2 + 0.059617361111111114*lm^3)*NL + 
          (-0.35661275881608256 + 0.2608099800377337*lm + 0.20705534034781745*
             lm^2 + 0.059617361111111114*lm^3)*NH))}, 
     {0.47, NC*(CF^2*(-0.45195864734532903 - 0.5277249585693182*lm + 
          0.9656702481242213*lm^2 - 0.540225*lm^3) + 
        CA*CF*(-1.155682446260403 - 0.32472950870077016*lm - 
          1.7733525567018646*lm^2 - 0.3301375*lm^3) + 
        CF*((0.37026230929530646 + 0.2605977163420214*lm + 
            0.20783455576397541*lm^2 + 0.060025*lm^3)*NM + 
          (0.6838581494341192 + 0.2605977163420214*lm + 0.20783455576397541*
             lm^2 + 0.060025*lm^3)*NL + (-0.35744137002595555 + 
            0.2605977163420214*lm + 0.20783455576397541*lm^2 + 0.060025*lm^3)*
           NH))}, {0.475, NC*(CF^2*(-0.4529606554653845 - 
          0.5335720266638752*lm + 0.9780810983268936*lm^2 - 
          0.54390625*lm^3) + CA*CF*(-1.1525028120287653 - 
          0.3113123152616451*lm - 1.781873616994676*lm^2 - 
          0.33238715277777775*lm^3) + 
        CF*((0.36637257621984587 + 0.2603562017720214*lm + 
            0.20860296824145627*lm^2 + 0.06043402777777778*lm^3)*NM + 
          (0.6863825387878176 + 0.2603562017720214*lm + 0.20860296824145627*
             lm^2 + 0.06043402777777778*lm^3)*NL + 
          (-0.35823099639329087 + 0.2603562017720214*lm + 0.20860296824145627*
             lm^2 + 0.06043402777777778*lm^3)*NH))}, 
     {0.48, NC*(CF^2*(-0.4539836455784481 - 0.5396104812503352*lm + 
          0.9906552010381323*lm^2 - 0.5476*lm^3) + 
        CA*CF*(-1.1493954319119097 - 0.29760114919417485*lm - 
          1.7903495993655858*lm^2 - 0.33464444444444447*lm^3) + 
        CF*((0.36243280155135205 + 0.2600858277698936*lm + 
            0.20936053321798528*lm^2 + 0.060844444444444444*lm^3)*NM + 
          (0.688912592863367 + 0.2600858277698936*lm + 0.20936053321798528*
             lm^2 + 0.060844444444444444*lm^3)*NL + 
          (-0.3589815976124495 + 0.2600858277698936*lm + 0.20936053321798528*
             lm^2 + 0.060844444444444444*lm^3)*NH))}, 
     {0.485, NC*(CF^2*(-0.45502580047296215 - 0.5458452093582655*lm + 
          1.0033929523805427*lm^2 - 0.55130625*lm^3) + 
        CA*CF*(-1.1463653711633779 - 0.2835978416588299*lm - 
          1.7987802617396684*lm^2 - 0.336909375*lm^3) + 
        CF*((0.35844372270404373 + 0.2597869832912435*lm + 0.2101072066799397*
             lm^2 + 0.06125625*lm^3)*NM + (0.6914488155754536 + 
            0.2597869832912435*lm + 0.2101072066799397*lm^2 + 
            0.06125625*lm^3)*NL + (-0.35969313635831046 + 0.2597869832912435*
             lm + 0.2101072066799397*lm^2 + 0.06125625*lm^3)*NH))}, 
     {0.49, NC*(CF^2*(-0.456085222193394 - 0.5522810588703458*lm + 
          1.0162947436590024*lm^2 - 0.555025*lm^3) + 
        CA*CF*(-1.1434176080202414 - 0.2693042139446878*lm - 
          1.8071653649861652*lm^2 - 0.33918194444444444*lm^3) + 
        CF*((0.3544060631945273 + 0.25946005481558304*lm + 
            0.21084294514899973*lm^2 + 0.06166944444444444*lm^3)*NM + 
          (0.6939916992968462 + 0.25946005481558304*lm + 0.21084294514899973*
             lm^2 + 0.06166944444444444*lm^3)*NL + 
          (-0.3603655782218848 + 0.25946005481558304*lm + 0.21084294514899973*
             lm^2 + 0.06166944444444444*lm^3)*NH))}, 
     {0.495, NC*(CF^2*(-0.4571599348205981 - 0.5589228390333179*lm + 
          1.029360961477094*lm^2 - 0.55875625*lm^3) + 
        CA*CF*(-1.1405570354710775 - 0.2547220774420865*lm - 
          1.8155046728473314*lm^2 - 0.3414621527777778*lm^3) + 
        CF*((0.3503205329253461 + 0.25910542635782374*lm + 
            0.21156770566921176*lm^2 + 0.06208402777777778*lm^3)*NM + 
          (0.6965417251131605 + 0.25910542635782374*lm + 0.21156770566921176*
             lm^2 + 0.06208402777777778*lm^3)*NL + 
          (-0.36099889164780385 + 0.25910542635782374*lm + 
            0.21156770566921176*lm^2 + 0.06208402777777778*lm^3)*NH))}, 
     {0.5, CF*NC*(CF*(-0.45824788713216197 - 0.5657753209460582*lm + 
          1.0425919878512084*lm^2 - 0.5625*lm^3) + 
        CA*(-1.1377884629531894 - 0.2398532336080883*lm - 
          1.823797951868706*lm^2 - 0.34375*lm^3) + 0.34618782845558144*NM + 
        0.2587234794781332*lm*NM + 0.2122814457943102*lm^2*NM + 
        0.0625*lm^3*NM + 0.6990993630668513*NL + 0.2587234794781332*lm*
         NL + 0.2122814457943102*lm^2*NL + 0.0625*lm^3*NL - 
        0.3615930478731479*NH + 0.2587234794781332*lm*NH + 
        0.2122814457943102*lm^2*NH + 0.0625*lm^3*NH)}, 
     {0.505, CF*NC*(CF*(-0.4593469552641603 - 0.5728432381424395*lm + 
          1.055988200314703*lm^2 - 0.56625625*lm^3) + 
        CA*(-1.1351166181682744 - 0.22469947401887774*lm - 
          1.8320449713354594*lm^2 - 0.34604548611111113*lm^3) + 
        0.34200863329744224*NM + 0.25831459330619144*lm*NM + 
        0.21298412357614413*lm^2*NM + 0.06291736111111111*lm^3*NM + 
        0.7016650724167853*NL + 0.25831459330619144*lm*NL + 
        0.21298412357614413*lm^2*NL + 0.06291736111111111*lm^3*NL - 
        0.3621480208704738*NH + 0.25831459330619144*lm*NH + 
        0.21298412357614413*lm^2*NH + 0.06291736111111111*lm^3*NH)}, 
     {0.51, CF*NC*(CF*(-0.46045494507229184 - 0.5801312869617874*lm + 
          1.0695499720324093*lm^2 - 0.570025*lm^3) + 
        CA*(-1.1325461485272674 - 0.20926258026217295*lm - 
          1.8402455032024165*lm^2 - 0.3483486111111111*lm^3) + 
        0.337783618138043*NM + 0.25787914453782246*lm*NM + 
        0.21367569755195454*lm^2*NM + 0.0633361111111111*lm^3*NM + 
        0.7042393018454397*NL + 0.25787914453782246*lm*NL + 
        0.21367569755195454*lm^2*NL + 0.0633361111111111*lm^3*NL - 
        0.3626637872873741*NH + 0.25787914453782246*lm*NH + 
        0.21367569755195454*lm^2*NH + 0.0633361111111111*lm^3*NH)}, 
     {0.515, CF*NC*(CF*(-0.4615695946218797 - 0.5876441271338569*lm + 
          1.0832776718975468*lm^2 - 0.57380625*lm^3) + 
        CA*(-1.1300816229072614 - 0.1935443240120462*lm - 
          1.8483993220348325*lm^2 - 0.350659375*lm^3) + 
        0.333513441127002*NM + 0.25741750746230263*lm*NM + 
        0.21435612673360593*lm^2*NM + 0.06375625*lm^3*NM + 
        0.7068224897087041*NL + 0.25741750746230263*lm*NL + 
        0.21435612673360593*lm^2*NL + 0.06375625*lm^3*NL - 
        0.3631403263930933*NH + 0.25741750746230263*lm*NH + 
        0.21435612673360593*lm^2*NH + 0.06375625*lm^3*NH)}, 
     {0.52, CF*NC*(CF*(-0.46268857647592004 - 0.5953863822430208*lm + 
          1.097171664633174*lm^2 - 0.5776*lm^3) + 
        CA*(-1.127727533186255 - 0.17754646701669227*lm - 
          1.8565062049463936*lm^2 - 0.3529777777777778*lm^3) + 
        0.32919874811978317*NM + 0.25693005397448393*lm*NM + 
        0.215025370596314*lm^2*NM + 0.06417777777777778*lm^3*NM + 
        0.7094150642540603*NL + 0.25693005397448393*lm*NL + 
        0.215025370596314*lm^2*NL + 0.06417777777777778*lm^3*NL - 
        0.3635776200238421*NH + 0.25693005397448393*lm*NH + 
        0.215025370596314*lm^2*NH + 0.06417777777777778*lm^3*NH)}, 
     {0.525, CF*NC*(CF*(-0.463809499924958 - 0.6033626402121667*lm + 
          1.1112323108890507*lm^2 - 0.58140625*lm^3) + 
        CA*(-1.1254882957811698 - 0.1612707611116332*lm - 
          1.8645659315400247*lm^2 - 0.35530381944444445*lm^3) + 
        0.3248401729231938*NM + 0.25641715359089173*lm*NM + 
        0.21568338906788326*lm^2*NM + 0.06460069444444444*lm^3*NM + 
        0.7120174438385276*NL + 0.25641715359089173*lm*NL + 
        0.21568338906788326*lm^2*NL + 0.06460069444444444*lm^3*NL - 
        0.3639756525302395*NH + 0.25641715359089173*lm*NH + 
        0.21568338906788326*lm^2*NH + 0.06460069444444444*lm^3*NH)}, 
     {0.53, CF*NC*(CF*(-0.4649299131373446 - 0.6115774537814815*lm + 
          1.1254599673356322*lm^2 - 0.585225*lm^3) + 
        CA*(-1.1233682531505624 - 0.14471894823815393*lm - 
          1.872578283850447*lm^2 - 0.3576375*lm^3) + 0.3204383375350649*NM + 
        0.2558791734663697*lm*NM + 0.21633014251826307*lm^2*NM + 
        0.065025*lm^3*NM + 0.714630037141052*NL + 0.2558791734663697*lm*
         NL + 0.21633014251826307*lm^2*NL + 0.065025*lm^3*NL - 
        0.3643344107262217*NH + 0.2558791734663697*lm*NH + 
        0.21633014251826307*lm^2*NH + 0.065025*lm^3*NH)}, 
     {0.535, CF*NC*(CF*(-0.4660473052329585 - 0.6200353409820052*lm + 
          1.1398549867553032*lm^2 - 0.58905625*lm^3) + 
        CA*(-1.1213716752628622 - 0.12789276046660283*lm - 
          1.8805430462884258*lm^2 - 0.35997881944444443*lm^3) + 
        0.315993852378257*NM + 0.2553164784112172*lm*NM + 
        0.21696559174941074*lm^2*NM + 0.06545069444444444*lm^3*NM + 
        0.7172532433694936*NL + 0.2553164784112172*lm*NL + 
        0.21696559174941074*lm^2*NL + 0.06545069444444444*lm^3*NL - 
        0.3646538838393663*NH + 0.2553164784112172*lm*NH + 
        0.21696559174941074*lm^2*NH + 0.06545069444444444*lm^3*NH)}, 
     {0.54, CF*NC*(CF*(-0.4671591082833481 - 0.6287407856038514*lm + 
          1.154417718130941*lm^2 - 0.5929*lm^3) + 
        CA*(-1.1195027610309436 - 0.11079392002421198*lm - 
          1.8884600055866472*lm^2 - 0.3623277777777778*lm^3) + 
        0.3115073165291313*NM + 0.25472943090877226*lm*NM + 
        0.217589697985451*lm^2*NM + 0.06587777777777777*lm^3*NM + 
        0.7198874524623625*NL + 0.25472943090877226*lm*NL + 
        0.217589697985451*lm^2*NL + 0.06587777777777777*lm^3*NL - 
        0.36493406346258633*NH + 0.25472943090877226*lm*NH + 
        0.217589697985451*lm^2*NH + 0.06587777777777777*lm^3*NH)}, 
     {0.545, CF*NC*(CF*(-0.4682626992411246 - 0.6376982376590078*lm + 
          1.169148506731907*lm^2 - 0.59675625*lm^3) + 
        CA*(-1.1177656397138358 - 0.09342413932711427*lm - 
          1.896328950747168*lm^2 - 0.364684375*lm^3) + 
        0.3069793179406246*NM + 0.2541183911333931*lm*NM + 
        0.21820242286312144*lm^2*NM + 0.06630625*lm^3*NM + 
        0.7225330452854485*NL + 0.2541183911333931*lm*NL + 
        0.21820242286312144*lm^2*NL + 0.06630625*lm^3*NL - 
        0.36517494350714674*NH + 0.2541183911333931*lm*NH + 
        0.21820242286312144*lm^2*NH + 0.06630625*lm^3*NH)}, 
     {0.55, CF*NC*(CF*(-0.4693554018013201 - 0.6469121138386442*lm + 
          1.1840476941975515*lm^2 - 0.600625*lm^3) + 
        CA*(-1.1161643722863464 - 0.07578512101625252*lm - 
          1.9041496729903853*lm^2 - 0.3670486111111111*lm^3) + 
        0.3024104336600623*NM + 0.2534837169687955*lm*NM + 
        0.2188037284224943*lm^2*NM + 0.06673611111111111*lm^3*NM + 
        0.7251903938234864*NL + 0.2534837169687955*lm*NL + 
        0.2188037284224943*lm^2*NL + 0.06673611111111111*lm^3*NL - 
        0.36537652015696076*NH + 0.2534837169687955*lm*NH + 
        0.2188037284224943*lm^2*NH + 0.06673611111111111*lm^3*NH)}, 
     {0.555, CF*NC*(CF*(-0.47043448819731143 - 0.6563867979648663*lm + 
          1.199115618618319*lm^2 - 0.60450625*lm^3) + 
        CA*(-1.1147029527773695 - 0.05787855799689524*lm - 
          1.9119219657054718*lm^2 - 0.3694204861111111*lm^3) + 
        0.2978012300418406*NM + 0.25282576402670737*lm*NM + 
        0.21939357709796456*lm^2*NM + 0.06716736111111112*lm^3*NM + 
        0.7278598613669965*NL + 0.25282576402670737*lm*NL + 
        0.21939357709796456*lm^2*NL + 0.06716736111111112*lm^3*NL - 
        0.36553879182412363*NH + 0.25282576402670737*lm*NH + 
        0.21939357709796456*lm^2*NH + 0.06716736111111112*lm^3*NH)}, 
     {0.56, CF*NC*(CF*(-0.4714971809338036 - 0.6661266414368665*lm + 
          1.2143526146145345*lm^2 - 0.6084*lm^3) + 
        CA*(-1.1133853095776267 - 0.03970613348148981*lm - 
          1.919645624402229*lm^2 - 0.3718*lm^3) + 0.2931522629551082*NM + 
        0.25214488566580145*lm*NM + 0.21997193170949617*lm^2*NM + 
        0.0676*lm^3*NM + 0.7305418026944324*NL + 0.25214488566580145*lm*
         NL + 0.21997193170949617*lm^2*NL + 0.0676*lm^3*NL - 
        0.3656617591056424*NH + 0.25214488566580145*lm*NH + 
        0.21997193170949617*lm^2*NH + 0.0676*lm^3*NH)}, 
     {0.565, CF*NC*(CF*(-0.4725406544592627 - 0.6761359636714362*lm + 
          1.229759013412951*lm^2 - 0.61230625*lm^3) + 
        CA*(-1.1122153067175748 - 0.02126952103560112*lm - 
          1.9273204466643077*lm^2 - 0.37418715277777775*lm^3) + 
        0.28846407798657225*NM + 0.2514414330108728*lm*NM + 
        0.22053875545411655*lm^2*NM + 0.06803402777777778*lm^3*NM + 
        0.7332365642497659*NL + 0.2514414330108728*lm*NL + 
        0.22053875545411655*lm^2*NL + 0.06803402777777778*lm^3*NL - 
        0.3657454247413242*NH + 0.2514414330108728*lm*NH + 
        0.22053875545411655*lm^2*NH + 0.06803402777777778*lm^3*NH)}, 
     {0.57, CF*NC*(CF*(-0.47356203678009123 - 0.6864190525378078*lm + 
          1.2453351429211328*lm^2 - 0.616225*lm^3) + 
        CA*(-1.1111967451162028 - 0.0025703846266976337*lm - 
          1.934946232103752*lm^2 - 0.3765819444444444*lm^3) + 
        0.2837372106385527*NM + 0.2507157549722278*lm*NM + 
        0.2210940118976519*lm^2*NM + 0.06846944444444444*lm^3*NM + 
        0.7359444843156385*NL + 0.2507157549722278*lm*NL + 
        0.2210940118976519*lm^2*NL + 0.06846944444444444*lm^3*NL - 
        0.36578979357278407*NH + 0.2507157549722278*lm*NH + 
        0.2210940118976519*lm^2*NH + 0.06846944444444444*lm^3*NH)}, 
     {0.575, CF*NC*(CF*(-0.4745584110187443 - 0.6969801647868105*lm + 
          1.2610813277997475*lm^2 - 0.62015625*lm^3) + 
        CA*(-1.1103333638014163 + 0.01638962132443778*lm - 
          1.942522782316821*lm^2 - 0.378984375*lm^3) + 0.27897218652240435*
         NM + 0.24996819826525463*lm*NM + 0.22163766496669474*lm^2*NM + 
        0.06890625*lm^3*NM + 0.7386658931821994*NL + 0.24996819826525463*lm*
         NL + 0.22163766496669474*lm^2*NL + 0.06890625*lm^3*NL - 
        0.3657948725035374*NH + 0.24996819826525463*lm*NH + 
        0.22163766496669474*lm^2*NH + 0.06890625*lm^3*NH)}, 
     {0.58, CF*NC*(CF*(-0.4755268169178949 - 0.7078235264743283*lm + 
          1.2769978895328347*lm^2 - 0.6241*lm^3) + 
        CA*(-1.1096288411027038 + 0.03560885188988229*lm - 
          1.9500499008410455*lm^2 - 0.3813944444444444*lm^3) + 
        0.27416952154742547*NM + 0.24919910743014703*lm*NM + 
        0.22216967894079614*lm^2*NM + 0.06934444444444444*lm^3*NM + 
        0.74140111331175*NL + 0.24919910743014703*lm*NL + 
        0.22216967894079614*lm^2*NL + 0.06934444444444444*lm^3*NL - 
        0.36576067046014127*NH + 0.24919910743014703*lm*NH + 
        0.22216967894079614*lm^2*NH + 0.06934444444444444*lm^3*NH)}, 
     {0.585, CF*NC*(CF*(-0.476464252292672 - 0.7189533333790573*lm + 
          1.2930851464961235*lm^2 - 0.62805625*lm^3) + 
        CA*(-1.109086795816751 + 0.055085671578529886*lm - 
          1.95752739311348*lm^2 - 0.3838121527777778*lm^3) + 
        0.2693297221053662*NM + 0.24840882485175453*lm*NM + 
        0.22269001844487518*lm^2*NM + 0.06978402777777777*lm^3*NM + 
        0.7441504594993122*NL + 0.24840882485175453*lm*NL + 
        0.22269001844487518*lm^2*NL + 0.06978402777777777*lm^3*NL - 
        0.36568719835435176*NH + 0.24840882485175453*lm*NH + 
        0.22269001844487518*lm^2*NH + 0.06978402777777777*lm^3*NH)}, 
     {0.59, CF*NC*(CF*(-0.47736767443291167 - 0.7303737514145652*lm + 
          1.309343414023455*lm^2 - 0.632025*lm^3) + 
        CA*(-1.108710788346664 + 0.0748184542780158*lm - 1.9649550664301108*
           lm^2 - 0.3862375*lm^3) + 0.26445328525064987*NM + 
        0.24759769077953522*lm*NM + 0.22319864844183832*lm^2*NM + 
        0.070225*lm^3*NM + 0.746914239029232*NL + 0.24759769077953522*lm*
         NL + 0.22319864844183832*lm^2*NL + 0.070225*lm^3*NL - 
        0.365574469046265*NH + 0.24759769077953522*lm*NH + 
        0.22319864844183832*lm^2*NH + 0.070225*lm^3*NH)}, 
     {0.595, CF*NC*(CF*(-0.4782340014572842 - 0.7420889170356669*lm + 
          1.3257730044713807*lm^2 - 0.63600625*lm^3) + 
        CA*(-1.1085043218154433 + 0.09480558319478274*lm - 
          1.9723327299063784*lm^2 - 0.3886704861111111*lm^3) + 
        0.2595406988764158*NM + 0.2467660433475875*lm*NM + 
        0.22369553422540214*lm^2*NM + 0.0706673611111111*lm^3*NM + 
        0.7496927518279273*NL + 0.2467660433475875*lm*NL + 
        0.22369553422540214*lm^2*NL + 0.0706673611111111*lm^3*NL - 
        0.36542249730841064*NH + 0.2467660433475875*lm*NH + 
        0.22369553422540214*lm^2*NH + 0.0706673611111111*lm^3*NH)}, 
     {0.6, CF*NC*(CF*(-0.47906011362108364 - 0.7541029376391293*lm + 
          1.3423742272819885*lm^2 - 0.64*lm^3) + 
        CA*(-1.1084708431543342 + 0.11504545079245272*lm - 
          1.9796601944387848*lm^2 - 0.39111111111111113*lm^3) + 
        0.2545924418864904*NM + 0.24591421859474008*lm*NM + 
        0.2241806414131124*lm^2*NM + 0.07111111111111111*lm^3*NM + 
        0.7524862906128871*NL + 0.24591421859474008*lm*NL + 
        0.2241806414131124*lm^2*NL + 0.07111111111111111*lm^3*NL - 
        0.365231299790768*NH + 0.24591421859474008*lm*NH + 
        0.2241806414131124*lm^2*NH + 0.07111111111111111*lm^3*NH)}, 
     {0.605, CF*NC*(CF*(-0.47984285457939724 - 0.766419891958728*lm + 
          1.3591473890440198*lm^2 - 0.64400625*lm^3) + 
        CA*(-1.108613744166667 + 0.13553645872865813*lm - 
          1.9869372726675434*lm^2 - 0.393559375*lm^3) + 
        0.24960898436339027*NM + 0.24504255048467977*lm*NM + 
        0.22465393593955335*lm^2*NM + 0.07155625*lm^3*NM + 
        0.7552951410380249*NL + 0.24504255048467977*lm*NL + 
        0.22465393593955335*lm^2*NL + 0.07155625*lm^3*NL - 
        0.3650008949866761*NH + 0.24504255048467977*lm*NH + 
        0.22465393593955335*lm^2*NH + 0.07155625*lm^3*NH)}, 
     {0.61, CF*NC*(CF*(-0.4805790326072992 - 0.7790438304546841*lm + 
          1.3760927935523284*lm^2 - 0.648025*lm^3) + 
        CA*(-1.1089363625677862 + 0.15627701779047673*lm - 
          1.9941637789402438*lm^2 - 0.3960152777777778*lm^3) + 
        0.2445907877324591*NM + 0.24415137092609904*lm*NM + 
        0.2251153840497413*lm^2*NM + 0.07200277777777778*lm^3*NM + 
        0.7581195818354866*NL + 0.24415137092609904*lm*NL + 
        0.2251153840497413*lm^2*NL + 0.07200277777777778*lm^3*NL - 
        0.36473130319960945*NH + 0.24415137092609904*lm*NH + 
        0.2251153840497413*lm^2*NH + 0.07200277777777778*lm^3*NH)}, 
     {0.615, CF*NC*(CF*(-0.4812654217786519 - 0.7919787756975106*lm + 
          1.3932107418657373*lm^2 - 0.65205625*lm^3) + 
        CA*(-1.109441983001649 + 0.17726554782860618*lm - 
          2.001339529276494*lm^2 - 0.39847881944444447*lm^3) + 
        0.23953830492223593*NM + 0.24324100979284602*lm*NM + 
        0.22556495229269585*lm^2*NM + 0.07245069444444445*lm^3*NM + 
        0.7609598849540085*NL + 0.24324100979284602*lm*NL + 
        0.22556495229269585*lm^2*NL + 0.07245069444444445*lm^3*NL - 
        0.36442254651079375*NH + 0.24324100979284602*lm*NH + 
        0.22556495229269585*lm^2*NH + 0.07245069444444445*lm^3*NH)}, 
     {0.62, CF*NC*(CF*(-0.4818987631050322 - 0.8052287227463037*lm + 
          1.4105015323633423*lm^2 - 0.6561*lm^3) + 
        CA*(-1.1101338380346693 + 0.19850047769040594*lm - 
          2.008464341333513*lm^2 - 0.40095*lm^3) + 0.23445198052115257*NM + 
        0.24231179494406077*lm*NM + 0.2260026075151842*lm^2*NM + 
        0.0729*lm^3*NM + 0.7638163156939227*NL + 0.24231179494406077*lm*
         NL + 0.2260026075151842*lm^2*NL + 0.0729*lm^3*NL - 
        0.3640746487476341*NH + 0.24231179494406077*lm*NH + 
        0.2260026075151842*lm^2*NH + 0.0729*lm^3*NH)}, 
     {0.625, CF*NC*(CF*(-0.4824757656362406 - 0.8187976395215187*lm + 
          1.427965460799313*lm^2 - 0.66015625*lm^3) + 
        CA*(-1.1110151091273521 + 0.21998024515192607*lm - 
          2.015538034372642*lm^2 - 0.4034288194444444*lm^3) + 
        0.22933225093065257*NM + 0.24136405224428345*lm*NM + 
        0.2264283168556319*lm^2*NM + 0.07335069444444445*lm^3*NM + 
        0.7666891328388992*NL + 0.24136405224428345*lm*NL + 
        0.2264283168556319*lm^2*NL + 0.07335069444444445*lm^3*NL - 
        0.36368763545293253*NH + 0.24136405224428345*lm*NH + 
        0.2264283168556319*lm^2*NH + 0.07335069444444445*lm^3*NH)}, 
     {0.63, CF*NC*(CF*(-0.4829931075237942 - 0.8326894671722719*lm + 
          1.4456028203562383*lm^2 - 0.664225*lm^3) + 
        CA*(-1.1120889275842758 + 0.24170329684903544*lm - 
          2.0225604292267434*lm^2 - 0.4059152777777778*lm^3) + 
        0.22417954451482391*NM + 0.2403981055835202*lm*NM + 
        0.22684204773819575*lm^2*NM + 0.07380277777777777*lm^3*NM + 
        0.7695785887845134*NL + 0.2403981055835202*lm*NL + 
        0.22684204773819575*lm^2*NL + 0.07380277777777777*lm^3*NL - 
        0.3632615338548694*NH + 0.2403981055835202*lm*NH + 
        0.22684204773819575*lm^2*NH + 0.07380277777777777*lm^3*NH)}, 
     {0.635, CF*NC*(CF*(-0.48344743704874804 - 0.846908120438214*lm + 
          1.463413901697062*lm^2 - 0.66830625*lm^3) + 
        CA*(-1.1133583754829357 + 0.2636680882077553*lm - 
          2.029531348268462*lm^2 - 0.408409375*lm^3) + 
        0.218994281746634*NM + 0.23941427689725414*lm*NM + 
        0.2272437678669931*lm^2*NM + 0.07425625*lm^3*NM + 
        0.7724849296637282*NL + 0.23941427689725414*lm*NL + 
        0.2272437678669931*lm^2*NL + 0.07425625*lm^3*NL - 
        0.36279637283772675*NH + 0.23941427689725414*lm*NH + 
        0.2272437678669931*lm^2*NH + 0.07425625*lm^3*NH)}, 
     {0.64, CF*NC*(CF*(-0.4838353736151385 - 0.8614574880060227*lm + 
          1.4813989930156517*lm^2 - 0.6724*lm^3) + 
        CA*(-1.1148264865819781 + 0.2858730833738967*lm - 
          2.036450615379324*lm^2 - 0.4109111111111111*lm^3) + 
        0.21377687535085377*NM + 0.23841288618638978*lm*NM + 
        0.22763344522048315*lm^2*NM + 0.07471111111111112*lm^3*NM + 
        0.7754083954693711*NL + 0.23841288618638978*lm*NL + 
        0.22763344522048315*lm^2*NL + 0.07471111111111112*lm^3*NL - 
        0.3622921829133298*NH + 0.23841288618638978*lm*NH + 
        0.22763344522048315*lm^2*NH + 0.07471111111111112*lm^3*NH)}, 
     {0.645, CF*NC*(CF*(-0.4841535087102893 - 0.876341432860565*lm + 
          1.4995583800860453*lm^2 - 0.67650625*lm^3) + 
        CA*(-1.1164962472093185 + 0.30831675514209583*lm - 
          2.043318055919639*lm^2 - 0.4134204861111111*lm^3) + 
        0.20852773044375533*NM + 0.23739425153711982*lm*NM + 
        0.22801104804599498*lm^2*NM + 0.07516736111111111*lm^3*NM + 
        0.7783492201736901*NL + 0.23739425153711982*lm*NL + 
        0.22801104804599498*lm^2*NL + 0.07516736111111111*lm^3*NL - 
        0.36174899619318635*NH + 0.23739425153711982*lm*NH + 
        0.22801104804599498*lm^2*NH + 0.07516736111111111*lm^3*NH)}, 
     {0.65, CF*NC*(CF*(-0.48439840683317353 - 0.8915637926307796*lm + 
          1.5178923463104135*lm^2 - 0.680625*lm^3) + 
        CA*(-1.1183705971306412 + 0.3309975848843332*lm - 
          2.0501334966991918*lm^2 - 0.4159375*lm^3) + 0.20324724466966526*
         NM + 0.23635868914070435*lm*NM + 0.2283765448543985*lm^2*NM + 
        0.075625*lm^3*NM + 0.7813076318450657*NL + 0.23635868914070435*lm*
         NL + 0.2283765448543985*lm^2*NL + 0.075625*lm^3*NL - 
        0.36116684636130253*NH + 0.23635868914070435*lm*NH + 
        0.2283765448543985*lm^2*NH + 0.075625*lm^3*NH)}, 
     {0.655, CF*NC*(CF*(-0.4845666063919801 - 0.9071283799303377*lm + 
          1.536401172765781*lm^2 - 0.68475625*lm^3) + 
        CA*(-1.1204524303987564 + 0.3539140624780195*lm - 
          2.0568967659486894*lm^2 - 0.41846215277777776*lm^3) + 
        0.19793580833445362*NM + 0.2353065133131529*lm*NM + 
        0.22872990441491323*lm^2*NM + 0.07608402777777777*lm^3*NM + 
        0.7842838527619577*NL + 0.2353065133131529*lm*NL + 
        0.22872990441491323*lm^2*NL + 0.07608402777777777*lm^3*NL - 
        0.36054576864765486*NH + 0.2353065133131529*lm*NH + 
        0.22872990441491323*lm^2*NH + 0.07608402777777777*lm^3*NH)}, 
     {0.66, CF*NC*(CF*(-0.4846546205719853 - 0.9230389826931333*lm + 
          1.5550851382495399*lm^2 - 0.6889*lm^3) + 
        CA*(-1.1227445961842792 + 0.377064686233725*lm - 2.063607693291948*
           lm^2 - 0.42099444444444445*lm^3) + 0.19259380453603642*NM + 
        0.23423803651480113*lm*NM + 0.22907109575005113*lm^2*NM + 
        0.07654444444444444*lm^3*NM + 0.787278099524159*NL + 
        0.23423803651480113*lm*NL + 0.22907109575005113*lm^2*NL + 
        0.07654444444444444*lm^3*NL - 0.3598857998022993*NH + 
        0.23423803651480113*lm*NH + 0.22907109575005113*lm^2*NH + 
        0.07654444444444444*lm^3*NH)}, 
     {0.665, CF*NC*(CF*(-0.4846589381747898 - 0.9392993645036645*lm + 
          1.573944519323797*lm^2 - 0.69305625*lm^3) + 
        CA*(-1.1252498995880917 + 0.40044796282262346*lm - 
          2.0702661097187907*lm^2 - 0.423534375*lm^3) + 
        0.18722160929196785*NM + 0.23315356936977394*lm*NM + 
        0.2294000881306892*lm^2*NM + 0.07700625*lm^3*NM + 
        0.7902905831614306*NL + 0.23315356936977394*lm*NL + 
        0.2294000881306892*lm^2*NL + 0.07700625*lm^3*NL - 
        0.3591869780700983*NH + 0.23315356936977394*lm*NH + 
        0.2294000881306892*lm^2*NH + 0.07700625*lm^3*NH)}, 
     {0.67, CF*NC*(CF*(-0.4845760244299411 - 0.955913264922361*lm + 
          1.5929795903585866*lm^2 - 0.697225*lm^3) + 
        CA*(-1.1279711024360237 + 0.4240624072037185*lm - 
          2.0768718475586416*lm^2 - 0.42608194444444447*lm^3) + 
        0.18181959166419553*NM + 0.23205342068532805*lm*NM + 
        0.22971685107126816*lm^2*NM + 0.07746944444444444*lm^3*NM + 
        0.793321509239588*NL + 0.23205342068532805*lm*NL + 
        0.22971685107126816*lm^2*NL + 0.07746944444444444*lm^3*NL - 
        0.35844934316604826*NH + 0.23205342068532805*lm*NH + 
        0.22971685107126816*lm^2*NH + 0.07746944444444444*lm^3*NH)}, 
     {0.675, CF*NC*(CF*(-0.4844023217799195 - 0.9728843998059207*lm + 
          1.6121906235739842*lm^2 - 0.70140625*lm^3) + 
        CA*(-1.1309109240561908 + 0.44790654255091583*lm - 
          2.083424740454787*lm^2 - 0.42863715277777775*lm^3) + 
        0.17638811388105105*NM + 0.23093789747106708*lm*NM + 
        0.23002135432511286*lm^2*NM + 0.07793402777777778*lm^3*NM + 
        0.796371077964104*NL + 0.23093789747106708*lm*NL + 
        0.23002135432511286*lm^2*NL + 0.07793402777777778*lm^3*NL - 
        0.3576729362511889*NH + 0.23093789747106708*lm*NH + 
        0.23002135432511286*lm^2*NH + 0.07793402777777778*lm^3*NH)}, 
     {0.68, CF*NC*(CF*(-0.48413425063943144 - 0.9902164616227135*lm + 
          1.6315778890811559*lm^2 - 0.7056*lm^3) + 
        CA*(-1.134072042039408 + 0.4719789001799998*lm - 2.089924623339294*
           lm^2 - 0.4312*lm^3) + 0.17092753145654555*NM + 
        0.22980730495802332*lm*NM + 0.2303135678798716*lm^2*NM + 
        0.0784*lm^3*NM + 0.7994394842812994*NL + 0.22980730495802332*lm*
         NL + 0.2303135678798716*lm^2*NL + 0.0784*lm^3*NL - 
        0.35685779990907884*NH + 0.22980730495802332*lm*NH + 
        0.2303135678798716*lm^2*NH + 0.0784*lm^3*NH)}, 
     {0.685, CF*NC*(CF*(-0.4837682101299155 - 1.0079131197633155*lm + 
          1.6511416549223699*lm^2 - 0.70980625*lm^3) + 
        CA*(-1.13745709298309 + 0.49627801947556965*lm - 2.096371332408552*
           lm^2 - 0.43377048611111113*lm^3) + 0.16543819330703857*NM + 
        0.22866194661760061*lm*NM + 0.23059346195307*lm^2*NM + 
        0.07886736111111112*lm^3*NM + 0.8025269179771813*NL + 
        0.22866194661760061*lm*NL + 0.23059346195307*lm^2*NL + 
        0.07886736111111112*lm^3*NL - 0.35600397812282*NH + 
        0.22866194661760061*lm*NH + 0.23059346195307*lm^2*NH + 
        0.07886736111111112*lm^3*NH)}, 
     {0.69, CF*NC*(CF*(-0.4833005787901331 - 1.0259780208462346*lm + 
          1.6708821871100097*lm^2 - 0.714025*lm^3) + 
        CA*(-1.1410686732190392 + 0.5208024478179875*lm - 
          2.1027647050994385*lm^2 - 0.4363486111111111*lm^3) + 
        0.15992044186534635*NM + 0.22750212418037316*lm*NM + 
        0.2308610069877767*lm^2*NM + 0.07933611111111111*lm^3*NM + 
        0.8056335637739939*NL + 0.22750212418037316*lm*NL + 
        0.2308610069877767*lm^2*NL + 0.07933611111111111*lm^3*NL - 
        0.3551115162526155*NH + 0.22750212418037316*lm*NH + 
        0.2308610069877767*lm^2*NH + 0.07933611111111111*lm^3*NH)}, 
     {0.695, CF*NC*(CF*(-0.482727715263683 - 1.0444147890188913*lm + 
          1.6907997496646083*lm^2 - 0.71825625*lm^3) + 
        CA*(-1.144909339525509 + 0.5455507405103852*lm - 2.109104580066073*
           lm^2 - 0.438934375*lm^3) + 0.15437461319235382*NM + 
        0.22632813765473578*lm*NM + 0.23111617364837686*lm^2*NM + 
        0.07980625*lm^3*NM + 0.8087596014245408*NL + 0.22632813765473578*lm*
         NL + 0.23111617364837686*lm^2*NL + 0.07980625*lm^3*NL - 
        0.35418046101384576*NH + 0.22632813765473578*lm*NH + 
        0.23111617364837686*lm^2*NH + 0.07980625*lm^3*NH)}, 
     {0.7, CF*NC*(CF*(-0.48204595896424585 - 1.063227026253917*lm + 
          1.7108946046519413*lm^2 - 0.7225*lm^3) + 
        CA*(-1.1489816098239274 + 0.5705214607057774*lm - 
          2.115390797157147*lm^2 - 0.4415277777777778*lm^3) + 
        0.1488010370861938*NM + 0.2251402853454016*lm*NM + 
        0.23135893281645095*lm^2*NM + 0.08027777777777778*lm^3*NM + 
        0.81190520580434*NL + 0.2251402853454016*lm*NL + 
        0.23135893281645095*lm^2*NL + 0.08027777777777778*lm^3*NL - 
        0.3532108604556478*NH + 0.2251402853454016*lm*NH + 
        0.23135893281645095*lm^2*NH + 0.08027777777777778*lm^3*NH)}, 
     {0.705, CF*NC*(CF*(-0.48125163071933585 - 1.0824183126408318*lm + 
          1.7311670122191996*lm^2 - 0.72675625*lm^3) + 
        CA*(-1.1532879638606448 + 0.5957131793343193*lm - 
          2.1216231973938227*lm^2 - 0.44412881944444443*lm^3) + 
        0.14320003718905333*NM + 0.22393886387174303*lm*NM + 
        0.2315892555867556*lm^2*NM + 0.08075069444444445*lm^3*NM + 
        0.8150705470016651*NL + 0.22393886387174303*lm*NL + 
        0.2315892555867556*lm^2*NL + 0.08075069444444445*lm^3*NL - 
        0.3522027639399836*NH + 0.22393886387174303*lm*NH + 
        0.2315892555867556*lm^2*NH + 0.08075069444444445*lm^3*NH)}, 
     {0.71, CF*NC*(CF*(-0.48034103339330675 - 1.1019922066731702*lm + 
          1.7516172306302729*lm^2 - 0.731025*lm^3) + 
        CA*(-1.1578308438740736 + 0.6211244750307524*lm - 
          2.1278016229481667*lm^2 - 0.4467375*lm^3) + 0.13757193109166774*
         NM + 0.2227241681859734*lm*NM + 0.231807113263303*lm^2*NM + 
        0.081225*lm^3*NM + 0.8182557904055326*NL + 0.2227241681859734*lm*
         NL + 0.231807113263303*lm^2*NL + 0.081225*lm^3*NL - 
        0.3511562221211838*NH + 0.2227241681859734*lm*NH + 
        0.231807113263303*lm^2*NH + 0.081225*lm^3*NH)}, 
     {0.715, CF*NC*(CF*(-0.47931045249033116 - 1.1219522455311117*lm + 
          1.7722455163001685*lm^2 - 0.73530625*lm^3) + 
        CA*(-1.1626126552475662 + 0.6467539340620708*lm - 
          2.133925917122119*lm^2 - 0.44935381944444447*lm^3) + 
        0.13191703043555936*NM + 0.22149649159116547*lm*NM + 
        0.23201247735553684*lm^2*NM + 0.08170069444444444*lm^3*NM + 
        0.8214610967916851*NL + 0.22149649159116547*lm*NL + 
        0.23201247735553684*lm^2*NL + 0.08170069444444444*lm^3*NL - 
        0.35007128692595296*NH + 0.22149649159116547*lm*NH + 
        0.23201247735553684*lm^2*NH + 0.08170069444444444*lm^3*NH)}, 
     {0.72, CF*NC*(CF*(-0.4781561567380458 - 1.1423019453596848*lm + 
          1.7930521238285888*lm^2 - 0.7396*lm^3) + 
        CA*(-1.1676357671483752 + 0.6726001502554457*lm - 
          2.1399959243269735*lm^2 - 0.45197777777777776*lm^3) + 
        0.12623564101307766*NM + 0.22025612575910464*lm*NM + 
        0.23220531957460125*lm^2*NM + 0.08217777777777778*lm^3*NM + 
        0.8246866224066259*NL + 0.22025612575910464*lm*NL + 
        0.23220531957460125*lm^2*NL + 0.08217777777777778*lm^3*NL - 
        0.3489480115338238*NH + 0.22025612575910464*lm*NH + 
        0.23220531957460125*lm^2*NH + 0.08217777777777778*lm^3*NH)}, 
     {0.725, CF*NC*(CF*(-0.47687439865252906 - 1.1630448015426063*lm + 
          1.8140373060326949*lm^2 - 0.74390625*lm^3) + 
        CA*(-1.1729025131530346 + 0.6986617249264361*lm - 
          2.146011490063353*lm^2 - 0.454609375*lm^3) + 0.12052806286529558*
         NM + 0.2190033607479747*lm*NM + 0.23238561182970055*lm^2*NM + 
        0.08265625*lm^3*NM + 0.8279325190497536*NL + 0.2190033607479747*lm*
         NL + 0.23238561182970055*lm^2*NL + 0.08265625*lm^3*NL - 
        0.3477864503580481*NH + 0.2190033607479747*lm*NH + 
        0.23238561182970055*lm^2*NH + 0.08265625*lm^3*NH)}, 
     {0.73, CF*NC*(CF*(-0.4754614150852531 - 1.1841842889718202*lm + 
          1.8352013139790766*lm^2 - 0.748225*lm^3) + 
        CA*(-1.1784151918594787 + 0.7249372668075184*lm - 
          2.1519724609016753*lm^2 - 0.4572486111111111*lm^3) + 
        0.1147945903778149*NM + 0.2177384850198734*lm*NM + 
        0.23255332622454702*lm^2*NM + 0.0831361111111111*lm^3*NM + 
        0.8311989341536477*NL + 0.2177384850198734*lm*NL + 
        0.23255332622454702*lm^2*NL + 0.0831361111111111*lm^3*NL - 
        0.34658665902691116*NH + 0.2177384850198734*lm*NH + 
        0.23255332622454702*lm^2*NH + 0.0831361111111111*lm^3*NH)}, 
     {0.735, CF*NC*(CF*(-0.47391342775262785 - 1.205723862312798*lm + 
          1.8565443970149527*lm^2 - 0.75255625*lm^3) + 
        CA*(-1.1841760674862238 + 0.751425391976959*lm - 2.1578786844630846*
           lm^2 - 0.4598954861111111*lm^3) + 0.10903551237453314*NM + 
        0.21646178545815692*lm*NM + 0.23270843505389416*lm^2*NM + 
        0.08361736111111111*lm^3*NM + 0.834486010862552*NL + 
        0.21646178545815692*lm*NL + 0.23270843505389416*lm^2*NL + 
        0.08361736111111111*lm^3*NL - 0.3453486943654595*NH + 
        0.21646178545815692*lm*NH + 0.23270843505389416*lm^2*NH + 
        0.08361736111111111*lm^3*NH)}, 
     {0.74, CF*NC*(CF*(-0.4722266437487327 - 1.2276669562656648*lm + 
          1.8780668027986236*lm^2 - 0.7569*lm^3) + 
        CA*(-1.1901873704589174 + 0.7781247237880585*lm - 
          2.163730009400841*lm^2 - 0.46255*lm^3) + 0.10325111220942183*NM + 
        0.2151735473846112*lm*NM + 0.23285091080015294*lm^2*NM + 
        0.0841*lm^3*NM + 0.8377938881091037*NL + 0.2151735473846112*lm*
         NL + 0.23285091080015294*lm^2*NL + 0.0841*lm^3*NL - 
        0.344072614377629*NH + 0.2151735473846112*lm*NH + 
        0.23285091080015294*lm^2*NH + 0.0841*lm^3*NH)}, 
     {0.745, CF*NC*(CF*(-0.47039725604180826 - 1.2500169858222143*lm + 
          1.8997687773291978*lm^2 - 0.76125625*lm^3) + 
        CA*(-1.1964512979845578 + 0.805033892798787*lm - 2.169526285382157*
           lm^2 - 0.4652121527777778*lm^3) + 0.09744166785636575*NM + 
        0.2138740545764489*lm*NM + 0.23298072613008913*lm^2*NM + 
        0.08458402777777778*lm^3*NM + 0.8411227006893516*NL + 
        0.2138740545764489*lm*NL + 0.23298072613008913*lm^2*NL + 
        0.08458402777777778*lm^3*NL - 0.34275847822876365*NH + 
        0.2138740545764489*lm*NH + 0.23298072613008913*lm^2*NH + 
        0.08458402777777778*lm^3*NH)}, 
     {0.75, CF*NC*(CF*(-0.4684214439550618 - 1.2727773465188719*lm + 
          1.9216505649756108*lm^2 - 0.765625*lm^3) + 
        CA*(-1.2029700146136748 + 0.8321515367018351*lm - 
          2.17526736307046*lm^2 - 0.4678819444444444*lm^3) + 
        0.09160745199711058*NM + 0.21256358928313127*lm*NM + 
        0.23309785389159882*lm^2*NM + 0.08506944444444445*lm^3*NM + 
        0.8444725793361092*NL + 0.21256358928313127*lm*NL + 
        0.23309785389159882*lm^2*NL + 0.08506944444444445*lm^3*NL - 
        0.3414063462285137*NH + 0.21256358928313127*lm*NH + 
        0.23309785389159882*lm^2*NH + 0.08506944444444445*lm^3*NH)}, 
     {0.755, CF*NC*(CF*(-0.46629537363231643 - 1.2959514146856732*lm + 
          1.9437124085049582*lm^2 - 0.77000625*lm^3) + 
        CA*(-1.2097456527907624 + 0.859476300255099*lm - 2.180953094108081*
           lm^2 - 0.470559375*lm^3) + 0.0857487321073657*NM + 
        0.21124243224301392*lm*NM + 0.2332022671105602*lm^2*NM + 
        0.08555625*lm^3*NM + 0.8478436507906854*NL + 0.21124243224301392*lm*
         NL + 0.2332022671105602*lm^2*NL + 0.08555625*lm^3*NL - 
        0.34001627981410265*NH + 0.21124243224301392*lm*NH + 
        0.2332022671105602*lm^2*NH + 0.08555625*lm^3*NH)}, 
     {0.76, CF*NC*(CF*(-0.4640151984890185 - 1.3195425476913147*lm + 
          1.9659545491101618*lm^2 - 0.7744*lm^3) + 
        CA*(-1.2167803133932356 + 0.8870068352126189*lm - 
          2.1865833310993454*lm^2 - 0.47324444444444447*lm^3) + 
        0.07986577054110713*NM + 0.2099108626998159*lm*NM + 
        0.2332939389877598*lm^2*NM + 0.08604444444444445*lm^3*NM + 
        0.8512360378730316*NL + 0.2099108626998159*lm*NL + 
        0.2332939389877598*lm^2*NL + 0.08604444444444445*lm^3*NL - 
        0.33858834153395406*NH + 0.2099108626998159*lm*NH + 
        0.2332939389877598*lm^2*NH + 0.08604444444444445*lm^3*NH)}, 
     {0.765, CF*NC*(CF*(-0.46157705964909507 - 1.34355408418434*lm + 
          1.9883772264369854*lm^2 - 0.77880625*lm^3) + 
        CA*(-1.2240760662591894 + 0.9147418002559857*lm - 
          2.1921579275940646*lm^2 - 0.47593715277777776*lm^3) + 
        0.07395882461312502*NM + 0.20856915841891152*lm*NM + 
        0.2333728428958905*lm^2*NM + 0.08653402777777777*lm^3*NM + 
        0.8546498595503503*NL + 0.20856915841891152*lm*NL + 
        0.2333728428958905*lm^2*NL + 0.08653402777777777*lm^3*NL - 
        0.337122595031667*NH + 0.20856915841891152*lm*NH + 
        0.2333728428958905*lm^2*NH + 0.08653402777777777*lm^3*NH)}, 
     {0.77, CF*NC*(CF*(-0.45897708636813944 - 1.3679893443305213*lm + 
          2.010980678610422*lm^2 - 0.783225*lm^3) + 
        CA*(-1.2316349507042184 + 0.9426798609262336*lm - 
          2.197676738071409*lm^2 - 0.4786375*lm^3) + 0.06802814667985799*
         NM + 0.20721759570344503*lm*NM + 0.2334389523766198*lm^2*NM + 
        0.087025*lm^3*NM + 0.8580852310041996*NL + 0.20721759570344503*lm*
         NL + 0.2334389523766198*lm^2*NL + 0.087025*lm^3*NL - 
        0.3356191050303325*NH + 0.20721759570344503*lm*NH + 
        0.2334389523766198*lm^2*NH + 0.087025*lm^3*NH)}, 
     {0.775, CF*NC*(CF*(-0.4562113964433814 - 1.3928516300464964*lm + 
          2.0337651422604646*lm^2 - 0.78765625*lm^3) + 
        CA*(-1.2394589760275594 + 0.9708196895562311*lm - 
          2.2031396179241605*lm^2 - 0.4813454861111111*lm^3) + 
        0.06207398421855674*NM + 0.20585644941026765*lm*NM + 
        0.23349224113772618*lm^2*NM + 0.08751736111111111*lm^3*NM + 
        0.8615422636961348*NL + 0.20585644941026765*lm*NL + 
        0.23349224113772618*lm^2*NL + 0.08751736111111111*lm^3*NL - 
        0.33407793731718005*NH + 0.20585644941026765*lm*NH + 
        0.23349224113772618*lm^2*NH + 0.08751736111111111*lm^3*NH)}, 
     {0.78, CF*NC*(CF*(-0.453276096610886 - 1.4181442252297216*lm + 
          2.056730852547283*lm^2 - 0.7921*lm^3) + 
        CA*(-1.2475501220078056 + 0.9991599652035842*lm - 
          2.208546423443327*lm^2 - 0.4840611111111111*lm^3) + 
        0.05609657990481681*NM + 0.20448599296569736*lm*NM + 
        0.23353268305030186*lm^2*NM + 0.08801111111111111*lm^3*NM + 
        0.8650210654319234*NL + 0.20448599296569736*lm*NL + 
        0.23353268305030186*lm^2*NL + 0.08801111111111111*lm^3*NL - 
        0.3324991587285476*NH + 0.20448599296569736*lm*NH + 
        0.23353268305030186*lm^2*NH + 0.08801111111111111*lm^3*NH)}, 
     {0.785, CF*NC*(CF*(-0.45016728293040603 - 1.4438703959847965*lm + 
          2.0798780431858197*lm^2 - 0.79655625*lm^3) + 
        CA*(-1.2559103393884372 + 1.0276993735840618*lm - 
          2.2138970118031103*lm^2 - 0.486784375*lm^3) + 
        0.05009617168852052*NM + 0.2031064983811012*lm*NM + 
        0.23356025214602005*lm^2*NM + 0.08850625*lm^3*NM + 
        0.8685217404243684*NL + 0.2031064983811012*lm*NL + 
        0.23356025214602005*lm^2*NL + 0.08850625*lm^3*NL - 
        0.3308828371351639*NH + 0.2031064983811012*lm*NH + 
        0.23356025214602005*lm^2*NH + 0.08850625*lm^3*NH)}, 
     {0.79, CF*NC*(CF*(-0.44688104115829896 - 1.4700333908462224*lm + 
          2.103206946469818*lm^2 - 0.801025*lm^3) + 
        CA*(-1.2645415503534099 + 1.0564366070055566*lm - 
          2.2191912410462225*lm^2 - 0.48951527777777776*lm^3) + 
        0.044072992868226225*NM + 0.20171823626830093*lm*NM + 
        0.23357492261446466*lm^2*NM + 0.08900277777777778*lm^3*NM + 
        0.8720443893547772*NL + 0.20171823626830093*lm*NL + 
        0.23357492261446466*lm^2*NL + 0.08900277777777778*lm^3*NL - 
        0.3292290414277374*NH + 0.20171823626830093*lm*NH + 
        0.23357492261446466*lm^2*NH + 0.08900277777777778*lm^3*NH)}, 
     {0.795, CF*NC*(CF*(-0.4434134471089056 - 1.4966364409976491*lm + 
          2.126717793295307*lm^2 - 0.80550625*lm^3) + 
        CA*(-1.273445648993028 + 1.0853703643025874*lm - 2.2244289700695346*
           lm^2 - 0.49225381944444446*lm^3) + 0.038027272164042496*NM + 
        0.2003214758548022*lm*NM + 0.23357666880052141*lm^2*NM + 
        0.08950069444444445*lm^3*NM + 0.8755891094331072*NL + 
        0.2003214758548022*lm*NL + 0.23357666880052141*lm^2*NL + 
        0.08950069444444445*lm^3*NL - 0.32753784150284143*NH + 
        0.2003214758548022*lm*NH + 0.23357666880052141*lm^2*NH + 
        0.08950069444444445*lm^3*NH)}, 
     {0.8, CF*NC*(CF*(-0.43976056700477134 - 1.5236827604876688*lm + 
          2.150410813183546*lm^2 - 0.81*lm^3) + 
        CA*(-1.2826245017603353 + 1.1144993507713548*lm - 
          2.229610058610055*lm^2 - 0.495*lm^3) + 0.03195923378902353*NM + 
        0.19891648499884762*lm*NM + 0.2335654652018282*lm^2*NM + 
        0.09*lm^3*NM + 0.8791559944568237*NL + 0.19891648499884762*lm*NL + 
        0.2335654652018282*lm^2*NL + 0.09*lm^3*NL - 0.32580930824909016*
         NH + 0.19891648499884762*lm*NH + 0.2335654652018282*lm^2*NH + 
        0.09*lm^3*NH)}, {0.805, 
      CF*NC*(CF*(-0.4359184578160789 - 1.5511755464422117*lm + 
          2.174286234303453*lm^2 - 0.81450625*lm^3) + 
        CA*(-1.2920799479182397 + 1.1438222781053553*lm - 
          2.234734367231223*lm^2 - 0.49775381944444447*lm^3) + 
        0.02586909751912133*NM + 0.19750353020429492*lm*NM + 
        0.23354128646628303*lm^2*NM + 0.09050069444444445*lm^3*NM + 
        0.8827451348685009*NL + 0.19750353020429492*lm*NL + 
        0.23354128646628303*lm^2*NL + 0.09050069444444445*lm^3*NL - 
        0.32404351353359573*NH + 0.19750353020429492*lm*NH + 
        0.23354128646628303*lm^2*NH + 0.09050069444444445*lm^3*NH)}, 
     {0.81, CF*NC*(CF*(-0.4318831675896479 - 1.5791179792735999*lm + 
          2.198344283493523*lm^2 - 0.819025*lm^3) + 
        CA*(-1.3018137999775878 + 1.1733378643315613*lm - 
          2.2398017573095137*lm^2 - 0.5005152777777778*lm^3) + 
        0.019757078761729115*NM + 0.19608287663532023*lm*NM + 
        0.23350410738960853*lm^2*NM + 0.09100277777777778*lm^3*NM + 
        0.8863566178121977*NL + 0.19608287663532023*lm*NL + 
        0.23350410738960853*lm^2*NL + 0.09100277777777778*lm^3*NL - 
        0.32224053018870064*NH + 0.19608287663532023*lm*NH + 
        0.23350410738960853*lm^2*NH + 0.09100277777777778*lm^3*NH)}, 
     {0.815, CF*NC*(CF*(-0.42765073576784396 - 1.6075132228863156*lm + 
          2.2225851862832604*lm^2 - 0.82355625*lm^3) + 
        CA*(-1.311827844126402 + 1.2030448337471737*lm - 2.244812091021341*
           lm^2 - 0.503284375*lm^3) + 0.013623388622849578*NM + 
        0.1946547881309481*lm*NM + 0.23345390291297108*lm^2*NM + 
        0.09150625*lm^3*NM + 0.8899905271886379*NL + 0.1946547881309481*lm*
         NL + 0.23345390291297108*lm^2*NL + 0.09150625*lm^3*NL - 
        0.3204004319989776*NH + 0.1946547881309481*lm*NH + 
        0.23345390291297108*lm^2*NH + 0.09150625*lm^3*NH)}, 
     {0.82, CF*NC*(CF*(-0.4232171934977278 - 1.6363644248795335*lm + 
          2.247009166914123*lm^2 - 0.8281*lm^3) + 
        CA*(-1.3221238406504796 + 1.2329419168569506*lm - 
          2.2497652313302585*lm^2 - 0.5060611111111111*lm^3) + 
        0.007468233972920718*NM + 0.19321952721940858*lm*NM + 
        0.23339064812065302*lm^2*NM + 0.09201111111111111*lm^3*NM + 
        0.8936469437092266*NL + 0.19321952721940858*lm*NL + 
        0.23339064812065302*lm^2*NL + 0.09201111111111111*lm^3*NL - 
        0.3185232936884901*NH + 0.19321952721940858*lm*NH + 
        0.23339064812065302*lm^2*NH + 0.09201111111111111*lm^3*NH)}, 
     {0.825, CF*NC*(CF*(-0.4185785639307639 - 1.665674716746477*lm + 
          2.2716164483600063*lm^2 - 0.83265625*lm^3) + 
        CA*(-1.3327035243455576 + 1.2630278503111179*lm - 
          2.254661041974441*lm^2 - 0.5088454861111111*lm^3) + 
        0.0012918175113310745*NM + 0.19177735513232258*lm*NM + 
        0.2333143182377771*lm^2*NM + 0.09251736111111111*lm^3*NM + 
        0.8973259449489281*NL + 0.19177735513232258*lm*NL + 
        0.2333143182377771*lm^2*NL + 0.09251736111111111*lm^3*NL - 
        0.31660919090830736*NH + 0.19177735513232258*lm*NH + 
        0.2333143182377771*lm^2*NH + 0.09251736111111111*lm^3*NH)}, 
     {0.83, CF*NC*(CF*(-0.41373086251339536 - 1.6954472140706451*lm + 
          2.2964072523472705*lm^2 - 0.837225*lm^3) + 
        CA*(-1.3435686049212352 + 1.2933013768438644*lm - 
          2.259499387454446*lm^2 - 0.5116375*lm^3) - 0.004905662170344655*
         NM + 0.19032853181871676*lm*NM + 0.23322488862808108*lm^2*NM + 
        0.093025*lm^3*NM + 0.9010276053980366*NL + 0.19032853181871676*lm*
         NL + 0.23322488862808108*lm^2*NL + 0.093025*lm^3*NL - 
        0.3146582002242666*NH + 0.19032853181871676*lm*NH + 
        0.23322488862808108*lm^2*NH + 0.093025*lm^3*NH)}, 
     {0.835, CF*NC*(CF*(-0.40867009726878323 - 1.7256850167189652*lm + 
          2.3213817993743238*lm^2 - 0.84180625*lm^3) + 
        CA*(-1.3547207673968433 + 1.3237612452124252*lm - 
          2.2642801330212468*lm^2 - 0.5144371527777778*lm^3) - 
        0.011124010526359378*NM + 0.18887331595886872*lm*NM + 
        0.23312233479174183*lm^2*NM + 0.09353402777777778*lm^3*NM + 
        0.9047519965128642*NL + 0.18887331595886872*lm*NL + 
        0.23312233479174183*lm^2*NL + 0.09353402777777778*lm^3*NL - 
        0.3126703991049769*NH + 0.18887331595886872*lm*NH + 
        0.23312233479174183*lm^2*NH + 0.09353402777777778*lm^3*NH)}, 
     {0.84, CF*NC*(CF*(-0.40339226906999626 - 1.7563912090319236*lm + 
          2.3465403087307766*lm^2 - 0.8464*lm^3) + 
        CA*(-1.3661616724894465 + 1.354406210136756*lm - 2.2690031446645254*
           lm^2 - 0.5172444444444444*lm^3) - 0.01736303699602741*NM + 
        0.18741196497798399*lm*NM + 0.23300663236324706*lm^2*NM + 
        0.09404444444444444*lm^3*NM + 0.9084991867653748*NL + 
        0.18741196497798399*lm*NL + 0.23300663236324706*lm^2*NL + 
        0.09404444444444444*lm^3*NL - 0.3106458659100581*NH + 
        0.18741196497798399*lm*NH + 0.23300663236324706*lm^2*NH + 
        0.09404444444444444*lm^3*NH)}, 
     {0.845, CF*NC*(CF*(-0.3978933719049276 - 1.7875688600107205*lm + 
          2.3718829985161745*lm^2 - 0.85100625*lm^3) + 
        CA*(-1.3778929569941565 + 1.3852350322397984*lm - 
          2.2736682891012268*lm^2 - 0.520059375*lm^3) - 
        0.02362255494414967*NM + 0.18594473505970588*lm*NM + 
        0.23287775710931394*lm^2*NM + 0.09455625*lm^3*NM + 
        0.912269241691788*NL + 0.18594473505970588*lm*NL + 
        0.23287775710931394*lm^2*NL + 0.09455625*lm^3*NL - 
        0.3085846798786091*NH + 0.18594473505970588*lm*NH + 
        0.23287775710931394*lm^2*NH + 0.09455625*lm^3*NH)}, 
     {0.85, CF*NC*(CF*(-0.39216939313320587 - 1.8192210235015045*lm + 
          2.397410085658324*lm^2 - 0.855625*lm^3) + 
        CA*(-1.389916234156933 + 1.4162464779883404*lm - 2.2782754337643576*
           lm^2 - 0.5228819444444445*lm^3) - 0.0299023816026024*NM + 
        0.18447188115945973*lm*NM + 0.2327356849268529*lm^2*NM + 
        0.09506944444444444*lm^3*NM + 0.9160622239401792*NL + 
        0.18447188115945973*lm*NL + 0.2327356849268529*lm^2*NL + 
        0.09506944444444444*lm^3*NL - 0.3064869211178999*NH + 
        0.18447188115945973*lm*NH + 0.2327356849268529*lm^2*NH + 
        0.09506944444444444*lm^3*NH)}, 
     {0.855, CF*NC*(CF*(-0.386216313735358 - 1.851350738376731*lm + 
          2.4231217859312166*lm^2 - 0.86025625*lm^3) + 
        CA*(-1.4022330940400436 + 1.44743931963447*lm - 2.2828244467920342*
           lm^2 - 0.5257121527777778*lm^3) - 0.0362023380130623*NM + 
        0.1829936570176324*lm*NM + 0.23258039184097593*lm^2*NM + 
        0.09558402777777777*lm^3*NM + 0.9198781933170991*NL + 
        0.1829936570176324*lm*NL + 0.23258039184097593*lm^2*NL + 
        0.09558402777777777*lm^3*NL - 0.3043526705922811*NH + 
        0.1829936570176324*lm*NH + 0.23258039184097593*lm^2*NH + 
        0.09558402777777777*lm^3*NH)}, 
     {0.86, CF*NC*(CF*(-0.3800301085544728 - 1.8839610287136952*lm + 
          2.44901831397257*lm^2 - 0.8649*lm^3) + 
        CA*(-1.4148451038803467 + 1.4788123351576248*lm - 
          2.287315197016763*lm^2 - 0.52855*lm^3) - 0.04252224897084162*NM + 
        0.1815103151725891*lm*NM + 0.23241185400304779*lm^2*NM + 
        0.0961*lm^3*NM + 0.9237172068332369*NL + 0.1815103151725891*lm*
         NL + 0.23241185400304779*lm^2*NL + 0.0961*lm^3*NL - 
        0.3021820101123068*NH + 0.1815103151725891*lm*NH + 
        0.23241185400304779*lm^2*NH + 0.0961*lm^3*NH)}, 
     {0.865, CF*NC*(CF*(-0.3736067465306058 - 1.9170549039702887*lm + 
          2.475099883300985*lm^2 - 0.86955625*lm^3) + 
        CA*(-1.4277538084405634 + 1.5103643082072364*lm - 
          2.291747553954954*lm^2 - 0.5313954861111111*lm^3) - 
        0.04886194296980747*NM + 0.18002210697352836*lm*NM + 
        0.23223004768877947*lm^2*NM + 0.0966173611111111*lm^3*NM + 
        0.927579318748151*NL + 0.18002210697352836*lm*NL + 
        0.23223004768877947*lm^2*NL + 0.0966173611111111*lm^3*NL - 
        0.29997502232406376*NH + 0.18002210697352836*lm*NH + 
        0.23223004768877947*lm^2*NH + 0.0966173611111111*lm^3*NH)}, 
     {0.87, CF*NC*(CF*(-0.36694219092815683 - 1.9506353591580214*lm + 
          2.5013667063327385*lm^2 - 0.874225*lm^3) + 
        CA*(-1.4409607303536962 + 1.5420940280459685*lm - 
          2.2961213877966595*lm^2 - 0.5342486111111111*lm^3) - 
        0.055221252148360295*NM + 0.17852928259317685*lm*NM + 
        0.23203494929636237*lm^2*NM + 0.09713611111111112*lm^3*NM + 
        0.9314645806140877*NL + 0.17852928259317685*lm*NL + 
        0.23203494929636237*lm^2*NL + 0.09713611111111112*lm^3*NL - 
        0.2977317906987038*NH + 0.17852928259317685*lm*NH + 
        0.23203494929636237*lm^2*NH + 0.09713611111111112*lm^3*NH)}, 
     {0.875, CF*NC*(CF*(-0.36003239955644467 - 1.9847053750123629*lm + 
          2.527818994398217*lm^2 - 0.87890625*lm^3) + 
        CA*(-1.4544673704607454 + 1.574000289493548*lm - 2.3004365693955338*
           lm^2 - 0.537109375*lm^3) - 0.0616000122364471*NM + 
        0.17703209104032555*lm*NM + 0.23182653534464254*lm^2*NM + 
        0.09765625*lm^3*NM + 0.9353730413189115*NL + 0.17703209104032555*lm*
         NL + 0.23182653534464254*lm^2*NL + 0.09765625*lm^3*NL - 
        0.2954523995221728*NH + 0.17703209104032555*lm*NH + 
        0.23182653534464254*lm^2*NH + 0.09765625*lm^3*NH)}, 
     {0.88, CF*NC*(CF*(-0.3528733249836953 - 2.0192679181604394*lm + 
          2.554456957757997*lm^2 - 0.8836*lm^3) + 
        CA*(-1.4682752081418793 + 1.6060818928711909*lm - 
          2.3046929702590018*lm^2 - 0.5399777777777778*lm^3) - 
        0.06799806250358563*NM + 0.17553078017220874*lm*NM + 
        0.23160478247133368*lm^2*NM + 0.09817777777777778*lm^3*NM + 
        0.9393047471281677*NL + 0.17553078017220874*lm*NL + 
        0.23160478247133368*lm^2*NL + 0.09817777777777778*lm^3*NL - 
        0.2931369338851319*NH + 0.17553078017220874*lm*NH + 
        0.23160478247133368*lm^2*NH + 0.09817777777777778*lm^3*NH)}, 
     {0.885, CF*NC*(CF*(-0.3454609147446521 - 2.0543259412861397*lm + 
          2.5812808056185865*lm^2 - 0.88830625*lm^3) + 
        CA*(-1.4823857016412008 + 1.638337643946615*lm - 2.3088904625386415*
           lm^2 - 0.5428538194444444*lm^3) - 0.07441524570787633*NM + 
        0.17402559670672735*lm*NM + 0.23136966743126816*lm^2*NM + 
        0.09870069444444445*lm^3*NM + 0.9432597417262967*NL + 
        0.17402559670672735*lm*NL + 0.23136966743126816*lm^2*NL + 
        0.09870069444444445*lm^3*NL - 0.29078547967306745*NH + 
        0.17402559670672735*lm*NH + 0.23136966743126816*lm^2*NH + 
        0.09870069444444445*lm^3*NH)}, 
     {0.89, CF*NC*(CF*(-0.3377911115420113 - 2.0898823832926685*lm + 
          2.608290746147836*lm^2 - 0.893025*lm^3) + 
        CA*(-1.4968002883852574 + 1.6707663538796467*lm - 
          2.3130289190207667*lm^2 - 0.5457375*lm^3) - 0.08085140804597948*
         NM + 0.17251678623451802*lm*NM + 0.2311211670946849*lm^2*NM + 
        0.099225*lm^3*NM + 0.9472380662570226*NL + 0.17251678623451802*lm*
         NL + 0.2311211670946849*lm^2*NL + 0.099225*lm^3*NL - 
        0.2883981235565828*NH + 0.17251678623451802*lm*NH + 
        0.2311211670946849*lm^2*NH + 0.099225*lm^3*NH)}, 
     {0.895, CF*NC*(CF*(-0.3298598534418754 - 2.125940169462592*lm + 
          2.6354869864900206*lm^2 - 0.89775625*lm^3) + 
        CA*(-1.5115203852954293 + 1.7033668391684094*lm - 
          2.31710821311721*lm^2 - 0.5486288194444444*lm^3) - 
        0.08730639910403569*NM + 0.17100459323087*lm*NM + 
        0.23085925844555327*lm^2*NM + 0.09975069444444444*lm^3*NM + 
        0.9512397593629334*NL + 0.17100459323087*lm*NL + 
        0.23085925844555327*lm^2*NL + 0.09975069444444444*lm^3*NL - 
        0.2859749529818698*NH + 0.17100459323087*lm*NH + 
        0.23085925844555327*lm^2*NH + 0.09975069444444444*lm^3*NH)}, 
     {0.9, CF*NC*(CF*(-0.32166307406341516 - 2.1625022116154207*lm + 
          2.6628697327806097*lm^2 - 0.9025*lm^3) + 
        CA*(-1.5265473890943388 + 1.7361379215960993*lm - 
          2.321128218856294*lm^2 - 0.5515277777777777*lm^3) - 
        0.09378007180950801*NM + 0.1694892610674907*lm*NM + 
        0.23058391857993224*lm^2*NM + 0.10027777777777777*lm^3*NM + 
        0.9552648572242728*NL + 0.1694892610674907*lm*NL + 
        0.23058391857993224*lm^2*NL + 0.10027777777777777*lm^3*NL - 
        0.2835160561613545*NH + 0.1694892610674907*lm*NH + 
        0.23058391857993224*lm^2*NH + 0.10027777777777777*lm^3*NH)}, 
     {0.905, CF*NC*(CF*(-0.3131967027629213 - 2.199571408262766*lm + 
          2.6904391901607276*lm^2 - 0.90725625*lm^3) + 
        CA*(-1.5418826766064067 + 1.769078428178343*lm - 
          2.325088810874*lm^2 - 0.554434375*lm^3) - 0.10027228238392517*NM + 
        0.16797103202412217*lm*NM + 0.2302951247043636*lm^2*NM + 
        0.10080625*lm^3*NM + 0.9593133935969623*NL + 0.16797103202412217*lm*
         NL + 0.2302951247043636*lm^2*NL + 0.10080625*lm^3*NL - 
        0.28102152206451286*NH + 0.16797103202412217*lm*NH + 
        0.2302951247043636*lm^2*NH + 0.10080625*lm^3*NH)}, 
     {0.91, CF*NC*(CF*(-0.3044566648124214 - 2.2371506447611194*lm + 
          2.718195562791312*lm^2 - 0.912025*lm^3) + 
        CA*(-1.55752760505269 + 1.8021871911111318*lm - 2.3289898644053095*
           lm^2 - 0.5573486111111111*lm^3) - 0.10678289029650524*NM + 
        0.1664501473000097*lm*NM + 0.22999285413429868*lm^2*NM + 
        0.10133611111111111*lm^3*NM + 0.9633853998498716*NL + 
        0.1664501473000097*lm*NL + 0.22999285413429868*lm^2*NL + 
        0.10133611111111111*lm^3*NL - 0.27849144040885304*NH + 
        0.1664501473000097*lm*NH + 0.22999285413429868*lm^2*NH + 
        0.10133611111111111*lm^3*NH)}, 
     {0.915, CF*NC*(CF*(-0.2954388815730327 - 2.275242793462286*lm + 
          2.746139053866982*lm^2 - 0.91680625*lm^3) + 
        CA*(-1.5734835123401285 + 1.8354630477193343*lm - 
          2.3328312552757335*lm^2 - 0.5602704861111111*lm^3) - 
        0.11331175821864019*NM + 0.16492684702522434*lm*NM + 
        0.2296770842925576*lm^2*NM + 0.10186736111111111*lm^3*NM + 
        0.9674809050013536*NL + 0.16492684702522434*lm*NL + 
        0.2296770842925576*lm^2*NL + 0.10186736111111111*lm^3*NL - 
        0.27592590165105957*NH + 0.16492684702522434*lm*NH + 
        0.2296770842925576*lm^2*NH + 0.10186736111111111*lm^3*NH)}, 
     {0.92, CF*NC*(CF*(-0.2861392706632151 - 2.3138507138615214*lm + 
          2.7742698656296176*lm^2 - 0.9216*lm^3) + 
        CA*(-1.5897517173453166 + 1.8689048404057795*lm - 
          2.3366128598930116*lm^2 - 0.5632*lm^3) - 0.1198587519792218*NM + 
        0.16340137027184087*lm*NM + 0.22934779270782027*lm^2*NM + 
        0.1024*lm^3*NM + 0.9715999357550636*NL + 0.16340137027184087*lm*
         NL + 0.22934779270782027*lm^2*NL + 0.1024*lm^3*NL - 
        0.27332499697829654*NH + 0.16340137027184087*lm*NH + 
        0.22934779270782027*lm^2*NH + 0.1024*lm^3*NH)}, 
     {0.925, CF*NC*(CF*(-0.27655374612208217 - 2.3529772527434027*lm + 
          2.8025881993816633*lm^2 - 0.92640625*lm^3) + 
        CA*(-1.60633352019293 + 1.9025114166009094*lm - 2.3403345552389836*
           lm^2 - 0.5661371527777778*lm^3) - 0.12642374052079033*NM + 
        0.16187395506497304*lm*NM + 0.22900495701314852*lm^2*NM + 
        0.10293402777777778*lm^3*NM + 0.9757425165350773*NL + 
        0.16187395506497304*lm*NL + 0.22900495701314852*lm^2*NL + 
        0.10293402777777778*lm^3*NL - 0.27068881829966485*NH + 
        0.16187395506497304*lm*NH + 0.22900495701314852*lm^2*NH + 
        0.10293402777777778*lm^3*NH)}, 
     {0.93, CF*NC*(CF*(-0.26667821856792506 - 2.392625244325479*lm + 
          2.8310942554991563*lm^2 - 0.931225*lm^3) + 
        CA*(-1.6232302025289171 + 1.9362816287129974*lm - 
          2.343996218861627*lm^2 - 0.5690819444444445*lm^3) - 
        0.13300659585648741*NM + 0.16034483839366734*lm*NM + 
        0.22864855494453817*lm^2*NM + 0.10346944444444445*lm^3*NM + 
        0.9799086695203238*NL + 0.16034483839366734*lm*NL + 
        0.22864855494453817*lm^2*NL + 0.10346944444444445*lm^3*NL - 
        0.2680174582378108*NH + 0.16034483839366734*lm*NH + 
        0.22864855494453817*lm^2*NH + 0.10346944444444445*lm^3*NH)}, 
     {0.935, CF*NC*(CF*(-0.25650859535209686 - 2.4327975103997366*lm + 
          2.859788233444492*lm^2 - 0.93605625*lm^3) + 
        CA*(-1.6404430277885746 + 1.970214334078927*lm - 2.347597728867255*
           lm^2 - 0.572034375*lm^3) - 0.13960719302779526*NM + 
        0.1588142562216574*lm*NM + 0.2282785643395009*lm^2*NM + 
        0.10400625*lm^3*NM + 0.9840984146783522*NL + 0.1588142562216574*lm*
         NL + 0.2282785643395009*lm^2*NL + 0.10400625*lm^3*NL - 
        0.2653110101206825*NH + 0.1588142562216574*lm*NH + 
        0.2282785643395009*lm^2*NH + 0.10400625*lm^3*NH)}, 
     {0.94, CF*NC*(CF*(-0.24604078070840077 - 2.4734968604719123*lm + 
          2.8886703317789286*lm^2 - 0.9409*lm^3) + 
        CA*(-1.6579732414596158 + 2.0043083949155287*lm - 
          2.351138963912877*lm^2 - 0.5749944444444445*lm^3) - 
        0.1462254100630451*NM + 0.15728244349798026*lm*NM + 
        0.22789496313567462*lm^2*NM + 0.10454444444444444*lm^3*NM + 
        0.9883117697984424*NL + 0.15728244349798026*lm*NL + 
        0.22789496313567462*lm^2*NL + 0.10454444444444444*lm^3*NL - 
        0.2625695679734298*NH + 0.15728244349798026*lm*NH + 
        0.22789496313567462*lm^2*NH + 0.10454444444444444*lm^3*NH)}, 
     {0.945, CF*NC*(CF*(-0.23527067589812128 - 2.5147260918987016*lm + 
          2.9177407481748405*lm^2 - 0.94575625*lm^3) + 
        CA*(-1.6758220713403424 + 2.0385626782714703*lm - 
          2.3546198031987084*lm^2 - 0.5779621527777777*lm^3) - 
        0.15286112793667736*NM + 0.15574963416745632*lm*NM + 
        0.22749772936946216*lm^2*NM + 0.10508402777777778*lm^3*NM + 
        0.9925487505240795*NL + 0.15574963416745632*lm*NL + 
        0.22749772936946216*lm^2*NL + 0.10508402777777778*lm^3*NL - 
        0.2597932265104456*NH + 0.15574963416745632*lm*NH + 
        0.22749772936946216*lm^2*NH + 0.10508402777777778*lm^3*NH)}, 
     {0.95, CF*NC*(CF*(-0.22419417935083233 - 2.5564879900228856*lm + 
          2.9469996794277247*lm^2 - 0.950625*lm^3) + 
        CA*(-1.6939907277930275 + 2.072976055979696*lm - 2.358040126460835*
           lm^2 - 0.5809375*lm^3) - 0.15951423052923744*NM + 
        0.15421606118103476*lm*NM + 0.22708684117469724*lm^2*NM + 
        0.105625*lm^3*NM + 0.9968093703848047*NL + 0.15421606118103476*lm*
         NL + 0.22708684117469724*lm^2*NL + 0.105625*lm^3*NL - 
        0.2569820811275444*NH + 0.15421606118103476*lm*NH + 
        0.22708684117469724*lm^2*NH + 0.105625*lm^3*NH)}, 
     {0.955, CF*NC*(CF*(-0.21280718680111185 - 2.598785328306421*lm + 
          2.976447321467966*lm^2 - 0.95550625*lm^3) + 
        CA*(-1.7124804039926085 + 2.1075474046104095*lm - 
          2.3613998139640207*lm^2 - 0.5839204861111111*lm^3) - 
        0.1661846045880906*NM + 0.1526819565060056*lm*NM + 
        0.2266622767813371*lm^2*NM + 0.10616736111111111*lm^3*NM + 
        1.0010936408274558*NL + 0.1526819565060056*lm*NL + 
        0.2266622767813371*lm^2*NL + 0.10616736111111111*lm^3*NL - 
        0.254136227894275*NH + 0.1526819565060056*lm*NH + 
        0.2266622767813371*lm^2*NH + 0.10616736111111111*lm^3*NH)}, 
     {0.96, CF*NC*(CF*(-0.2011055914212886 - 2.641620868461525*lm + 
          3.0060838693723677*lm^2 - 0.9604*lm^3) + 
        CA*(-1.731292276170798 + 2.1422756054245995*lm - 2.364698746494664*
           lm^2 - 0.5869111111111112*lm^3) - 0.17287213968884063*NM + 
        0.15114755113608053*lm*NM + 0.22622401451418134*lm^2*NM + 
        0.10671111111111112*lm^3*NM + 1.0054015712468138*NL + 
        0.15114755113608053*lm*NL + 0.22622401451418134*lm^2*NL + 
        0.10671111111111112*lm^3*NL - 0.25125576354636503*NH + 
        0.15114755113608053*lm*NH + 0.22622401451418134*lm^2*NH + 
        0.10671111111111112*lm^3*NH)}, 
     {0.965, CF*NC*(CF*(-0.18908528395034216 - 2.6849973605797888*lm + 
          3.035909517375454*lm^2 - 0.96530625*lm^3) + 
        CA*(-1.750427503855707 + 2.1771595443280987*lm - 2.367936805353889*
           lm^2 - 0.589909375*lm^3) - 0.17957672819743659*NM + 
        0.14961307510134378*lm*NM + 0.22577203279161626*lm^2*NM + 
        0.10725625*lm^3*NM + 1.009733169015666*NL + 0.14961307510134378*lm*
         NL + 0.22577203279161626*lm^2*NL + 0.10725625*lm^3*NL - 
        0.24834078547829364*NH + 0.14961307510134378*lm*NH + 
        0.22577203279161626*lm^2*NH + 0.10725625*lm^3*NH)}, 
     {0.97, CF*NC*(CF*(-0.17674215281907385 - 2.7289175432593518*lm + 
          3.065924458880545*lm^2 - 0.970225*lm^3) + 
        CA*(-1.7698872301070772 + 2.2121981118261753*lm - 
          2.371113872350778*lm^2 - 0.5929152777777777*lm^3) - 
        0.1862982652329526*NM + 0.14807875747807486*lm*NM + 
        0.2253063101243839*lm^2*NM + 0.10780277777777778*lm^3*NM + 
        1.0140884395143013*NL + 0.14807875747807486*lm*NL + 
        0.2253063101243839*lm^2*NL + 0.10780277777777778*lm^3*NL - 
        0.2453913917359891*NH + 0.14807875747807486*lm*NH + 
        0.2253063101243839*lm^2*NH + 0.10780277777777778*lm^3*NH)}, 
     {0.975, CF*NC*(CF*(-0.16407208427166178 - 2.773384143730175*lm + 
          3.0961288864706193*lm^2 - 0.97515625*lm^3) + 
        CA*(-1.78967258174722 + 2.2473902029786497*lm - 2.3742298297957327*
           lm^2 - 0.5959288194444444*lm^3) - 0.1930366486310266*NM + 
        0.1465448263984447*lm*NM + 0.22482682511437566*lm^2*NM + 
        0.10835069444444445*lm^3*NM + 1.0184673861594502*NL + 
        0.1465448263984447*lm*NL + 0.22482682511437566*lm^2*NL + 
        0.10835069444444445*lm^3*NL - 0.24240768100964957*NH + 
        0.1465448263984447*lm*NH + 0.22482682511437566*lm^2*NH + 
        0.10835069444444445*lm^3*NH)}, 
     {0.98, CF*NC*(CF*(-0.15107096248370996 - 2.81839987797744*lm + 
          3.1265229919189577*lm^2 - 0.9801*lm^3) + 
        CA*(-1.8097846695877495 + 2.2827347173555355*lm - 
          2.3772845604939703*lm^2 - 0.59895*lm^3) - 0.19979177890794325*NM + 
        0.14501150906008647*lm*NM + 0.22433355645344916*lm^2*NM + 
        0.1089*lm^3*NM + 1.022870010432679*NL + 0.14501150906008647*lm*
         NL + 0.22433355645344916*lm^2*NL + 0.1089*lm^3*NL - 
        0.23938975262668358*NH + 0.14501150906008647*lm*NH + 
        0.22433355645344916*lm^2*NH + 0.1089*lm^3*NH)}, 
     {0.985, CF*NC*(CF*(-0.1377346696768979 - 2.863967450863109*lm + 
          3.1571069661995805*lm^2 - 0.98505625*lm^3) + 
        CA*(-1.8302245886522022 + 2.3182305589931937*lm - 
          2.380277947739145*lm^2 - 0.6019788194444444*lm^3) - 
        0.20656355922534744*NM + 0.1434790317355435*lm*NM + 
        0.2238264829222688*lm^2*NM + 0.10945069444444444*lm^3*NM + 
        1.0272963119082559*NL + 0.1434790317355435*lm*NL + 
        0.2238264829222688*lm^2*NL + 0.10945069444444444*lm^3*NL - 
        0.23633770654476738*NH + 0.1434790317355435*lm*NH + 
        0.2238264829222688*lm^2*NH + 0.10945069444444444*lm^3*NH)}, 
     {0.99, CF*NC*(CF*(-0.12405908623033308 - 2.910089556245677*lm + 
          3.1878809994974837*lm^2 - 0.990025*lm^3) + 
        CA*(-1.8509934183946308 + 2.353876636351004*lm - 2.3832098753070934*
           lm^2 - 0.6050152777777777*lm^3) - 0.21335189535557478*NM + 
        0.14194761978159476*lm*NM + 0.22330558338916848*lm^2*NM + 
        0.11000277777777778*lm^3*NM + 1.0317462882804949*NL + 
        0.14194761978159476*lm*NL + 0.22330558338916848*lm^2*NL + 
        0.11000277777777778*lm^3*NL - 0.23325164334501705*NH + 
        0.14194761978159476*lm*NH + 0.22330558338916848*lm^2*NH + 
        0.11000277777777778*lm^3*NH)}, 
     {0.995, CF*NC*(CF*(-0.11004009078870636 - 2.9567688770981415*lm + 
          3.2188452812186714*lm^2 - 0.99500625*lm^3) + 
        CA*(-1.8720922229142571 + 2.389671862268535*lm - 2.3860802274497006*
           lm^2 - 0.608059375*lm^3) - 0.2201566956475858*NM + 
        0.14041749764846048*lm*NM + 0.22277083680903648*lm^2*NM + 
        0.11055625*lm^3*NM + 1.0362199353905932*NL + 0.14041749764846048*lm*
         NL + 0.22277083680903648*lm^2*NL + 0.11055625*lm^3*NL - 
        0.2301316642252725*NH + 0.14041749764846048*lm*NH + 
        0.22277083680903648*lm^2*NH + 0.11055625*lm^3*NH)}, 
     {1., -3.007364054733763*(CA - 2.*CF)*CF*NC + 0.001388888888888889*CF*NC*
        (CF*(-4399.489202281107 - 2162.8858216494473*lm + 2340.*lm^2 - 
           720.*lm^3) - 2.*CA*(-400.9831212842988 - 873.2214554123618*lm + 
           860.*lm^2 + 220.*lm^3) + 20.*((-8.17120335576568 + 5.*lm + 
             8.*lm^2 + 4.*lm^3)*NM + (37.465820901107016 + 5.*lm + 8.*lm^2 + 
             4.*lm^3)*NL + (-8.17120335576568 + 5.*lm + 8.*lm^2 + 4.*lm^3)*
            NH))}}
 
CbarTable["a", 2, 0] = {{0., 4.2866941015089165*^-6*CF*NC*
       (4.*CA*(-4566.775197079015 - 38047.87780943795*lm - 8910.*lm^2) - 
        3.*(CF*(-22820.768994014612 - 29160.*lm) - 
          80.*((74.38940068102023 + 51.47841760435743*lm + 27.*lm^2)*NM + 
            (74.38940068102023 + 51.47841760435743*lm + 27.*lm^2)*NL + 
            (-42.00116934067009 + 51.47841760435743*lm + 27.*lm^2)*NH)))}, 
     {0.005, CF*NC*(CF*(0.2864628059512532 + 0.375*lm) + 
        CA*(-0.09655903284753531 - 0.6609951080085179*lm - 
          0.1527777777777778*lm^2) + 0.07845122986123806*NM + 
        0.054524363072255784*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.07846079812492528*NL + 0.054524363072255784*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.04413965770811651*NH + 
        0.054524363072255784*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.01, CF*NC*(CF*(0.28006640799913474 + 0.375*lm) + 
        CA*(-0.11443499807302017 - 0.6695547186483333*lm - 
          0.1527777777777778*lm^2) + 0.08028750099012931*NM + 
        0.056080655915858584*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08032932356835018*NL + 0.056080655915858584*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.0450715900219818*NH + 
        0.056080655915858584*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.015, CF*NC*(CF*(0.27442589732607736 + 0.375*lm) + 
        CA*(-0.13177823184214274 - 0.6780345382964411*lm - 
          0.1527777777777778*lm^2) + 0.08201644395696375*NM + 
        0.05762244130642363*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08211631346124425*NL + 0.05762244130642363*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.046005609248017075*NH + 
        0.05762244130642363*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.02, CF*NC*(CF*(0.2695674027486648 + 0.375*lm) + 
        CA*(-0.14851441965798945 - 0.6864083406402615*lm - 
          0.1527777777777778*lm^2) + 0.08362709150580669*NM + 
        0.059144950823481875*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08381245443381888*NL + 0.059144950823481875*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.04694071110112006*NH + 
        0.059144950823481875*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.025, CF*NC*(CF*(0.2654786664360526 + 0.375*lm) + 
        CA*(-0.16460382385591418 - 0.6946581128098948*lm - 
          0.1527777777777778*lm^2) + 0.08511430373591339*NM + 
        0.060644909399778846*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08541346004438198*NL + 0.060644909399778846*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.04787605046295858*NH + 
        0.060644909399778846*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.03, CF*NC*(CF*(0.2621302586609443 + 0.375*lm) + 
        CA*(-0.18002601473352473 - 0.702770955907594*lm - 
          0.1527777777777778*lm^2) + 0.08647616296658284*NM + 
        0.0621199717811787*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0869177492622917*NL + 0.0621199717811787*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.04881089656694797*NH + 
        0.0621199717811787*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.035, CF*NC*(CF*(0.2594846128234991 + 0.375*lm) + 
        CA*(-0.19477258833218264 - 0.7107374802747798*lm - 
          0.1527777777777778*lm^2) + 0.08771273002771342*NM + 
        0.06356843075703068*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08832536340055046*NL + 0.06356843075703068*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.04974460732986522*NH + 
        0.06356843075703068*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.04, CF*NC*(CF*(0.25750053055280125 + 0.375*lm) + 
        CA*(-0.20884309667929737 - 0.7185508446414154*lm - 
          0.1527777777777778*lm^2) + 0.08882534925198605*NM + 
        0.06498904246005532*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.08963737337175368*NL + 0.06498904246005532*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.050676612609260985*NH + 
        0.06498904246005532*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.045, CF*NC*(CF*(0.25613562877447904 + 0.375*lm) + 
        CA*(-0.22224254868923193 - 0.7262061282829039*lm - 
          0.1527777777777778*lm^2) + 0.08981622231525727*NM + 
        0.06638091221305321*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0908555232334791*NL + 0.06638091221305321*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.051606402383728864*NH + 
        0.06638091221305321*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.05, CF*NC*(CF*(0.255347733613711 + 0.375*lm) + 
        CA*(-0.23497977586397345 - 0.7336998958338683*lm - 
          0.1527777777777778*lm^2) + 0.0906881303945941*NM + 
        0.06774341540413767*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0919820020291318*NL + 0.06774341540413767*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.05253351794641347*NH + 
        0.06774341540413767*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.055, CF*NC*(CF*(0.2550956910728307 + 0.375*lm) + 
        CA*(-0.24706631450041422 - 0.7410298824986649*lm - 
          0.1527777777777778*lm^2) + 0.09144424505050613*NM + 
        0.0690761402522825*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09301929119910098*NL + 0.0690761402522825*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.053457545081138244*NH + 
        0.0690761402522825*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.06, CF*NC*(CF*(0.25533983642172237 + 0.375*lm) + 
        CA*(-0.25851561530955625 - 0.7481947588919113*lm - 
          0.1527777777777778*lm^2) + 0.09208799541066465*NM + 
        0.07037884505105457*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09397005923018974*NL + 0.07037884505105457*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.054378108614801385*NH + 
        0.07037884505105457*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.065, CF*NC*(CF*(0.2560422559140015 + 0.375*lm) + 
        CA*(-0.2693424702477297 - 0.7551939508919926*lm - 
          0.1527777777777778*lm^2) + 0.09262297272028701*NM + 
        0.07165142541470573*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09483708719934557*NL + 0.07165142541470573*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.05529486796557553*NH + 
        0.07165142541470573*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.07, CF*NC*(CF*(0.2571669186562901 + 0.375*lm) + 
        CA*(-0.2795625887167761 - 0.7620274988371277*lm - 
          0.1527777777777778*lm^2) + 0.09305286057905275*NM + 
        0.07289388867745757*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09562321525173377*NL + 0.07289388867745757*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.0562075134358979*NH + 
        0.07289388867745757*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.075, CF*NC*(CF*(0.25867972588053595 + 0.375*lm) + 
        CA*(-0.28919227949597 - 0.7686959456582233*lm - 0.1527777777777778*
           lm^2) + 0.09338138333830646*NM + 0.0741063335540204*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09633130367236868*NL + 
        0.0741063335540204*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.057115763077822276*NH + 0.0741063335540204*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.08, CF*NC*(CF*(0.2605485072558575 + 0.375*lm) + 
        CA*(-0.2982482093141538 - 0.7752002467951129*lm - 
          0.1527777777777778*lm^2) + 0.09361226763337956*NM + 
        0.0752889337607276*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09696420436806927*NL + 0.0752889337607276*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.05801936000827985*NH + 
        0.0752889337607276*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.085, CF*NC*(CF*(0.26274298331262075 + 0.375*lm) + 
        CA*(-0.3067472180805089 - 0.7815416968342317*lm - 
          0.1527777777777778*lm^2) + 0.09374921359536817*NM + 
        0.076441924676931*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09752473991702391*NL + 0.076441924676931*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.058918070084823165*NH + 
        0.076441924676931*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.09, CF*NC*(CF*(0.26523470650135367 + 0.375*lm) + 
        CA*(-0.31470617669937073 - 0.78772186919678*lm - 0.1527777777777778*
           lm^2) + 0.09379587330633529*NM + 0.07756559237921253*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09801568820548386*NL + 
        0.07756559237921253*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.05981167987497128*NH + 0.07756559237921253*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.095, CF*NC*(CF*(0.26799698923359033 + 0.375*lm) + 
        CA*(-0.3221418773394245 - 0.7937425661585236*lm - 
          0.1527777777777778*lm^2) + 0.09375583474409498*NM + 
        0.07866026455407499*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0984397712422667*NL + 0.07866026455407499*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.06069999486809358*NH + 
        0.07866026455407499*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.1, CF*NC*(CF*(0.2710048245275222 + 0.375*lm) + 
        CA*(-0.3290709487300966 - 0.7996057771504135*lm - 
          0.1527777777777778*lm^2) + 0.09363260993085455*NM + 
        0.07972630291623678*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09879964712979544*NL + 0.07972630291623678*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.061582837890140636*NH + 
        0.07972630291623678*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.105, CF*NC*(CF*(0.27423480306915 + 0.375*lm) + 
        CA*(-0.33550979095072364 - 0.8053136437681806*lm - 
          0.1527777777777778*lm^2) + 0.09342962632834484*NM + 
        0.08076409684673991*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09909790443989122*NL + 0.08076409684673991*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.06246004768987529*NH + 
        0.08076409684673991*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.11, CF*NC*(CF*(0.27766502927449416 + 0.375*lm) + 
        CA*(-0.34147452552975927 - 0.8108684302690692*lm - 
          0.1527777777777778*lm^2) + 0.09315022075685542*NM + 
        0.08177405802871966*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09933705843333109*NL + 0.08177405802871966*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.06333147767149777*NH + 
        0.08177405802871966*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.115, CF*NC*(CF*(0.2812750380990994 + 0.375*lm) + 
        CA*(-0.3469809576532708 - 0.8162724985939962*lm - 
          0.1527777777777778*lm^2) + 0.09279763528633943*NM + 
        0.0827566159059791*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09951954869956851*NL + 0.0827566159059791*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.06419699475330136*NH + 
        0.0827566159059791*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.12, CF*NC*(CF*(0.28504571375990245 + 0.375*lm) + 
        CA*(-0.3520445480063747 - 0.821528287149675*lm - 0.1527777777777778*
           lm^2) + 0.09237501467380521*NM + 0.08371221382519342*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.0996477378934402*NL + 
        0.08371221382519342*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.06505647833565488*NH + 0.08371221382519342*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.125, CF*NC*(CF*(0.2889592111288627 + 0.375*lm) + 
        CA*(-0.35668039231299487 - 0.8266382927353204*lm - 
          0.1527777777777778*lm^2) + 0.09188540501551688*NM + 
        0.08464130574985623*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.099723911320081*NL + 0.08464130574985623*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.06590981936446942*NH + 
        0.08464130574985623*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.13, CF*NC*(CF*(0.2929988802730017 + 0.375*lm) + 
        CA*(-0.3609032070494574 - 0.8316050551147277*lm - 
          0.1527777777777778*lm^2) + 0.0913317533539283*NM + 
        0.08554435345520302*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09975027717504806*NL + 0.08554435345520302*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.06675691947857065*NH + 
        0.08554435345520302*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.135, CF*NC*(CF*(0.2971491944150588 + 0.375*lm) + 
        CA*(-0.36472732012139 - 0.8364311438254483*lm - 0.1527777777777778*
           lm^2) + 0.09071690803391443*NM + 0.08642182412987948*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09972896728892502*NL + 
        0.08642182412987948*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.06759769023121096*NH + 0.08642182412987948*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.14, CF*NC*(CF*(0.3013956814478975 + 0.375*lm) + 
        CA*(-0.36816666553614896 - 0.8411191468886804*lm - 
          0.1527777777777778*lm^2) + 0.09004361964508259*NM + 
        0.0872741883231944*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09966203825802089*NL + 0.0872741883231944*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.06843205237741935*NH + 
        0.0872741883231944*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.145, CF*NC*(CF*(0.30572485903689256 + 0.375*lm) + 
        CA*(-0.3712347812924097 - 0.8456716611408547*lm - 
          0.1527777777777778*lm^2) + 0.08931454241984782*NM + 
        0.0881019181872261*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.099551472867741*NL + 0.0881019181872261*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.06925993522008328*NH + 
        0.0881019181872261*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.15, CF*NC*(CF*(0.31012417327577085 + 0.375*lm) + 
        CA*(-0.3739448098575769 - 0.8500912839540534*lm - 
          0.1527777777777778*lm^2) + 0.0885322359827991*NM + 
        0.08890548597144406*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09939918173462477*NL + 0.08890548597144406*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.07008127600863917*NH + 
        0.08890548597144406*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.155, CF*NC*(CF*(0.3145819408142885 + 0.375*lm) + 
        CA*(-0.37630950072179675 - 0.8543806061498324*lm - 
          0.1527777777777778*lm^2) + 0.08769916736732455*NM + 
        0.08968536273431296*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09920700510825516*NL + 0.08968536273431296*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.07089601938506544*NH + 
        0.08968536273431296*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.16, CF*NC*(CF*(0.319087294344672 + 0.375*lm) + 
        CA*(-0.3783412146116395 - 0.8585422059415844*lm - 
          0.1527777777777778*lm^2) + 0.086817713231733*NM + 
        0.09044201724190422*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09897671478623496*NL + 0.09044201724190422*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.07170411687255283*NH + 
        0.09044201724190422*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.165, CF*NC*(CF*(0.32363013131358775 + 0.375*lm) + 
        CA*(-0.3800519290222438 - 0.862578643765713*lm - 0.1527777777777778*
           lm^2) + 0.08589016222013461*NM + 0.09117591502810943*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.09871001610492929*NL + 
        0.09117591502810943*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.072505526402801*NH + 0.09117591502810943*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.17, CF*NC*(CF*(0.3282010657144059 + 0.375*lm) + 
        CA*(-0.38145324478788684 - 0.8664924578826735*lm - 
          0.1527777777777778*lm^2) + 0.08491871742382223*NM + 
        0.09188751759482951*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0984085499762464*NL + 0.09188751759482951*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.07330021187837658*NH + 
        0.09188751759482951*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.175, CF*NC*(CF*(0.3327913828084045 + 0.375*lm) + 
        CA*(-0.3825563934606132 - 0.8702861606462254*lm - 
          0.1527777777777778*lm^2) + 0.08390549890736519*NM + 
        0.09257728173365715*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09807389494678934*NL + 0.09257728173365715*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.07408814276698125*NH + 
        0.09257728173365715*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.18, CF*NC*(CF*(0.33739299662165617 + 0.375*lm) + 
        CA*(-0.3833722453070806 - 0.8739622353537029*lm - 
          0.1527777777777778*lm^2) + 0.08285254627050084*NM + 
        0.0932456589531985*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09770756926057939*NL + 0.0932456589531985*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.07486929372483343*NH + 
        0.0932456589531985*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.185, CF*NC*(CF*(0.34199841006542675 + 0.375*lm) + 
        CA*(-0.3839113177669888 - 0.8775231336022522*lm - 
          0.1527777777777778*lm^2) + 0.08176182122250739*NM + 
        0.09389309499838928*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09731103291047694*NL + 0.09389309499838928*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.0756436442466726*NH + 
        0.09389309499838928*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.19, CF*NC*(CF*(0.34660067753109436 + 0.375*lm) + 
        CA*(-0.3841837842437741 - 0.8809712730862465*lm - 
          0.1527777777777778*lm^2) + 0.08063521015031477*NM + 
        0.0945200294500246*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09688568966659791*NL + 0.0945200294500246*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.07641117834015931*NH + 
        0.0945200294500246*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.195, CF*NC*(CF*(0.35119336981520577 + 0.375*lm) + 
        CA*(-0.3841994831208059 - 0.8843090357797744*lm - 
          0.1527777777777778*lm^2) + 0.07947452666535716*NM + 
        0.09512689539430241*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.09643288907259491*NL + 0.09512689539430241*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.077171884222674*NH + 
        0.09512689539430241*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.2, NC*(CF^2*(0.35577054123563523 + 0.375*lm) + 
        CA*CF*(-0.3839679269148987 - 0.8875387664555031*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.07828151411685307 + 0.09571411915352582*lm + 
            0.027777777777777776*lm^2)*NM + (0.095953928402758 + 
            0.09571411915352582*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0779257540387182 + 0.09571411915352582*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.205, NC*(CF^2*(0.360326698807069 + 0.375*lm) + 
        CA*CF*(-0.3834983114950328 - 0.8906627714975308*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.07705784806396962 + 0.09628212007025813*lm + 
            0.027777777777777776*lm^2)*NM + (0.09545005457458683 + 
            0.09628212007025813*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.07867278359629765 + 0.09628212007025813*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.21, NC*(CF^2*(0.3648567733476032 + 0.375*lm) + 
        CA*CF*(-0.38279952530564965 - 0.8936833179712635*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0758051386956392 + 0.09683131033820953*lm + 
            0.027777777777777776*lm^2)*NM + (0.094922466012864 + 
            0.09683131033820953*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.07941297212082181 + 0.09683131033820953*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.215, NC*(CF^2*(0.3693560923989888 + 0.375*lm) + 
        CA*CF*(-0.38188015854675944 - 0.8966026329180102*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.07452493319697082 + 0.09736209487398166*lm + 
            0.027777777777777776*lm^2)*NM + (0.09437231446238194 + 
            0.09736209487398166*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08014632202519065 + 0.09736209487398166*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.22, NC*(CF^2*(0.3738203548459443 + 0.375*lm) + 
        CA*CF*(-0.38074851227026846 - 0.8994229028460057*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.073218718055027 + 0.09787487122452629*lm + 
            0.027777777777777776*lm^2)*NM + (0.09380070674738634 + 
            0.09787487122452629*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08087283869486117 + 0.09787487122452629*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.225, NC*(CF^2*(0.37824560712832755 + 0.375*lm) + 
        CA*CF*(-0.3794126073604464 - 0.9021462733930496*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.07188792130204702 + 0.098370029505807*lm + 
            0.027777777777777776*lm^2)*NM + (0.09320870647654016 + 
            0.098370029505807*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08159253028679349 + 0.098370029505807*lm + 0.027777777777777776*
             lm^2)*NH))}, {0.23, NC*(CF^2*(0.38262822094565135 + 0.375*lm) + 
        CA*CF*(-0.3778801933724901 - 0.9047748491389646*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.07053391469386722 + 0.09884795236870063*lm + 
            0.027777777777777776*lm^2)*NM + (0.09259733569281003 + 
            0.09884795236870063*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08230540754127305 + 0.09884795236870063*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.235, NC*(CF^2*(0.38696487235964877 + 0.375*lm) + 
        CA*CF*(-0.3761587572085417 - 0.9073106935486955*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.06915801582226402 + 0.0993090149886517*lm + 
            0.027777777777777776*lm^2)*NM + (0.09196757646816194 + 
            0.0993090149886517*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08301148360569026 + 0.0993090149886517*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.24, NC*(CF^2*(0.39125252220607964 + 0.375*lm) + 
        CA*CF*(-0.3742555316148249 - 0.909755829029163*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.06776149016057466 + 0.09975358507600943*lm + 
            0.027777777777777776*lm^2)*NM + (0.09132037244334001 + 
            0.09975358507600943*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0837107738694374 + 0.09975358507600943*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.245, NC*(CF^2*(0.39548839773284794 + 0.375*lm) + 
        CA*CF*(-0.37217750348749196 - 0.9121122370849731*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.06634555304249233 + 0.10018202290433856*lm + 
            0.027777777777777776*lm^2)*NM + (0.09065663031331361 + 
            0.10018202290433856*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08440329580915097 + 0.10018202290433856*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.25, NC*(CF^2*(0.399669975386405 + 0.375*lm) + 
        CA*CF*(-0.36993142197775475 - 0.9143818585598393*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.06491137157435002 + 0.10059468135431424*lm + 
            0.027777777777777776*lm^2)*NM + (0.08997722125922251 + 
            0.10059468135431424*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08508906884359023 + 0.10059468135431424*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.255, NC*(CF^2*(0.4037949646734907 + 0.375*lm) + 
        CA*CF*(-0.3675238063895749 - 0.9165665939520998*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.06346006648156091 + 0.10099190597108886*lm + 
            0.027777777777777776*lm^2)*NM + (0.08928298232784297 + 
            0.10099190597108886*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08576811419749937 + 0.10099190597108886*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.26, NC*(CF^2*(0.40786129302985835 + 0.375*lm) + 
        CA*CF*(-0.3649609538653645 - 0.9186683037940637*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.061992713890157286 + 0.10137403503326411*lm + 
            0.027777777777777776*lm^2)*NM + (0.08857471775974489 + 
            0.10137403503326411*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08644045477385187 + 0.10137403503326411*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.265, NC*(CF^2*(0.411867091631974 + 0.375*lm) + 
        CA*CF*(-0.36224894685697623 - 0.9206888090861033*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0605103470445965 + 0.10174139963181676*lm + 
            0.027777777777777776*lm^2)*NM + (0.08785320026742326 + 
            0.10174139963181676*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08710611503392135 + 0.10174139963181676*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.27, NC*(CF^2*(0.41581068209174604 + 0.375*lm) + 
        CA*CF*(-0.3593936603807719 - 0.9226298917774526*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05901395796316882 + 0.10209432375751663*lm + 
            0.027777777777777776*lm^2)*NM + (0.08711917226476802 + 
            0.10209432375751663*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08776512088466615 + 0.10209432375751663*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.275, NC*(CF^2*(0.4196905639781462 + 0.375*lm) + 
        CA*CF*(-0.356400769056814 - 0.9244932952865983*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05750449903248454 + 0.10243312439554314*lm + 
            0.027777777777777776*lm^2)*NM + (0.08637334704929507 + 
            0.10243312439554314*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08841749957295263 + 0.10243312439554314*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.28, NC*(CF^2*(0.42350540311309925 + 0.375*lm) + 
        CA*CF*(-0.3532757539332322 - 0.9262807250549613*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05598288454260924 + 0.10275811162615457*lm + 
            0.027777777777777776*lm^2)*NM + (0.08561640993859725 + 
            0.10275811162615457*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08906327958617745 + 0.10275811162615457*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.285, NC*(CF^2*(0.4272540205923325 + 0.375*lm) + 
        CA*CF*(-0.3500239090976527 - 0.9279938491282899*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05444999216449616 + 0.10306958873039614*lm + 
            0.027777777777777776*lm^2)*NM + (0.08484901936249568 + 
            0.10306958873039614*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.08970249055888094 + 0.10306958873039614*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.29, NC*(CF^2*(0.43093538248497465 + 0.375*lm) + 
        CA*CF*(-0.34665034807826023 - 0.9296342987608277*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05290666437140979 + 0.10336785229994847*lm + 
            0.027777777777777776*lm^2)*NM + (0.08407180791237844 + 
            0.10336785229994847*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09033516318497313 + 0.10336785229994847*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.295, NC*(CF^2*(0.43454859016870956 + 0.375*lm) + 
        CA*CF*(-0.343160010037665 - 0.9312036690378813*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.05135370980606676 + 0.10365319235032186*lm + 
            0.027777777777777776*lm^2)*NM + (0.08328538334920953 + 
            0.10365319235032186*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09096132913522038 + 0.10365319235032186*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.3, NC*(CF^2*(0.4380928082508887 + 0.375*lm) + 
        CA*CF*(-0.33955763425863256 - 0.9327035195129241*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0497919045952356 + 0.10392589243669327*lm + 
            0.027777777777777776*lm^2)*NM + (0.0824903295716789 + 
            0.10392589243669327*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09158102097966592 + 0.10392589243669327*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.305, NC*(CF^2*(0.4415675200968458 + 0.375*lm) + 
        CA*CF*(-0.3358478979552237 - 0.9341353748558131*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.04822199361353738 + 0.10418622977176399*lm + 
            0.027777777777777776*lm^2)*NM + (0.0816872075459434 + 
            0.10418622977176399*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0921942721146794 + 0.10418622977176399*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.31, NC*(CF^2*(0.44497210456655556 + 0.375*lm) + 
        CA*CF*(-0.3320352142319224 - 0.9355007255091013*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.04664469169818006 + 0.10443447534508912*lm + 
            0.027777777777777776*lm^2)*NM + (0.08087655619838391 + 
            0.10443447534508912*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09280111669435204 + 0.10443447534508912*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.315, NC*(CF^2*(0.4483061195517348 + 0.375*lm) + 
        CA*CF*(-0.3281238830078936 - 0.9368010283497782*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.04506068481634316 + 0.10467089404339402*lm + 
            0.027777777777777776*lm^2)*NM + (0.08005889327277307 + 
            0.10467089404339402*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09340158956597286 + 0.10467089404339402*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.32, NC*(CF^2*(0.45156921819486323 + 0.375*lm) + 
        CA*CF*(-0.32411805786730513 - 0.9380377073540885*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.04347063118690257 + 0.10489574477145044*lm + 
            0.027777777777777776*lm^2)*NM + (0.07923471615321509 + 
            0.10489574477145044*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09399572620933919 + 0.10489574477145044*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.325, NC*(CF^2*(0.4547611423096502 + 0.375*lm) + 
        CA*CF*(-0.32002175111479714 - 0.939212154263363*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.04187516235815566 + 0.1051092805731367*lm + 
            0.027777777777777776*lm^2)*NM + (0.07840450265418276 + 
            0.1051092805731367*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09458356267967115 + 0.1051092805731367*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.33, NC*(CF^2*(0.45788171620675955 + 0.375*lm) + 
        CA*CF*(-0.3158388386564678 - 0.9403257292490438*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.040274884243172444 + 0.10531174875235139*lm + 
            0.027777777777777776*lm^2)*NM + (0.07756871177893916 + 
            0.10531174875235139*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09516513555391472 + 0.10531174875235139*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.335, NC*(CF^2*(0.4609308408998317 + 0.375*lm) + 
        CA*CF*(-0.3115730647115319 - 0.941379761575314*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.03867037811435873 + 0.10550339099349144*lm + 
            0.027777777777777776*lm^2)*NM + (0.07672778444759226 + 
            0.10550339099349144*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09574048188023229 + 0.10550339099349144*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.34, NC*(CF^2*(0.46390848866842443 + 0.375*lm) + 
        CA*CF*(-0.3072280463597954 - 0.942375550257939*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.037062201558775314 + 0.10568444348124144*lm + 
            0.027777777777777776*lm^2)*NM + (0.07588214419599075 + 
            0.10568444348124144*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09630963913049251 + 0.10568444348124144*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.345, NC*(CF^2*(0.466814697955973 + 0.375*lm) + 
        CA*CF*(-0.30280727793005613 - 0.943314364718107*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.03545088939571918 + 0.1058551370194538*lm + 
            0.027777777777777776*lm^2)*NM + (0.07503219784662919 + 
            0.1058551370194538*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09687264515558265 + 0.1058551370194538*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.35, NC*(CF^2*(0.46964956858225076 + 0.375*lm) + 
        CA*CF*(-0.29831413523448513 - 0.9441974454302173*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.03383695455802358 + 0.1060156971489284*lm + 
            0.027777777777777776*lm^2)*NM + (0.07417833615268998 + 
            0.1060156971489284*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09742953814337925 + 0.1060156971489284*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.355, NC*(CF^2*(0.47241325725109684 + 0.375*lm) + 
        CA*CF*(-0.2937518796539692 - 0.9450260045627041*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.03222088893848655 + 0.10616634426392602*lm + 
            0.027777777777777776*lm^2)*NM + (0.07332093441630995 + 
            0.10616634426392602*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09798035657922145 + 0.10616634426392602*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.36, NC*(CF^2*(0.4751059733353944 + 0.375*lm) + 
        CA*CF*(-0.2891236620793173 - 0.945801226611115*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.030603164202795602 + 0.10630729372727343*lm + 
            0.027777777777777776*lm^2)*NM + (0.07246035308211912 + 
            0.10630729372727343*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09852513920874297 + 0.10630729372727343*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.365, NC*(CF^2*(0.47772797492241753 + 0.375*lm) + 
        CA*CF*(-0.28443252671314073 - 0.9465242690227734*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.02898423257028395 + 0.10643875598393861*lm + 
            0.027777777777777776*lm^2)*NM + (0.07159693830706063 + 
            0.10643875598393861*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.09906392500292545 + 0.10643875598393861*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.37, NC*(CF^2*(0.48027956510368497 + 0.375*lm) + 
        CA*CF*(-0.27968141473709823 - 0.9471962628124593*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.027364527563758245 + 0.1065609366729724*lm + 
            0.027777777777777776*lm^2)*NM + (0.07073102250746197 + 
            0.1065609366729724*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.0995967531252468 + 0.1065609366729724*lm + 0.027777777777777776*
             lm^2)*NH))}, {0.375, 
      NC*(CF^2*(0.48276108849451455 + 0.375*lm) + 
        CA*CF*(-0.2748731678491199 - 0.9478183131686293*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.025744464729681775 + 0.10667403673773057*lm + 
            0.027777777777777776*lm^2)*NM + (0.06986292488429054 + 
            0.10667403673773057*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10012366290080355 + 0.10667403673773057*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.38, NC*(CF^2*(0.4851729279693174 + 0.375*lm) + 
        CA*CF*(-0.27001053167507383 - 0.948391500049782*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.024124442329849907 + 0.1067782525343038*lm + 
            0.027777777777777776*lm^2)*NM + (0.06899295192748993 + 
            0.1067782525343038*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10064469378729507 + 0.1067782525343038*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.385, NC*(CF^2*(0.4875155015995956 + 0.375*lm) + 
        CA*CF*(-0.26509615905924844 - 0.9489168787706441*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0225048420057294 + 0.10687377593809691*lm + 
            0.027777777777777776*lm^2)*NM + (0.06812139790025755 + 
            0.10687377593809691*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10115988534776396 + 0.10687377593809691*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.39, NC*(CF^2*(0.48978925978238613 + 0.375*lm) + 
        CA*CF*(-0.26013261323789255 - 0.9493954805779165*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.020886029416551107 + 0.10696079444851006*lm + 
            0.027777777777777776*lm^2)*NM + (0.06724854530409001 + 
            0.10696079444851006*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10166927722499251 + 0.10696079444851006*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.395, NC*(CF^2*(0.4919946825476612 + 0.375*lm) + 
        CA*CF*(-0.2551223708999357 - 0.9498283132153796*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.019268354852219075 + 0.10703949129168519*lm + 
            0.027777777777777776*lm^2)*NM + (0.06637466532538913 + 
            0.10703949129168519*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10217290911746237 + 0.10703949129168519*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.4, NC*(CF^2*(0.4941322770338978 + 0.375*lm) + 
        CA*CF*(-0.2500678251388895 - 0.9502163614782063*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.017652153822048728 + 0.10711004552129003*lm + 
            0.027777777777777776*lm^2)*NM + (0.06550001826438898 + 
            0.10711004552129003*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.1026708207567889 + 0.10711004552129003*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.405, NC*(CF^2*(0.49620257512169863 + 0.375*lm) + 
        CA*CF*(-0.2449712882998091 - 0.9505605877563733*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.016037747620316557 + 0.1071726321173204*lm + 
            0.027777777777777776*lm^2)*NM + (0.06462485394713349 + 
            0.1071726321173204*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10316305188654692 + 0.1071726321173204*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.41, NC*(CF^2*(0.4982061312159621 + 0.375*lm) + 
        CA*CF*(-0.23983499472507297 - 0.9508619325671089*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.014425443869558258 + 0.1072274220829087*lm + 
            0.027777777777777776*lm^2)*NM + (0.0637494121212036 + 
            0.1072274220829087*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10364964224241148 + 0.1072274220829087*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.415, NC*(CF^2*(0.5001435201676823 + 0.375*lm) + 
        CA*CF*(-0.23466110340261742 - 0.9511213150763426*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.012815537042517542 + 0.10727458253913298*lm + 
            0.027777777777777776*lm^2)*NM + (0.06287392283586424 + 
            0.10727458253913298*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10413063153353747 + 0.10727458253913298*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.42, NC*(CF^2*(0.5020153353270097 + 0.375*lm) + 
        CA*CF*(-0.2294517005201475 - 0.951339633609158*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.011208308963618418 + 0.1073142768178267*lm + 
            0.027777777777777776*lm^2)*NM + (0.06199860680727334 + 
            0.1073142768178267*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10460605942511163 + 0.1073142768178267*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.425, NC*(CF^2*(0.5038221867196953 + 0.375*lm) + 
        CA*CF*(-0.22420880192871992 - 0.9515177661492791*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.009604029290774418 + 0.10734666455239417*lm + 
            0.027777777777777776*lm^2)*NM + (0.061123675769368224 + 
            0.10734666455239417*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10507596552200982 + 0.10734666455239417*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.43, NC*(CF^2*(0.505564699339555 + 0.375*lm) + 
        CA*CF*(-0.2189343555189977 - 0.9516565708276389*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.00800295597836223 + 0.10737190176664142*lm + 
            0.027777777777777776*lm^2)*NM + (0.060249332811018796 + 
            0.10737190176664142*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.1055403893534988 + 0.10737190176664142*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.435, NC*(CF^2*(0.5072435115499875 + 0.375*lm) + 
        CA*CF*(-0.2136302435133369 - 0.9517568864001074*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.00640533572209462 + 0.10739014096163568*lm + 
            0.027777777777777776*lm^2)*NM + (0.0593757727000124 + 
            0.10739014096163568*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10599937035892339 + 0.10739014096163568*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.44, NC*(CF^2*(0.5088592735880519 + 0.375*lm) + 
        CA*CF*(-0.20829828467678307 - 0.9518195327144684*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.004811404386547751 + 0.10740153120061041*lm + 
            0.027777777777777776*lm^2)*NM + (0.05850318219441099 + 
            0.10740153120061041*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10645294787432803 + 0.10740153120061041*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.445, NC*(CF^2*(0.5104126461649624 + 0.375*lm) + 
        CA*CF*(-0.20294023644992887 - 0.9518453111667569*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0032213874160365603 + 0.10740621819193559*lm + 
            0.027777777777777776*lm^2)*NM + (0.05763174034179873 + 
            0.10740621819193559*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.1069011611199543 + 0.10740621819193559*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.45, NC*(CF^2*(0.5119042991572593 + 0.375*lm) + 
        CA*CF*(-0.19755779700649215 - 0.9518350051470769*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.00163550022952241 + 0.1074043443701756*lm + 
            0.027777777777777776*lm^2)*NM + (0.05676161876691612 + 
            0.1074043443701756*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.107344049188573 + 0.1074043443701756*lm + 0.027777777777777776*
             lm^2)*NH))}, {0.455, NC*(CF^2*(0.513334910383222 + 0.375*lm) + 
        CA*CF*(-0.1921526072383572 - 0.9517893804750363*lm - 
          0.1527777777777778*lm^2) + 
        CF*((0.0000539486001839105 + 0.10739604897525912*lm + 
            0.027777777777777776*lm^2)*NM + (0.05589298194815555 + 
            0.10739604897525912*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.1077816510345999 + 0.10739604897525912*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.46, NC*(CF^2*(0.5147051644594726 + 0.375*lm) + 
        CA*CF*(-0.18672625267074838 - 0.9517091858249429*lm - 
          0.1527777777777778*lm^2) + 
        CF*((-0.0015230709797029783 + 0.10738146812978759*lm + 
            0.027777777777777776*lm^2)*NM + (0.05502598748337335 + 
            0.10738146812978759*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10821400546395386 + 0.10738146812978759*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.465, NC*(CF^2*(0.5160157517329548 + 0.375*lm) + 
        CA*CF*(-0.1812802653100787 - 0.9515951531409164*lm - 
          0.1527777777777778*lm^2) + 
        CF*((-0.00309537094800609 + 0.10736073491451005*lm + 
            0.027777777777777776*lm^2)*NM + (0.054160786345453814 + 
            0.10736073491451005*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10864115112461545 + 0.10736073491451005*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.47, NC*(CF^2*(0.5172673672838127 + 0.375*lm) + 
        CA*CF*(-0.17581612542694727 - 0.951447998042077*lm - 
          0.1527777777777778*lm^2) + 
        CF*((-0.004662772335513369 + 0.10733397944199381*lm + 
            0.027777777777777776*lm^2)*NM + (0.05329752312804236 + 
            0.10733397944199381*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.1090631264978491 + 0.10733397944199381*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.475, NC*(CF^2*(0.5184607099949349 + 0.375*lm) + 
        CA*CF*(-0.17033526327665843 - 0.9512684202179789*lm - 
          0.1527777777777778*lm^2) + 
        CF*((-0.006225104441702919 + 0.10730132892852141*lm + 
            0.027777777777777776*lm^2)*NM + (0.05243633628184724 + 
            0.10730132892852141*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10947996989004727 + 0.10730132892852141*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.48, NC*(CF^2*(0.5195964816841872 + 0.375*lm) + 
        CA*CF*(-0.16483906075954988 - 0.9510571038144593*lm - 
          0.1527777777777778*lm^2) + 
        CF*((-0.007782204522982448 + 0.10726290776424512*lm + 
            0.027777777777777776*lm^2)*NM + (0.051577358341892234 + 
            0.10726290776424512*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.10989171942517044 + 0.10726290776424512*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.485, NC*(CF^2*(0.520675386295595 + 0.375*lm) + 
        CA*CF*(-0.1593288530233341 - 0.9508147178100825*lm - 
          0.1527777777777778*lm^2) + 
        CF*((-0.00933391749289659 + 0.10721883758163116*lm + 
            0.027777777777777776*lm^2)*NM + (0.05072071614608659 + 
            0.10721883758163116*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.11029841303774125 + 0.10721883758163116*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.49, NC*(CF^2*(0.5216981291459568 + 0.375*lm) + 
        CA*CF*(-0.15380593000957524 - 0.9505419163833555*lm - 
          0.1527777777777778*lm^2) + 
        CF*((-0.010880095633819333 + 0.10716923732222625*lm + 
            0.027777777777777776*lm^2)*NM + (0.04986653104546294 + 
            0.10716923732222625*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.1107000884663687 + 0.10716923732222625*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.495, NC*(CF^2*(0.5226654162235775 + 0.375*lm) + 
        CA*CF*(-0.14827153794634462 - 0.9502393392708983*lm - 
          0.1527777777777778*lm^2) + 
        CF*((-0.012420598319671626 + 0.1071142233017795*lm + 
            0.027777777777777776*lm^2)*NM + (0.049014919106419 + 
            0.1071142233017795*lm + 0.027777777777777776*lm^2)*NL + 
          (-0.11109678324776905 + 0.1071142233017795*lm + 
            0.027777777777777776*lm^2)*NH))}, 
     {0.5, CF*NC*(CF*(0.5235779534019583 + 0.375*lm) + 
        CA*(-0.14272688067937028 - 0.9499076120596526*lm - 
          0.1527777777777778*lm^2) - 0.013955291767826146*NM + 
        0.10705390926337116*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.04816599129502863*NL + 0.10705390926337116*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11148853470968878*NH + 
        0.10705390926337116*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.505, CF*NC*(CF*(0.524436446399019 + 0.375*lm) + 
        CA*(-0.13717312152571368 - 0.9495473467684964*lm - 
          0.1527777777777778*lm^2) - 0.015484048704033618*NM + 
        0.10698840648316096*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.04731985370754362*NL + 0.10698840648316096*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11187537997246183*NH + 
        0.10698840648316096*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.51, CF*NC*(CF*(0.525241599316122 + 0.375*lm) + 
        CA*(-0.13161138388068663 - 0.9491591417973424*lm - 
          0.1527777777777778*lm^2) - 0.01700674824050176*NM + 
        0.10691782376113296*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.04647660768166613*NL + 0.10691782376113296*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11225735593384396*NH + 
        0.10691782376113296*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.515, CF*NC*(CF*(0.5259941147533589 + 0.375*lm) + 
        CA*(-0.12604275303693616 - 0.9487435825230518*lm - 
          0.1527777777777778*lm^2) - 0.018523275549745102*NM + 
        0.10684226752944377*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.045636350018826766*NL + 0.10684226752944377*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11263449927223816*NH + 
        0.10684226752944377*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.52, CF*NC*(CF*(0.5266946931547326 + 0.375*lm) + 
        CA*(-0.12046827729570389 - 0.9483012415420984*lm - 
          0.1527777777777778*lm^2) - 0.020033521659985606*NM + 
        0.10676184189654314*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.04479917313786039*NL + 0.10676184189654314*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11300684644081574*NH + 
        0.10676184189654314*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.525, CF*NC*(CF*(0.5273440323603039 + 0.375*lm) + 
        CA*(-0.11488896917543408 - 0.9478326789783516*lm - 
          0.1527777777777778*lm^2) - 0.021537383235349875*NM + 
        0.10667664870313463*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.04396516523557369*NL + 0.10667664870313463*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.1133744336639973*NH + 
        0.10667664870313463*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.53, CF*NC*(CF*(0.5279428271921385 + 0.375*lm) + 
        CA*(-0.10930580657887207 - 0.9473384427830969*lm - 
          0.1527777777777778*lm^2) - 0.02303476236435976*NM + 
        0.10658678757672468*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.04313441044130157*NL + 0.10658678757672468*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11373729693426694*NH + 
        0.10658678757672468*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.535, CF*NC*(CF*(0.5284917690720163 + 0.375*lm) + 
        CA*(-0.10371973392016068 - 0.9468190690274715*lm - 
          0.1527777777777778*lm^2) - 0.024525566356387828*NM + 
        0.10649235598479279*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.04230698896569044*NL + 0.10649235598479279*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11409547200930134*NH + 
        0.10649235598479279*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.54, CF*NC*(CF*(0.5289915456689857 + 0.375*lm) + 
        CA*(-0.09813166321338505 - 0.9462750821874951*lm - 
          0.1527777777777778*lm^2) - 0.0260097075457628*NM + 
        0.10639344928661527*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.041482977243936806*NL + 0.10639344928661527*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11444899440939575*NH + 
        0.10639344928661527*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.545, CF*NC*(CF*(0.5294428405749528 + 0.375*lm) + 
        CA*(-0.09254247512396144 - 0.9457069954218726*lm - 
          0.1527777777777778*lm^2) - 0.0274871031032233*NM + 
        0.10629016078377482*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.040662448073699495*NL + 0.10629016078377482*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11479789941517023*NH + 
        0.10629016078377482*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.55, CF*NC*(CF*(0.5298463330066085 + 0.375*lm) + 
        CA*(-0.08695301998421316 - 0.9451153108427411*lm - 
          0.1527777777777778*lm^2) - 0.028957674854430508*NM + 
        0.10618258176938727*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.039845470747895226*NL + 0.10618258176938727*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11514222206554024*NH + 
        0.10618258176938727*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.555, CF*NC*(CF*(0.5302026975320844 + 0.375*lm) + 
        CA*(-0.08136411877442615 - 0.9445005197795344*lm - 
          0.1527777777777778*lm^2) - 0.030421349105262507*NM + 
        0.10607080157607696*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.03903211118257813*NL + 0.10607080157607696*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.1154819971559366*NH + 
        0.10607080157607696*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.56, CF*NC*(CF*(0.5305126038208342 + 0.375*lm) + 
        CA*(-0.07577656407062755 - 0.9438631030361322*lm - 
          0.1527777777777778*lm^2) - 0.03187805647362445*NM + 
        0.1059549076227311*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.03822243204009578*NL + 0.1059549076227311*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11581725923676028*NH + 
        0.1059549076227311*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.565, CF*NC*(CF*(0.5307767164153142 + 0.375*lm) + 
        CA*(-0.07019112096028422 - 0.9432035311414612*lm - 
          0.1527777777777778*lm^2) - 0.03332773172751962*NM + 
        0.10583498546006365*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.03741649284770606*NL + 0.10583498546006365*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.116148042612059*NH + 
        0.10583498546006365*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.57, CF*NC*(CF*(0.5309956945231252 + 0.375*lm) + 
        CA*(-0.06460852792707295 - 0.94252226459371*lm - 0.1527777777777778*
           lm^2) - 0.03477031362913712*NM + 0.10571111881501799*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.03661435011183165*NL + 
        0.10571111881501799*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.11647438133841233*NH + 0.10571111881501799*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.575, CF*NC*(CF*(0.5311701918283552 + 0.375*lm) + 
        CA*(-0.059029497705830464 - 0.9418197540983185*lm - 
          0.1527777777777778*lm^2) - 0.03620574478472169*NM + 
        0.10558338963403772*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.035816057428121766*NL + 0.10558338963403772*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11679630922401371*NH + 
        0.10558338963403772*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.58, CF*NC*(CF*(0.5313008563209313 + 0.375*lm) + 
        CA*(-0.053454718108750285 - 0.9410964407998984*lm - 
          0.1527777777777778*lm^2) - 0.03763397150000103*NM + 
        0.10545187812523404*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.035021665587483417*NL + 0.10545187812523404*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11711385982793748*NH + 
        0.10545187812523404*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.585, CF*NC*(CF*(0.5313883301428648 + 0.375*lm) + 
        CA*(-0.047884852823852575 - 0.9403527565082385*lm - 
          0.1527777777777778*lm^2) - 0.0390549436409551*NM + 
        0.10531666279947771*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.034231222678238304*NL + 0.10531666279947771*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11742706645958031*NH + 
        0.10531666279947771*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.59, CF*NC*(CF*(0.5314332494503331 + 0.375*lm) + 
        CA*(-0.04232054218671544 - 0.939589123918547*lm - 
          0.1527777777777778*lm^2) - 0.04046861449972066*NM + 
        0.10517782051044289*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0334447741845545*NL + 0.10517782051044289*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11773596217826665*NH + 
        0.10517782051044289*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.595, CF*NC*(CF*(0.5314362442906038 + 0.375*lm) + 
        CA*(-0.03676240392641841 - 0.9388059568260759*lm - 
          0.1527777777777778*lm^2) - 0.041874940665432736*NM + 
        0.10503542649362997*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.03266236308129641*NL + 0.10503542649362997*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11804057979300847*NH + 
        0.10503542649362997*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.6, CF*NC*(CF*(0.5313979384928679 + 0.375*lm) + 
        CA*(-0.031211033886613716 - 0.9380036603352749*lm - 
          0.1527777777777778*lm^2) - 0.0432738818998129*NM + 
        0.10488955440439342*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.03188402992543039*NL + 0.10488955440439342*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11834095186241017*NH + 
        0.10488955440439342*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.605, CF*NC*(CF*(0.5313189495720974 + 0.375*lm) + 
        CA*(-0.025667006722606335 - 0.9371826310636133*lm - 
          0.1527777777777778*lm^2) - 0.044665401017321825*NM + 
        0.1047402763550004*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.03110981294411793*NL + 0.1047402763550004*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11863711069470959*NH + 
        0.1047402763550004*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.61, CF*NC*(CF*(0.5311998886450987 + 0.375*lm) + 
        CA*(-0.020130876575291178 - 0.9363432573402107*lm - 
          0.1527777777777778*lm^2) - 0.04604946376970108*NM + 
        0.10458766295074538*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.030339748119622825*NL + 0.10458766295074538*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11892908834794721*NH + 
        0.10458766295074538*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.615, CF*NC*(CF*(0.5310413603579787 + 0.375*lm) + 
        CA*(-0.014603177722763922 - 0.9354859193994098*lm - 
          0.1527777777777778*lm^2) - 0.047426038734736116*NM + 
        0.10443178332514522*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.029573869271153796*NL + 0.10443178332514522*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11921691663025555*NH + 
        0.10443178332514522*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.62, CF*NC*(CF*(0.5308439628242857 + 0.375*lm) + 
        CA*(-0.009084425210391713 - 0.934610989569424*lm - 
          0.1527777777777778*lm^2) - 0.048795097209079395*NM + 
        0.10427270517423871*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.028812208133758926*NL + 0.10427270517423871*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.1195006271002611*NH + 
        0.10427270517423871*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.625, CF*NC*(CF*(0.5306082875731327 + 0.375*lm) + 
        CA*(-0.003575115460100604 - 0.9337188324561884*lm - 
          0.1527777777777778*lm^2) - 0.05015661310497879*NM + 
        0.10411049479001405*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.028054794434383728*NL + 0.10411049479001405*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.11978025106759219*NH + 
        0.10411049479001405*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.63, CF*NC*(CF*(0.5303349195066466 + 0.375*lm) + 
        CA*(0.001924273140391444 - 0.9328098051225403*lm - 
          0.1527777777777778*lm^2) - 0.05151056285076291*NM + 
        0.10394521709298714*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.02730165596520008*NL + 0.10394521709298714*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12005581959348564*NH + 
        0.10394521709298714*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.635, CF*NC*(CF*(0.5300244368661291 + 0.375*lm) + 
        CA*(0.007413279667694242 - 0.9318842572628523*lm - 
          0.1527777777777778*lm^2) - 0.05285692529494078*NM + 
        0.10377693566395295*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.026552818654308974*NL + 0.10377693566395295*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12032736349148634*NH + 
        0.10377693566395295*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.64, CF*NC*(CF*(0.5296774112063493 + 0.375*lm) + 
        CA*(0.012891460111541964 - 0.9309425313732361*lm - 
          0.1527777777777778*lm^2) - 0.05419568161377917*NM + 
        0.10360571277493182*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.02580830663391589*NL + 0.10360571277493182*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12059491332823331*NH + 
        0.10360571277493182*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.645, CF*NC*(CF*(0.5292944073774184 + 0.375*lm) + 
        CA*(0.018358386841615858 - 0.9299849629174367*lm - 
          0.1527777777777778*lm^2) - 0.05552681522222606*NM + 
        0.10343160941933192*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.025068142306073713*NL + 0.10343160941933192*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12085849942432692*NH + 
        0.10343160941933192*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.65, CF*NC*(CF*(0.528875983513737 + 0.375*lm) + 
        CA*(0.023813648091766313 - 0.9290118804885282*lm - 
          0.1527777777777778*lm^2) - 0.05685031168805435*NM + 
        0.10325468534134856*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.024332346406084185*NL + 0.10325468534134856*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12111815185527168*NH + 
        0.10325468534134856*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.655, CF*NC*(CF*(0.5284226910295252 + 0.375*lm) + 
        CA*(0.029256847461030598 - 0.9280236059665241*lm - 
          0.1527777777777778*lm^2) - 0.05816615864910468*NM + 
        0.10307499906462055*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.023600938063645507*NL + 0.10307499906462055*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12137390045248968*NH + 
        0.10307499906462055*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.66, CF*NC*(CF*(0.5279350746204823 + 0.375*lm) + 
        CA*(0.03468760343086485 - 0.9270204546720096*lm - 
          0.1527777777777778*lm^2) - 0.059474345733510986*NM + 
        0.10289260792016335*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.02287393486182992*NL + 0.10289260792016335*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12162577480439964*NH + 
        0.10289260792016335*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.665, CF*NC*(CF*(0.5274136722711454 + 0.375*lm) + 
        CA*(0.04010554889803014 - 0.9260027355159013*lm - 
          0.1527777777777778*lm^2) - 0.06077486448279735*NM + 
        0.10270756807359821*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.02215135289397204*NL + 0.10270756807359821*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12187380425755728*NH + 
        0.10270756807359821*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.67, CF*NC*(CF*(0.5268590152675426 + 0.375*lm) + 
        CA*(0.04551033072259309 - 0.9249707511454385*lm - 
          0.1527777777777778*lm^2) - 0.0620677082777387*NM + 
        0.10251993455169588*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.02143320681854545*NL + 0.10251993455169588*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12211801791785244*NH + 
        0.10251993455169588*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.675, CF*NC*(CF*(0.5262716282147597 + 0.375*lm) + 
        CA*(0.050901609290521156 - 0.9239247980865035*lm - 
          0.1527777777777778*lm^2) - 0.06335287226688253*NM + 
        0.10232976126825316*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.02071950991210184*NL + 0.10232976126825316*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12235844465175891*NH + 
        0.10232976126825316*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.68, CF*NC*(CF*(0.5256520290590619 + 0.375*lm) + 
        CA*(0.05627905809037176 - 0.922865166882372*lm - 0.1527777777777778*
           lm^2) - 0.06463035329763259*NM + 0.10213710104932015*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.02001027412034439*NL + 
        0.10213710104932015*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.1225951130876333*NH + 0.10213710104932015*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.685, CF*NC*(CF*(0.5250007291142343 + 0.375*lm) + 
        CA*(0.06164236330359266 - 0.921792142228985*lm - 0.1527777777777778*
           lm^2) - 0.06590014984979947*NM + 0.10194200565779525*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.01930551010740395*NL + 
        0.10194200565779525*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12282805161705897*NH + 0.10194200565779525*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.69, CF*NC*(CF*(0.5243182330918219 + 0.375*lm) + 
        CA*(0.06699122340796845 - 0.920706003106838*lm - 0.1527777777777778*
           lm^2) - 0.06716226197152682*NM + 0.10174452581740488*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.018605227303384136*NL + 
        0.10174452581740488*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12305728839623174*NH + 0.10174452581740488*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.695, CF*NC*(CF*(0.523605039134972 + 0.375*lm) + 
        CA*(0.07232534879376523 - 0.919607022909575*lm - 0.1527777777777778*
           lm^2) - 0.06841669121750545*NM + 0.10154471123608434*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.017909433950238703*NL + 
        0.10154471123608434*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12328285134738412*NH + 0.10154471123608434*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.7, CF*NC*(CF*(0.5228616388555982 + 0.375*lm) + 
        CA*(0.07764446139214118 - 0.9184954695693764*lm - 
          0.1527777777777778*lm^2) - 0.06966344058939082*NM + 
        0.10134261062877552*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.017218137146042242*NL + 0.10134261062877552*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12350476816024471*NH + 
        0.10134261062877552*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.705, CF*NC*(CF*(0.5220885173746 + 0.375*lm) + 
        CA*(0.08294829431540714 - 0.9173716056792258*lm - 
          0.1527777777777778*lm^2) - 0.07090251447834307*NM + 
        0.10113827173965721*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.016531342887712765*NL + 0.10113827173965721*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12372306629353022*NH + 
        0.10113827173965721*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.71, CF*NC*(CF*(0.5212861533648918 + 0.375*lm) + 
        CA*(0.08823659150873565 - 0.916235688612138*lm - 0.1527777777777778*
           lm^2) - 0.07213391860961159*NM + 0.10093174136382307*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.015849056112242542*NL + 
        0.10093174136382307*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12393777297646688*NH + 0.10093174136382307*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.715, CF*NC*(CF*(0.5204550190970063 + 0.375*lm) + 
        CA*(0.09350910741293171 - 0.9150879706374312*lm - 
          0.1527777777777778*lm^2) - 0.07335765998908914*NM + 
        0.10072306536842184*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.015171280736491337*NL + 0.10072306536842184*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12414891521033904*NH + 
        0.10072306536842184*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.72, CF*NC*(CF*(0.5195955804870535 + 0.375*lm) + 
        CA*(0.09876560663789238 - 0.9139286990341184*lm - 
          0.1527777777777778*lm^2) - 0.07457374685176374*NM + 
        0.10051228871327407*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.014498019695594135*NL + 0.10051228871327407*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12435651977006203*NH + 
        0.10051228871327407*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.725, CF*NC*(CF*(0.5187082971468279 + 0.375*lm) + 
        CA*(0.10400586364639568 - 0.9127581162014992*lm - 
          0.1527777777777778*lm^2) - 0.07578218861199901*NM + 
        0.10029945547097964*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.013829274980033428*NL + 0.10029945547097964*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12456061320577741*NH + 
        0.10029945547097964*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.73, CF*NC*(CF*(0.5177936224358725 + 0.375*lm) + 
        CA*(0.10922966244787201 - 0.9115764597670208*lm - 
          0.1527777777777778*lm^2) - 0.07698299581557631*NM + 
        0.10008460884652905*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.013165047671424223*NL + 0.10008460884652905*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.1247612218444679*NH + 
        0.10008460884652905*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.735, CF*NC*(CF*(0.5168520035153144 + 0.375*lm) + 
        CA*(0.11443679630182407 - 0.9103839626914874*lm - 
          0.1527777777777778*lm^2) - 0.07817618009343495*NM + 
        0.09986779119643203*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.012505337977058084*NL + 0.09986779119643203*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.1249583717915903*NH + 
        0.09986779119643203*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.74, CF*NC*(CF*(0.5158838814033034 + 0.375*lm) + 
        CA*(0.11962706743057262 - 0.9091808533716811*lm - 
          0.1527777777777778*lm^2) - 0.07936175411704854*NM + 
        0.09964904404737635*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.011850145263250757*NL + 0.09964904404737635*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12515208893272411*NH + 
        0.09964904404737635*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.745, CF*NC*(CF*(0.5148896910318929 + 0.375*lm) + 
        CA*(0.12480028674101738 - 0.9079673557404694*lm - 
          0.1527777777777778*lm^2) - 0.08053973155537879*NM + 
        0.09942840811442878*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.011199468087536246*NL + 0.09942840811442878*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12534239893523413*NH + 
        0.09942840811442878*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.75, CF*NC*(CF*(0.5138698613052108 + 0.375*lm) + 
        CA*(0.12995627355511313 - 0.9067436893644616*lm - 
          0.1527777777777778*lm^2) - 0.08171012703334932*NM + 
        0.09920592331879098*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.010553304229748537*NL + 0.09920592331879098*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12552932724994537*NH + 
        0.09920592331879098*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.755, CF*NC*(CF*(0.5128248151587825 + 0.375*lm) + 
        CA*(0.13509485534877186 - 0.9055100695392803*lm - 
          0.1527777777777778*lm^2) - 0.08287295609178508*NM + 
        0.09898162880512167*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.009911650722030676*NL + 0.09898162880512167*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12571289911282818*NH + 
        0.09898162880512167*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.76, CF*NC*(CF*(0.5117549696198699 + 0.375*lm) + 
        CA*(0.14021586749891174 - 0.9042667073825124*lm - 
          0.1527777777777778*lm^2) - 0.08402823514876459*NM + 
        0.09875556295843659*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.009274503877809327*NL + 0.09875556295843659*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12589313954669257*NH + 
        0.09875556295843659*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.765, CF*NC*(CF*(0.5106607358687049 + 0.375*lm) + 
        CA*(0.1453191530383841 - 0.9030138099243981*lm - 0.1527777777777778*
           lm^2) - 0.0851759814623342*NM + 0.09852776342059763*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.00864185931977159*NL + 
        0.09852776342059763*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12607007336288992*NH + 0.09852776342059763*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.77, CF*NC*(CF*(0.5095425193005003 + 0.375*lm) + 
        CA*(0.15040456241851846 - 0.9017515801963204*lm - 
          0.1527777777777778*lm^2) - 0.08631621309453569*NM + 
        0.09829826710640169*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.008013712006879378*NL + 0.09829826710640169*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12624372516302063*NH + 
        0.09829826710640169*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.775, CF*NC*(CF*(0.5084007195881295 + 0.375*lm) + 
        CA*(0.15547195327903487 - 0.9004802173171513*lm - 
          0.1527777777777778*lm^2) - 0.08744894887670038*NM + 
        0.09806711021928004*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.00739005626045542*NL + 0.09806711021928004*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12641411934064647*NH + 
        0.09806711021928004*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.78, CF*NC*(CF*(0.5072357307453721 + 0.375*lm) + 
        CA*(0.16052119022508235 - 0.8991999165775117*lm - 
          0.1527777777777778*lm^2) - 0.08857420837596439*NM + 
        0.0978343282666183*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.006770885789373605*NL + 0.0978343282666183*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12658128008300673*NH + 
        0.0978343282666183*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.785, CF*NC*(CF*(0.5060479411906316 + 0.375*lm) + 
        CA*(0.16555214461116943 - 0.897910869522*lm - 0.1527777777777778*
           lm^2) - 0.08969201186296162*NM + 0.09759995607470708*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.00615619371438523*NL + 
        0.09759995607470708*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12674523137273605*NH + 0.09759995607470708*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.79, CF*NC*(CF*(0.5048377338110349 + 0.375*lm) + 
        CA*(0.170564694331762 - 0.8966132640294422*lm - 0.1527777777777778*
           lm^2) - 0.09080238028065273*NM + 0.09736402780333292*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.0055459725916114895*NL + 
        0.09736402780333292*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12690599698958413*NH + 0.09736402780333292*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.795, CF*NC*(CF*(0.5036054860268315 + 0.375*lm) + 
        CA*(0.17555872361833097 - 0.8953072843912159*lm - 
          0.1527777777777778*lm^2) - 0.09190533521424973*NM + 
        0.09712657696001904*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.004940214435231436*NL + 0.09712657696001904*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12706360051213514*NH + 
        0.09712657696001904*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.8, CF*NC*(CF*(0.5023515698560131 + 0.375*lm) + 
        CA*(0.18053412284264006 - 0.893993111387699*lm - 0.1527777777777778*
           lm^2) - 0.0930008988621974*NM + 0.09688763641392506*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.004338910739393559*NL + 
        0.09688763641392506*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12721806531952637*NH + 0.09688763641392506*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.805, CF*NC*(CF*(0.5010763519790821 + 0.375*lm) + 
        CA*(0.18549078832607077 - 0.8926709223628909*lm - 
          0.1527777777777778*lm^2) - 0.09408909400817418*NM + 
        0.09664723840941451*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.003742052499378101*NL + 0.09664723840941451*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12736941459316542*NH + 
        0.09664723840941451*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.81, CF*NC*(CF*(0.4997801938039015 + 0.375*lm) + 
        CA*(0.19042862215478973 - 0.891340891297255*lm - 0.1527777777777778*
           lm^2) - 0.09516994399407681*NM + 0.0964054145792989*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.0031496302320361907*NL + 
        0.0964054145792989*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12751767131844435*NH + 0.0964054145792989*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.815, CF*NC*(CF*(0.4984634515305625 + 0.375*lm) + 
        CA*(0.1953475320005688 - 0.8900031888788285*lm - 0.1527777777777778*
           lm^2) - 0.09624347269395367*NM + 0.09616219595776679*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.0025616339955309687*NL + 
        0.09616219595776679*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12766285828645088*NH + 0.09616219595776679*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.82, CF*NC*(CF*(0.4971264762162116 + 0.375*lm) + 
        CA*(0.20024743094707642 - 0.8886579825726444*lm - 
          0.1527777777777778*lm^2) - 0.09730970448885388*NM + 
        0.09591761299300605*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.001978053408404908*NL + 0.09591761299300605*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12780499809567508*NH + 
        0.09591761299300605*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.825, CF*NC*(CF*(0.4957696138397822 + 0.375*lm) + 
        CA*(0.20512823732146346 - 0.8873054366885106*lm - 
          0.1527777777777778*lm^2) - 0.09836866424255988*NM + 
        0.09567169555952716*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0013988776679966766*NL + 0.09567169555952716*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12794411315371138*NH + 
        0.09567169555952716*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.83, CF*NC*(CF*(0.49439320536658055 + 0.375*lm) + 
        CA*(0.20998987453107426 - 0.8859457124471867*lm - 
          0.1527777777777778*lm^2) - 0.0994203772781725*NM + 
        0.09542447297019556*lm*NM + 0.027777777777777776*lm^2*NM + 
        0.0008240955682300249*NL + 0.09542447297019556*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12808022567895494*NH + 
        0.09542447297019556*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.835, CF*NC*(CF*(0.4929975868126787 + 0.375*lm) + 
        CA*(0.2148322709051182 - 0.8845789680450027*lm - 0.1527777777777778*
           lm^2) - 0.10046486935551889*NM + 0.09517597398798028*lm*NM + 
        0.027777777777777776*lm^2*NM + 0.0002536955167963603*NL + 
        0.09517597398798028*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.1282133577022919*NH + 0.09517597398798028*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.84, CF*NC*(CF*(0.4915830893090704 + 0.375*lm) + 
        CA*(0.21965535954114332 - 0.8832053587169572*lm - 
          0.1527777777777778*lm^2) - 0.1015021666493544*NM + 
        0.09492622683742655*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.00031233444824810904*NL + 0.09492622683742655*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12834353106878293*NH + 
        0.09492622683742655*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.845, CF*NC*(CF*(0.4901500391655507 + 0.375*lm) + 
        CA*(0.2244590781561592 - 0.8818250367983361*lm - 0.1527777777777778*
           lm^2) - 0.10253229572833096*NM + 0.0946752592158591*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.0008740066424505433*NL + 
        0.0946752592158591*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.1284707674393395*NH + 0.0946752592158591*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.85, CF*NC*(CF*(0.48869875793428086 + 0.375*lm) + 
        CA*(0.22924336894226044 - 0.8804381517848905*lm - 
          0.1527777777777778*lm^2) - 0.10355528353470526*NM + 
        0.09442309830432352*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.00143133371947556*NL + 0.09442309830432352*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12859508829239213*NH + 
        0.09442309830432352*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.855, CF*NC*(CF*(0.4872295624730041 + 0.375*lm) + 
        CA*(0.23400817842660843 - 0.8790448503916075*lm - 
          0.1527777777777778*lm^2) - 0.1045711573647608*NM + 
        0.09416977077827209*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.0019843286561465495*NL + 0.09416977077827209*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12871651492555086*NH + 
        0.09416977077827209*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.86, CF*NC*(CF*(0.4857427650078816 + 0.375*lm) + 
        CA*(0.23875345733563302 - 0.8776452766101149*lm - 
          0.1527777777777778*lm^2) - 0.10557994484991952*NM + 
        0.0939153028180007*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.002533004737996199*NL + 0.0939153028180007*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12883506845725648*NH + 
        0.0939153028180007*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.865, CF*NC*(CF*(0.4842386731959182 + 0.375*lm) + 
        CA*(0.2434791604633206 - 0.8762395717647508*lm - 0.1527777777777778*
           lm^2) - 0.10658167393851879*NM + 0.09365972011884356*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.0030773755453088513*NL + 
        0.09365972011884356*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.1289507698284231*NH + 0.09365972011884356*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.87, CF*NC*(CF*(0.4827175901869515 + 0.375*lm) + 
        CA*(0.24818524654345964 - 0.8748278745673337*lm - 
          0.1527777777777778*lm^2) - 0.10757637287823091*NM + 
        0.09340304790113138*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.0036174549396379525*NL + 0.09340304790113138*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12906363980407098*NH + 
        0.09340304790113138*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.875, CF*NC*(CF*(0.4811798146851798 + 0.375*lm) + 
        CA*(0.25287167812571926 - 0.8734103211706682*lm - 
          0.1527777777777778*lm^2) - 0.10856407019910297*NM + 
        0.09314531091991946*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.004153257050782433*NL + 0.09314531091991946*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12917369897494968*NH + 
        0.09314531091991946*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.88, CF*NC*(CF*(0.47962564101020655 + 0.375*lm) + 
        CA*(0.25753842145544015 - 0.8719870452208138*lm - 
          0.1527777777777778*lm^2) - 0.10954479469719569*NM + 
        0.0928865334744914*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.0046847962642064585*NL + 0.0928865334744914*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.12928096775915088*NH + 
        0.0928865334744914*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.885, CF*NC*(CF*(0.4780553591575807 + 0.375*lm) + 
        CA*(0.26218544635702146 - 0.8705581779081542*lm - 
          0.1527777777777778*lm^2) - 0.11051857541880063*NM + 
        0.0926267394176442*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.005212087208887517*NL + 0.0926267394176442*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.1293854664037111*NH + 
        0.0926267394176442*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.89, CF*NC*(CF*(0.4764692548588138 + 0.375*lm) + 
        CA*(0.2668127261207914 - 0.8691238480172921*lm - 0.1527777777777778*
           lm^2) - 0.11148544164521595*NM + 0.09236595216476019*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.005735144745578373*NL + 
        0.09236595216476019*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12948721498620325*NH + 0.09236595216476019*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.895, CF*NC*(CF*(0.4748676096408584 + 0.375*lm) + 
        CA*(0.2714202373932521 - 0.8676841819758037*lm - 0.1527777777777778*
           lm^2) - 0.11244542287806157*NM + 0.09210419470267138*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.006253983955468905*NL + 
        0.09210419470267138*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12958623341631767*NH + 0.09210419470267138*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.9, CF*NC*(CF*(0.4732507008850308 + 0.375*lm) + 
        CA*(0.2760079600705947 - 0.866239303901878*lm - 0.1527777777777778*
           lm^2) - 0.11339854882511516*NM + 0.09184148959832125*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.0067686201292343545*NL + 
        0.09184148959832125*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.1296825414374316*NH + 0.09184148959832125*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.905, CF*NC*(CF*(0.47161880188536626 + 0.375*lm) + 
        CA*(0.28057587719538163 - 0.8647893356508726*lm - 
          0.1527777777777778*lm^2) - 0.11434484938665139*NM + 
        0.09157785900722937*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.007279068756456983*NL + 0.09157785900722937*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.1297761586281675*NH + 
        0.09157785900722937*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.91, CF*NC*(CF*(0.4699721819063928 + 0.375*lm) + 
        CA*(0.2851239748562986 - 0.8633343968608103*lm - 0.1527777777777778*
           lm^2) - 0.11528435464226701*NM + 0.09131332468176348*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.007785345515408591*NL + 
        0.09131332468176348*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.12986710440393964*NH + 0.09131332468176348*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.915, CF*NC*(CF*(0.4683111062403144 + 0.375*lm) + 
        CA*(0.2896522420908814 - 0.8618746049968445*lm - 0.1527777777777778*
           lm^2) - 0.11621709483817537*NM + 0.09104790797922425*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.008287466263181801*NL + 
        0.09104790797922425*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.1299553980184891*NH + 0.09104790797922425*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.92, CF*NC*(CF*(0.46663583626359284 + 0.375*lm) + 
        CA*(0.29416067079112507 - 0.8604100753947205*lm - 
          0.1527777777777778*lm^2) - 0.11714310037495428*NM + 
        0.09078162986974717*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.008785447026158424*NL + 0.09078162986974717*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.13004105856540654*NH + 
        0.09078162986974717*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.925, CF*NC*(CF*(0.4649466294929203 + 0.375*lm) + 
        CA*(0.2986492556118862 - 0.8589409213032544*lm - 0.1527777777777778*
           lm^2) - 0.11806240179573198*NM + 0.09051451094402606*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.009279303990803631*NL + 
        0.09051451094402606*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.1301241049796434*NH + 0.09051451094402606*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.93, CF*NC*(CF*(0.4632437396405758 + 0.375*lm) + 
        CA*(0.3031179938819936 - 0.857467253925858*lm - 0.1527777777777778*
           lm^2) - 0.11897502977479608*NM + 0.09024657142086306*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.009769053494775066*NL + 
        0.09024657142086306*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.13020455603901035*NH + 0.09024657142086306*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.935, CF*NC*(CF*(0.46152741666915875 + 0.375*lm) + 
        CA*(0.3075668855179831 - 0.855989182461131*lm - 0.1527777777777778*
           lm^2) - 0.11988101510661138*NM + 0.08997783115454908*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.010254712018336398*NL + 
        0.08997783115454908*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.13028243036566398*NH + 0.08997783115454908*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.94, CF*NC*(CF*(0.45979790684569516 + 0.375*lm) + 
        CA*(0.3119959329403759 - 0.8545068141425448*lm - 0.1527777777777778*
           lm^2) - 0.1207803886952326*NM + 0.08970830964207886*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.010736296176065162*NL + 
        0.08970830964207886*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.13035774642758083*NH + 0.08970830964207886*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.945, CF*NC*(CF*(0.4580554527951114 + 0.375*lm) + 
        CA*(0.3164051409924238 - 0.8530202542772399*lm - 0.1527777777777778*
           lm^2) - 0.12167318154409859*NM + 0.08943802603020524*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.011213822708845154*NL + 
        0.08943802603020524*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.13043052254001908*NH + 0.08943802603020524*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.95, CF*NC*(CF*(0.45630029355307306 + 0.375*lm) + 
        CA*(0.32079451686124455 - 0.8515296062839595*lm - 
          0.1527777777777778*lm^2) - 0.12255942474619541*NM + 
        0.08916699912233605*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.011687308476133876*NL + 0.08916699912233605*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.13050077686696757*NH + 
        0.08916699912233605*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.955, CF*NC*(CF*(0.4545326646181856 + 0.375*lm) + 
        CA*(0.32516407000127573 - 0.8500349717301393*lm - 
          0.1527777777777778*lm^2) - 0.12343914947457539*NM + 
        0.08889524738527785*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.012156770448495955*NL + 0.08889524738527785*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.13056852742258246*NH + 
        0.08889524738527785*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.96, CF*NC*(CF*(0.4527527980035556 + 0.375*lm) + 
        CA*(0.32951381205997526 - 0.848536450368177*lm - 0.1527777777777778*
           lm^2) - 0.12431238697322068*NM + 0.08862278895583017*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.012622225700393732*NL + 
        0.08862278895583017*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.13063379207261122*NH + 0.08862278895583017*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.965, CF*NC*(CF*(0.4509609222877112 + 0.375*lm) + 
        CA*(0.333843756805702 - 0.8470341401708988*lm - 0.1527777777777778*
           lm^2) - 0.12517916854823924*NM + 0.08834964164723413*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.013083691403226506*NL + 
        0.08834964164723413*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.1306965885358037*NH + 0.08834964164723413*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.97, CF*NC*(CF*(0.4491572626648808 + 0.375*lm) + 
        CA*(0.3381539200577087 - 0.8455281373662438*lm - 0.1527777777777778*
           lm^2) - 0.12603952555938236*NM + 0.08807582295547867*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.013541184818610235*NL + 
        0.08807582295547867*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.13075693438531097*NH + 0.08807582295547867*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.975, CF*NC*(CF*(0.4473420409946317 + 0.375*lm) + 
        CA*(0.34244431961818483 - 0.8440185364711859*lm - 
          0.1527777777777778*lm^2) - 0.12689348941187284*NM + 
        0.08780135006546813*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.013994723291889758*NL + 0.08780135006546813*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.130814847050071*NH + 
        0.08780135006546813*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.98, CF*NC*(CF*(0.4455154758508672 + 0.375*lm) + 
        CA*(0.3467149752062861 - 0.8425054303249118*lm - 0.1527777777777778*
           lm^2) - 0.12774109154853328*NM + 0.08752623985705467*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.014444324245875901*NL + 
        0.08752623985705467*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.13087034381618193*NH + 0.08752623985705467*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.985, CF*NC*(CF*(0.4436777825701858 + 0.375*lm) + 
        CA*(0.35096590839409203 - 0.8409889101212723*lm - 
          0.1527777777777778*lm^2) - 0.12858236344220472*NM + 
        0.08725050891093841*lm*NM + 0.027777777777777776*lm^2*NM - 
        0.014890005174800061*NL + 0.08725050891093841*lm*NL + 
        0.027777777777777776*lm^2*NL - 0.13092344182826265*NH + 
        0.08725050891093841*lm*NH + 0.027777777777777776*lm^2*NH)}, 
     {0.99, CF*NC*(CF*(0.4418291732996024 + 0.375*lm) + 
        CA*(0.3551971425444329 - 0.8394690654405259*lm - 0.1527777777777778*
           lm^2) - 0.12941733658844545*NM + 0.08697417351443905*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.015331783638479113*NL + 
        0.08697417351443905*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.13097415809080046*NH + 0.08697417351443905*lm*NH + 
        0.027777777777777776*lm^2*NH)}, 
     {0.995, CF*NC*(CF*(0.43996985704363456 + 0.375*lm) + 
        CA*(0.35940870275052994 - 0.83794598428039*lm - 0.1527777777777778*
           lm^2) - 0.13024604249850108*NM + 0.08669724966714162*lm*NM + 
        0.027777777777777776*lm^2*NM - 0.01576967725668377*NL + 
        0.08669724966714162*lm*NL + 0.027777777777777776*lm^2*NL - 
        0.1310225094694861*NH + 0.08669724966714162*lm*NH + 
        0.027777777777777776*lm^2*NH)}, {1., 0.00019290123456790122*CF*NC*
       (-1.*CA*(-1884.9055921900137 + 4336.*lm + 792.*lm^2) + 
        2.*(CF*(1135.5553029302812 + 972.*lm) + (-339.72958489905443 + 
            224.*lm + 72.*lm^2)*NM - 42.*NL + 224.*lm*NL + 72.*lm^2*NL - 
          339.72958489905443*NH + 224.*lm*NH + 72.*lm^2*NH))}}
 
CbarTable["a", 2, 1] = {{0., -2.679183813443073*^-7*CF*NC*
       (CA*(592964.8250444641 + 865592.7977204673*lm + 427680.*lm^2) + 
        2.*(CF*(-138025.3669776792 - 321179.5617712915*lm - 349920.*lm^2) + 
          60.*((-2627.0212293857026 - 486.77696624313234*lm - 648.*lm^2)*
             NM + (-2627.0212293857026 - 486.77696624313234*lm - 648.*lm^2)*
             NL + 3.*(-43.17331277252964 - 162.2589887477108*lm - 216.*lm^2)*
             NH)))}, {0.005, 
      CF*NC*(CA*(-0.16935517172098338 - 0.23310041101758686*lm - 
          0.11381180500597649*lm^2) + CF*(0.07010262360488086 + 
          0.17544707508407725*lm + 0.1862374991006888*lm^2) + 
        0.08538419532100316*NM + 0.01604527687784768*lm*NM + 
        0.02069305545563209*lm^2*NM + 0.0853913760193216*NL + 
        0.01604527687784768*lm*NL + 0.02069305545563209*lm^2*NL + 
        0.004104246961129645*NH + 0.01604527687784768*lm*NH + 
        0.02069305545563209*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.17951460694653643 - 0.23422070242227483*lm - 
          0.11302758681755634*lm^2) + CF*(0.06673279200828336 + 
          0.17869964931045929*lm + 0.18495423297418312*lm^2) + 
        0.08623218167242944*NM + 0.016430438201640234*lm*NM + 
        0.020550470330464792*lm^2*NM + 0.08626355195891192*NL + 
        0.016430438201640234*lm*NL + 0.020550470330464792*lm^2*NL + 
        0.004045053446086196*NH + 0.016430438201640234*lm*NH + 
        0.020550470330464792*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.18922122741934516 - 0.23524569319303026*lm - 
          0.1122335592446056*lm^2) + CF*(0.06391274070473633 + 
          0.18181403122025924*lm + 0.18365491512753643*lm^2) + 
        0.08698585627155417*NM + 0.01680054207766702*lm*NM + 
        0.02040610168083738*lm^2*NM + 0.08706027854725705*NL + 
        0.01680054207766702*lm*NL + 0.02040610168083738*lm^2*NL + 
        0.003986849955558298*NH + 0.01680054207766702*lm*NH + 
        0.02040610168083738*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.1984249908277851 - 0.23616426959624237*lm - 
          0.11143192177181166*lm^2) + CF*(0.06162768089567971 + 
          0.18476805381842343*lm + 0.18234314471750998*lm^2) + 
        0.08763985903681548*NM + 0.017153058855426492*lm*NM + 
        0.020260349413056666*lm^2*NM + 0.08777673123889386*NL + 
        0.017153058855426492*lm*NL + 0.020260349413056666*lm^2*NL + 
        0.00392988040885334*NH + 0.017153058855426492*lm*NH + 
        0.020260349413056666*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.20710570992053748 - 0.23697094990382556*lm - 
          0.11062447084811985*lm^2) + CF*(0.05984106863991557 + 
          0.1875494955803241*lm + 0.1810218613878325*lm^2) + 
        0.08819358537794236*NM + 0.017486576149890964*lm*NM + 
        0.020113540154203607*lm^2*NM + 0.08841217125915089*NL + 
        0.017486576149890964*lm*NL + 0.020113540154203607*lm^2*NL + 
        0.003874332486848606*NH + 0.017486576149890964*lm*NH + 
        0.020113540154203607*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.2152590620803148 - 0.2376635035782369*lm - 
          0.10981271932893219*lm^2) + CF*(0.05850936399631341 + 
          0.19015196839218806*lm + 0.17969354072007088*lm^2) + 
        0.08864885787155496*NM + 0.0178003383265381*lm*NM + 
        0.019965948968896762*lm^2*NM + 0.08896789367353254*NL + 
        0.0178003383265381*lm*NL + 0.019965948968896762*lm^2*NL + 
        0.0038203539768740845*NH + 0.0178003383265381*lm*NH + 
        0.019965948968896762*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.22289005493172112 - 0.23824176070903033*lm - 
          0.10899796453722187*lm^2) + CF*(0.057587730693347695 + 
          0.19257284617137532*lm + 0.17836030560636307*lm^2) + 
        0.08900884703953865*NM + 0.018094014285590536*lm*NM + 
        0.01981781173404034*lm^2*NM + 0.08944630034785915*NL + 
        0.018094014285590536*lm*NL + 0.01981781173404034*lm^2*NL + 
        0.003768062205530786*NH + 0.018094014285590536*lm*NH + 
        0.01981781173404034*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.23000945470133324 - 0.23870692288242196*lm - 
          0.10818133238525211*lm^2) + CF*(0.05703254454420319 + 
          0.19481205734173004*lm + 0.17702399844859434*lm^2) + 
        0.08927748787396668*NM + 0.01836756195558863*lm*NM + 
        0.019669333160954927*lm^2*NM + 0.08985040993896541*NL + 
        0.01836756195558863*lm*NL + 0.019669333160954927*lm^2*NL + 
        0.003717550242766823*NH + 0.01836756195558863*lm*NH + 
        0.019669333160954927*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.23663164619599275 - 0.23906112827544598*lm - 
          0.1073638082993704*lm^2) + CF*(0.05680253499856591 + 
          0.19687131719815032*lm + 0.1756862317626061*lm^2) + 
        0.08945913551570796*NM + 0.018621142063449923*lm*NM + 
        0.019520692418067344*lm^2*NM + 0.0901835745873659*NL + 
        0.018621142063449923*lm*NL + 0.019520692418067344*lm^2*NL + 
        0.003668891316891163*NH + 0.018621142063449923*lm*NH + 
        0.019520692418067344*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.2427732715299711 - 0.23930716105622243*lm - 
          0.10654626007253831*lm^2) + CF*(0.056859273568970345 + 
          0.19875361101856323*lm + 0.1743484255732445*lm^2) + 
        0.08955835067103399*NM + 0.018855060009965462*lm*NM + 
        0.019372047285916058*lm^2*NM + 0.0904493066607754*NL + 
        0.018855060009965462*lm*NL + 0.019372047285916058*lm^2*NL + 
        0.0036221421270260274*NH + 0.018855060009965462*lm*NH + 
        0.019372047285916058*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.24845232799992684 - 0.23944824927567265*lm - 
          0.10572945541109982*lm^2) + CF*(0.057167329598146036 + 
          0.2004628315830771*lm + 0.17301183612725424*lm^2) + 
        0.08957976119793064*NM + 0.019069725062429783*lm*NM + 
        0.019223537347472695*lm^2*NM + 0.09065116896294038*NL + 
        0.019069725062429783*lm*NL + 0.019223537347472695*lm^2*NL + 
        0.003577345423897238*NH + 0.019069725062429783*lm*NH + 
        0.019223537347472695*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.25368755295802126 - 0.23948792016878032*lm - 
          0.10491407580411806*lm^2) + CF*(0.05769425109432487 + 
          0.20200351729187313*lm + 0.1716775785885568*lm^2) + 
        0.08952797101237189*NM + 0.019265620836345962*lm*NM + 
        0.019075286509839647*lm^2*NM + 0.09079270370022538*NL + 
        0.019265620836345962*lm*NL + 0.019075286509839647*lm^2*NL + 
        0.003534532077738205*NH + 0.019265620836345962*lm*NH + 
        0.019075286509839647*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.25849799616818553 - 0.23942989433053025*lm - 
          0.10410072773750184*lm^2) + CF*(0.058410453391995396 + 
          0.20338065870191807*lm + 0.1703466453886394*lm^2) + 
        0.08940749964812265*NM + 0.01944328345968276*lm*NM + 
        0.018927405043182154*lm^2*NM + 0.0908773861458446*NL + 
        0.01944328345968276*lm*NL + 0.018927405043182154*lm^2*NL + 
        0.0034937227711389672*NH + 0.01944328345968276*lm*NH + 
        0.018927405043182154*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.2629027188970502 - 0.2392780071126821*lm - 
          0.10328995192765247*lm^2) + CF*(0.05928906104204487 + 
          0.204599553191365*lm + 0.1690199213361586*lm^2) + 
        0.08922274231002933*NM + 0.01960328514466725*lm*NM + 
        0.01877999125957318*lm^2*NM + 0.09090859455642918*NL + 
        0.01960328514466725*lm*NL + 0.01877999125957318*lm^2*NL + 
        0.0034549294082746053*NH + 0.01960328514466725*lm*NH + 
        0.01877999125957318*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.2669205810150792 - 0.23903614959795813*lm - 
          0.10248223103829475*lm^2) + CF*(0.060305728586784235 + 
          0.20566569440503435*lm + 0.16769819624448232*lm^2) + 
        0.08897794395901172*NM + 0.019746221670105996*lm*NM + 
        0.01863313291605359*lm^2*NM + 0.09088959104711472*NL + 
        0.019746221670105996*lm*NL + 0.01863313291605359*lm^2*NL + 
        0.0034181563037512966*NH + 0.019746221670105996*lm*NH + 
        0.01863313291605359*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.27057009053941417 - 0.23870822396290625*lm - 
          0.10167799620983481*lm^2) + CF*(0.061438454947495974 + 
          0.2065846873942282*lm + 0.16638217561609334*lm^2) + 
        0.08867718317670081*NM + 0.01987270275461622*lm*NM + 
        0.018486908401788148*lm^2*NM + 0.09082350999084744*NL + 
        0.01987270275461622*lm*NL + 0.018486908401788148*lm^2*NL + 
        0.003383401196341339*NH + 0.01987270275461622*lm*NH + 
        0.018486908401788148*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.27386929823923634 - 0.2382981096049795*lm - 
          0.10087763264175141*lm^2) + CF*(0.06266739988937152 + 
          0.2073621830846478*lm + 0.1650724897774114*lm^2) + 
        0.08832436293306627*NM + 0.019983344606119915*lm*NM + 
        0.01834138775304571*lm^2*NM + 0.09071335165062361*NL + 
        0.019983344606119915*lm*NL + 0.01834138775304571*lm^2*NL + 
        0.003350656120969948*NH + 0.019983344606119915*lm*NH + 
        0.01834138775304571*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.27683572520084293 - 0.23780963744050376*lm - 
          0.10008148440783876*lm^2) + CF*(0.06397470734344134 + 
          0.20800382750333102*lm + 0.16376970175828162*lm^2) + 
        0.0879232062660712*NM + 0.02007876413447601*lm*NM + 
        0.018196633528697957*lm^2*NM + 0.09056197948032711*NL + 
        0.02007876413447601*lm*NL + 0.018196633528697957*lm^2*NL + 
        0.0033199081641562254*NH + 0.02007876413447601*lm*NH + 
        0.018196633528697957*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.27948631475001523 - 0.23724657047972272*lm - 
          0.09928985864149716*lm^2) + CF*(0.06534433815556936 + 
          0.20851522241733245*lm + 0.1624743141406317*lm^2) + 
        0.08747725546930976*NM + 0.020159574451173386*lm*NM + 
        0.0180527015711813*lm^2*NM + 0.0903721200056451*NL + 
        0.020159574451173386*lm*NL + 0.0180527015711813*lm^2*NL + 
        0.003291140122356255*NH + 0.020159574451173386*lm*NH + 
        0.0180527015711813*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.28183740251033246 - 0.23661258927153764*lm - 
          0.09850302919760759*lm^2) + CF*(0.06676191349287977 + 
          0.2089018948883338*lm + 0.16118677505063062*lm^2) + 
        0.08698987378210754*NM + 0.020226381375543927*lm*NM + 
        0.01790964167229229*lm^2*NM + 0.0901463645157009*NL + 
        0.020226381375543927*lm*NL + 0.01790964167229229*lm^2*NL + 
        0.0032643310784960826*NH + 0.020226381375543927*lm*NH + 
        0.01790964167229229*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.28390470003124907 - 0.235911281156153*lm - 
          0.09772123987500801*lm^2) + CF*(0.06821456932317398 + 
          0.2091692738536491*lm + 0.15990748343183128*lm^2) + 
        0.08646424885287742*NM + 0.020279780735001172*lm*NM + 
        0.017767498159092367*lm^2*NM + 0.08988717201466996*NL + 
        0.020279780735001172*lm*NL + 0.017767498159092367*lm^2*NL + 
        0.0032394569089080907*NH + 0.020279780735001172*lm*NH + 
        0.017767498159092367*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.2857032885922524 - 0.23514613251403438*lm - 
          0.09694470726673868*lm^2) + CF*(0.06969082189077658 + 
          0.20932267228399207*lm + 0.15863679370920875*lm^2) + 
        0.08590339744157774*NM + 0.020320356296198955*lm*NM + 
        0.017626310412134305*lm^2*NM + 0.08959687303514272*NL + 
        0.020320356296198955*lm*NL + 0.017626310412134305*lm^2*NL + 
        0.003216490730567963*NH + 0.020320356296198955*lm*NH + 
        0.017626310412134305*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.2872476206338542 - 0.23432052338373574*lm - 
          0.09617362329241101*lm^2) + CF*(0.0711804438213067 + 
          0.20936727379290634*lm + 0.1573750199330362*lm^2) + 
        0.08531017096696805*NM + 0.020348678200451886*lm*NM + 
        0.01748611332589291*lm^2*NM + 0.08927767402305221*NL + 
        0.020348678200451886*lm*NL + 0.01748611332589291*lm^2*NL + 
        0.0031954032967536823*NH + 0.020348678200451886*lm*NH + 
        0.01748611332589291*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.2885515268832614 - 0.23343772395870266*lm - 
          0.0954081574571642*lm^2) + CF*(0.072674350323536 + 
          0.20930812281573694*lm + 0.1561224394753596*lm^2) + 
        0.08468726160598*NM + 0.020365301804056702*lm*NM + 
        0.0173469377194844*lm^2*NM + 0.08893166208159033*NL + 
        0.020365301804056702*lm*NL + 0.0173469377194844*lm^2*NL + 
        0.003176163347865321*NH + 0.020365301804056702*lm*NH + 
        0.0173469377194844*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.28962822769936225 - 0.2325008925772437*lm - 
          0.09464845887394045*lm^2) + CF*(0.07416449487218713 + 
          0.20915011766034128*lm + 0.1548792963391753*lm^2) + 
        0.08403720872722734*NM + 0.020370766844868007*lm*NM + 
        0.01720881070435281*lm^2*NM + 0.08856080991793129*NL + 
        0.020370766844868007*lm*NL + 0.01720881070435281*lm^2*NL + 
        0.0031587379230525307*NH + 0.020370766844868007*lm*NH + 
        0.01720881070435281*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.29049034750366104 - 0.2315130748995539*lm - 
          0.09389465807969008*lm^2) + CF*(0.07564377372173531 + 
          0.20889800587321936*lm + 0.15364580413040196*lm^2) + 
        0.08336240549614743*NM + 0.020365596872387298*lm*NM + 
        0.017071756014489105*lm^2*NM + 0.08816698087797603*NL + 
        0.020365596872387298*lm*NL + 0.017071756014489105*lm^2*NL + 
        0.003143092637423458*NH + 0.020365596872387298*lm*NH + 
        0.017071756014489105*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.2911499314224407 - 0.23047720402732658*lm - 
          0.09314686867122124*lm^2) + CF*(0.07710593859908262 + 
          0.20855638147448935*lm + 0.15242214873472568*lm^2) + 
        0.08266510553080238*NM + 0.02035029889096686*lm*NM + 
        0.016935794303858408*lm^2*NM + 0.08775193398497502*NL + 
        0.02035029889096686*lm*NL + 0.016935794303858408*lm^2*NL + 
        0.0031291919289023733*NH + 0.02035029889096686*lm*NH + 
        0.016935794303858408*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.29161846346278675 - 0.2293961013696388*lm - 
          0.09240518878245414*lm^2) + CF*(0.07854551694015333 + 
          0.20812968370108287*lm + 0.15120849073492496*lm^2) + 
        0.08194742951869265*NM + 0.020325363175399486*lm*NM + 
        0.01680094341499166*lm^2*NM + 0.08731732892073467*NL + 
        0.020325363175399486*lm*NL + 0.01680094341499166*lm^2*NL + 
        0.003116999278225786*NH + 0.020325363175399486*lm*NH + 
        0.01680094341499166*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.29190688569688394 - 0.2282724780967144*lm - 
          0.09166970242161467*lm^2) + CF*(0.07995773906406661 + 
          0.20762219696542014*lm + 0.1500049675990058*lm^2) + 
        0.08121137172869791*NM + 0.020291263225805836*lm*NM + 
        0.016667218622111755*lm^2*NM + 0.08686473090524574*NL + 
        0.020291263225805836*lm*NL + 0.016667218622111755*lm^2*NL + 
        0.0031064774050901084*NH + 0.020291263225805836*lm*NH + 
        0.016667218622111755*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.29202561804652855 - 0.2271089370532616*lm - 
          0.09094048068425153*lm^2) + CF*(0.08133847171341187 + 
          0.20703805179086537*lm + 0.14881169566513888*lm^2) + 
        0.08045880637036841*NM + 0.020248455834815802*lm*NM + 
        0.016534632851682097*lm^2*NM + 0.08639561544347646*NL + 
        0.020248455834815802*lm*NL + 0.016534632851682097*lm^2*NL + 
        0.0030975884430670493*NH + 0.020248455834815802*lm*NH + 
        0.016534632851682097*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.2919845783513607 - 0.22590797502712615*lm - 
          0.09021758285576564*lm^2) + CF*(0.08268415742693005 + 
          0.20638122652858099*lm + 0.14762877194579832*lm^2) + 
        0.07969149376663595*NM + 0.02019738124492014*lm*NM + 
        0.01640319688286648*lm^2*NM + 0.08591137291782212*NL + 
        0.02019738124492014*lm*NL + 0.01640319688286648*lm^2*NL + 
        0.003090294095569761*NH + 0.02019738124492014*lm*NH + 
        0.01640319688286648*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.29179320247602136 - 0.22467198528833016*lm - 
          0.08950105741530813*lm^2) + CF*(0.08399175924943704 + 
          0.20565554969534622*lm + 0.1464562757705042*lm^2) + 
        0.07891108631662277*NM + 0.02013846337780691*lm*NM + 
        0.016272919530056024*lm^2*NM + 0.08541331301208067*NL + 
        0.02013846337780691*lm*NL + 0.016272919530056024*lm^2*NL + 
        0.0030845557748711647*NH + 0.02013846337780691*lm*NH + 
        0.016272919530056024*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.29146046426782996 - 0.22340326032919497*lm - 
          0.08879094295136603*lm^2) + CF*(0.08525871032175143 + 
          0.20486470280025987*lm + 0.14529427028405348*lm^2) + 
        0.0781191342333617*NM + 0.02007211012069455*lm*NM + 
        0.016143807809339276*lm^2*NM + 0.08490266895840654*NL + 
        0.02007211012069455*lm*NL + 0.016143807809339276*lm^2*NL + 
        0.0030803347259361386*NH + 0.02007211012069455*lm*NH + 
        0.016143807809339276*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.290994895221093 - 0.2221039947489394*lm - 
          0.08808726899805493*lm^2) + CF*(0.08648286792987518 + 
          0.2040122235513717*lm + 0.14414280381499897*lm^2) + 
        0.07731709104747482*NM + 0.019998713657282056*lm*NM + 
        0.01601586709055544*lm^2*NM + 0.0843806016029124*NL + 
        0.019998713657282056*lm*NL + 0.01601586709055544*lm^2*NL + 
        0.0030775921366240017*NH + 0.019998713657282056*lm*NH + 
        0.01601586709055544*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.2904046037393899 - 0.22077628823650644*lm - 
          0.08739005680003424*lm^2) + CF*(0.0876624716272403 + 
          0.20310150935223784*lm + 0.14300191112732874*lm^2) + 
        0.07650631887262441*NM + 0.019918650833075896*lm*NM + 
        0.01588910123636986*lm^2*NM + 0.08384820328876227*NL + 
        0.019918650833075896*lm*NL + 0.01588910123636986*lm^2*NL + 
        0.003076289235640946*NH + 0.019918650833075896*lm*NH + 
        0.01588910123636986*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.289697293915133 - 0.21942214861385548*lm - 
          0.08669932001301797*lm^2) + CF*(0.08879610507622784 + 
          0.20213582101398717*lm + 0.14187161456675668*lm^2) + 
        0.07568809343218076*NM + 0.01983228354661419*lm*NM + 
        0.01576351272963963*lm^2*NM + 0.08330650155797144*NL + 
        0.01983228354661419*lm*NL + 0.01576351272963963*lm^2*NL + 
        0.0030763873794690615*NH + 0.01983228354661419*lm*NH + 
        0.01576351272963963*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.288880283767901 - 0.21804349490893507*lm - 
          0.08601506534604508*lm^2) + CF*(0.08988266128529407 + 
          0.20111828662136585*lm + 0.14075192511171014*lm^2) + 
        0.0748636088493057*NM + 0.019739959159564537*lm*NM + 
        0.015639102790190016*lm^2*NM + 0.08275646267488429*NL + 
        0.019739959159564537*lm*NL + 0.015639102790190016*lm^2*NL + 
        0.0030778481293655033*NH + 0.019739959159564537*lm*NH + 
        0.015639102790190016*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.28796052290069046 - 0.2166421604333024*lm - 
          0.08533729315097587*lm^2) + CF*(0.09092131094590729 + 
          0.20005190550190213*lm + 0.1396428433379605*lm^2) + 
        0.07403398220473044*NM + 0.019642010919878748*lm*NM + 
        0.015515871481995612*lm^2*NM + 0.08219899497558093*NL + 
        0.019642010919878748*lm*NL + 0.015515871481995612*lm^2*NL + 
        0.00308063331940912*NH + 0.019642010919878748*lm*NH + 
        0.015515871481995612*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.28694460954725326 - 0.21521989584410964*lm - 
          0.08466599796407694*lm^2) + CF*(0.09191147359918676 + 
          0.19893955225620547*lm + 0.13854436030485315*lm^2) + 
        0.07320025786808416*NM + 0.019538758393192215*lm*NM + 
        0.015393817811650352*lm^2*NM + 0.08163495204837447*NL + 
        0.019538758393192215*lm*NL + 0.015393817811650352*lm^2*NL + 
        0.003084705116469902*NH + 0.019538758393192215*lm*NH + 
        0.015393817811650352*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.2858388069902017 - 0.21377837217411683*lm - 
          0.08400116900403254*lm^2) + CF^2*(0.09285279137649678 + 
          0.19778398081480994*lm + 0.13745645837023507*lm^2) + 
        CF*((0.0723634115913137 + 0.019430507898493047*lm + 
            0.015272939818915008*lm^2)*NM + (0.08106513575118938 + 
            0.019430507898493047*lm + 0.015272939818915008*lm^2)*NL + 
          (0.0030900260728868867 + 0.019430507898493047*lm + 
            0.015272939818915008*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.28464905936446233 - 0.21231918381665812*lm - 
          0.08334279063026181*lm^2) + CF^2*(0.09374510513206501 + 
          0.19658782849314851*lm + 0.13637911194042843*lm^2) + 
        CF*((0.07152435445920922 + 0.019317552944786348*lm + 
            0.015153234660047601*lm^2)*NM + (0.08049029907201895 + 
            0.019317552944786348*lm + 0.015153234660047601*lm^2)*NL + 
          (0.003096559172560892 + 0.019317552944786348*lm + 
            0.015153234660047601*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.28338100680065115 - 0.21084385145520457*lm - 
          0.08269084276502024*lm^2) + CF^2*(0.09458843267157444 + 
          0.19535362002141382*lm + 0.13531228816094223*lm^2) + 
        CF*((0.07068393652028401 + 0.019200174666065568*lm + 
            0.015034698684549135*lm^2)*NM + (0.07991114883889908 + 
            0.019200174666065568*lm + 0.015034698684549135*lm^2)*NL + 
          (0.0031042678710982434 + 0.019200174666065568*lm + 
            0.015034698684549135*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.28203999996609197 - 0.20935382492942356*lm - 
          0.08204530128241176*lm^2) + CF^2*(0.09538294899418162 + 
          0.1940837715303941*lm + 0.13425594755303744*lm^2) + 
        CF*((0.06984295032083832 + 0.01907864225239495*lm + 
            0.014917327505893047*lm^2)*NM + (0.07932834828594541 + 
            0.01907864225239495*lm + 0.014917327505893047*lm^2)*NL + 
          (0.0031131161305792934 + 0.01907864225239495*lm + 
            0.014917327505893047*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.28063111397818186 - 0.20785048603151418*lm - 
          0.08140613836712648*lm^2) + CF^2*(0.09612896830743042 + 
          0.19278059447800916*lm + 0.13321004460075242*lm^2) + 
        CF*((0.06900213420785765 + 0.018953213375320417*lm + 
            0.01480111606675027*lm^2)*NM + (0.07874251948201112 + 
            0.018953213375320417*lm + 0.01480111606675027*lm^2)*NL + 
          (0.003123068449469883 + 0.018953213375320417*lm + 
            0.01480111606675027*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.27915916171528754 - 0.20633515122816037*lm - 
          0.08077332284544539*lm^2) + CF^2*(0.09682692768405156 + 
          0.1914462995043241*lm + 0.132174528292547*lm^2) + 
        CF*((0.06816217546065437 + 0.018824134606174027*lm + 
            0.014686058699171889*lm^2)*NM + (0.0781542456284582 + 
            0.018824134606174027*lm + 0.014686058699171889*lm^2)*NL + 
          (0.0031340898881446312 + 0.018824134606174027*lm + 
            0.014686058699171889*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.27762870653838645 - 0.20480907430474185*lm - 
          0.08014682049080925*lm^2) + CF^2*(0.09747737221452062 + 
          0.19008300020538563*lm + 0.13114934262132424*lm^2) + 
        CF*((0.06732371325183667 + 0.018691641826129438*lm + 
            0.014572149180147136*lm^2)*NM + (0.07756407323241508 + 
            0.018691641826129438*lm + 0.014572149180147136*lm^2)*NL + 
          (0.0031461460904453806 + 0.018691641826129438*lm + 
            0.014572149180147136*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.276044074440374 - 0.2032734489295223*lm - 
          0.07952659430603312*lm^2) + CF^2*(0.09808094152554808 + 
          0.18869271681838148*lm + 0.130134427046236*lm^2) + 
        CF*((0.06648734144592698 + 0.01855596062711209*lm + 
            0.014459380782915112*lm^2)*NM + (0.0769725141617318 + 
            0.01855596062711209*lm + 0.014459380782915112*lm^2)*NL + 
          (0.003159203301660607 + 0.01855596062711209*lm + 
            0.014459380782915112*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.2744093656410999 - 0.20172941113642748*lm - 
          0.07891260478405494*lm^2) + CF^2*(0.09863835754577087 + 
          0.18727737981243478*lm + 0.12912971691936262*lm^2) + 
        CF*((0.06565361124355826 + 0.018417306702874926*lm + 
            0.014347746324373625*lm^2)*NM + (0.0763800475876528 + 
            0.018417306702874926*lm + 0.014347746324373625*lm^2)*NL + 
          (0.0031732283832728945 + 0.018417306702874926*lm + 
            0.014347746324373625*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.272728465647186 - 0.20017804172576573*lm - 
          0.07830481014893481*lm^2) + CF^2*(0.09915041341052959 + 
          0.18583883338086685*lm + 0.12813514388007513*lm^2) + 
        CF*((0.06482303367918696 + 0.018275886229724553*lm + 
            0.014237238208897237*lm^2)*NM + (0.07578712182101671 + 
            0.018275886229724553*lm + 0.014237238208897237*lm^2)*NL + 
          (0.0031881888247917004 + 0.018275886229724553*lm + 
            0.014237238208897237*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.2710050557960585 - 0.19862036858285054*lm - 
          0.07770316657866717*lm^2) + CF^2*(0.09961796340676514 + 
          0.18437883883203549*lm + 0.12715063621963718*lm^2) + 
        CF*((0.06399608197979668 + 0.018131896236529183*lm + 
            0.014127848468848576*lm^2)*NM + (0.07519415604756752 + 
            0.018131896236529183*lm + 0.014127848468848576*lm^2)*NL + 
          (0.0032040527529584683 + 0.018131896236529183*lm + 
            0.014127848468848576*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.2692426233039212 - 0.19705736891498615*lm - 
          0.07710762841123037*lm^2) + CF^2*(0.10004191386773761 + 
          0.18289907787692405*lm + 0.12617611921837696*lm^2) + 
        CF*((0.06317319379188448 + 0.01798552496376236*lm + 
            0.014019568802041884*lm^2)*NM + (0.07460154196772938 + 
            0.01798552496376236*lm + 0.014019568802041884*lm^2)*NL + 
          (0.003220788938585226 + 0.01798552496376236*lm + 
            0.014019568802041884*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.2674444708373897 - 0.19548997140768215*lm - 
          0.07651814833517354*lm^2) + CF^2*(0.10042321493501842 + 
          0.18140115581254593*lm + 0.1252115154575567*lm^2) + 
        CF*((0.0623547732837004 + 0.01783695221143924*lm + 
            0.01391239060639519*lm^2)*NM + (0.07400964534596235 + 
            0.01783695221143924*lm + 0.01391239060639519*lm^2)*NL + 
          (0.003238366801264021 + 0.01783695221143924*lm + 
            0.01391239060639519*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.26561372562834185 - 0.1939190583012932*lm - 
          0.07593467756592938*lm^2) + CF^2*(0.10076285311226853 + 
          0.17988660460097125*lm + 0.12425674510788443*lm^2) + 
        CF*((0.06154119312941403 + 0.017686349675887832*lm + 
            0.01380630501198716*lm^2)*NM + (0.07341880747458036 + 
            0.017686349675887832*lm + 0.01380630501198716*lm^2)*NL + 
          (0.003256756412163195 + 0.017686349675887832*lm + 
            0.01380630501198716*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.26375334815122475 - 0.19234546738954417*lm - 
          0.0753571660089399*lm^2) + CF^2*(0.10106184454173173 + 
          0.17835688584439593*lm + 0.12331172619644709*lm^2) + 
        CF*((0.060732796381582334 + 0.017533881275369045*lm + 
            0.013701302910716345*lm^2)*NM + (0.07282934655667996 + 
            0.017533881275369045*lm + 0.013701302910716345*lm^2)*NL + 
          (0.0032759284951069407 + 0.017533881275369045*lm + 
            0.013701302910716345*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.26186614038162803 - 0.19076999394160804*lm - 
          0.07478556241059187*lm^2) + CF^2*(0.1013212289401748 + 
          0.17681339365717993*lm + 0.12237637485369578*lm^2) + 
        CF*((0.05992989823799643 + 0.01737970346461822*lm + 
            0.013597374983743976*lm^2)*NM + (0.07224155901260014 + 
            0.01737970346461822*lm + 0.013597374983743976*lm^2)*NL + 
          (0.0032958544261169707 + 0.01737970346461822*lm + 
            0.013597374983743976*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.2599547536543945 - 0.18919339254956777*lm - 
          0.07421981449787554*lm^2) + CF^2*(0.10154206413624502 + 
          0.17525745743619567*lm + 0.12145060554197815*lm^2) + 
        CF*((0.059132787708691695 + 0.017223965538429552*lm + 
            0.013494511726886461*lm^2)*NM + (0.07165572071411072 + 
            0.017223965538429552*lm + 0.013494511726886461*lm^2)*NL + 
          (0.003316506231579111 + 0.017223965538429552*lm + 
            0.013494511726886461*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.25802169613893117 - 0.18761637890321473*lm - 
          0.07365986910760576*lm^2) + CF^2*(0.10172542115594861 + 
          0.17369034453116408*lm + 0.12053433126699124*lm^2) + 
        CF*((0.05834172918861739 + 0.01706680992444432*lm + 
            0.013392703474110139*lm^2)*NM + (0.071072088150311 + 
            0.01706680992444432*lm + 0.013392703474110139*lm^2)*NL + 
          (0.0033378565851831465 + 0.01706680992444432*lm + 
            0.013392703474110139*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.25606933994872816 - 0.1860396314942275*lm - 
          0.07310567230597677*lm^2) + CF^2*(0.10187237980725546 + 
          0.17211326281692674*lm + 0.11962746377341653*lm^2) + 
        CF*((0.05755696394118884 + 0.016908372465335997*lm + 
            0.013291940419268502*lm^2)*NM + (0.07049089952901276 + 
            0.016908372465335997*lm + 0.013291940419268502*lm^2)*NL + 
          (0.003359878803770576 + 0.016908372465335997*lm + 
            0.013291940419268502*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.2540999279014553 - 0.18446379325183673*lm - 
          0.07255716949915997*lm^2) + CF^2*(0.10198402471883422 + 
          0.1705273631698152*lm + 0.11872991372589813*lm^2) + 
        CF*((0.05677871149766696 + 0.016748782690610985*lm + 
            0.013192212636210903*lm^2)*NM + (0.06991237581718111 + 
            0.016748782690610985*lm + 0.013192212636210903*lm^2)*NL + 
          (0.003382546842213735 + 0.016748782690610985*lm + 
            0.013192212636210903*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.25211554082783094 - 0.182889473112121*lm - 
          0.07201430553559812*lm^2) + CF^2*(0.10206136355653274 + 
          0.16893374185044602*lm + 0.1178415908764333*lm^2) + 
        CF*((0.05600717097706728 + 0.016588164078263756*lm + 
            0.013093510097381477*lm^2)*NM + (0.06933672172381565 + 
            0.016588164078263756*lm + 0.013093510097381477*lm^2)*NL + 
          (0.0034058352874375944 + 0.016588164078263756*lm + 
            0.013093510097381477*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.2501182667071868 - 0.18131724752309927*lm - 
          0.07147702480059787*lm^2) + CF^2*(0.10210564990532839 + 
          0.16733344279539442*lm + 0.11696240421916014*lm^2) + 
        CF*((0.055242522331026465 + 0.016426634306540858*lm + 
            0.012995822691017792*lm^2)*NM + (0.06876412662847048 + 
            0.016426634306540858*lm + 0.012995822691017792*lm^2)*NL + 
          (0.00342971935168656 + 0.016426634306540858*lm + 
            0.012995822691017792*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.2481099517114153 - 0.17974766188778907*lm - 
          0.07094527130377595*lm^2) + CF^2*(0.10211787091636418 + 
          0.16572745982029177*lm + 0.11609226213345157*lm^2) + 
        CF*((0.05448492751785071 + 0.01626430549607961*lm + 
            0.012899140237050175*lm^2)*NM + (0.06819476545843792 + 
            0.01626430549607961*lm + 0.012899140237050175*lm^2)*NL + 
          (0.0034541748651287798 + 0.01626430549607961*lm + 
            0.012899140237050175*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.2460923829647192 - 0.17818123194739047*lm - 
          0.07041898875987189*lm^2) + CF^2*(0.10209909927424346 + 
          0.16411673873695345*lm + 0.115231072516154*lm^2) + 
        CF*((0.05373453160969943 + 0.01610128444269568*lm + 
            0.012803452501794889*lm^2)*NM + (0.0676287995174533 + 
            0.01610128444269568*lm + 0.012803452501794889*lm^2)*NL + 
          (0.0034791782678823143 + 0.01610128444269568*lm + 
            0.012803452501794889*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.24406724746296496 - 0.17661844510673555*lm - 
          0.06989812066340022*lm^2) + CF^2*(0.10205039831635063 + 
          0.16250217938718173*lm + 0.11437874290374582*lm^2) + 
        CF*((0.05299146383668405 + 0.01593767284109897*lm + 
            0.012708749211527313*lm^2)*NM + (0.06706637726862123 + 
            0.01593767284109897*lm + 0.012708749211527313*lm^2)*NL + 
          (0.0035047066015401495 + 0.01593767284109897*lm + 
            0.012708749211527313*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.24203613707664492 - 0.17505976170411452*lm - 
          0.06938261035758057*lm^2) + CF^2*(0.10197282009995863 + 
          0.16088463759590518*lm + 0.11353518058513185*lm^2) + 
        CF*((0.05225583857142486 + 0.015773567499820357*lm + 
            0.01261502006501465*lm^2)*NM + (0.0665076350741128 + 
            0.015773567499820357*lm + 0.01261502006501465*lm^2)*NL + 
          (0.0035307375002635133 + 0.015773567499820357*lm + 
            0.01261502006501465*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.2400005533070449 - 0.1735056162275524*lm - 
          0.06887240109795008*lm^2) + CF^2*(0.10186740370742373 + 
          0.1592649270463166*lm + 0.11270029270573649*lm^2) + 
        CF*((0.051527756257426095 + 0.015609060547632649*lm + 
            0.012522254745081833*lm^2)*NM + (0.06595269789404141 + 
            0.015609060547632649*lm + 0.012522254745081833*lm^2)*NL + 
          (0.0035572491815072478 + 0.015609060547632649*lm + 
            0.012522254745081833*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.23796191180770698 - 0.17195641847956883*lm - 
          0.0683674361110332*lm^2) + CF^2*(0.10173517376789512 + 
          0.15764382107965585*lm + 0.11187398636350888*lm^2) + 
        CF*((0.050807304284434765 + 0.015444239631748635*lm + 
            0.012430442929278765*lm^2)*NM + (0.06540167994679007 + 
            0.015444239631748635*lm + 0.012430442929278765*lm^2)*NL + 
          (0.0035842204364348513 + 0.015444239631748635*lm + 
            0.012430442929278765*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.23592154668271983 - 0.1704125546924064*lm - 
          0.0678676586484161*lm^2) + CF^2*(0.10157713917578604 + 
          0.15602205442225903*lm + 0.11105616869740816*lm^2) + 
        CF*((0.05009455781376704 + 0.01527918810807678*lm + 
            0.012339574299712018*lm^2)*NM + (0.064854685332935 + 
            0.01527918810807678*lm + 0.012339574299712018*lm^2)*NL + 
          (0.003611630620074303 + 0.01527918810807678*lm + 
            0.012339574299712018*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.2338807145728406 - 0.16887438859566276*lm - 
          0.0673730120365472*lm^2) + CF^2*(0.10139429198794539 + 
          0.15440032484245775*lm + 0.11024674696889543*lm^2) + 
        CF*((0.04938958055645633 + 0.015113985223812057*lm + 
            0.012249638552099491*lm^2)*NM + (0.06431180862479065 + 
            0.015113985223812057*lm + 0.012249638552099491*lm^2)*NL + 
          (0.003639459641264744 + 0.015113985223812057*lm + 
            0.012249638552099491*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.2318405985399216 - 0.16734226243820907*lm - 
          0.06688343972256261*lm^2) + CF^2*(0.10118760648297148 + 
          0.1527792947398693*lm + 0.10944562863692064*lm^2) + 
        CF*((0.04869242550687301 + 0.014948706292635094*lm + 
            0.012160625404102293*lm^2)*NM + (0.06377313542348591 + 
            0.014948706292635094*lm + 0.012160625404102293*lm^2)*NL + 
          (0.0036676879524335793 + 0.014948706292635094*lm + 
            0.012160625404102293*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.22980231175961402 - 0.16581649796622236*lm - 
          0.06639888531641287*lm^2) + CF^2*(0.10095803836750833 + 
          0.151159592669567*lm + 0.10865272142685743*lm^2) + 
        CF*((0.048003135634308546 + 0.014783422862787861*lm + 
            0.01207252460298416*lm^2)*NM + (0.06323874288537484 + 
            0.014783422862787861*lm + 0.01207252460298416*lm^2)*NL + 
          (0.00369629653924601 + 0.014783422862787861*lm + 
            0.01207252460298416*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.22776690103185238 - 0.16429739735910334*lm - 
          0.06591929262954835*lm^2) + CF^2*(0.10070652411567114 + 
          0.14954181480356507*lm + 0.10786793339380639*lm^2) + 
        CF*((0.04732174453491209 + 0.014618202878288593*lm + 
            0.011985325932645154*lm^2)*NM + (0.06270870021948256 + 
            0.014618202878288593*lm + 0.011985325932645154*lm^2)*NL + 
          (0.003725266910159243 + 0.014618202878288593*lm + 
            0.011985325932645154*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.22573535011817675 - 0.16278524412499482*lm - 
          0.06544460571040171*lm^2) + CF^2*(0.10043398042894928 + 
          0.14792652633199174*lm + 0.10709117298065733*lm^2) + 
        CF*((0.04664827704629283 + 0.014453110833542466*lm + 
            0.011899019220073038*lm^2)*NM + (0.06218306915759127 + 
            0.014453110833542466*lm + 0.011899019220073038*lm^2)*NL + 
          (0.0037545810859162905 + 0.014453110833542466*lm + 
            0.011899019220073038*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.2237085829144405 - 0.16128030395755827*lm - 
          0.06497476887688945*lm^2) + CF^2*(0.10014130380487729 + 
          0.14631426280626236*lm + 0.10632234907127365*lm^2) + 
        CF*((0.04598274982669247 + 0.01428820792159816*lm + 
            0.011813594341252627*lm^2)*NM + (0.06166190439848079 + 
            0.01428820792159816*lm + 0.011813594341252627*lm^2)*NL + 
          (0.003784221589004632 + 0.01428820792159816*lm + 
            0.011813594341252627*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.22168746646715615 - 0.15978282555560955*lm - 
          0.06450972674613849*lm^2) + CF^2*(0.09982937020400426 + 
          0.14470553142649886*lm + 0.10556137103913571*lm^2) + 
        CF*((0.04532517190102635 + 0.014123552176293656*lm + 
            0.011729041226570635*lm^2)*NM + (0.06114525402775233 + 
            0.014123552176293656*lm + 0.011729041226570635*lm^2)*NL + 
          (0.003814171433107994 + 0.014123552176293656*lm + 
            0.011729041226570635*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.21967281384118414 - 0.15829304140715825*lm - 
          0.06404942426162959*lm^2) + CF^2*(0.09949903480530893 + 
          0.14310081227537566*lm + 0.10480814879175751*lm^2) + 
        CF*((0.04467554517538649 + 0.013959198608527712*lm + 
            0.011645349865750835*lm^2)*NM + (0.06063315991458361 + 
            0.013959198608527712*lm + 0.011645349865750835*lm^2)*NL + 
          (0.0038444141125735425 + 0.013959198608527712*lm + 
            0.011645349865750835*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.2176653868461958 - 0.15681116853933888*lm - 
          0.06359380671793606*lm^2) + CF^2*(0.09915113184126001 + 
          0.14150055950050494*lm + 0.1040625928111681*lm^2) + 
        CF*((0.04403386492194503 + 0.013795199336886325*lm + 
            0.01156251031235201*lm^2)*NM + (0.060125658086687316 + 
            0.013795199336886325*lm + 0.01156251031235201*lm^2)*NL + 
          (0.003874933591914564 + 0.013795199336886325*lm + 
            0.01156251031235201*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.21566589862891936 - 0.15533740923566727*lm - 
          0.06314281978322367*lm^2) + CF^2*(0.09878647450437274 + 
          0.1399052024474061*lm + 0.10332461419072965*lm^2) + 
        CF*((0.04340012023586971 + 0.013631603712846423*lm + 
            0.01148051268785885*lm^2)*NM + (0.059622779084673366 + 
            0.013631603712846423*lm + 0.01148051268785885*lm^2)*NL + 
          (0.003905714295368643 + 0.013631603712846423*lm + 
            0.01148051268785885*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.21367501613784948 - 0.15387195172200194*lm - 
          0.06269640951966643*lm^2) + CF^2*(0.09840585491785307 + 
          0.13831514674503662*lm + 0.10259412466854508*lm^2) + 
        CF*((0.042774294465853714 + 0.013468458440771753*lm + 
            0.011399347185393897*lm^2)*NM + (0.05912454829694761 + 
            0.013468458440771753*lm + 0.011399347185393897*lm^2)*NL + 
          (0.003936741096526163 + 0.013468458440771753*lm + 
            0.011399347185393897*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.2116933624667551 - 0.15241497082253608*lm - 
          0.06225452240192216*lm^2) + CF^2*(0.09801004416353769 + 
          0.13673077534579497*lm + 0.10187103665769082*lm^2) + 
        CF*((0.042156365619721255 + 0.01330580769290887*lm + 
            0.011319004073076757*lm^2)*NM + (0.05863098627621585 + 
            0.01330580769290887*lm + 0.011319004073076757*lm^2)*NL + 
          (0.003967999308044728 + 0.01330580769290887*lm + 
            0.011319004073076757*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.209721519083015 - 0.1509666285870962*lm - 
          0.061817105333802004*lm^2) + CF^2*(0.09759979236094897 + 
          0.13515244952183808*lm + 0.1011552632734942*lm^2) + 
        CF*((0.04154630674653495 + 0.01314369321958397*lm + 
            0.01123947369705491*lm^2)*NM + (0.05814210903860227 + 
            0.01314369321958397*lm + 0.01123947369705491*lm^2)*NL + 
          (0.003999474671464588 + 0.01314369321958397*lm + 
            0.01123947369705491*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.2077600279464999 - 0.1495270748909709*lm - 
          0.06138410566325894*lm^2) + CF^2*(0.09717582879180572 + 
          0.13358050981949196*lm + 0.10044671835806009*lm^2) + 
        CF*((0.040944086296513846 + 0.01298215445479429*lm + 
            0.0111607464842289*lm^2)*NM + (0.05765792834633423 + 
            0.01298215445479429*lm + 0.0111607464842289*lm^2)*NL + 
          (0.004031153347130207 + 0.01298215445479429*lm + 0.0111607464842289*
             lm^2)*NH))}, {0.415, 
      NC*(CA*CF*(-0.20580939352443586 - 0.1480964480084464*lm - 
          0.06095547119581183*lm^2) + CF^2*(0.09673886206483188 + 
          0.13201527697346777*lm + 0.09974531650223754*lm^2) + 
        CF*((0.04034966846000988 + 0.012821228617380907*lm + 
            0.01108281294469306*lm^2)*NM + (0.057178451974892505 + 
            0.012821228617380907*lm + 0.01108281294469306*lm^2)*NL + 
          (0.004063021904237587 + 0.012821228617380907*lm + 
            0.01108281294469306*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.20387008470741771 - 0.14667487516117714*lm - 
          0.06053115020651365*lm^2) + CF^2*(0.0962895803161717 + 
          0.13045705278253375*lm + 0.09905097306520416*lm^2) + 
        CF*((0.03976301348675127 + 0.012660950807962933*lm + 
            0.011005663673911573*lm^2)*NM + (0.05670368396547529 + 
            0.012660950807962933*lm + 0.011005663673911573*lm^2)*NL + 
          (0.004095067311006953 + 0.012660950807962933*lm + 
            0.011005663673911573*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.20194253663145412 - 0.14526247304247342*lm - 
          0.0601110914505654*lm^2) + CF^2*(0.09582865144108377 + 
          0.1289061209482307*lm + 0.09836360419183429*lm^2) + 
        CF*((0.03918407798637224 + 0.01250135410180648*lm + 
            0.010929289354648255*lm^2)*NM + (0.05623362486357716 + 
            0.01250135410180648*lm + 0.010929289354648255*lm^2)*NL + 
          (0.004127276924994127 + 0.01250135410180648*lm + 
            0.010929289354648255*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.2000271524107367 - 0.14385934831854497*lm - 
          0.059695244172670144*lm^2) + CF^2*(0.09535672335307936 + 
          0.1273627478781582*lm + 0.09768312682800569*lm^2) + 
        CF*((0.03861281521143112 + 0.01234246963779525*lm + 
            0.010853680758667298*lm^2)*NM + (0.055768271944439236 + 
            0.01234246963779525*lm + 0.010853680758667298*lm^2)*NL + 
          (0.004159638483545163 + 0.01234246963779525*lm + 
            0.010853680758667298*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.19812430478551057 - 0.14246559810769513*lm - 
          0.059283558115215594*lm^2) + CF^2*(0.09487442426686246 + 
          0.125827183455301*lm + 0.09700945873398915*lm^2) + 
        CF*((0.03804917532373633 + 0.012184326703663274*lm + 
            0.010778828748221017*lm^2)*NM + (0.055307619426084816 + 
            0.012184326703663274*lm + 0.010778828748221017*lm^2)*NL + 
          (0.004192140094403761 + 0.012184326703663274*lm + 
            0.010778828748221017*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.1962343376892793 - 0.14108131043841954*lm - 
          0.05887598352536756*lm^2) + CF^2*(0.09438236300190432 + 
          0.12429966177480642*lm + 0.096342518496056*lm^2) + 
        CF*((0.037493105645034476 + 0.01202695281764412*lm + 
            0.010704724277339556*lm^2)*NM + (0.05485165867061489 + 
            0.01202695281764412*lm + 0.010704724277339556*lm^2)*NL + 
          (0.004224770226462246 + 0.01202695281764412*lm + 
            0.010704724277339556*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.19435756773931118 - 0.13970656468732334*lm - 
          0.05847247116115121*lm^2) + CF^2*(0.09388112930367207 + 
          0.12278040184956948*lm + 0.09568222553642926*lm^2) + 
        CF*((0.03694455089287501 + 0.011870373806684955*lm + 
            0.010631358392936583*lm^2)*NM + (0.05440037837440051 + 
            0.011870373806684955*lm + 0.010631358392936583*lm^2)*NL + 
          (0.004257517700685792 + 0.011870373806684955*lm + 
            0.010631358392936583*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.19249428565424972 - 0.13834143199773188*lm - 
          0.05807297229659202*lm^2) + CF^2*(0.09337129417987325 + 
          0.12126960828592777*lm + 0.09502850012169603*lm^2) + 
        CF*((0.03640345340253719 + 0.011714613881367974*lm + 
            0.010558722235744004*lm^2)*NM + (0.053953764747773705 + 
            0.011714613881367974*lm + 0.010558722235744004*lm^2)*NL + 
          (0.00429037168118547 + 0.011714613881367974*lm + 
            0.010558722235744004*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.190644757602393 - 0.13698597567983378*lm - 
          0.05767743872598345*lm^2) + CF^2*(0.09285341024923074 + 
          0.11976747193071662*lm + 0.09438126336979111*lm^2) + 
        CF*((0.0358697533356986 + 0.011559695707676084*lm + 
            0.0104868070410879*lm^2)*NM + (0.05351180168478528 + 
            0.011559695707676084*lm + 0.0104868070410879*lm^2)*NL + 
          (0.004323321666460831 + 0.011559695707676084*lm + 
            0.0104868070410879*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.18880922648410428 - 0.1356402515931584*lm - 
          0.057285822767344056*lm^2) + CF^2*(0.092328012100688 + 
          0.11827417049088444*lm + 0.09374043725565391*lm^2) + 
        CF*((0.035343388876745825 + 0.011405640475734311*lm + 
            0.010415604139517101*lm^2)*NM + (0.05307447092356642 + 
            0.011405640475734311*lm + 0.010415604139517101*lm^2)*NL + 
          (0.0043563574808069844 + 0.011405640475734311*lm + 
            0.010415604139517101*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.18698791315154975 - 0.13430430851215686*lm - 
          0.056898077265122575*lm^2) + CF^2*(0.09179561666096007 + 
          0.11678986912681996*lm + 0.09310594461565512*lm^2) + 
        CF*((0.03482429641726404 + 0.01125246796565305*lm + 
            0.010345104957295013*lm^2)*NM + (0.05264175219780149 + 
            0.01125246796565305*lm + 0.010345104957295013*lm^2)*NL + 
          (0.004389469265889748 + 0.01125246796565305*lm + 
            0.010345104957295013*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.18518101756886968 - 0.13297818847562132*lm - 
          0.05651415559220572*lm^2) + CF^2*(0.09125672356868754 + 
          0.11531472102049559*lm + 0.09247770915088209*lm^2) + 
        CF*((0.03431241072946057 + 0.011100196610594287*lm + 
            0.010275301016764677*lm^2)*NM + (0.05221362337979133 + 
            0.011100196610594287*lm + 0.010275301016764677*lm^2)*NL + 
          (0.004422647472483335 + 0.011100196610594287*lm + 
            0.010275301016764677*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.18338871991570152 - 0.13166192712064712*lm - 
          0.056134011651279736*lm^2) + CF^2*(0.09071181555355483 + 
          0.11384886791948652*lm + 0.09185565542936684*lm^2) + 
        CF*((0.03380766512911523 + 0.010948843557176895*lm + 
            0.010206183936596315*lm^2)*NM + (0.05179006061556023 + 
            0.010948843557176895*lm + 0.010206183936596315*lm^2)*NL + 
          (0.0044558828523912405 + 0.010948843557176895*lm + 
            0.010206183936596315*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.18161118163683157 - 0.13035555400181117*lm - 
          0.055757599875593554*lm^2) + CF^2*(0.09016135881890693 + 
          0.11239244065788119*lm + 0.0912397088873349*lm^2) + 
        CF*((0.033309991628643384 + 0.010798424723332449*lm + 
            0.010137745431926101*lm^2)*NM + (0.05137103845243456 + 
            0.010798424723332449*lm + 0.010137745431926101*lm^2)*NL + 
          (0.004489166450515702 + 0.010798424723332449*lm + 
            0.010137745431926101*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.1798485464406149 - 0.12905909289621076*lm - 
          0.055384875229168185*lm^2) + CF^2*(0.0896058034265484 + 
          0.110945559655057*lm + 0.09062979582954794*lm^2) + 
        CF*((0.03281932108082502 + 0.010648954853718407*lm + 
            0.010069977314394216*lm^2)*NM + (0.050956529959498086 + 
            0.010648954853718407*lm + 0.010069977314394216*lm^2)*NL + 
          (0.004522489597112552 + 0.010648954853718407*lm + 
            0.010069977314394216*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.1781009412486707 - 0.12777256209497972*lm - 
          0.05501579320649404*lm^2) + CF^2*(0.08904558368254302 + 
          0.10950833539325447*lm + 0.09002584342880843*lm^2) + 
        CF*((0.032335583313729606 + 0.01050044757279108*lm + 
            0.010002871492089825*lm^2)*NM + (0.050546506841306266 + 
            0.01050044757279108*lm + 0.010002871492089825*lm^2)*NL + 
          (0.004555843900203098 + 0.01050044757279108*lm + 
            0.010002871492089825*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.17636847709923364 - 0.12649597468187182*lm - 
          0.05465030983175522*lm^2) + CF^2*(0.0884811185229513 + 
          0.10808086887484486*lm + 0.08942777972469036*lm^2) + 
        CF*((0.03185870725732473 + 0.010352915435636644*lm + 
            0.00993641996941004*lm^2)*NM + (0.05014093954522159 + 
            0.010352915435636644*lm + 0.00993641996941004*lm^2)*NL + 
          (0.004589221238158745 + 0.010352915435636644*lm + 
            0.00993641996941004*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.17465125001592885 - 0.12522933867541952*lm - 
          0.054288381683919376*lm^2) + CF*(0.08791280966448091 + 
          0.10666325180954316*lm + 0.08883553366459535*lm^2) + 
        0.031388621138287984*NM + 0.010206369948012288*lm*NM + 
        0.009870614851621703*lm^2*NM + 0.04973979742228275*NL + 
        0.010206369948012288*lm*NL + 0.009870614851621703*lm^2*NL + 
        0.004622613758261243*NH + 0.010206369948012288*lm*NH + 
        0.009870614851621703*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.1729493417863737 - 0.123972657805093*lm - 
          0.05392996578455069*lm^2) + CF*(0.08734105137822232 + 
          0.10525556808753564*lm + 0.08824903492017386*lm^2) + 
        0.03092525227190348*NM + 0.010060821733426666*lm*NM + 
        0.009805448324463763*lm^2*NM + 0.04934304857253431*NL + 
        0.010060821733426666*lm*NL + 0.009805448324463763*lm^2*NL + 
        0.004656013845189856*NH + 0.010060821733426666*lm*NH + 
        0.009805448324463763*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.17126282079864277 - 0.12272593092829316*lm - 
          0.05357501977078587*lm^2) + CF*(0.08676621601238615 + 
          0.10385789251239622*lm + 0.08766821417037687*lm^2) + 
        0.03046852767138089*NM + 0.009916280387111119*lm*NM + 
        0.00974091268559743*lm^2*NM + 0.04895066033086184*NL + 
        0.009916280387111119*lm*NL + 0.00974091268559743*lm^2*NL + 
        0.0046894141527376665*NH + 0.009916280387111119*lm*NH + 
        0.00974091268559743*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.16959174274098648 - 0.12148915284664683*lm - 
          0.053223501769392216*lm^2) + CF*(0.08618866486499592 + 
          0.10247029236478658*lm + 0.08709300289536907*lm^2) + 
        0.030018373789278085*NM + 0.009772754653580563*lm*NM + 
        0.009677000321707676*lm^2*NM + 0.04856259907278177*NL + 
        0.009772754653580563*lm*NL + 0.009677000321707676*lm^2*NL + 
        0.004722807569753553*NH + 0.009772754653580563*lm*NH + 
        0.009677000321707676*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.16793615131516895 - 0.1202623143720495*lm - 
          0.05287537042708968*lm^2) + CF*(0.08560874575893718 + 
          0.10109282745564595*lm + 0.08652333342614675*lm^2) + 
        0.029574716703890273*NM + 0.00963025243162461*lm*NM + 
        0.009613703714016306*lm^2*NM + 0.04817883036902668*NL + 
        0.00963025243162461*lm*NL + 0.009613703714016306*lm^2*NL + 
        0.004756187220813979*NH + 0.00963025243162461*lm*NH + 
        0.009613703714016306*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.16629607890550596 - 0.11904540253870789*lm - 
          0.052530584907618055*lm^2) + CF*(0.08502679341124114 + 
          0.09972555047847775*lm + 0.08595913893973864*lm^2) + 
        0.029137482204877833*NM + 0.009488780813539406*lm*NM + 
        0.009551015437748738*lm^2*NM + 0.04779931906115984*NL + 
        0.009488780813539406*lm*NL + 0.009551015437748738*lm^2*NL + 
        0.004789546459774296*NH + 0.009488780813539406*lm*NH + 
        0.009551015437748738*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.16467154721521038 - 0.1178384008057124*lm - 
          0.05218910488854258*lm^2) + CF*(0.08444312979744284 + 
          0.09836850734661345*lm + 0.08540035345397877*lm^2) + 
        0.028706595873347125*NM + 0.009348346122698185*lm*NM + 
        0.009488928161553197*lm^2*NM + 0.04742402933285113*NL + 
        0.009348346122698185*lm*NL + 0.009488928161553197*lm^2*NL + 
        0.004822878863475084*NH + 0.009348346122698185*lm*NH + 
        0.009488928161553197*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.16306256787162765 - 0.1166412892505533*lm - 
          0.051850890557820585*lm^2) + CF*(0.08385806451063586 + 
          0.09702173751608963*lm + 0.08484691182188824*lm^2) + 
        0.028281983156696344*NM + 0.009208953949530547*lm*NM + 
        0.009427434646876471*lm^2*NM + 0.04705292477704562*NL + 
        0.009208953949530547*lm*NL + 0.009427434646876471*lm^2*NL + 
        0.004856178225601175*NH + 0.009208953949530547*lm*NH + 
        0.009427434646876471*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.16146914300186602 - 0.11545404475397626*lm - 
          0.051515902610150106*lm^2) + CF*(0.08327189511489735 + 
          0.09568527429474734*lm + 0.08429874972570017*lm^2) + 
        0.027863569438521037*NM + 0.009070609185977479*lm*NM + 
        0.009366527747300018*lm^2*NM + 0.04668596845924401*NL + 
        0.009070609185977479*lm*NL + 0.009366527747300018*lm^2*NL + 
        0.004889438550690955*NH + 0.009070609185977479*lm*NH + 
        0.009366527747300018*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.15989126578025173 - 0.11427664117655498*lm - 
          0.05118410224312023*lm^2) + CF*(0.08268490749280406 + 
          0.09435914513813681*lm + 0.08375580367056037*lm^2) + 
        0.02745128010385788*NM + 0.008933316058486306*lm*NM + 
        0.009306200407840042*lm^2*NM + 0.046323122977102095*NL + 
        0.008933316058486306*lm*NL + 0.009306200407840042*lm^2*NL + 
        0.004922654048293441*NH + 0.008933316058486306*lm*NH + 
        0.009306200407840042*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.15832892094896836 - 0.11310904952734242*lm - 
          0.05085545115318168*lm^2) + CF*(0.08209737618680338 + 
          0.09304337193278524*lm + 0.08321801097793366*lm^2) + 
        0.02704504060002974*NM + 0.008797078159606996*lm*NM + 
        0.00924644566421485*lm^2*NM + 0.04596435051654561*NL + 
        0.008797078159606996*lm*NL + 0.00924644566421485*lm^2*NL + 
        0.004955819127270589*NH + 0.008797078159606996*lm*NH + 
        0.00924644566421485*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.15678208531317311 - 0.11195123812494641*lm - 
          0.05052991153145469*lm^2) + CF*(0.08150956473424202 + 
          0.09173797126736208*lm + 0.08268530977874404*lm^2) + 
        0.026644776493340773*NM + 0.008661898478248675*lm*NM + 
        0.009187256642082671*lm^2*NM + 0.04560961290458623*NL + 
        0.008661898478248675*lm*NL + 0.009187256642082671*lm^2*NL + 
        0.0049889283902422405*NH + 0.008661898478248675*lm*NH + 
        0.009187256642082671*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.15525072821181887 - 0.11080317275135938*lm - 
          0.05020744605939042*lm^2) + CF*(0.08092172599589136 + 
          0.09044295469225334*lm + 0.08215763900627522*lm^2) + 
        0.02625041352185639*NM + 0.008527779428652684*lm*NM + 
        0.009128626556252803*lm^2*NM + 0.0452588716590146*NL + 
        0.008527779428652684*lm*NL + 0.009128626556252803*lm^2*NL + 
        0.005021976628171058*NH + 0.008527779428652684*lm*NH + 
        0.009128626556252803*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.1537348119653503 - 0.1096648167988586*lm - 
          0.04988801790430078*lm^2) + CF*(0.08033410247783955 + 
          0.08915832896803413*lm + 0.08163493838885583*lm^2) + 
        0.025861877644490282*NM + 0.008394722878136092*lm*NM + 
        0.00907054870987287*lm^2*NM + 0.04491208803513684*NL + 
        0.008394722878136092*lm*NL + 0.00907054870987287*lm^2*NL + 
        0.005054958815084806*NH + 0.008394722878136092*lm*NH + 
        0.00907054870987287*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.15223429230138552 - 0.10853613141027837*lm - 
          0.049571590714770866*lm^2) + CF*(0.07974692664665121 + 
          0.08788409630330826*lm + 0.08111714844235232*lm^2) + 
        0.0254790950866082*NM + 0.008262730173657357*lm*NM + 
        0.009013016493594702*lm^2*NM + 0.04456922306971246*NL + 
        0.008262730173657357*lm*NL + 0.009013016493594702*lm^2*NL + 
        0.005087870102933275*NH + 0.008262730173657357*lm*NH + 
        0.009013016493594702*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.15074911875943986 - 0.10741707561294313*lm - 
          0.04925812861596688*lm^2) + CF*(0.0791604212377208 + 
          0.08662025458236357*lm + 0.08060421046249125*lm^2) + 
        0.02510199238234689*NM + 0.008131802167253522*lm*NM + 
        0.00895602338472125*lm^2*NM + 0.04423023762224272*NL + 
        0.008131802167253522*lm*NL + 0.00895602338472125*lm^2*NL + 
        0.005120705816577163*NH + 0.008131802167253522*lm*NH + 
        0.00895602338472125*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.14927923507569663 - 0.10630760644653711*lm - 
          0.04894759620485197*lm^2) + CF*(0.07857479955677021 + 
          0.08536679758307245*lm + 0.0800960665170305*lm^2) + 
        0.024730496413835592*NM + 0.008001939240396373*lm*NM + 
        0.008899562946336722*lm^2*NM + 0.04389509241375101*NL + 
        0.008001939240396373*lm*NL + 0.008899562946336722*lm^2*NL + 
        0.005153461448906205*NH + 0.008001939240396373*lm*NH + 
        0.008899562946336722*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.14782457954878145 - 0.1052076790851749*lm - 
          0.04863995854532126*lm^2) + CF*(0.07799026577446315 + 
          0.08412371518544853*lm + 0.07959265943779842*lm^2) + 
        0.02436453444749723*NM + 0.00787314132731283*lm*NM + 
        0.008843628826422046*lm^2*NM + 0.04356374806318922*NL + 
        0.00787314132731283*lm*NL + 0.008843628826422046*lm^2*NL + 
        0.005186132656083849*NH + 0.00787314132731283*lm*NH + 
        0.008843628826422046*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.14638508538744874 - 0.10411724695392467*lm - 
          0.04833518116326669*lm^2) + CF*(0.07740701521412714 + 
          0.08289099357125355*lm + 0.07909393281261821*lm^2) + 
        0.024004034167596743*NM + 0.007745407937313022*lm*NM + 
        0.008788214756957579*lm^2*NM + 0.0432361651215968*NL + 
        0.007745407937313022*lm*NL + 0.008788214756957579*lm^2*NL + 
        0.005218715252915779*NH + 0.007745407937313022*lm*NH + 
        0.008788214756957579*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.14496068104104615 - 0.10303626184002583*lm - 
          0.04803323004158166*lm^2) + CF*(0.07682523463259291 + 
          0.08166861541503083*lm + 0.07859983097713363*lm^2) + 
        0.023648923707194812*NM + 0.007618738176167618*lm*NM + 
        0.008733314553014848*lm^2*NM + 0.04291230410413288*NL + 
        0.007618738176167618*lm*NL + 0.008733314553014848*lm^2*NL + 
        0.005251205208339599*NH + 0.007618738176167618*lm*NH + 
        0.008733314553014848*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.14355129051357973 - 0.10196467399903125*lm - 
          0.047734071615114615*lm^2) + CF*(0.07624510249417511 + 
          0.08045656006692635*lm + 0.07811029900655118*lm^2) + 
        0.023299131676656565*NM + 0.007493130766574202*lm*NM + 
        0.008678922111839021*lm^2*NM + 0.04259212552009503*NL + 
        0.007493130766574202*lm*NL + 0.008678922111839021*lm^2*NL + 
        0.005283598641033009*NH + 0.007493130766574202*lm*NH + 
        0.008678922111839021*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.14215683366216275 - 0.10090243225609527*lm - 
          0.04743767276558019*lm^2) + CF*(0.07566678923783349 + 
          0.07925480372764299*lm + 0.07762528270731303*lm^2) + 
        0.02295458718985665*NM + 0.007368584067750832*lm*NM + 
        0.00862503141192367*lm^2*NM + 0.042275589901032785*NL + 
        0.007368584067750832*lm*NL + 0.00862503141192367*lm^2*NL + 
        0.005315891815137807*NH + 0.007368584067750832*lm*NH + 
        0.00862503141192367*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.14077722648059385 - 0.0998494841026178*lm - 
          0.04714400081643593*lm^2) + CF*(0.0750904575375651 + 
          0.07806331961585831*lm + 0.07714472860871334*lm^2) + 
        0.02261521988821435*NM + 0.00724509609419327*lm*NM + 
        0.00857163651207926*lm^2*NM + 0.04196265782705785*NL + 
        0.00724509609419327*lm*NL + 0.00857163651207926*lm^2*NL + 
        0.005348081136097097*NH + 0.00724509609419327*lm*NH + 
        0.00857163651207926*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.13941238136877332 - 0.09880577578844685*lm - 
          0.04685302352773202*lm^2) + CF*(0.07451626255608994 + 
          0.07688207812842285*lm + 0.07666858395447057*lm^2) + 
        0.022280959962685063*NM + 0.007122664533630861*lm*NM + 
        0.00851873155049673*lm^2*NM + 0.04165328995144793*NL + 
        0.007122664533630861*lm*NL + 0.00851873155049673*lm^2*NL + 
        0.005380163146603101*NH + 0.007122664533630861*lm*NH + 
        0.00851873155049673*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.1380622073886323 - 0.09777125240983185*lm - 
          0.04656470909094084*lm^2) + CF*(0.07394435219190139 + 
          0.07571104699364184*lm + 0.07619679669426684*lm^2) + 
        0.021951738173827538*NM + 0.007001286764214522*lm*NM + 
        0.008466310743807425*lm^2*NM + 0.041347447023635846*NL + 
        0.007001286764214522*lm*NL + 0.008466310743807425*lm^2*NL + 
        0.005412134522652976*NH + 0.007001286764214522*lm*NH + 
        0.008466310743807425*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.1367266105072178 - 0.09674585799331276*lm - 
          0.04627902612377296*lm^2) + CF*(0.07337486731976207 + 
          0.07455019141793097*lm + 0.07572931547526483*lm^2) + 
        0.021627485870059835*NM + 0.006880959870968907*lm*NM + 
        0.008414368386140538*lm^2*NM + 0.04104508991067094*NL + 
        0.006880959870968907*lm*NL + 0.008414368386140538*lm^2*NL + 
        0.005443992069710128*NH + 0.006880959870968907*lm*NH + 
        0.008414368386140538*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.13540549382754388 - 0.09572953557572103*lm - 
          0.04599594366498528*lm^2) + CF*(0.07280794202473284 + 
          0.07339947422612388*lm + 0.07526608963361227*lm^2) + 
        0.021308135004210655*NM + 0.006761680661539462*lm*NM + 
        0.008362898848179142*lm^2*NM + 0.04074617961723495*NL + 
        0.006761680661539462*lm*NL + 0.008362898848179142*lm^2*NL + 
        0.005475732718968466*NH + 0.006761680661539462*lm*NH + 
        0.008362898848179142*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.13409875780779254 - 0.09472222728046155*lm - 
          0.045715431169187096*lm^2) + CF*(0.07224370382982895 + 
          0.07225885599569763*lm + 0.07480706918594252*lm^2) + 
        0.02099361814846692*NM + 0.006643445681263765*lm*NM + 
        0.008311896576215835*lm^2*NM + 0.040450677304290625*NL + 
        0.006643445681263765*lm*NL + 0.008311896576215835*lm^2*NL + 
        0.005507353523717161*NH + 0.006643445681263765*lm*NH + 
        0.008311896576215835*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.13280630046941674 - 0.09372387439023666*lm - 
          0.04543745850164899*lm^2) + CF*(0.07168227391740364 + 
          0.07112829518517133*lm + 0.07435220482088016*lm^2) + 
        0.020683868507812987*NM + 0.00652625122759533*lm*NM + 
        0.008261356091208908*lm^2*NM + 0.04015854430643691*NL + 
        0.00652625122759533*lm*NL + 0.008261356091208908*lm^2*NL + 
        0.0055388516558034385*NH + 0.00652625122759533*lm*NH + 
        0.008261356091208908*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.13152801759467408 - 0.09273441741636694*lm - 
          0.045161995933119425*lm^2) + CF*(0.07112376734436358 + 
          0.07000774825692148*lm + 0.07390144789055907*lm^2) + 
        0.0203788199320516*NM + 0.006410093363906849*lm*NM + 
        0.008211271987839896*lm^2*NM + 0.03986974214804084*NL + 
        0.006410093363906849*lm*NL + 0.008211271987839896*lm^2*NL + 
        0.005570224402191022*NH + 0.006410093363906849*lm*NH + 
        0.008211271987839896*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.1302638029140933 - 0.09175379616485627*lm - 
          0.04488901413465338*lm^2) + CF*(0.07056829325132491 + 
          0.06889716979464836*lm + 0.07345475040216007*lm^2) + 
        0.020078406926491793*NM + 0.006294967932698705*lm*NM + 
        0.00816163893357334*lm^2*NM + 0.03958423255821265*NL + 
        0.006294967932698705*lm*NL + 0.00816163893357334*lm^2*NL + 
        0.005601469161611857*NH + 0.006294967932698705*lm*NH + 
        0.00816163893357334*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.12901354828435121 - 0.09078194979934259*lm - 
          0.044618484172457014*lm^2) + CF*(0.07001595506582195 + 
          0.06779651261571691*lm + 0.07301206500947512*lm^2) + 
        0.01978256466138428*NM + 0.0061808705682375245*lm*NM + 
        0.008112451667719458*lm^2*NM + 0.039301977484687*NL + 
        0.0061808705682375245*lm*NL + 0.008112451667719458*lm^2*NL + 
        0.005632583441308794*NH + 0.0061808705682375245*lm*NH + 
        0.008112451667719458*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.12777714385701627 - 0.08981881690106942*lm - 
          0.04435037750275226*lm^2) + CF*(0.06946685069968339 + 
          0.06670572787858678*lm + 0.0725733450045037*lm^2) + 
        0.019491228980180447*NM + 0.006067796708648462*lm*NM + 
        0.008063705000500411*lm^2*NM + 0.03902293910667012*NL + 
        0.006067796708648462*lm*NL + 0.008063705000500411*lm^2*NL + 
        0.005663564853866956*NH + 0.006067796708648462*lm*NH + 
        0.008063705000500411*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.12655447823859176 - 0.08886433552600749*lm - 
          0.044084665966664556*lm^2) + CF*(0.06892107274069294 + 
          0.06562476518553675*lm + 0.07213854430908745*lm^2) + 
        0.01920433640668688*NM + 0.005955741607483946*lm*NM + 
        0.008015393812120828*lm^2*NM + 0.03874707984670936*NL + 
        0.005955741607483946*lm*NL + 0.008015393812120828*lm^2*NL + 
        0.00569441111413154*NH + 0.005955741607483946*lm*NH + 
        0.008015393812120828*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.12534543864227216 - 0.08791844325925013*lm - 
          0.04382132178513705*lm^2) + CF*(0.06837870863865313 + 
          0.06455357268088027*lm + 0.0717076174665879*lm^2) + 
        0.01892182415118348*NM + 0.005844700344790624*lm*NM + 
        0.0079675130518431*lm^2*NM + 0.03847436238163891*NL + 
        0.005844700344790624*lm*NL + 0.0079675130518431*lm^2*NL + 
        0.005725120036209877*NH + 0.005844700344790624*lm*NH + 
        0.0079675130518431*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.12414991103180587 - 0.08698107726680084*lm - 
          0.04356031755387417*lm^2) + CF*(0.06783984088597214 + 
          0.06349209714486051*lm + 0.07128051963361227*lm^2) + 
        0.01864363011556938*NM + 0.005734667837695385*lm*NM + 
        0.007920057737068031*lm^2*NM + 0.03820474965265246*NL + 
        0.005734667837695385*lm*NL + 0.007920057737068031*lm^2*NL + 
        0.0057556895305555765*NH + 0.005734667837695385*lm*NH + 
        0.007920057737068031*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.1229677802578388 - 0.08605217434486616*lm - 
          0.04330162623831712*lm^2) + CF*(0.06730454719289432 + 
          0.062440284083405385*lm + 0.07085720657179165*lm^2) + 
        0.01836969289759743*NM + 0.005625638850530383*lm*NM + 
        0.007873022952421293*lm^2*NM + 0.03793820487455103*NL + 
        0.005625638850530383*lm*NL + 0.007873022952421293*lm^2*NL + 
        0.005786117601132656*NH + 0.005625638850530383*lm*NH + 
        0.007873022952421293*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.12179893018709634 - 0.08513167096676237*lm - 
          0.04304522116865382*lm^2) + CF*(0.06677290065749561 + 
          0.06139807781391538*lm + 0.07043763463961535*lm^2) + 
        0.018099951794254675*NM + 0.00551760800451624*lm*NM + 
        0.007826403848846149*lm^2*NM + 0.037674691544211734*NL + 
        0.00551760800451624*lm*NL + 0.007826403848846149*lm^2*NL + 
        0.0058164023426575924*NH + 0.00551760800451624*lm*NH + 
        0.007826403848846149*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.12064324382474309 - 0.08421950332753934*lm - 
          0.042791076034865566*lm^2) + CF*(0.06624496993056511 + 
          0.060365421547249845*lm + 0.07002176078432547*lm^2) + 
        0.017834346804343013*NM + 0.005410569787021733*lm*NM + 
        0.0077801956427028295*lm^2*NM + 0.03741417344832077*NL + 
        0.005410569787021733*lm*NL + 0.0077801956427028295*lm^2*NL + 
        0.005846541937917267*NH + 0.005410569787021733*lm*NH + 
        0.0077801956427028295*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.1195006034302449 - 0.08331560738642114*lm - 
          0.042539164881812246*lm^2) + CF*(0.06572081937549372 + 
          0.059342257466070275*lm + 0.0696095425338746*lm^2) + 
        0.017572818630311352*NM + 0.005304518560417538*lm*NM + 
        0.007734393614874954*lm^2*NM + 0.0371566146704117*NL + 
        0.005304518560417538*lm*NL + 0.007734393614874954*lm^2*NL + 
        0.005876534655160818*NH + 0.005304518560417538*lm*NH + 
        0.007734393614874954*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.1183708906270415 - 0.08241991890715793*lm - 
          0.04228946210435822*lm^2) + CF*(0.06520050922329057 + 
          0.058328526799692706*lm + 0.06920093798894983*lm^2) + 
        0.017315308679387638*NM + 0.00519944857054086*lm*NM + 
        0.007688993109883313*lm^2*NM + 0.036901979597248*NL + 
        0.00519944857054086*lm*NL + 0.007688993109883313*lm^2*NL + 
        0.005906378845563484*NH + 0.00519944857054086*lm*NH + 
        0.007688993109883313*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.1172539865063239 - 0.0815323734963802*lm - 
          0.04204194244254028*lm^2) + CF*(0.06468409572284697 + 
          0.05732416989559471*lm + 0.06879590581506592*lm^2) + 
        0.01706175906405655*NM + 0.0050953539547870805*lm*NM + 
        0.007643989535007324*lm^2*NM + 0.036650232924586794*NL + 
        0.0050953539547870805*lm*NL + 0.007643989535007324*lm^2*NL + 
        0.00593607294076052*NH + 0.0050953539547870805*lm*NH + 
        0.007643989535007324*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.11614977172519697 - 0.08065290664004231*lm - 
          0.041796580976779345*lm^2) + CF*(0.06417163128656707 + 
          0.056329126287716524*lm + 0.06839440523472984*lm^2) + 
        0.01681211260192605*NM + 0.004992228749843877*lm*NM + 
        0.0075993783594144266*lm^2*NM + 0.03640133966235882*NL + 
        0.004992228749843877*lm*NL + 0.0075993783594144266*lm^2*NL + 
        0.005965615450449354*NH + 0.004992228749843877*lm*NH + 
        0.0075993783594144266*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.11505812659949392 - 0.07978145373803808*lm - 
          0.04155335312313721*lm^2) + CF*(0.06366316463148258 + 
          0.05534333476169001*lm + 0.06799639601967906*lm^2) + 
        0.016566312815023666*NM + 0.004890066899082611*lm*NM + 
        0.007555155113297674*lm^2*NM + 0.03615526513929774*NL + 
        0.004890066899082611*lm*NL + 0.007555155113297674*lm^2*NL + 
        0.005995004960058157*NH + 0.004890066899082611*lm*NH + 
        0.007555155113297674*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.11397893119149757 - 0.07891795013706877*lm - 
          0.04131223462861953*lm^2) + CF*(0.06315874091596874 + 
          0.05436673341712348*lm + 0.06760183848319559*lm^2) + 
        0.016324303928561004*NM + 0.004788862259621209*lm*NM + 
        0.0075113153870217325*lm^2*NM + 0.03591197500705033*NL + 
        0.004788862259621209*lm*NL + 0.0075113153870217325*lm^2*NL + 
        0.006024240128479086*NH + 0.004788862259621209*lm*NH + 
        0.0075113153870217325*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.11291206539281048 - 0.07806233116183893*lm - 
          0.04107320156652615*lm^2) + CF*(0.06265840187217606 + 
          0.05339925972706514*lm + 0.06721069347249733*lm^2) + 
        0.01608603086920296*NM + 0.004688608609072102*lm*NM + 
        0.007467854830277482*lm^2*NM + 0.03567143524379738*NL + 
        0.004688608609072102*lm*NL + 0.007467854830277482*lm^2*NL + 
        0.00605331968586444*NH + 0.004688608609072102*lm*NH + 
        0.007467854830277482*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.11185740900260553 - 0.07721453214465339*lm - 
          0.04083623033184968*lm^2) + CF*(0.062162185934291854 + 
          0.052440850594762736*lm + 0.06682292236120857*lm^2) + 
        0.015851439262876018*NM + 0.004589299651988294*lm*NM + 
        0.007424769151245396*lm^2*NM + 0.035433612157413516*NL + 
        0.004589299651988294*lm*NL + 0.007424769151245396*lm^2*NL + 
        0.006082242431484073*NH + 0.004589299651988294*lm*NH + 
        0.007424769151245396*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.11081484180147698 - 0.0763744884534852*lm - 
          0.04060129763672324*lm^2) + CF*(0.06167012836274321 + 
          0.051491442407832065*lm + 0.06643848704191076*lm^2) + 
        0.015620475432148088*NM + 0.00449092902602003*lm*NM + 
        0.007382054115767861*lm^2*NM + 0.03519847238819285*NL + 
        0.00449092902602003*lm*NL + 0.007382054115767861*lm^2*NL + 
        0.0061110072316424005*NH + 0.00449092902602003*lm*NH + 
        0.007382054115767861*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.10978424362110217 - 0.07554213551858119*lm - 
          0.040368380505918*lm^2) + CF*(0.06118226136445162 + 
          0.05055097108994242*lm + 0.0660573499187749*lm^2) + 
        0.015393086393210529*NM + 0.004393490307794067*lm*NM + 
        0.007339705546530545*lm^2*NM + 0.03496598291116585*NL + 
        0.004393490307794067*lm*NL + 0.007339705546530545*lm^2*NL + 
        0.006139613017653407*NH + 0.004393490307794067*lm*NH + 
        0.007339705546530545*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.1087654944099139 - 0.07471740885766914*lm - 
          0.040137456272391195*lm^2) + CF*(0.060698614209247666 + 
          0.049619372150122465*lm + 0.0656794739002765*lm^2) + 
        0.015169219852491332*NM + 0.004296977018527006*lm*NM + 
        0.007297719322252944*lm^2*NM + 0.03473611103803147*NL + 
        0.004296977018527006*lm*NL + 0.007297719322252944*lm^2*NL + 
        0.00616805878387208*NH + 0.004296977018527006*lm*NH + 
        0.007297719322252944*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.10775847429497445 - 0.07390024409982783*lm - 
          0.03990850257288517*lm^2) + CF*(0.06021921334255191 + 
          0.04869658072978561*lm + 0.06530482239199391*lm^2) + 
        0.01494882420292674*NM + 0.004201382629383699*lm*NM + 
        0.007256091376888213*lm^2*NM + 0.03450882441872743*NL + 
        0.004201382629383699*lm*NL + 0.007256091376888213*lm^2*NL + 
        0.0061963435857807486*NH + 0.004201382629383699*lm*NH + 
        0.007256091376888213*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.10676306364023314 - 0.07309057700807846*lm - 
          0.03968149734357782*lm^2) + CF*(0.05974408249442672 + 
          0.04778253164757018*lm + 0.06493335928949098*lm^2) + 
        0.014731848519917075*NM + 0.004106700566591298*lm*NM + 
        0.0072148176988323315*lm^2*NM + 0.03428409104266036*NL + 
        0.004106700566591298*lm*NL + 0.0072148176988323315*lm^2*NL + 
        0.0062244665381288354*NH + 0.004106700566591298*lm*NH + 
        0.0072148176988323315*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.10577914310134068 - 0.0722883435007536*lm - 
          0.039456418815784884*lm^2) + CF*(0.059273242785101175 + 
          0.04687715944208533*lm + 0.06456504897128434*lm^2) + 
        0.014518242556991093*NM + 0.00401292421631903*lm*NM + 
        0.007173894330142706*lm^2*NM + 0.034061879239616163*NL + 
        0.00401292421631903*lm*NL + 0.007173894330142706*lm^2*NL + 
        0.006252426813124569*NH + 0.00401292421631903*lm*NH + 
        0.007173894330142706*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.10480659367718596 - 0.07149347967169736*lm - 
          0.03923324551171422*lm^2) + CF*(0.05880671282706956 + 
          0.045980398412650114*lm + 0.064199856291896*lm^2) + 
        0.014307956741201791*NM + 0.00392004692933342*lm*NM + 
        0.007133317365766221*lm^2*NM + 0.033842157680370244*NL + 
        0.00392004692933342*lm*NL + 0.007133317365766221*lm^2*NL + 
        0.006280223638677242*NH + 0.00392004692933342*lm*NH + 
        0.007133317365766221*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.10384529675831264 - 0.07070592180934815*lm - 
          0.039011956240272525*lm^2) + CF*(0.05834450882386164 + 
          0.04509218265810953*lm + 0.0638377465749914*lm^2) + 
        0.014100942168275298*NM + 0.0038280620254382545*lm*NM + 
        0.007093082952776822*lm^2*NM + 0.033624895377015886*NL + 
        0.0038280620254382545*lm*NL + 0.007093082952776822*lm^2*NL + 
        0.006307856296688641*NH + 0.0038280620254382545*lm*NH + 
        0.007093082952776822*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.10289513417236598 - 0.06992560641475329*lm - 
          0.03879253009292436*lm^2) + CF*(0.05788664466558093 + 
          0.04421244611380758*lm + 0.06347868560660351*lm^2) + 
        0.013897150597533235*NM + 0.003736962797708184*lm*NM + 
        0.007053187289622611*lm^2*NM + 0.03341006168302833*NL + 
        0.003736962797708184*lm*NL + 0.007053187289622611*lm^2*NL + 
        0.006335324121392298*NH + 0.003736962797708184*lm*NH + 
        0.007053187289622611*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.10195598822671326 - 0.06915247021856252*lm - 
          0.03857494643960381*lm^2) + CF*(0.05743313202130494 + 
          0.04334112258679458*lm + 0.0631226396284426*lm^2) + 
        0.013696534446607761*NM + 0.0036467425165245346*lm*NM + 
        0.007013626625382512*lm^2*NM + 0.03319762629308112*NL + 
        0.0036467425165245346*lm*NL + 0.007013626625382512*lm^2*NL + 
        0.006362626497739245*NH + 0.0036467425165245346*lm*NH + 
        0.007013626625382512*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.10102774174837431 - 0.06838645019704558*lm - 
          0.03835918492467859*lm^2) + CF*(0.056983980428439475 + 
          0.04247814578934226*lm + 0.06276957533129224*lm^2) + 
        0.013499046785967425*NM + 0.0035573944334215063*lm*NM + 
        0.006974397259032471*lm^2*NM + 0.032987559242630325*NL + 
        0.0035573944334215063*lm*NL + 0.006974397259032471*lm^2*NL + 
        0.0063897628598290285*NH + 0.0035573944334215063*lm*NH + 
        0.006974397259032471*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.10011027812139267 - 0.06762748358717706*lm - 
          0.038145225462966774*lm^2) + CF*(0.05653919737911662 + 
          0.041623449370837465*lm + 0.062419459848491086*lm^2) + 
        0.013304641333270901*NM + 0.0034689117847506237*lm*NM + 
        0.006935495538721232*lm^2*NM + 0.03277983090728158*NL + 
        0.0034689117847506237*lm*NL + 0.006935495538721232*lm^2*NL + 
        0.006416732689384694*NH + 0.0034689117847506237*lm*NH + 
        0.006935495538721232*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.09920348132177136 - 0.06687550790082974*lm - 
          0.03793304823580594*lm^2) + CF*(0.05609878840372422 + 
          0.040776966948122224*lm + 0.06207226074950063*lm^2) + 
        0.013113272447564644*NM + 0.003381287795170976*lm*NM + 
        0.006896917861055626*lm^2*NM + 0.03257441200195404*NL + 
        0.003381287795170976*lm*NL + 0.006896917861055626*lm^2*NL + 
        0.0064435355142705795*NH + 0.003381287795170976*lm*NH + 
        0.006896917861055626*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.09830723595009197 - 0.06613046093811628*lm - 
          0.037722633687174635*lm^2) + CF*(0.05566275715165242 + 
          0.03993863213434527*lm + 0.061727946033558495*lm^2) + 
        0.012924895123339648*NM + 0.0032945156809724655*lm*NM + 
        0.0068586606703953884*lm^2*NM + 0.032371273579854455*NL + 
        0.0032945156809724655*lm*NL + 0.0068586606703953884*lm^2*NL + 
        0.006470170907051701*NH + 0.0032945156809724655*lm*NH + 
        0.0068586606703953884*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.09742142726193012 - 0.06539228079991677*lm - 
          0.037513962519866044*lm^2) + CF*(0.05523110546934069 + 
          0.03910837856638725*lm + 0.06138648412341716*lm^2) + 
        0.012739464984461532*NM + 0.0032085886532390064*lm*NM + 
        0.006820720458157462*lm^2*NM + 0.03217038703127422*NL + 
        0.0032085886532390064*lm*NL + 0.006820720458157462*lm^2*NL + 
        0.006496638483593607*NH + 0.0032085886532390064*lm*NH + 
        0.006820720458157462*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.09654594119617471 - 0.0646609058996289*lm - 
          0.03730701569171359*lm^2) + CF*(0.05480383347570679 + 
          0.0382861399309194*lm + 0.061047843859167686*lm^2) + 
        0.012556938277987347*NM + 0.00312349992085831*lm*NM + 
        0.006783093762129743*lm^2*NM + 0.03197172408222113*NL + 
        0.00312349992085831*lm*NL + 0.006783093762129743*lm^2*NL + 
        0.006522937901701572*NH + 0.00312349992085831*lm*NH + 
        0.006783093762129743*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.09568066440135424 - 0.06393627497417514*lm - 
          0.03710177441186831*lm^2) + CF*(0.05438093963503704 + 
          0.037471849989153067*lm + 0.06071199449214814*lm^2) + 
        0.012377271867881755*NM + 0.003039242693384634*lm*NM + 
        0.006745777165794237*lm^2*NM + 0.031775256792897395*NL + 
        0.003039242693384634*lm*NL + 0.006745777165794237*lm^2*NL + 
        0.006549068859798057*NH + 0.003039242693384634*lm*NH + 
        0.006745777165794237*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.09482548426006761 - 0.06321832709430042*lm - 
          0.036898220137127666*lm^2) + CF*(0.053962420827415106 + 
          0.03666544260033492*lm + 0.060378905678936175*lm^2) + 
        0.012200423228644397*NM + 0.002955810183760618*lm*NM + 
        0.006708767297659575*lm^2*NM + 0.03158095755603443*NL + 
        0.002955810183760618*lm*NL + 0.006708767297659575*lm^2*NL + 
        0.006575031095637353*NH + 0.002955810183760618*lm*NH + 
        0.006708767297659575*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.09398028891161357 - 0.06250700167419203*lm - 
          0.03669633456831553*lm^2) + CF*(0.053548272416764665 + 
          0.035866851744040674*lm + 0.060048547475425415*lm^2) + 
        0.012026350438859645*NM + 0.002873195610904049*lm*NM + 
        0.006672060830602824*lm^2*NM + 0.031388799095094816*NL + 
        0.002873195610904049*lm*NL + 0.006672060830602824*lm^2*NL + 
        0.0066008243850564155*NH + 0.002873195610904049*lm*NH + 
        0.006672060830602824*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.09314496727290723 - 0.06180223848045246*lm - 
          0.03649609964671299*lm^2) + CF*(0.05313848831657925 + 
          0.03507601154131769*lm + 0.059720890330984905*lm^2) + 
        0.011855012174679148*NM + 0.0027913922021652084*lm*NM + 
        0.006635654481220545*lm^2*NM + 0.031198754462350826*NL + 
        0.0027913922021652084*lm*NL + 0.006635654481220545*lm^2*NL + 
        0.00662644854076085*NH + 0.0027913922021652084*lm*NH + 
        0.006635654481220545*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.09231940905776932 - 0.06110397764045417*lm - 
          0.036297497550539674*lm^2) + CF*(0.05273306105341057 + 
          0.03429285627472509*lm + 0.05939590508270129*lm^2) + 
        0.011686367703247082*NM + 0.002710393195660172*lm*NM + 
        0.006599545009189032*lm^2*NM + 0.031010797036848763*NL + 
        0.002710393195660172*lm*NL + 0.006599545009189032*lm^2*NL + 
        0.006651903411145105*NH + 0.002710393195660172*lm*NH + 
        0.006599545009189032*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.09150350479466877 - 0.060412159650104484*lm - 
          0.03610051069148511*lm^2) + CF*(0.052331981828184854 + 
          0.033517320407317766*lm + 0.05907356294970291*lm^2) + 
        0.01152037687607727*NM + 0.002630191842485253*lm*NM + 
        0.006563729216633656*lm^2*NM + 0.030824900522267655*NL + 
        0.002630191842485253*lm*NL + 0.006563729216633656*lm^2*NL + 
        0.006677188879145897*NH + 0.002630191842485253*lm*NH + 
        0.006563729216633656*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.09069714584299629 - 0.05972672538104724*lm - 
          0.03590512171128986*lm^2) + CF*(0.0519352405754145 + 
          0.03274933860061879*lm + 0.058753835527565225*lm^2) + 
        0.011357000122390888*NM + 0.002550781408817546*lm*NM + 
        0.006528203947507247*lm^2*NM + 0.03064103894468051*NL + 
        0.002550781408817546*lm*NL + 0.006528203947507247*lm^2*NL + 
        0.006702304861127978*NH + 0.002550781408817546*lm*NH + 
        0.006528203947507247*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0899002244079425 - 0.05904761608732692*lm - 
          0.03571131347837592*lm^2) + CF*(0.051542826020370996 + 
          0.03198884573162318*lm + 0.05843669478279695*lm^2) + 
        0.011196198442422823*NM + 0.0024721551779063357*lm*NM + 
        0.006492966086977439*lm^2*NM + 0.030459186650225754*NL + 
        0.0024721551779063357*lm*NL + 0.006492966086977439*lm^2*NL + 
        0.006727251305801306*NH + 0.0024721551779063357*lm*NH + 
        0.006492966086977439*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.08911263355405112 - 0.05837477341153995*lm - 
          0.035519069084525935*lm^2) + CF*(0.05115472573428277 + 
          0.031235776908873813*lm + 0.058122113047406075*lm^2) + 
        0.011037933400704355*NM + 0.0023943064519599405*lm*NM + 
        0.006458012560822898*lm^2*NM + 0.030279318302696256*NL + 
        0.0023943064519599405*lm*NL + 0.006458012560822898*lm^2*NL + 
        0.00675202819316879*NH + 0.0023943064519599405*lm*NH + 
        0.006458012560822898*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.08833426721751417 - 0.05770813939049646*lm - 
          0.03532837184161089*lm^2) + CF*(0.050770926187620025 + 
          0.030490067487648872*lm + 0.0578100630135451*lm^2) + 
        0.01088216711932923*NM + 0.0023172285539323732*lm*NM + 
        0.006423340334838344*lm^2*NM + 0.03010140888105272*NL + 
        0.0023172285539323732*lm*NL + 0.006423340334838344*lm^2*NL + 
        0.0067766355335037234*NH + 0.0023172285539323732*lm*NH + 
        0.006423340334838344*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.08756502021727319 - 0.05704765646041523*lm - 
          0.03513920527836566*lm^2) + CF*(0.05039141280152697 + 
          0.029751653084298644*lm + 0.05750051772823471*lm^2) + 
        0.010728862271209852*NM + 0.0022409148292140213*lm*NM + 
        0.006388946414248301*lm^2*NM + 0.029925433676868035*NL + 
        0.0022409148292140213*lm*NL + 0.006388946414248301*lm^2*NL + 
        0.006801073366356104*NH + 0.0022409148292140213*lm*NH + 
        0.006388946414248301*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.08680478826498772 - 0.05639326746167337*lm - 
          0.034951553137212044*lm^2) + CF*(0.05001616999745991 + 
          0.02902046958976768*lm + 0.05719345058816516*lm^2) + 
        0.010577982073329783*NM + 0.0021653586472303874*lm*NM + 
        0.0063548278431294625*lm^2*NM + 0.029751368291708713*NL + 
        0.0021653586472303874*lm*NL + 0.0063548278431294625*lm^2*NL + 
        0.006825341759587027*NH + 0.0021653586472303874*lm*NH + 
        0.0063548278431294625*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.08605346797392882 - 0.055744915643131346*lm - 
          0.03476539937112881*lm^2) + CF*(0.04964518124508819 + 
          0.028296453182337165*lm + 0.056888835334574415*lm^2) + 
        0.010429490279998399*NM + 0.0020905534029527512*lm*NM + 
        0.006320981703841602*lm^2*NM + 0.02957918863445923*NL + 
        0.0020905534029527512*lm*NL + 0.006320981703841602*lm^2*NL + 
        0.006849440808430376*NH + 0.0020905534029527512*lm*NH + 
        0.006320981703841602*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.08531095686685357 - 0.055102544666053174*lm - 
          0.03458072814056814*lm^2) + CF*(0.049278429108513155 + 
          0.02757954033962071*lm + 0.05658664604820241*lm^2) + 
        0.010283351176113169*NM + 0.0020164925183244783*lm*NM + 
        0.0062874051164669344*lm^2*NM + 0.029408870918594794*NL + 
        0.0020164925183244783*lm*NL + 0.0062874051164669344*lm^2*NL + 
        0.006873370634581037*NH + 0.0020164925183244783*lm*NH + 
        0.0062874051164669344*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.08457715338291323 - 0.054466098607640706*lm - 
          0.03439752381041807*lm^2) + CF*(0.04891589529085888 + 
          0.02686966784984548*lm + 0.056286857144320475*lm^2) + 
        0.010139529570434586*NM + 0.0019431694436065259*lm*NM + 
        0.0062540952382578304*lm^2*NM + 0.029240391659407658*NL + 
        0.0019431694436065259*lm*NL + 0.0062540952382578304*lm^2*NL + 
        0.006897131385308929*NH + 0.0019431694436065259*lm*NH + 
        0.0062540952382578304*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.08385195688364563 - 0.05383552196420024*lm - 
          0.03421577094701038*lm^2) + CF*(0.04855756067728669 + 
          0.02616677282244937*lm + 0.055989443367835165*lm^2) + 
        0.00999799078887853*NM + 0.001870577658645575*lm*NM + 
        0.006221049263092797*lm^2*NM + 0.029073727671191985*NL + 
        0.001870577658645575*lm*NL + 0.006221049263092797*lm^2*NL + 
        0.006920723232598092*NH + 0.001870577658645575*lm*NH + 
        0.006221049263092797*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.08313526765809989 - 0.053210759653958675*lm - 
          0.03403545431517339*lm^2) + CF*(0.04820340537648404 + 
          0.025470792698023517*lm + 0.055694379788465545*lm^2) + 
        0.009858700667830431*NM + 0.0017987106740680657*lm*NM + 
        0.006188264420940616*lm^2*NM + 0.028908856064391798*NL + 
        0.0017987106740680657*lm*NL + 0.006188264420940616*lm^2*NL + 
        0.006944146372310172*NH + 0.0017987106740680657*lm*NH + 
        0.006188264420940616*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.08242698692713939 - 0.052591757019546034*lm - 
          0.03385655887532914*lm^2) + CF*(0.04785340876067676 + 
          0.02478166525762839*lm + 0.05540164179599313*lm^2) + 
        0.009721625547485352*NM + 0.0017275620324032814*lm*NM + 
        0.00615573797733257*lm^2*NM + 0.028745754242716394*NL + 
        0.0017275620324032814*lm*NL + 0.00615573797733257*lm^2*NL + 
        0.006967401023371598*NH + 0.0017275620324032814*lm*NH + 
        0.00615573797733257*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.08172701684696677 - 0.05197845983016016*lm - 
          0.033679069780634445*lm^2) + CF*(0.047507549504212356 + 
          0.02409932863151048*lm + 0.055111205095583635*lm^2) + 
        0.009586732265217794*NM + 0.0016571253091385045*lm*NM + 
        0.006123467232842627*lm^2*NM + 0.028584399900227393*NL + 
        0.0016571253091385045*lm*NL + 0.006123467232842627*lm^2*NL + 
        0.0069904874269838034*NH + 0.0016571253091385045*lm*NH + 
        0.006123467232842627*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.08103526051191284 - 0.05137081428342883*lm - 
          0.03350297237416529*lm^2) + CF*(0.047165805620760455 + 
          0.023423721307245533*lm + 0.054823045703179564*lm^2) + 
        0.009453988148984748*NM + 0.0015873941137091413*lm*NM + 
        0.006091449522575508*lm^2*NM + 0.0284247710184012*NL + 
        0.0015873941137091413*lm*NL + 0.006091449522575508*lm^2*NL + 
        0.00701340584585585*NH + 0.0015873941137091413*lm*NH + 
        0.006091449522575508*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.08035162195652878 - 0.05076876700698404*lm - 
          0.03332825218614395*lm^2) + CF*(0.046828154499175226 + 
          0.022754782137333184*lm + 0.05453713994096283*lm^2) + 
        0.00932336101076526*NM + 0.001518362090426598*lm*NM + 
        0.006059682215662536*lm^2*NM + 0.02826684586317061*NL + 
        0.001518362090426598*lm*NL + 0.006059682215662536*lm^2*NL + 
        0.0070361565634588265*NH + 0.001518362090426598*lm*NH + 
        0.006059682215662536*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.07967600615702022 - 0.050172265059762286*lm - 
          0.033154894931208385*lm^2) + CF*(0.046494572938063174 + 
          0.02209245034626691*lm + 0.05425346443288645*lm^2) + 
        0.009194819140039553*NM + 0.0014500229193465746*lm*NM + 
        0.006028162714765161*lm^2*NM + 0.028110602981949*NL + 
        0.0014500229193465746*lm*NL + 0.006028162714765161*lm^2*NL + 
        0.007058739883301416*NH + 0.0014500229193465746*lm*NH + 
        0.006028162714765161*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.07900831903205868 - 0.04958125593304431*lm - 
          0.03298288650572335*lm^2) + CF*(0.046165037179098464 + 
          0.021436665537102155*lm + 0.05397199610027457*lm^2) + 
        0.009068331297310467*NM + 0.0013823703170803398*lm*NM + 
        0.005996888455586063*lm^2*NM + 0.027956021200640262*NL + 
        0.0013823703170803398*lm*NL + 0.005996888455586063*lm^2*NL + 
        0.007081156128226049*NH + 0.0013823703170803398*lm*NH + 
        0.005996888455586063*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.07834846744300548 - 0.04899568755124716*lm - 
          0.0328122129851326*lm^2) + CF*(0.04583952293912659 + 
          0.020787367697544613*lm + 0.05369271215748971*lm^2) + 
        0.008943866707669834*NM + 0.001315398037551444*lm*NM + 
        0.0059658569063877455*lm^2*NM + 0.02780307962063762*NL + 
        0.001315398037551444*lm*NL + 0.0059658569063877455*lm^2*NL + 
        0.007103405639725059*NH + 0.001315398037551444*lm*NH + 
        0.0059658569063877455*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.07769635919358056 - 0.04841550827248075*lm - 
          0.03264286062135176*lm^2) + CF*(0.045518005441095986 + 
          0.020144497205579783*lm + 0.05341559010766651*lm^2) + 
        0.0088213950544121*NM + 0.0012490998727002257*lm*NM + 
        0.005935065567518501*lm^2*NM + 0.027651757615814142*NL + 
        0.0012490998727002257*lm*NL + 0.005935065567518501*lm^2*NL + 
        0.007125488777276292*NH + 0.0012490998727002257*lm*NH + 
        0.005935065567518501*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.07705190302900779 - 0.04784066688888077*lm - 
          0.03247481584020118*lm^2) + CF*(0.04520045944385596 + 
          0.019507994834663932*lm + 0.053140607738511016*lm^2) + 
        0.00870088647269742*NM + 0.001183469653138381*lm*NM + 
        0.005904511970945669*lm^2*NM + 0.02750203482950767*NL + 
        0.001183469653138381*lm*NL + 0.005904511970945669*lm^2*NL + 
        0.007147405917697627*NH + 0.001183469653138381*lm*NH + 
        0.005904511970945669*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.07641500863466656 - 0.04727111262672918*lm - 
          0.032308065238878386*lm^2) + CF*(0.044886859270858136 + 
          0.018877801758495953*lm + 0.05286774311816463*lm^2) + 
        0.008582311543266179*NM + 0.0011185012487557608*lm*NM + 
        0.005874193679796071*lm^2*NM + 0.027353891171502664*NL + 
        0.0011185012487557608*lm*NL + 0.005874193679796071*lm^2*NL + 
        0.007169157454519879*NH + 0.0011185012487557608*lm*NH + 
        0.005874193679796071*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.07578558663427816 - 0.04670679514637293*lm - 
          0.03214259558346946*lm^2) + CF*(0.044577178837797486 + 
          0.01825385955538867*lm + 0.05259697459113184*lm^2) + 
        0.008465641286206754*NM + 0.0010541885692814848*lm*NM + 
        0.0058441082879035385*lm^2*NM + 0.027207306815011358*NL + 
        0.0010541885692814848*lm*NL + 0.0058441082879035385*lm^2*NL + 
        0.007190743797377569*NH + 0.0010541885692814848*lm*NH + 
        0.0058441082879035385*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.07516354858765402 - 0.04614766454195148*lm - 
          0.03197839380649881*lm^2) + CF*(0.04427139167922779 + 
          0.017636110212257458*lm + 0.052328280774270784*lm^2) + 
        0.008350847154778197*NM + 0.0009905255648013699*lm*NM + 
        0.005814253419363421*lm^2*NM + 0.02706226219365647*NL + 
        0.0009905255648013699*lm*NL + 0.005814253419363421*lm^2*NL + 
        0.007212165371417077*NH + 0.0009905255648013699*lm*NH + 
        0.005814253419363421*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.07454880698803182 - 0.04559367134094268*lm - 
          0.031815447004516925*lm^2) + CF*(0.043969470974185576 + 
          0.01702449612824333*lm + 0.05206164055284588*lm^2) + 
        0.0082379010292893*NM + 0.0009275062262335945*lm*NM + 
        0.005784626728093986*lm^2*NM + 0.026918737998457506*NL + 
        0.0009275062262335945*lm*NL + 0.005784626728093986*lm^2*NL + 
        0.007233422616721683*NH + 0.0009275062262335945*lm*NH + 
        0.005784626728093986*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.07394127525902386 - 0.04504476650353672*lm - 
          0.031653742435725385*lm^2) + CF*(0.04367138957085503 + 
          0.01641896011798687*lm + 0.05179703307664154*lm^2) + 
        0.008126775211035414*NM + 0.0008651245857644386*lm*NM + 
        0.005755225897404615*lm^2*NM + 0.02677671517482266*NL + 
        0.0008651245857644386*lm*NL + 0.005755225897404615*lm^2*NL + 
        0.007254515987753028*NH + 0.0008651245857644386*lm*NH + 
        0.005755225897404615*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.07334086775120148 - 0.044500901421847046*lm - 
          0.03149326751763875*lm^2) + CF*(0.04337712001030598 + 
          0.015819445414568836*lm + 0.051534437756136135*lm^2) + 
        0.008017442416294224*NM + 0.0008033747172458681*lm*NM + 
        0.005726048639570682*lm^2*NM + 0.026636174919548124*NL + 
        0.0008033747172458681*lm*NL + 0.005726048639570682*lm^2*NL + 
        0.0072754459528085414*NH + 0.0008033747172458681*lm*NH + 
        0.005726048639570682*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.07274749973833765 - 0.043962027918966924*lm - 
          0.031334009824782724*lm^2) + CF*(0.04308663454933548 + 
          0.015225895672132507*lm + 0.05127383425873537*lm^2) + 
        0.007909875770381589*NM + 0.0007422507365566606*lm*NM + 
        0.0056970926954150415*lm^2*NM + 0.026497098677826507*NL + 
        0.0007422507365566606*lm*NL + 0.0056970926954150415*lm^2*NL + 
        0.007296212993494394*NH + 0.0007422507365566606*lm*NH + 
        0.0056970926954150415*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.07216108741332913 - 0.04342809824787994*lm - 
          0.03117595708642807*lm^2) + CF*(0.04279990518244287 + 
          0.01463825496820231*lm + 0.05101520250506412*lm^2) + 
        0.0078040488017683644*NM + 0.0006817468019286988*lm*NM + 
        0.005668355833896013*lm^2*NM + 0.026359468140265987*NL + 
        0.0006817468019286988*lm*NL + 0.005668355833896013*lm^2*NL + 
        0.007316817604213533*NH + 0.0006817468019286988*lm*NH + 
        0.005668355833896013*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.0715815478838185 - 0.04289906509023238*lm - 
          0.031019097184359745*lm^2) + CF*(0.04251690366296731 + 
          0.014056467805712621*lm + 0.05075852266531595*lm^2) + 
        0.007699935436259121*NM + 0.000621857114239996*lm*NM + 
        0.005639835851701772*lm^2*NM + 0.02622326523992165*NL + 
        0.000621857114239996*lm*NL + 0.005639835851701772*lm^2*NL + 
        0.007337260291668398*NH + 0.000621857114239996*lm*NH + 
        0.005639835851701772*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.07100879916753539 - 0.04237488155497508*lm - 
          0.030863418150680784*lm^2) + CF*(0.04223760152341551 + 
          0.013480479114760123*lm + 0.050503775155659465*lm^2) + 
        0.007597509991233438*NM + 0.0005625759172759496*lm*NM + 
        0.005611530572851051*lm^2*NM + 0.026088472149340448*NL + 
        0.0005625759172759496*lm*NL + 0.005611530572851051*lm^2*NL + 
        0.00735754157437789*NH + 0.0005625759172759496*lm*NH + 
        0.005611530572851051*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.07044276018737529 - 0.04185550117688192*lm - 
          0.03070890816565036*lm^2) + CF*(0.04196197009500701 + 
          0.012910234254092484*lm + 0.05025094063470059*lm^2) + 
        0.007496747169950457*NM + 0.0005038974979602651*lm*NM + 
        0.005583437848300066*lm^2*NM + 0.025955071277621033*NL + 
        0.0005038974979602651*lm*NL + 0.005583437848300066*lm^2*NL + 
        0.007377661982208219*NH + 0.0005038974979602651*lm*NH + 
        0.005583437848300066*lm^2*NH)}, {1., 2.2326531778692272*^-8*CF*NC*
       (108.*CF*(17289.668723934716 + 5120.*lm + 20736.*lm^2) - 
        6.*CA*(521676.4181359023 + 308608.*lm + 228096.*lm^2) + 
        331337.7164552391*NM + 19968.*lm*NM + 248832.*lm^2*NM + 
        1.156608*^6*NL + 19968.*lm*NL + 248832.*lm^2*NL + 
        331337.7164552391*NH + 19968.*lm*NH + 248832.*lm^2*NH)}}
 
CbarTable["a", 2, 2] = {{0., -8.573388203017833*^-8*CF*NC*
       (CF*(-817920.1586039913 - 2.5609985392376385*^6*lm - 2.3328*^6*lm^2) + 
        CA*(1.180946508732078*^6 + 2.2243273314337227*^6*lm + 712800.*lm^2) + 
        60.*((-9100.57495786913 - 3991.294943738554*lm - 2160.*lm^2)*NM + 
          (-9100.57495786913 - 3991.294943738554*lm - 2160.*lm^2)*NL - 
          2.*(-898.9399877902611 + 1995.647471869277*lm + 1080.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.10708992795338083 - 0.18988042603034808*lm - 
          0.06033677878440709*lm^2) + CF*(0.06867288964109601 + 
          0.22200734629510546*lm + 0.19746582147624137*lm^2) + 
        0.047167160887064075*NM + 0.02056148402234925*lm*NM + 
        0.010970323415346744*lm^2*NM + 0.047172943739056145*NL + 
        0.02056148402234925*lm*NL + 0.010970323415346744*lm^2*NL - 
        0.00917054544304369*NH + 0.02056148402234925*lm*NH + 
        0.010970323415346744*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.11261754645752388 - 0.18897136679723534*lm - 
          0.0595462383052422*lm^2) + CF*(0.06758798511755669 + 
          0.22426549065459658*lm + 0.19487859808988356*lm^2) + 
        0.047447217754634834*NM + 0.020579135512333847*lm*NM + 
        0.01082658878277131*lm^2*NM + 0.04747241271233378*NL + 
        0.020579135512333847*lm*NL + 0.01082658878277131*lm^2*NL - 
        0.009090434178264528*NH + 0.020579135512333847*lm*NH + 
        0.01082658878277131*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.11773498217874812 - 0.18796489765193025*lm - 
          0.058744535640076465*lm^2) + CF*(0.0668781896972591 + 
          0.22627873076415816*lm + 0.1922548439129775*lm^2) + 
        0.047642592633490584*NM + 0.02058165909438285*lm*NM + 
        0.010680824661832084*lm^2*NM + 0.04770190454892799*NL + 
        0.02058165909438285*lm*NL + 0.010680824661832084*lm^2*NL - 
        0.009008332548475296*NH + 0.02058165909438285*lm*NH + 
        0.010680824661832084*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.12241291991017245 - 0.18686115875876738*lm - 
          0.05793539166573582*lm^2) + CF*(0.06650377647161844 + 
          0.2280228937538636*lm + 0.18960673636058994*lm^2) + 
        0.047752384937023704*NM + 0.02056821922357256*lm*NM + 
        0.01053370757558833*lm^2*NM + 0.0478604058190838*NL + 
        0.02056821922357256*lm*NL + 0.01053370757558833*lm^2*NL - 
        0.008924491306984226*NH + 0.02056821922357256*lm*NH + 
        0.01053370757558833*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.12664728167110123 - 0.1856635268088931*lm - 
          0.057121752907718*lm^2) + CF*(0.06641666016483125 + 
          0.22948952510115325*lm + 0.1869439186070771*lm^2) + 
        0.047779403314367704*NM + 0.020538748003136726*lm*NM + 
        0.010385773255948727*lm^2*NM + 0.04795006408077564*NL + 
        0.020538748003136726*lm*NL + 0.010385773255948727*lm^2*NL - 
        0.008839124917062097*NH + 0.020538748003136726*lm*NH + 
        0.010385773255948727*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.13044652378545746 - 0.18437693271551517*lm - 
          0.05630602759553577*lm^2) + CF*(0.06656956556005396 + 
          0.23067882025884182*lm + 0.18427427213084432*lm^2) + 
        0.047728122296592915*NM + 0.020493584686498614*lm*NM + 
        0.010237459562824685*lm^2*NM + 0.04797440987525695*NL + 
        0.020493584686498614*lm*NL + 0.010237459562824685*lm^2*NL - 
        0.008752422298087852*NH + 0.020493584686498614*lm*NH + 
        0.010237459562824685*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.13382585845631875 - 0.18300707298924007*lm - 
          0.05549021990792696*lm^2) + CF*(0.06691888833034815 + 
          0.23159615502057496*lm + 0.1816043560623064*lm^2) + 
        0.047603773378423246*NM + 0.020433301225961376*lm*NM + 
        0.010089130892350357*lm^2*NM + 0.047937588337453034*NL + 
        0.020433301225961376*lm*NL + 0.010089130892350357*lm^2*NL - 
        0.008664552812878246*NH + 0.020433301225961376*lm*NH + 
        0.010089130892350357*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.13680418776043557 - 0.18155998407528934*lm - 
          0.05467601681424569*lm^2) + CF*(0.06742553373307798 + 
          0.23225011756697342*lm + 0.1789396913920768*lm^2) + 
        0.047411877435399666*NM + 0.020358604783946167*lm*NM + 
        0.00994109396622649*lm^2*NM + 0.04784397374749915*NL + 
        0.020358604783946167*lm*NL + 0.00994109396622649*lm^2*NL - 
        0.008575670061104402*NH + 0.020358604783946167*lm*NH + 
        0.00994109396622649*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.13940232931286695 - 0.18004179432522524*lm - 
          0.053864848785188754*lm^2) + CF*(0.06805498756145614 + 
          0.23265129484176036*lm + 0.17628495966061775*lm^2) + 
        0.04715798548431845*NM + 0.02027027858817909*lm*NM + 
        0.00979360887003432*lm^2*NM + 0.04769796068537543*NL + 
        0.02027027858817909*lm*NL + 0.00979360887003432*lm^2*NL - 
        0.00848591448078892*NH + 0.02027027858817909*lm*NH + 
        0.00979360887003432*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.14164193352140594 - 0.1784585731910139*lm - 
          0.05305793451530777*lm^2) + CF*(0.06877707849077774 + 
          0.23281148294942136*lm + 0.17364414932282543*lm^2) + 
        0.04684752968607497*NM + 0.020169144163418914*lm*NM + 
        0.009646897184601412*lm^2*NM + 0.04750384660348236*NL + 
        0.020169144163418914*lm*NL + 0.009646897184601412*lm^2*NL - 
        0.00839541523377334*NH + 0.020169144163418914*lm*NH + 
        0.009646897184601412*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.14354480144197854 - 0.17681623775309221*lm - 
          0.0522563151320691*lm^2) + CF*(0.06956562219308082 + 
          0.2327431547887369*lm + 0.17102066770495344*lm^2) + 
        0.046485737196050606*NM + 0.020056036420413998*lm*NM + 
        0.009501148205830746*lm^2*NM + 0.04726576544161236*NL + 
        0.020056036420413998*lm*NL + 0.009501148205830746*lm^2*NL - 
        0.00830429163029103*NH + 0.020056036420413998*lm*NH + 
        0.009501148205830746*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.14513244803574638 - 0.17512049487997322*lm - 
          0.05146088111477829*lm^2) + CF*(0.07039803190463673 + 
          0.23245909255811562*lm + 0.16841742910291077*lm^2) + 
        0.04607758170669443*NM + 0.01993178691029437*lm*NM + 
        0.009356523839050598*lm^2*NM + 0.04698765125088052*NL + 
        0.01993178691029437*lm*NL + 0.009356523839050598*lm^2*NL - 
        0.008212654241394272*NH + 0.01993178691029437*lm*NH + 
        0.009356523839050598*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.14642582205480126 - 0.1733768063820008*lm - 
          0.05067239394811469*lm^2) + CF*(0.07125493419983003 + 
          0.23197213037051612*lm + 0.16583692564837535*lm^2) + 
        0.04562775838744461*NM + 0.019797212478155423*lm*NM + 
        0.009213162536020851*lm^2*NM + 0.04667322008997005*NL + 
        0.019797212478155423*lm*NL + 0.009213162536020851*lm^2*NL - 
        0.00812060579148966*NH + 0.019797212478155423*lm*NH + 
        0.009213162536020851*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.14744512898803644 - 0.17159036940895267*lm - 
          0.04989150384788881*lm^2) + CF*(0.07211980737038644 + 
          0.23129497275856462*lm + 0.16328128532036337*lm^2) + 
        0.045140673670844275*NM + 0.019653107597157618*lm*NM + 
        0.009071182517797965*lm^2*NM + 0.04632596329663321*NL + 
        0.019653107597157618*lm*NL + 0.009071182517797965*lm^2*NL - 
        0.008028241890984753*NH + 0.019653107597157618*lm*NH + 
        0.009071182517797965*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.14820972335467408 - 0.16976610714150356*lm - 
          0.049118764479167784*lm^2) + CF*(0.0729786494417778 + 
          0.2304400667786943*lm + 0.16075232011364002*lm^2) + 
        0.04462044456420877*NM + 0.019500239270218017*lm*NM + 
        0.00893068445075778*lm^2*NM + 0.045949147916890865*NL + 
        0.019500239270218017*lm*NL + 0.00893068445075778*lm^2*NL - 
        0.00793565164957409*NH + 0.019500239270218017*lm*NH + 
        0.00893068445075778*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.14873804840357369 - 0.16790866651140052*lm - 
          0.0483546453211137*lm^2) + CF*(0.07381967771686068 + 
          0.22941951269671515*lm + 0.15825156650546301*lm^2) + 
        0.044070904074119226*NM + 0.0193393437542118*lm*NM + 
        0.008791753694747944*lm^2*NM + 0.04554582163235943*NL + 
        0.0193393437542118*lm*NL + 0.008791753694747944*lm^2*NL - 
        0.007842918198392817*NH + 0.0193393437542118*lm*NH + 
        0.008791753694747944*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.14904760854390794 - 0.16602242074016682*lm - 
          0.04759954215696063*lm^2) + CF*(0.07463305919552216 + 
          0.2282450028543851*lm + 0.1557803197864166*lm^2) + 
        0.043495610503199215*NM + 0.019171124594122086*lm*NM + 
        0.008654462210356477*lm^2*NM + 0.04511882046864182*NL + 
        0.019171124594122086*lm*NL + 0.008654462210356477*lm^2*NL - 
        0.007750119141207916*NH + 0.019171124594122086*lm*NH + 
        0.008654462210356477*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.1491549644741062 - 0.16411147516895766*lm - 
          0.04685378604726713*lm^2) + CF*(0.0754106700136601 + 
          0.22692778134748973*lm + 0.1533396634274197*lm^2) + 
        0.04289785912244046*NM + 0.018996251606558583*lm*NM + 
        0.008518870190412205*lm^2*NM + 0.0446707781567156*NL + 
        0.018996251606558583*lm*NL + 0.008518870190412205*lm^2*NL - 
        0.0076573269493740445*NH + 0.018996251606558583*lm*NH + 
        0.008518870190412205*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.14907574402549 - 0.16217967530658253*lm - 
          0.04611765106000761*lm^2) + CF*(0.07614588153848033 + 
          0.22547861919289736*lm + 0.15093049437820674*lm^2) + 
        0.042280695207063436*NM + 0.01881536055425291*lm*NM + 
        0.00838502746545593*lm^2*NM + 0.044204136397330125*NL + 
        0.01881536055425291*lm*NL + 0.00838502746545593*lm^2*NL - 
        0.007564609311508965*NH + 0.01881536055425291*lm*NH + 
        0.00838502746545593*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.14882466378949946 - 0.16023061633228738*lm - 
          0.045391360970154906*lm^2) + CF*(0.07683337061812218 + 
          0.223907801078444*lm + 0.14855354499323423*lm^2) + 
        0.04164692774679964*NM + 0.018629053323520536*lm*NM + 
        0.008252974721846346*lm^2*NM + 0.04372115552654958*NL + 
        0.018629053323520536*lm*NL + 0.008252974721846346*lm^2*NL - 
        0.00747202944617143*NH + 0.018629053323520536*lm*NH + 
        0.008252974721846346*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.14841555800746356 - 0.1582676535050624*lm - 
          0.04467509509660517*lm^2) + CF*(0.07746895153476072 + 
          0.22222512079028067*lm + 0.1462094021343442*lm^2) + 
        0.040999143360509534*NM + 0.018437898466168823*lm*NM + 
        0.008122744563019122*lm^2*NM + 0.043223925246408786*NL + 
        0.018437898466168823*lm*NL + 0.008122744563019122*lm^2*NL - 
        0.007379646383895391*NH + 0.018437898466168823*lm*NH + 
        0.008122744563019122*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.14786141218773224 - 0.15629391308336016*lm - 
          0.04396899341072834*lm^2) + CF*(0.07804942735523406 + 
          0.22043988313237375*lm + 0.14389852388965638*lm^2) + 
        0.040339720095817745*NM + 0.018242432002756447*lm*NM + 
        0.007994362438314242*lm^2*NM + 0.04271437519712297*NL + 
        0.018242432002756447*lm*NL + 0.007994362438314242*lm^2*NL - 
        0.00728751522351868*NH + 0.018242432002756447*lm*NH + 
        0.007994362438314242*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.14717439961469508 - 0.15431230346821498*lm - 
          0.04327316102525901*lm^2) + CF*(0.07857245855914208 + 
          0.2185609106791791*lm + 0.14162125426448402*lm^2) + 
        0.03967084089944298*NM + 0.018043158409863452*lm*NM + 
        0.007867847459138001*lm^2*NM + 0.04219428522446671*NL + 
        0.018043158409863452*lm*NL + 0.007867847459138001*lm^2*NL - 
        0.007195687366690156*NH + 0.018043158409863452*lm*NH + 
        0.007867847459138001*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.14636591941722005 - 0.15232552636196692*lm - 
          0.04258767215248055*lm^2) + CF*(0.07903644702246647 + 
          0.2165965540925783*lm + 0.1393778361353909*lm^2) + 
        0.038994506617665806*NM + 0.01784055173300675*lm*NM + 
        0.007743213118632827*lm^2*NM + 0.04166529524934458*NL + 
        0.01784055173300675*lm*NL + 0.007743213118632827*lm^2*NL - 
        0.0071042107336443455*NH + 0.01784055173300675*lm*NH + 
        0.007743213118632827*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.14544663522958784 - 0.150336087792892*lm - 
          0.0419125736051773*lm^2) + CF*(0.07944043362967673 + 
          0.2145547050267621*lm + 0.13716842270785298*lm^2) + 
        0.03831254843851474*NM + 0.017635056780980658*lm*NM + 
        0.007620467928214055*lm^2*NM + 0.04112891468374057*NL + 
        0.017635056780980658*lm*NL + 0.007620467928214055*lm^2*NL - 
        0.007013129962726*NH + 0.017635056780980658*lm*NH + 
        0.007620467928214055*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.14442651374605267 - 0.14834630889900519*lm - 
          0.04124788790156354*lm^2) + CF*(0.0797840079711721 + 
          0.2124428108665592*lm + 0.13499308767784432*lm^2) + 
        0.03762663972421517*NM + 0.017427090368052355*lm*NM + 
        0.007499615982102462*lm^2*NM + 0.040586531363153704*NL + 
        0.017427090368052355*lm*NL + 0.007499615982102462*lm^2*NL - 
        0.006922486595679556*NH + 0.017427090368052355*lm*NH + 
        0.007499615982102462*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.14331486266818158 - 0.14635833639628176*lm - 
          0.04059361602557092*lm^2) + CF*(0.08006722875219434 + 
          0.21026789071442367*lm + 0.13285183426550484*lm^2) + 
        0.03693830720865254*NM + 0.017217042578530684*lm*NM + 
        0.007380657459194713*lm^2*NM + 0.04003941998368042*NL + 
        0.017217042578530684*lm*NL + 0.007380657459194713*lm^2*NL - 
        0.006832319250354653*NH + 0.017217042578530684*lm*NH + 
        0.007380657459194713*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.14212036769125505 - 0.14437415268046203*lm - 
          0.03994973988592664*lm^2) + CF*(0.08029055369285622 + 
          0.208036552172196*lm + 0.13074460326303267*lm^2) + 
        0.03624894155310934*NM + 0.01700527803441503*lm*NM + 
        0.00726358907016848*lm^2*NM + 0.039488750044402124*NL + 
        0.01700527803441503*lm*NL + 0.00726358907016848*lm^2*NL - 
        0.006742663782193394*NH + 0.01700527803441503*lm*NH + 
        0.00726358907016848*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.14085112828578603 - 0.14239558552954495*lm - 
          0.03931622451096601*lm^2) + CF*(0.08045477783679993 + 
          0.20575500856542173*lm + 0.12867128021770693*lm^2) + 
        0.035559807266497476*NM + 0.01679213715159455*lm*NM + 
        0.007148404456539274*lm^2*NM + 0.03893559330428614*NL + 
        0.01679213715159455*lm*NL + 0.007148404456539274*lm^2*NL - 
        0.006653553435639139*NH + 0.01679213715159455*lm*NH + 
        0.007148404456539274*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.13951469211232675 - 0.14042431738754868*lm - 
          0.03869302001078357*lm^2) + CF*(0.08056097930905637 + 
          0.20342909633745157*lm + 0.1266317018534735*lm^2) + 
        0.03487205200524921*NM + 0.01657793737375315*lm*NM + 
        0.007035094547415194*lm^2*NM + 0.03838093076853556*NL + 
        0.01657793737375315*lm*NL + 0.007035094547415194*lm^2*NL - 
        0.006565018986426548*NH + 0.01657793737375315*lm*NH + 
        0.007035094547415194*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.13811808796919905 - 0.13846189422022298*lm - 
          0.038080063333900516*lm^2) + CF*(0.08061047167306813 + 
          0.20106429240292553*lm + 0.12462566182003805*lm^2) + 
        0.034186715274049755*NM + 0.016362974375997447*lm*NM + 
        0.006923647878891003*lm^2*NM + 0.037825659223027615*NL + 
        0.016362974375997447*lm*NL + 0.006923647878891003*lm^2*NL - 
        0.0064770888755680545*NH + 0.016362974375997447*lm*NH + 
        0.006923647878891003*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.1366678572187437 - 0.13650973394095386*lm - 
          0.03747727984193042*lm^2) + CF*(0.0806047621338376 + 
          0.1986657312994336*lm + 0.12265291584631774*lm^2) + 
        0.03350473655248686*NM + 0.016147523232453994*lm*NM + 
        0.006814050880350986*lm^2*NM + 0.037270597337733094*NL + 
        0.016147523232453994*lm*NL + 0.006814050880350986*lm^2*NL - 
        0.006389789335735089*NH + 0.016147523232453994*lm*NH + 
        0.006814050880350986*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.13517008367192793 - 0.13456913441071142*lm - 
          0.03688458472262131*lm^2) + CF*(0.08054551492003877 + 
          0.19623822201505825*lm + 0.12071318636494248*lm^2) + 
        0.0328269628750431*NM + 0.015931839543820284*lm*NM + 
        0.006706288131385693*lm^2*NM + 0.036716491361220946*NL + 
        0.015931839543820284*lm*NL + 0.006706288131385693*lm^2*NL - 
        0.006303144510637257*NH + 0.015931839543820284*lm*NH + 
        0.006706288131385693*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.13363042193650862 - 0.1326412810200153*lm - 
          0.036301884259028736*lm^2) + CF*(0.08043451925390381 + 
          0.19378626440036398*lm + 0.11880616666591222*lm^2) + 
        0.032154155893101256*NM + 0.015716160522211007*lm*NM + 
        0.006600342592550679*lm^2*NM + 0.0361640204288222*NL + 
        0.015716160522211007*lm*NL + 0.006600342592550679*lm^2*NL - 
        0.006217176567924855*NH + 0.015716160522211007*lm*NH + 
        0.006600342592550679*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.13205412425254676 - 0.13072725386387396*lm - 
          0.03572907697034606*lm^2) + CF*(0.08027366138489905 + 
          0.19131406509790821*lm + 0.11693152463022345*lm^2) + 
        0.03148699844811554*NM + 0.015500706031698655*lm*NM + 
        0.006496195812790192*lm^2*NM + 0.0356138015069719*NL + 
        0.015500706031698655*lm*NL + 0.006496195812790192*lm^2*NL - 
        0.006131905806075827*NH + 0.015500706031698655*lm*NH + 
        0.006496195812790192*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.13044606585252647 - 0.12882803452275615*lm - 
          0.03516605463801541*lm^2) + CF*(0.08006490022268842 + 
          0.1888255529418272*lm + 0.11508890608805042*lm^2) + 
        0.030826100685111924*NM + 0.01528567958377028*lm*NM + 
        0.006393828116002801*lm^2*NM + 0.03506639399582605*NL + 
        0.01528567958377028*lm*NL + 0.006393828116002801*lm^2*NL - 
        0.006047350755675099*NH + 0.01528567958377028*lm*NH + 
        0.006393828116002801*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.1288107688929012 - 0.1269445124640809*lm - 
          0.03461270322911051*lm^2) + CF*(0.07981024615763067 + 
          0.1863243937955249*lm + 0.11327793784072532*lm^2) + 
        0.030172005735512222*NM + 0.015071269287559383*lm*NM + 
        0.006293218768929184*lm^2*NM + 0.034522304011578527*NL + 
        0.015071269287559383*lm*NL + 0.006293218768929184*lm^2*NL - 
        0.005963528275449673*NH + 0.015071269287559383*lm*NH + 
        0.006293218768929184*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.12715242501057167 - 0.12507749107961824*lm - 
          0.03406890372757662*lm^2) + CF*(0.07951174270402521 + 
          0.18381400480776813*lm + 0.11149823038115986*lm^2) + 
        0.02952519499828657*NM + 0.014857648755202112*lm*NM + 
        0.006194346132286659*lm^2*NM + 0.03398198836906632*NL + 
        0.014857648755202112*lm*NL + 0.006194346132286659*lm^2*NL - 
        0.005880453643385554*NH + 0.014857648755202112*lm*NH + 
        0.006194346132286659*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.12547491656245152 - 0.1232276933747009*lm - 
          0.03353453288269647*lm^2) + CF*(0.07917145064350485 + 
          0.18129756807720399*lm + 0.10974938034337027*lm^2) + 
        0.028886093049146*NM + 0.014644977963040649*lm*NM + 
        0.006097187796853904*lm^2*NM + 0.03344585828431174*NL + 
        0.014644977963040649*lm*NL + 0.006097187796853904*lm^2*NL - 
        0.005798140643220936*NH + 0.014644977963040649*lm*NH + 
        0.006097187796853904*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.12378183648293185 - 0.12139576732534872*lm - 
          0.033009463883095364*lm^2) + CF^2*(0.07879143413099256 + 
          0.17877804372296452*lm + 0.10803097270831209*lm^2) + 
        CF*((0.028255071714008987 + 0.0144334040696777*lm + 
            0.006001720706017339*lm^2)*NM + (0.032914282815654464 + 
            0.0144334040696777*lm + 0.006001720706017339*lm^2)*NL + 
          (-0.005716601646583143 + 0.0144334040696777*lm + 
            0.006001720706017339*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.12207650741363989 - 0.11958229091937697*lm - 
          0.03249356696367866*lm^2) + CF^2*(0.07837374969502811 + 
          0.17625818236501384*lm + 0.10634258279022106*lm^2) + 
        CF*((0.027632455681962088 + 0.014223062192093313*lm + 
            0.005907921266123392*lm^2)*NM + (0.03238759206110555 + 
            0.014223062192093313*lm + 0.005907921266123392*lm^2)*NL + 
          (-0.005635847691013785 + 0.014223062192093313*lm + 
            0.005907921266123392*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.12036199891525184 - 0.11778777689735467*lm - 
          0.031986709952090756*lm^2) + CF^2*(0.07792043540358677 + 
          0.17374053702254344*lm + 0.1046837780250243*lm^2) + 
        CF*((0.027018524700931197 + 0.01401407614118398*lm + 
            0.005815765445834683*lm^2)*NM + (0.03186608012853609 + 
            0.01401407614118398*lm + 0.005815765445834683*lm^2)*NL + 
          (-0.005555888554106604 + 0.01401407614118398*lm + 
            0.005815765445834683*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.11864114426959438 - 0.11601267720894305*lm - 
          0.03148875876057997*lm^2) + CF^2*(0.07743350289031416 + 
          0.1712274744422884*lm + 0.1030541195800799*lm^2) + 
        CF*((0.026413518166047055 + 0.013806559118186018*lm + 
            0.005725228865559995*lm^2)*NM + (0.031350007894309084 + 
            0.013806559118186018*lm + 0.005725228865559995*lm^2)*NL + 
          (-0.0054767328239651875 + 0.013806559118186018*lm + 
            0.005725228865559995*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.11691655596757071 - 0.11425738719971366*lm - 
          0.03099957782853383*lm^2) + CF^2*(0.07691493013581742 + 
          0.16872118587133067*lm + 0.10145316380247435*lm^2) + 
        CF*((0.025817638261626252 + 0.013600614373510357*lm + 
            0.005636286877915242*lm^2)*NM + (0.030839605564989155 + 
            0.013600614373510357*lm + 0.005636286877915242*lm^2)*NL + 
          (-0.005398387966172702 + 0.013600614373510357*lm + 
            0.005636286877915242*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.11519064028594923 - 0.11252224954304749*lm - 
          0.03051903052040308*lm^2) + CF^2*(0.07636665553704254 + 
          0.16622369729094164*lm + 0.09988046352131917*lm^2) + 
        CF*((0.02523105306669538 + 0.013396335829551723*lm + 
            0.005548914640073287*lm^2)*NM + (0.030335075055825802 + 
            0.013396335829551723*lm + 0.005548914640073287*lm^2)*NL + 
          (-0.00532086038745167 + 0.013396335829551723*lm + 
            0.005548914640073287*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.11346561095522283 - 0.11080755793117253*lm - 
          0.030046979483249824*lm^2) + CF^2*(0.07579057301782749 + 
          0.16373687912943152*lm + 0.09833556921790852*lm^2) + 
        CF*((0.024653899430283097 + 0.013193808669047938*lm + 
            0.005463087178772696*lm^2)*NM + (0.029836592198809814 + 
            0.013193808669047938*lm + 0.005463087178772696*lm^2)*NL + 
          (-0.005244155496182562 + 0.013193808669047938*lm + 
            0.005463087178772696*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.11174350197107441 - 0.1091135605388239*lm - 
          0.029583286967727582*lm^2) + CF^2*(0.07518852805448922 + 
          0.16126245547292953*lm + 0.09681803007619937*lm^2) + 
        CF*((0.02408628563275723 + 0.012993109890559946*lm + 
            0.005378779448677743*lm^2)*NM + (0.02934430879224984 + 
            0.012993109890559946*lm + 0.005378779448677743*lm^2)*NL + 
          (-0.005168277759934149 + 0.012993109890559946*lm + 
            0.005378779448677743*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.1100261795996564 - 0.10744046327242172*lm - 
          0.02912781511592132*lm^2) + CF^2*(0.07456231450424519 + 
          0.15880201279360354*lm + 0.0953273949248334*lm^2) + 
        CF*((0.023528293848521908 + 0.012794308832623811*lm + 
            0.005295966384712967*lm^2)*NM + (0.028858354503010022 + 
            0.012794308832623811*lm + 0.005295966384712967*lm^2)*NL + 
          (-0.005093230760155721 + 0.012794308832623811*lm + 
            0.005295966384712967*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.10831535362459586 - 0.10578843281706742*lm - 
          0.028680426219137724*lm^2) + CF^2*(0.07391367213684054 + 
          0.15635700821511886*lm + 0.09386321308081437*lm^2) + 
        CF*((0.022979982424208182 + 0.01259746766809609*lm + 
            0.005214622948934131*lm^2)*NM + (0.028378838631789395 + 
            0.01259746766809609*lm + 0.005214622948934131*lm^2)*NL + 
          (-0.0050190172441673545 + 0.01259746766809609*lm + 
            0.005214622948934131*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.10661258788122492 - 0.10415759949306631*lm - 
          0.028240982948435002*lm^2) + CF^2*(0.0732442847807523 + 
          0.15392877733518864*lm + 0.0924250351039691*lm^2) + 
        CF*((0.022441387985645333 + 0.01240264187017586*lm + 
            0.005134724172442728*lm^2)*NM + (0.027905851751109084 + 
            0.01240264187017586*lm + 0.005134724172442728*lm^2)*NL + 
          (-0.004945639174579188 + 0.01240264187017586*lm + 
            0.005134724172442728*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.104919310121197 - 0.1025480599331001*lm - 
          0.02780934856041242*lm^2) + CF^2*(0.0725557790052337 + 
          0.15151854162493628*lm + 0.09101241347044065*lm^2) + 
        CF*((0.02191252738592464 + 0.012209880651542597*lm + 
            0.005056245192802258*lm^2)*NM + (0.02743946722500306 + 
            0.012209880651542597*lm + 0.005056245192802258*lm^2)*NL + 
          (-0.004873097776262837 + 0.012209880651542597*lm + 
            0.005056245192802258*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.10323682124831643 - 0.10095987959060058*lm - 
          0.027385387080539506*lm^2) + CF^2*(0.07184972326820308 + 
          0.1491274154245098*lm + 0.08962490317267474*lm^2) + 
        CF*((0.021393399506027266 + 0.012019227378000883*lm + 
            0.004979161287370819*lm^2)*NM + (0.026979742618780986 + 
            0.012019227378000883*lm + 0.004979161287370819*lm^2)*NL + 
          (-0.00480139358099168 + 0.012019227378000883*lm + 
            0.004979161287370819*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.10156630396411044 - 0.0993930950893207*lm - 
          0.02696896346608919*lm^2) + CF^2*(0.0711276274677137 + 
          0.14675641255399635*lm + 0.08826206225265552*lm^2) + 
        CF*((0.02088398691867265 + 0.011830719957971556*lm + 
            0.0049034479029253075*lm^2)*NM + (0.02652672100664517 + 
            0.011830719957971556*lm + 0.0049034479029253075*lm^2)*NL + 
          (-0.004730526469860486 + 0.011830719957971556*lm + 
            0.0049034479029253075*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.09990883085943407 - 0.09784771642356016*lm - 
          0.02655994375054576*lm^2) + CF^2*(0.07039094284159451 + 
          0.14440645255820386*lm + 0.0869234522745134*lm^2) + 
        CF*((0.02038425742532594 + 0.011644391209116051*lm + 
            0.004829080681917411*lm^2)*NM + (0.026080432184396506 + 
            0.011644391209116051*lm + 0.004829080681917411*lm^2)*NL + 
          (-0.004660495713589397 + 0.011644391209116051*lm + 
            0.004829080681917411*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.09826537198617197 - 0.09632372901798612*lm - 
          0.026158195171184836*lm^2) + CF^2*(0.06964106216580768 + 
          0.14207836660333428*lm + 0.08560863874205947*lm^2) + 
        CF*((0.019894165475541126 + 0.011460269203326606*lm + 
            0.00475603548566997*lm^2)*NM + (0.02564089379395405 + 
            0.011460269203326606*lm + 0.00475603548566997*lm^2)*NL + 
          (-0.004591300010812086 + 0.011460269203326606*lm + 
            0.00475603548566997*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.09663680194093673 - 0.09482109565549196*lm - 
          0.025763586281365956*lm^2) + CF^2*(0.06887932020730166 + 
          0.13977290304298087*lm + 0.08431719146628859*lm^2) + 
        CF*((0.019413653477230824 + 0.011278377591260961*lm + 
            0.00468428841479381*lm^2)*NM + (0.025208112365937514 + 
            0.011278377591260961*lm + 0.00468428841479381*lm^2)*NL + 
          (-0.004522937524442871 + 0.011278377591260961*lm + 
            0.00468428841479381*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.09502390649050269 - 0.09333975828106177*lm - 
          0.02537598704893762*lm^2) + CF^2*(0.0681069943915942 + 
          0.13749073267025969*lm + 0.08304868488743221*lm^2) + 
        CF*((0.01894265300578086 + 0.011098735907546325*lm + 
            0.0046138158270795674*lm^2)*NM + (0.02478208428611961 + 
            0.011098735907546325*lm + 0.0046138158270795674*lm^2)*NL + 
          (-0.0044554059162128816 + 0.011098735907546325*lm + 
            0.0046138158270795674*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.09342738876663395 - 0.09187963968915477*lm - 
          0.0249952689420273*lm^2) + CF^2*(0.06732530564921992 + 
          0.13523245367224318*lm + 0.0818026983557257*lm^2) + 
        CF*((0.018481085919413553 + 0.010921359857724303*lm + 
            0.004544594353095873*lm^2)*NM + (0.024362796691143534 + 
            0.010921359857724303*lm + 0.004544594353095873*lm^2)*NL + 
          (-0.004388702379462018 + 0.010921359857724303*lm + 
            0.004544594353095873*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.0918478750559943 - 0.09044064510169213*lm - 
          0.024621305003374182*lm^2) + CF^2*(0.06653541940863186 + 
          0.13299859630220962*lm + 0.08057881637467915*lm^2) + 
        CF*((0.01802886538761018 + 0.01074626158795661*lm + 
            0.004476600909704397*lm^2)*NM + (0.02395022829851826 + 
            0.01074626158795661*lm + 0.004476600909704397*lm^2)*NL + 
          (-0.004322823670267244 + 0.01074626158795661*lm + 
            0.004476600909704397*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.09028585143600097 - 0.08902266364331729*lm - 
          0.02425396991425846*lm^2) + CF^2*(0.0657383091602869 + 
          0.1307896272845671*lm + 0.07937662881030041*lm^2) + 
        CF*((0.017585896839007572 + 0.01057344993846069*lm + 
            0.004409812711683356*lm^2)*NM + (0.02354435017554855 + 
            0.01057344993846069*lm + 0.004409812711683356*lm^2)*NL + 
          (-0.004257766136986829 + 0.01057344993846069*lm + 
            0.004409812711683356*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.08874195422329928 - 0.08762556972021258*lm - 
          0.02389314004898698*lm^2) + CF^2*(0.06493532845450795 + 
          0.12860595396665797*lm + 0.07819573106941194*lm^2) + 
        CF*((0.01715207883458958 + 0.010402930681595384*lm + 
            0.004344207281633997*lm^2)*NM + (0.023145126451526124 + 
            0.010402930681595384*lm + 0.004344207281633997*lm^2)*NL + 
          (-0.004193525748293825 + 0.010402930681595384*lm + 
            0.004344207281633997*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.0872165309235306 - 0.0862492243083848*lm - 
          0.02353869352080991*lm^2) + CF^2*(0.06412732464542831 + 
          0.12644792823100534*lm + 0.07703572424992335*lm^2) + 
        CF*((0.016727303871741393 + 0.010234706745469325*lm + 
            0.004279762458329075*lm^2)*NM + (0.022752514977201363 + 
            0.010234706745469325*lm + 0.004279762458329075*lm^2)*NL + 
          (-0.004130098119770424 + 0.010234706745469325*lm + 
            0.004279762458329075*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.08570995164283184 - 0.0848934761569833*lm - 
          0.023190510220065675*lm^2) + CF^2*(0.06331525424210857 + 
          0.12431585018093207*lm + 0.07589621526566948*lm^2) + 
        CF*((0.01631145912413897 + 0.010068778423899121*lm + 
            0.004216456403648304*lm^2)*NM + (0.022366467935269897 + 
            0.010068778423899121*lm + 0.004216456403648304*lm^2)*NL + 
          (-0.004067478539130988 + 0.010068778423899121*lm + 
            0.004216456403648304*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.08422253349810978 - 0.08355816291188409*lm - 
          0.02284847184528147*lm^2) + CF^2*(0.06250002488594666 + 
          0.12220997161186481*lm + 0.0747768169481939*lm^2) + 
        CF*((0.015904427122280684 + 0.009905143573500568*lm + 
            0.004154267608232994*lm^2)*NM + (0.021986932405343503 + 
            0.009905143573500568*lm + 0.004154267608232994*lm^2)*NL + 
          (-0.004005661990137854 + 0.009905143573500568*lm + 
            0.004154267608232994*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.08275454449656404 - 0.08224311216446115*lm - 
          0.0225124619278927*lm^2) + CF^2*(0.061682496844791435 + 
          0.1201304992800377*lm + 0.07367714812764885*lm^2) + 
        CF*((0.015506086378978332 + 0.00974379779865413*lm + 
            0.004093174895980492*lm^2)*NM + (0.021613850886629 + 
            0.00974379779865413*lm + 0.004093174895980492*lm^2)*NL + 
          (-0.003944643175272461 + 0.00974379779865413*lm + 
            0.004093174895980492*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.08130620716174963 - 0.08094814243017144*lm - 
          0.022182365851186964*lm^2) + CF^2*(0.0608634845318678 + 
          0.11807759797972835*lm + 0.0725968336947937*lm^2) + 
        CF*((0.015116311963776413 + 0.009584734625045757*lm + 
            0.004033157427488538*lm^2)*NM + (0.021247161781310493 + 
            0.009584734625045757*lm + 0.004033157427488538*lm^2)*NL + 
          (-0.00388441653721984 + 0.009584734625045757*lm + 
            0.004033157427488538*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.07987770192270462 - 0.0796730640613026*lm - 
          0.02185807086402524*lm^2) + CF^2*(0.06004375803982414 + 
          0.11605139343960014*lm + 0.07153550464590079*lm^2) + 
        CF*((0.014734976030839541 + 0.009427945662445873*lm + 
            0.003974194702550044*lm^2)*NM + (0.020886799841418408 + 
            0.009427945662445873*lm + 0.003974194702550044*lm^2)*NL + 
          (-0.003824976279222609 + 0.009427945662445873*lm + 
            0.003974194702550044*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.07846917028006399 - 0.07841768009797041*lm - 
          0.0215394660898452*lm^2) + CF^2*(0.059224044678432 + 
          0.11405197504818412*lm + 0.07049279811222066*lm^2) + 
        CF*((0.01436194830133061 + 0.009273420757352756*lm + 
            0.003916266561790036*lm^2)*NM + (0.020532696581772064 + 
            0.009273420757352756*lm + 0.003916266561790036*lm^2)*NL + 
          (-0.003766316384361412 + 0.009273420757352756*lm + 
            0.003916266561790036*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.07708071776543511 - 0.0771817870612058*lm - 
          0.021226442531407527*lm^2) + CF^2*(0.05840503051232468 + 
          0.11207939841801709*lm + 0.06946835737551554*lm^2) + 
        CF*((0.013997096507881154 + 0.009121148136091875*lm + 
            0.003859353187528641*lm^2)*NM + (0.02018478066139971 + 
            0.009121148136091875*lm + 0.003859353187528641*lm^2)*NL + 
          (-0.003708430633805591 + 0.009121148136091875*lm + 
            0.003859353187528641*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.07571241670495082 - 0.07596517569173965*lm - 
          0.020918893071706433*lm^2) + CF^2*(0.057587361887337395 + 
          0.1101336877974549*lm + 0.06846183187103924*lm^2) + 
        CF*((0.013640286799369438 + 0.008971114538929686*lm + 
            0.0038034351039466247*lm^2)*NM + (0.019842978235670546 + 
            0.008971114538929686*lm + 0.0038034351039466247*lm^2)*NL + 
          (-0.0036513126240924738 + 0.008971114538929686*lm + 
            0.0038034351039466247*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.07436430880119424 - 0.07476763163787409*lm - 
          0.020616712471429134*lm^2) + CF^2*(0.05677164694322386 + 
          0.10821483833870583*lm + 0.06747287717922262*lm^2) + 
        CF*((0.013291384112285714 + 0.008823305345729044*lm + 
            0.0037484931766234787*lm^2)*NM + (0.019507213281215633 + 
            0.008823305345729044*lm + 0.0037484931766234787*lm^2)*NL + 
          (-0.0035949557834731405 + 0.008823305345729044*lm + 
            0.0037484931766234787*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.0730364075441527 - 0.07358893609562377*lm - 
          0.020319797363315698*lm^2) + CF^2*(0.05595845710589487 + 
          0.1063228182301747*lm + 0.06650115500721501*lm^2) + 
        CF*((0.012950252509377673 + 0.008677704693643665*lm + 
            0.003694508611511945*lm^2)*NM + (0.01917740789556839 + 
            0.008677704693643665*lm + 0.003694508611511945*lm^2)*NL + 
          (-0.0035393533873775192 + 0.008677704693643665*lm + 
            0.003694508611511945*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.07172870046254771 - 0.07242886640411624*lm - 
          0.020028046243740553*lm^2) + CF^2*(0.05514832855594753 + 
          0.10445757070077559*lm + 0.06554633316133272*lm^2) + 
        CF*((0.01261675548902366 + 0.00853429558732084*lm + 
            0.0036414629534073733*lm^2)*NM + (0.018853482573319685 + 
            0.00853429558732084*lm + 0.0036414629534073733*lm^2)*NL + 
          (-0.0034844985730321243 + 0.00853429558732084*lm + 
            0.0036414629534073733*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.07044115122549986 - 0.07128719659905937*lm - 
          0.019741359461809025*lm^2) + CF^2*(0.054341763669542686 + 
          0.1026190159034585*lm + 0.064608085511375*lm^2) + 
        CF*((0.012290756266605212 + 0.008393060002054985*lm + 
            0.0035893380839652775*lm^2)*NM + (0.018535356460456294 + 
            0.008393060002054985*lm + 0.0035893380839652775*lm^2)*NL + 
          (-0.003430384353280792 + 0.008393060002054985*lm + 
            0.0035893380839652775*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.0691737016042849 - 0.07016369792691154*lm - 
          0.019459639206237004*lm^2) + CF^2*(0.05353923242917888 + 
          0.10080705268480274*lm + 0.06368609194768474*lm^2) + 
        CF*((0.01197211803105348 + 0.008253978980309239*lm + 
            0.0035381162193158185*lm^2)*NM + (0.01822294758843449 + 
            0.008253978980309239*lm + 0.0035381162193158185*lm^2)*NL + 
          (-0.0033770036296398246 + 0.008253978980309239*lm + 
            0.0035381162193158185*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.06792627330295047 - 0.0690581393222302*lm - 
          0.01918278949025869*lm^2) + CF^2*(0.05274117380168363 + 
          0.09902156024715662*lm + 0.0627800383317557*lm^2) + 
        CF*((0.011660704177475023 + 0.008117032721998523*lm + 
            0.0034877799073197613*lm^2)*NM + (0.01791617308943167 + 
            0.008117032721998523*lm + 0.0034877799073197613*lm^2)*NL + 
          (-0.00332434920462691 + 0.008117032721998523*lm + 
            0.0034877799073197613*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.06669876966627043 - 0.0679702878505224*lm - 
          0.01891071613478611*lm^2) + CF^2*(0.05194799708176159 + 
          0.09726239970944792*lm + 0.061889616441118185*lm^2) + 
        CF*((0.011356378518218843 + 0.007982200668904808*lm + 
            0.003438312024506566*lm^2)*NM + (0.017614949394117858 + 
            0.007982200668904808*lm + 0.003438312024506566*lm^2)*NL + 
          (-0.0032724137934011946 + 0.007982200668904808*lm + 
            0.003438312024506566*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.06549107727284222 - 0.06689990911877938*lm - 
          0.018643326750024686*lm^2) + CF^2*(0.051160083199572784 + 
          0.09552941557245341*lm + 0.061014523909171704*lm^2) + 
        CF*((0.01105900547381936 + 0.00784946158357401*lm + 
            0.0033896957727317617*lm^2)*NM + (0.017319192413195086 + 
            0.00784946158357401*lm + 0.0033896957727317617*lm^2)*NL + 
          (-0.003221190034743636 + 0.00784946158357401*lm + 
            0.0033896957727317617*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.06430306742068555 - 0.06584676765574321*lm - 
          0.018380530715731362*lm^2) + CF^2*(0.05037778599127773 + 
          0.0938224370939958*lm + 0.06015446416057536*lm^2) + 
        CF*((0.010768450245435789 + 0.00771879362302374*lm + 
            0.0033419146755875205*lm^2)*NM + (0.017028817703865336 + 
            0.00771879362302374*lm + 0.0033419146755875205*lm^2)*NL + 
          (-0.0031706705014151355 + 0.00771879362302374*lm + 
            0.0033419146755875205*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.06313459751220324 - 0.06481062726382832*lm - 
          0.01812223916028554*lm^2) + CF^2*(0.049601433431740054 + 
          0.09214127957923386*lm + 0.05930914634275268*lm^2) + 
        CF*((0.010484578970111682 + 0.007590174407572132*lm + 
            0.003294952574597371*lm^2)*NM + (0.016743740622306703 + 
            0.007590174407572132*lm + 0.003294952574597371*lm^2)*NL + 
          (-0.0031208477099204045 + 0.007590174407572132*lm + 
            0.003294952574597371*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.06198551234495622 - 0.06379125134450274*lm - 
          0.017868364938728155*lm^2) + CF^2*(0.048831328828911155 + 
          0.09048574559092423*lm + 0.058478285254019415*lm^2) + 
        CF*((0.010207258860254914 + 0.007463581085079933*lm + 
            0.0032487936252233005*lm^2)*NM + (0.01646387646316203 + 
            0.007463581085079933*lm + 0.0032487936252233005*lm^2)*NL + 
          (-0.0030717141296999705 + 0.007463581085079933*lm + 
            0.0032487936252233005*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.06085564531427374 - 0.06278840319882313*lm - 
          0.017618822609910472*lm^2) + CF^2*(0.04806775197961589 + 
          0.08885562608426173*lm + 0.05766160126879791*lm^2) + 
        CF*((0.009936358328506183 + 0.00733899039088112*lm + 
            0.003203422292710995*lm^2)*NM + (0.016189140586974318 + 
            0.00733899039088112*lm + 0.003203422292710995*lm^2)*NL + 
          (-0.0030232621917991283 + 0.00733899039088112*lm + 
            0.003203422292710995*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.05974481953334465 - 0.0618018463047138*lm - 
          0.017373528412881797*lm^2) + CF^2*(0.04731096028668407 + 
          0.0872507014706475*lm + 0.05685882026034043*lm^2) + 
        CF*((0.009671747099125999 + 0.007216378703661267*lm + 
            0.0031588233477966906*lm^2)*NM + (0.015919448536437963 + 
            0.007216378703661267*lm + 0.0031588233477966906*lm^2)*NL + 
          (-0.002975484297009163 + 0.007216378703661267*lm + 
            0.0031588233477966906*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.058652848876094 - 0.06083134457248218*lm - 
          0.01713240024263366*lm^2) + CF^2*(0.046561189837585 + 
          0.08567074261449077*lm + 0.05606967352134652*lm^2) + 
        CF*((0.00941329630706938 + 0.0070957220975278144*lm + 
            0.0031149818622970287*lm^2)*NM + (0.015654716142274462 + 
            0.0070957220975278144*lm + 0.0031149818622970287*lm^2)*NL + 
          (-0.00292837282353663 + 0.0070957220975278144*lm + 
            0.0031149818622970287*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.05757953894774409 - 0.05987666257997138*lm - 
          0.016895357625307587*lm^2) + CF^2*(0.04581865644473883 + 
          0.08411551176691975*lm + 0.05529389768282483*lm^2) + 
        CF*((0.009160878585371148 + 0.006976996390502132*lm + 
            0.0030718832046013798*lm^2)*NM + (0.015394859619484915 + 
            0.006976996390502132*lm + 0.0030718832046013798*lm^2)*NL + 
          (-0.0028819201342062326 + 0.006976996390502132*lm + 
            0.0030718832046013798*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.05652468798779224 - 0.05893756578866467*lm - 
          0.016662321692963916*lm^2) + CF^2*(0.04508355664810543 + 
          0.08258476344005879*lm + 0.05453123463151827*lm^2) + 
        CF*((0.008914368142345223 + 0.00686017718964986*lm + 
            0.0030295130350843484*lm^2)*NM + (0.015139795654679175 + 
            0.00686017718964986*lm + 0.0030295130350843484*lm^2)*NL + 
          (-0.002836118583227097 + 0.00686017718964986*lm + 
            0.0030295130350843484*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.055488087709634946 - 0.058013820741975426*lm - 
          0.016433215158000152*lm^2) + CF^2*(0.04435606868034632 + 
          0.08107824522532353*lm + 0.05378143142618232*lm^2) + 
        CF*((0.008673640828770734 + 0.006745239933053348*lm + 
            0.0029878573014545736*lm^2)*NM + (0.01488944148513303 + 
            0.006745239933053348*lm + 0.0029878573014545736*lm^2)*NL + 
          (-0.002790960522530379 + 0.006745239933053348*lm + 
            0.0029878573014545736*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.0544695240809954 - 0.05710519524688048*lm - 
          0.016207962287299364*lm^2) + CF^2*(0.04363635339535621 + 
          0.07959569855899072*lm + 0.053044240212979744*lm^2) + 
        CF*((0.008438574196327493 + 0.006632159928818085*lm + 
            0.0029469022340544303*lm^2)*NM + (0.014643714970179333 + 
            0.006632159928818085*lm + 0.0029469022340544303*lm^2)*NL + 
          (-0.002746438307749566 + 0.006632159928818085*lm + 
            0.0029469022340544303*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.053468778048912355 - 0.05621145853998326*lm - 
          0.015986488876181558*lm^2) + CF^2*(0.04292455516075634 + 
          0.07813685943811524*lm + 0.05231941814023055*lm^2) + 
        CF*((0.008209047547734879 + 0.006520912391293787*lm + 
            0.0029066343411239194*lm^2)*NM + (0.014402534655496907 + 
            0.006520912391293787*lm + 0.0029066343411239194*lm^2)*NL + 
          (-0.0027025443037708157 + 0.006520912391293787*lm + 
            0.0029066343411239194*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.052485626212904 - 0.05533238143902635*lm - 
          0.015768722222224165*lm^2) + CF^2*(0.042220802715202024 + 
          0.07670145908969321*lm + 0.05160672727273363*lm^2) + 
        CF*((0.007984941979496877 + 0.006411472474680191*lm + 
            0.002867040404040757*lm^2)*NM + (0.014165819830821947 + 
            0.006411472474680191*lm + 0.002867040404040757*lm^2)*NL + 
          (-0.0026592708899718744 + 0.006411472474680191*lm + 
            0.002867040404040757*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.05151984144956241 - 0.05446773648081*lm - 
          0.015554591099011524*lm^2) + CF^2*(0.04152520999114462 + 
          0.07528922459580603*lm + 0.0509059345058559*lm^2) + 
        CF*((0.007766140417421045 + 0.006303815304177664*lm + 
            0.00282810747254755*lm^2)*NM + (0.013933490581570023 + 
            0.006303815304177664*lm + 0.00282810747254755*lm^2)*NL + 
          (-0.0026166104651022754 + 0.006303815304177664*lm + 
            0.00282810747254755*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.05057119349184582 - 0.05361729804641431*lm - 
          0.015344025729867415*lm^2) + CF^2*(0.04083787690417743 + 
          0.0738998794773245*lm + 0.05021681147956609*lm^2) + 
        CF*((0.0075525276461878565 + 0.006197916004833282*lm + 
            0.002789822859975894*lm^2)*NM + (0.013705467834822942 + 
            0.006197916004833282*lm + 0.002789822859975894*lm^2)*NL + 
          (-0.0025745554518473903 + 0.006197916004833282*lm + 
            0.002789822859975894*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.049639449465867 - 0.05278084247456717*lm - 
          0.015136957761619475*lm^2) + CF^2*(0.04015889010958562 + 
          0.07253314423860661*lm + 0.04953913449257283*lm^2) + 
        CF*((0.007343990332801053 + 0.006093749728224235*lm + 
            0.0027521741384762682*lm^2)*NM + (0.01348167340010314 + 
            0.006093749728224235*lm + 0.0027521741384762682*lm^2)*NL + 
          (-0.0025330983010846517 + 0.006093749728224235*lm + 
            0.0027521741384762682*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.048724374388002825 - 0.0519581481639482*lm - 
          0.014933320238439464*lm^2) + CF^2*(0.039488323727169275 + 
          0.07118873687548327*lm + 0.04887268441671097*lm^2) + 
        CF*((0.007140417044829355 + 0.005991291677112028*lm + 
            0.0027151491342617207*lm^2)*NM + (0.013262030005328773 + 
            0.005991291677112028*lm + 0.0027151491342617207*lm^2)*NL + 
          (-0.0024922314958734483 + 0.005991291677112028*lm + 
            0.0027151491342617207*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.04782573162487918 - 0.05114899566516976*lm - 
          0.01473304757579889*lm^2) + CF^2*(0.03882624003523121 + 
          0.06986637334869682*lm + 0.04821724661170546*lm^2) + 
        CF*((0.006941698263775653 + 0.005890517128193106*lm + 
            0.0026787359228725256*lm^2)*NM + (0.013046461328315467 + 
            0.005890517128193106*lm + 0.0026787359228725256*lm^2)*NL + 
          (-0.0024519475551128423 + 0.005890517128193106*lm + 
            0.0026787359228725256*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.04694328331863834 - 0.050353167763130625*lm - 
          0.014536075534575445*lm^2) + CF^2*(0.038172690134663054 + 
          0.06856576802483302*lm + 0.04757261084042873*lm^2) + 
        CF*((0.006747726393988842 + 0.0057914014530641425*lm + 
            0.002642922824468263*lm^2)*NM + (0.01283489202416501 + 
            0.0057914014530641425*lm + 0.002642922824468263*lm^2)*NL + 
          (-0.0024122390370202814 + 0.0057914014530641425*lm + 
            0.002642922824468263*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.04607679077975044 - 0.04957044955039432*lm - 
          0.014342341195341939*lm^2) + CF^2*(0.03752771458408193 + 
          0.06728663408667157*lm + 0.04693857118475544*lm^2) + 
        CF*((0.006558395767509173 + 0.005693920137513231*lm + 
            0.00260769839915308*lm^2)*NM + (0.012627247748857732 + 
            0.005693920137513231*lm + 0.00260769839915308*lm^2)*NL + 
          (-0.002373098542295838 + 0.005693920137513231*lm + 
            0.00260769839915308*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.04522601484948792 - 0.0488006284922042*lm - 
          0.014151782932866027*lm^2) + CF^2*(0.036891344006970014 + 
          0.06602868391477004*lm + 0.046314925962107*lm^2) + 
        CF*((0.006373602645239527 + 0.005598048799241683*lm + 
            0.002573051442339278*lm^2)*NM + (0.012423455179343087 + 
            0.005598048799241683*lm + 0.002573051442339278*lm^2)*NL + 
          (-0.0023345187170973635 + 0.005598048799241683*lm + 
            0.002573051442339278*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.044390716234043226 - 0.04804349448370879*lm - 
          0.013964340390845867*lm^2) + CF^2*(0.036263599671755485 + 
          0.06479162944199289*lm + 0.04570147764276829*lm^2) + 
        CF*((0.006193245214753889 + 0.005503763204114951*lm + 
            0.002538970980153794*lm^2)*NM + (0.012223442030402447 + 
            0.005503763204114951*lm + 0.002538970980153794*lm^2)*NL + 
          (-0.002296492255770616 + 0.005503763204114951*lm + 
            0.002538970980153794*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.04357066211921339 - 0.047298841260851314*lm - 
          0.013779954793584697*lm^2) + CF*(0.035644479713838904 + 
          0.0635751847077337*lm + 0.045098033869913554*lm^2) + 
        0.0060172255182176166*NM + 0.005411039450564937*lm*NM + 
        0.0025054463261063083*lm^2*NM + 0.012027138393847845*NL + 
        0.005411039450564937*lm*NL + 0.0025054463261063083*lm^2*NL - 
        0.0022590119009074467*NH + 0.005411039450564937*lm*NH + 
        0.0025054463261063083*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.042765600050732794 - 0.046566460747220824*lm - 
          0.013598567511323554*lm^2) + CF*(0.035034019694884094 + 
          0.062379056853961*lm + 0.04450440276433163*lm^2) + 
        0.005845441350445443*NM + 0.0053198532737338735*lm*NM + 
        0.0024724668202406462*lm^2*NM + 0.011834471200806513*NL + 
        0.0053198532737338735*lm*NL + 0.0024724668202406462*lm^2*NL - 
        0.002222070456016654*NH + 0.0053198532737338735*lm*NH + 
        0.0024724668202406462*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.04197529976933458 - 0.04584615205973758*lm - 
          0.013420122256967771*lm^2) + CF*(0.03443219851622721 + 
          0.061202961056404104*lm + 0.043920400113712704*lm^2) + 
        0.005677798996060402*NM + 0.0052301811745382575*lm*NM + 
        0.002440022228539595*lm^2*NM + 0.01164537296962481*NL + 
        0.0052301811745382575*lm*NL + 0.002440022228539595*lm^2*NL - 
        0.002185660771371753*NH + 0.0052301811745382575*lm*NH + 
        0.002440022228539595*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.04119952424145643 - 0.04513771524006172*lm - 
          0.013244563500752734*lm^2) + CF*(0.03383900540401749 + 
          0.06004661050381407*lm + 0.043345844184281675*lm^2) + 
        0.005514204259314923*NM + 0.005141999646779184*lm*NM + 
        0.0024081024546823153*lm^2*NM + 0.011459775671356517*NL + 
        0.005141999646779184*lm*NL + 0.0024081024546823153*lm^2*NL - 
        0.0021497757574395378*NH + 0.005141999646779184*lm*NH + 
        0.0024081024546823153*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.04043803761068447 - 0.04444095294800796*lm - 
          0.01307183686008371*lm^2) + CF*(0.03325442274182658 + 
          0.05890971935937274*lm + 0.042780556996637596*lm^2) + 
        0.005354564821683119*NM + 0.0050552853948250525*lm*NM + 
        0.0023766976109243112*lm^2*NM + 0.011277612360373931*NL + 
        0.0050552853948250525*lm*NL + 0.0023766976109243112*lm^2*NL - 
        0.002114408383636471*NH + 0.0050552853948250525*lm*NH + 
        0.0023766976109243112*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.03969060539596057 - 0.04375567048203319*lm - 
          0.012901889076017015*lm^2) + CF*(0.03267842650989935 + 
          0.05779200298343399*lm + 0.04222436424878296*lm^2) + 
        0.005198790224971969*NM + 0.004970015342778956*lm*NM + 
        0.002345798013821276*lm^2*NM + 0.01109881717643154*NL + 
        0.004970015342778956*lm*NL + 0.002345798013821276*lm^2*NL - 
        0.0020795516799677954*NH + 0.004970015342778956*lm*NH + 
        0.002345798013821276*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.03895699467235736 - 0.04308167579509425*lm - 
          0.01273466799009285*lm^2) + CF*(0.032110986703245914 + 
          0.05669317813878471*lm + 0.04167709524030387*lm^2) + 
        0.005046791852854126*NM + 0.004886166642722923*lm*NM + 
        0.0023153941800168817*lm^2*NM + 0.010923325344981258*NL + 
        0.004886166642722923*lm*NL + 0.0023153941800168817*lm^2*NL - 
        0.0020451987385165047*NH + 0.004886166642722923*lm*NH + 
        0.0023153941800168817*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.03823697423557854 - 0.0424187795062142*lm - 
          0.012570122521526571*lm^2) + CF*(0.03155206772944781 + 
          0.05561296317948791*lm + 0.041138582797723325*lm^2) + 
        0.004898482910994452*NM + 0.004803716682098912*lm*NM + 
        0.0022854768220957403*lm^2*NM + 0.010751073175887714*NL + 
        0.004803716682098912*lm*NL + 0.0022854768220957403*lm^2*NL - 
        0.0020113427147904197*NH + 0.004803716682098912*lm*NH + 
        0.0022854768220957403*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.037530314751270645 - 0.04176679490807417*lm - 
          0.012408202644763916*lm^2) + CF*(0.031001628787022756 + 
          0.05455107822430969*lm + 0.04060866320104554*lm^2) + 
        0.004753778405929404*NM + 0.0047226430902829915*lm*NM + 
        0.00225603684450253*lm^2*NM + 0.010581998060681882*NL + 
        0.0047226430902829915*lm*NL + 0.00225603684450253*lm^2*NL - 
        0.0019779768289352254*NH + 0.0047226430902829915*lm*NH + 
        0.00225603684450253*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.03683678889016481 - 0.04112553797092836*lm - 
          0.012248859367404526*lm^2) + CF*(0.03045962422516356 + 
          0.05350724531567442*lm + 0.04008717611150572*lm^2) + 
        0.004612595122846297*NM + 0.004642923744405762*lm*NM + 
        0.0022270653395280956*lm^2*NM + 0.01041603846848169*NL + 
        0.004642923744405762*lm*NL + 0.0022270653395280956*lm^2*NL - 
        0.0019450943668209305*NH + 0.004642923744405762*lm*NH + 
        0.0022270653395280956*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.03615617145000421 - 0.04049482734312099*lm - 
          0.012092044708497167*lm^2) + CF*(0.02992600388563915 + 
          0.05248118856503868*lm + 0.03957396450053618*lm^2) + 
        0.004474851602398227*NM + 0.004564536774468934*lm*NM + 
        0.002198553583363121*lm^2*NM + 0.010253133940699285*NL + 
        0.004564536774468934*lm*NL + 0.002198553583363121*lm^2*NL - 
        0.001912688681008844*NH + 0.004564536774468934*lm*NH + 
        0.002198553583363121*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.03548823946515291 - 0.03987448434846643*lm - 
          0.011937711677208952*lm^2) + CF*(0.029400713427617898 + 
          0.05147263428552344*lm + 0.03906887457995657*lm^2) + 
        0.004340468116679911*NM + 0.004487460567805048*lm*NM + 
        0.0021704930322198096*lm^2*NM + 0.010093225084646192*NL + 
        0.004487460567805048*lm*NL + 0.0021704930322198096*lm^2*NL - 
        0.001880753191605819*NH + 0.004487460567805048*lm*NH + 
        0.0021704930322198096*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.03483277230472654 - 0.03926433298073758*lm - 
          0.011785814251870155*lm^2) + CF*(0.02888369463614657 + 
          0.05048131111259577*lm + 0.038571755733393234*lm^2) + 
        0.004209366644479952*NM + 0.004411673772924483*lm*NM + 
        0.0021428753185218463*lm^2*NM + 0.009936253566139799*NL + 
        0.004411673772924483*lm*NL + 0.0021428753185218463*lm^2*NL - 
        0.0018492813870121718*NH + 0.004411673772924483*lm*NH + 
        0.0021428753185218463*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.034189551760032445 - 0.038664199895491615*lm - 
          0.011636307359395269*lm^2) + CF*(0.028374885714991836 + 
          0.04950695011354602*lm + 0.038082460448929975*lm^2) + 
        0.004081470845915924*NM + 0.004337155302791306*lm*NM + 
        0.002115692247162776*lm^2*NM + 0.009782162101207241*NL + 
        0.004337155302791306*lm*NL + 0.002115692247162776*lm^2*NL - 
        0.0018182668245693722*NH + 0.004337155302791306*lm*NH + 
        0.002115692247162776*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.033558362122057775 - 0.038073914399448155*lm - 
          0.011489146855080372*lm^2) + CF*(0.027874221564525393 + 
          0.04854928488646357*lm + 0.037600844252990304*lm^2) + 
        0.003956706036550194*NM + 0.004263884337567017*lm*NM + 
        0.0020889357918327947*lm^2*NM + 0.009630894446975876*NL + 
        0.004263884337567017*lm*NL + 0.0020889357918327947*lm^2*NL - 
        0.0017877031311132965*NH + 0.004263884337567017*lm*NH + 
        0.0020889357918327947*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.03293899024969791 - 0.03749330843762083*lm - 
          0.01134428950277608*lm^2) + CF*(0.027381634045308644 + 
          0.04760805164937363*lm + 0.03712676564544899*lm^2) + 
        0.0038349991610765358*NM + 0.004191840326858909*lm*NM + 
        0.002062598091413833*lm^2*NM + 0.009482395391833197*NL + 
        0.004191840326858909*lm*NL + 0.002062598091413833*lm^2*NL - 
        0.0017575840034385448*NH + 0.004191840326858909*lm*NH + 
        0.002062598091413833*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.03233122562937392 - 0.0369222165783906*lm - 
          0.011201692955434904*lm^2) + CF*(0.026897052228008166 + 
          0.046682989320159664*lm + 0.03666008603596878*lm^2) + 
        0.003716278766660229*NM + 0.004121002991507569*lm*NM + 
        0.00203667144644271*lm^2*NM + 0.009336610744932979*NL + 
        0.004121002991507569*lm*NL + 0.00203667144644271*lm^2*NL - 
        0.00172790320867905*NH + 0.004121002991507569*lm*NH + 
        0.00203667144644271*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.03173486042664716 - 0.03636047599669691*lm - 
          0.011061315736031158*lm^2) + CF*(0.026420402630249334 + 
          0.045773839587859654*lm + 0.03620066968155652*lm^2) + 
        0.00360047497600755*NM + 0.004051352324945946*lm*NM + 
        0.002011148315642029*lm^2*NM + 0.009193487325118918*NL + 
        0.004051352324945946*lm*NL + 0.002011148315642029*lm^2*NL - 
        0.0016986545846099466*NH + 0.004051352324945946*lm*NH + 
        0.002011148315642029*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.031149689530400784 - 0.035807926455511556*lm - 
          0.010923117218851199*lm^2) + CF*(0.025951609440992195 + 
          0.04488034697589063*lm + 0.0357483836253312*lm^2) + 
        0.003487519460234186*NM + 0.003982868594160502*lm*NM + 
        0.0019860213125183998*lm^2*NM + 0.009052972949331774*NL + 
        0.003982868594160502*lm*NL + 0.0019860213125183998*lm^2*NL - 
        0.0016698320398754111*NH + 0.003982868594160502*lm*NH + 
        0.0019860213125183998*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.030575510590121847 - 0.03526441028574932*lm - 
          0.010787057611151256*lm^2) + CF*(0.025490594732990864 + 
          0.04400225889772377*lm + 0.03530309763649502*lm^2) + 
        0.003377345411596247*NM + 0.003915532340283057*lm*NM + 
        0.001961283202027501*lm^2*NM + 0.008915016420561195*NL + 
        0.003915532340283057*lm*NL + 0.001961283202027501*lm^2*NL - 
        0.001641429554146958*NH + 0.003915532340283057*lm*NH + 
        0.001961283202027501*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.03001212404678413 - 0.03472977236475945*lm - 
          0.010653097935179778*lm^2) + CF*(0.025037278663875933 + 
          0.04313932570550198*lm + 0.03486468415149745*lm^2) + 
        0.0032698875161420553*NM + 0.003849324378840282*lm*NM + 
        0.001936926897305414*lm^2*NM + 0.008779567515398785*NL + 
        0.003849324378840282*lm*NL + 0.001936926897305414*lm^2*NL - 
        0.0016134411782164379*NH + 0.003849324378840282*lm*NH + 
        0.001936926897305414*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.029459333157799916 - 0.03420386009353255*lm - 
          0.010521200010560817*lm^2) + CF*(0.02459157966637782 + 
          0.04229130073206344*lm + 0.03443301821638086*lm^2) + 
        0.003165081926337814*NM + 0.0037842257996860604*lm*NM + 
        0.0019129454564656033*lm^2*NM + 0.008646576971244838*NL + 
        0.0037842257996860604*lm*NL + 0.0019129454564656033*lm^2*NL - 
        0.0015858610340277826*NH + 0.0037842257996860604*lm*NH + 
        0.0019129454564656033*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.028916944016479325 - 0.033686523372748814*lm - 
          0.010391326437034738*lm^2) + CF*(0.024153414628188465 + 
          0.04145794032680748*lm + 0.03400797743029551*lm^2) + 
        0.0030628662337155448*NM + 0.0037202179666405064*lm*NM + 
        0.0018893320794608616*lm^2*NM + 0.008515996473217094*NL + 
        0.0037202179666405064*lm*NL + 0.0018893320794608616*lm^2*NL - 
        0.0015586833146513197*NH + 0.0037202179666405064*lm*NH + 
        0.0018893320794608616*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.028384765566407823 - 0.033177614577784745*lm - 
          0.010263440577552156*lm^2) + CF*(0.023722699061938565 + 
          0.0406390038858139*lm + 0.03358944189017069*lm^2) + 
        0.002963179441587303*NM + 0.0036572825168578846*lm*NM + 
        0.0018660801050094829*lm^2*NM + 0.008387778640806266*NL + 
        0.0036572825168578846*lm*NL + 0.0018660801050094829*lm^2*NL - 
        0.0015319022842043022*NH + 0.0036572825168578846*lm*NH + 
        0.0018660801050094829*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.027862609611126226 - 0.032676988532788234*lm - 
          0.01013750654171689*lm^2) + CF*(0.023299347265748283 + 
          0.039834253876602575*lm + 0.033177294136528*lm^2) + 
        0.0028659619378656113*NM + 0.0035954013599443654*lm*NM + 
        0.0018431830075848889*lm^2*NM + 0.008261877014319598*NL + 
        0.0035954013599443654*lm*NL + 0.0018431830075848889*lm^2*NL - 
        0.0015055122777210964*NH + 0.0035954013599443654*lm*NH + 
        0.0018431830075848889*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.027350290819473055 - 0.03218450248392406*lm - 
          0.01001348916957339*lm^2) + CF*(0.022883272474790446 + 
          0.03904345585789786*lm + 0.03277141910042201*lm^2) + 
        0.0027711554680263043*NM + 0.0035345566768452425*lm*NM + 
        0.0018206343944678891*lm^2*NM + 0.00813824604115052*NL + 
        0.0035345566768452425*lm*NL + 0.0018206343944678891*lm^2*NL - 
        0.0014795077009763084*NH + 0.0035345566768452425*lm*NH + 
        0.0018206343944678891*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.02684762672692584 - 0.03170001607188524*lm - 
          0.009891354015734008*lm^2) + CF*(0.022474387004287232 + 
          0.03826637849474062*lm + 0.032371704051493116*lm^2) + 
        0.0026787031082464705*NM + 0.0034747309185200253*lm*NM + 
        0.0017984280028607287*lm^2*NM + 0.008016841061909455*NL + 
        0.0034747309185200253*lm*NL + 0.0017984280028607287*lm^2*NL - 
        0.001453883030263947*NH + 0.0034747309185200253*lm*NH + 
        0.0017984280028607287*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.026354437733256332 - 0.031223391303759052*lm - 
          0.009771067333841227*lm^2) + CF*(0.022072602384343703 + 
          0.037502793569270755*lm + 0.03197803854711675*lm^2) + 
        0.0025885492387469552*NM + 0.003415906804422684*lm*NM + 
        0.0017765576970620413*lm^2*NM + 0.007897618296448092*NL + 
        0.003415906804422684*lm*NL + 0.0017765576970620413*lm^2*NL - 
        0.0014286328121355751*NH + 0.003415906804422684*lm*NH + 
        0.0017765576970620413*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.02587054709679428 - 0.030754492524330487*lm - 
          0.009652596061359932*lm^2) + CF*(0.021677829487004707 + 
          0.036752475987484025*lm + 0.0315903143826325*lm^2) + 
        0.0025006395173658978*NM + 0.003358067320803245*lm*NM + 
        0.0017550174657018059*lm^2*NM + 0.007780534829806766*NL + 
        0.003358067320803245*lm*NL + 0.0017550174657018059*lm^2*NL - 
        0.0014037516631002361*NH + 0.003358067320803245*lm*NH + 
        0.0017550174657018059*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.025395780925575224 - 0.030293186386900237*lm - 
          0.009535907804694595*lm^2) + CF*(0.021289978645905303 + 
          0.03601520378224896*lm + 0.031208425542636854*lm^2) + 
        0.002414920853387001*NM + 0.0033011957188459223*lm*NM + 
        0.001733801419035381*lm^2*NM + 0.007665548598112235*NL + 
        0.0033011957188459223*lm*NL + 0.001733801419035381*lm^2*NL - 
        0.001379234269288804*NH + 0.0033011957188459223*lm*NH + 
        0.001733801419035381*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.024929968165629885 - 0.029839341823688866*lm - 
          0.00942097082462622*lm^2) + CF*(0.020908959768869126 + 
          0.03529075811285279*lm + 0.030832268153322177*lm^2) + 
        0.0023313413816436735*NM + 0.0032452755126580234*lm*NM + 
        0.0017129037862956766*lm^2*NM + 0.007552618374450847*NL + 
        0.0032452755126580234*lm*NL + 0.0017129037862956766*lm^2*NL - 
        0.0013550753860852654*NH + 0.0032452755126580234*lm*NH + 
        0.0017129037862956766*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.02447294058665591 - 0.029392830015893788*lm - 
          0.00930775402206379*lm^2) + CF*(0.020534682443793917 + 
          0.034578923261329296*lm + 0.03046174043584513*lm^2) + 
        0.0022498504369178243*NM + 0.0031902904771229524*lm*NM + 
        0.0016923189131025072*lm^2*NM + 0.007441703754740002*NL + 
        0.0031902904771229524*lm*NL + 0.0016923189131025072*lm^2*NL - 
        0.0013312698377273109*NH + 0.0031902904771229524*lm*NH + 
        0.0016923189131025072*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.024024532765296903 - 0.02895352436346109*lm - 
          0.009196226924104866*lm^2) + CF*(0.02016705603814895 + 
          0.03387948662580656*lm + 0.030096742660706832*lm^2) + 
        0.0021703985286498895*NM + 0.0031362246456298156*lm*NM + 
        0.0016720412589281573*lm^2*NM + 0.007332765143618881*NL + 
        0.0031362246456298156*lm*NL + 0.0016720412589281573*lm^2*NL - 
        0.0013078125168784855*NH + 0.0031362246456298156*lm*NH + 
        0.0016720412589281573*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.023584582066238917 - 0.028521300454629528*lm - 
          0.00908635967040004*lm^2) + CF*(0.01980598979239478 + 
          0.033192238711098034*lm + 0.0297371771031274*lm^2) + 
        0.00209293731597467*NM + 0.00308306230769131*lm*NM + 
        0.001652065394618189*lm^2*NM + 0.007225763740377539*NL + 
        0.00308306230769131*lm*NL + 0.001652065394618189*lm^2*NL - 
        0.0012846983841740328*NH + 0.00308306230769131*lm*NH + 
        0.001652065394618189*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.02315292862132057 - 0.0280960360353002*lm - 
          0.008978122999815782*lm^2) + CF*(0.019451392907622562 + 
          0.032516973116747415*lm + 0.029382947999397106*lm^2) + 
        0.0020174195830956806*NM + 0.003030788006460847*lm*NM + 
        0.001632385999966506*lm^2*NM + 0.007120661524941854*NL + 
        0.003030788006460847*lm*NL + 0.001632385999966506*lm^2*NL - 
        0.0012619224677424491*NH + 0.003030788006460847*lm*NH + 
        0.001632385999966506*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.022729415306840094 - 0.0276776109782812*lm - 
          0.008871488237390325*lm^2) + CF*(0.019103174627696718 + 
          0.031853486522724836*lm + 0.029033961504186516*lm^2) + 
        0.0019437992150090086*NM + 0.0029793865361591515*lm*NM + 
        0.0016129978613436955*lm^2*NM + 0.007017421243930163*NL + 
        0.0029793865361591515*lm*NL + 0.0016129978613436955*lm^2*NL - 
        0.001239479862704662*NH + 0.0029793865361591515*lm*NH + 
        0.0016129978613436955*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.022313887719230156 - 0.02726590725245308*lm - 
          0.008766427281577116*lm^2) + CF*(0.01876124431617271 + 
          0.031201578672959925*lm + 0.028690125648797832*lm^2) + 
        0.0018720311735860912*NM + 0.0029288429394199057*lm*NM + 
        0.0015938958693776572*lm^2*NM + 0.006916006396796022*NL + 
        0.0029288429394199057*lm*NL + 0.0015938958693776572*lm^2*NL - 
        0.0012173657306526386*NH + 0.0029288429394199057*lm*NH + 
        0.0015938958693776572*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.021906194149260035 - 0.026860808891897476*lm - 
          0.008662912591770471*lm^2) + CF*(0.0184255115282492 + 
          0.030561052356886383*lm + 0.028351350300339726*lm^2) + 
        0.0018020714740233671*NM + 0.0028791425045633988*lm*NM + 
        0.0015750750166855403*lm^2*NM + 0.006816381222070125*NL + 
        0.0028791425045633988*lm*NL + 0.0015750750166855403*lm^2*NL - 
        0.0011955752991091376*NH + 0.0028791425045633988*lm*NH + 
        0.0015750750166855403*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.02150618555491384 - 0.026462201965027958*lm - 
          0.008560917176108001*lm^2) + CF*(0.01809588607800267 + 
          0.029931713389161674*lm + 0.028017547121808*lm^2) + 
        0.001733877161665427*NM + 0.0028302707628065373*lm*NM + 
        0.0015565303956560001*lm^2*NM + 0.006718510683713184*NL + 
        0.0028302707628065373*lm*NL + 0.0015565303956560001*lm^2*NL - 
        0.0011741038609702204*NH + 0.0028302707628065373*lm*NH + 
        0.0015565303956560001*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.021113715533083374 - 0.0260699745437593*lm - 
          0.008460414579544412*lm^2) + CF*(0.01777227810114126 + 
          0.029313370587715777*lm + 0.02768862953305444*lm^2) + 
        0.0016674062892070459*NM + 0.002782213485417034*lm*NM + 
        0.0015382571962808023*lm^2*NM + 0.006622360457590377*NL + 
        0.002782213485417034*lm*NL + 0.0015382571962808023*lm^2*NL - 
        0.001152946773932054*NH + 0.002782213485417034*lm*NH + 
        0.0015382571962808023*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.020728640290204835 - 0.025684016672748392*lm - 
          0.008361378872191377*lm^2) + CF*(0.017454598113504045 + 
          0.028705835750273304*lm + 0.027364512672626327*lm^2) + 
        0.00160261789427837*NM + 0.0027349566808190584*lm*NM + 
        0.001520250704034796*lm^2*NM + 0.006527896918076915*NL + 
        0.0027349566808190584*lm*NL + 0.001520250704034796*lm^2*NL - 
        0.0011320994599034503*NH + 0.0027349566808190584*lm*NH + 
        0.001520250704034796*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.020350818611959608 - 0.02530422033873743*lm - 
          0.008263784637918105*lm^2) + CF*(0.017142757065521725 + 
          0.028108923629484455*lm + 0.027045113360459255*lm^2) + 
        0.0015394719774164815*NM + 0.002688486591657161*lm*NM + 
        0.001502506297803292*lm^2*NM + 0.006435087124803227*NL + 
        0.002688486591657161*lm*NL + 0.001502506297803292*lm^2*NL - 
        0.0011115574044055082*NH + 0.002688486591657161*lm*NH + 
        0.001502506297803292*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.019980111832151124 - 0.024930479440027586*lm - 
          0.008167606963207369*lm^2) + CF*(0.01683666639284489 + 
          0.02752245190679192*lm + 0.026730350061405932*lm^2) + 
        0.0014779294804256292*NM + 0.0026427896918247984*lm*NM + 
        0.0014850194478558852*lm^2*NM + 0.006343898809547369*NL + 
        0.0026427896918247984*lm*NL + 0.0014850194478558852*lm^2*NL - 
        0.0010913161559596481*NH + 0.0026427896918247984*lm*NH + 
        0.0014850194478558852*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.019616383800861895 - 0.024562689756108983*lm - 
          0.008072821426261747*lm^2) + CF*(0.016536238063336664 + 
          0.026946241165152866*lm + 0.0264201428495839*lm^2) + 
        0.001417952265127543*NM + 0.0025978526834633774*lm*NM + 
        0.0014677857138657724*lm^2*NM + 0.00625430036328138*NL + 
        0.0025978526834633774*lm*NL + 0.0014677857138657724*lm^2*NL - 
        0.0010713713254652606*NH + 0.0025978526834633774*lm*NH + 
        0.0014677857138657724*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.019259500851987587 - 0.024200748917470583*lm - 
          0.007979404086354922*lm^2) + CF*(0.016241384620617447 + 
          0.026380114860727756*lm + 0.0261144133735252*lm^2) + 
        0.0013595030925024638*NM + 0.002553662493937314*lm*NM + 
        0.0014508007429736222*lm^2*NM + 0.006166260823377485*NL + 
        0.002553662493937314*lm*NL + 0.0014508007429736222*lm^2*NL - 
        0.0010517185855681145*NH + 0.002553662493937314*lm*NH + 
        0.0014508007429736222*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.018909331770238076 - 0.023844556375611718*lm - 
          0.007887331473422875*lm^2) + CF*(0.015952019224340953 + 
          0.025823899293640637*lm + 0.025813084822111226*lm^2) + 
        0.0013025456022207978*NM + 0.0025102062727902254*lm*NM + 
        0.0014340602678950681*lm^2*NM + 0.006079749860979353*NL + 
        0.0025102062727902254*lm*NL + 0.0014340602678950681*lm^2*NL - 
        0.001032353670020612*NH + 0.0025102062727902254*lm*NH + 
        0.0014340602678950681*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.018565747757689034 - 0.02349401337327489*lm - 
          0.0077965805778899755*lm^2) + CF*(0.01566805568737235 + 
          0.025277423577908978*lm + 0.02551608189127628*lm^2) + 
        0.0012470442925646516*NM + 0.0024674713886870107*lm*NM + 
        0.0014175601050709047*lm^2*NM + 0.005994737768542868*NL + 
        0.0024674713886870107*lm*NL + 0.0014175601050709047*lm^2*NL - 
        0.0010132723730349132*NH + 0.0024674713886870107*lm*NH + 
        0.0014175601050709047*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.018228622399961557 - 0.023149022914917865*lm - 
          0.007707128840724917*lm^2) + CF*(0.015389408510031493 + 
          0.02474051961063485*lm + 0.025223330751463366*lm^2) + 
        0.0011929645007379098*NM + 0.002425445426346243*lm*NM + 
        0.0014012961528590759*lm^2*NM + 0.005911195447550295*NL + 
        0.002425445426346243*lm*NL + 0.0014012961528590759*lm^2*NL - 
        0.0009944705486298932*NH + 0.002425445426346243*lm*NH + 
        0.0014012961528590759*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.017897831632101714 - 0.022809489737441308*lm - 
          0.00761895414372161*lm^2) + CF*(0.015115992911556572 + 
          0.02421302204054337*lm + 0.02493475901581618*lm^2) + 
        0.0011402723835629745*NM + 0.0023841161834669724*lm*NM + 
        0.0013852643897675654*lm^2*NM + 0.005829094396401082*NL + 
        0.0023841161834669724*lm*NL + 0.0013852643897675654*lm^2*NL - 
        0.00097594410997284*NH + 0.0023841161834669724*lm*NH + 
        0.0013852643897675654*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.01757325370422654 - 0.022475320281186668*lm - 
          0.00753203480000015*lm^2) + CF*(0.014847724858936298 + 
          0.023694768235948762*lm + 0.0246502957090914*lm^2) + 
        0.0010889348985618054*NM + 0.0023434716676537398*lm*NM + 
        0.0013694608727273*lm^2*NM + 0.00574840669848206*NL + 
        0.0023434716676537398*lm*NL + 0.0013694608727273*lm^2*NL - 
        0.0009576890287167492*NH + 0.0023434716676537398*lm*NH + 
        0.0013694608727273*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.017254769146998198 - 0.022146422661217666*lm - 
          0.0074463495447230875*lm^2) + CF*(0.014584521093251774 + 
          0.02318559825222316*lm + 0.024369871237275558*lm^2) + 
        0.0010389197854184524*NM + 0.002303500093343324*lm*NM + 
        0.0013538817354041977*lm^2*NM + 0.0056691050104192234*NL + 
        0.002303500093343324*lm*NL + 0.0013538817354041977*lm^2*NL - 
        0.0009397013343340186*NH + 0.002303500093343324*lm*NH + 
        0.0013538817354041977*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.016942260736983177 - 0.021822706638897193*lm - 
          0.007361877526022275*lm^2) + CF*(0.014326299153662524 + 
          0.02268535479883839*lm + 0.024093417357891084*lm^2) + 
        0.0009901955478198803*NM + 0.0022641898787364835*lm*NM + 
        0.0013385231865495047*lm^2*NM + 0.0055911625505129054*NL + 
        0.0022641898787364835*lm*NL + 0.0013385231865495047*lm^2*NL - 
        0.0009219771134473009*NH + 0.0022641898787364835*lm*NH + 
        0.0013385231865495047*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.01663561346194926 - 0.02150408359377037*lm - 
          0.007278598296131674*lm^2) + CF*(0.01407297739916488 + 
          0.022193883206046247*lm + 0.023820867150976387*lm^2) + 
        0.0009427314356715353*NM + 0.0022255296427376964*lm*NM + 
        0.001323381508387577*lm^2*NM + 0.005514553087357651*NL + 
        0.0022255296427376964*lm*NL + 0.001323381508387577*lm^2*NL - 
        0.0009045125091582233*NH + 0.0022255296427376964*lm*NH + 
        0.001323381508387577*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.01633471448614877 - 0.021190466495763186*lm - 
          0.007196491802721525*lm^2) + CF*(0.013824475028244706 + 
          0.021711031391258514*lm + 0.02355215499072499*lm^2) + 
        0.0008964974276837771*NM + 0.002187508201905681*lm*NM + 
        0.0013084530550402772*lm^2*NM + 0.0054392509286477694*NL + 
        0.002187508201905681*lm*NL + 0.0013084530550402772*lm^2*NL - 
        0.0008873037203746459*NH + 0.002187508201905681*lm*NH + 
        0.0013084530550402772*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.016039453115632877 - 0.020881769877705073*lm - 
          0.007115538380429439*lm^2) + CF*(0.013580712096540786 + 
          0.021236649825183702*lm + 0.023287216517769074*lm^2) + 
        0.0008514642143250284*NM + 0.00215011456741725*lm*NM + 
        0.0012937342509871707*lm^2*NM + 0.005365230910169153*NL + 
        0.00215011456741725*lm*NL + 0.0012937342509871707*lm^2*NL - 
        0.0008703470011370811*NH + 0.00215011456741725*lm*NH + 
        0.0012937342509871707*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.015749720763638172 - 0.020577909808182797*lm - 
          0.007035718742583968*lm^2) + CF*(0.013341609532629485 + 
          0.020770591497773796*lm + 0.023025988612092985*lm^2) + 
        0.0008076031811372396*NM + 0.002113337942046863*lm*NM + 
        0.0012792215895607213*lm^2*NM + 0.0052924683849776225*NL + 
        0.002113337942046863*lm*NL + 0.0012792215895607213*lm^2*NL - 
        0.0008536386599448659*NH + 0.002113337942046863*lm*NH + 
        0.0012792215895607213*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.015465410916083359 - 0.020278803864732017*lm - 
          0.006957013973116349*lm^2) + CF*(0.013107089152036107 + 
          0.02031271188403044*lm + 0.0227684093665626*lm^2) + 
        0.0007648863924090459*NM + 0.0020771677171640217*lm*NM + 
        0.0012649116314757*lm^2*NM + 0.005220939212763788*NL + 
        0.0020771677171640217*lm*NL + 0.0012649116314757*lm^2*NL - 
        0.0008371750590826368*NH + 0.0020771677171640217*lm*NH + 
        0.0012649116314757*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.01518641909721081 - 0.01998437110737201*lm - 
          0.006879405518656167*lm^2) + CF*(0.012877073669573217 + 
          0.01986286890971674*lm + 0.02251441806105655*lm^2) + 
        0.0007232865752018091*NM + 0.0020415934697505084*lm*NM + 
        0.0012508010033920305*lm^2*NM + 0.005150619749404094*NL + 
        0.0020415934697505084*lm*NL + 0.0012508010033920305*lm^2*NL - 
        0.0008209526139476228*NH + 0.0020415934697505084*lm*NH + 
        0.0012508010033920305*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.014912642835404812 - 0.01969453205248821*lm - 
          0.006802875180806763*lm^2) + CF*(0.01265148671010136 + 
          0.019420922917017466*lm + 0.022263955137185768*lm^2) + 
        0.0006827771037235623*NM + 0.0020066049594392663*lm*NM + 
        0.0012368863965103204*lm^2*NM + 0.005081486836697511*NL + 
        0.0020066049594392663*lm*NL + 0.0012368863965103204*lm^2*NL - 
        0.0008049677923782407*NH + 0.0020066049594392663*lm*NH + 
        0.0012368863965103204*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.014643981629215614 - 0.019409208647066467*lm - 
          0.0067274051085963*lm^2) + CF*(0.012430252817802996 + 
          0.01898673663018747*lm + 0.02201696217358789*lm^2) + 
        0.0006433319840457378*NM + 0.001972192125576577*lm*NM + 
        0.0012231645651993273*lm^2*NM + 0.005013517792287078*NL + 
        0.001972192125576577*lm*NL + 0.0012231645651993273*lm^2*NL - 
        0.0007892171139844432*NH + 0.001972192125576577*lm*NH + 
        0.0012231645651993273*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.014380336913615822 - 0.019128324243282206*lm - 
          0.006652977791100492*lm^2) + CF*(0.012213297464056042 + 
          0.018560175121225278*lm + 0.021773381861783427*lm^2) + 
        0.0006049258391574372*NM + 0.0019383450843090473*lm*NM + 
        0.001209632325654635*lm^2*NM + 0.004946690399765299*NL + 
        0.0019383450843090473*lm*NL + 0.001209632325654635*lm^2*NL - 
        0.000773697149480241*NH + 0.0019383450843090473*lm*NH + 
        0.001209632325654635*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.014121612026513302 - 0.018851803573446946*lm - 
          0.006579576050233032*lm^2) + CF*(0.01200054705398913 + 
          0.01814110577560605*lm + 0.021533157982580833*lm^2) + 
        0.0005675338943518973*NM + 0.0019050541256967596*lm*NM + 
        0.0011962865545878242*lm^2*NM + 0.004880982898962213*NL + 
        0.0019050541256967596*lm*NL + 0.0011962865545878242*lm^2*NL - 
        0.0007584045200187922*NH + 0.0019050541256967596*lm*NH + 
        0.0011962865545878242*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.013867712175542543 - 0.018579572725314134*lm - 
          0.0065071830336999*lm^2) + CF*(0.011791928931796754 + 
          0.017729398258105593*lm + 0.021296235383017857*lm^2) + 
        0.0005311319629397275*NM + 0.0018723097108538326*lm*NM + 
        0.0011831241879454364*lm^2*NM + 0.004816373976414787*NL + 
        0.0018723097108538326*lm*NL + 0.0011831241879454364*lm^2*NL - 
        0.0007433358965304264*NH + 0.0018723097108538326*lm*NH + 
        0.0011831241879454364*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.013618544405154377 - 0.018311559117745534*lm - 
          0.006435782208113749*lm^2) + CF*(0.011587371384888535 + 
          0.017324924478744782*lm + 0.021062559953826814*lm^2) + 
        0.000495696432283425*NM + 0.001840102469117494*lm*NM + 
        0.0011701422196570453*lm^2*NM + 0.004752842756016121*NL + 
        0.001840102469117494*lm*NL + 0.0011701422196570453*lm^2*NL - 
        0.0007284879990639415*NH + 0.001840102469117494*lm*NH + 
        0.0011701422196570453*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.013374017564021928 - 0.018047691476739038*lm - 
          0.006365357352264691*lm^2) + CF*(0.011386803646943194 + 
          0.016927558558881336*lm + 0.020832078607411715*lm^2) + 
        0.00046120425014762093*NM + 0.0018084231952466734*lm*NM + 
        0.001157337700411762*lm^2*NM + 0.004690368789842803*NL + 
        0.0018084231952466734*lm*NL + 0.001157337700411762*lm^2*NL - 
        0.0007138575961314914*NH + 0.0018084231952466734*lm*NH + 
        0.001157337700411762*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.01313404227277897 - 0.017787899811818136*lm - 
          0.006295892550543854*lm^2) + CF*(0.011190155899934339 + 
          0.016537176797474*lm + 0.020604739256325343*lm^2) + 
        0.00042763291135948023*NM + 0.0017772628466510005*lm*NM + 
        0.001144707736462519*lm^2*NM + 0.004628932049158663*NL + 
        0.0017772628466510005*lm*NL + 0.001144707736462519*lm^2*NL - 
        0.0006994415040573595*NH + 0.0017772628466510005*lm*NH + 
        0.001144707736462519*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.0128985308921051 - 0.017532115392782904*lm - 
          0.006227372186516164*lm^2) + CF*(0.010997359275191767 + 
          0.016153657637542004*lm + 0.02038049079223472*lm^2) + 
        0.0003949604447736454*NM + 0.0017466125406510025*lm*NM + 
        0.0011322494884574844*lm^2*NM + 0.004568512915593033*NL + 
        0.0017466125406510025*lm*NL + 0.0011322494884574844*lm^2*NL - 
        0.0006852365863308865*NH + 0.0017466125406510025*lm*NH + 
        0.0011322494884574844*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.012667397491170584 - 0.01728027072682195*lm - 
          0.00615978093663888*lm^2) + CF*(0.010808345853558847 + 
          0.015776881632840908*lm + 0.020159283065363607*lm^2) + 
        0.0003631654005361082*NM + 0.0017164635517702006*lm*NM + 
        0.0011199601702979783*lm^2*NM + 0.004509092172491516*NL + 
        0.0017164635517702006*lm*NL + 0.0011199601702979783*lm^2*NL - 
        0.000671239752963807*NH + 0.0017164635517702006*lm*NH + 
        0.0011199601702979783*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.012440557816452303 - 0.017032299535984344*lm - 
          0.006093103764122506*lm^2) + CF*(0.010623048664703458 + 
          0.015406731414774165*lm + 0.019941066864400926*lm^2) + 
        0.0003322268376413886*NM + 0.0016868073090597145*lm*NM + 
        0.0011078370480222736*lm^2*NM + 0.0044506509964372136*NL + 
        0.0016868073090597145*lm*NL + 0.0011078370480222736*lm^2*NL - 
        0.0006574479598522255*NH + 0.0016868073090597145*lm*NH + 
        0.0011078370480222736*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.012217929260930793 - 0.016788136735010208*lm - 
          0.006027325912930725*lm^2) + CF*(0.010441401685637085 + 
          0.01504309165955811*lm + 0.01972579389686419*lm^2) + 
        0.0003021243117774088*NM + 0.0016576353934559028*lm*NM + 
        0.0010958774387146773*lm^2*NM + 0.0043931709489402485*NL + 
        0.0016576353934559028*lm*NL + 0.0010958774387146773*lm^2*NL - 
        0.0006438582081434456*NH + 0.0016576353934559028*lm*NH + 
        0.0010958774387146773*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.011999430833677185 - 0.016547718409518342*lm - 
          0.005962432901916146*lm^2) + CF*(0.010263339838493875 + 
          0.014685849055656447*lm + 0.019513416769907387*lm^2) + 
        0.0002728378634524672*NM + 0.0016289395351714994*lm*NM + 
        0.0010840787094392992*lm^2*NM + 0.004336633968293375*NL + 
        0.0016289395351714994*lm*NL + 0.0010840787094392992*lm^2*NL - 
        0.0006304675436078484*NH + 0.0016289395351714994*lm*NH + 
        0.0010840787094392992*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.011784983129837584 - 0.01631098179454896*lm - 
          0.005898410519088651*lm^2) + CF*(0.010088798987618837 + 
          0.014334892271499*lm + 0.019303888971562856*lm^2) + 
        0.00024434800639874186*NM + 0.001600711611120619*lm*NM + 
        0.0010724382761979365*lm^2*NM + 0.004281022361591392*NL + 
        0.001600711611120619*lm*NL + 0.0010724382761979365*lm^2*NL - 
        0.0006172730560160006*NH + 0.001600711611120619*lm*NH + 
        0.0010724382761979365*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.01157450830102141 - 0.01607786525345927*lm - 
          0.005835244816013253*lm^2) + CF*(0.009917715936011855 + 
          0.013990111923497976*lm + 0.01909716485240701*lm^2) + 
        0.00021663571624678501*NM + 0.0015729436423779575*lm*NM + 
        0.0010609536029115006*lm^2*NM + 0.004226318796912048*NL + 
        0.0015729436423779575*lm*NL + 0.0010609536029115006*lm^2*NL - 
        0.000604271878521155*NH + 0.0015729436423779575*lm*NH + 
        0.0010609536029115006*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.011367930026099145 - 0.015848308257169486*lm - 
          0.0057729221023344315*lm^2) + CF*(0.009750028421171739 + 
          0.013651400544373849*lm + 0.01889319960763996*lm^2) + 
        0.00018968241946550938*NM + 0.0015456277916724344*lm*NM + 
        0.001049622200424442*lm^2*NM + 0.0041725062956560555*NL + 
        0.0015456277916724344*lm*NL + 0.001049622200424442*lm^2*NL - 
        0.0005914611870472942*NH + 0.0015456277916724344*lm*NH + 
        0.001049622200424442*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.011165173482414007 - 0.015622251363756553*lm - 
          0.00571142894042396*lm^2) + CF*(0.009585675110382323 + 
          0.013318652551801678*lm + 0.018691949259569324*lm^2) + 
        0.0001634699825622109*NM + 0.0015187563609154815*lm*NM + 
        0.001038441625531629*lm^2*NM + 0.0041195682250438235*NL + 
        0.0015187563609154815*lm*NL + 0.001038441625531629*lm^2*NL - 
        0.0005788381996828525*NH + 0.0015187563609154815*lm*NH + 
        0.001038441625531629*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.01096616531741119 - 0.015399636198392713*lm - 
          0.005650752140149335*lm^2) + CF*(0.009424595595480364 + 
          0.012991764217387578*lm + 0.018493370640488734*lm^2) + 
        0.00013798070153722312*NM + 0.0014923217887641183*lm*NM + 
        0.0010274094800271519*lm^2*NM + 0.004067488290766476*NL + 
        0.0014923217887641183*lm*NL + 0.0010274094800271519*lm^2*NL - 
        0.0005664001760802386*NH + 0.0014923217887641183*lm*NH + 
        0.0010274094800271519*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.010770833620687495 - 0.015180405433625779*lm - 
          0.005590878753759972*lm^2) + CF*(0.00926673038714298 + 
          0.012670633635984058*lm + 0.018297421375941727*lm^2) + 
        0.00011319729158785279*NM + 0.0014663166482189085*lm*NM + 
        0.0010165234097745403*lm^2*NM + 0.0040162505297887*NL + 
        0.0014663166482189085*lm*NL + 0.0010165234097745403*lm^2*NL - 
        0.0005541444168612674*NH + 0.0014663166482189085*lm*NH + 
        0.0010165234097745403*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.010579107896463436 - 0.014964502769997903*lm - 
          0.005531796070888383*lm^2) + CF*(0.009112020908730341 + 
          0.01235516069535186*lm + 0.018104059868361982*lm^2) + 
        0.00008910287705630513*NM + 0.0014407336442568525*lm*NM + 
        0.001005781103797888*lm^2*NM + 0.003965839303300951*NL + 
        0.0014407336442568525*lm*NL + 0.001005781103797888*lm^2*NL - 
        0.0005420682630286023*NH + 0.0014407336442568525*lm*NH + 
        0.001005781103797888*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.010390919036479165 - 0.014751872916999417*lm - 
          0.0054734916136636455*lm^2) + CF*(0.008960409489717486 + 
          0.012045247046175113*lm + 0.01791324528108102*lm^2) + 
        0.00006568098161637004*NM + 0.0014155656114992156*lm*NM + 
        0.0009951802933933901*lm^2*NM + 0.003916239289818539*NL + 
        0.0014155656114992156*lm*NL + 0.0009951802933933901*lm^2*NL - 
        0.0005301690953832921*NH + 0.0014155656114992156*lm*NH + 
        0.0009951802933933901*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.010206199293314984 - 0.014542461574354177*lm - 
          0.0054159531319345035*lm^2) + CF*(0.008811839358747279 + 
          0.011740796072435675*lm + 0.017724937522694738*lm^2) + 
        0.00004291551869370625*NM + 0.0013908055119142627*lm*NM + 
        0.0009847187512608188*lm^2*NM + 0.0038674354784251105*NL + 
        0.0013908055119142627*lm*NL + 0.0009847187512608188*lm^2*NL - 
        0.0005184443339484816*NH + 0.0013908055119142627*lm*NH + 
        0.0009847187512608188*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.010024882254136546 - 0.014336215413632787*lm - 
          0.005359168598599525*lm^2) + CF*(0.008666254636334884 + 
          0.011441712862151772*lm + 0.01753909723178026*lm^2) + 
        0.00002079078211462964*NM + 0.0013664464325548317*lm*NM + 
        0.000974394290654459*lm^2*NM + 0.0038194131621580125*NL + 
        0.0013664464325548317*lm*NL + 0.000974394290654459*lm^2*NL - 
        0.0005068914373993601*NH + 0.0013664464325548317*lm*NH + 
        0.000974394290654459*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.009846902814864347 - 0.01413308206018987*lm - 
          0.005303126205041785*lm^2) + CF*(0.008523600327252467 + 
          0.011147904178485279*lm + 0.017355685761954932*lm^2) - 
        7.085630216172856*^-7*NM + 0.0013424815833306377*lm*NM + 
        0.0009642047645530518*lm^2*NM + 0.003772157931533081*NL + 
        0.0013424815833306377*lm*NL + 0.0009642047645530518*lm^2*NL - 
        0.0004955079024994094*NH + 0.0013424815833306377*lm*NH + 
        0.0009642047645530518*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.009672197154766594 - 0.013933010075421554*lm - 
          0.00524781435666562*lm^2) + CF*(0.008383822312621273 + 
          0.010859278431221274*lm + 0.0171746651672693*lm^2) - 
        0.000021597489252063488*NM + 0.0013189042948151806*lm*NM + 
        0.0009541480648482944*lm^2*NM + 0.00372565566820634*NL + 
        0.0013189042948151806*lm*NL + 0.0009541480648482944*lm^2*NL - 
        0.00048429126354299524*NH + 0.0013189042948151806*lm*NH + 
        0.0009541480648482944*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.00950070271147406 - 0.013735948939339205*lm - 
          0.0051932216685330315*lm^2) + CF*(0.008246867341736772 + 
          0.010575745648622865*lm + 0.016995998187926284*lm^2) - 
        0.00004189061544554895*NM + 0.0012957080160870876*lm*NM + 
        0.0009442221215514603*lm^2*NM + 0.0036798925387701467*NL + 
        0.0012957080160870876*lm*NL + 0.0009442221215514603*lm^2*NL - 
        0.00047323909180434817*NH + 0.0012957080160870876*lm*NH + 
        0.0009442221215514603*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.009332358156415105 - 0.013541849033455356*lm - 
          0.005139336961097407*lm^2) + CF*(0.008112683023651184 + 
          0.010297217449663625*lm + 0.016819648236318787*lm^2) - 
        0.00006160221528940239*NM + 0.0012728863126057063*lm*NM + 
        0.0009344249020177103*lm^2*NM + 0.0036348549886813172*NL + 
        0.0012728863126057063*lm*NL + 0.0009344249020177103*lm^2*NL - 
        0.00046234899499296195*NH + 0.0012728863126057063*lm*NH + 
        0.0009344249020177103*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.009167103370668696 - 0.013350661623977782*lm - 
          0.0050861492560322396*lm^2) + CF*(0.007981217818536297 + 
          0.010023607016639487*lm + 0.01664557938337824*lm^2) - 
        0.00008074622557197561*NM + 0.0012504328641207315*lm*NM + 
        0.00092475441018768*lm^2*NM + 0.003590529736318775*NL + 
        0.0012504328641207315*lm*NL + 0.00092475441018768*lm^2*NL - 
        0.000451618616715439*NH + 0.0012504328641207315*lm*NH + 
        0.00092475441018768*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.009004879421232834 - 0.013162338845307521*lm - 
          0.005033647772152634*lm^2) + CF*(0.007852421028848283 + 
          0.009754829068161311*lm + 0.0164737563452268*lm^2) - 
        0.00009933625426567371*NM + 0.0012283414626156341*lm*NM + 
        0.0009152086858459335*lm^2*NM + 0.0035469037671682895*NL + 
        0.0012283414626156341*lm*NL + 0.0009152086858459335*lm^2*NL - 
        0.00044104563594379935*NH + 0.0012283414626156341*lm*NH + 
        0.0009152086858459335*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.008845628537705527 - 0.012976833683836704*lm - 
          0.004981821921427383*lm^2) + CF*(0.007726242790314957 + 
          0.009490799832528934*lm + 0.016304144470125983*lm^2) - 
        0.00011738558841504023*NM + 0.0012066060102846345*lm*NM + 
        0.0009057858038958879*lm^2*NM + 0.003503964328131887*NL + 
        0.0012066060102846345*lm*NL + 0.0009057858038958879*lm^2*NL - 
        0.0004306277664902666*NH + 0.0012066060102846345*lm*NH + 
        0.0009057858038958879*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.008689294089375129 - 0.012794099962041942*lm - 
          0.004930661305079504*lm^2) + CF*(0.007602634062764816 + 
          0.009231437021486998*lm + 0.016136709725714737*lm^2) - 
        0.0001349072018343757*NM + 0.0011852205175429474*lm*NM + 
        0.0008964838736508188*lm^2*NM + 0.003461698921959539*NL + 
        0.0011852205175429474*lm*NL + 0.0008964838736508188*lm^2*NL - 
        0.0004203627564885374*NH + 0.0011852205175429474*lm*NH + 
        0.0008964838736508188*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.008535820562716583 - 0.012614092322869017*lm - 
          0.004880155709773126*lm^2) + CF*(0.007481546620816067 + 
          0.008976659804362448*lm + 0.015971418686530233*lm^2) - 
        0.00015191376261928697*NM + 0.0011641791010700067*lm*NM + 
        0.0008873010381405685*lm^2*NM + 0.00342009530180075*NL + 
        0.0011641791010700067*lm*NL + 0.0008873010381405685*lm^2*NL - 
        0.0004102483878815346*NH + 0.0011641791010700067*lm*NH + 
        0.0008873010381405685*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.008385153539289888 - 0.012436766214404624*lm - 
          0.004830295103884726*lm^2) + CF*(0.007362933044442826 + 
          0.008726388782583187*lm + 0.01580823852180456*lm^2) - 
        0.00016841764047648318*NM + 0.001143475981885367*lm*NM + 
        0.0008782354734335866*lm^2*NM + 0.0033791414658737003*NL + 
        0.001143475981885367*lm*NL + 0.0008782354734335866*lm^2*NL - 
        0.00040028247591564024*NH + 0.001143475981885367*lm*NH + 
        0.0008782354734335866*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.008237239674036879 - 0.012262077874830869*lm - 
          0.004781069633856685*lm^2) + CF*(0.007246746709434689 + 
          0.008480545964577016*lm + 0.01564713698353097*lm^2) - 
        0.0001844309138760531*NM + 0.001123105483456958*lm*NM + 
        0.0008692853879739427*lm^2*NM + 0.003338825652249617*NL + 
        0.001123105483456958*lm*NL + 0.0008692853879739427*lm^2*NL - 
        0.0003904628686413983*NH + 0.001123105483456958*lm*NH + 
        0.0008692853879739427*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.008092026673972186 - 0.012089984317658209*lm - 
          0.004732469620631267*lm^2) + CF*(0.007132941777764914 + 
          0.008239054741049632*lm + 0.01548808239479324*lm^2) - 
        0.00019996537703037705*NM + 0.0011030620298413645*lm*NM + 
        0.0008604490219329577*lm^2*NM + 0.003299136333750075*NL + 
        0.0011030620298413645*lm*NL + 0.0008604490219329577*lm^2*NL - 
        0.00038078744642067413*NH + 0.0011030620298413645*lm*NH + 
        0.0008604490219329577*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.007949463277264125 - 0.011920443317232594*lm - 
          0.004684485556163106*lm^2) + CF*(0.007021473187881575 + 
          0.008001839860640158*lm + 0.015331043638351985*lm^2) - 
        0.00021503254670374563*NM + 0.001083340143855786*lm*NM + 
        0.0008517246465751103*lm^2*NM + 0.0032600622129549655*NL + 
        0.001083340143855786*lm*NL + 0.0008517246465751103*lm^2*NL - 
        0.0003712541214402507*NH + 0.001083340143855786*lm*NH + 
        0.0008517246465751103*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.007809499232701028 - 0.011753413394512456*lm - 
          0.004637108100008356*lm^2) + CF*(0.006912296644935195 + 
          0.007768827405952393*lm + 0.015175990145481892*lm^2) - 
        0.00022964366885667637*NM + 0.001063934445281323*lm*NM + 
        0.0008431105636378829*lm^2*NM + 0.0032215922173188826*NL + 
        0.001063934445281323*lm*NL + 0.0008431105636378829*lm^2*NL - 
        0.0003618608372318409*NH + 0.001063934445281323*lm*NH + 
        0.0008431105636378829*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.0076720852795384605 - 0.011588853803111315*lm - 
          0.004590328075988713*lm^2) + CF*(0.006805368610955556 + 
          0.007539944769959683*lm + 0.01502289188505397*lm^2) - 
        0.00024380972512883967*NM + 0.0010448396490972311*lm*NM + 
        0.0008346051047252206*lm^2*NM + 0.003183715494393728*NL + 
        0.0010448396490972311*lm*NL + 0.0008346051047252206*lm^2*NL - 
        0.00035260556819848813*NH + 0.0010448396490972311*lm*NH + 
        0.0008346051047252206*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.007537173127722598 - 0.011426724515601698*lm - 
          0.004544136468928541*lm^2) + CF*(0.006700646294989616 + 
          0.007315120632781081*lm + 0.014871719352857042*lm^2) - 
        0.0002575414391644249*NM + 0.0010260505637457703*lm*NM + 
        0.0008262066307142802*lm^2*NM + 0.003146421407155351*NL + 
        0.0010260505637457703*lm*NL + 0.0008262066307142802*lm^2*NL - 
        0.0003434863191473268*NH + 0.0010260505637457703*lm*NH + 
        0.0008262066307142802*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.007404715438484957 - 0.011266986210076145*lm - 
          0.004498524421463392*lm^2) + CF*(0.006598087643211733 + 
          0.007094284938826251*lm + 0.01472244356115292*lm^2) - 
        0.00027084928278369873*NM + 0.0010075620894272744*lm*NM + 
        0.0008179135311751621*lm^2*NM + 0.003109699529432074*NL + 
        0.0010075620894272744*lm*NL + 0.0008179135311751621*lm^2*NL - 
        0.0003345011248286688*NH + 0.0010075620894272744*lm*NH + 
        0.0008179135311751621*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.007274665805303548 - 0.011109600256961054*lm - 
          0.0044534832309182405*lm^2) + CF*(0.006497651329016712 + 
          0.006877368874306339*lm + 0.014575036028459696*lm^2) - 
        0.0002837434820044292*NM + 0.0009893692164250618*lm*NM + 
        0.0008097242238033164*lm^2*NM + 0.0030735396414329963*NL + 
        0.0009893692164250618*lm*NL + 0.0008097242238033164*lm^2*NL - 
        0.0003256480494813805*NH + 0.0009893692164250618*lm*NH + 
        0.0008097242238033164*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.007146978735225499 - 0.010954528706079165*lm - 
          0.004409004346253806*lm^2) + CF*(0.006399296743105525 + 
          0.006664304845107854*lm + 0.014429468769557913*lm^2) - 
        0.00029623402291677133*NM + 0.0009714670234597937*lm*NM + 
        0.0008016371538643285*lm^2*NM + 0.0030379317253739816*NL + 
        0.0009714670234597937*lm*NL + 0.0008016371538643285*lm^2*NL - 
        0.0003169251863845115*NH + 0.0009714670234597937*lm*NH + 
        0.0008016371538643285*lm^2*NH)}, 
     {1., 3.986880674766477*^-12*CF*NC*
       (20.*CF*(7.904655917426103*^7 + 8.0953344*^7*lm + 1.7915904*^8*lm^2) - 
        2.*CA*(8.805893884643693*^8 + 1.35465984*^9*lm + 5.474304*^8*lm^2) + 
        3.*(5.*(-5.155754294605984*^6 + 1.5949824*^7*lm + 1.327104*^7*lm^2)*
           NM + 6144.*(40863. + 12980.*lm + 10800.*lm^2)*NL + 
          5.*(-5.155754294605984*^6 + 1.5949824*^7*lm + 1.327104*^7*lm^2)*
           NH))}}
 
CbarTable["a", 2, 3] = {{0., -2.2680921172004848*^-10*CF*NC*
       (CF*(-3.4006959039835095*^8 - 1.078594304894892*^9*lm - 
          8.26686*^8*lm^2) + 7.*CA*(5.6525331823675215*^7 + 
          8.739916495725876*^7*lm + 2.4057*^7*lm^2) + 
        70.*(45.*(-47454.35801988715 - 22941.884831215662*lm - 9720.*lm^2)*
           NM + 45.*(-47454.35801988715 - 22941.884831215662*lm - 
            9720.*lm^2)*NL + (456462.5279541789 - 1.0323848174047048*^6*lm - 
            437400.*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.09307246377518992 - 0.1372773251422657*lm - 
          0.0374951404168654*lm^2) + CF*(0.0766697882248387 + 
          0.2453467102312478*lm + 0.18406705295552106*lm^2) + 
        0.033959027983117444*NM + 0.01628295224345136*lm*NM + 
        0.006817298257611891*lm^2*NM + 0.033963886746692123*NL + 
        0.01628295224345136*lm*NL + 0.006817298257611891*lm^2*NL - 
        0.0071409817383636075*NH + 0.01628295224345136*lm*NH + 
        0.006817298257611891*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.09609520355380773 - 0.13569754334841147*lm - 
          0.0367786769267835*lm^2) + CF*(0.07646495215918367 + 
          0.2457804178447507*lm + 0.18054986854966446*lm^2) + 
        0.03394383317493286*NM + 0.01616151239433979*lm*NM + 
        0.006687032168506091*lm^2*NM + 0.0339649070918176*NL + 
        0.01616151239433979*lm*NL + 0.006687032168506091*lm^2*NL - 
        0.007031901300967257*NH + 0.01616151239433979*lm*NH + 
        0.006687032168506091*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.09874124455940035 - 0.13402552126606834*lm - 
          0.03605181528508094*lm^2) + CF*(0.07648980457648934 + 
          0.24588015779155092*lm + 0.17698163867221553*lm^2) + 
        0.03385214317091607*NM + 0.016025707767530886*lm*NM + 
        0.006554875506378352*lm^2*NM + 0.033901323992885354*NL + 
        0.016025707767530886*lm*NL + 0.006554875506378352*lm^2*NL - 
        0.006920664190415872*NH + 0.016025707767530886*lm*NH + 
        0.006554875506378352*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.10099868419972273 - 0.13227004325035885*lm - 
          0.035319379899514405*lm^2) + CF*(0.07669251978753441 + 
          0.24563391148499777*lm + 0.17338604677943434*lm^2) + 
        0.03368665358014959*NM + 0.015876019126623894*lm*NM + 
        0.006421705436275346*lm^2*NM + 0.0337753046328652*NL + 
        0.015876019126623894*lm*NL + 0.006421705436275346*lm^2*NL - 
        0.0068078738578933465*NH + 0.015876019126623894*lm*NH + 
        0.006421705436275346*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.1028764024885088 - 0.13044089721740446*lm - 
          0.034585077561168694*lm^2) + CF*(0.07702331314929856 + 
          0.24504736099208227*lm + 0.1697812898457372*lm^2) + 
        0.033452763548698625*NM + 0.01571336832289401*lm*NM + 
        0.0062881959202124894*lm^2*NM + 0.033591283933671*NL + 
        0.01571336832289401*lm*NL + 0.0062881959202124894*lm^2*NL - 
        0.006694012423077526*NH + 0.01571336832289401*lm*NH + 
        0.0062881959202124894*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.1043926453742679 - 0.12854787604252085*lm - 
          0.033851847822987446*lm^2) + CF*(0.07743882983037498 + 
          0.24413498206665907*lm + 0.16618179840375658*lm^2) + 
        0.033156821686479605*NM + 0.015538855651998433*lm*NM + 
        0.006154881422361354*lm^2*NM + 0.033354461419947176*NL + 
        0.015538855651998433*lm*NL + 0.006154881422361354*lm^2*NL - 
        0.006579477812830756*NH + 0.015538855651998433*lm*NH + 
        0.006154881422361354*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.10557000431502411 - 0.12660038183265238*lm - 
          0.033122061850744254*lm^2) + CF*(0.07790263898159608 + 
          0.2429158286695554*lm + 0.16259921272183545*lm^2) + 
        0.03280539061083294*NM + 0.015353641888409198*lm*NM + 
        0.006022193063771683*lm^2*NM + 0.03307019215236496*NL + 
        0.015353641888409198*lm*NL + 0.006022193063771683*lm^2*NL - 
        0.006464604734717436*NH + 0.015353641888409198*lm*NH + 
        0.006022193063771683*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.1064328586087255 - 0.12460725732228793*lm - 
          0.03239765072472506*lm^2) + CF*(0.07838471896046356 + 
          0.24141123881937418*lm + 0.15904301264865028*lm^2) + 
        0.03240489738714299*NM + 0.01515888794047961*lm*NM + 
        0.0058904819499500105*lm^2*NM + 0.0327437062632857*NL + 
        0.01515888794047961*lm*NL + 0.0058904819499500105*lm^2*NL - 
        0.006349678157996705*NH + 0.01515888794047961*lm*NH + 
        0.0058904819499500105*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.10700596892891155 - 0.12257671959662865*lm - 
          0.03168019483554586*lm^2) + CF*(0.07886068874615335 + 
          0.23964348746146685*lm + 0.15552095646540695*lm^2) + 
        0.03196146058933324*NM + 0.014955722113475588*lm*NM + 
        0.005760035424644702*lm^2*NM + 0.03237997472711069*NL + 
        0.014955722113475588*lm*NL + 0.005760035424644702*lm^2*NL - 
        0.006234942686413791*NH + 0.014955722113475588*lm*NH + 
        0.005760035424644702*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.10731367427890953 - 0.12051634458336977*lm - 
          0.030970989461281184*lm^2) + CF*(0.0793110232162824 + 
          0.23763496080636168*lm + 0.1520394028099258*lm^2) + 
        0.0314808073232718*NM + 0.014745222115026956*lm*NM + 
        0.005631088992960215*lm^2*NM + 0.03198364764927341*NL + 
        0.014745222115026956*lm*NL + 0.005631088992960215*lm^2*NL - 
        0.00612060943216458*NH + 0.014745222115026956*lm*NH + 
        0.005631088992960215*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.1073794298292747 - 0.11843307801763209*lm - 
          0.030271094674009163*lm^2) + CF*(0.07972033008167076 + 
          0.23540763973817178*lm + 0.14860355567240863*lm^2) + 
        0.030968239120890875*NM + 0.014528405500129333*lm*NM + 
        0.005503835395274393*lm^2*NM + 0.031559030929019356*NL + 
        0.014528405500129333*lm*NL + 0.005503835395274393*lm^2*NL - 
        0.006006861256932175*NH + 0.014528405500129333*lm*NH + 
        0.005503835395274393*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.10722554739770157 - 0.11633326038432296*lm - 
          0.02958137437733041*lm^2) + CF*(0.08007671021767862 + 
          0.23298277606975107*lm + 0.14521765603416747*lm^2) + 
        0.03042862536406171*NM + 0.014306225172643417*lm*NM + 
        0.005378431704969166*lm^2*NM + 0.031110083966060922*NL + 
        0.014306225172643417*lm*NL + 0.005378431704969166*lm^2*NL - 
        0.005893856887809916*NH + 0.014306225172643417*lm*NH + 
        0.005378431704969166*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.10687306062942499 - 0.11422265901118847*lm - 
          0.028902527494474525*lm^2) + CF*(0.08037120236759275 + 
          0.23038069361808*lm + 0.14188513497287494*lm^2) + 
        0.02986641242175923*NM + 0.014079568003312889*lm*NM + 
        0.005255004998995368*lm^2*NM + 0.03064042903028536*NL + 
        0.014079568003312889*lm*NL + 0.005255004998995368*lm^2*NL - 
        0.005781734225653049*NH + 0.014079568003312889*lm*NH + 
        0.005255004998995368*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.10634166861514524 - 0.11210650342644296*lm - 
          0.028235113304473397*lm^2) + CF*(0.08059730567041493 + 
          0.22762067219190424*lm + 0.13860873804014212*lm^2) + 
        0.02928564165098543*NM + 0.013849255395508183*lm*NM + 
        0.005133656964449709*lm^2*NM + 0.030153366977754493*NL + 
        0.013849255395508183*lm*NL + 0.005133656964449709*lm^2*NL - 
        0.005670613054571506*NH + 0.013849255395508183*lm*NH + 
        0.005133656964449709*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.10564972938333012 - 0.10998952171167511*lm - 
          0.027579572302361858*lm^2) + CF*(0.08075057119637397 + 
          0.22472088762453366*lm + 0.13539062766614002*lm^2) + 
        0.02868997216114836*NM + 0.013616045067691906*lm*NM + 
        0.005014467691338519*lm^2*NM + 0.029651896201737627*NL + 
        0.013616045067691906*lm*NL + 0.005014467691338519*lm^2*NL - 
        0.00556059729534144*NH + 0.013616045067691906*lm*NH + 
        0.005014467691338519*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.10481428508821182 - 0.10787597651052361*lm - 
          0.026936243563212038*lm^2) + CF*(0.08082825352232663 + 
          0.2216983900770973*lm + 0.13223246840122274*lm^2) + 
        0.028082705835385458*NM + 0.013380633582327127*lm*NM + 
        0.004897498829674916*lm^2*NM + 0.02913873296117865*NL + 
        0.013380633582327127*lm*NL + 0.004897498829674916*lm^2*NL - 
        0.005451776903670578*NH + 0.013380633582327127*lm*NH + 
        0.004897498829674916*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.10385110705279542 - 0.10576969990717243*lm - 
          0.026305379327271634*lm^2) + CF*(0.08082901404647823 + 
          0.21856910855573353*lm + 0.1291354985156971*lm^2) + 
        0.02746681306038977*NM + 0.01314365931234866*lm*NM + 
        0.004782796241322116*lm^2*NM + 0.028616331967920648*NL + 
        0.01314365931234866*lm*NL + 0.004782796241322116*lm^2*NL - 
        0.005344229486664119*NH + 0.01314365931234866*lm*NH + 
        0.004782796241322116*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.10277475282152125 - 0.10367412672702259*lm - 
          0.025687157343694787*lm^2) + CF*(0.08075266867366888 + 
          0.2153478733018308*lm + 0.12610059059631987*lm^2) + 
        0.026844958208747407*NM + 0.012905705639430106*lm*NM + 
        0.004670392244308143*lm^2*NM + 0.028086906561987066*NL + 
        0.012905705639430106*lm*NL + 0.004670392244308143*lm^2*NL - 
        0.005238021692054417*NH + 0.012905705639430106*lm*NH + 
        0.004670392244308143*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.10159862996367161 - 0.10159232602255165*lm - 
          0.025081691383750427*lm^2) + CF*(0.08059997346308845 + 
          0.21204845019561025*lm + 0.12312830315659301*lm^2) + 
        0.026219524292165945*NM + 0.01266730424587706*lm*NM + 
        0.004560307524318259*lm^2*NM + 0.02755244808165055*NL + 
        0.01266730424587706*lm*NL + 0.004560307524318259*lm^2*NL - 
        0.005133210411613783*NH + 0.01266730424587706*lm*NH + 
        0.004560307524318259*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.10033506308008693 - 0.09952703064004935*lm - 
          0.02448904024305857*lm^2) + CF*(0.08037244272417955 + 
          0.20868358300858933*lm + 0.12021892482956024*lm^2) + 
        0.025592636444289434*NM + 0.012428938407235088*lm*NM + 
        0.004452552771465194*lm^2*NM + 0.027014744209433443*NL + 
        0.012428938407235088*lm*NL + 0.004452552771465194*lm^2*NL - 
        0.0050298438307522205*NH + 0.012428938407235088*lm*NH + 
        0.004452552771465194*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.09899536161875173 - 0.09748066484678465*lm - 
          0.023909215485112847*lm^2) + CF*(0.08007219484082419 + 
          0.20526504052131414*lm + 0.11737251238146307*lm^2) + 
        0.024966184047624403*NM + 0.012191046223521507*lm*NM + 
        0.004347130088202336*lm^2*NM + 0.026475396185800738*NL + 
        0.012191046223521507*lm*NL + 0.004347130088202336*lm^2*NL - 
        0.004927962349413255*NH + 0.012191046223521507*lm*NH + 
        0.004347130088202336*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.09758988689287451 - 0.09545537005087114*lm - 
          0.023342188127844183*lm^2) + CF*(0.07970182179359105 + 
          0.2018036663587517*lm + 0.11458892353668962*lm^2) + 
        0.02434184142057758*NM + 0.011954023748260562*lm*NM + 
        0.004244034205062579*lm^2*NM + 0.025935834852604582*NL + 
        0.011954023748260562*lm*NL + 0.004244034205062579*lm^2*NL - 
        0.004827599394249702*NH + 0.011954023748260562*lm*NH + 
        0.004244034205062579*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.09612811723983726 - 0.09345302867860772*lm - 
          0.022787894436451336*lm^2) + CF*(0.07926427894141905 + 
          0.19830942999570902*lm + 0.11186784541530656*lm^2) + 
        0.02372108704652899*NM + 0.011718227989328369*lm*NM + 
        0.004143253533900243*lm^2*NM + 0.025397335532736407*NL + 
        0.011718227989328369*lm*NL + 0.004143253533900243*lm^2*NL - 
        0.004728782138176313*NH + 0.011718227989328369*lm*NH + 
        0.004143253533900243*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.09461871063908026 - 0.09147528629333805*lm - 
          0.022246240955900137*lm^2) + CF*(0.07876279212843088 + 
          0.19479147782010672*lm + 0.10920881923805521*lm^2) + 
        0.023105221369224542*NM + 0.011483979766018457*lm*NM + 
        0.004044771082890934*lm^2*NM + 0.024861031779991237*NL + 
        0.011483979766018457*lm*NL + 0.004044771082890934*lm^2*NL - 
        0.004631532140412186*NH + 0.011483979766018457*lm*NH + 
        0.004044771082890934*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.09306956437302799 - 0.08952357205039065*lm - 
          0.021717108893104627*lm^2) + CF*(0.07820077961024652 + 
          0.1912581834608954*lm + 0.10661126183887727*lm^2) + 
        0.022495383205364098*NM + 0.011251566414063344*lm*NM + 
        0.003948565253291751*lm^2*NM + 0.02432792804963939*NL + 
        0.011251566414063344*lm*NL + 0.003948565253291751*lm^2*NL - 
        0.004535865917803184*NH + 0.011251566414063344*lm*NH + 
        0.003948565253291751*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.09148787150195865 - 0.0875991175873894*lm - 
          0.02120035794024668*lm^2) + CF*(0.07758178665820621 + 
          0.18771719682271198*lm + 0.10407448443393824*lm^2) + 
        0.021892564841235158*NM + 0.011021244335501322*lm*NM + 
        0.0038546105345903053*lm^2*NM + 0.023798911349399203*NL + 
        0.011021244335501322*lm*NL + 0.0038546105345903053*lm^2*NL - 
        0.004441795456385543*NH + 0.011021244335501322*lm*NH + 
        0.0038546105345903053*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.08988017405467472 - 0.08570297445012966*lm - 
          0.02069582961581153*lm^2) + CF*(0.07690943100912984 + 
          0.18417549144388157*lm + 0.10159770902307477*lm^2) + 
        0.02129762588904786*NM + 0.010793241393885367*lm*NM + 
        0.0037628781119657326*lm^2*NM + 0.023274761934891836*NL + 
        0.010793241393885367*lm*NL + 0.0037628781119657326*lm^2*NL - 
        0.004349328670695319*NH + 0.010793241393885367*lm*NH + 
        0.0037628781119657326*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.08825241292809514 - 0.08383603015262397*lm - 
          0.02020335018787257*lm^2) + CF*(0.07618735759112767 + 
          0.18063940992422212*lm + 0.09918008274046534*lm^2) + 
        0.020711305982603293*NM + 0.010567759157828888*lm*NM + 
        0.0036733363977950128*lm^2*NM + 0.022756163114888275*NL + 
        0.010567759157828888*lm*NL + 0.0036733363977950128*lm^2*NL - 
        0.0042584698171572065*NH + 0.010567759157828888*lm*NH + 
        0.0036733363977950128*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.08660997455174885 - 0.08199902296673431*lm - 
          0.01972273323432475*lm^2) + CF*(0.07541920117976651 + 
          0.17711470726585993*lm + 0.09682069042304876*lm^2) + 
        0.020134236392674386*NM + 0.010344974997579023*lm*NM + 
        0.0035859514971499544*lm^2*NM + 0.022243710230840874*NL + 
        0.010344974997579023*lm*NL + 0.0035859514971499544*lm^2*NL - 
        0.004169219866935682*NH + 0.010344974997579023*lm*NH + 
        0.0035859514971499544*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.0849577344155823 - 0.08019255553263685*lm - 
          0.019253781886673624*lm^2) + CF*(0.07460855582968731 + 
          0.17360659204228648*lm + 0.0945185656254887*lm^2) + 
        0.019566950641105953*NM + 0.01012504404042272*lm*NM + 
        0.0035006876157588408*lm^2*NM + 0.02173791887307726*NL + 
        0.01012504404042272*lm*NL + 0.0035006876157588408*lm^2*NL - 
        0.004081576842853427*NH + 0.01012504404042272*lm*NH + 
        0.0035006876157588408*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.08330009758720042 - 0.07841710737663463*lm - 
          0.018796290797280034*lm^2) + CF*(0.07375895008969864 + 
          0.1701197653643197*lm + 0.09227270027755653*lm^2) + 
        0.01900989418992823*NM + 0.009908100991422487*lm*NM + 
        0.003417507417687279*lm^2*NM + 0.02123923239313344*NL + 
        0.009908100991422487*lm*NL + 0.003417507417687279*lm^2*NL - 
        0.00399553612434009*NH + 0.009908100991422487*lm*NH + 
        0.003417507417687279*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.0816410363617481 - 0.07667304641782678*lm - 
          0.018350047864365157*lm^2) + CF*(0.0728738271487507 + 
          0.16665845765100906*lm + 0.09008205315233805*lm^2) + 
        0.018463433278301317*NM + 0.009694261826363345*lm*NM + 
        0.0033363723389754833*lm^2*NM + 0.020748028768360408*NL + 
        0.009694261826363345*lm*NL + 0.0033363723389754833*lm^2*NL - 
        0.003911090723841057*NH + 0.009694261826363345*lm*NH + 
        0.0033363723389754833*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.0799841251971104 - 0.07496063954005891*lm - 
          0.01791483574438511*lm^2) + CF*(0.0719565291796829 + 
          0.16322646324223458*lm + 0.08794555729061782*lm^2) + 
        0.017927862976339876*NM + 0.009483625363954652*lm*NM + 
        0.0032572428626154747*lm^2*NM + 0.020264626871388833*NL + 
        0.009483625363954652*lm*NL + 0.0032572428626154747*lm^2*NL - 
        0.0038282315376694464*NH + 0.009483625363954652*lm*NH + 
        0.0032572428626154747*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.0783325730911929 - 0.07328006230054791*lm - 
          0.01749043317742193*lm^2) + CF*(0.0710102852503839 + 
          0.1598271729103383*lm + 0.08586212650734401*lm^2) + 
        0.01740341452129622*NM + 0.009276274724332564*lm*NM + 
        0.0031800787595312597*lm^2*NM + 0.019789292193435375*NL + 
        0.009276274724332564*lm*NL + 0.0031800787595312597*lm^2*NL - 
        0.0037469475739086906*NH + 0.009276274724332564*lm*NH + 
        0.0031800787595312597*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.07668925355847415 - 0.07163140784168334*lm - 
          0.01707661614787751*lm^2) + CF*(0.07003820226082642 + 
          0.15646360434252324*lm + 0.08383066108958051*lm^2) + 
        0.016890261998875992*NM + 0.009072278680797217*lm*NM + 
        0.003104839299614093*lm^2*NM + 0.01932224206688642*NL + 
        0.009072278680797217*lm*NL + 0.003104839299614093*lm^2*NL - 
        0.003667226159654476*NH + 0.009072278680797217*lm*NH + 
        0.003104839299614093*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.07505673236126599 - 0.07001469506781169*lm - 
          0.016673158899894038*lm^2) + CF*(0.06904325844207969 + 
          0.15313843067542718*lm + 0.081850052781298*lm^2) + 
        0.016388528431740986*NM + 0.008871692911527472*lm*NM + 
        0.0030314834363443705*lm^2*NM + 0.018863650429165952*NL + 
        0.008871692911527472*lm*NL + 0.0030314834363443705*lm^2*NL - 
        0.003589053129613457*NH + 0.008871692911527472*lm*NH + 
        0.0030314834363443705*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.07343729314864639 - 0.06842987614434372*lm - 
          0.016279834824474815*lm^2) + CF*(0.06802829902287362 + 
          0.1498540071693512*lm + 0.0799191891383309*lm^2) + 
        0.01589829134052889*NM + 0.0086745611577708*lm*NM + 
        0.00295996996808633*lm^2*NM + 0.018413652166625865*NL + 
        0.0086745611577708*lm*NL + 0.00295996996808633*lm^2*NL - 
        0.0035124129978436635*NH + 0.0086745611577708*lm*NH + 
        0.00295996996808633*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.07183296115464663 - 0.06687684337230547*lm - 
          0.015896417233175156*lm^2) + CF*(0.0669960337344532 + 
          0.1466123961129604*lm + 0.07803695732649621*lm^2) + 
        0.015419587853597908*NM + 0.008480916294725752*lm*NM + 
        0.002890257678759119*lm^2*NM + 0.017972347074111977*NL + 
        0.008480916294725752*lm*NL + 0.002890257678759119*lm^2*NL - 
        0.003437289114221353*NH + 0.008480916294725752*lm*NH + 
        0.002890257678759119*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.07024552510959148 - 0.06535543548748858*lm - 
          0.015522680031418833*lm^2) + CF*(0.06594903589089078 + 
          0.14341539005054518*lm + 0.07620224742696519*lm^2) + 
        0.014952419466444012*NM + 0.008290781321033234*lm*NM + 
        0.0028223054602579695*lm^2*NM + 0.017539803462968764*NL + 
        0.008290781321033234*lm*NL + 0.0028223054602579695*lm^2*NL - 
        0.0033636638070459824*NH + 0.008290781321033234*lm*NH + 
        0.0028223054602579695*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.06867655518392832 - 0.06386544342964474*lm - 
          0.015158398302926446*lm^2) + CF^2*(0.06488973816896922 + 
          0.14026453342365047*lm + 0.07441395530527528*lm^2) + 
        CF*((0.01449674775664573 + 0.008104170272481356*lm + 
            0.0027560724187138995*lm^2)*NM + (0.017116061447553232 + 
            0.008104170272481356*lm + 0.0027560724187138995*lm^2)*NL + 
          (-0.0032915185130445077 + 0.008104170272481356*lm + 
            0.0027560724187138995*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.0671274281492264 - 0.06240661562370762*lm - 
          0.014803348815380347*lm^2) + CF^2*(0.06382044699321109 + 
          0.1371611427174488*lm + 0.07267098509368534*lm^2) + 
        CF*((0.0140525233094024 + 0.007921089065214198*lm + 
            0.0026915179664327906*lm^2)*NM + (0.016701135937830326 + 
            0.007921089065214198*lm + 0.0026915179664327906*lm^2)*NL + 
          (-0.0032208338959050496 + 0.007921089065214198*lm + 
            0.0026915179664327906*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.06559933650873426 - 0.06097866281180368*lm - 
          0.014457310456265996*lm^2) + CF^2*(0.06274332861294526 + 
          0.1341063251999629*lm + 0.07097225133076035*lm^2) + 
        CF*((0.013619658259080092 + 0.0077415362734234135*lm + 
            0.002628601901139272*lm^2)*NM + (0.016295019363313058 + 
            0.0077415362734234135*lm + 0.002628601901139272*lm^2)*NL + 
          (-0.003151589954354971 + 0.0077415362734234135*lm + 
            0.002628601901139272*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.0640933088135822 - 0.0595812624718226*lm - 
          0.014120064606795728*lm^2) + CF^2*(0.06166042092715189 + 
          0.131100996339373*lm + 0.06931668079699721*lm^2) + 
        CF*((0.013198046860284907 + 0.007565503846196833*lm + 
            0.00256728447396286*lm^2)*NM + (0.01589768415148078 + 
            0.007565503846196833*lm + 0.00256728447396286*lm^2)*NL + 
          (-0.003083766120697366 + 0.007565503846196833*lm + 
            0.00256728447396286*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.0626102232198721 - 0.05821406285554351*lm - 
          0.013791395460916659*lm^2) + CF^2*(0.06057363482853504 + 
          0.1281458959813645*lm + 0.06770321408086359*lm^2) + 
        CF*((0.012787564443519538 + 0.007392977767903229*lm + 
            0.0025075264474393923*lm^2)*NM + (0.015509084981849448 + 
            0.007392977767903229*lm + 0.0025075264474393923*lm^2)*NL + 
          (-0.003017341350631054 + 0.007392977767903229*lm + 
            0.0025075264474393923*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.06115082087844107 - 0.05687668667674552*lm - 
          0.0134710902956117*lm^2) + CF^2*(0.05948475794507942 + 
          0.12524160336492446*lm + 0.06613080690573016*lm^2) + 
        CF*((0.012388069925630647 + 0.007223938666208875*lm + 
            0.002449289144656673*lm^2)*NM + (0.015129160835067015 + 
            0.007223938666208875*lm + 0.002449289144656673*lm^2)*NL + 
          (-0.002952294205098674 + 0.007223938666208875*lm + 
            0.002449289144656673*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.059715718258616456 - 0.055568734477355074*lm - 
          0.013158939698006116*lm^2) + CF^2*(0.058395458706791754 + 
          0.12238855105129302*lm + 0.0645984312447573*lm^2) + 
        CF*((0.011999408077705487 + 0.007058362371550747*lm + 
            0.0023925344905465665*lm^2)*NM + (0.014757836854755164 + 
            0.007058362371550747*lm + 0.0023925344905465665*lm^2)*NL + 
          (-0.002888602924842837 + 0.007058362371550747*lm + 
            0.0023925344905465665*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.058305418486895313 - 0.054289787697487095*lm - 
          0.012854737754178927*lm^2) + CF^2*(0.057307290651929695 + 
          0.11958703783700725*lm + 0.06310507624778747*lm^2) + 
        CF*((0.011621411571857556 + 0.006896220431633934*lm + 
            0.0023372250462143506*lm^2)*NM + (0.01439502603830401 + 
            0.006896220431633934*lm + 0.0023372250462143506*lm^2)*NL + 
          (-0.0028262454982768206 + 0.006896220431633934*lm + 
            0.0023372250462143506*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.056920321775738074 - 0.05303941147320905*lm - 
          0.012558282204037655*lm^2) + CF^2*(0.05622169690018065 + 
          0.11683724071819913*lm + 0.0616497490016394*lm^2) + 
        CF*((0.011253902826954317 + 0.006737480584277229*lm + 
            0.0022833240370977556*lm^2)*NM + (0.014040630771439357 + 
            0.006737480584277229*lm + 0.0022833240370977556*lm^2)*NL + 
          (-0.002765199723234632 + 0.006737480584277229*lm + 
            0.0022833240370977556*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.05556073501215906 - 0.05181715718398522*lm - 
          0.012269374566137178*lm^2) + CF^2*(0.05514001473143208 + 
          0.11413922596958267*lm + 0.060231475142855234*lm^2) + 
        CF*((0.010896695671017045 + 0.006582107191701106*lm + 
            0.002230795375661305*lm^2)*NM + (0.013694544220112414 + 
            0.006582107191701106*lm + 0.002230795375661305*lm^2)*NL + 
          (-0.0027054432631041206 + 0.006582107191701106*lm + 
            0.002230795375661305*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.054226880570716424 - 0.050622564770031374*lm - 
          0.01198782023590065*lm^2) + CF^2*(0.05406348021859452 + 
          0.11149295939791766*lm + 0.05884929933987592*lm^2) + 
        CF*((0.010549596836945983 + 0.006430061639136133*lm + 
            0.002179603679254664*lm^2)*NM + (0.013356651592100099 + 
            0.006430061639136133*lm + 0.002179603679254664*lm^2)*NL + 
          (-0.002646953697807523 + 0.006430061639136133*lm + 
            0.002179603679254664*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.05291890441067227 - 0.0494551648382171*lm - 
          0.011713428560325817*lm^2) + CF^2*(0.052993232871261904 + 
          0.10889831582620128*lm + 0.057502285659781285*lm^2) + 
        CF*((0.010212407306543861 + 0.006281302700426887*lm + 
            0.002129714283695603*lm^2)*NM + (0.013026831279641694 + 
            0.006281302700426887*lm + 0.002129714283695603*lm^2)*NL + 
          (-0.0025897085700520377 + 0.006281302700426887*lm + 
            0.002129714283695603*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.05163688351258709 - 0.04831448057368431*lm - 
          0.011446012891927513*lm^2) + CF^2*(0.05193032025417406 + 
          0.10635508786142753*lm + 0.056189517833098696*lm^2) + 
        CF*((0.00988492351656344 + 0.006135786873116401*lm + 
            0.0020810932530777294*lm^2)*NM + (0.012704955893466026 + 
            0.006135786873116401*lm + 0.0020810932530777294*lm^2)*NL + 
          (-0.0025336854272371796 + 0.006135786873116401*lm + 
            0.0020810932530777294*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.050380832705346316 - 0.04720002947299625*lm - 
          0.011185390624371709*lm^2) + CF^2*(0.05087570255049162 + 
          0.10386299399548511*lm + 0.054910099428733844*lm^2) + 
        CF*((0.009566938439274064 + 0.005993468685318261*lm + 
            0.0020337073862494014*lm^2)*NM + (0.012390893197675315 + 
            0.005993468685318261*lm + 0.0020337073862494014*lm^2)*NL + 
          (-0.002478861859372278 + 0.005993468685318261*lm + 
            0.0020337073862494014*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.04915071093060968 - 0.04611132491338348*lm - 
          0.010931383211993608*lm^2) + CF^2*(0.04983025704500542 + 
          0.10142168608564156*lm + 0.0536631539497868*lm^2) + 
        CF*((0.00925824254903978 + 0.005854300976517485*lm + 
            0.0019875242203624744*lm^2)*NM + (0.012084506954140034 + 
            0.005854300976517485*lm + 0.0019875242203624744*lm^2)*NL + 
          (-0.002425215533328309 + 0.005854300976517485*lm + 
            0.0019875242203624744*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.04794642698778065 - 0.04504787757150299*lm - 
          0.01068381617515817*lm^2) + CF^2*(0.04879478250643336 + 
          0.09903075625809112*lm + 0.05244782485986738*lm^2) + 
        CF*((0.008958624685227422 + 0.005718235154286256*lm + 
            0.0019425120318469402*lm^2)*NM + (0.011785657684317124 + 
            0.005718235154286256*lm + 0.0019425120318469402*lm^2)*NL + 
          (-0.002372724223721253 + 0.005718235154286256*lm + 
            0.0019425120318469402*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.04676784479890439 - 0.04400919670406659*lm - 
          0.010442519093212713*lm^2) + CF^2*(0.047770003451223536 + 
          0.09668974327522621*lm + 0.05126327554849877*lm^2) + 
        CF*((0.008667872821049607 + 0.005585221428756272*lm + 
            0.0018986398351295841*lm^2)*NM + (0.011494203355725843 + 
            0.005585221428756272*lm + 0.0018986398351295841*lm^2)*NL + 
          (-0.0023213658406995683 + 0.005585221428756272*lm + 
            0.0018986398351295841*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.04561478822921928 - 0.04299479130171847*lm - 
          0.010207325586594991*lm^2) + CF^2*(0.04675657427349917 + 
          0.09439813840462727*lm + 0.0501086892432845*lm^2) + 
        CF*((0.008385774746929473 + 0.005455209026554931*lm + 
            0.0018558773793809075*lm^2)*NM + (0.011209999999695701 + 
            0.005455209026554931*lm + 0.0018558773793809075*lm^2)*NL + 
          (-0.0022711184548857063 + 0.005455209026554931*lm + 
            0.0018558773793809075*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.044487045495566244 - 0.04200417112664143*lm - 
          0.009978073289493742*lm^2) + CF^2*(0.04575508322737338 + 
          0.09215539082524933*lm + 0.048983268875696546*lm^2) + 
        CF*((0.008112118676381477 + 0.005328146385787495*lm + 
            0.0018141951435443166*lm^2)*NM + (0.010932902266434483 + 
            0.005328146385787495*lm + 0.0018141951435443166*lm^2)*NL + 
          (-0.002221960319703729 + 0.005328146385787495*lm + 
            0.0018141951435443166*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.043384373191456785 - 0.04103684764354254*lm - 
          0.009754603814309962*lm^2) + CF^2*(0.044766056248830476 + 
          0.08996091260391399*lm + 0.04788623690661254*lm^2) + 
        CF*((0.007846693781475992 + 0.00520398133353105*lm + 
            0.0017735643298745385*lm^2)*NM + (0.01066276392294656 + 
            0.00520398133353105*lm + 0.0017735643298745385*lm^2)*NL + 
          (-0.002173869891301445 + 0.00520398133353105*lm + 
            0.0017735643298745385*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.04230636743866592 - 0.04009233485290476*lm - 
          0.009536762709034141*lm^2) + CF^2*(0.04378969557350836 + 
          0.08781408327298522*lm + 0.04681683511707669*lm^2) + 
        CF*((0.007589290664686811 + 0.005082661247197924*lm + 
            0.0017339568561880257*lm^2)*NM + (0.010399438298858456 + 
            0.005082661247197924*lm + 0.0017339568561880257*lm^2)*NL + 
          (-0.002126825846265547 + 0.005082661247197924*lm + 
            0.0017339568561880257*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.041253015267666136 - 0.039170150034687434*lm - 
          0.00932439940853553*lm^2) + CF^2*(0.04282697929792806 + 
          0.08571425403801403*lm + 0.04577432436917442*lm^2) + 
        CF*((0.007339701772825864 + 0.0049641332010258565*lm + 
            0.00169534534700646*lm^2)*NM + (0.010142778684775871 + 
            0.0049641332010258565*lm + 0.00169534534700646*lm^2)*NL + 
          (-0.002080807097306404 + 0.0049641332010258565*lm + 
            0.00169534534700646*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.04022384881855242 - 0.03826981441000972*lm - 
          0.009117367180652881*lm^2) + CF^2*(0.04187796701607371 + 
          0.08366075164217222*lm + 0.04475798434138687*lm^2) + 
        CF*((0.007097721758880262 + 0.0048483440988589515*lm + 
            0.0016577031237550693*lm^2)*NM + (0.00989263868740087 + 
            0.0048483440988589515*lm + 0.0016577031237550693*lm^2)*NL + 
          (-0.0020357928070791863 + 0.0048483440988589515*lm + 
            0.0016577031237550693*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.03921853281321977 - 0.037390853727753644*lm - 
          0.00891552306788041*lm^2) + CF^2*(0.040942972386575044 + 
          0.08165288191245502*lm + 0.04376711324232201*lm^2) + 
        CF*((0.006863147796256137 + 0.004735240794296931*lm + 
            0.0016210041941600744*lm^2)*NM + (0.009648872545276164 + 
            0.004735240794296931*lm + 0.0016210041941600744*lm^2)*NL + 
          (-0.001991762400293882 + 0.004735240794296931*lm + 
            0.0016210041941600744*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.03823671601786094 - 0.03653279878247268*lm - 
          0.00871872782535704*lm^2) + CF^2*(0.04002226402697842 + 
          0.07968993301090896*lm + 0.0428010275062982*lm^2) + 
        CF*((0.006635779850540423 + 0.004624770199209933*lm + 
            0.0015852232409740074*lm^2)*NM + (0.009411335408692736 + 
            0.004624770199209933*lm + 0.0015852232409740074*lm^2)*NL + 
          (-0.001948695574253168 + 0.004624770199209933*lm + 
            0.0015852232409740074*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.037278033598084286 - 0.035695185869484426*lm - 
          0.00852684585579005*lm^2) + CF^2*(0.03911606850222172 + 
          0.07777117841252985*lm + 0.041859061473878426*lm^2) + 
        CF*((0.0064154209121484495 + 0.00451687938154162*lm + 
            0.0015503356101436454*lm^2)*NM + (0.009179883586994493 + 
            0.00451687938154162*lm + 0.0015503356101436454*lm^2)*NL + 
          (-0.0019065723079498755 + 0.00451687938154162*lm + 
            0.0015503356101436454*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.03634210914926731 - 0.03487755718255833*lm - 
          0.008339745141875188*lm^2) + CF^2*(0.03822457293881501 + 
          0.07589587962996913*lm + 0.04094056706011456*lm^2) + 
        CF*((0.006201876960082946 + 0.004411515653254364*lm + 
            0.0015163172985227615*lm^2)*NM + (0.008954374766236981 + 
            0.004411515653254364*lm + 0.0015163172985227615*lm^2)*NL + 
          (-0.0018653728698413813 + 0.004411515653254364*lm + 
            0.0015163172985227615*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.03542855722782312 - 0.0340794611591785*lm - 
          0.008157297176713435*lm^2) + CF^2*(0.03734792888573747 + 
          0.07406328870377975*lm + 0.040044913412956865*lm^2) + 
        CF*((0.005994958305844991 + 0.004308626649206206*lm + 
            0.0014831449412206245*lm^2)*NM + (0.008734668199904089 + 
            0.004308626649206206*lm + 0.0014831449412206245*lm^2)*NL + 
          (-0.0018250778244109358 + 0.004308626649206206*lm + 
            0.0014831449412206245*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.03453698395766518 - 0.033300452777964555*lm - 
          0.007979376892668845*lm^2) + CF^2*(0.03648625254332978 + 
          0.0722726504756193*lm + 0.03917148656401069*lm^2) + 
        CF*((0.005794477354959516 + 0.004208160397690021*lm + 
            0.0014507957986670628*lm^2)*NM + (0.008520624875155118 + 
            0.004208160397690021*lm + 0.0014507957986670628*lm^2)*NL + 
          (-0.0017856680376265243 + 0.004208160397690021*lm + 
            0.0014507957986670628*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.033666989849358425 - 0.03254009381246754*lm - 
          0.00780586258906203*lm^2) + CF^2*(0.03563962961061879 + 
          0.07052320466060272*lm + 0.03831968907357724*lm^2) + 
        CF*((0.005600251171743305 + 0.004110065383310322*lm + 
            0.0014192477434658236*lm^2)*NM + (0.008312107656862692 + 
            0.004110065383310322*lm + 0.0014192477434658236*lm^2)*NL + 
          (-0.0017471246813715255 + 0.004110065383310322*lm + 
            0.0014192477434658236*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.03281817058767484 - 0.031797953045220435*lm - 
          0.007636635859048898*lm^2) + CF^2*(0.034808116240453 + 
          0.06881418773385382*lm + 0.037488939671694595*lm^2) + 
        CF*((0.005412100206468557 + 0.004014290602822153*lm + 
            0.0013884792470997998*lm^2)*NM + (0.00810898141150818 + 
            0.004014290602822153*lm + 0.0013884792470997998*lm^2)*NL + 
          (-0.001709429236959194 + 0.004014290602822153*lm + 
            0.0013884792470997998*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.031990118565032546 - 0.031073606445612238*lm - 
          0.007471581515993963*lm^2) + CF^2*(0.03399174163758737 + 
          0.06714483464523982*lm + 0.03667867289669764*lm^2) + 
        CF*((0.005229848782421515 + 0.003920785614509407*lm + 
            0.0013584693665443569*lm^2)*NM + (0.007911113112823777 + 
            0.003920785614509407*lm + 0.0013584693665443569*lm^2)*NL + 
          (-0.0016725634977875178 + 0.003920785614509407*lm + 
            0.0013584693665443569*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.031182424032042102 - 0.03036663731486765*lm - 
          0.0073105875196113335*lm^2) + CF^2*(0.03319051002436299 + 
          0.06551438037528026*lm + 0.035888338732637456*lm^2) + 
        CF*((0.00505332505665895 + 0.0038295005816361243*lm + 
            0.0013291977308384241*lm^2)*NM + (0.007718371930908083 + 
            0.0038295005816361243*lm + 0.0013291977308384241*lm^2)*NL + 
          (-0.0016365095712311019 + 0.0038295005816361243*lm + 
            0.0013291977308384241*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.030394676187322618 - 0.02967663640115067*lm - 
          0.007153544902113921*lm^2) + CF^2*(0.03240440260232497 + 
          0.06392206134429707*lm + 0.035117402246741064*lm^2) + 
        CF*((0.0048823610730293066 + 0.0037403863104638426*lm + 
            0.0013006445276570766*lm^2)*NM + (0.0075306293063933175 + 
            0.0037403863104638426*lm + 0.0013006445276570766*lm^2)*NL + 
          (-0.0016012498798130095 + 0.0037403863104638426*lm + 
            0.0013006445276570766*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.0296264641510192 - 0.02900320198756663*lm - 
          0.007000347694582225*lm^2) + CF^2*(0.031633379384300116 + 
          0.06236711668601125*lm + 0.034365343227949104*lm^2) + 
        CF*((0.004716792781295752 + 0.003653394283290608*lm + 
            0.0012727904899240408*lm^2)*NM + (0.007347759011106261 + 
            0.003653394283290608*lm + 0.0012727904899240408*lm^2)*NL + 
          (-0.0015667671617469246 + 0.003653394283290608*lm + 
            0.0012727904899240408*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.028877377840366793 - 0.02834593995561306*lm - 
          0.006850892853737766*lm^2) + CF^2*(0.030877380920763243 + 
          0.06084878939599032*lm + 0.03363165582743994*lm^2) + 
        CF*((0.004556460045006356 + 0.0035684766869324785*lm + 
            0.0012456168824977758*lm^2)*NM + (0.007169637196540419 + 
            0.0035684766869324785*lm + 0.0012456168824977758*lm^2)*NL + 
          (-0.001533044470887578 + 0.0035684766869324785*lm + 
            0.0012456168824977758*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.02814700875495434 - 0.027704463826422762*lm - 
          0.006705080189282718*lm^2) + CF^2*(0.030136329924272048 + 
          0.05936632736460431*lm + 0.03291584820193335*lm^2) + 
        CF*((0.00440120663644877 + 0.003485586437036237*lm + 
            0.0012191054889604943*lm^2)*NM + (0.006996142431342859 + 
            0.003485586437036237*lm + 0.0012191054889604943*lm^2)*NL + 
          (-0.0015000651761498392 + 0.003485586437036237*lm + 
            0.0012191054889604943*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.027434950679410357 - 0.027078394781951835*lm - 
          0.00656281229194611*lm^2) + CF^2*(0.02941013279708783 + 
          0.05791898430345389*lm + 0.032217442160462725*lm^2) + 
        CF*((0.004250880221868465 + 0.003404677198582226*lm + 
            0.0011932385985356565*lm^2)*NM + (0.006827155728914729 + 
            0.003404677198582226*lm + 0.0011932385985356565*lm^2)*NL + 
          (-0.0014678129604525575 + 0.003404677198582226*lm + 
            0.0011932385985356565*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.02674080031028714 - 0.026467361668089735*lm - 
          0.006423994462358013*lm^2) + CF^2*(0.02869868106629551 + 
          0.05650602057358819*lm + 0.03153597281521206*lm^2) + 
        CF*((0.004105332337485201 + 0.0033257034029086758*lm + 
            0.0011679989931560023*lm^2)*NM + (0.006662560566128837 + 
            0.0033257034029086758*lm + 0.0011679989931560023*lm^2)*NL + 
          (-0.0014362718192196752 + 0.0033257034029086758*lm + 
            0.0011679989931560023*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.026064157813513653 - 0.025871000981506333*lm - 
          0.006288534640856117*lm^2) + CF^2*(0.028001852730899498 + 
          0.05512670392322937*lm + 0.030870988236930026*lm^2) + 
        CF*((0.0039644183576947045 + 0.0032486202615633723*lm + 
            0.001143369934701112*lm^2)*NM + (0.006502242894080126 + 
            0.0032486202615633723*lm + 0.001143369934701112*lm^2)*NL + 
          (-0.0014054260584971333 + 0.0032486202615633723*lm + 
            0.001143369934701112*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.025404627318218374 - 0.02528895684190172*lm - 
          0.006156343338313841*lm^2) + CF^2*(0.027319513525114473 + 
          0.0537803101421618*lm + 0.03022204911535886*lm^2) + 
        CF*((0.003827997456144198 + 0.003173383777264878*lm + 
            0.0011193351524206984*lm^2)*NM + (0.00634609114170464 + 
            0.003173383777264878*lm + 0.0011193351524206984*lm^2)*NL + 
          (-0.0013752602927170324 + 0.003173383777264878*lm + 
            0.0011193351524206984*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.02476181735233486 - 0.02472088095118676*lm - 
          0.00602733356806548*lm^2) + CF^2*(0.026651518102087282 + 
          0.052466123639424586*lm + 0.02958872842504872*lm^2) + 
        CF*((0.003695932560854085 + 0.0030999507522336796*lm + 
            0.00109587883055736*lm^2)*NM + (0.006193996213029211 + 
            0.0030999507522336796*lm + 0.00109587883055736*lm^2)*NL + 
          (-0.0013457594421232915 + 0.0030999507522336796*lm + 
            0.00109587883055736*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.02413534122492752 - 0.024166432540995677*lm - 
          0.005901420778991641*lm^2) + CF^2*(0.025997711142049726 + 
          0.05118343795046274*lm + 0.028970611096868056*lm^2) + 
        CF*((0.003568090304030272 + 0.0030282787941333794*lm + 
            0.0010729855961802983*lm^2)*NM + (0.006045851478746777 + 
            0.0030282787941333794*lm + 0.0010729855961802983*lm^2)*NL + 
          (-0.0013169087299583332 + 0.0030282787941333794*lm + 
            0.0010729855961802983*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.023524817359805324 - 0.02362527830981495*lm - 
          0.00577852278981735*lm^2) + CF^2*(0.025357928388806586 + 
          0.049931556179443684*lm + 0.02836729369546699*lm^2) + 
        CF*((0.003444340967291778 + 0.0029583263198433313*lm + 
            0.0010506405072395182*lm^2)*NM + (0.0059015527627507254 + 
            0.0029583263198433313*lm + 0.0010506405072395182*lm^2)*NL + 
          (-0.0012886936793425879 + 0.0029583263198433313*lm + 
            0.0010506405072395182*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.022929869584675567 - 0.02309709235090507*lm - 
          0.005658559724665384*lm^2) + CF^2*(0.024731997618411515 + 
          0.04870979138202798*lm + 0.027778384102902794*lm^2) + 
        CF*((0.0033245584233951796 + 0.0028900525572667832*lm + 
            0.0010288290408482516*lm^2)*NM + (0.005760998324205198 + 
            0.0028900525572667832*lm + 0.0010288290408482516*lm^2)*NL + 
          (-0.0012611001099718704 + 0.0028900525572667832*lm + 
            0.0010288290408482516*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.022350127379578772 - 0.022581556072092442*lm - 
          0.00554145394989872*lm^2) + CF^2*(0.024119739543382996 + 
          0.04751746689349571*lm + 0.027203501208593717*lm^2) + 
        CF*((0.0032086200738285536 + 0.0028234175453625584*lm + 
            0.0010075370817997672*lm^2)*NM + (0.0056240888356767 + 
            0.0028234175453625584*lm + 0.0010075370817997672*lm^2)*NL + 
          (-0.0012341141345996196 + 0.0028234175453625584*lm + 
            0.0010075370817997672*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.02178522608842179 - 0.022078358108417247*lm - 
          0.005427130012278221*lm^2) + CF^2*(0.023520968656434035 + 
          0.04635391660676914*lm + 0.02664227460572945*lm^2) + 
        CF*((0.0030964067849312167 + 0.002758382132573465*lm + 
            0.0009867509113233128*lm^2)*NM + (0.005490727357805035 + 
            0.002758382132573465*lm + 0.0009867509113233128*lm^2)*NL + 
          (-0.0012077221553497722 + 0.002758382132573465*lm + 
            0.0009867509113233128*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.021234807096602023 - 0.02158719422853873*lm - 
          0.005315514578454769*lm^2) + CF^2*(0.02293549401646299 + 
          0.04521848520453769*lm + 0.0260943442942325*lm^2) + 
        CF*((0.002987802820668833 + 0.0026949079738108972*lm + 
            0.0009664571960826852*lm^2)*NM + (0.005360819310948307 + 
            0.0026949079738108972*lm + 0.0009664571960826852*lm^2)*NL + 
          (-0.0011819108598334377 + 0.0026949079738108972*lm + 
            0.0009664571960826852*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.020698517977982687 - 0.021107767235721754*lm - 
          0.005206536375808934*lm^2) + CF^2*(0.022363119980466677 + 
          0.044110528349379896*lm + 0.025559360390334764*lm^2) + 
        CF*((0.002882695774242949 + 0.002632957526142384*lm + 
            0.000946642977419806*lm^2)*NM + (0.00523427244419708 + 
            0.002632957526142384*lm + 0.000946642977419806*lm^2)*NL + 
          (-0.0011566672172654265 + 0.002632957526142384*lm + 
            0.000946642977419806*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.020176012613867766 - 0.020639786864156975*lm - 
          0.005100126134645828*lm^2) + CF^2*(0.021803646884155432 + 
          0.04302941283548813*lm + 0.025036982842806792*lm^2) + 
        CF*((0.002780976497960593 + 0.0025724940433171097*lm + 
            0.000927295660844696*lm^2)*NM + (0.005110996802116485 + 
            0.0025724940433171097*lm + 0.000927295660844696*lm^2)*NL + 
          (-0.0011319784742773872 + 0.0025724940433171097*lm + 
            0.000927295660844696*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.0196669512866667 - 0.02018296967130103*lm - 
          0.004996216531747995*lm^2) + CF^2*(0.02125687167443875 + 
          0.04197451670533336*lm + 0.024526881155853792*lm^2) + 
        CF*((0.0026825390326157455 + 0.002513481569253544*lm + 
            0.0009084030057723627*lm^2)*NM + (0.004990904689541866 + 
            0.002513481569253544*lm + 0.0009084030057723627*lm^2)*NL + 
          (-0.0011078321507908319 + 0.002513481569253544*lm + 
            0.0009084030057723627*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.019171000750360163 - 0.019737038926862523*lm - 
          0.004894742135284921*lm^2) + CF^2*(0.02072258849606796 + 
          0.04094522933435779*lm + 0.02402873411867143*lm^2) + 
        CF*((0.002587280534937553 + 0.002455884930603287*lm + 
            0.0008899531155063492*lm^2)*NM + (0.004873910634723131 + 
            0.002455884930603287*lm + 0.0008899531155063492*lm^2)*NL + 
          (-0.0010842160357381785 + 0.002455884930603287*lm + 
            0.0008899531155063492*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.018687834280324476 - 0.019301724499003706*lm - 
          0.004795639351074058*lm^2) + CF^2*(0.02020058923586126 + 
          0.0399409514865519*lm + 0.023542229541636286*lm^2) + 
        CF*((0.002495101206146795 + 0.0023996697284959334*lm + 
            0.0008719344274680105*lm^2)*NM + (0.004759931351085147 + 
            0.0023996697284959334*lm + 0.0008719344274680105*lm^2)*NL + 
          (-0.0010611181827345022 + 0.0023996697284959334*lm + 
            0.0008719344274680105*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.018217131704126283 - 0.018876762738276386*lm - 
          0.004698846370184946*lm^2) + CF^2*(0.01969066402626586 + 
          0.03896109534355698*lm + 0.023067063999089733*lm^2) + 
        CF*((0.0024059042191233444 + 0.002344802329561174*lm + 
            0.0008543357036699901*lm^2)*NM + (0.004648885697846081 + 
            0.002344802329561174*lm + 0.0008543357036699901*lm^2)*NL + 
          (-0.0010385269056836586 + 0.002344802329561174*lm + 
            0.0008543357036699901*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.017758579415341733 - 0.018461896359763152*lm - 
          0.004604303117875172*lm^2) + CF^2*(0.019192601711095134 + 
          0.03800508450973512*lm + 0.022602942578659933*lm^2) + 
        CF*((0.002319595646041728 + 0.002291249856316401*lm + 
            0.0008371460214318494*lm^2)*NM + (0.004540694639712268 + 
            0.002291249856316401*lm + 0.0008371460214318494*lm^2)*NL + 
          (-0.0010164307744314157 + 0.002291249856316401*lm + 
            0.0008371460214318494*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.017311870372029917 - 0.018056874323851595*lm - 
          0.0045119512038444345*lm^2) + CF^2*(0.018706190275606948 + 
          0.03707235399546277*lm + 0.022149578637054496*lm^2) + 
        CF*((0.002236084386217099 + 0.0022389801770007515*lm + 
            0.0008203547643353517*lm^2)*NM + (0.0044352812058469256 + 
            0.0022389801770007515*lm + 0.0008203547643353517*lm^2)*NL + 
          (-0.0009948186101626404 + 0.0022389801770007515*lm + 
            0.0008203547643353517*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.016876704081396222 - 0.0176614517160291*lm - 
          0.004421733873790797*lm^2) + CF^2*(0.018231217243059743 + 
          0.03616235018073232*lm + 0.021706693562245735*lm^2) + 
        CF*((0.0021552820942969766 + 0.002187961894929734*lm + 
            0.0008039516134165087*lm^2)*NM + (0.004332570448290505 + 
            0.002187961894929734*lm + 0.0008039516134165087*lm^2)*NL + 
          (-0.0009736794810930535 + 0.002187961894929734*lm + 
            0.0008039516134165087*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.016452786572073552 - 0.017275389626048857*lm - 
          0.004333595962251402*lm^2) + CF^2*(0.017767470039808945 + 
          0.03527453076098622*lm + 0.021274016541961427*lm^2) + 
        CF*((0.002077103108954763 + 0.0021381643374383105*lm + 
            0.000787926538591164*lm^2)*NM + (0.0042324893999927254 + 
            0.0021381643374383105*lm + 0.000787926538591164*lm^2)*NL + 
          (-0.0009530026978838407 + 0.0021381643374383105*lm + 
            0.000787926538591164*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.01603983035533458 - 0.01689845502678405*lm - 
          0.004247483846708291*lm^2) + CF^2*(0.017314736330902962 + 
          0.03440836467695999*lm + 0.020851284338386154*lm^2) + 
        CF*((0.0020014643823454887 + 0.00208955754447452*lm + 
            0.0007722697903105983*lm^2)*NM + (0.004134967032600012 + 
            0.00208955754447452*lm + 0.0007722697903105983*lm^2)*NL + 
          (-0.0009327778092302806 + 0.00208955754447452*lm + 
            0.0007722697903105983*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.015637554376423803 - 0.016530420653055836*lm - 
          0.004163345402938703*lm^2) + CF^2*(0.01687280432800191 + 
          0.03356333203017305*lm + 0.020438241068971817*lm^2) + 
        CF*((0.0019282854103475286 + 0.0020421122569003695*lm + 
            0.0007569718914434006*lm^2)*NM + (0.004039934214127235 + 
            0.0020421122569003695*lm + 0.0007569718914434006*lm^2)*NL + 
          (-0.000912994597360317 + 0.0020421122569003695*lm + 
            0.0007569718914434006*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.015245748287822233 - 0.016171084537411864*lm - 
          0.004081132339260949*lm^2) + CF*(0.01644146837403874 + 
          0.032738993305989714*lm + 0.02003464966546284*lm^2) + 
        0.0018575027656239488*NM + 0.0019958029282954913*lm*NM + 
        0.0007420240616838089*lm^2*NM + 0.003947334513349247*NL + 
        0.0019958029282954913*lm*NL + 0.0007420240616838089*lm^2*NL - 
        0.0008936434310882462*NH + 0.0019958029282954913*lm*NH + 
        0.0007420240616838089*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.01486400405771849 - 0.01582018790335029*lm - 
          0.004000790234326504*lm^2) + CF*(0.016020507289399463 + 
          0.03193470016955799*lm + 0.01964024296851193*lm^2) + 
        0.0017890091152087974*NM + 0.0019505951017567294*lm*NM + 
        0.0007274164062411826*lm^2*NM + 0.003857078910874446*NL + 
        0.0019505951017567294*lm*NL + 0.0007274164062411826*lm^2*NL - 
        0.0008747137703378513*NH + 0.0019505951017567294*lm*NH + 
        0.0007274164062411826*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.014492136695034763 - 0.015477543613931033*lm - 
          0.003922274057530708*lm^2) + CF*(0.015609718600136933 + 
          0.031150048637273258*lm + 0.019254799918787112*lm^2) + 
        0.0017227486976003068*NM + 0.0019064651726910984*lm*NM + 
        0.000713140737732856*lm^2*NM + 0.0037691167224589354*NL + 
        0.0019064651726910984*lm*NL + 0.000713140737732856*lm^2*NL - 
        0.0008561964996807134*NH + 0.0019064651726910984*lm*NH + 
        0.000713140737732856*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.014129889950946576 - 0.015142946162002192*lm - 
          0.0038455372447728604*lm^2) + CF*(0.01520889528456345 + 
          0.030384562071970548*lm + 0.01887809192888495*lm^2) + 
        0.0016586504399946711*NM + 0.001863386551325687*lm*NM + 
        0.0006991885899587019*lm^2*NM + 0.0036833859317784946*NL + 
        0.001863386551325687*lm*NL + 0.0006991885899587019*lm^2*NL - 
        0.0008380822895632223*NH + 0.001863386551325687*lm*NH + 
        0.0006991885899587019*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.01377701369647402 - 0.014816195217045995*lm - 
          0.0037705345264837514*lm^2) + CF*(0.014817832048980914 + 
          0.029637774452878456*lm + 0.01850989676637478*lm^2) + 
        0.001596645489205886*NM + 0.0018213332895327839*lm*NM + 
        0.0006855517320879548*lm^2*NM + 0.0035998262163165697*NL + 
        0.0018213332895327839*lm*NL + 0.0006855517320879548*lm^2*NL - 
        0.0008203620221576479*NH + 0.0018213332895327839*lm*NH + 
        0.0006855517320879548*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.013433263828628474 - 0.01449709550658658*lm - 
          0.0036972218897273063*lm^2) + CF*(0.014436325503237197 + 
          0.028909230226607963*lm + 0.018149998367752232*lm^2) + 
        0.0015366671469911213*NM + 0.001780280068037522*lm*NM + 
        0.0006722221617686011*lm^2*NM + 0.0035183789053402025*NL + 
        0.001780280068037522*lm*NL + 0.0006722221617686011*lm^2*NL - 
        0.0008030267870231461*NH + 0.001780280068037522*lm*NH + 
        0.0006722221617686011*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.013098402173466934 - 0.014185456699133365*lm - 
          0.003625556541411899*lm^2) + CF*(0.014064174318859212 + 
          0.028198484152996386*lm + 0.01779818665784023*lm^2) + 
        0.0014786508068293154*NM + 0.001740202183647941*lm*NM + 
        0.000659192098438527*lm^2*NM + 0.003438986938480942*NL + 
        0.001740202183647941*lm*NL + 0.000659192098438527*lm^2*NL - 
        0.0007860678768145147*NH + 0.001740202183647941*lm*NH + 
        0.000659192098438527*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.012772196386539045 - 0.01388109328874212*lm - 
          0.0035554968725820565*lm^2) + CF*(0.0137011793709425 + 
          0.02750510114654409*lm + 0.017454257374493732*lm^2) + 
        0.0014225338921573139*NM + 0.0017010755365291657*lm*NM + 
        0.0006464539768331011*lm^2*NM + 0.0033615948249513775*NL + 
        0.0017010755365291657*lm*NL + 0.0006464539768331011*lm^2*NL - 
        0.0007694767830414563*NH + 0.0017010755365291657*lm*NH + 
        0.0006464539768331011*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.012454419851172172 - 0.013583824481265196*lm - 
          0.0034870024237617357*lm^2) + CF*(0.013347143864906801 + 
          0.026828656114124348*lm + 0.017118011898466703*lm^2) + 
        0.0013682557960640255*NM + 0.0016628766175413696*lm*NM + 
        0.0006340004406839519*lm^2*NM + 0.0032861486034236292*NL + 
        0.0016628766175413696*lm*NL + 0.0006340004406839519*lm^2*NL - 
        0.0007532451918807895*NH + 0.0016628766175413696*lm*NH + 
        0.0006340004406839519*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.012144851575002977 - 0.013293474082352694*lm - 
          0.0034200338513208526*lm^2) + CF*(0.013001873449160728 + 
          0.02616873378959306*lm + 0.016789257088302367*lm^2) + 
        0.001315757822439588*NM + 0.0016255824956593007*lm*NM + 
        0.0006218243366037914*lm^2*NM + 0.0032125958025922036*NL + 
        0.0016255824956593007*lm*NL + 0.0006218243366037914*lm^2*NL - 
        0.0007373649800437635*NH + 0.0016255824956593007*lm*NH + 
        0.0006218243366037914*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.011843276085129507 - 0.013009870387257224*lm - 
          0.003354552894837234*lm^2) + CF*(0.01266517631465591 + 
          0.02552492856587518*lm + 0.01646780512011006*lm^2) + 
        0.0012649831285734075*NM + 0.0015891708054893918*lm*NM + 
        0.0006099187081522245*lm^2*NM + 0.0031408854024399667*NL + 
        0.0015891708054893918*lm*NL + 0.0006099187081522245*lm^2*NL - 
        0.0007218282107003547*NH + 0.0015891708054893918*lm*NH + 
        0.0006099187081522245*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.011549483322225782 - 0.01273284607248672*lm - 
          0.003290522345426695*lm^2) + CF*(0.012336863282251745 + 
          0.024896844325057788*lm + 0.016153473332094683*lm^2) + 
        0.0012158766691920972*NM + 0.0015536197348988462*lm*NM + 
        0.000598276790077581*lm^2*NM + 0.003070967796222673*NL + 
        0.0015536197348988462*lm*NL + 0.000598276790077581*lm^2*NL - 
        0.0007066271294621799*NH + 0.0015536197348988462*lm*NH + 
        0.000598276790077581*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.011263268533931087 - 0.012462238089341965*lm - 
          0.003227906015014451*lm^2) + CF*(0.012016747878756041 + 
          0.024284094266976374*lm + 0.015846084073707304*lm^2) + 
        0.001168385141925827*NM + 0.0015189080127695751*lm*NM + 
        0.0005868920027299002*lm^2*NM + 0.003002794753184435*NL + 
        0.0015189080127695751*lm*NL + 0.0005868920027299002*lm^2*NL - 
        0.0006917541604254243*NH + 0.0015189080127695751*lm*NH + 
        0.0005868920027299002*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.010984432167798434 - 0.012197887559368617*lm - 
          0.00316666870652163*lm^2) + CF*(0.011704646402453943 + 
          0.023686300736740027*lm + 0.015545464559288003*lm^2) + 
        0.001122456934189319*NM + 0.001485014896888462*lm*NM + 
        0.0005757579466402964*lm^2*NM + 0.0029363193820137194*NL + 
        0.001485014896888462*lm*NL + 0.0005757579466402964*lm^2*NL - 
        0.0006772019022749648*NH + 0.001485014896888462*lm*NH + 
        0.0005757579466402964*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.010712779764060973 - 0.011939639671746912*lm - 
          0.0031067761849411686*lm^2) + CF*(0.011400377978887835 + 
          0.02310309505160354*lm + 0.015251446726074829*lm^2) + 
        0.001078042071461732*NM + 0.0014519201619841266*lm*NM + 
        0.0005648683972620307*lm^2*NM + 0.002871496095046918*NL + 
        0.0014519201619841266*lm*NL + 0.0005648683972620307*lm^2*NL - 
        0.0006629631244506786*NH + 0.0014519201619841266*lm*NH + 
        0.0005648683972620307*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.010448121848451179 - 0.011687343582636402*lm - 
          0.0030481951492779408*lm^2) + CF*(0.011103764607603896 + 
          0.022534117327558934*lm + 0.014963867096455346*lm^2) + 
        0.0010350921669478883*NM + 0.0014196040879191612*lm*NM + 
        0.0005542172998687165*lm^2*NM + 0.002808280573224206*NL + 
        0.0014196040879191612*lm*NL + 0.0005542172998687165*lm^2*NL - 
        0.0006490307633767304*NH + 0.0014196040879191612*lm*NH + 
        0.0005542172998687165*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.010190273825285518 - 0.011440852316487617*lm - 
          0.0029908932053285034*lm^2) + CF*(0.010814631200536601 + 
          0.021979016305986154*lm + 0.014682566644339924*lm^2) + 
        0.000993560372601745*NM + 0.0013880474480456983*lm*NM + 
        0.0005437987646051824*lm^2*NM + 0.002746629731800297*NL + 
        0.0013880474480456983*lm*NL + 0.0005437987646051824*lm^2*NL - 
        0.0006353979187544731*NH + 0.0013880474480456983*lm*NH + 
        0.0005437987646051824*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.00993905587100671 - 0.011200022669327585*lm - 
          0.0029348388392764005*lm^2) + CF*(0.010532805612660765 + 
          0.021437449180672093*lm + 0.014407390665538694*lm^2) + 
        0.0009534013314916355*NM + 0.0013572314977311375*lm*NM + 
        0.0005336070616866183*lm^2*NM + 0.0026865016868107827*NL + 
        0.0013572314977311375*lm*NL + 0.0005336070616866183*lm^2*NL - 
        0.0006220578499194324*NH + 0.0013572314977311375*lm*NH + 
        0.0005336070616866183*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.009694292828356637 - 0.010964715114021677*lm - 
          0.002880001392079518*lm^2) + CF*(0.010258118665501222 + 
          0.02090908142547854*lm + 0.014138188652026724*lm^2) + 
        0.0009145711314856397*NM + 0.0013271379630599208*lm*NM + 
        0.0005236366167417305*lm^2*NM + 0.0026278557222930068*NL + 
        0.0013271379630599208*lm*NL + 0.0005236366167417305*lm^2*NL - 
        0.0006090039722627037*NH + 0.0013271379630599208*lm*NH + 
        0.0005236366167417305*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.009455814101335376 - 0.010734793707510086*lm - 
          0.0028263510346265212*lm^2) + CF*(0.009990404164053175 + 
          0.020393586622913323*lm + 0.01387481416998474*lm^2) + 
        0.0008770272602344134*NM + 0.0012977490297163578*lm*NM + 
        0.0005138820062957312*lm^2*NM + 0.00257065225825885*NL + 
        0.0012977490297163578*lm*NL + 0.0005138820062957312*lm^2*NL - 
        0.0005962298537169583*NH + 0.0012977490297163578*lm*NH + 
        0.0005138820062957312*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.009223453551085432 - 0.010510126000013524*lm - 
          0.0027738587436399787*lm^2) + CF*(0.009729498907631171 + 
          0.019890646293834233*lm + 0.013617124741505351*lm^2) + 
        0.0008407285614279561*NM + 0.0012690473320527116*lm*NM + 
        0.0005043379533890871*lm^2*NM + 0.0025148528194154094*NL + 
        0.0012690473320527116*lm*NL + 0.0005043379533890871*lm^2*NL - 
        0.0005837292113071314*NH + 0.0012690473320527116*lm*NH + 
        0.0005043379533890871*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.008997049392825236 - 0.010290582946199391*lm - 
          0.002722496278304288*lm^2) + CF*(0.009475242695131727 + 
          0.019399949728492627*lm + 0.013364981729857414*lm^2) + 
        0.0008056351923020739*NM + 0.0012410159423460044*lm*NM + 
        0.0004949993233280524*lm^2*NM + 0.0024604200046282527*NL + 
        0.0012410159423460044*lm*NL + 0.0004949993233280524*lm^2*NL - 
        0.0005714959077657543*NH + 0.0012410159423460044*lm*NH + 
        0.0004949993233280524*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.008776444093942003 - 0.01007603881829657*lm - 
          0.0026722361575970905*lm^2) + CF*(0.009227478325163555 + 
          0.018921193819102372*lm + 0.013118250228203898*lm^2) + 
        0.0007717085823697047*NM + 0.0012136383602463308*lm*NM + 
        0.00048586111956310733*lm^2*NM + 0.002407317457120839*NL + 
        0.0012136383602463308*lm*NL + 0.00048586111956310733*lm^2*NL - 
        0.0005595239482127908*NH + 0.0012136383602463308*lm*NH + 
        0.00048586111956310733*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.008561484273341196 - 0.009866371121144276*lm - 
          0.0026230516383033823*lm^2) + CF*(0.008986051591470087 + 
          0.018454082894100183*lm + 0.012876798951671148*lm^2) + 
        0.0007389113933518051*NM + 0.0011868985024188377*lm*NM + 
        0.00047691847969152403*lm^2*NM + 0.0023555098354026403*NL + 
        0.0011868985024188377*lm*NL + 0.00047691847969152403*lm^2*NL - 
        0.0005478074768997444*NH + 0.0011868985024188377*lm*NH + 
        0.00047691847969152403*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.008352020602138016 - 0.009661460509157917*lm - 
          0.0025749166936920617*lm^2) + CF*(0.008750811274041434 + 
          0.017998328554245307*lm + 0.01264050013267012*lm^2) + 
        0.0007072074802821314*NM + 0.0011607806923809626*lm*NM + 
        0.0004681666715803748*lm^2*NM + 0.002304962784917643*NL + 
        0.0011607806923809626*lm*NL + 0.0004681666715803748*lm^2*NL - 
        0.0005363407740177168*NH + 0.0011607806923809626*lm*NH + 
        0.0004681666715803748*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.008147907705765386 - 0.009461190705192763*lm - 
          0.0025278059928351827*lm^2) + CF*(0.00852160912628704 + 
          0.017553649510689617*lm + 0.012409229419372714*lm^2) + 
        0.0006765618537599865*NM + 0.0011352696505359974*lm*NM + 
        0.0004596010896063968*lm^2*NM + 0.002255642910404088*NL + 
        0.0011352696505359974*lm*NL + 0.0004596010896063968*lm^2*NL - 
        0.0005251182525690236*NH + 0.0011352696505359974*lm*NH + 
        0.0004596010896063968*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.00794900406756288 - 0.00926544842128417*lm - 
          0.0024816948805506975*lm^2) + CF*(0.008298299858615847 + 
          0.017119771425133733*lm + 0.01218286577724888*lm^2) + 
        0.0006469406433248302*NM + 0.001110350484403572*lm*NM + 
        0.0004512172510092177*lm^2*NM + 0.0022075177489556345*NL + 
        0.001110350484403572*lm*NL + 0.0004512172510092177*lm^2*NL - 
        0.0005141344553019001*NH + 0.001110350484403572*lm*NH + 
        0.0004512172510092177*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.00775517193390181 - 0.009074123281241481*lm - 
          0.0024365593579499865*lm^2) + CF*(0.0080807411187479 + 
          0.016696426752170316*lm + 0.011961291393572661*lm^2) + 
        0.0006183110619265533*NM + 0.0010860086790472146*lm*NM + 
        0.000443010792354543*lm^2*NM + 0.0021605557437735204*NL + 
        0.0010860086790472146*lm*NL + 0.000443010792354543*lm^2*NL - 
        0.0005033840517077691*NH + 0.0010860086790472146*lm*NH + 
        0.000443010792354543*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.0075662772208932375 - 0.008887107745071121*lm - 
          0.002392376063571975*lm^2) + CF*(0.007868793469059658 + 
          0.016283354583902516*lm + 0.011744391584807877*lm^2) + 
        0.0005906413714652029*NM + 0.001062230087698755*lm*NM + 
        0.0004349774661039954*lm^2*NM + 0.0021147262185987684*NL + 
        0.001062230087698755*lm*NL + 0.0004349774661039954*lm^2*NL - 
        0.0004928618350804845*NH + 0.001062230087698755*lm*NH + 
        0.0004349774661039954*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.007382189422717843 - 0.00870429703520307*lm - 
          0.0023491222550861284*lm^2) + CF*(0.007662320361245086 + 
          0.015880300496913285*lm + 0.011532054706786449*lm^2) + 
        0.000563900849373987*NM + 0.0010390009225789746*lm*NM + 
        0.000427113137288387*lm^2*NM + 0.002069999352813055*NL + 
        0.0010390009225789746*lm*NL + 0.000427113137288387*lm^2*NL - 
        0.0004825627196369141*NH + 0.0010390009225789746*lm*NH + 
        0.000427113137288387*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.007202781521609555 - 0.008525589064493796*lm - 
          0.002306775791547116*lm^2) + CF*(0.007461188108555407 + 
          0.015487016401650028*lm + 0.011324172067594934*lm^2) + 
        0.0005380597562194976*NM + 0.0010163077459135889*lm*NM + 
        0.00041941378028129383*lm^2*NM + 0.00202634615719647*NL + 
        0.0010163077459135889*lm*NL + 0.00041941378028129383*lm^2*NL - 
        0.00047248173769817774*NH + 0.0010163077459135889*lm*NH + 
        0.00041941378028129383*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.007027929899518282 - 0.00835088436597767*lm - 
          0.002265315116184394*lm^2) + CF*(0.007265265855862599 + 
          0.015103260394278664*lm + 0.011120637843087026*lm^2) + 
        0.00051308930429325*NM + 0.0009941374611433526*lm*NM + 
        0.00041187547566988984*lm^2*NM + 0.001983738450330084*NL + 
        0.0009941374611433526*lm*NL + 0.00041187547566988984*lm^2*NL - 
        0.0004626140369308193*NH + 0.0009941374611433526*lm*NH + 
        0.00041187547566988984*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.006857514251471176 - 0.008180086024338054*lm - 
          0.002224719239710446*lm^2) + CF*(0.007074425547774739 + 
          0.014728796611051712*lm + 0.01092134899494219*lm^2) + 
        0.0004889616271688465*NM + 0.0009724773043268157*lm*NM + 
        0.0004044944072200811*lm^2*NM + 0.001942148835631006*NL + 
        0.0009724773043268157*lm*NL + 0.0004044944072200811*lm^2*NL - 
        0.0004529548776471519*NH + 0.0009724773043268157*lm*NH + 
        0.0004044944072200811*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.006691417500646425 - 0.008013099609068585*lm - 
          0.0021849677241318646*lm^2) + CF*(0.006888541895015605 + 
          0.0143633950852262*lm + 0.010726205191192792*lm^2) + 
        0.00046564975019931933*NM + 0.0009513148357340219*lm*NM + 
        0.00039726685893306634*lm^2*NM + 0.0019015506790073763*NL + 
        0.0009513148357340219*lm*NL + 0.00039726685893306634*lm^2*NL - 
        0.0004434996301639861*NH + 0.0009513148357340219*lm*NH + 
        0.00039726685893306634*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.006529525715168683 - 0.007849833109294513*lm - 
          0.00214604066704792*lm^2) + CF*(0.006707492339265983 + 
          0.014006831606559236*lm + 0.010535108729144335*lm^2) + 
        0.00044312756192950296*NM + 0.0009306379316292358*lm*NM + 
        0.0003901892121905309*lm^2*NM + 0.0018619180871206323*NL + 
        0.0009306379316292358*lm*NL + 0.0003901892121905309*lm^2*NL - 
        0.000434243772218923*NH + 0.0009306379316292358*lm*NH + 
        0.0003901892121905309*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.006371728026630724 - 0.007690196870223579*lm - 
          0.0021079186864216936*lm^2) + CF*(0.006531157016650257 + 
          0.013658887583401684*lm + 0.010347964460615587*lm^2) + 
        0.00042136978639860254*NM + 0.0009104347762405894*lm*NM + 
        0.00038325794298576247*lm^2*NM + 0.0018232258862422384*NL + 
        0.0009104347762405894*lm*NL + 0.00038325794298576247*lm^2*NL - 
        0.0004251828864433698*NH + 0.0009104347762405894*lm*NH + 
        0.00038325794298576247*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.006217916550341886 - 0.007534103531195472*lm - 
          0.0020705829058092953*lm^2) + CF*(0.006359418720038729 + 
          0.01331934990740376*lm + 0.01016467971942745*lm^2) + 
        0.00040035195630848007*NM + 0.0008906938539143811*lm*NM + 
        0.0003764696192380537*lm^2*NM + 0.0017854496016920288*NL + 
        0.0008906938539143811*lm*NL + 0.0003764696192380537*lm^2*NL - 
        0.0004163126578914158*NH + 0.0008906938539143811*lm*NH + 
        0.0003764696192380537*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.006067986307300212 - 0.007381467965298701*lm - 
          0.0020340149400330967*lm^2) + CF*(0.006192162860323856 + 
          0.012988010820840133*lm + 0.009985164251071564*lm^2) + 
        0.00038005038703355526*NM + 0.0008714039414516094*lm*NM + 
        0.0003698208981878357*lm^2*NM + 0.0017485654378452664*NL + 
        0.0008714039414516094*lm*NL + 0.0003698208981878357*lm^2*NL - 
        0.00040762887162368896*NH + 0.0008714039414516094*lm*NH + 
        0.0003698208981878357*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0059218351478818355 - 0.00723220722052352*lm - 
          0.001998196881285332*lm^2) + CF*(0.006029277426817069 + 
          0.012664667786556665*lm + 0.00980933014449163*lm^2) + 
        0.0003604421514486176*NM + 0.0008525541006241995*lm*NM + 
        0.00036330852387006035*lm^2*NM + 0.0017125502586955322*NL + 
        0.0008525541006241995*lm*NL + 0.00036330852387006035*lm^2*NL - 
        0.00039912741034529983*NH + 0.0008525541006241995*lm*NH + 
        0.00036330852387006035*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.005779363677238251 - 0.007086240462419421*lm - 
          0.0019631112856488193*lm^2) + CF*(0.005870652946902032 + 
          0.012349123360535697*lm + 0.009637091765912384*lm^2) + 
        0.00034150505555126284*NM + 0.0008341336708682672*lm*NM + 
        0.00035692932466342166*lm^2*NM + 0.0016773815689605823*NL + 
        0.0008341336708682672*lm*NL + 0.00035692932466342166*lm^2*NL - 
        0.00039080425209696735*NH + 0.0008341336708682672*lm*NH + 
        0.00035692932466342166*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.005640475182389386 - 0.006943488918225763*lm - 
          0.0019287411600219437*lm^2) + CF*(0.005716182445070106 + 
          0.012041185067072354*lm + 0.009468365694653178*lm^2) + 
        0.0003232176148561007*NM + 0.0008161322621516723*lm*NM + 
        0.0003506802109130807*lm^2*NM + 0.0016430374957183745*NL + 
        0.0008161322621516723*lm*NL + 0.0003506802109130807*lm^2*NL - 
        0.00038265546799841284*NH + 0.0008161322621516723*lm*NH + 
        0.0003506802109130807*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.005505075560998034 - 0.006803875822444051*lm - 
          0.0018950699494354386*lm^2) + CF*(0.005565761401454265 + 
          0.01174066527655004*lm + 0.00930307066086488*lm^2) + 
        0.00030555903153832686*NM + 0.0007985397480130319*lm*NM + 
        0.0003445581726246252*lm^2*NM + 0.0016094967705605418*NL + 
        0.0007985397480130319*lm*NL + 0.0003445581726246252*lm^2*NL - 
        0.0003746772200431012*NH + 0.0007985397480130319*lm*NH + 
        0.0003445581726246252*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.005373073251809066 - 0.0066673263638205825*lm - 
          0.00186208152474886*lm^2) + CF*(0.005419287709968845 + 
          0.01144738108579961*lm + 0.009141127485130768*lm^2) + 
        0.0002885091723047088*NM + 0.0007813462587692954*lm*NM + 
        0.0003385602772270655*lm^2*NM + 0.0015767387122506997*NL + 
        0.0007813462587692954*lm*NL + 0.0003385602772270655*lm^2*NL - 
        0.00036686575894340456*NH + 0.0007813462587692954*lm*NH + 
        0.0003385602772270655*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.005244379166734968 - 0.006533767633708252*lm - 
          0.00182976017071503*lm^2) + CF*(0.0052766616361542016 + 
          0.011161154201023265*lm + 0.008982459019873783*lm^2) + 
        0.0002720485469705006*NM + 0.0007645421748889314*lm*NM + 
        0.0003326836674027327*lm^2*NM + 0.0015447432098750899*NL + 
        0.0007645421748889314*lm*NL + 0.0003326836674027327*lm^2*NL - 
        0.0003592174220252604*NH + 0.0007645421748889314*lm*NH + 
        0.0003326836674027327*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.005118906624567587 - 0.006403128575776576*lm - 
          0.0017980905744010654*lm^2) + CF*(0.005137785774817534 + 
          0.010881810823261262*lm + 0.00882699009251432*lm^2) + 
        0.000256158287721273*NM + 0.0007481181205277259*lm*NM + 
        0.0003269255589820119*lm^2*NM + 0.0015134907064732056*NL + 
        0.0007481181205277259*lm*NL + 0.0003269255589820119*lm^2*NL - 
        0.0003517286311713956*NH + 0.0007481181205277259*lm*NH + 
        0.0003269255589820119*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.004996571286294489 - 0.0062753399370392236*lm - 
          0.0017670578139549686*lm^2) + CF*(0.005002565007553878 + 
          0.010609181536376671*lm + 0.008674647450324391*lm^2) + 
        0.00024082012903912063*NM + 0.0007320649572241636*lm*NM + 
        0.0003212832389009034*lm^2*NM + 0.0014829621831361957*NL + 
        0.0007320649572241636*lm*NL + 0.0003212832389009034*lm^2*NL - 
        0.00034439589081218937*NH + 0.0007320649572241636*lm*NH + 
        0.0003212832389009034*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.004877291091997089 - 0.006150334220168619*lm - 
          0.0017366473477070782*lm^2) + CF*(0.0048709064602244475 + 
          0.010343101197531162*lm + 0.008525359706925657*lm^2) + 
        0.00022601638827318834*NM + 0.0007163737777513341*lm*NM + 
        0.0003157540632194688*lm^2*NM + 0.001453139143561011*NL + 
        0.0007163737777513341*lm*NL + 0.0003157540632194688*lm^2*NL - 
        0.00033721578596324927*NH + 0.0007163737777513341*lm*NH + 
        0.0003157540632194688*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.0047609861993066094 - 0.006028045637067534*lm - 
          0.0017068450035960193*lm^2) + CF*(0.004742719460463118 + 
          0.010083408830122483*lm + 0.008379057290380458*lm^2) + 
        0.0002117299468349367*NM + 0.000701035900122291*lm*NM + 
        0.00031033545519927624*lm^2*NM + 0.0014240035990484366*NL + 
        0.000701035900122291*lm*NL + 0.00031033545519927624*lm^2*NL - 
        0.0003301849803087786*NH + 0.000701035900122291*lm*NH + 
        0.00031033545519927624*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.004647578923392946 - 0.005908410063667929*lm - 
          0.0016776369689091035*lm^2) + CF*(0.004617915495275925 + 
          0.00982994751915256*lm + 0.008235672392826507*lm^2) + 
        0.0001979442319990483*NM + 0.0006860428617457813*lm*NM + 
        0.00030502490343801877*lm^2*NM + 0.001395538053933337*NL + 
        0.0006860428617457813*lm*NL + 0.00030502490343801877*lm^2*NL - 
        0.00032330021432981935*NH + 0.0006860428617457813*lm*NH + 
        0.00030502490343801877*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.004536993678460786 - 0.005791364995927682*lm - 
          0.00164900978032744*lm^2) + CF*(0.004496408168792839 + 
          0.009582564308993334*lm + 0.008095138921607433*lm^2) + 
        0.000184643199291354*NM + 0.0006713864137292618*lm*NM + 
        0.0002998199600595345*lm^2*NM + 0.0013677254914356396*NL + 
        0.0006713864137292618*lm*NL + 0.0002998199600595345*lm^2*NL - 
        0.0003165583034764591*NH + 0.0006713864137292618*lm*NH + 
        0.0002998199600595345*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0044291569207266105 - 0.00567684950699626*lm - 
          0.0016209503142663234*lm^2) + CF*(0.0043781131602259535 + 
          0.009341110103516145*lm + 0.00795739245185286*lm^2) + 
        0.00017181131544563482*NM + 0.0006570585153261213*lm*NM + 
        0.0002947182389575133*lm^2*NM + 0.0013405493599207851*NL + 
        0.0006570585153261213*lm*NL + 0.0002947182389575133*lm^2*NL - 
        0.00030995613638309916*NH + 0.0006570585153261213*lm*NH + 
        0.0002947182389575133*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.004323997092849671 - 0.005564804205520814*lm - 
          0.0015934457775017502*lm^2) + CF*(0.004262948182083294 + 
          0.009105439568549117*lm + 0.007822370180463138*lm^2) + 
        0.0001594335419116283*NM + 0.0006430513285240406*lm*NM + 
        0.00028971741409122734*lm^2*NM + 0.0013139935595585803*NL + 
        0.0006430513285240406*lm*NL + 0.00028971741409122734*lm^2*NL - 
        0.00030349067312588767*NH + 0.0006430513285240406*lm*NH + 
        0.00028971741409122734*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.004221444569789644 - 0.005455171195064613*lm - 
          0.001566483698074211*lm^2) + CF*(0.004150832938683006 + 
          0.008875411036626*lm + 0.007690010881455218*lm^2) + 
        0.00014749531889703582*NM + 0.0006293572127714345*lm*NM + 
        0.00028481521783167474*lm^2*NM + 0.0012880424293696025*NL + 
        0.0006293572127714345*lm*NL + 0.00028481521783167474*lm^2*NL - 
        0.0002971589435214314*NH + 0.0006293572127714345*lm*NH + 
        0.00028481521783167474*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.004121431606063267 - 0.005347894034610207*lm - 
          0.0015400519164611663*lm^2) + CF*(0.004041689085008423 + 
          0.008650886413989008*lm + 0.007560254862627543*lm^2) + 
        0.00013598254992679135*NM + 0.0006159687198389412*lm*NM + 
        0.00028000943935657565*lm^2*NM + 0.0012626807346485232*NL + 
        0.0006159687198389412*lm*NL + 0.00028000943935657565*lm^2*NL - 
        0.00029095804546590834*NH + 0.0006159687198389412*lm*NH + 
        0.00028000943935657565*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.004023892284372092 - 0.005242917700120183*lm - 
          0.0015141385770098986*lm^2) + CF*(0.003935440185940586 + 
          0.008431731089807428*lm + 0.007433043923503138*lm^2) + 
        0.00012488158690331005*NM + 0.0006028785888129492*lm*NM + 
        0.0002752979230927088*lm^2*NM + 0.0012378936547539359*NL + 
        0.0006028785888129492*lm*NL + 0.0002752979230927088*lm^2*NL - 
        0.0002848851433137144*NH + 0.0006028785888129492*lm*NH + 
        0.0002752979230927088*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.003928762465573255 - 0.005140188547128836*lm - 
          0.001488732119622681*lm^2) + CF*(0.0038320116759011525 + 
          0.008217813847573228*lm + 0.007308321314511344*lm^2) + 
        0.00011417921565188595*NM + 0.0005900797412181762*lm*NM + 
        0.00027067856720412384*lm^2*NM + 0.001213666771254499*NL + 
        0.0005900797412181762*lm*NL + 0.00027067856720412384*lm^2*NL - 
        0.00027893746629478717*NH + 0.0005900797412181762*lm*NH + 
        0.00027067856720412384*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0038359797399651627 - 0.005039654274338607*lm - 
          0.0014638212716864614*lm^2) + CF*(0.0037313308189351945 + 
          0.00800900677863435*lm + 0.007186031697369902*lm^2) + 
        0.00010386264193585282*NM + 0.0005775652762663507*lm*NM + 
        0.0002661493221248112*lm^2*NM + 0.0011899860564214212*NL + 
        0.0005775652762663507*lm*NL + 0.0002661493221248112*lm^2*NL - 
        0.0002731123069697622*NH + 0.0005775652762663507*lm*NH + 
        0.0002661493221248112*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.0037454833798599174 - 0.004941263888195605*lm - 
          0.0014393950402395036*lm^2) + CF*(0.0036333266692602415 + 
          0.007805185197826082*lm + 0.00706612110663029*lm^2) + 
        0.00009391947792655984*NM + 0.0005653284662280761*lm*NM + 
        0.0002617081891344552*lm^2*NM + 0.0011668378620575497*NL + 
        0.0005653284662280761*lm*NL + 0.0002617081891344552*lm^2*NL - 
        0.00026740701972212714*NH + 0.0005653284662280761*lm*NH + 
        0.0002617081891344552*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.003657214293414377 - 0.004844967668419056*lm - 
          0.001415442704367667*lm^2) + CF*(0.0035379300323049537 + 
          0.007606227561160623*lm + 0.006948536912350365*lm^2) + 
        0.00008433772911364282*NM + 0.0005533627519249963*lm*NM + 
        0.0002573532189759395*lm^2*NM + 0.0011442089086535366*NL + 
        0.0005533627519249963*lm*NL + 0.0002573532189759395*lm^2*NL - 
        0.00026181901928655304*NH + 0.0005533627519249963*lm*NH + 
        0.0002573532189759395*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0035711149796918574 - 0.004750717134460013*lm - 
          0.0013919538078232358*lm^2) + CF*(0.0034450734262580947 + 
          0.007412015385534815*lm + 0.0068332277838595214*lm^2) + 
        0.00007510578164149397*NM + 0.0005416617383394188*lm*NM + 
        0.0002530825105133156*lm^2*NM + 0.0011220862748617876*NL + 
        0.0005416617383394188*lm*NL + 0.0002530825105133156*lm^2*NL - 
        0.0002563457793125936*NH + 0.0005416617383394188*lm*NH + 
        0.0002530825105133156*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.003487129484926614 - 0.004658465012865189*lm - 
          0.00136891815185943*lm^2) + CF*(0.0033546910441459073 + 
          0.007222433170415953*lm + 0.006720143654582656*lm^2) + 
        0.00006621239005824611*NM + 0.000530219190338596*lm*NM + 
        0.0002488942094289873*lm^2*NM + 0.0011004573872791187*NL + 
        0.000530219190338596*lm*NL + 0.0002488942094289873*lm^2*NL - 
        0.000250984830962955*NH + 0.000530219190338596*lm*NH + 
        0.0002488942094289873*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.0034052033599634613 - 0.004568165205522252*lm - 
          0.0013463257882739518*lm^2) + CF*(0.003266718716453667 + 
          0.007037368321465638*lm + 0.006609235687890309*lm^2) + 
        0.000057646665463992596*NM + 0.0005190290285109*lm*NM + 
        0.00024478650695890035*lm^2*NM + 0.001079310010529266*NL + 
        0.0005190290285109*lm*NL + 0.00024478650695890035*lm^2*NL - 
        0.00024573376154555344*NH + 0.0005190290285109*lm*NH + 
        0.00024478650695890035*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0033252836188451106 - 0.004479772758763475*lm - 
          0.0013241670126551274*lm^2) + CF*(0.003181093874304965 + 
          0.006856711076061677*lm + 0.006500456243943353*lm^2) + 
        0.000049398064045360246*NM + 0.0005080853251111808*lm*NM + 
        0.00024075763866456863*lm^2*NM + 0.001058632237636613*NL + 
        0.0005080853251111808*lm*NL + 0.00024075763866456863*lm^2*NL - 
        0.0002405902131785894*NH + 0.0005080853251111808*lm*NH + 
        0.00024075763866456863*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.003247318698520084 - 0.004393243833305096*lm - 
          0.0013024323578244093*lm^2) + CF*(0.0030977555132102826 + 
          0.0066803544306782555*lm + 0.0063937588475016455*lm^2) + 
        0.00004145637598394045*NM + 0.0004973823001126334*lm*NM + 
        0.00023680588324080168*lm^2*NM + 0.0010384124806827185*NL + 
        0.0004973823001126334*lm*NL + 0.00023680588324080168*lm^2*NL - 
        0.00023555188148788125*NH + 0.0004973823001126334*lm*NH + 
        0.00023680588324080168*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.00317125841964437 - 0.00430853567500028*lm - 
          0.0012811125874692003*lm^2) + CF*(0.0030166441573945156 + 
          0.006508194070084812*lm + 0.006289098156666984*lm^2) + 
        0.00003381171472646217*NM + 0.00048691431736255*lm*NM + 
        0.00023292956135803644*lm^2*NM + 0.0010186394617374415*NL + 
        0.00048691431736255*lm*NL + 0.00023292956135803644*lm^2*NL - 
        0.00023061651433571456*NH + 0.00048691431736255*lm*NH + 
        0.00023292956135803644*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.003097053948450313 - 0.004225606586384069*lm - 
          0.0012601986899601566*lm^2) + CF*(0.0029377018247113964 + 
          0.006340128298324296*lm + 0.006186429932531679*lm^2) + 
        0.000026454506604960298*NM + 0.0004766758808393811*lm*NM + 
        0.00022912703453821032*lm^2*NM + 0.0009993022040566712*NL + 
        0.0004766758808393811*lm*NL + 0.00022912703453821032*lm^2*NL - 
        0.00022578191058047578*NH + 0.0004766758808393811*lm*NH + 
        0.00022912703453821032*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.003024657759656585 - 0.0041444158989891846*lm - 
          0.0012396818723473025*lm^2) + CF*(0.002860871992151146 + 
          0.006176057971431871*lm + 0.00608571100970494*lm^2) + 
        0.00001937548079555415*NM + 0.00046666163100857514*lm*NM + 
        0.0002253967040631459*lm^2*NM + 0.0009803900235388781*NL + 
        0.00046666163100857514*lm*NL + 0.0002253967040631459*lm^2*NL - 
        0.00022104591886635354*NH + 0.00046666163100857514*lm*NH + 
        0.0002253967040631459*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.002954023600393473 - 0.004064923946412086*lm - 
          0.0012195535545294798*lm^2) + CF*(0.002786099561946221 + 
          0.006015886431855441*lm + 0.005986899267690173*lm^2) + 
        0.00001256565960480226*NM + 0.00045686634127471443*lm*NM + 
        0.00022173700991445086*lm^2*NM + 0.0009618925204329125*NL + 
        0.00045686634127471443*lm*NL + 0.00022173700991445086*lm^2*NL - 
        0.00021640643644240404*NH + 0.00045686634127471443*lm*NH + 
        0.00022173700991445086*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.002885106455118094 - 0.003987092038109108*lm - 
          0.001199805363591823*lm^2) + CF*(0.0027133308282786513 + 
          0.005859519444539828*lm + 0.005889953603087131*lm^2) + 
        6.016349072943132*^-6*NM + 0.00044728491452751524*lm*NM + 
        0.00021814642974396782*lm^2*NM + 0.0009437995712896696*NL + 
        0.00044728491452751524*lm*NL + 0.00021814642974396782*lm^2*NL - 
        0.00021186140801029011*NH + 0.00044728491452751524*lm*NH + 
        0.00021814642974396782*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.002817862511494579 - 0.003910882433903068*lm - 
          0.0011804291283061192*lm^2) + CF*(0.0026425134445912267 + 
          0.005706865134636857*lm + 0.005794833902593676*lm^2) - 
        2.8087011633440215*^-7*NM + 0.00043791237977930717*lm*NM + 
        0.00021462347787383986*lm^2*NM + 0.000926101321150453*NL + 
        0.00043791237977930717*lm*NL + 0.00021462347787383986*lm^2*NL - 
        0.00020740882460001716*NH + 0.00043791237977930717*lm*NH + 
        0.00021462347787383986*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0027522491272146793 - 0.0038362583191811185*lm - 
          0.0011614168737890762*lm^2) + CF*(0.002573596391503619 + 
          0.005557833926804066*lm + 0.005701501016782738*lm^2) - 
        6.3341514296222365*^-6*NM + 0.0004287438888916568*lm*NM + 
        0.0002111667043252866*lm^2*NM + 0.000908788175965049*NL + 
        0.0004287438888916568*lm*NL + 0.0002111667043252866*lm^2*NL - 
        0.0002030467224730029*NH + 0.0004287438888916568*lm*NH + 
        0.0002111667043252866*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.002688224797734681 - 0.003763183780765172*lm - 
          0.0011427608163136825*lm^2) + CF*(0.0025065299453334907 + 
          0.005412338486055283*lm + 0.0056099167346308045*lm^2) - 
        0.000012151390990739735*NM + 0.0004197747133888485*lm*NM + 
        0.000207774693875215*lm^2*NM + 0.0008918507952327265*NL + 
        0.0004197747133888485*lm*NL + 0.000207774693875215*lm^2*NL - 
        0.00019877318205183098*NH + 0.0004197747133888485*lm*NH + 
        0.000207774693875215*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.002625749124904966 - 0.003691623783436629*lm - 
          0.0011244533582689892*lm^2) + CF*(0.0024412656472216597 + 
          0.005270293660126825*lm + 0.005520043758775037*lm^2) - 
        0.000017740235810302518*NM + 0.0004110002413559847*lm*NM + 
        0.0002044460651398162*lm^2*NM + 0.0008752800848595619*NL + 
        0.0004110002413559847*lm*NL + 0.0002044460651398162*lm^2*NL - 
        0.00019458632687605155*NH + 0.0004110002413559847*lm*NH + 
        0.0002044460651398162*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.0025647827864690004 - 0.0036215441470976296*lm - 
          0.0011064870832638*lm^2) + CF*(0.002377756272859512 + 
          0.005131616423323608*lm + 0.005431845681476836*lm^2) - 
        0.0000231080917470201*NM + 0.0004024159744195161*lm*NM + 
        0.00020117946968432727*lm^2*NM + 0.0008590671902256689*NL + 
        0.0004024159744195161*lm*NL + 0.00020117946968432727*lm^2*NL - 
        0.00019048432258340553*NH + 0.0004024159744195161*lm*NH + 
        0.00020117946968432727*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.002505287506408995 - 0.003552911524551473*lm - 
          0.0010888547513698919*lm^2) + CF*(0.002315955802816043 + 
          0.004996225821810038*lm + 0.005345286961270378*lm^2) - 
        0.00002826213120953818*NM + 0.00039401752480806146*lm*NM + 
        0.00019797359115816216*lm^2*NM + 0.0008432034894560998*NL + 
        0.00039401752480806146*lm*NL + 0.00019797359115816216*lm^2*NL - 
        0.0001864653759158623*NH + 0.00039401752480806146*lm*NH + 
        0.00019797359115816216*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.002447226026115924 - 0.0034856933798853174*lm - 
          0.0010715492945005311*lm^2) + CF*(0.002255819393461172 + 
          0.004864042920311107*lm + 0.005260332900275335*lm^2) - 
        0.0000332093006073585*NM + 0.0003858006124914224*lm*NM + 
        0.00019482714445464202*lm^2*NM + 0.0008276805868893545*NL + 
        0.0003858006124914224*lm*NL + 0.00019482714445464202*lm^2*NL - 
        0.00018252773374987272*NH + 0.0003858006124914224*lm*NH + 
        0.00019482714445464202*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.002390562076362076 - 0.00341985796743867*lm - 
          0.0010545638119201833*lm^2) + CF*(0.0021973033484813114 + 
          0.004734990750189722*lm + 0.005176949622153627*lm^2) - 
        0.00003795632755909453*NM + 0.0003777610623957488*lm*NM + 
        0.0001917388748945788*lm^2*NM + 0.000812490306737611*NL + 
        0.0003777610623957488*lm*NL + 0.0001917388748945788*lm^2*NL - 
        0.00017866968215025372*NH + 0.0003777610623957488*lm*NH + 
        0.0001917388748945788*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.0023352603500547517 - 0.003355374311341635*lm - 
          0.001037891565881445*lm^2) + CF*(0.0021403650909825557 + 
          0.004608994258866884*lm + 0.00509510405069073*lm^2) - 
        0.00004250972786605472*NM + 0.0003698948016928555*lm*NM + 
        0.00018870755743299*lm^2*NM + 0.0007976246869329573*NL + 
        0.0003698948016928555*lm*NL + 0.00018870755743299*lm^2*NL - 
        0.00017488954544713157*NH + 0.0003698948016928555*lm*NH + 
        0.00018870755743299*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.002281286475750198 - 0.0032922121856072783*lm - 
          0.0010215259773853503*lm^2) + CF*(0.002084963136176318 + 
          0.004485980260551933*lm + 0.005014763888982629*lm^2) - 
        0.000046875812258885865*NM + 0.00036219785716173816*lm*NM + 
        0.00018573199588824553*lm^2*NM + 0.0007830759731540671*NL + 
        0.00036219785716173816*lm*NL + 0.00018573199588824553*lm^2*NL - 
        0.000171185685335385*NH + 0.00036219785716173816*lm*NH + 
        0.00018573199588824553*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.002228606991907326 - 0.003230342094762889*lm - 
          0.0010054606220613312*lm^2) + CF*(0.002031057064641744 + 
          0.004365877388250705*lm + 0.004935897599210171*lm^2) - 
        0.00005106069292475835*NM + 0.00035466635262038256*lm*NM + 
        0.00018281102219296929*lm^2*NM + 0.0007688366130279279*NL + 
        0.00035466635262038256*lm*NL + 0.00018281102219296929*lm^2*NL - 
        0.00016755649999604066*NH + 0.00035466635262038256*lm*NH + 
        0.00018281102219296929*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.0021771893218612225 - 0.00316973525500531*lm - 
          0.0009896892261632183*lm^2) + CF*(0.0019786074961587827 + 
          0.004248616047020029*lm + 0.004858474382983072*lm^2) - 
        0.00005507028982233121*NM + 0.0003472965064260059*lm*NM + 
        0.0001799434956660397*lm^2*NM + 0.0007548992505013774*NL + 
        0.0003472965064260059*lm*NL + 0.0001799434956660397*lm^2*NL - 
        0.00016400042323908587*NH + 0.0003472965064260059*lm*NH + 
        0.0001799434956660397*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.0021270017494969223 - 0.0031103635758659093*lm - 
          0.0009742056626777982*lm^2) + CF*(0.0019275760641054164 + 
          0.004134128368437646*lm + 0.004782464162236464*lm^2) - 
        0.00005891033679149861*NM + 0.00034008462904191447*lm*NM + 
        0.00017712830230505423*lm^2*NM + 0.00074125672037737*NL + 
        0.00034008462904191447*lm*NL + 0.00017712830230505423*lm^2*NL - 
        0.0001605159236671763*NH + 0.00034008462904191447*lm*NH + 
        0.00017712830230505423*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.0020780133956043575 - 0.0030521996423711313*lm - 
          0.0009590039475425366*lm^2) + CF*(0.0018779253904121775 + 
          0.004022348166257223*lm + 0.0047078375606633615*lm^2) - 
        0.0000625863874646905*NM + 0.0003330271206692055*lm*NM + 
        0.00017436435409864303*lm^2*NM + 0.0007279020430110289*NL + 
        0.0003330271206692055*lm*NL + 0.00017436435409864303*lm^2*NL - 
        0.00015710150385972647*NH + 0.0003330271206692055*lm*NH + 
        0.00017436435409864303*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.0020301941948958624 - 0.0029952166976849664*lm - 
          0.0009440782359691976*lm^2) + CF*(0.0018296190610667831 + 
          0.003913210893218759*lm + 0.00463456588566697*lm^2) - 
        0.00006610382098627785*NM + 0.00032612046894158457*lm*NM + 
        0.00017165058835803593*lm^2*NM + 0.000714828419160697*NL + 
        0.00032612046894158457*lm*NL + 0.00017165058835803593*lm^2*NL - 
        0.0001537556995768845*NH + 0.00032612046894158457*lm*NH + 
        0.00017165058835803593*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.001983514873668045 - 0.0029393886262200106*lm - 
          0.0009294228188701839*lm^2) + CF*(0.0017826216021614401 + 
          0.0038066535989853055*lm + 0.004562621110817266*lm^2) - 
        0.0000694678475464178*NM + 0.00031936124668161225*lm*NM + 
        0.00016898596706730617*lm^2*NM + 0.0007020292249893346*NL + 
        0.00031936124668161225*lm*NL + 0.00016898596706730617*lm^2*NL - 
        0.00015047707898290237*NH + 0.00031936124668161225*lm*NH + 
        0.00016898596706730617*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.0019379469280902866 - 0.002884689937204177*lm - 
          0.0009150321193845263*lm^2) + CF*(0.0017368984564751328 + 
          0.0037026148891775297*lm + 0.004491975858796765*lm^2) - 
        0.00007268351373546585*NM + 0.0003127461097167368*lm*NM + 
        0.00016636947625173207*lm^2*NM + 0.0006894980072117504*NL + 
        0.0003127461097167368*lm*NL + 0.00016636947625173207*lm^2*NL - 
        0.00014726424188842536*NH + 0.0003127461097167368*lm*NH + 
        0.00016636947625173207*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.0018934626031025558 - 0.002831095748690447*lm - 
          0.000900900689500547*lm^2) + CF*(0.001692415960582999 + 
          0.0036010348854782557*lm + 0.004422603384820868*lm^2) - 
        0.00007575570772487942*NM + 0.0003062717947535084*lm*NM + 
        0.00016380012536373583*lm^2*NM + 0.0006772284783832869*NL + 
        0.0003062717947535084*lm*NL + 0.00016380012536373583*lm^2*NL - 
        0.0001441158190112346*NH + 0.0003062717947535084*lm*NH + 
        0.00016380012536373583*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.001850034871905667 - 0.002778581771997406*lm - 
          0.0008870232067723144*lm^2) + CF*(0.0016491413224847258 + 
          0.0035018551867797396*lm + 0.004354477560518634*lm^2) - 
        0.00007868916428034254*NM + 0.0002999351173084143*lm*NM + 
        0.00016127694668587533*lm^2*NM + 0.0006652145123257137*NL + 
        0.0002999351173084143*lm*NL + 0.00016127694668587533*lm^2*NL - 
        0.00014103047125498796*NH + 0.0002999351173084143*lm*NH + 
        0.00016127694668587533*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.0018076374160275208 - 0.002727124296568628*lm - 
          0.0008733944711270973*lm^2) + CF*(0.001607042599743745 + 
          0.0034050188313470213*lm + 0.004287572858260296*lm^2) - 
        0.00008148846961265104*NM + 0.0002937329696938107*lm*NM + 
        0.00015879899475038133*lm^2*NM + 0.0006534501396862029*NL + 
        0.0002937329696938107*lm*NL + 0.00015879899475038133*lm^2*NL - 
        0.00013800688900551556*NH + 0.0002937329696938107*lm*NH + 
        0.00015879899475038133*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.001766244605949289 - 0.002676700175239312*lm - 
          0.0008600094017611164*lm^2) + CF*(0.0015660886781288866 + 
          0.0033104702599713*lm + 0.004221864335918208*lm^2) - 
        0.0000841580660717148*NM + 0.0002876623190574678*lm*NM + 
        0.00015636534577474843*lm^2*NM + 0.0006419295436253926*NL + 
        0.0002876623190574678*lm*NL + 0.00015636534577474843*lm^2*NL - 
        0.00013504379144423505*NH + 0.0002876623190574678*lm*NH + 
        0.00015636534577474843*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.0017258314822759147 - 0.002627286809898882*lm - 
          0.0008468630341209717*lm^2) + CF*(0.0015262492507500454 + 
          0.003218155280087867*lm + 0.004157327622048406*lm^2) - 
        0.0000867022566888556*NM + 0.00028172020547428256*lm*NM + 
        0.00015397509711290394*lm^2*NM + 0.0006306470556306565*NL + 
        0.00028172020547428256*lm*NL + 0.00015397509711290394*lm^2*NL - 
        0.00013213992587826477*NH + 0.00028172020547428256*lm*NH + 
        0.00015397509711290394*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.0016863737374356984 - 0.002578862137538574*lm - 
          0.0008339505169682097*lm^2) + CF*(0.0014874947976793469 + 
          0.0031280210308337114*lm + 0.004093938901480303*lm^2) - 
        0.00008912520957240771*NM + 0.0002759037400887501*lm*NM + 
        0.00015162736672149268*lm^2*NM + 0.000619597151450819*NL + 
        0.0002759037400887501*lm*NL + 0.00015162736672149268*lm^2*NL - 
        0.00012929406708682008*NH + 0.0002759037400887501*lm*NH + 
        0.00015162736672149268*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.001647847697894138 - 0.0025314046166733427*lm - 
          0.000821267109524574*lm^2) + CF*(0.00144979656604923 + 
          0.0030400159490204946*lm + 0.004031674901302454*lm^2) - 
        0.00009143096216146161*NM + 0.0002702101033068221*lm*NM + 
        0.00014932129264083163*lm^2*NM + 0.0006087744471486684*NL + 
        0.0002702101033068221*lm*NL + 0.00014932129264083163*lm^2*NL - 
        0.0001265050166834902*NH + 0.0002702101033068221*lm*NH + 
        0.00014932129264083163*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.0016102303068675757 - 0.0024848932141276927*lm - 
          0.0008088081786955547*lm^2) + CF*(0.0014131265506188335 + 
          0.002954089735999151*lm + 0.003970512877232723*lm^2) - 
        0.00009362342534243033*NM + 0.00026463654303581576*lm*NM + 
        0.00014705603249010087*lm^2*NM + 0.0005981736952677271*NL + 
        0.00026463654303581576*lm*NL + 0.00014705603249010087*lm^2*NL - 
        0.0001237716024940016*NH + 0.00026463654303581576*lm*NH + 
        0.00014705603249010087*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.001573499107522591 - 0.002439307392175363*lm - 
          0.0007965691963699351*lm^2) + CF*(0.001377457474800049 + 
          0.0028701933253929366*lm + 0.0039104306003614996*lm^2) - 
        0.00009570638743296239*NM + 0.0002591803729710727*lm*NM + 
        0.00014483076297635184*lm^2*NM + 0.0005877897811098493*NL + 
        0.0002591803729710727*lm*NL + 0.00014483076297635184*lm^2*NL - 
        0.00012109267794908348*NH + 0.0002591803729710727*lm*NH + 
        0.00014483076297635184*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.0015376322266474418 - 0.002394627096023035*lm - 
          0.0007845457367930956*lm^2) + CF*(0.001342762772134594 + 
          0.0027882788516762937*lm + 0.0038514063442570147*lm^2) - 
        0.00009768351803757451*NM + 0.00025383897092809995*lm*NM + 
        0.00014264467941692646*lm^2*NM + 0.0005776177191203179*NL + 
        0.00025383897092809995*lm*NL + 0.00014264467941692646*lm^2*NL - 
        0.00011846712149206064*NH + 0.00025383897092809995*lm*NH + 
        0.00014264467941692646*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.0015026083587822304 - 0.002350832741628533*lm - 
          0.000772733474011914*lm^2) + CF*(0.0013090165682134744 + 
          0.0027082996195774514*lm + 0.0037934188724221235*lm^2) - 
        0.00009955837177923127*NM + 0.0002486097772189598*lm*NM + 
        0.00014049699527489344*lm^2*NM + 0.0005676526493772133*NL + 
        0.0002486097772189598*lm*NL + 0.00014049699527489344*lm^2*NL - 
        0.00011589383600080761*NH + 0.0002486097772189598*lm*NH + 
        0.00014049699527489344*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.0014684067507948248 - 0.0023079052038442395*lm - 
          0.0007611281793891619*lm^2) + CF*(0.001276193663030216 + 
          0.002630210074283201*lm + 0.0037364474260922495*lm^2) - 
        0.00010133439191095837*NM + 0.00024349029307170855*lm*NM + 
        0.00013838694170712035*lm^2*NM + 0.0005578898341819272*NL + 
        0.00024349029307170855*lm*NL + 0.00013838694170712035*lm^2*NL - 
        0.00011337174822370737*NH + 0.00024349029307170855*lm*NH + 
        0.00013838694170712035*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.0014350071868899112 - 0.0022658258048767073*lm - 
          0.000749725719185365*lm^2) + CF*(0.0012442695137592904 + 
          0.002553965772424828*lm + 0.003680471712364519*lm^2) - 
        0.00010301491381143945*NM + 0.00023847807909171351*lm*NM + 
        0.00013631376712461182*lm^2*NM + 0.0005483246547477845*NL + 
        0.00023847807909171351*lm*NL + 0.00013631376712461182*lm^2*NL - 
        0.00011089980822926597*NH + 0.00023847807909171351*lm*NH + 
        0.00013631376712461182*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.001402389974038905 - 0.0022245763030537095*lm - 
          0.0007385220522061585*lm^2) + CF*(0.001213220217951197 + 
          0.0024795233538246805*lm + 0.0036254718926484143*lm^2) - 
        0.00010460316836841475*NM + 0.0002335707537637122*lm*NM + 
        0.0001342767367647561*lm^2*NM + 0.000538952607983836*NL + 
        0.0002335707537637122*lm*NL + 0.0001342767367647561*lm^2*NL - 
        0.00010847698886904387*NH + 0.0002335707537637122*lm*NH + 
        0.0001342767367647561*lm^2*NH)}, 
     {1., 1.2713267457801266*^-16*CF*NC*
       (-1.*CA*(1.0780359434488018*^13 + 1.717999632384*^13*lm + 
          5.722472448*^12*lm^2) + 2.*(35.*CF*(1.3293452248802095*^11 + 
            2.70453178368*^11*lm + 4.013162496*^11*lm^2) + 
          35.*(-1.1922559933746834*^10 + 2.5706102784*^10*lm + 
            1.48635648*^10*lm^2)*NM + 2.083529293824*^12*NL + 
          8.9971359744*^11*lm*NL + 5.20224768*^11*lm^2*NL - 
          4.172895976811392*^11*NH + 8.9971359744*^11*lm*NH + 
          5.20224768*^11*lm^2*NH))}}
 
CbarTable["a", 2, 4] = {{0., -6.943139134287199*^-12*CF*NC*
       (3.*CF*(-4.076696129615126*^9 - 1.2069497103215195*^10*lm - 
          8.2301184*^9*lm^2) + 12.*CA*(9.284320385597681*^8 + 
          1.240896236581136*^9*lm + 3.143448*^8*lm^2) + 
        560.*(9.*(-746381.0908126297 - 363991.7907277644*lm - 136080.*lm^2)*
           NM + 9.*(-746381.0908126297 - 363991.7907277644*lm - 
            136080.*lm^2)*NL + (1.3743768926234106*^6 - 
            3.2759261165498802*^6*lm - 1.22472*^6*lm^2)*NH))}, 
     {0.005, CF*NC*(CA*(-0.07922522388600359 - 0.1016849012617048*lm - 
          0.025566848075163077*lm^2) + CF*(0.08468892851598488 + 
          0.25037673827747736*lm + 0.16734664194652193*lm^2) + 
        0.02600995991644028*NM + 0.012571868443412723*lm*NM + 
        0.0046485178318478315*lm^2*NM + 0.026014158999330544*NL + 
        0.012571868443412723*lm*NL + 0.0046485178318478315*lm^2*NL - 
        0.0052348784240312165*NH + 0.012571868443412723*lm*NH + 
        0.0046485178318478315*lm^2*NH)}, 
     {0.01, CF*NC*(CA*(-0.08079741851029366 - 0.09988274169302092*lm - 
          0.024926173543827507*lm^2) + CF*(0.08461792096242278 + 
          0.24898512733265712*lm + 0.16315313592323458*lm^2) + 
        0.025833874577541036*NM + 0.012392458330737934*lm*NM + 
        0.004532031553423183*lm^2*NM + 0.025851980937608748*NL + 
        0.012392458330737934*lm*NL + 0.004532031553423183*lm^2*NL - 
        0.005122745097091452*NH + 0.012392458330737934*lm*NH + 
        0.004532031553423183*lm^2*NH)}, 
     {0.015, CF*NC*(CA*(-0.08202289769443821 - 0.09799680767116506*lm - 
          0.02427660970709255*lm^2) + CF*(0.08465426370654461 + 
          0.24718953389360226*lm + 0.15890144535551484*lm^2) + 
        0.025588705262715773*NM + 0.012199873528653224*lm*NM + 
        0.00441392903765319*lm^2*NM + 0.02563056469583124*NL + 
        0.012199873528653224*lm*NL + 0.00441392903765319*lm^2*NL - 
        0.005008606878001314*NH + 0.012199873528653224*lm*NH + 
        0.00441392903765319*lm^2*NH)}, 
     {0.02, CF*NC*(CA*(-0.08290436098055702 - 0.09604262936034506*lm - 
          0.023623794362662594*lm^2) + CF*(0.08474415895474412 + 
          0.24500005397323385*lm + 0.15462847219197334*lm^2) + 
        0.0252800688599907*NM + 0.01199563308903338*lm*NM + 
        0.004295235338665927*lm^2*NM + 0.025354720418361936*NL + 
        0.01199563308903338*lm*NL + 0.004295235338665927*lm^2*NL - 
        0.00489332826884035*NH + 0.01199563308903338*lm*NH + 
        0.004295235338665927*lm^2*NH)}, 
     {0.025, CF*NC*(CA*(-0.08346101942972993 - 0.09403465635844697*lm - 
          0.02297193022626421*lm^2) + CF*(0.08484344732936727 + 
          0.2424430160436432*lm + 0.15036172511736576*lm^2) + 
        0.024915326554042494*NM + 0.011781391682235005*lm*NM + 
        0.004176714586593493*lm^2*NM + 0.025030670150221295*NL + 
        0.011781391682235005*lm*NL + 0.004176714586593493*lm^2*NL - 
        0.0047775738699184665*NH + 0.011781391682235005*lm*NH + 
        0.004176714586593493*lm^2*NH)}, 
     {0.03, CF*NC*(CA*(-0.08371846189520786 - 0.09198593093411023*lm - 
          0.022324247625634824*lm^2) + CF*(0.08491800279670184 + 
          0.23955132822680061*lm + 0.1461223480950643*lm^2) + 
        0.024502121586286715*NM + 0.011558773115972315*lm*NM + 
        0.004058954113751787*lm^2*NM + 0.0246648193636853*NL + 
        0.011558773115972315*lm*NL + 0.004058954113751787*lm^2*NL - 
        0.004661871396863784*NH + 0.011558773115972315*lm*NH + 
        0.004058954113751787*lm^2*NH)}, 
     {0.035, CF*NC*(CA*(-0.08370439258700839 - 0.08990807752040755*lm - 
          0.021683266465825145*lm^2) + CF*(0.08494232354722173 + 
          0.23636015529600304*lm + 0.1419268350490373*lm^2) + 
        0.024047818880087637*NM + 0.011329307805007124*lm*NM + 
        0.003942412084695481*lm^2*NM + 0.024263307071625398*NL + 
        0.011329307805007124*lm*NL + 0.003942412084695481*lm^2*NL - 
        0.004546647294832442*NH + 0.011329307805007124*lm*NH + 
        0.003942412084695481*lm^2*NH)}, 
     {0.04, CF*NC*(CA*(-0.08344658190624125 - 0.0878113851592246*lm - 
          0.021050964702291685*lm^2) + CF*(0.08489797793752205 + 
          0.23290472236448534*lm + 0.1377881325968183*lm^2) + 
        0.023559274143256956*NM + 0.011094408775527058*lm*NM + 
        0.003827448127689397*lm^2*NM + 0.023831830018848796*NL + 
        0.011094408775527058*lm*NL + 0.003827448127689397*lm^2*NL - 
        0.004432249633222552*NH + 0.011094408775527058*lm*NH + 
        0.003827448127689397*lm^2*NH)}, 
     {0.045, CF*NC*(CA*(-0.08297182705129909 - 0.08570491763013771*lm - 
          0.02042889522190717*lm^2) + CF*(0.0847722279874004 + 
          0.22921913762001228*lm + 0.1337164050888469*lm^2) + 
        0.023042746992496598*NM + 0.010855364641732472*lm*NM + 
        0.0037143445858013034*lm^2*NM + 0.02337558247415143*NL + 
        0.010855364641732472*lm*NL + 0.0037143445858013034*lm^2*NL - 
        0.0043189640090339695*NH + 0.010855364641732472*lm*NH + 
        0.0037143445858013034*lm^2*NH)}, 
     {0.05, CF*NC*(CA*(-0.08230542654856893 - 0.08359662812869033*lm - 
          0.019818271120559453*lm^2) + CF*(0.08455687778473274 + 
          0.2253357580663092*lm + 0.12971959278911643*lm^2) + 
        0.022503883039357794*NM + 0.010613340722772913*lm*NM + 
        0.0036033220219199007*lm^2*NM + 0.02289924937404713*NL + 
        0.010613340722772913*lm*NL + 0.0036033220219199007*lm^2*NL - 
        0.004207025184689695*NH + 0.010613340722772913*lm*NH + 
        0.0036033220219199007*lm^2*NH)}, 
     {0.055, CF*NC*(CA*(-0.0814709346119259 - 0.08149346960900226*lm - 
          0.019220030183621995*lm^2) + CF*(0.08424732853820037 + 
          0.22128486462407088*lm + 0.12580383392916214*lm^2) + 
        0.021947730301883663*NM + 0.010369384183939123*lm*NM + 
        0.0034945509424767263*lm^2*NM + 0.022407024934387697*NL + 
        0.010369384183939123*lm*NL + 0.0034945509424767263*lm^2*NL - 
        0.004096625929151563*NH + 0.010369384183939123*lm*NH + 
        0.0034945509424767263*lm^2*NH)}, 
     {0.06, CF*NC*(CA*(-0.0804900741803238 - 0.07940149743486759*lm - 
          0.018634884945675344*lm^2) + CF*(0.08384180868435069 + 
          0.21709452107572794*lm + 0.12197379237169316*lm^2) + 
        0.021378772553843555*NM + 0.010124431116431219*lm*NM + 
        0.003388160899213699*lm^2*NM + 0.0219026431453163*NL + 
        0.010124431116431219*lm*NL + 0.003388160899213699*lm^2*NL - 
        0.003987923925701231*NH + 0.010124431116431219*lm*NH + 
        0.003388160899213699*lm^2*NH)}, 
     {0.065, CF*NC*(CA*(-0.07938274170990149 - 0.07732596331193022*lm - 
          0.01806336234534743*lm^2) + CF*(0.0833407482688941 + 
          0.21279054491273575*lm + 0.11823291716954681*lm^2) + 
        0.020800970392067367*NM + 0.009879314439609392*lm*NM + 
        0.0032842476991540785*lm^2*NM + 0.02138941316810913*NL + 
        0.009879314439609392*lm*NL + 0.0032842476991540785*lm^2*NL - 
        0.0038810472878328113*NH + 0.009879314439609392*lm*NH + 
        0.0032842476991540785*lm^2*NH)}, 
     {0.07, CF*NC*(CA*(-0.07816706496300153 - 0.0752714004938829*lm - 
          0.017505835635687455*lm^2) + CF*(0.0827462711209793 + 
          0.20839654683495376*lm + 0.11458365143359062*lm^2) + 
        0.020217804972677302*NM + 0.009634772008811363*lm*NM + 
        0.0031828792064886283*lm^2*NM + 0.020870255938328856*NL + 
        0.009634772008811363*lm*NL + 0.0031828792064886283*lm^2*NL - 
        0.0037760990403563543*NH + 0.009634772008811363*lm*NH + 
        0.0031828792064886283*lm^2*NH)}, 
     {0.075, CF*NC*(CA*(-0.07685949057228576 - 0.07324170070016359*lm - 
          0.016962550385178188*lm^2) + CF*(0.08206178297458504 + 
          0.20393401196408614*lm + 0.11102760252116631*lm^2) + 
        0.019632321616908942*NM + 0.009391454583624873*lm*NM + 
        0.0030841000700323976*lm^2*NM + 0.020347740006738686*NL + 
        0.009391454583624873*lm*NL + 0.0030841000700323976*lm^2*NL - 
        0.003673160810934091*NH + 0.009391454583624873*lm*NH + 
        0.0030841000700323976*lm^2*NH)}, 
     {0.08, CF*NC*(CA*(-0.07547488713911024 - 0.07124018336078014*lm - 
          0.016433645877614034*lm^2) + CF*(0.08129163778450284 + 
          0.19942240555558924*lm + 0.10756568210801913*lm^2) + 
        0.019047171751177382*NM + 0.009149933465817935*lm*NM + 
        0.0029879356141116423*lm^2*NM + 0.01982411559373887*NL + 
        0.009149933465817935*lm*NL + 0.0029879356141116423*lm^2*NL - 
        0.0035722959061168613*NH + 0.009149933465817935*lm*NH + 
        0.0029879356141116423*lm^2*NH)}, 
     {0.085, CF*NC*(CA*(-0.07402665501298598 - 0.0692696578554101*lm - 
          0.015919172869302996*lm^2) + CF*(0.08044086787224276 + 
          0.19487929201078028*lm + 0.10419822241725597*lm^2) + 
        0.01846465237667375*NM + 0.008910707706434201*lm*NM + 
        0.002894395067145999*lm^2*NM + 0.019301346363481152*NL + 
        0.008910707706434201*lm*NL + 0.002894395067145999*lm^2*NL - 
        0.0034735518989072473*NH + 0.008910707706434201*lm*NH + 
        0.002894395067145999*lm^2*NH)}, 
     {0.09, CF*NC*(CA*(-0.07252683722685356 - 0.06733247940508298*lm - 
          0.015419108422101226*lm^2) + CF*(0.07951496627369818 + 
          0.19032045982972567*lm + 0.10092507330829895*lm^2) + 
        0.01788674269371758*NM + 0.008674210835479266*lm*NM + 
        0.0028034742585638594*lm^2*NM + 0.018781138726192224*NL + 
        0.008674210835479266*lm*NL + 0.0028034742585638594*lm^2*NL - 
        0.003376962822747696*NH + 0.008674210835479266*lm*NH + 
        0.0028034742585638594*lm^2*NH)}, 
     {0.095, CF*NC*(CA*(-0.07098622816579105 - 0.06543059923813747*lm - 
          0.014933368361508544*lm^2) + CF*(0.07851971185248172 + 
          0.18576004765488094*lm + 0.09774568382078319*lm^2) + 
        0.017315137760872915*NM + 0.008440817100138722*lm*NM + 
        0.0027151578839106445*lm^2*NM + 0.018264968649924367*NL + 
        0.008440817100138722*lm*NL + 0.0027151578839106445*lm^2*NL - 
        0.0032825510442704075*NH + 0.008440817100138722*lm*NH + 
        0.0027151578839106445*lm^2*NH)}, 
     {0.1, CF*NC*(CA*(-0.0694144778984514 - 0.06356560960411747*lm - 
          0.014461817786717476*lm^2) + CF*(0.07746102949680808 + 
          0.1812106682277785*lm + 0.0946591709676053*lm^2) + 
        0.016751279218964098*NM + 0.008210847217045415*lm*NM + 
        0.002629421415766814*lm^2*NM + 0.017754106060063165*NL + 
        0.008210847217045415*lm*NL + 0.002629421415766814*lm^2*NL - 
        0.003190328870917354*NH + 0.008210847217045415*lm*NH + 
        0.002629421415766814*lm^2*NH)}, 
     {0.105, CF*NC*(CA*(-0.06782019097962505 - 0.061738784158104604*lm - 
          0.014004279969230019*lm^2) + CF*(0.07634487912433177 + 
          0.17668352821224675*lm + 0.09166437798041467*lm^2) + 
        0.01619638319653725*NM + 0.007984573655701328*lm*NM + 
        0.0025462327216781854*lm^2*NM + 0.017249636957230037*NL + 
        0.007984573655701328*lm*NL + 0.0025462327216781854*lm^2*NL - 
        0.0031002999376184984*NH + 0.007984573655701328*lm*NH + 
        0.0025462327216781854*lm^2*NH)}, 
     {0.11, CF*NC*(CA*(-0.06621101910776696 - 0.059951114187808074*lm - 
          0.013560543908804032*lm^2) + CF*(0.07517716835150762 + 
          0.17218854261110805*lm + 0.08875992376671729*lm^2) + 
        0.015651465560437217*NM + 0.007762225476737726*lm*NM + 
        0.0024655534379643693*lm^2*NM + 0.01675248340969828*NL + 
        0.007762225476737726*lm*NL + 0.0024655534379643693*lm^2*NL - 
        0.003012460407797307*NH + 0.007762225476737726*lm*NH + 
        0.0024655534379643693*lm^2*NH)}, 
     {0.115, CF*NC*(CA*(-0.0645937473982345 - 0.0582033411085043*lm - 
          0.013130370763666232*lm^2) + CF*(0.07396368459932771 + 
          0.16773444303579554*lm + 0.0859442449985426*lm^2) + 
        0.015117364697924213*NM + 0.007543992752102811*lm*NM + 
        0.002387340138848406*lm^2*NM + 0.01626342158583025*NL + 
        0.007543992752102811*lm*NL + 0.002387340138848406*lm^2*NL - 
        0.0029268000171891995*NH + 0.007543992752102811*lm*NH + 
        0.002387340138848406*lm^2*NH)}, 
     {0.12, CF*NC*(CA*(-0.06297437427825658 - 0.05649598560745811*lm - 
          0.012713499331776805*lm^2) + CF*(0.07271004315055885 + 
          0.1633288794559124*lm + 0.08321563198981183*lm^2) + 
        0.01459476202441507*NM + 0.007330030595655602*lm*NM + 
        0.0023115453330503286*lm^2*NM + 0.015783097991862057*NL + 
        0.007330030595655602*lm*NL + 0.0023115453330503286*lm^2*NL - 
        0.0028433029837233097*NH + 0.007330030595655602*lm*NH + 
        0.0023115453330503286*lm^2*NH)}, 
     {0.125, CF*NC*(CA*(-0.061358185166719696 - 0.054829373779983245*lm - 
          0.012309650728426129*lm^2) + CF*(0.07142164827980686 + 
          0.15897851530900323*lm + 0.08057225931333466*lm^2) + 
        0.01408420040935129*NM + 0.00712046283275785*lm*NM + 
        0.002238118314259296*lm^2*NM + 0.01531204407462388*NL + 
        0.00712046283275785*lm*NL + 0.002238118314259296*lm^2*NL - 
        0.0027619488026241193*NH + 0.00712046283275785*lm*NH + 
        0.002238118314259296*lm^2*NH)}, 
     {0.13, CF*NC*(CA*(-0.059749820199364825 - 0.053203660563722624*lm - 
          0.011918532380443485*lm^2) + CF*(0.07010366507415436 + 
          0.15468911602394106*lm + 0.078012211944721*lm^2) + 
        0.013586100705599366*NM + 0.006915385336772563*lm*NM + 
        0.002167005887353361*lm^2*NM + 0.014850689339977284*NL + 
        0.006915385336772563*lm*NL + 0.002167005887353361*lm^2*NL - 
        0.002682712942650191*NH + 0.006915385336772563*lm*NH + 
        0.002167005887353361*lm^2*NH)}, 
     {0.135, CF*NC*(CA*(-0.05815333631712761 - 0.05161885074581191*lm - 
          0.011539841437256834*lm^2) + CF*(0.06876099997015438 + 
          0.15046563112787897*lm + 0.07553350758931746*lm^2) + 
        0.013100776557572863*NM + 0.006714869059212154*lm*NM + 
        0.0020981529885921515*lm^2*NM + 0.014399373127423844*NL + 
        0.006714869059212154*lm*NL + 0.0020981529885921515*lm^2*NL - 
        0.002605567456796301*NH + 0.006714869059212154*lm*NH + 
        0.0020981529885921515*lm^2*NH)}, 
     {0.14, CF*NC*(CA*(-0.05657226406511887 - 0.05007481778903162*lm - 
          0.011173267682830808*lm^2) + CF*(0.06739828836948424 + 
          0.14631227018306203*lm + 0.07313411574216529*lm^2) + 
        0.012628447651479323*NM + 0.0065189627788382895*lm*NM + 
        0.002031503215060147*lm^2*NM + 0.013958355170450295*NL + 
        0.0065189627788382895*lm*NL + 0.002031503215060147*lm^2*NL - 
        0.002530481518692734*NH + 0.0065189627788382895*lm*NH + 
        0.002031503215060147*lm^2*NH)}, 
     {0.145, CF*NC*(CA*(-0.0550096594610376 - 0.048571320697535975*lm - 
          0.010818496019288372*lm^2) + CF*(0.06601988797395812 + 
          0.14223257284749458*lm + 0.07081197394443298*lm^2) + 
        0.012169251558759846*NM + 0.006327695593435679*lm*NM + 
        0.001966999276234249*lm^2*NM + 0.013527825061310669*NL + 
        0.006327695593435679*lm*NL + 0.001966999276234249*lm^2*NL - 
        0.002457421894230254*NH + 0.006327695593435679*lm*NH + 
        0.001966999276234249*lm^2*NH)}, 
     {0.15, CF*NC*(CA*(-0.05346815129079011 - 0.04710801911996139*lm - 
          0.01047520858215827*lm^2) + CF*(0.06462987671157212 + 
          0.13822947338073077*lm + 0.06856500162867231*lm^2) + 
        0.01172325431163227*NM + 0.00614107917635305*lm*NM + 
        0.0019045833785742306*lm^2*NM + 0.013107910728454259*NL + 
        0.00614107917635305*lm*NL + 0.0019045833785742306*lm^2*NL - 
        0.0023863533565383847*NH + 0.00614107917635305*lm*NH + 
        0.0019045833785742306*lm^2*NH)}, 
     {0.155, CF*NC*(CA*(-0.05194998418007771 - 0.04568448686737309*lm - 
          0.01014308653820541*lm^2) + CF*(0.06323205431749192 + 
          0.13430535992880877*lm + 0.06639111188643541*lm^2) + 
        0.01129045983831846*NM + 0.005959109818284765*lm*NM + 
        0.0018441975524009838*lm^2*NM + 0.01269868602488707*NL + 
        0.005959109818284765*lm*NL + 0.0018441975524009838*lm^2*NL - 
        0.002317239051285056*NH + 0.005959109818284765*lm*NH + 
        0.0018441975524009838*lm^2*NH)}, 
     {0.16, CF*NC*(CA*(-0.050457057776834915 - 0.04430022400533961*lm - 
          0.009821811609324639*lm^2) + CF*(0.06182994679461039 + 
          0.1304621289248434*lm + 0.06428822144285219*lm^2) + 
        0.010870818375885232*NM + 0.005781770273193236*lm*NM + 
        0.0017857839289681164*lm^2*NM + 0.012300177516504427*NL + 
        0.005781770273193236*lm*NL + 0.0017857839289681164*lm^2*NL - 
        0.0022500408182992947*NH + 0.005781770273193236*lm*NH + 
        0.0017857839289681164*lm^2*NH)}, 
     {0.165, CF*NC*(CA*(-0.04899096236310352 - 0.04295466766319125*lm - 
          0.009511067359722625*lm^2) + CF*(0.06042681311386286 + 
          0.1267012349371282*lm + 0.06225425908182082*lm^2) + 
        0.010464233972186415*NM + 0.00560903142576838*lm*NM + 
        0.0017292849744950226*lm^2*NM + 0.011912370550892622*NL + 
        0.00560903142576838*lm*NL + 0.0017292849744950226*lm^2*NL - 
        0.0021847194747081212*NH + 0.00560903142576838*lm*NH + 
        0.0017292849744950226*lm^2*NH)}, 
     {0.17, CF*NC*(CA*(-0.04755301119851543 - 0.041647201689006756*lm - 
          0.009210540278352294*lm^2) + CF*(0.05902565363117664 + 
          0.12302373628703385*lm + 0.0602871727310332*lm^2) + 
        0.010070571188227182*NM + 0.0054408537963990455*lm*NM + 
        0.0016746436869731444*lm^2*NM + 0.011535214679269016*NL + 
        0.0054408537963990455*lm*NL + 0.0016746436869731444*lm^2*NL - 
        0.0021212350640950712*NH + 0.0054408537963990455*lm*NH + 
        0.0016746436869731444*lm^2*NH)}, 
     {0.175, CF*NC*(CA*(-0.046144269883875405 - 0.04037716526588971*lm - 
          0.008919920684120758*lm^2) + CF*(0.05762921980317512 + 
          0.11943033674617654*lm + 0.05838493538697224*lm^2) + 
        0.009689661124540016*NM + 0.005277188898299111*lm*NM + 
        0.0016218037607492288*lm^2*NM + 0.01116862849709024*NL + 
        0.005277188898299111*lm*NL + 0.0016218037607492288*lm^2*NL - 
        0.002059547075607824*NH + 0.005277188898299111*lm*NH + 
        0.0016218037607492288*lm^2*NH)}, 
     {0.18, CF*NC*(CA*(-0.04476558302681748 - 0.03914386059347491*lm - 
          0.008638903477622641*lm^2) + CF*(0.05624002488812384 + 
          0.1159214236074681*lm + 0.0565455500353482*lm^2) + 
        0.00932130693179463*NM + 0.005117980460190199*lm*NM + 
        0.0015707097232041166*lm^2*NM + 0.01081250396237133*NL + 
        0.005117980460190199*lm*NL + 0.0015707097232041166*lm^2*NL - 
        0.001999614636448084*NH + 0.005117980460190199*lm*NH + 
        0.0015707097232041166*lm^2*NH)}, 
     {0.185, CF*NC*(CA*(-0.043417598499845514 - 0.03794655972819423*lm - 
          0.008367188759941687*lm^2) + CF*(0.05486035543908249 + 
          0.11249710240863153*lm + 0.054767053701436495*lm^2) + 
        0.008965289048836372*NM + 0.00496316552679261*lm*NM + 
        0.001521307047262125*lm^2*NM + 0.01046671024488148*NL + 
        0.00496316552679261*lm*NL + 0.001521307047262125*lm^2*NL - 
        0.0019413966807535715*NH + 0.00496316552679261*lm*NH + 
        0.001521307047262125*lm^2*NH)}, 
     {0.19, CF*NC*(CA*(-0.042100789617698905 - 0.036784510666498564*lm - 
          0.008104482336321762*lm^2) + CF*(0.05349228356118093 + 
          0.10915722857020332*lm + 0.05304752074683335*lm^2) + 
        0.008621370578765586*NM + 0.0048126754483137114*lm*NM + 
        0.001473542242967593*lm^2*NM + 0.010131097154068706*NL + 
        0.0048126754483137114*lm*NL + 0.001473542242967593*lm^2*NL - 
        0.0018848520975179005*NH + 0.0048126754483137114*lm*NH + 
        0.001473542242967593*lm^2*NH)}, 
     {0.195, CF*NC*(CA*(-0.04081547564839017 - 0.03565694274686047*lm - 
          0.007850496120158472*lm^2) + CF*(0.05213768016068795 + 
          0.10590143619340575*lm + 0.051385065513764545*lm^2) + 
        0.008289303526848493*NM + 0.004666436769144571*lm*NM + 
        0.001427362930937904*lm^2*NM + 0.009805498188769367*NL + 
        0.004666436769144571*lm*NL + 0.001427362930937904*lm^2*NL - 
        0.0018299398598798243*NH + 0.004666436769144571*lm*NH + 
        0.001427362930937904*lm^2*NH)}, 
     {0.2, NC*(CA*CF*(-0.0395618095843119 - 0.0345630714388666*lm - 
          0.00760494845074275*lm^2) + CF^2*(0.050798166509061875 + 
          0.10272916424688297*lm + 0.04977784440486164*lm^2) + 
        CF*((0.007968722057790032 + 0.004524372025076596*lm + 
            0.0013827179001350454*lm^2)*NM + (0.009489733247434172 + 
            0.004524372025076596*lm + 0.0013827179001350454*lm^2)*NL + 
          (-0.0017766191378409276 + 0.004524372025076596*lm + 
            0.0013827179001350454*lm^2)*NH))}, 
     {0.205, NC*(CA*CF*(-0.038339883983261026 - 0.033502102580958516*lm - 
          0.007367564336446951*lm^2) + CF^2*(0.049475305275056516 + 
          0.0996396803553792*lm + 0.048224057474925495*lm^2) + 
        CF*((0.007659476409386245 + 0.004386400457525394*lm + 
            0.001339557152081264*lm^2)*NM + (0.009183611033706749 + 
            0.004386400457525394*lm + 0.001339557152081264*lm^2)*NL + 
          (-0.001724849396233993 + 0.004386400457525394*lm + 
            0.001339557152081264*lm^2)*NH))}, 
     {0.21, NC*(CA*CF*(-0.03714963584370667 - 0.03247323612231261*lm - 
          0.007138075633540096*lm^2) + CF^2*(0.048170392542480886 + 
          0.09663210238814292*lm + 0.046721949601353355*lm^2) + 
        CF*((0.007361228656811227 + 0.004252438652493839*lm + 
            0.0012978319333709265*lm^2)*NM + (0.00888693118868381 + 
            0.004252438652493839*lm + 0.0012978319333709265*lm^2)*NL + 
          (-0.0016745904795576621 + 0.004252438652493839*lm + 
            0.0012978319333709265*lm^2)*NH))}, 
     {0.215, NC*(CA*CF*(-0.03599092187608328 - 0.031475669418893515*lm - 
          0.006916221169516714*lm^2) + CF^2*(0.04688459317508014 + 
          0.09370541803027536*lm + 0.045269811291382134*lm^2) + 
        CF*((0.0070736860811518145 + 0.004122401111315614*lm + 
            0.0012574947580939481*lm^2)*NM + (0.00859948617803024 + 
            0.004122401111315614*lm + 0.0012574947580939481*lm^2)*NL + 
          (-0.0016258026851121634 + 0.004122401111315614*lm + 
            0.0012574947580939481*lm^2)*NH))}, 
     {0.22, NC*(CA*CF*(-0.034863516785433646 - 0.030508600128805213*lm - 
          0.0067017468186940125*lm^2) + CF^2*(0.04561892444030153 + 
          0.09085850250644624*lm + 0.04386597917690626*lm^2) + 
        CF*((0.0067965525285453325 + 0.0039962007595891105*lm + 
            0.0012184994215807296*lm^2)*NM + (0.008321062959283407 + 
            0.0039962007595891105*lm + 0.0012184994215807296*lm^2)*NL + 
          (-0.0015784468257128896 + 0.0039962007595891105*lm + 
            0.0012184994215807296*lm^2)*NH))}, 
     {0.225, NC*(CA*CF*(-0.03376712393242027 - 0.029571228747643435*lm - 
          0.006494405536850107*lm^2) + CF^2*(0.044374266345165045 + 
          0.08809013461341438*lm + 0.0425088362412007*lm^2) + 
        CF*((0.006529530067731647 + 0.0038737494001351448*lm + 
            0.0011808010067000194*lm^2)*NM + (0.00805144445212777 + 
            0.0038737494001351448*lm + 0.0011808010067000194*lm^2)*NL + 
          (-0.0015324842831158979 + 0.0038737494001351448*lm + 
            0.0011808010067000194*lm^2)*NH))}, 
     {0.23, NC*(CA*CF*(-0.03270138492810745 - 0.02866276082057156*lm - 
          0.0062939573608210885*lm^2) + CF^2*(0.043151371547807474 + 
          0.08539901120561354*lm + 0.041196811816283485*lm^2) + 
        CF*((0.006272320430523031 + 0.003754958115285817*lm + 
            0.0011443558837856524*lm^2)*NM + (0.0077904108321245474 + 
            0.003754958115285817*lm + 0.0011443558837856524*lm^2)*NL + 
          (-0.001487877053177389 + 0.003754958115285817*lm + 
            0.0011443558837856524*lm^2)*NH))}, 
     {0.235, NC*(CA*CF*(-0.03166588826110382 - 0.027782408864254003*lm - 
          0.006100169378229116*lm^2) + CF^2*(0.04195087482424778 + 
          0.08278376026668559*lm + 0.0399283813847724*lm^2) + 
        CF*((0.006024626258398041 + 0.0036397376233320068*lm + 
            0.0011091217051325665*lm^2)*NM + (0.0075377406663163235 + 
            0.0036397376233320068*lm + 0.0011091217051325665*lm^2)*NL + 
          (-0.0014445877836383669 + 0.0036397376233320068*lm + 
            0.0011091217051325665*lm^2)*NH))}, 
     {0.24, NC*(CA*CF*(-0.030660177047040035 - 0.026929394028546338*lm - 
          0.005912815671862748*lm^2) + CF^2*(0.04077330207880083 + 
          0.08024295268924297*lm + 0.0387020662158289*lm^2) + 
        CF*((0.005786152177244308 + 0.003527998593519525*lm + 
            0.001075057394884136*lm^2)*NM + (0.007293211907269571 + 
            0.003527998593519525*lm + 0.001075057394884136*lm^2)*NL + 
          (-0.0014025798053577021 + 0.003527998593519525*lm + 
            0.001075057394884136*lm^2)*NH))}, 
     {0.245, NC*(CA*CF*(-0.02968375598204032 - 0.026102947524924126*lm - 
          0.005731677242661462*lm^2) + CF^2*(0.03961907889295614 + 
          0.07777511287529036*lm + 0.037516432861056846*lm^2) + 
        CF*((0.00555660571848061 + 0.003419651923585205*lm + 
            0.0010421231350293569*lm^2)*NM + (0.007056602760448045 + 
            0.003419651923585205*lm + 0.0010421231350293569*lm^2)*NL + 
          (-0.0013618171577089591 + 0.003419651923585205*lm + 
            0.0010421231350293569*lm^2)*NH))}, 
     {0.25, NC*(CA*CF*(-0.02873609757464783 - 0.025302311846000177*lm - 
          0.005556541914758138*lm^2) + CF^2*(0.03848853861344519 + 
          0.07537872826059834*lm + 0.036370092532962355*lm^2) + 
        CF*((0.0053356981041038296 + 0.003314608983460959*lm + 
            0.0010102803481378433*lm^2)*NM + (0.006827692438308162 + 
            0.003314608983460959*lm + 0.0010102803481378433*lm^2)*NL + 
          (-0.0013222646087915312 + 0.003314608983460959*lm + 
            0.0010102803481378433*lm^2)*NH))}, 
     {0.255, NC*(CA*CF*(-0.027816647723779085 - 0.024526741798104424*lm - 
          0.005387204225596672*lm^2) + CF^2*(0.03738192998435811 + 
          0.0730522578578615*lm + 0.035261700385723675*lm^2) + 
        CF*((0.005123144910799005 + 0.003212781828442897*lm + 
            0.000979491677381213*lm^2)*NM + (0.006606261813156505 + 
            0.003212781828442897*lm + 0.000979491677381213*lm^2)*NL + 
          (-0.0012838876710360657 + 0.003212781828442897*lm + 
            0.000979491677381213*lm^2)*NH))}, 
     {0.26, NC*(CA*CF*(-0.026924830704058794 - 0.023775505366755826*lm - 
          0.005223465303759113*lm^2) + CF^2*(0.03629942433151471 + 
          0.07079413990565254*lm + 0.03418995471551419*lm^2) + 
        CF*((0.004918666626817936 + 0.003114083384821265*lm + 
            0.0009497209643198388*lm^2)*NM + (0.0063920939795944045 + 
            0.003114083384821265*lm + 0.0009497209643198388*lm^2)*NL + 
          (-0.0012466526127251163 + 0.003114083384821265*lm + 
            0.0009497209643198388*lm^2)*NH))}, 
     {0.265, NC*(CA*CF*(-0.026060053614064646 - 0.02304788443291888*lm - 
          0.005065132736800637*lm^2) + CF^2*(0.03524112230958034 + 
          0.06860279870296282*lm + 0.03315359609542235*lm^2) + 
        CF*((0.004721989113833739 + 0.0030184276106925414*lm + 
            0.0009209332248728431*lm^2)*NM + (0.0061849747362812185 + 
            0.0030184276106925414*lm + 0.0009209332248728431*lm^2)*NL + 
          (-0.0012105264658948884 + 0.0030184276106925414*lm + 
            0.0009209332248728431*lm^2)*NH))}, 
     {0.27, NC*(CA*CF*(-0.02522171033761187 - 0.022343175356187614*lm - 
          0.0049120204310956475*lm^2) + CF^2*(0.03420706022390086 + 
          0.06647665070245985*lm + 0.0321514064580806*lm^2) + 
        CF*((0.004532843984942027 + 0.0029257296344252014*lm + 
            0.0008930946238355723*lm^2)*NM + (0.005984692995764246 + 
            0.0029257296344252014*lm + 0.0008930946238355723*lm^2)*NL + 
          (-0.0011754770310371601 + 0.0029257296344252014*lm + 
            0.0008930946238355723*lm^2)*NH))}, 
     {0.275, NC*(CA*CF*(-0.0244091850628887 - 0.02166068943945925*lm - 
          0.004763948465438929*lm^2) + CF^2*(0.03319721593922716 + 
          0.06441410992945645*lm + 0.031182208137418448*lm^2) + 
        CF*((0.004350968908360254 + 0.002835905873023252*lm + 
            0.0008661724482616235*lm^2)*NM + (0.005791041130237949 + 
            0.002835905873023252*lm + 0.0008661724482616235*lm^2)*NL + 
          (-0.0011414728789773032 + 0.002835905873023252*lm + 
            0.0008661724482616235*lm^2)*NH))}, 
     {0.28, NC*(CA*CF*(-0.023621855399235673 - 0.02099975328823091*lm - 
          0.0046207429399178195*lm^2) + CF^2*(0.032211514387016284 + 
          0.06241359278793691*lm + 0.030244862879462094*lm^2) + 
        CF*((0.00417610784589594 + 0.0027488741324246373*lm + 
            0.0008401350799850582*lm^2)*NM + (0.005603815260298485 + 
            0.0027488741324246373*lm + 0.0008401350799850582*lm^2)*NL + 
          (-0.0011084833502655505 + 0.0027488741324246373*lm + 
            0.0008401350799850582*lm^2)*NH))}, 
     {0.285, NC*(CA*CF*(-0.022859095126093593 - 0.02035970907636152*lm - 
          0.0044822358213708795*lm^2) + CF^2*(0.031249832680883452 + 
          0.060473522309789626*lm + 0.029338270830791213*lm^2) + 
        CF*((0.004008011233792455 + 0.002664553691583213*lm + 
            0.0008149519675219781*lm^2)*NM + (0.005422815493042423 + 
            0.002664553691583213*lm + 0.0008149519675219781*lm^2)*NL + 
          (-0.0010764785523831501 + 0.002664553691583213*lm + 
            0.0008149519675219781*lm^2)*NH))}, 
     {0.29, NC*(CA*CF*(-0.022120276603577748 - 0.019739914728973608*lm - 
          0.004348264786572154*lm^2) + CF^2*(0.030312004847070924 + 
          0.058592331898618316*lm + 0.028461369512108644*lm^2) + 
        CF*((0.0038464361133831097 + 0.0025828653720115628*lm + 
            0.0007905935975585734*lm^2)*NM + (0.005247846115213035 + 
            0.0025828653720115628*lm + 0.0007905935975585734*lm^2)*NL + 
          (-0.0010454293550395243 + 0.0025828653720115628*lm + 
            0.0007905935975585734*lm^2)*NH))}, 
     {0.295, NC*(CA*CF*(-0.021404772868620723 - 0.019139744032114162*lm - 
          0.004218673064124952*lm^2) + CF^2*(0.029397826172315657 + 
          0.05676846861511477*lm + 0.02761313278336332*lm^2) + 
        CF*((0.0036911462169879035 + 0.0025037315943058918*lm + 
            0.0007670314662045366*lm^2)*NM + (0.005078715746516336 + 
            0.0025037315943058918*lm + 0.0007670314662045366*lm^2)*NL + 
          (-0.0010153073837970146 + 0.0025037315943058918*lm + 
            0.0007670314662045366*lm^2)*NH))}, 
     {0.3, NC*(CA*CF*(-0.02071169874226899 - 0.01855858667783916*lm - 
          0.004093309275912543*lm^2) + CF^2*(0.028506535780551928 + 
          0.05500039604694603*lm + 0.02679256980597301*lm^2) + 
        CF*((0.0035419120160866953 + 0.002427076423032317*lm + 
            0.0007442380501659169*lm^2)*NM + (0.004915237457705888 + 
            0.002427076423032317*lm + 0.0007442380501659169*lm^2)*NL + 
          (-0.000986085012250547 + 0.002427076423032317*lm + 
            0.0007442380501659169*lm^2)*NH))}, 
     {0.305, NC*(CA*CF*(-0.020040987121475506 - 0.017995848252523337*lm - 
          0.003972027278833064*lm^2) + CF^2*(0.02763896975048252 + 
          0.0532865968024092*lm + 0.025998724006907323*lm^2) + 
        CF*((0.003398510734858753 + 0.0023528256012246914*lm + 
            0.0007221867779696479*lm^2)*NM + (0.004757228857564175 + 
            0.0023528256012246914*lm + 0.0007221867779696479*lm^2)*NL + 
          (-0.0009577353529524944 + 0.0023528256012246914*lm + 
            0.0007221867779696479*lm^2)*NH))}, 
     {0.31, NC*(CA*CF*(-0.019391731551630334 - 0.017450950175415897*lm - 
          0.003854686007440258*lm^2) + CF^2*(0.026794246936328002 + 
          0.05162557466371309*lm + 0.02523067204869987*lm^2) + 
        CF*((0.0032607263369234855 + 0.0022809065756266324*lm + 
            0.0007008520013527742*lm^2)*NM + (0.004604512152484168 + 
            0.0022809065756266324*lm + 0.0007008520013527742*lm^2)*NL + 
          (-0.0009302322472622134 + 0.0022809065756266324*lm + 
            0.0007008520013527742*lm^2)*NH))}, 
     {0.315, NC*(CA*CF*(-0.01876332552502058 - 0.016923329593757034*lm - 
          0.0037411493180188092*lm^2) + CF^2*(0.02597204835590463 + 
          0.05001585643263315*lm + 0.024487522808850387*lm^2) + 
        CF*((0.0031283494802930517 + 0.002211248513703538*lm + 
            0.0006802089669125107*lm^2)*NM + (0.004456914181972659 + 
            0.002211248513703538*lm + 0.0006802089669125107*lm^2)*NL + 
          (-0.0009035502542789633 + 0.002211248513703538*lm + 
            0.0006802089669125107*lm^2)*NH))}, 
     {0.32, NC*(CA*CF*(-0.018155170646235272 - 0.016412439240131322*lm - 
          0.003631285834541332*lm^2) + CF^2*(0.02517203440529873 + 
          0.04845599349843213*lm + 0.023768416371543265*lm^2) + 
        CF*((0.003001177454073601 + 0.002143782313353155*lm + 
            0.0006602337880984241*lm^2)*NM + (0.004314266433052886 + 
            0.002143782313353155*lm + 0.0006602337880984241*lm^2)*NL + 
          (-0.00087766463899622 + 0.002143782313353155*lm + 
            0.0006602337880984241*lm^2)*NH))}, 
     {0.325, NC*(CA*CF*(-0.017566677460909192 - 0.015917747257156643*lm - 
          0.003524968796882398*lm^2) + CF^2*(0.024393847473214558 + 
          0.046944563155323554*lm + 0.02307252303413933*lm^2) + 
        CF*((0.0028790139158532163 + 0.002078440606154868*lm + 
            0.0006409034176149815*lm^2)*NM + (0.004176405036234213 + 
            0.002078440606154868*lm + 0.0006409034176149815*lm^2)*NL + 
          (-0.0008525513598094856 + 0.002078440606154868*lm + 
            0.0006409034176149815*lm^2)*NH))}, 
     {0.33, NC*(CA*CF*(-0.016996921610309544 - 0.015438736994084915*lm - 
          0.003422075911601995*lm^2) + CF^2*(0.02363642526297536 + 
          0.04548016969435812*lm + 0.022399042330485786*lm^2) + 
        CF*((0.0027609696025940496 + 0.0020151577549174567*lm + 
            0.0006221956202912718*lm^2)*NM + (0.004043170745437623 + 
            0.0020151577549174567*lm + 0.0006221956202912718*lm^2)*NL + 
          (-0.0008281870554857114 + 0.0020151577549174567*lm + 
            0.0006221956202912718*lm^2)*NH))}, 
     {0.335, NC*(CA*CF*(-0.01644636903603676 - 0.014974906779418462*lm - 
          0.003322489205555614*lm^2) + CF^2*(0.022901452256050284 + 
          0.04406144529241852*lm + 0.021747202072727654*lm^2) + 
        CF*((0.002648961171758364 + 0.001953869846211975*lm + 
            0.0006040889464646571*lm^2)*NM + (0.003914408904014541 + 
            0.001953869846211975*lm + 0.0006040889464646571*lm^2)*NL + 
          (-0.0008045490316947006 + 0.001953869846211975*lm + 
            0.0006040889464646571*lm^2)*NH))}, 
     {0.34, NC*(CA*CF*(-0.015913419225739717 - 0.014525769673218917*lm - 
          0.0032260948825397874*lm^2) + CF^2*(0.022186447286307812 + 
          0.04268705071899751*lm + 0.0211162574129877*lm^2) + 
        CF*((0.0025406971025670414 + 0.0018945146785099348*lm + 
            0.0005865627059163251*lm^2)*NM + (0.0037899693987703533 + 
            0.0018945146785099348*lm + 0.0005865627059163251*lm^2)*NL + 
          (-0.0007816152472155777 + 0.0018945146785099348*lm + 
            0.0005865627059163251*lm^2)*NH))}, 
     {0.345, NC*(CA*CF*(-0.015397892184066914 - 0.01409085320239917*lm - 
          0.003132783183139585*lm^2) + CF^2*(0.02149173858265566 + 
          0.04135567587959388*lm + 0.020505489926004556*lm^2) + 
        CF*((0.0024367485790229566 + 0.0018370317464865569*lm + 
            0.0005695969423890155*lm^2)*NM + (0.0036697066037002764 + 
            0.0018370317464865569*lm + 0.0005695969423890155*lm^2)*NL + 
          (-0.0007593642998484596 + 0.0018370317464865569*lm + 
            0.0005695969423890155*lm^2)*NH))}, 
     {0.35, NC*(CA*CF*(-0.014899231532191812 - 0.01366969908193999*lm - 
          0.003042448247907595*lm^2) + CF^2*(0.020816871077552826 + 
          0.04006604021287642*lm + 0.01991420671357699*lm^2) + 
        CF*((0.0023369086448009257 + 0.001781362221993943*lm + 
            0.0005531724087104719*lm^2)*NM + (0.003553479314961921 + 
            0.001781362221993943*lm + 0.0005531724087104719*lm^2)*NL + 
          (-0.0007377754121678137 + 0.001781362221993943*lm + 
            0.0005531724087104719*lm^2)*NH))}, 
     {0.355, NC*(CA*CF*(-0.014416921610978286 - 0.01326186292465729*lm - 
          0.0029549879839716915*lm^2) + CF^2*(0.020161441723729634 + 
          0.038816892957224784*lm + 0.01934173953145107*lm^2) + 
        CF*((0.0022410320156014043 + 0.0017274489321591157*lm + 
            0.0005372705425403076*lm^2)*NM + (0.0034411506784438497 + 
            0.0017274489321591157*lm + 0.0005372705425403076*lm^2)*NL + 
          (-0.0007168284171201976 + 0.0017274489321591157*lm + 
            0.0005372705425403076*lm^2)*NH))}, 
     {0.36, NC*(CA*CF*(-0.01395045188647609 - 0.012866913941861085*lm - 
          0.002870303935140801*lm^2) + CF^2*(0.01952502940991957 + 
          0.037607013300845496*lm + 0.018787443939103424*lm^2) + 
        CF*((0.0021489651894762893 + 0.0016752363350165409*lm + 
            0.000521873442752873*lm^2)*NM + (0.0033325881111409034 + 
            0.0016752363350165409*lm + 0.000521873442752873*lm^2)*NL + 
          (-0.0006965037435825483 + 0.0016752363350165409*lm + 
            0.000521873442752873*lm^2)*NH))}, 
     {0.365, NC*(CA*CF*(-0.013499324204339715 - 0.012484434636989564*lm - 
          0.002788301155553543*lm^2) + CF^2*(0.01890721056327988 + 
          0.03643521042837209*lm + 0.0182506984727141*lm^2) + 
        CF*((0.002060560171747839 + 0.0016246704930435638*lm + 
            0.0005069638464642805*lm^2)*NM + (0.003227663217413448 + 
            0.0016246704930435638*lm + 0.0005069638464642805*lm^2)*NL + 
          (-0.0006767824018629639 + 0.0016246704930435638*lm + 
            0.0005069638464642805*lm^2)*NH))}, 
     {0.37, NC*(CA*CF*(-0.013063052879918281 - 0.012114020494069212*lm - 
          0.0027088880868934967*lm^2) + CF^2*(0.018307560407416542 + 
          0.03530032347567847*lm + 0.017730903841484708*lm^2) + 
        CF*((0.0019756743421117788 + 0.0015756990449297913*lm + 
            0.0004925251067079085*lm^2)*NM + (0.0031262517010874585 + 
            0.0015756990449297913*lm + 0.0004925251067079085*lm^2)*NL + 
          (-0.0006576459692615753 + 0.0015756990449297913*lm + 
            0.0004925251067079085*lm^2)*NH))}, 
     {0.375, NC*(CA*CF*(-0.01264116473014063 - 0.011755279662641971*lm - 
          0.0026319764391766424*lm^2) + CF^2*(0.01772565408449291 + 
          0.03420122140355652*lm + 0.017227482147338023*lm^2) + 
        CF*((0.0018941703074799349 + 0.0015282711758774989*lm + 
            0.00047854117075938956*lm^2)*NM + (0.0030282332742442705 + 
            0.0015282711758774989*lm + 0.00047854117075938956*lm^2)*NL + 
          (-0.0006390765756753469 + 0.0015282711758774989*lm + 
            0.00047854117075938956*lm^2)*NH))}, 
     {0.38, NC*(CA*CF*(-0.012233199059298032 - 0.011407832640611017*lm - 
          0.002557481075100867*lm^2) + CF^2*(0.01716106766256254 + 
          0.03313680279992332*lm + 0.016739876127932946*lm^2) + 
        CF*((0.0018159157466239961 + 0.0014823375866993233*lm + 
            0.0004649965591092485*lm^2)*NM + (0.0029334915634515965 + 
            0.0014823375866993233*lm + 0.0004649965591092485*lm^2)*NL + 
          (-0.0006210568892980137 + 0.0014823375866993233*lm + 
            0.0004649965591092485*lm^2)*NH))}, 
     {0.385, NC*(CA*CF*(-0.011838707607290489 - 0.011071311956285825*lm - 
          0.0024853198979340034*lm^2) + CF^2*(0.01661337904280593 + 
          0.032105995619322786*lm + 0.016267548422840748*lm^2) + 
        CF*((0.0017407832574743614 + 0.0014378504619515376*lm + 
            0.00045187634507890966*lm^2)*NM + (0.0028419140141000936 + 
            0.0014378504619515376*lm + 0.00045187634507890966*lm^2)*NL + 
          (-0.000603570102463391 + 0.0014378504619515376*lm + 
            0.00045187634507890966*lm^2)*NH))}, 
     {0.39, NC*(CA*CF*(-0.01145725446429353 - 0.010745361850753192*lm - 
          0.002415413742905462*lm^2) + CF^2*(0.016082168772662577 + 
          0.031107756867663598*lm + 0.015809980862653932*lm^2) + 
        CF*((0.0016686502046066912 + 0.0013947634373158455*lm + 
            0.0004391661350737204*lm^2)*NM + (0.0027533917934312513 + 
            0.0013947634373158455*lm + 0.0004391661350737204*lm^2)*NL + 
          (-0.0005865999176193906 + 0.0013947634373158455*lm + 
            0.0004391661350737204*lm^2)*NH))}, 
     {0.395, NC*(CA*CF*(-0.011088415956328061 - 0.010429637961562077*lm - 
          0.0023476862720568344*lm^2) + CF^2*(0.015567020772359195 + 
          0.03014107223938418*lm + 0.015366673780735642*lm^2) + 
        CF*((0.0015993985684541801 + 0.0013530315664196228*lm + 
            0.00042685204946487894*lm^2)*NM + (0.0026678196927719332 + 
            0.0013530315664196228*lm + 0.00042685204946487894*lm^2)*NL + 
          (-0.0005701305335018099 + 0.0013530315664196228*lm + 
            0.00042685204946487894*lm^2)*NH))}, 
     {0.4, NC*(CA*CF*(-0.01073178050553355 - 0.010123807008585131*lm - 
          0.0022820638724987247*lm^2) + CF^2*(0.015067522981364795 + 
          0.02920495571354901*lm + 0.01493714534726438*lm^2) + 
        CF*((0.0015329147957618082 + 0.0013126112872637074*lm + 
            0.0004149207040906772*lm^2)*NM + (0.0025850960294276372 + 
            0.0013126112872637074*lm + 0.0004149207040906772*lm^2)*NL + 
          (-0.0005541466315059344 + 0.0013126112872637074*lm + 
            0.0004149207040906772*lm^2)*NH))}, 
     {0.405, NC*(CA*CF*(-0.010386948468720474 - 0.009827546482807323*lm - 
          0.0022184755580143124*lm^2) + CF^2*(0.014583267931193565 + 
          0.02829844911475435*lm + 0.014520930925184592*lm^2) + 
        CF*((0.0014690896524944019 + 0.001273460388407937*lm + 
            0.00040335919236623866*lm^2)*NM + (0.00250512254862982 + 
            0.001273460388407937*lm + 0.00040335919236623866*lm^2)*NL + 
          (-0.0005386333622039807 + 0.001273460388407937*lm + 
            0.00040335919236623866*lm^2)*NH))}, 
     {0.41, NC*(CA*CF*(-0.010053531957298462 - 0.009540544338690945*lm - 
          0.002156852873944564*lm^2) + CF^2*(0.014113853250307526 + 
          0.02742062164415008*lm + 0.014117582447637148*lm^2) + 
        CF*((0.0014078180789965334 + 0.0012355379750475454*lm + 
            0.0003921550679899208*lm^2)*NM + (0.002427804325881765 + 
            0.0012355379750475454*lm + 0.0003921550679899208*lm^2)*NL + 
          (-0.0005235763322260196 + 0.0012355379750475454*lm + 
            0.0003921550679899208*lm^2)*NH))}, 
     {0.415, NC*(CA*CF*(-0.009731154641401438 - 0.009262498690675377*lm - 
          0.0020971298052855085*lm^2) + CF^2*(0.013658882106567558 + 
          0.0265705693853626*lm + 0.013726667816414238*lm^2) + 
        CF*((0.0013489990476165076 + 0.0011988044350980502*lm + 
            0.0003812963282337288*lm^2)*NM + (0.0023530496700019114 + 
            0.0011988044350980502*lm + 0.0003812963282337288*lm^2)*NL + 
          (-0.0005089615912109911 + 0.0011988044350980502*lm + 
            0.0003812963282337288*lm^2)*NH))}, 
     {0.42, NC*(CA*CF*(-0.009419451540858895 - 0.008993117514288487*lm - 
          0.0020392426879243873*lm^2) + CF^2*(0.013217963592546844 + 
          0.025747414789628605*lm + 0.013347770320959625*lm^2) + 
        CF*((0.0012925354244025086 + 0.0011632214053922635*lm + 
            0.000370771397804434*lm^2)*NM + (0.002280770027122777 + 
            0.0011632214053922635*lm + 0.000370771397804434*lm^2)*NL + 
          (-0.0004947756191365501 + 0.0011632214053922635*lm + 
            0.000370771397804434*lm^2)*NH))}, 
     {0.425, NC*(CA*CF*(-0.009118068804928213 - 0.008732118352273327*lm - 
          0.0019831301229387126*lm^2) + CF^2*(0.012790713057728527 + 
          0.02495030614401575*lm + 0.012980488077417028*lm^2) + 
        CF*((0.0012383338309508718 + 0.0011287517380804072*lm + 
            0.00036056911326158407*lm^2)*NM + (0.0022108798858671342 + 
            0.0011287517380804072*lm + 0.00036056911326158407*lm^2)*NL + 
          (-0.0004810053138529294 + 0.0011287517380804072*lm + 
            0.00036056911326158407*lm^2)*NH))}, 
     {0.43, NC*(CA*CF*(-0.008826663483469043 - 0.008479228026068326*lm - 
          0.0019287328938801694*lm^2) + CF^2*(0.012376752393289692 + 
          0.024178417026211423*lm + 0.012624433487215654*lm^2) + 
        CF*((0.001186304513647969 + 0.0010953594673128798*lm + 
            0.0003506787079782126*lm^2)*NM + (0.0021432966838904875 + 
            0.0010953594673128798*lm + 0.0003506787079782126*lm^2)*NL + 
          (-0.0004676379788947201 + 0.0010953594673128798*lm + 
            0.0003506787079782126*lm^2)*NH))}, 
     {0.435, NC*(CA*CF*(-0.008544903290598349 - 0.00823418235292052*lm - 
          0.001875993886963845*lm^2) + CF^2*(0.011975710272011494 + 
          0.023430945749000804*lm + 0.01227923271467244*lm^2) + 
        CF*((0.0011363612124595669 + 0.0010630097762749074*lm + 
            0.00034108979762979*lm^2)*NM + (0.002077940715949812 + 
            0.0010630097762749074*lm + 0.00034108979762979*lm^2)*NL + 
          (-0.00045466131140834895 + 0.0010630097762749074*lm + 
            0.00034108979762979*lm^2)*NH))}, 
     {0.44, NC*(CA*CF*(-0.008272466363062645 - 0.00799672586885902*lm - 
          0.0018248580140823303*lm^2) + CF^2*(0.011587222348351852 + 
          0.02270711479722782*lm + 0.011944525183084344*lm^2) + 
        CF*((0.001088421035266837 + 0.0010316689646330019*lm + 
            0.00033179236619678733*lm^2)*NM + (0.0020147350436325677 + 
            0.0010316689646330019*lm + 0.00033179236619678733*lm^2)*NL + 
          (-0.0004420633907964889 + 0.0010316689646330019*lm + 
            0.00033179236619678733*lm^2)*NH))}, 
     {0.445, NC*(CA*CF*(-0.008009041014400252 - 0.007766611557709166*lm - 
          0.001775272138563767*lm^2) + CF^2*(0.01121093142147161 + 
          0.022006170259734354*lm + 0.011619963088781021*lm^2) + 
        CF*((0.0010424043344619497 + 0.0010013044164447617*lm + 
            0.00032277675246613946*lm^2)*NM + (0.0019536054068568904 + 
            0.0010013044164447617*lm + 0.00032277675246613946*lm^2)*NL + 
          (-0.0004298326669875158 + 0.0010013044164447617*lm + 
            0.00032277675246613946*lm^2)*NH))}, 
     {0.45, NC*(CA*CF*(-0.007754325486532539 - 0.007543600586286227*lm - 
          0.0017271850035928628*lm^2) + CF^2*(0.010846487565202397 + 
          0.02132738125850179*lm + 0.011305210932607829*lm^2) + 
        CF*((0.000998234589102908 + 0.0009718845685760069*lm + 
            0.00031403363701688414*lm^2)*NM + (0.0018944801372333224 + 
            0.0009718845685760069*lm + 0.00031403363701688414*lm^2)*NL + 
          (-0.0004179579495073005 + 0.0009718845685760069*lm + 
            0.00031403363701688414*lm^2)*NH))}, 
     {0.455, NC*(CA*CF*(-0.007508027699203124 - 0.007327462045870519*lm - 
          0.0016805471632141543*lm^2) + CF^2*(0.010493548226555434 + 
          0.02067003937697221*lm + 0.010999945068310828*lm^2) + 
        CF*((0.0009558382861056982 + 0.0009433788796624388*lm + 
            0.0003055540296753008*lm^2)*NM + (0.0018372900733601954 + 
            0.0009433788796624388*lm + 0.0003055540296753008*lm^2)*NL + 
          (-0.0004064283965789176 + 0.0009433788796624388*lm + 
            0.0003055540296753008*lm^2)*NH))}, 
     {0.46, NC*(CA*CF*(-0.007269864999396847 - 0.007117972700032967*lm - 
          0.0016353109158373995*lm^2) + CF^2*(0.010151778297834597 + 
          0.020033458089302642*lm + 0.010703853267299342*lm^2) + 
        CF*((0.0009151448107622711 + 0.0009157577996469264*lm + 
            0.0002973292574249817*lm^2)*NM + (0.0017819684781086144 + 
            0.0009157577996469264*lm + 0.0002973292574249817*lm^2)*NL + 
          (-0.0003952335045500897 + 0.0009157577996469264*lm + 
            0.0002973292574249817*lm^2)*NH))}, 
     {0.465, NC*(CA*CF*(-0.007039563910510563 - 0.006914916738851129*lm - 
          0.0015914302401657853*lm^2) + CF^2*(0.009820850162725426 + 
          0.019416972192101867*lm + 0.010416634299266958*lm^2) + 
        CF*((0.000876086336321601 + 0.00088899273991804*lm + 
            0.0002893509527574155*lm^2)*NM + (0.0017284509579386792 + 
            0.00088899273991804*lm + 0.0002893509527574155*lm^2)*NL + 
          (-0.00038436309754093624 + 0.00088899273991804*lm + 
            0.0002893509527574155*lm^2)*NH))}, 
     {0.47, NC*(CA*CF*(-0.006816859882693288 - 0.0067180855395300495*lm - 
          0.0015488607334687007*lm^2) + CF^2*(0.009500443720041399 + 
          0.018819937240014895*lm + 0.01013799752815877*lm^2) + 
        CF*((0.000838597718678037 + 0.0008630560440705576*lm + 
            0.0002816110424488547*lm^2)*NM + (0.001676675384275963 + 
            0.0008630560440705576*lm + 0.0002816110424488547*lm^2)*NL + 
          (-0.00037380731769339463 + 0.0008630560440705576*lm + 
            0.0002816110424488547*lm^2)*NH))}, 
     {0.475, NC*(CA*CF*(-0.006601497044879388 - 0.006527277433419743*lm - 
          0.001507559552122035*lm^2) + CF^2*(0.009190246387031845 + 
          0.01824172898635238*lm + 0.009867662522980594*lm^2) + 
        CF*((0.0008026163944763782 + 0.0008379209593042759*lm + 
            0.00027410173674946093*lm^2)*NM + (0.0016265818169661397 + 
            0.0008379209593042759*lm + 0.00027410173674946093*lm^2)*NL + 
          (-0.00036355661482172154 + 0.0008379209593042759*lm + 
            0.00027410173674946093*lm^2)*NH))}, 
     {0.48, NC*(CA*CF*(-0.00639322795907201 - 0.006342297479401321*lm - 
          0.001467485354340339*lm^2) + CF^2*(0.008889953084227194 + 
          0.01768174282981058*lm + 0.009605358682954946*lm^2) + 
        CF*((0.0007680822824025543 + 0.0008135616084735502*lm + 
            0.0002668155189709707*lm^2)*NM + (0.0015781124298158969 + 
            0.0008135616084735502*lm + 0.0002668155189709707*lm^2)*NL + 
          (-0.00035360173752226184 + 0.0008135616084735502*lm + 
            0.0002668155189709707*lm^2)*NH))}, 
     {0.485, NC*(CA*CF*(-0.006191813377408922 - 0.006162957243596474*lm - 
          0.0014285982450266835*lm^2) + CF^2*(0.008599266203745515 + 
          0.017139393268189872*lm + 0.009350824876538292*lm^2) + 
        CF*((0.0007349376876104911 + 0.00078995296279649*lm + 
            0.000259745135459397*lm^2)*NM + (0.001531211438219716 + 
            0.00078995296279649*lm + 0.000259745135459397*lm^2)*NL + 
          (-0.00034393372351612385 + 0.00078995296279649*lm + 
            0.000259745135459397*lm^2)*NH))}, 
     {0.49, NC*(CA*CF*(-0.005997022002486105 - 0.0059890745853400104*lm - 
          0.0013908597226676503*lm^2) + CF^2*(0.008317895562864564 + 
          0.016614113359895502*lm + 0.009103809093824619*lm^2) + 
        CF*((0.0007031272097292483 + 0.0007670708152296366*lm + 
            0.00025288358593957277*lm^2)*NM + (0.0014858250288646581 + 
            0.0007670708152296366*lm + 0.00025288358593957277*lm^2)*NL + 
          (-0.00033454389093144437 + 0.0007670708152296366*lm + 
            0.00025288358593957277*lm^2)*NH))}, 
     {0.495, NC*(CA*CF*(-0.005808630251294417 - 0.00582047344934208*lm - 
          0.0013542326282025554*lm^2) + CF^2*(0.008045558344413095 + 
          0.016105354193891783*lm + 0.008864068111871272*lm^2) + 
        CF*((0.000672597654022933 + 0.0007448917545111917*lm + 
            0.00024622411421864644*lm^2)*NM + (0.0014419012914988069 + 
            0.0007448917545111917*lm + 0.00024622411421864644*lm^2)*NL + 
          (-0.0003254238294578642 + 0.0007448917545111917*lm + 
            0.00024622411421864644*lm^2)*NH))}, 
     {0.5, CF*NC*(CA*(-0.005626685730176795 - 0.005657065627728395*lm - 
          0.0013186845097176228*lm^2) + CF*(0.007782493147299008 + 
          0.015613065417898843*lm + 0.008631389518151714*lm^2) + 
        0.0006433340233347765*NM + 0.0007234072523795971*lm*NM + 
        0.00023976081994865872*lm^2*NM + 0.001399425007378916*NL + 
        0.0007234072523795971*lm*NL + 0.00023976081994865872*lm^2*NL - 
        0.00031656774912160196*NH + 0.0007234072523795971*lm*NH + 
        0.00023976081994865872*lm^2*NH)}, 
     {0.505, CF*NC*(CA*(-0.005450410932914475 - 0.005498509860892496*lm - 
          0.0012841733547842838*lm^2) + CF*(0.007527324348028939 + 
          0.015135695600625942*lm + 0.008405498322224404*lm^2) + 
        0.0006152093908997675*NM + 0.0007025649835179749*lm*NM + 
        0.00023348606450623342*lm^2*NM + 0.0013582726751013364*NL + 
        0.0007025649835179749*lm*NL + 0.00023348606450623342*lm^2*NL - 
        0.00030796267520697204*NH + 0.0007025649835179749*lm*NH + 
        0.00023348606450623342*lm^2*NH)}, 
     {0.51, CF*NC*(CA*(-0.005279915153025512 - 0.005344743898056366*lm - 
          0.0012506698117155507*lm^2) + CF*(0.0072803955151912 + 
          0.014673313944128802*lm + 0.008186202403956332*lm^2) + 
        0.0005882193568282989*NM + 0.0006823604217289639*lm*NM + 
        0.00022739451122100922*lm^2*NM + 0.0013184388772910563*NL + 
        0.0006823604217289639*lm*NL + 0.00022739451122100922*lm^2*NL - 
        0.00029960374172624516*NH + 0.0006823604217289639*lm*NH + 
        0.00022739451122100922*lm^2*NH)}, 
     {0.515, CF*NC*(CA*(-0.005115002511772989 - 0.005195613793618075*lm - 
          0.0012181416034463023*lm^2) + CF*(0.007041450878988733 + 
          0.01422543697333497*lm + 0.007973290495284887*lm^2) + 
        0.0005623185935757284*NM + 0.0006627730459760428*lm*NM + 
        0.0002214802915356913*lm^2*NM + 0.0012798785554332102*NL + 
        0.0006627730459760428*lm*NL + 0.0002214802915356913*lm^2*NL - 
        0.0002914835344220926*NH + 0.0006627730459760428*lm*NH + 
        0.0002214802915356913*lm^2*NH)}, 
     {0.52, CF*NC*(CA*(-0.0049554838463878636 - 0.005050970774879632*lm - 
          0.0011865575689441713*lm^2) + CF*(0.006810241797020371 + 
          0.013791596948176624*lm + 0.007766558633089122*lm^2) + 
        0.0005374635971319595*NM + 0.0006437830174951661*lm*NM + 
        0.00021573773980803116*lm^2*NM + 0.0012425482592329582*NL + 
        0.0006437830174951661*lm*NL + 0.00021573773980803116*lm^2*NL - 
        0.00028359487161445164*NH + 0.0006437830174951661*lm*NH + 
        0.00021573773980803116*lm^2*NH)}, 
     {0.525, CF*NC*(CA*(-0.004801176485695504 - 0.004910671064512634*lm - 
          0.00115588762226076*lm^2) + CF*(0.00658652661676535 + 
          0.013371341366542253*lm + 0.007565809891161339*lm^2) + 
        0.0005136126133590725*NM + 0.0006253711569915427*lm*NM + 
        0.00021016138586559273*lm^2*NM + 0.0012064060880966042*NL + 
        0.0006253711569915427*lm*NL + 0.00021016138586559273*lm^2*NL - 
        0.00027593079675688315*NH + 0.0006253711569915427*lm*NH + 
        0.00021016138586559273*lm^2*NH)}, 
     {0.53, CF*NC*(CA*(-0.0046519040325354 - 0.004774575709048544*lm - 
          0.0011261027131475923*lm^2) + CF*(0.00637007053597021 + 
          0.012964232481251468*lm + 0.0073708541224206045*lm^2) + 
        0.0004907255672759464*NM + 0.0006075189225697139*lm*NM + 
        0.0002047459478450168*lm^2*NM + 0.0011714116347173093*NL + 
        0.0006075189225697139*lm*NL + 0.0002047459478450168*lm^2*NL - 
        0.0002684845712282483*NH + 0.0006075189225697139*lm*NH + 
        0.0002047459478450168*lm^2*NH)}, 
     {0.535, CF*NC*(CA*(-0.00450749615282198 - 0.004642550413201152*lm - 
          0.0010971747891758445*lm^2) + CF*(0.00616064546141718 + 
          0.012569846830783285*lm + 0.007181507710969164*lm^2) + 
        0.00046876399517568114*NM + 0.000590208388376047*lm*NM + 
        0.000199486325304699*lm^2*NM + 0.0011375259306938106*NL + 
        0.000590208388376047*lm*NL + 0.000199486325304699*lm^2*NL - 
        0.0002612496673527416*NH + 0.000590208388376047*lm*NH + 
        0.000199486325304699*lm^2*NH)}, 
     {0.54, CF*NC*(CA*(-0.00436778837109406 - 0.00451446537983407*lm - 
          0.0010690767593012575*lm^2) + CF*(0.00595802986651465 + 
          0.012187774783484403*lm + 0.006997593333608231*lm^2) + 
        0.00044769097946577996*NM + 0.0005734222239331763*lm*NM + 
        0.00019437759260022865*lm^2*NM + 0.0011047113941126763*NL + 
        0.0005734222239331763*lm*NL + 0.00019437759260022865*lm^2*NL - 
        0.00025421976164149236*NH + 0.0005734222239331763*lm*NH + 
        0.00019437759260022865*lm^2*NH)}, 
     {0.545, CF*NC*(CA*(-0.00423262187240048 - 0.004390195155391295*lm - 
          0.0010417824588179114*lm^2) + CF*(0.005762008648114148 + 
          0.011817620094981073*lm + 0.006818939730444512*lm^2) + 
        0.00042747108612507367*NM + 0.0005571436741463386*lm*NM + 
        0.00018941499251234754*lm^2*NM + 0.0010729317790267472*NL + 
        0.0005571436741463386*lm*NL + 0.00018941499251234754*lm^2*NL - 
        0.0002473887282491139*NH + 0.0005571436741463386*lm*NH + 
        0.00018941499251234754*lm^2*NH)}, 
     {0.55, CF*NC*(CA*(-0.0041018433103696995 - 0.004269618480613939*lm - 
          0.0010152666156467264*lm^2) + CF*(0.005572372982924347 + 
          0.011458999478515886*lm + 0.006645381484233118*lm^2) + 
        0.0004080703046752505*NM + 0.0005413565399619696*lm*NM + 
        0.00018459393011758661*lm^2*NM + 0.0010421521267644368*NL + 
        0.0005413565399619696*lm*NL + 0.00018459393011758661*lm^2*NL - 
        0.0002407506326387499*NH + 0.0005413565399619696*lm*NH + 
        0.00018459393011758661*lm^2*NH)}, 
     {0.555, CF*NC*(CA*(-0.003975304621311701 - 0.004152618146371271*lm - 
          0.0009895048179066651*lm^2) + CF*(0.005388920183860851 + 
          0.011111542187929337*lm + 0.006476758808116353*lm^2) + 
        0.00038945599056861626*NM + 0.0005260451596593499*lm*NM + 
        0.0001799099668921209*lm^2*NM + 0.0010123387190065802*NL + 
        0.0005260451596593499*lm*NL + 0.0001799099668921209*lm^2*NL - 
        0.0002342997254493302*NH + 0.0005260451596593499*lm*NH + 
        0.0001799099668921209*lm^2*NH)}, 
     {0.56, CF*NC*(CA*(-0.003852862844201324 - 0.004039080854439069*lm - 
          0.0009644734827186362*lm^2) + CF*(0.005211453556640742 + 
          0.010774889613005148*lm + 0.006312917341431073*lm^2) + 
        0.0003715968098973391*NM + 0.00051119439075651*lm*NM + 
        0.00017535881503975205*lm^2*NM + 0.0009834590325694644*NL + 
        0.00051119439075651*lm*NL + 0.00017535881503975205*lm^2*NL - 
        0.00022803043655891328*NH + 0.00051119439075651*lm*NH + 
        0.00017535881503975205*lm^2*NH)}, 
     {0.565, CF*NC*(CA*(-0.0037343799463932055 - 0.003928897083063094*lm - 
          0.0009401498261940484*lm^2) + CF*(0.005039782256903028 + 
          0.010448694886898063*lm + 0.006153707953270135*lm^2) + 
        0.00035446268633294777*NM + 0.0004967895925120225*lm*NM + 
        0.00017093633203528152*lm^2*NM + 0.0009554816958345857*NL + 
        0.0004967895925120225*lm*NL + 0.00017093633203528152*lm^2*NL - 
        0.00022193736933814976*NH + 0.0004967895925120225*lm*NH + 
        0.00017093633203528152*lm^2*NH)}, 
     {0.57, CF*NC*(CA*(-0.003619722654919694 - 0.0038219609571502*lm - 
          0.0009165118345618398*lm^2) + CF*(0.004873721148110084 + 
          0.010132622505363165*lm + 0.005998986553495679*lm^2) + 
        0.0003380247502082431*NM + 0.00048281660900473456*lm*NM + 
        0.00016663851537487997*lm^2*NM + 0.0009283764467675379*NL + 
        0.00048281660900473456*lm*NL + 0.00016663851537487997*lm^2*NL - 
        0.00021601529508806115*NH + 0.00048281660900473456*lm*NH + 
        0.00016663851537487997*lm^2*NH)}, 
     {0.575, CF*NC*(CA*(-0.0035087622932245956 - 0.0037181701229341948*lm - 
          0.0008935382363896146*lm^2) + CF*(0.004713090660460862 + 
          0.009826347957506523*lm + 0.005848613910913842*lm^2) + 
        0.0003222552896570641*NM + 0.00046926175277390967*lm*NM + 
        0.00016246149752538447*lm^2*NM + 0.0009021140924702507*NL + 
        0.00046926175277390967*lm*NL + 0.00016246149752538447*lm^2*NL - 
        0.00021025914765648106*NH + 0.00046926175277390967*lm*NH + 
        0.00016246149752538447*lm^2*NH)}, 
     {0.58, CF*NC*(CA*(-0.0034013746231871538 - 0.0036174256269680695*lm - 
          0.000871208475856251*lm^2) + CF*(0.00455771665102392 + 
          0.009529557367778328*lm + 0.005702455478331825*lm^2) + 
        0.000307127703730516*NM + 0.00045611178900266527*lm*NM + 
        0.00015840154106477292*lm^2*NM + 0.0008766664702125724*NL + 
        0.00045611178900266527*lm*NL + 0.00015840154106477292*lm^2*NL - 
        0.00020466401822765863*NH + 0.00045611178900266527*lm*NH + 
        0.00015840154106477292*lm^2*NH)}, 
     {0.585, CF*NC*(CA*(-0.0032974396922924773 - 0.0035196317992986135*lm - 
          0.0008495026870350179*lm^2) + CF*(0.004407430265277187 + 
          0.009241947148931336*lm + 0.005560381224229208*lm^2) + 
        0.0002926164574113289*NM + 0.0004433539202280082*lm*NM + 
        0.00015445503400636688*lm^2*NM + 0.0008520064098909109*NL + 
        0.0004433539202280082*lm*NL + 0.00015445503400636688*lm^2*NL - 
        0.00019922515027967307*NH + 0.0004433539202280082*lm*NH + 
        0.00015445503400636688*lm^2*NH)}, 
     {0.59, CF*NC*(CA*(-0.0031968416858064903 - 0.0034246961406837395*lm - 
          0.0008284016691478388*lm^2) + CF*(0.004262067800221582 + 
          0.008963223665669574*lm + 0.005422265470785855*lm^2) + 
        0.0002786970384509704*NM + 0.00043097577156118*lm*NM + 
        0.00015061848529960707*lm^2*NM + 0.0008281076978633344*NL + 
        0.00043097577156118*lm*NL + 0.00015061848529960707*lm^2*NL - 
        0.0001939379347044541*NH + 0.00043097577156118*lm*NH + 
        0.00015061848529960707*lm^2*NH)}, 
     {0.595, CF*NC*(CA*(-0.003099468783815546 - 0.0033325292137170643*lm - 
          0.0008078868627528911*lm^2) + CF*(0.004121470569217322 + 
          0.008693102908714742*lm + 0.005287986738018924*lm^2) + 
        0.0002653459159569876*NM + 0.00041896537640243357*lm*NM + 
        0.00014688852050052568*lm^2*NM + 0.0008049450421121693*NL + 
        0.00041896537640243357*lm*NL + 0.00014688852050052568*lm^2*NL - 
        0.0001887979050853471*NH + 0.00041896537640243357*lm*NH + 
        0.00014688852050052568*lm^2*NH)}, 
     {0.6, CF*NC*(CA*(-0.0030052130229929557 - 0.0032430445377283758*lm - 
          0.0007879403268292067*lm^2) + CF*(0.003985484768674619 + 
          0.008431310179020516*lm + 0.005157427593791172*lm^2) + 
        0.00025254050066081163*NM + 0.0004073111626347643*lm*NM + 
        0.0001432618776053103*lm^2*NM + 0.0007824940386867267*NL + 
        0.0004073111626347643*lm*NL + 0.0001432618776053103*lm^2*NL - 
        0.00018380073312730238*NH + 0.0004073111626347643*lm*NH + 
        0.0001432618776053103*lm^2*NH)}, 
     {0.605, CF*NC*(CA*(-0.0029139701629569484 - 0.0031561584873326604*lm - 
          0.0007685447167233735*lm^2) + CF*(0.0038539613467146335 + 
          0.008177579781868083*lm + 0.005030474509462081*lm^2) + 
        0.0002402591067989113*NM + 0.00039600193928152126*lm*NM + 
        0.00013973540304061335*lm^2*NM + 0.0007607311393803468*NL + 
        0.00039600193928152126*lm*NL + 0.00013973540304061335*lm^2*NL - 
        0.00017894222423490551*NH + 0.00039600193928152126*lm*NH + 
        0.00013973540304061335*lm^2*NH)}, 
     {0.61, CF*NC*(CA*(-0.002825639557086894 - 0.003071790194504254*lm - 
          0.0007496832629248059*lm^2) + CF*(0.0037267558739018485 + 
          0.007931654730579548*lm + 0.004907017720962366*lm^2) + 
        0.00022848091554275425*NM + 0.000385026883613215*lm*NM + 
        0.00013630604780451015*lm^2*NM + 0.0007396336205974553*NL + 
        0.000385026883613215*lm*NL + 0.00013630604780451015*lm^2*NL - 
        0.00017421831323360105*NH + 0.000385026883613215*lm*NH + 
        0.00013630604780451015*lm^2*NH)}, 
     {0.615, CF*NC*(CA*(-0.0027401240276670276 - 0.002989861454056525*lm - 
          0.0007313397506373727*lm^2) + CF*(0.003603728416135374 + 
          0.007693286459589508*lm + 0.004786951095080985*lm^2) + 
        0.0002171859399155035*NM + 0.00037437552868923235*lm*NM + 
        0.00013297086375224957*lm^2*NM + 0.0007191795533678013*NL + 
        0.00037437552868923235*lm*NL + 0.00013297086375224957*lm^2*NL - 
        0.0001696250602295943*NH + 0.00037437552868923235*lm*NH + 
        0.00013297086375224957*lm^2*NH)}, 
     {0.62, CF*NC*(CA*(-0.0026573297452293777 - 0.002910296632411215*lm - 
          0.0007134985001164387*lm^2) + CF*(0.003484743409774096 + 
          0.0074622345466188456*lm + 0.004670172000762145*lm^2) + 
        0.00020635499113576974*NM + 0.0003640377513205492*lm*NM + 
        0.00012972700002117067*lm^2*NM + 0.0006993477744664711*NL + 
        0.0003640377513205492*lm*NL + 0.00012972700002117067*lm^2*NL - 
        0.00016515864660404444*NH + 0.0003640377513205492*lm*NH + 
        0.00012972700002117067*lm^2*NH)}, 
     {0.625, CF*NC*(CA*(-0.002577166111970137 - 0.0028330225795451945*lm - 
          0.0006961443477415964*lm^2) + CF*(0.0033696695390589147 + 
          0.007238266443698819*lm + 0.004556581185217722*lm^2) + 
        0.00019596964633104033*NM + 0.00035400376043991387*lm*NM + 
        0.00012657169958938115*lm^2*NM + 0.0006801178585996675*NL + 
        0.00035400376043991387*lm*NL + 0.00012657169958938115*lm^2*NL - 
        0.00016081537113729003*NH + 0.00035400376043991387*lm*NH + 
        0.00012657169958938115*lm^2*NH)}, 
     {0.63, CF*NC*(CA*(-0.0024995456491162535 - 0.0027579685440059375*lm - 
          0.0006792626277965318*lm^2) + CF*(0.0032583796158845595 + 
          0.007021157216797666*lm + 0.004446082654668208*lm^2) + 
        0.0001860122175656281*NM + 0.0003442640858663449*lm*NM + 
        0.00012350229596300578*lm^2*NM + 0.0006614700916175856*NL + 
        0.0003442640858663449*lm*NL + 0.00012350229596300578*lm^2*NL - 
        0.00015659164625897*NH + 0.0003442640858663449*lm*NH + 
        0.00012350229596300578*lm^2*NH)}, 
     {0.635, CF*NC*(CA*(-0.0024243838881216565 - 0.0026850660908904747*lm - 
          0.0006628391549286005*lm^2) + CF*(0.0031507504619635598 + 
          0.006810689293806248*lm + 0.004338583559532657*lm^2) + 
        0.000176465722130124*NM + 0.000334809567451154*lm*NM + 
        0.00012051620998701826*lm^2*NM + 0.0006433854447170369*NL + 
        0.000334809567451154*lm*NL + 0.00012051620998701826*lm^2*NL - 
        0.00015248399442002617*NH + 0.000334809567451154*lm*NH + 
        0.00012051620998701826*lm^2*NH)}, 
     {0.64, CF*NC*(CA*(-0.0023515992655751303 - 0.0026142490226859303*lm - 
          0.0006468602072617649*lm^2) + CF*(0.0030466627934158134 + 
          0.0066066522206437075*lm + 0.004233994083895188*lm^2) + 
        0.00016731385404140256*NM + 0.0003256313445930665*lm*NM + 
        0.00011761094677486634*lm^2*NM + 0.0006258455495977415*NL + 
        0.0003256313445930665*lm*NL + 0.00011761094677486634*lm^2*NL - 
        0.00014848904458268942*NH + 0.0003256313445930665*lm*NH + 
        0.00011761094677486634*lm^2*NH)}, 
     {0.645, CF*NC*(CA*(-0.0022811130217045227 - 0.0025454533028730327*lm - 
          0.0006313125101375893*lm^2) + CF*(0.0029460011078088384 + 
          0.006408842425248587*lm + 0.004132227339082402*lm^2) + 
        0.0001585409567042176*NM + 0.00031672084611036546*lm*NM + 
        0.00011478409275228895*lm^2*NM + 0.0006088326745374467*NL + 
        0.00031672084611036546*lm*NL + 0.00011478409275228895*lm^2*NL - 
        0.00014460352882466845*NH + 0.00031672084611036546*lm*NH + 
        0.00011478409275228895*lm^2*NH)}, 
     {0.65, CF*NC*(CA*(-0.002212849102364621 - 0.0024786169821971672*lm - 
          0.0006161832204599823*lm^2) + CF*(0.002848653573666094 + 
          0.006217062989225548*lm + 0.004033199261192611*lm^2) + 
        0.0001501319966873444*NM + 0.00030806978045833203*lm*NM + 
        0.00011203331281090586*lm^2*NM + 0.0005923297013522284*NL + 
        0.00030806978045833203*lm*NL + 0.00011203331281090586*lm^2*NL - 
        0.00014082427905387208*NH + 0.00030806978045833203*lm*NH + 
        0.00011203331281090586*lm^2*NH)}, 
     {0.655, CF*NC*(CA*(-0.0021467340643987133 - 0.00241368012751463*lm - 
          0.000601459911620342*lm^2) + CF*(0.002754511922453743 + 
          0.006031123426922436*lm + 0.003936828512424057*lm^2) + 
        0.00014207253856907075*NM + 0.00029967012628059734*lm*NM + 
        0.00010935634756733491*lm^2*NM + 0.0005763201032094997*NL + 
        0.00029967012628059734*lm*NL + 0.00010935634756733491*lm^2*NL - 
        0.00013714822383010595*NH + 0.00029967012628059734*lm*NH + 
        0.00010935634756733491*lm^2*NH)}, 
     {0.66, CF*NC*(CA*(-0.0020826969842665096 - 0.0023505847531247693*lm - 
          0.0005871305589806767*lm^2) + CF*(0.002663471343049816 + 
          0.005850839471717253*lm + 0.0038430363860553385*lm^2) + 
        0.0001343487208086185*NM + 0.0002915141232833552*lm*NM + 
        0.0001067510107237594*lm^2*NM + 0.0005607879232623776*NL + 
        0.0002915141232833552*lm*NL + 0.0001067510107237594*lm^2*NL - 
        0.00013357238529029163*NH + 0.0002915141232833552*lm*NH + 
        0.0001067510107237594*lm^2*NH)}, 
     {0.665, CF*NC*(CA*(-0.002020669369833767 - 0.0022892747545016127*lm - 
          0.00057318352589316*lm^2) + CF*(0.0025754303786938776 + 
          0.005676032869299321*lm + 0.0037517467149370473*lm^2) + 
        0.0001269472326017929*NM + 0.00028359426342171074*lm*NM + 
        0.0001042151865260291*lm^2*NM + 0.0005457177540751526*NL + 
        0.00028359426342171074*lm*NL + 0.0001042151865260291*lm^2*NL - 
        0.00013009387617386105*NH + 0.00028359426342171074*lm*NH + 
        0.0001042151865260291*lm^2*NH)}, 
     {0.67, CF*NC*(CA*(-0.0019605850752216236 - 0.00222969584434143*lm - 
          0.0005596075502354333*lm^2) + CF*(0.00249029082641001 + 
          0.005506531177733768*lm + 0.0036628857833592*lm^2) + 
        0.00011985529168080513*NM + 0.000275903282387763*lm*NM + 
        0.00010174682731553333*lm^2*NM + 0.0005310947178106724*NL + 
        0.000275903282387763*lm*NL + 0.00010174682731553333*lm^2*NL - 
        0.0001267098969450804*NH + 0.000275903282387763*lm*NH + 
        0.00010174682731553333*lm^2*NH)}, 
     {0.675, CF*NC*(CA*(-0.0019023802186162722 - 0.0021717954908454535*lm - 
          0.0005463917314417817*lm^2) + CF*(0.0024079576388911133 + 
          0.0053421675741032884*lm + 0.0035763822421643896*lm^2) + 
        0.00011306062301980468*NM + 0.00026843415139033127*lm*NM + 
        0.00009934395117123305*lm^2*NM + 0.0005169044471514732*NL + 
        0.00026843415139033127*lm*NL + 0.00009934395117123305*lm^2*NL - 
        0.00012341773300915773*NH + 0.00026843415139033127*lm*NH + 
        0.00009934395117123305*lm^2*NH)}, 
     {0.68, CF*NC*(CA*(-0.0018459931029422385 - 0.002115522858159653*lm - 
          0.0005335255180110972*lm^2) + CF*(0.0023283388288281672 + 
          0.005182780667525946*lm + 0.003492167026981727*lm^2) + 
        0.00010655143840918647*NM + 0.00026118006921654256*lm*NM + 
        0.0000970046396383813*lm^2*NM + 0.0005031330669274939*NL + 
        0.00026118006921654256*lm*NL + 0.0000970046396383813*lm^2*NL - 
        0.00012021475201908429*NH + 0.00026118006921654256*lm*NH + 
        0.0000970046396383813*lm^2*NH)}, 
     {0.685, CF*NC*(CA*(-0.0017913641393051151 - 0.002060828748896076*lm - 
          0.0005209986954732948*lm^2) + CF*(0.0022513453756642125 + 
          0.005028214318352627*lm + 0.0034101732794615657*lm^2) + 
        0.00010031641686321106*NM + 0.00025413445456579683*lm*NM + 
        0.00009472703554059904*lm^2*NM + 0.0004897671764241708*NL + 
        0.00025413445456579683*lm*NL + 0.00009472703554059904*lm^2*NL - 
        0.00011709840127025498*NH + 0.00025413445456579683*lm*NH + 
        0.00009472703554059904*lm^2*NH)}, 
     {0.69, CF*NC*(CA*(-0.0017384357731121786 - 0.0020076655486627897*lm - 
          0.000508801374796574*lm^2) + CF*(0.0021768911347492905 + 
          0.004878317463352573*lm + 0.003330336271395757*lm^2) + 
        0.00009434468582689278*NM + 0.0002472909386469198*lm*NM + 
        0.00009250934087210437*lm^2*NM + 0.00047679383234564595*NL + 
        0.0002472909386469198*lm*NL + 0.00009250934087210437*lm^2*NL - 
        0.00011406620518000365*NH + 0.0002472909386469198*lm*NH + 
        0.00009250934087210437*lm^2*NH)}, 
     {0.695, CF*NC*(CA*(-0.001687152412781854 - 0.001955987172531932*lm - 
          0.0004969239812186103*lm^2) + CF*(0.002104892748869455 + 
          0.004732943946700172*lm + 0.003252593331612722*lm^2) + 
        0.00008862580314947431*NM + 0.00024064335802959845*lm*NM + 
        0.00009034981476702006*lm^2*NM + 0.00046420053240872654*NL + 
        0.00024064335802959845*lm*NL + 0.00009034981476702006*lm^2*NL - 
        0.00011111576284927952*NH + 0.00024064335802959845*lm*NH + 
        0.00009034981476702006*lm^2*NH)}, 
     {0.7, CF*NC*(CA*(-0.001637460360955502 - 0.0019057490133777414*lm - 
          0.00048535724348543067*lm^2) + CF*(0.002035269562120195 + 
          0.004591952356580991*lm + 0.0031768837755410005*lm^2) + 
        0.0000831497397931175*NM + 0.00023418574774147316*lm*NM + 
        0.00008824677154280558*lm^2*NM + 0.0004519751995441096*NL + 
        0.00023418574774147316*lm*NL + 0.00008824677154280558*lm^2*NL - 
        0.00010824474570377705*NH + 0.00023418574774147316*lm*NH + 
        0.00008824677154280558*lm^2*NH)}, 
     {0.705, CF*NC*(CA*(-0.0015893077481274687 - 0.0018569078920187645*lm - 
          0.0004740921834823691*lm^2) + CF*(0.00196794353609215 + 
          0.00445520586723972*lm + 0.0031031488373391434*lm^2) + 
        0.00007790686324670277*NM + 0.00022791233460253292*lm*NM + 
        0.0000861985788149762*lm^2*NM + 0.0004401061666822311*NL + 
        0.00022791233460253292*lm*NL + 0.0000861985788149762*lm^2*NL - 
        0.00010545089521191606*NH + 0.00022791233460253292*lm*NH + 
        0.0000861985788149762*lm^2*NH)}, 
     {0.71, CF*NC*(CA*(-0.0015426444686117843 - 0.0018094220091006729*lm - 
          0.0004631201062421124*lm^2) + CF*(0.0019028391683348356 + 
          0.004322572086297373*lm + 0.0030313316044938265*lm^2) + 
        0.0000728879216158417*NM + 0.00022181753078872444*lm*NM + 
        0.00008420365568038407*lm^2*NM + 0.0004285821621019198*NL + 
        0.00022181753078872444*lm*NL + 0.00008420365568038407*lm^2*NL - 
        0.00010273202067715171*NH + 0.00022181753078872444*lm*NH + 
        0.00008420365568038407*lm^2*NH)}, 
     {0.715, CF*NC*(CA*(-0.0014974221187662765 - 0.0017632508986582967*lm - 
          0.0004524325903154375*lm^2) + CF*(0.0018398834130622418 + 
          0.004193922907169722*lm + 0.0029613769547919546*lm^2) + 
        0.00006808402836137535*NM + 0.00021589592761694446*lm*NM + 
        0.00008226047096644317*lm^2*NM + 0.00041739229532082817*NL + 
        0.00021589592761694446*lm*NL + 0.00008226047096644317*lm^2*NL - 
        0.00010008599710217288*NH + 0.00021589592761694446*lm*NH + 
        0.00008226047096644317*lm^2*NH)}, 
     {0.72, CF*NC*(CA*(-0.0014535939373972314 - 0.0017183553832975876*lm - 
          0.00044202147849081177*lm^2) + CF*(0.0017790056040625217 + 
          0.004069134366423506*lm + 0.0028932314955762224*lm^2) + 
        0.00006348664765975185*NM + 0.00021014228954383636*lm*NM + 
        0.00008036754154378396*lm^2*NM + 0.000406526043507378*NL + 
        0.00021014228954383636*lm*NL + 0.00008036754154378396*lm^2*NL - 
        0.00009751076312262592*NH + 0.00021014228954383636*lm*NH + 
        0.00008036754154378396*lm^2*NH)}, 
     {0.725, CF*NC*(CA*(-0.001411114748270034 - 0.001674697530940263*lm - 
          0.00043187886884956935*lm^2) + CF*(0.0017201373797726242 + 
          0.003948086505911442*lm + 0.0028268435051971813*lm^2) + 
        0.000059087580359755735*NM + 0.00020455154837105654*lm*NM + 
        0.0000785234306999217*lm^2*NM + 0.00039597323839469937*NL + 
        0.00020455154837105654*lm*NL + 0.0000785234306999217*lm^2*NL - 
        0.00009500431900807541*NH + 0.00020455154837105654*lm*NH + 
        0.0000785234306999217*lm^2*NH)}, 
     {0.73, CF*NC*(CA*(-0.001369940904653494 - 0.001632240613075863*lm - 
          0.00042199710614390277*lm^2) + CF*(0.0016632126104775505 + 
          0.003830663239531525*lm + 0.0027621628765782725*lm^2) + 
        0.00005487895051109798*NM + 0.00019911879764991492*lm*NM + 
        0.00007672674657161868*lm^2*NM + 0.00038572405367775766*NL + 
        0.00019911879764991492*lm*NL + 0.00007672674657161868*lm^2*NL - 
        0.0000925647247279877*NH + 0.00019911879764991492*lm*NH + 
        0.00007672674657161868*lm^2*NH)}, 
     {0.735, CF*NC*(CA*(-0.0013300302358277784 - 0.0015909490644678615*lm - 
          0.00041236877348540933*lm^2) + CF*(0.0016081673275929584 + 
          0.003716752224460471*lm + 0.0026991410628135885*lm^2) + 
        0.000050853192441371475*NM + 0.00019383928727852474*lm*NM + 
        0.0000749761406337108*lm^2*NM + 0.0003757689928755529*NL + 
        0.00019383928727852474*lm*NL + 0.0000749761406337108*lm^2*NL - 
        0.00009019009808059305*NH + 0.00019383928727852474*lm*NH + 
        0.0000749761406337108*lm^2*NH)}, 
     {0.74, CF*NC*(CA*(-0.0012913419954880458 - 0.0015507884442623303*lm - 
          0.00040298668433241656*lm^2) + CF*(0.0015549396549890552 + 
          0.0036062447367154297*lm + 0.002637731024721272*lm^2) + 
        0.00004700303835883451*NM + 0.00018870841828482314*lm*NM + 
        0.00007327030624225755*lm^2*NM + 0.0003660988776409454*NL + 
        0.00018870841828482314*lm*NL + 0.00007327030624225755*lm^2*NL - 
        0.00008787861288255234*NH + 0.00018870841828482314*lm*NH + 
        0.00007327030624225755*lm^2*NH)}, 
     {0.745, CF*NC*(CA*(-0.0012538368119780088 - 0.001511725398449442*lm - 
          0.00039384387476477055*lm^2) + CF*(0.0015034697423131208 + 
          0.003499035550902347*lm + 0.0025778871802784984*lm^2) + 
        0.00004332150645940386*NM + 0.00018372173778904256*lm*NM + 
        0.00007160797722995828*lm^2*NM + 0.0003567048365013052*NL + 
        0.00018372173778904256*lm*NL + 0.00007160797722995828*lm^2*NL - 
        0.00008562849721742048*NH + 0.00018372173778904256*lm*NH + 
        0.00007160797722995828*lm^2*NH)}, 
     {0.75, CF*NC*(CA*(-0.0012174766402897237 - 0.001473727623629847*lm - 
          0.0003849335960352202*lm^2) + CF*(0.0014536997002675396 + 
          0.00339502282401348*lm + 0.002519565355866896*lm^2) + 
        0.00003980188951712293*NM + 0.00017887493413942535*lm*NM + 
        0.00006998792655185822*lm^2*NM + 0.0003475782940138053*NL + 
        0.00017887493413942535*lm*NL + 0.00006998792655185822*lm^2*NL - 
        0.00008343803174096424*NH + 0.00017887493413942535*lm*NH + 
        0.00006998792655185822*lm^2*NH)}, 
     {0.755, CF*NC*(CA*(-0.0011822247157679438 - 0.0014367638320396193*lm - 
          0.00037624930738695237*lm^2) + CF*(0.0014055735377999212 + 
          0.0032941079831406363*lm + 0.002462722739260052*lm^2) + 
        0.00003643774393821879*NM + 0.00017416383221518144*lm*NM + 
        0.00006840896497944589*lm^2*NM + 0.0003387109603197809*NL + 
        0.00017416383221518144*lm*NL + 0.00006840896497944589*lm^2*NL - 
        0.00008130554804145535*NH + 0.00017416383221518144*lm*NH + 
        0.00006840896497944589*lm^2*NH)}, 
     {0.76, CF*NC*(CA*(-0.0011480455094593509 - 0.0014008037177891122*lm - 
          0.0003677846691272463*lm^2) + CF*(0.001359037101161705 + 
          0.0031961956169746933*lm + 0.0024073178342874303*lm^2) + 
        0.000033222879259676794*NM + 0.00016958438889088902*lm*NM + 
        0.00006686993984131751*lm^2*NM + 0.0003300948210831546*NL + 
        0.00016958438889088902*lm*NL + 0.00006686993984131751*lm^2*NL - 
        0.00007922942705312039*NH + 0.00016958438889088902*lm*NH + 
        0.00006686993984131751*lm^2*NH)}, 
     {0.765, CF*NC*(CA*(-0.0011149046850489161 - 0.0013658179242726216*lm - 
          0.0003595335359476074*lm^2) + CF*(0.001314038014791579 + 
          0.003101193370965849*lm + 0.002353310417111612*lm^2) + 
        0.00003015134807404408*NM + 0.00016513268865673279*lm*NM + 
        0.00006536973380865589*lm^2*NM + 0.00032172212779848954*NL + 
        0.00016513268865673279*lm*NL + 0.00006536973380865589*lm^2*NL - 
        0.00007720809752098919*NH + 0.00016513268865673279*lm*NH + 
        0.00006536973380865589*lm^2*NH)}, 
     {0.77, CF*NC*(CA*(-0.0010827690573275261 - 0.001331778012707278*lm - 
          0.00035148995048111804*lm^2) + CF*(0.0012705256239800946 + 
          0.003009011846022869*lm + 0.0023006614940582273*lm^2) + 
        0.000027217436362924717*NM + 0.00016080493938916372*lm*NM + 
        0.00006390726372383965*lm^2*NM + 0.00031358538845477026*NL + 
        0.00016080493938916372*lm*NL + 0.00006390726372383965*lm^2*NL - 
        0.00007524003451544037*NH + 0.00016080493938916372*lm*NH + 
        0.00006390726372383965*lm^2*NH)}, 
     {0.775, CF*NC*(CA*(-0.0010516065521368465 - 0.0012986564317610625*lm - 
          0.00034364813708810595*lm^2) + CF*(0.0012284509392719938 + 
          0.0029195645006333333*lm + 0.0022493332609403297*lm^2) + 
        0.000024415654222350175*NM + 0.00015659746826674717*lm*NM + 
        0.00006248147947056472*lm^2*NM + 0.00030567735854153264*NL + 
        0.00015659746826674717*lm*NL + 0.00006248147947056472*lm^2*NL - 
        0.0000733237579947988*NH + 0.00015659746826674717*lm*NH + 
        0.00006248147947056472*lm^2*NH)}, 
     {0.78, CF*NC*(CA*(-0.0010213861677391882 - 0.0012664264882312536*lm - 
          0.00033600249586157805*lm^2) + CF*(0.0011877665825630016 + 
          0.002832767556290512*lm + 0.0021992890638212383*lm^2) + 
        0.000021740726963901682*NM + 0.00015250671782614375*lm*NM + 
        0.00006109136288392328*lm^2*NM + 0.00029799103238446685*NL + 
        0.00015250671782614375*lm*NL + 0.00006109136288392328*lm^2*NL - 
        0.0000714578314143939*NH + 0.00015250671782614375*lm*NH + 
        0.00006109136288392328*lm^2*NH)}, 
     {0.785, CF*NC*(CA*(-0.0009920779375618756 - 0.0012350623187359913*lm - 
          0.0003285475968442033*lm^2) + CF*(0.0011484267348481376 + 
          0.0027485399061160797*lm + 0.0021504933611620576*lm^2) + 
        0.000019187586576125106*NM + 0.0001485292421533398*lm*NM + 
        0.00005973592669894605*lm^2*NM + 0.00029051963479810003*NL + 
        0.0001485292421533398*lm*NL + 0.00005973592669894605*lm^2*NL - 
        0.00006964086038053992*NH + 0.0001485292421533398*lm*NH + 
        0.00005973592669894605*lm^2*NH)}, 
     {0.79, CF*NC*(CA*(-0.0009636528942673181 - 0.001204538862382966*lm - 
          0.0003212781744489455*lm^2) + CF*(0.0011103870855789836 + 
          0.0026668030265713316*lm + 0.002102911687302189*lm^2) + 
        0.000016751363531417086*NM + 0.00014466170320541138*lm*NM + 
        0.00005841421353617191*lm^2*NM + 0.0002832566130436333*NL + 
        0.00014466170320541138*lm*NL + 0.00005841421353617191*lm^2*NL - 
        0.0000678714913479502*NH + 0.00014466170320541138*lm*NH + 
        0.00005841421353617191*lm^2*NH)}, 
     {0.795, CF*NC*(CA*(-0.0009360830351016229 - 0.0011748318343805238*lm - 
          0.00031418912207575926*lm^2) + CF*(0.001073604783587782 + 
          0.0025874808921529575*lm + 0.0020565106172231516*lm^2) + 
        0.000014427378924172983*NM + 0.00014090086725826665*lm*NM + 
        0.000057125294922865324*lm^2*NM + 0.000276195629080457*NL + 
        0.00014090086725826665*lm*NL + 0.000057125294922865324*lm^2*NL - 
        0.00006614841035914695*NH + 0.00014090086725826665*lm*NH + 
        0.000057125294922865324*lm^2*NH)}, 
     {0.8, CF*NC*(CA*(-0.0009093412884761961 - 0.0011459177005577147*lm - 
          0.00030727548691705304*lm^2) + CF*(0.0010380383895367401 + 
          0.0025104998929727338*lm + 0.0020112577325479834*lm^2) + 
        0.000012211136926574348*NM + 0.0001372436014759689*lm*NM + 
        0.000055868270348555094*lm^2*NM + 0.0002693305521003016*NL + 
        0.0001372436014759689*lm*NL + 0.000055868270348555094*lm^2*NL - 
        0.00006447034182447522*NH + 0.0001372436014759689*lm*NH + 
        0.000055868270348555094*lm^2*NH)}, 
     {0.805, CF*NC*(CA*(-0.000883401481738326 - 0.001117773652761007*lm - 
          0.00030053246494491075*lm^2) + CF*(0.0010036478298514563 + 
          0.0024357887551237026*lm + 0.001967121588730325*lm^2) + 
        0.000010098317548957146*NM + 0.00013368687059739384*lm*NM + 
        0.00005464226635362013*lm^2*NM + 0.0002626554513333989*NL + 
        0.00013368687059739384*lm*NL + 0.00005464226635362013*lm^2*NL - 
        0.00006283604734137623*NH + 0.00013368687059739384*lm*NH + 
        0.00005464226635362013*lm^2*NH)}, 
     {0.81, CF*NC*(CA*(-0.0008582383100882537 - 0.0010903775850965448*lm - 
          0.0002939553960733336*lm^2) + CF*(0.0009703943520979789 + 
          0.0023632784637385358*lm + 0.0019240716833890928*lm^2) + 
        8.084769692242187*^-6*NM + 0.000130227733736121*lm*NM + 
        0.000053446435649697025*lm^2*NM + 0.00025616458911643215*NL + 
        0.000130227733736121*lm*NL + 0.000053446435649697025*lm^2*NL - 
        0.00006124432455162003*NH + 0.000130227733736121*lm*NH + 
        0.000053446435649697025*lm^2*NH)}, 
     {0.815, CF*NC*(CA*(-0.0008338273066016987 - 0.001063708070987936*lm - 
          0.0002875397594890259*lm^2) + CF*(0.0009382404817636322 + 
          0.002292902188648839*lm + 0.0018820784257463513*lm^2) + 
        6.166504480427692*^-6*NM + 0.00012686334128960222*lm*NM + 
        0.000052279956270731985*lm^2*NM + 0.0002498524142124388*NL + 
        0.00012686334128960222*lm*NL + 0.000052279956270731985*lm^2*NL - 
        0.00005969400603524041*NH + 0.00012686334128960222*lm*NH + 
        0.000052279956270731985*lm^2*NH)}, 
     {0.82, CF*NC*(CA*(-0.0008101448133182274 - 0.0010377443410206427*lm - 
          0.0002812811691444988*lm^2) + CF*(0.0009071499804024028 + 
          0.002224595212557099*lm + 0.0018411131071276283*lm^2) + 
        4.33968886164112*^-6*NM + 0.00012359093195378658*lm*NM + 
        0.00005114203075354523*lm^2*NM + 0.00024371355537320538*NL + 
        0.00012359093195378658*lm*NL + 0.00005114203075354523*lm^2*NL - 
        0.000058183958239956915*NH + 0.00012359093195378658*lm*NH + 
        0.00005114203075354523*lm^2*NH)}, 
     {0.825, CF*NC*(CA*(-0.0007871679533572279 - 0.0010124662615450693*lm - 
          0.0002751753694075085*lm^2) + CF*(0.0008770878051063715 + 
          0.0021582948616358727*lm + 0.0018011478724855102*lm^2) + 
        2.6006394667241077*^-6*NM + 0.00012040782983951475*lm*NM + 
        0.000050031885346819724*lm^2*NM + 0.00023774281513505138*NL + 
        0.00012040782983951475*lm*NL + 0.000050031885346819724*lm^2*NL - 
        0.00005671308044490985*NH + 0.00012040782983951475*lm*NH + 
        0.000050031885346819724*lm^2*NH)}, 
     {0.83, CF*NC*(CA*(-0.0007648746040245884 - 0.000987854314011461*lm - 
          0.0002692182308610751*lm^2) + CF*(0.0008480200692653792 + 
          0.002093940438471607*lm + 0.0017621556929088551*lm^2) + 
        9.458167147817056*^-7*NM + 0.00011731144168712427*lm*NM + 
        0.0000489487692474682*lm^2*NM + 0.00023193516383924697*NL + 
        0.00011731144168712427*lm*NL + 0.0000489487692474682*lm^2*NL - 
        0.000055280303757572636*NH + 0.00011731144168712427*lm*NH + 
        0.0000489487692474682*lm^2*NH)}, 
     {0.835, CF*NC*(CA*(-0.0007432433708744687 - 0.0009638895750106807*lm - 
          0.00026340574624855067*lm^2) + CF*(0.0008199140045778547 + 
          0.002031473157273199*lm + 0.0017241103390814225*lm^2) - 
        6.281808444344976*^-7*NM + 0.00011429925417583106*lm*NM + 
        0.00004789195386337285*lm^2*NM + 0.00022628573386864094*NL + 
        0.00011429925417583106*lm*NL + 0.00004789195386337285*lm^2*NL - 
        0.000053884590142744386*NH + 0.00011429925417583106*lm*NH + 
        0.00004789195386337285*lm^2*NH)}, 
     {0.84, CF*NC*(CA*(-0.0007222535626918076 - 0.0009405536969958699*lm - 
          0.0002577340265584192*lm^2) + CF*(0.000792737924276469 + 
          0.0019708360812680597*lm + 0.0016869863556551077*lm^2) - 
        2.1246219610193864*^-6*NM + 0.00011136883132457355*lm*NM + 
        0.00004686073210153077*lm^2*NM + 0.00022078981409239746*NL + 
        0.00011136883132457355*lm*NL + 0.00004686073210153077*lm^2*NL - 
        0.000052524931482562145*NH + 0.00011136883132457355*lm*NH + 
        0.00004686073210153077*lm^2*NH)}, 
     {0.845, CF*NC*(CA*(-0.0007018851673624163 - 0.0009178288896608959*lm - 
          0.000252199297243715*lm^2) + CF*(0.0007664611875330465 + 
          0.0019119740622109888*lm + 0.0016507590365043162*lm^2) - 
        3.5466478975904345*^-6*NM + 0.00010851781198112141*lm*NM + 
        0.00004585441768067545*lm^2*NM + 0.0002154428445110477*NL + 
        0.00010851781198112141*lm*NL + 0.00004585441768067545*lm^2*NL - 
        0.00005120034866650763*NH + 0.00010851781198112141*lm*NH + 
        0.00004585441768067545*lm^2*NH)}, 
     {0.85, CF*NC*(CA*(-0.0006821188285986862 - 0.0008956979019523599*lm - 
          0.00024679789457114203*lm^2) + CF*(0.0007410541650079281 + 
          0.0018548336819336772*lm + 0.0016154044008292931*lm^2) - 
        4.897277433067516*^-6*NM + 0.00010574390739636315*lm*NM + 
        0.000044872344467480365*lm^2*NM + 0.00021024041109436067*NL + 
        0.00010574390739636315*lm*NL + 0.000044872344467480365*lm^2*NL - 
        0.00004990989071041794*NH + 0.00010574390739636315*lm*NH + 
        0.000044872344467480365*lm^2*NH)}, 
     {0.855, CF*NC*(CA*(-0.0006629358234900697 - 0.0008741440046927723*lm - 
          0.00024152626209516774*lm^2) + CF*(0.0007164882055097555 + 
          0.0017993631958650503*lm + 0.0015808991700774616*lm^2) - 
        6.179411666106594*^-6*NM + 0.00010304489888079583*lm*NM + 
        0.000043913865835485046*lm^2*NM + 0.0002051782408048226*NL + 
        0.00010304489888079583*lm*NL + 0.000043913865835485046*lm^2*NL - 
        0.00004865263390354261*NH + 0.00010304489888079583*lm*NH + 
        0.000043913865835485046*lm^2*NH)}, 
     {0.86, CF*NC*(CA*(-0.0006443180408485905 - 0.000853150973793313*lm - 
          0.00023638094725254283*lm^2) + CF*(0.000692735603732427 + 
          0.001745512478455019*lm + 0.0015472207456530074*lm^2) - 
        7.395838626382445*^-6*NM + 0.00010041863554034453*lm*NM + 
        0.00004297835404591687*lm^2*NM + 0.00020025219679978986*NL + 
        0.00010041863554034453*lm*NL + 0.00004297835404591687*lm^2*NL - 
        0.000047427680982721844*NH + 0.00010041863554034453*lm*NH + 
        0.00004297835404591687*lm^2*NH)}, 
     {0.865, CF*NC*(CA*(-0.0006262479603207058 - 0.0008327030740353685*lm - 
          0.000231358598072875*lm^2) + CF*(0.0006697695690367524 + 
          0.001693232970436467*lm + 0.0015143471873860909*lm^2) - 
        8.54923770157523*^-6*NM + 0.00009786303208874057*lm*NM + 
        0.00004206519964961363*lm^2*NM + 0.00019545827380564515*NL + 
        0.00009786303208874057*lm*NL + 0.00004206519964961363*lm^2*NL - 
        0.00004623416033279159*NH + 0.00009786303208874057*lm*NH + 
        0.00004206519964961363*lm^2*NH)}, 
     {0.87, CF*NC*(CA*(-0.0006087086322378604 - 0.0008127850434007936*lm - 
          0.00022645596000105098*lm^2) + CF*(0.0006475641952451188 + 
          0.001642477627862507*lm + 0.001482257192734152*lm^2) - 
        9.642183887589592*^-6*NM + 0.00009537606673378538*lm*NM + 
        0.000041173810909282*lm^2*NM + 0.0001907925936575407*NL + 
        0.00009537606673378538*lm*NL + 0.000041173810909282*lm^2*NL - 
        0.000045071225212351314*NH + 0.00009537606673378538*lm*NH + 
        0.000041173810909282*lm^2*NH)}, 
     {0.875, CF*NC*(CA*(-0.0005916836581790724 - 0.0007933820779315639*lm - 
          0.00022166987282746094*lm^2) + CF*(0.0006260944314182539 + 
          0.0015932008728581643*lm + 0.0014509300766888352*lm^2) - 
        0.0000106771518692223*NM + 0.00009295577913492149*lm*NM + 
        0.000040303613241356536*lm^2*NM + 0.0001862514009985582*NL + 
        0.00009295577913492149*lm*NL + 0.000040303613241356536*lm^2*NL - 
        0.0000439380530040593*NH + 0.00009295577913492149*lm*NH + 
        0.000040303613241356536*lm^2*NH)}, 
     {0.88, CF*NC*(CA*(-0.0005751571722198432 - 0.000774479817100186*lm - 
          0.00021699726772213425*lm^2) + CF*(0.0006053360535839494 + 
          0.0015453585460277154*lm + 0.0014203457523630605*lm^2) - 
        0.000011656519938194939*NM + 0.0000906002684296226*lm*NM + 
        0.00003945404867675168*lm^2*NM + 0.00018183105913234976*NL + 
        0.0000906002684296226*lm*NL + 0.00003945404867675168*lm^2*NL - 
        0.000042833844488648425*NH + 0.0000906002684296226*lm*NH + 
        0.00003945404867675168*lm^2*NH)}, 
     {0.885, CF*NC*(CA*(-0.0005591138228426111 - 0.000756064329672904*lm - 
          0.00021243516436904338*lm^2) + CF*(0.0005852656373883754 + 
          0.0014989078604609068*lm + 0.0013904847122337386*lm^2) - 
        0.000012582573755180974*NM + 0.00008830769132620392*lm*NM + 
        0.00003862457533982607*lm^2*NM + 0.00017752804602355203*NL + 
        0.00008830769132620392*lm*NL + 0.00003862457533982607*lm^2*NL - 
        0.000041757823141882516*NH + 0.00008830769132620392*lm*NH + 
        0.00003862457533982607*lm^2*NH)}, 
     {0.89, CF*NC*(CA*(-0.0005435387554848629 - 0.0007381221000483884*lm - 
          0.00020798066819697456*lm^2) + CF*(0.0005658605316413807 + 
          0.0014538073572832116*lm + 0.0013613280100165607*lm^2) - 
        0.000013457509962181431*NM + 0.00008607626026073766*lm*NM + 
        0.00003781466694490446*lm^2*NM + 0.00017333895044048176*NL + 
        0.00008607626026073766*lm*NL + 0.00003781466694490446*lm^2*NL - 
        0.000040709234453699516*NH + 0.00008607626026073766*lm*NH + 
        0.00003781466694490446*lm^2*NH)}, 
     {0.895, CF*NC*(CA*(-0.0005284175957018794 - 0.0007206400150552199*lm - 
          0.00020363096770350034*lm^2) + CF*(0.0005470988327279259 + 
          0.001410016862697157*lm + 0.001332857243150184*lm^2) - 
        0.00001428343965133979*NM + 0.00008390424161584155*lm*NM + 
        0.00003702381230972734*lm^2*NM + 0.00016926046823483314*NL + 
        0.00008390424161584155*lm*NL + 0.00003702381230972734*lm^2*NL - 
        0.000039687345268813236*NH + 0.00008390424161584155*lm*NH + 
        0.00003702381230972734*lm^2*NH)}, 
     {0.9, CF*NC*(CA*(-0.0005137364329219244 - 0.0007036053511920811*lm - 
          0.0001993833318687207*lm^2) + CF*(0.0005289593598585449 + 
          0.0013674974464635702*lm + 0.0013050545358679901*lm^2) - 
        0.000015062391696034071*NM + 0.0000817899539991868*lm*NM + 
        0.00003625151488522195*lm^2*NM + 0.00016528939875329633*NL + 
        0.0000817899539991868*lm*NL + 0.00003625151488522195*lm^2*NL - 
        0.00003869144314806978*NH + 0.0000817899539991868*lm*NH + 
        0.00003625151488522195*lm^2*NH)}, 
     {0.905, CF*NC*(CA*(-0.000499481804772491 - 0.0006870057622951499*lm - 
          0.00019523510765556478*lm^2) + CF*(0.0005114216311324631 + 
          0.0013262113817733387*lm + 0.001277902522836424*lm^2) - 
        0.000015796315949842016*NM + 0.00007973176657964865*lm*NM + 
        0.00003549729230101178*lm^2*NM + 0.00016142264137621246*NL + 
        0.00007973176657964865*lm*NL + 0.00003549729230101178*lm^2*NL - 
        0.00003772083574987856*NH + 0.00007973176657964865*lm*NH + 
        0.00003549729230101178*lm^2*NH)}, 
     {0.91, CF*NC*(CA*(-0.0004856406819569959 - 0.0006708292676177497*lm - 
          0.0001911837175935663*lm^2) + CF*(0.0004944658403877283 + 
          0.0012861221064619838*lm + 0.0012513843333397064*lm^2) - 
        0.000016487086318743335*NM + 0.00007772809747909618*lm*NM + 
        0.00003476067592610296*lm^2*NM + 0.00015765719217856526*NL + 
        0.00007772809747909618*lm*NL + 0.00003476067592610296*lm^2*NL - 
        0.000036774850231060596*NH + 0.00007772809747909618*lm*NH + 
        0.00003476067592610296*lm^2*NH)}, 
     {0.915, CF*NC*(CA*(-0.0004722004536620604 - 0.0006550642403078456*lm - 
          0.00018722665744314254*lm^2) + CF*(0.0004780728348134231 + 
          0.0012471941855209797*lm + 0.0012254835759914786*lm^2) - 
        0.000017136503711700785*NM + 0.00007577741221788934*lm*NM + 
        0.000034041210444207736*lm^2*NM + 0.00015399014070878954*NL + 
        0.00007577741221788934*lm*NL + 0.000034041210444207736*lm^2*NL - 
        0.00003585283266647892*NH + 0.00007577741221788934*lm*NH + 
        0.000034041210444207736*lm^2*NH)}, 
     {0.92, CF*NC*(CA*(-0.00045914891347623865 - 0.0006396993962695017*lm - 
          0.0001833614939375177*lm^2) + CF*(0.0004622240932997298 + 
          0.0012093932748613475*lm + 0.0012001843239546612*lm^2) - 
        0.000017746298874548915*NM + 0.00007387822221221936*lm*NM + 
        0.00003333845344318504*lm^2*NM + 0.00015041866688104885*NL + 
        0.00007387822221221936*lm*NL + 0.00003333845344318504*lm^2*NL - 
        0.00003495414748683739*NH + 0.00007387822221221936*lm*NH + 
        0.00003333845344318504*lm^2*NH)}, 
     {0.925, CF*NC*(CA*(-0.0004464742458017527 - 0.0006247237833949096*lm - 
          0.00017958586259953852*lm^2) + CF*(0.0004469017055023082 + 
          0.0011726860862865721*lm + 0.0011754711006515249*lm^2) - 
        0.00001831813511191526*NM + 0.00007202908332149532*lm*NM + 
        0.00003265197501809791*lm^2*NM + 0.00014694003797680006*NL + 
        0.00007202908332149532*lm*NL + 0.00003265197501809791*lm^2*NL - 
        0.000034078176934054655*NH + 0.00007202908332149532*lm*NH + 
        0.00003265197501809791*lm^2*NH)}, 
     {0.93, CF*NC*(CA*(-0.00043416501274146405 - 0.0006101267711540822*lm - 
          0.00017589746563073433*lm^2) + CF*(0.0004320883515981222 + 
          0.00113704035363339*lm + 0.0011513288659466248*lm^2) - 
        0.000018853610901703414*NM + 0.00007022859444404338*lm*NM + 
        0.00003198135738740624*lm^2*NM + 0.00014355160575162189*NL + 
        0.00007022859444404338*lm*NL + 0.00003198135738740624*lm^2*NL - 
        0.000033224320533640075*NH + 0.00007022859444404338*lm*NH + 
        0.00003198135738740624*lm^2*NH)}, 
     {0.935, CF*NC*(CA*(-0.0004222101414439605 - 0.0005958980405297727*lm - 
          0.00017229406987007105*lm^2) + CF*(0.000417767282710518 + 
          0.0011024248000404155*lm + 0.0011277430027859196*lm^2) - 
        0.000019354262406480054*NM + 0.00006847539615944635*lm*NM + 
        0.0000313261945218311*lm^2*NM + 0.000140250803643438*NL + 
        0.00006847539615944635*lm*NL + 0.0000313261945218311*lm^2*NL - 
        0.000032391994583517705*NH + 0.00006847539615944635*lm*NH + 
        0.0000313261945218311*lm^2*NH)}, 
     {0.94, CF*NC*(CA*(-0.00041059891189026173 - 0.0005820275742856239*lm - 
          0.0001687735048199452*lm^2) + CF*(0.0004039223019820013 + 
          0.001068809106305965*lm + 0.001104699304276005*lm^2) - 
        0.000019821565885928617*NM + 0.00006676816941591123*lm*NM + 
        0.00003068609178544458*lm^2*NM + 0.00013703514407841134*NL + 
        0.00006676816941591123*lm*NL + 0.00003068609178544458*lm^2*NL - 
        0.00003158063165876297*NH + 0.00006676816941591123*lm*NH + 
        0.00003068609178544458*lm^2*NH)}, 
     {0.945, CF*NC*(CA*(-0.00039932094510625003 - 0.0005685056475559879*lm - 
          0.00016533366073705433*lm^2) + CF*(0.0003905377462738015 + 
          0.0010361638802977736*lm + 0.0010821839611879918*lm^2) - 
        0.00002025694001436044*NM + 0.00006510563426110918*lm*NM + 
        0.00003006066558855533*lm^2*NM + 0.00013390221587092956*NL + 
        0.00006510563426110918*lm*NL + 0.00003006066558855533*lm^2*NL - 
        0.0000307896801317346*NH + 0.00006510563426110918*lm*NH + 
        0.00003006066558855533*lm^2*NH)}, 
     {0.95, CF*NC*(CA*(-0.00038836619178551283 - 0.0005553228187462658*lm - 
          0.00016197248678586894*lm^2) + CF*(0.0003775984684719308 + 
          0.0010044606273785952*lm + 0.001060183549871142*lm^2) - 
        0.0000206617481071095*NM + 0.00006348654861498774*lm*NM + 
        0.00002944954305197617*lm^2*NM + 0.0001308496817142352*NL + 
        0.00006348654861498774*lm*NL + 0.00002944954305197617*lm^2*NL - 
        0.00003001860370710196*NH + 0.00006348654861498774*lm*NH + 
        0.00002944954305197617*lm^2*NH)}, 
     {0.955, CF*NC*(CA*(-0.00037772492130784367 - 0.0005424699207330241*lm - 
          0.00015868798925251478*lm^2) + CF*(0.00036508982038005466 + 
          0.000973671721812922*lm + 0.001038685020561915*lm^2) - 
        0.000021037300259479015*NM + 0.0000619097070831084*lm*NM + 
        0.000028852361682275412*lm^2*NM + 0.00012787527575838746*NL + 
        0.0000619097070831084*lm*NL + 0.000028852361682275412*lm^2*NL - 
        0.0000292668809712844*NH + 0.0000619097070831084*lm*NH + 
        0.000028852361682275412*lm^2*NH)}, 
     {0.96, CF*NC*(CA*(-0.0003673877111391886 - 0.0005299380523535249*lm - 
          0.00015547822981695596*lm^2) + CF*(0.0003529976361800846 + 
          0.0009437703791212666*lm + 0.0010176756860746207*lm^2) - 
        0.000021384855401757203*NM + 0.00006037393980911389*lm*NM + 
        0.000028268769057628355*lm^2*NM + 0.00012497680127236555*NL + 
        0.00006037393980911389*lm*NL + 0.000028268769057628355*lm^2*NL - 
        0.000028534004955835765*NH + 0.00006037393980911389*lm*NH + 
        0.000028268769057628355*lm^2*NH)}, 
     {0.965, CF*NC*(CA*(-0.0003573454365993436 - 0.0005177185701746811*lm - 
          0.0001523413238814471*lm^2) + CF*(0.00034130821644198285 + 
          0.0009147306293496194*lm + 0.0009971432108603808*lm^2) - 
        0.00002170562327367442*NM + 0.00005887811136497907*lm*NM + 
        0.00002769842252389947*lm^2*NM + 0.00012215212838724698*NL + 
        0.00005887811136497907*lm*NL + 0.00002769842252389947*lm^2*NL - 
        0.00002781948271432255*NH + 0.00005887811136497907*lm*NH + 
        0.00002769842252389947*lm^2*NH)}, 
     {0.97, CF*NC*(CA*(-0.00034758926098421117 - 0.0005058030805318057*lm - 
          0.00014927543895329768*lm^2) + CF*(0.0003300083126648366 + 
          0.0008865272912228117*lm + 0.0009770756004215848*lm^2) - 
        0.00002200076632153532*NM + 0.00005742111967774703*lm*NM + 
        0.000027140988900599575*lm^2*NM + 0.00011939919191750794*NL + 
        0.00005742111967774703*lm*NL + 0.000027140988900599575*lm^2*NL - 
        0.00002712283491225954*NH + 0.00005742111967774703*lm*NH + 
        0.000027140988900599575*lm^2*NH)}, 
     {0.975, CF*NC*(CA*(-0.00033811062602990627 - 0.0004941834318278669*lm - 
          0.00014627879308006412*lm^2) + CF*(0.000319085112331809 + 
          0.0008591359471516082*lm + 0.0009574611910695105*lm^2) - 
        0.000022271401521126658*NM + 0.00005600189499149815*lm*NM + 
        0.000026596144196375293*lm^2*NM + 0.00011671598925760609*NL + 
        0.00005600189499149815*lm*NL + 0.000026596144196375293*lm^2*NL - 
        0.000026443595429681262*NH + 0.00005600189499149815*lm*NH + 
        0.000026596144196375293*lm^2*NH)}, 
     {0.98, CF*NC*(CA*(-0.00032890124270646684 - 0.000482851707084296*lm - 
          0.0001433496533353538*lm^2) + CF*(0.0003085262244621129 + 
          0.0008325329190643983*lm + 0.0009382886400132249*lm^2) - 
        0.000022518602129373976*NM + 0.00005461939886334385*lm*NM + 
        0.000026063573333700693*lm^2*NM + 0.00011410057835111275*NL + 
        0.00005461939886334385*lm*NL + 0.000026063573333700693*lm^2*NL - 
        0.000025781310975941696*NH + 0.00005461939886334385*lm*NH + 
        0.000026063573333700693*lm^2*NH)}, 
     {0.985, CF*NC*(CA*(-0.00031995308232937313 - 0.0004718002167347132*lm - 
          0.00014048633435349272*lm^2) + CF*(0.0002983196656436771 + 
          0.0008066952450353689*lm + 0.0009195469157683161*lm^2) - 
        0.000022743399367598432*NM + 0.000053272623192280116*lm*NM + 
        0.000025542969882453223*lm^2*NM + 0.00011155107572976505*NL + 
        0.000053272623192280116*lm*NL + 0.000025542969882453223*lm^2*NL - 
        0.000025135540716348333*NH + 0.000053272623192280116*lm*NH + 
        0.000025542969882453223*lm^2*NH)}, 
     {0.99, CF*NC*(CA*(-0.00031125836797751117 - 0.00046102149165324377*lm - 
          0.00013768719691137138*lm^2) + CF*(0.0002884538465306854 + 
          0.0007816006566820194*lm + 0.0009012252888744307*lm^2) - 
        0.000022946784039107967*NM + 0.00005196058927977657*lm*NM + 
        0.000025034035802067523*lm^2*NM + 0.00010906565461990681*NL + 
        0.00005196058927977657*lm*NL + 0.000025034035802067523*lm^2*NL - 
        0.000024505855910249817*NH + 0.00005196058927977657*lm*NH + 
        0.000025034035802067523*lm^2*NH)}, 
     {0.995, CF*NC*(CA*(-0.00030280956620663206 - 0.0004505082764093973*lm - 
          0.00013495064655584616*lm^2) + CF*(0.00027891755879066397 + 
          0.0007572275573058261*lm + 0.000883313322910993*lm^2) - 
        0.00002312970808374513*NM + 0.000050682346921016925*lm*NM + 
        0.000024536481191972028*lm^2*NM + 0.0001066425431138837*NL + 
        0.000050682346921016925*lm*NL + 0.000024536481191972028*lm^2*NL - 
        0.0000238918395602091*NH + 0.000050682346921016925*lm*NH + 
        0.000024536481191972028*lm^2*NH)}, 
     {1., 2.67535089600195*^-20*CF*NC*(-1.*CA*(1.1011616438352386*^16 + 
          1.645591699390464*^16*lm + 4.944216195072*^15*lm^2) + 
        2.*(63.*CF*(8.000729534009794*^13 + 2.1761127088128*^14*lm + 
            2.56842399744*^14*lm^2) + 1260.*(-3.454981601697765*^11 + 
            7.33281255424*^11*lm + 3.567255552*^11*lm^2)*NM + 
          1.948903647739904*^15*NL + 9.2393438183424*^14*lm*NL + 
          4.49474199552*^14*lm^2*NL - 4.353276818139184*^14*NH + 
          9.2393438183424*^14*lm*NH + 4.49474199552*^14*lm^2*NH))}}


(********************************)
End[]
EndPackage[]
(********************************)					   

Protect["coefhl2`*"] ;
Unprotect[Cbar2] ;
Unprotect[CbarL2] ;

Protect[Global`ep] ;

WriteString[
  "stdout",
  "Package: coefhl2.m\n",
  "Version 2.0 (June 2012)\n"
];

